#include <stdio.h>
#include "uninameslist.h"
#include "nameslist-dll.h"

/* This file was generated using the program 'buildnameslist.c' */


/*
The data contained in these arrays were derived from data contained in
NamesList.txt which came from www.unicode.org. Below is the copyright
notice for the information given:

UNICODE LICENSE V3

COPYRIGHT AND PERMISSION NOTICE

Copyright © 1991-2024 Unicode, Inc.

NOTICE TO USER: Carefully read the following legal agreement. BY
DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING DATA FILES, AND/OR
SOFTWARE, YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
TERMS AND CONDITIONS OF THIS AGREEMENT. IF YOU DO NOT AGREE, DO NOT
DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE THE DATA FILES OR SOFTWARE.
Permission is hereby granted, free of charge, to any person obtaining a
copy of data files and any associated documentation (the "Data Files") or
software and any associated documentation (the "Software") to deal in the
Data Files or Software without restriction, including without limitation
the rights to use, copy, modify, merge, publish, distribute, and/or sell
copies of the Data Files or Software, and to permit persons to whom the
Data Files or Software are furnished to do so, provided that either (a)
this copyright and permission notice appear with all copies of the Data
Files or Software, or (b) this copyright and permission notice appear in
associated Documentation.

THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF ANY
KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT OF
THIRD PARTY RIGHTS.

IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS NOTICE
BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL DAMAGES,
OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS,
WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION,
ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THE DATA
FILES OR SOFTWARE.

Except as contained in this notice, the name of a copyright holder shall
not be used in advertising or otherwise to promote the sale, use or other
dealings in these Data Files or Software without prior written
authorization of the copyright holder.

*/

/* Retrieve a pointer to the name of a Unicode codepoint. */
UN_DLL_EXPORT
const char *uniNamesList_name(unsigned long uni) {
	const char *pt=NULL;

	if ( uni<0x110000 )
		pt=UnicodeNameAnnot[uni>>16][(uni>>8)&0xff][uni&0xff].name;
	return( pt );
}

/* Retrieve a pointer to annotation details of a Unicode codepoint. */
UN_DLL_EXPORT
const char *uniNamesList_annot(unsigned long uni) {
	const char *pt=NULL;

	if ( uni<0x110000 )
		pt=UnicodeNameAnnot[uni>>16][(uni>>8)&0xff][uni&0xff].annot;
	return( pt );
}

/* Retrieve Nameslist.txt version number. */
UN_DLL_EXPORT
const char *uniNamesList_NamesListVersion(void) {
	return( "Nameslist-Version: 17.0" );
}


/* These functions are available in libuninameslist-0.4.20140731 and higher */

/* Return number of blocks in this NamesList. */
UN_DLL_EXPORT
int uniNamesList_blockCount(void) {
	return( UNICODE_EN_BLOCK_MAX );
}

/* Return block number for this unicode value, -1 if unlisted unicode value */
UN_DLL_EXPORT
int uniNamesList_blockNumber(unsigned long uni) {
	int i;

	if ( uni<0x110000 ) {
		for (i=0; i<UNICODE_EN_BLOCK_MAX; i++) {
			if ( uni<(unsigned long)(UnicodeBlock[i].start) ) break;
			if ( uni<=(unsigned long)(UnicodeBlock[i].end) ) return( i );
		}
	}
	return( -1 );
}

/* Return unicode value starting this Unicode block (-1 if bad uniBlock). */
UN_DLL_EXPORT
long uniNamesList_blockStart(int uniBlock) {
	if ( uniBlock<0 || uniBlock>=UNICODE_EN_BLOCK_MAX )
		return( -1 );
	return( (long)(UnicodeBlock[uniBlock].start) );
}

/* Return unicode value ending this Unicode block (-1 if bad uniBlock). */
UN_DLL_EXPORT
long uniNamesList_blockEnd(int uniBlock) {
	if ( uniBlock<0 || uniBlock>=UNICODE_EN_BLOCK_MAX )
		return( -1 );
	return( (long)(UnicodeBlock[uniBlock].end) );
}

/* Return a pointer to the blockname for this unicode block. */
UN_DLL_EXPORT
const char * uniNamesList_blockName(int uniBlock) {
	if ( uniBlock<0 || uniBlock>=UNICODE_EN_BLOCK_MAX )
		return( NULL );
	return( UnicodeBlock[uniBlock].name );
}


/* These functions are available in libuninameslist-20171118 and higher */

/* Return count of how many names2 are found in this version of library */
UN_DLL_EXPORT
int uniNamesList_names2cnt(void) {
	return( 40 );
}

static const unsigned long unicode_name2code[] = {
	0x01A2, 0x01A3, 0x0616, 0x0709, 0x0CDE, 0x0E9D, 0x0E9F, 0x0EA3,
	0x0EA5, 0x0FD0, 0x11EC, 0x11ED, 0x11EE, 0x11EF, 0x1BBD, 0x2118,
	0x2448, 0x2449, 0x2B7A, 0x2B7C, 0xA015, 0xAA6E, 0xFE18, 0xFEFF,
	74452, 74453, 74535, 92171, 92289, 92302, 92380, 92541,
	93782, 93783, 93814, 93815, 110593, 118981, 125081, 125082
};

static const char unicode_name2vals[] = {
	3,24, 3,22, 3,47, 3,34, 3,19, 3,17, 3,17, 3,13,
	3,13, 3,35, 3,32, 3,37, 3,30, 3,33, 3,26, 3,29,
	3,17, 3,16, 3,59, 3,60, 3,26, 3,25, 3,61, 3,15,
	3,24, 3,42, 3,20, 3,30, 3,29, 3,26, 3,28, 3,26,
	3,28, 3,29, 3,26, 3,27, 3,21, 3,52, 3,31, 3,32
};

/* Return unicode value with names2 (0<=count<uniNamesList_names2cnt(). */
UN_DLL_EXPORT
long uniNamesList_names2val(int count) {
	if ( count<0 || count>=40 ) return( -1 );
	return( (long)(unicode_name2code[count]) );
}

/* Return list location for this unicode value. Return -1 if not found. */
UN_DLL_EXPORT
int uniNamesList_names2getU(unsigned long uni) {
	int i;

	if ( uni<0x110000 ) for ( i=0; i<40; ++i ) {
		if ( uni==unicode_name2code[i] ) return( i );
		if ( uni<unicode_name2code[i] ) break;
	}
	return( -1 );
}

/* Stringlength of names2. Use this if you want to truncate annotations */
UN_DLL_EXPORT
int uniNamesList_names2lnC(int count) {
	if ( count<0 || count>=40 ) return( -1 );
	return( (int)(unicode_name2vals[(count<<1)+1]) );
}

UN_DLL_EXPORT
int uniNamesList_names2lnU(unsigned long uni) {
	return( uniNamesList_names2lnC(uniNamesList_names2getU(uni)) );
}

/* Return pointer to start of normalized alias names2 within annotation */
UN_DLL_EXPORT
const char *uniNamesList_names2anC(int count) {
	int c;
	const char *pt;

	if ( count<0 || count>=40 ) return( NULL );
	c = unicode_name2vals[count<<1];
	pt = uniNamesList_annot((unsigned long)(uniNamesList_names2val(count)));
	while ( --c>=0 ) ++pt;
	return( pt );
}

UN_DLL_EXPORT
const char *uniNamesList_names2anU(unsigned long uni) {
	return( uniNamesList_names2anC(uniNamesList_names2getU(uni)) );
}


/* These functions are available in libuninameslist-20200413 and higher */

UN_DLL_LOCAL
int uniNamesList_haveFR(unsigned int lang) {
#ifdef WANTLIBOFR
	if ( lang==1 ) return( 1 );
#endif
	return( 0 );
}

#ifndef WANTLIBOFR
/* make these internal stubs since there's no French lib */
UN_DLL_LOCAL const char *uniNamesList_NamesListVersionFR(void) {return( NULL );}
UN_DLL_LOCAL const char *uniNamesList_nameFR(unsigned long uni) {return( NULL );}
UN_DLL_LOCAL const char *uniNamesList_annotFR(unsigned long uni) {return( NULL );}
UN_DLL_LOCAL int uniNamesList_blockCountFR(void) {return( -1 );}
UN_DLL_LOCAL int uniNamesList_blockNumberFR(unsigned long uni) {return( -1 );}
UN_DLL_LOCAL long uniNamesList_blockStartFR(int uniBlock) {return( -1 );}
UN_DLL_LOCAL long uniNamesList_blockEndFR(int uniBlock) {return( -1 );}
UN_DLL_LOCAL const char *uniNamesList_blockNameFR(int uniBlock) {return( NULL );}
#endif

/* Return language codes available from libraries. 0=English, 1=French. */
UN_DLL_EXPORT
const char *uniNamesList_Languages(unsigned int lang) {
	if ( uniNamesList_haveFR(lang) )
		return( "FR" );
	else if ( lang==0 )
		return( "EN" );
	return( NULL );
}

UN_DLL_EXPORT
const char *uniNamesList_NamesListVersionAlt(unsigned int lang) {
	if ( uniNamesList_haveFR(lang) )
		return( (const char *)(uniNamesList_NamesListVersionFR()) );
	else if ( lang==0 )
		return( uniNamesList_NamesListVersion() );
	return( NULL );
}

/* Return pointer to name/annotation for this unicode value using lang. */
/* Return English if language does not have information for this Ucode. */
UN_DLL_EXPORT
const char *uniNamesList_nameAlt(unsigned long uni, unsigned int lang) {
	const char *pt=NULL;

	if ( uni<0x110000 ) {
		if ( uniNamesList_haveFR(lang) )
			pt=(const char *)(uniNamesList_nameFR(uni));
		if ( pt==NULL )
			pt=uniNamesList_name(uni);
	}
	return( pt );
}

UN_DLL_EXPORT
const char *uniNamesList_annotAlt(unsigned long uni, unsigned int lang) {
	const char *pt=NULL;

	if ( uni<0x110000 ) {
		if ( uniNamesList_haveFR(lang) )
			pt=(const char *)(uniNamesList_annotFR(uni));
		if ( pt==NULL )
			pt=uniNamesList_annot(uni);
	}
	return( pt );
}

/* Returns 2 lang pointers to names/annotations for this unicode value, */
/* Return str0=English, and str1=language_version (or NULL if no info). */
UN_DLL_EXPORT
int uniNamesList_nameBoth(unsigned long uni, unsigned int lang, const char **str0, const char **str1) {
	int error=-1;
	*str0=*str1=NULL;

	if ( uni<0x110000 ) {
		error=0;
		*str0=uniNamesList_name(uni);
		if ( uniNamesList_haveFR(lang) )
			*str1=(const char *)(uniNamesList_nameFR(uni));
		else if ( lang==0 )
			*str1=*str0;
	}
	return( error );
}

UN_DLL_EXPORT
int uniNamesList_annotBoth(unsigned long uni, unsigned int lang, const char **str0, const char **str1) {
	int error=-1;
	*str0=*str1=NULL;

	if ( uni<0x110000 ) {
		error=0;
		*str0=uniNamesList_annot(uni);
		if ( uniNamesList_haveFR(lang) )
			*str1=(const char *)(uniNamesList_annotFR(uni));
		else if ( lang==0 )
			*str1=*str0;
	}
	return( error );
}

/* Common access. Blocklists won't sync if they are different versions. */
UN_DLL_EXPORT
int uniNamesList_blockCountAlt(unsigned int lang) {
	int c=-1;

	if ( uniNamesList_haveFR(lang) )
		c=(int)(uniNamesList_blockCountFR());
	if ( c<0 )
		c=UNICODE_EN_BLOCK_MAX;
	return( c );
}

UN_DLL_EXPORT
long uniNamesList_blockStartAlt(int uniBlock, unsigned int lang) {
	long c=-1;

	if ( uniNamesList_haveFR(lang) )
		c=(long)(uniNamesList_blockStartFR(uniBlock));
	if ( c<0 )
		c=uniNamesList_blockStart(uniBlock);
	return( c );
}

UN_DLL_EXPORT
long uniNamesList_blockEndAlt(int uniBlock, unsigned int lang) {
	long c=-1;

	if ( uniNamesList_haveFR(lang) )
		c=(long)(uniNamesList_blockEndFR(uniBlock));
	if ( c<0 )
		c=uniNamesList_blockEnd(uniBlock);
	return( c );
}

UN_DLL_EXPORT
const char *uniNamesList_blockNameAlt(int uniBlock, unsigned int lang) {
	const char *pt=NULL;

	if ( uniNamesList_haveFR(lang) )
		pt=(const char *)(uniNamesList_blockNameFR(uniBlock));
	if ( pt==NULL )
		pt=uniNamesList_blockName(uniBlock);
	return( pt );
}

UN_DLL_EXPORT
int uniNamesList_blockNumberBoth(unsigned long uni, unsigned int lang, int *bn0, int *bn1) {
	int error=-1;

	*bn0=*bn1=-1;
	if ( uni<0x110000 ) {
		error=0;
		*bn0=uniNamesList_blockNumber(uni);
		if ( uniNamesList_haveFR(lang) )
			*bn1=(int)(uniNamesList_blockNumberFR(uni));
		else if ( lang==0 )
			*bn1=*bn0;
	}
	return( error );
}


UN_DLL_LOCAL
static const struct unicode_nameannot nullarray[] = {
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL }
};

UN_DLL_LOCAL
static const struct unicode_nameannot nullarray2[] = {
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL },
	{ NULL, "	* the value ?FFFE is guaranteed not to be a Unicode character at all" },
	{ NULL, "	* the value ?FFFF is guaranteed not to be a Unicode character at all" },
};

UN_DLL_LOCAL
static const struct unicode_nameannot * const nullnullarray[] = {
	nullarray, nullarray, nullarray, nullarray, nullarray, nullarray, nullarray, nullarray,
	nullarray, nullarray, nullarray, nullarray, nullarray, nullarray, nullarray, nullarray,
	nullarray, nullarray, nullarray, nullarray, nullarray, nullarray, nullarray, nullarray,
	nullarray, nullarray, nullarray, nullarray, nullarray, nullarray, nullarray, nullarray,
	nullarray, nullarray, nullarray, nullarray, nullarray, nullarray, nullarray, nullarray,
	nullarray, nullarray, nullarray, nullarray, nullarray, nullarray, nullarray, nullarray,
	nullarray, nullarray, nullarray, nullarray, nullarray, nullarray, nullarray, nullarray,
	nullarray, nullarray, nullarray, nullarray, nullarray, nullarray, nullarray, nullarray,
	nullarray, nullarray, nullarray, nullarray, nullarray, nullarray, nullarray, nullarray,
	nullarray, nullarray, nullarray, nullarray, nullarray, nullarray, nullarray, nullarray,
	nullarray, nullarray, nullarray, nullarray, nullarray, nullarray, nullarray, nullarray,
	nullarray, nullarray, nullarray, nullarray, nullarray, nullarray, nullarray, nullarray,
	nullarray, nullarray, nullarray, nullarray, nullarray, nullarray, nullarray, nullarray,
	nullarray, nullarray, nullarray, nullarray, nullarray, nullarray, nullarray, nullarray,
	nullarray, nullarray, nullarray, nullarray, nullarray, nullarray, nullarray, nullarray,
	nullarray, nullarray, nullarray, nullarray, nullarray, nullarray, nullarray, nullarray,
	nullarray, nullarray, nullarray, nullarray, nullarray, nullarray, nullarray, nullarray,
	nullarray, nullarray, nullarray, nullarray, nullarray, nullarray, nullarray, nullarray,
	nullarray, nullarray, nullarray, nullarray, nullarray, nullarray, nullarray, nullarray,
	nullarray, nullarray, nullarray, nullarray, nullarray, nullarray, nullarray, nullarray,
	nullarray, nullarray, nullarray, nullarray, nullarray, nullarray, nullarray, nullarray,
	nullarray, nullarray, nullarray, nullarray, nullarray, nullarray, nullarray, nullarray,
	nullarray, nullarray, nullarray, nullarray, nullarray, nullarray, nullarray, nullarray,
	nullarray, nullarray, nullarray, nullarray, nullarray, nullarray, nullarray, nullarray,
	nullarray, nullarray, nullarray, nullarray, nullarray, nullarray, nullarray, nullarray,
	nullarray, nullarray, nullarray, nullarray, nullarray, nullarray, nullarray, nullarray,
	nullarray, nullarray, nullarray, nullarray, nullarray, nullarray, nullarray, nullarray,
	nullarray, nullarray, nullarray, nullarray, nullarray, nullarray, nullarray, nullarray,
	nullarray, nullarray, nullarray, nullarray, nullarray, nullarray, nullarray, nullarray,
	nullarray, nullarray, nullarray, nullarray, nullarray, nullarray, nullarray, nullarray,
	nullarray, nullarray, nullarray, nullarray, nullarray, nullarray, nullarray, nullarray,
	nullarray, nullarray, nullarray, nullarray, nullarray, nullarray, nullarray, nullarray,
	nullarray, nullarray, nullarray, nullarray, nullarray, nullarray, nullarray, nullarray2
};

UN_DLL_EXPORT
const struct unicode_block UnicodeBlock[] = {
	{ 0x0, 0x7f, "C0 Controls and Basic Latin (Basic Latin)" },
	{ 0x80, 0xff, "C1 Controls and Latin-1 Supplement (Latin-1 Supplement)" },
	{ 0x100, 0x17f, "Latin Extended-A" },
	{ 0x180, 0x24f, "Latin Extended-B" },
	{ 0x250, 0x2af, "IPA Extensions" },
	{ 0x2b0, 0x2ff, "Spacing Modifier Letters" },
	{ 0x300, 0x36f, "Combining Diacritical Marks" },
	{ 0x370, 0x3ff, "Greek and Coptic" },
	{ 0x400, 0x4ff, "Cyrillic" },
	{ 0x500, 0x52f, "Cyrillic Supplement" },
	{ 0x530, 0x58f, "Armenian" },
	{ 0x590, 0x5ff, "Hebrew" },
	{ 0x600, 0x6ff, "Arabic" },
	{ 0x700, 0x74f, "Syriac" },
	{ 0x750, 0x77f, "Arabic Supplement" },
	{ 0x780, 0x7bf, "Thaana" },
	{ 0x7c0, 0x7ff, "NKo" },
	{ 0x800, 0x83f, "Samaritan" },
	{ 0x840, 0x85f, "Mandaic" },
	{ 0x860, 0x86f, "Syriac Supplement" },
	{ 0x870, 0x89f, "Arabic Extended-B" },
	{ 0x8a0, 0x8ff, "Arabic Extended-A" },
	{ 0x900, 0x97f, "Devanagari" },
	{ 0x980, 0x9ff, "Bengali" },
	{ 0xa00, 0xa7f, "Gurmukhi" },
	{ 0xa80, 0xaff, "Gujarati" },
	{ 0xb00, 0xb7f, "Oriya" },
	{ 0xb80, 0xbff, "Tamil" },
	{ 0xc00, 0xc7f, "Telugu" },
	{ 0xc80, 0xcff, "Kannada" },
	{ 0xd00, 0xd7f, "Malayalam" },
	{ 0xd80, 0xdff, "Sinhala" },
	{ 0xe00, 0xe7f, "Thai" },
	{ 0xe80, 0xeff, "Lao" },
	{ 0xf00, 0xfff, "Tibetan" },
	{ 0x1000, 0x109f, "Myanmar" },
	{ 0x10a0, 0x10ff, "Georgian" },
	{ 0x1100, 0x11ff, "Hangul Jamo" },
	{ 0x1200, 0x137f, "Ethiopic" },
	{ 0x1380, 0x139f, "Ethiopic Supplement" },
	{ 0x13a0, 0x13ff, "Cherokee" },
	{ 0x1400, 0x167f, "Unified Canadian Aboriginal Syllabics" },
	{ 0x1680, 0x169f, "Ogham" },
	{ 0x16a0, 0x16ff, "Runic" },
	{ 0x1700, 0x171f, "Tagalog" },
	{ 0x1720, 0x173f, "Hanunoo" },
	{ 0x1740, 0x175f, "Buhid" },
	{ 0x1760, 0x177f, "Tagbanwa" },
	{ 0x1780, 0x17ff, "Khmer" },
	{ 0x1800, 0x18af, "Mongolian" },
	{ 0x18b0, 0x18ff, "Unified Canadian Aboriginal Syllabics Extended" },
	{ 0x1900, 0x194f, "Limbu" },
	{ 0x1950, 0x197f, "Tai Le" },
	{ 0x1980, 0x19df, "New Tai Lue" },
	{ 0x19e0, 0x19ff, "Khmer Symbols" },
	{ 0x1a00, 0x1a1f, "Buginese" },
	{ 0x1a20, 0x1aaf, "Tai Tham" },
	{ 0x1ab0, 0x1aff, "Combining Diacritical Marks Extended" },
	{ 0x1b00, 0x1b7f, "Balinese" },
	{ 0x1b80, 0x1bbf, "Sundanese" },
	{ 0x1bc0, 0x1bff, "Batak" },
	{ 0x1c00, 0x1c4f, "Lepcha" },
	{ 0x1c50, 0x1c7f, "Ol Chiki" },
	{ 0x1c80, 0x1c8f, "Cyrillic Extended-C" },
	{ 0x1c90, 0x1cbf, "Georgian Extended" },
	{ 0x1cc0, 0x1ccf, "Sundanese Supplement" },
	{ 0x1cd0, 0x1cff, "Vedic Extensions" },
	{ 0x1d00, 0x1d7f, "Phonetic Extensions" },
	{ 0x1d80, 0x1dbf, "Phonetic Extensions Supplement" },
	{ 0x1dc0, 0x1dff, "Combining Diacritical Marks Supplement" },
	{ 0x1e00, 0x1eff, "Latin Extended Additional" },
	{ 0x1f00, 0x1fff, "Greek Extended" },
	{ 0x2000, 0x206f, "General Punctuation" },
	{ 0x2070, 0x209f, "Superscripts and Subscripts" },
	{ 0x20a0, 0x20cf, "Currency Symbols" },
	{ 0x20d0, 0x20ff, "Combining Diacritical Marks for Symbols" },
	{ 0x2100, 0x214f, "Letterlike Symbols" },
	{ 0x2150, 0x218f, "Number Forms" },
	{ 0x2190, 0x21ff, "Arrows" },
	{ 0x2200, 0x22ff, "Mathematical Operators" },
	{ 0x2300, 0x23ff, "Miscellaneous Technical" },
	{ 0x2400, 0x243f, "Control Pictures" },
	{ 0x2440, 0x245f, "Optical Character Recognition" },
	{ 0x2460, 0x24ff, "Enclosed Alphanumerics" },
	{ 0x2500, 0x257f, "Box Drawing" },
	{ 0x2580, 0x259f, "Block Elements" },
	{ 0x25a0, 0x25ff, "Geometric Shapes" },
	{ 0x2600, 0x26ff, "Miscellaneous Symbols" },
	{ 0x2700, 0x27bf, "Dingbats" },
	{ 0x27c0, 0x27ef, "Miscellaneous Mathematical Symbols-A" },
	{ 0x27f0, 0x27ff, "Supplemental Arrows-A" },
	{ 0x2800, 0x28ff, "Braille Patterns" },
	{ 0x2900, 0x297f, "Supplemental Arrows-B" },
	{ 0x2980, 0x29ff, "Miscellaneous Mathematical Symbols-B" },
	{ 0x2a00, 0x2aff, "Supplemental Mathematical Operators" },
	{ 0x2b00, 0x2bff, "Miscellaneous Symbols and Arrows" },
	{ 0x2c00, 0x2c5f, "Glagolitic" },
	{ 0x2c60, 0x2c7f, "Latin Extended-C" },
	{ 0x2c80, 0x2cff, "Coptic" },
	{ 0x2d00, 0x2d2f, "Georgian Supplement" },
	{ 0x2d30, 0x2d7f, "Tifinagh" },
	{ 0x2d80, 0x2ddf, "Ethiopic Extended" },
	{ 0x2de0, 0x2dff, "Cyrillic Extended-A" },
	{ 0x2e00, 0x2e7f, "Supplemental Punctuation" },
	{ 0x2e80, 0x2eff, "CJK Radicals Supplement" },
	{ 0x2f00, 0x2fdf, "Kangxi Radicals" },
	{ 0x2ff0, 0x2fff, "Ideographic Description Characters" },
	{ 0x3000, 0x303f, "CJK Symbols and Punctuation" },
	{ 0x3040, 0x309f, "Hiragana" },
	{ 0x30a0, 0x30ff, "Katakana" },
	{ 0x3100, 0x312f, "Bopomofo" },
	{ 0x3130, 0x318f, "Hangul Compatibility Jamo" },
	{ 0x3190, 0x319f, "Kanbun" },
	{ 0x31a0, 0x31bf, "Bopomofo Extended" },
	{ 0x31c0, 0x31ef, "CJK Strokes" },
	{ 0x31f0, 0x31ff, "Katakana Phonetic Extensions" },
	{ 0x3200, 0x32ff, "Enclosed CJK Letters and Months" },
	{ 0x3300, 0x33ff, "CJK Compatibility" },
	{ 0x3400, 0x4dbf, "CJK Unified Ideographs Extension A" },
	{ 0x4dc0, 0x4dff, "Yijing Hexagram Symbols" },
	{ 0x4e00, 0x9fff, "CJK Unified Ideographs" },
	{ 0xa000, 0xa48f, "Yi Syllables" },
	{ 0xa490, 0xa4cf, "Yi Radicals" },
	{ 0xa4d0, 0xa4ff, "Lisu" },
	{ 0xa500, 0xa63f, "Vai" },
	{ 0xa640, 0xa69f, "Cyrillic Extended-B" },
	{ 0xa6a0, 0xa6ff, "Bamum" },
	{ 0xa700, 0xa71f, "Modifier Tone Letters" },
	{ 0xa720, 0xa7ff, "Latin Extended-D" },
	{ 0xa800, 0xa82f, "Syloti Nagri" },
	{ 0xa830, 0xa83f, "Common Indic Number Forms" },
	{ 0xa840, 0xa87f, "Phags-pa" },
	{ 0xa880, 0xa8df, "Saurashtra" },
	{ 0xa8e0, 0xa8ff, "Devanagari Extended" },
	{ 0xa900, 0xa92f, "Kayah Li" },
	{ 0xa930, 0xa95f, "Rejang" },
	{ 0xa960, 0xa97f, "Hangul Jamo Extended-A" },
	{ 0xa980, 0xa9df, "Javanese" },
	{ 0xa9e0, 0xa9ff, "Myanmar Extended-B" },
	{ 0xaa00, 0xaa5f, "Cham" },
	{ 0xaa60, 0xaa7f, "Myanmar Extended-A" },
	{ 0xaa80, 0xaadf, "Tai Viet" },
	{ 0xaae0, 0xaaff, "Meetei Mayek Extensions" },
	{ 0xab00, 0xab2f, "Ethiopic Extended-A" },
	{ 0xab30, 0xab6f, "Latin Extended-E" },
	{ 0xab70, 0xabbf, "Cherokee Supplement" },
	{ 0xabc0, 0xabff, "Meetei Mayek" },
	{ 0xac00, 0xd7a3, "Hangul Syllables" },
	{ 0xd7b0, 0xd7ff, "Hangul Jamo Extended-B" },
	{ 0xd800, 0xdb7f, "High Surrogates" },
	{ 0xdb80, 0xdbff, "High Private Use Surrogates" },
	{ 0xdc00, 0xdfff, "Low Surrogates" },
	{ 0xe000, 0xf8ff, "Private Use Area" },
	{ 0xf900, 0xfaff, "CJK Compatibility Ideographs" },
	{ 0xfb00, 0xfb4f, "Alphabetic Presentation Forms" },
	{ 0xfb50, 0xfdff, "Arabic Presentation Forms-A" },
	{ 0xfe00, 0xfe0f, "Variation Selectors" },
	{ 0xfe10, 0xfe1f, "Vertical Forms" },
	{ 0xfe20, 0xfe2f, "Combining Half Marks" },
	{ 0xfe30, 0xfe4f, "CJK Compatibility Forms" },
	{ 0xfe50, 0xfe6f, "Small Form Variants" },
	{ 0xfe70, 0xfeff, "Arabic Presentation Forms-B" },
	{ 0xff00, 0xffef, "Halfwidth and Fullwidth Forms" },
	{ 0xfff0, 0xffff, "Specials" },
	{ 0x10000, 0x1007f, "Linear B Syllabary" },
	{ 0x10080, 0x100ff, "Linear B Ideograms" },
	{ 0x10100, 0x1013f, "Aegean Numbers" },
	{ 0x10140, 0x1018f, "Ancient Greek Numbers" },
	{ 0x10190, 0x101cf, "Ancient Symbols" },
	{ 0x101d0, 0x101ff, "Phaistos Disc" },
	{ 0x10280, 0x1029f, "Lycian" },
	{ 0x102a0, 0x102df, "Carian" },
	{ 0x102e0, 0x102ff, "Coptic Epact Numbers" },
	{ 0x10300, 0x1032f, "Old Italic" },
	{ 0x10330, 0x1034f, "Gothic" },
	{ 0x10350, 0x1037f, "Old Permic" },
	{ 0x10380, 0x1039f, "Ugaritic" },
	{ 0x103a0, 0x103df, "Old Persian" },
	{ 0x10400, 0x1044f, "Deseret" },
	{ 0x10450, 0x1047f, "Shavian" },
	{ 0x10480, 0x104af, "Osmanya" },
	{ 0x104b0, 0x104ff, "Osage" },
	{ 0x10500, 0x1052f, "Elbasan" },
	{ 0x10530, 0x1056f, "Caucasian Albanian" },
	{ 0x10570, 0x105bf, "Vithkuqi" },
	{ 0x105c0, 0x105ff, "Todhri" },
	{ 0x10600, 0x1077f, "Linear A" },
	{ 0x10780, 0x107bf, "Latin Extended-F" },
	{ 0x10800, 0x1083f, "Cypriot Syllabary" },
	{ 0x10840, 0x1085f, "Imperial Aramaic" },
	{ 0x10860, 0x1087f, "Palmyrene" },
	{ 0x10880, 0x108af, "Nabataean" },
	{ 0x108e0, 0x108ff, "Hatran" },
	{ 0x10900, 0x1091f, "Phoenician" },
	{ 0x10920, 0x1093f, "Lydian" },
	{ 0x10940, 0x1095f, "Sidetic" },
	{ 0x10980, 0x1099f, "Meroitic Hieroglyphs" },
	{ 0x109a0, 0x109ff, "Meroitic Cursive" },
	{ 0x10a00, 0x10a5f, "Kharoshthi" },
	{ 0x10a60, 0x10a7f, "Old South Arabian" },
	{ 0x10a80, 0x10a9f, "Old North Arabian" },
	{ 0x10ac0, 0x10aff, "Manichaean" },
	{ 0x10b00, 0x10b3f, "Avestan" },
	{ 0x10b40, 0x10b5f, "Inscriptional Parthian" },
	{ 0x10b60, 0x10b7f, "Inscriptional Pahlavi" },
	{ 0x10b80, 0x10baf, "Psalter Pahlavi" },
	{ 0x10c00, 0x10c4f, "Old Turkic" },
	{ 0x10c80, 0x10cff, "Old Hungarian" },
	{ 0x10d00, 0x10d3f, "Hanifi Rohingya" },
	{ 0x10d40, 0x10d8f, "Garay" },
	{ 0x10e60, 0x10e7f, "Rumi Numeral Symbols" },
	{ 0x10e80, 0x10ebf, "Yezidi" },
	{ 0x10ec0, 0x10eff, "Arabic Extended-C" },
	{ 0x10f00, 0x10f2f, "Old Sogdian" },
	{ 0x10f30, 0x10f6f, "Sogdian" },
	{ 0x10f70, 0x10faf, "Old Uyghur" },
	{ 0x10fb0, 0x10fdf, "Chorasmian" },
	{ 0x10fe0, 0x10fff, "Elymaic" },
	{ 0x11000, 0x1107f, "Brahmi" },
	{ 0x11080, 0x110cf, "Kaithi" },
	{ 0x110d0, 0x110ff, "Sora Sompeng" },
	{ 0x11100, 0x1114f, "Chakma" },
	{ 0x11150, 0x1117f, "Mahajani" },
	{ 0x11180, 0x111df, "Sharada" },
	{ 0x111e0, 0x111ff, "Sinhala Archaic Numbers" },
	{ 0x11200, 0x1124f, "Khojki" },
	{ 0x11280, 0x112af, "Multani" },
	{ 0x112b0, 0x112ff, "Khudawadi" },
	{ 0x11300, 0x1137f, "Grantha" },
	{ 0x11380, 0x113ff, "Tulu-Tigalari" },
	{ 0x11400, 0x1147f, "Newa" },
	{ 0x11480, 0x114df, "Tirhuta" },
	{ 0x11580, 0x115ff, "Siddham" },
	{ 0x11600, 0x1165f, "Modi" },
	{ 0x11660, 0x1167f, "Mongolian Supplement" },
	{ 0x11680, 0x116cf, "Takri" },
	{ 0x116d0, 0x116ff, "Myanmar Extended-C" },
	{ 0x11700, 0x1174f, "Ahom" },
	{ 0x11800, 0x1184f, "Dogra" },
	{ 0x118a0, 0x118ff, "Warang Citi" },
	{ 0x11900, 0x1195f, "Dives Akuru" },
	{ 0x119a0, 0x119ff, "Nandinagari" },
	{ 0x11a00, 0x11a4f, "Zanabazar Square" },
	{ 0x11a50, 0x11aaf, "Soyombo" },
	{ 0x11ab0, 0x11abf, "Unified Canadian Aboriginal Syllabics Extended-A" },
	{ 0x11ac0, 0x11aff, "Pau Cin Hau" },
	{ 0x11b00, 0x11b5f, "Devanagari Extended-A" },
	{ 0x11b60, 0x11b7f, "Sharada Supplement" },
	{ 0x11bc0, 0x11bff, "Sunuwar" },
	{ 0x11c00, 0x11c6f, "Bhaiksuki" },
	{ 0x11c70, 0x11cbf, "Marchen" },
	{ 0x11d00, 0x11d5f, "Masaram Gondi" },
	{ 0x11d60, 0x11daf, "Gunjala Gondi" },
	{ 0x11db0, 0x11def, "Tolong Siki" },
	{ 0x11ee0, 0x11eff, "Makasar" },
	{ 0x11f00, 0x11f5f, "Kawi" },
	{ 0x11fb0, 0x11fbf, "Lisu Supplement" },
	{ 0x11fc0, 0x11fff, "Tamil Supplement" },
	{ 0x12000, 0x123ff, "Cuneiform" },
	{ 0x12400, 0x1247f, "Cuneiform Numbers and Punctuation" },
	{ 0x12480, 0x1254f, "Early Dynastic Cuneiform" },
	{ 0x12f90, 0x12fff, "Cypro-Minoan" },
	{ 0x13000, 0x1342f, "Egyptian Hieroglyphs" },
	{ 0x13430, 0x1345f, "Egyptian Hieroglyph Format Controls" },
	{ 0x13460, 0x143ff, "Egyptian Hieroglyphs Extended-A" },
	{ 0x14400, 0x1467f, "Anatolian Hieroglyphs" },
	{ 0x16100, 0x1613f, "Gurung Khema" },
	{ 0x16800, 0x16a3f, "Bamum Supplement" },
	{ 0x16a40, 0x16a6f, "Mro" },
	{ 0x16a70, 0x16acf, "Tangsa" },
	{ 0x16ad0, 0x16aff, "Bassa Vah" },
	{ 0x16b00, 0x16b8f, "Pahawh Hmong" },
	{ 0x16d40, 0x16d7f, "Kirat Rai" },
	{ 0x16e40, 0x16e9f, "Medefaidrin" },
	{ 0x16ea0, 0x16edf, "Beria Erfe" },
	{ 0x16f00, 0x16f9f, "Miao" },
	{ 0x16fe0, 0x16fff, "Ideographic Symbols and Punctuation" },
	{ 0x17000, 0x187ff, "Tangut" },
	{ 0x18800, 0x18aff, "Tangut Components" },
	{ 0x18b00, 0x18cff, "Khitan Small Script" },
	{ 0x18d00, 0x18d1e, "Tangut Supplement" },
	{ 0x18d80, 0x18dff, "Tangut Components Supplement" },
	{ 0x1aff0, 0x1afff, "Kana Extended-B" },
	{ 0x1b000, 0x1b0ff, "Kana Supplement" },
	{ 0x1b100, 0x1b12f, "Kana Extended-A" },
	{ 0x1b130, 0x1b16f, "Small Kana Extension" },
	{ 0x1b170, 0x1b2ff, "Nushu" },
	{ 0x1bc00, 0x1bc9f, "Duployan" },
	{ 0x1bca0, 0x1bcaf, "Shorthand Format Controls" },
	{ 0x1cc00, 0x1cebf, "Symbols for Legacy Computing Supplement" },
	{ 0x1cec0, 0x1ceff, "Miscellaneous Symbols Supplement" },
	{ 0x1cf00, 0x1cfcf, "Znamenny Musical Notation" },
	{ 0x1d000, 0x1d0ff, "Byzantine Musical Symbols" },
	{ 0x1d100, 0x1d1ff, "Musical Symbols" },
	{ 0x1d200, 0x1d24f, "Ancient Greek Musical Notation" },
	{ 0x1d2c0, 0x1d2df, "Kaktovik Numerals" },
	{ 0x1d2e0, 0x1d2ff, "Mayan Numerals" },
	{ 0x1d300, 0x1d35f, "Tai Xuan Jing Symbols" },
	{ 0x1d360, 0x1d37f, "Counting Rod Numerals" },
	{ 0x1d400, 0x1d7ff, "Mathematical Alphanumeric Symbols" },
	{ 0x1d800, 0x1daaf, "Sutton SignWriting" },
	{ 0x1df00, 0x1dfff, "Latin Extended-G" },
	{ 0x1e000, 0x1e02f, "Glagolitic Supplement" },
	{ 0x1e030, 0x1e08f, "Cyrillic Extended-D" },
	{ 0x1e100, 0x1e14f, "Nyiakeng Puachue Hmong" },
	{ 0x1e290, 0x1e2bf, "Toto" },
	{ 0x1e2c0, 0x1e2ff, "Wancho" },
	{ 0x1e4d0, 0x1e4ff, "Nag Mundari" },
	{ 0x1e5d0, 0x1e5ff, "Ol Onal" },
	{ 0x1e6c0, 0x1e6ff, "Tai Yo" },
	{ 0x1e7e0, 0x1e7ff, "Ethiopic Extended-B" },
	{ 0x1e800, 0x1e8df, "Mende Kikakui" },
	{ 0x1e900, 0x1e95f, "Adlam" },
	{ 0x1ec70, 0x1ecbf, "Indic Siyaq Numbers" },
	{ 0x1ed00, 0x1ed4f, "Ottoman Siyaq Numbers" },
	{ 0x1ee00, 0x1eeff, "Arabic Mathematical Alphabetic Symbols" },
	{ 0x1f000, 0x1f02f, "Mahjong Tiles" },
	{ 0x1f030, 0x1f09f, "Domino Tiles" },
	{ 0x1f0a0, 0x1f0ff, "Playing Cards" },
	{ 0x1f100, 0x1f1ff, "Enclosed Alphanumeric Supplement" },
	{ 0x1f200, 0x1f2ff, "Enclosed Ideographic Supplement" },
	{ 0x1f300, 0x1f5ff, "Miscellaneous Symbols and Pictographs" },
	{ 0x1f600, 0x1f64f, "Emoticons" },
	{ 0x1f650, 0x1f67f, "Ornamental Dingbats" },
	{ 0x1f680, 0x1f6ff, "Transport and Map Symbols" },
	{ 0x1f700, 0x1f77f, "Alchemical Symbols" },
	{ 0x1f780, 0x1f7ff, "Geometric Shapes Extended" },
	{ 0x1f800, 0x1f8ff, "Supplemental Arrows-C" },
	{ 0x1f900, 0x1f9ff, "Supplemental Symbols and Pictographs" },
	{ 0x1fa00, 0x1fa6f, "Chess Symbols" },
	{ 0x1fa70, 0x1faff, "Symbols and Pictographs Extended-A" },
	{ 0x1fb00, 0x1fbff, "Symbols for Legacy Computing" },
	{ 0x1ff80, 0x1ffff, "Unassigned" },
	{ 0x20000, 0x2a6df, "CJK Unified Ideographs Extension B" },
	{ 0x2a700, 0x2b73f, "CJK Unified Ideographs Extension C" },
	{ 0x2b740, 0x2b81d, "CJK Unified Ideographs Extension D" },
	{ 0x2b820, 0x2cead, "CJK Unified Ideographs Extension E" },
	{ 0x2ceb0, 0x2ebe0, "CJK Unified Ideographs Extension F" },
	{ 0x2ebf0, 0x2ee5d, "CJK Unified Ideographs Extension I" },
	{ 0x2f800, 0x2fa1f, "CJK Compatibility Ideographs Supplement" },
	{ 0x2ff80, 0x2ffff, "Unassigned" },
	{ 0x30000, 0x3134a, "CJK Unified Ideographs Extension G" },
	{ 0x31350, 0x323af, "CJK Unified Ideographs Extension H" },
	{ 0x323b0, 0x33479, "CJK Unified Ideographs Extension J" },
	{ 0x3ff80, 0x3ffff, "Unassigned" },
	{ 0x4ff80, 0x4ffff, "Unassigned" },
	{ 0x5ff80, 0x5ffff, "Unassigned" },
	{ 0x6ff80, 0x6ffff, "Unassigned" },
	{ 0x7ff80, 0x7ffff, "Unassigned" },
	{ 0x8ff80, 0x8ffff, "Unassigned" },
	{ 0x9ff80, 0x9ffff, "Unassigned" },
	{ 0xaff80, 0xaffff, "Unassigned" },
	{ 0xbff80, 0xbffff, "Unassigned" },
	{ 0xcff80, 0xcffff, "Unassigned" },
	{ 0xdff80, 0xdffff, "Unassigned" },
	{ 0xe0000, 0xe007f, "Tags" },
	{ 0xe0100, 0xe01ef, "Variation Selectors Supplement" },
	{ 0xeff80, 0xeffff, "Unassigned" },
	{ 0xfff80, 0xfffff, "Supplementary Private Use Area-A" },
	{ 0x10ff80, 0x10ffff, "Supplementary Private Use Area-B" }
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_00_00[] = {
/* 0000 */ { NULL,"	= NULL"},
/* 0001 */ { NULL,"	= START OF HEADING"},
/* 0002 */ { NULL,"	= START OF TEXT"},
/* 0003 */ { NULL,"	= END OF TEXT"},
/* 0004 */ { NULL,"	= END OF TRANSMISSION"},
/* 0005 */ { NULL,"	= ENQUIRY"},
/* 0006 */ { NULL,"	= ACKNOWLEDGE"},
/* 0007 */ { NULL,"	= BELL"},
/* 0008 */ { NULL,"	= BACKSPACE"},
/* 0009 */ { NULL,"	= CHARACTER TABULATION\n"
	"	= horizontal tabulation (HT)\n"
	"	= tab"},
/* 000A */ { NULL,"	= LINE FEED (LF)\n"
	"	= new line (NL)\n"
	"	= end of line (EOL)"},
/* 000B */ { NULL,"	= LINE TABULATION\n"
	"	= vertical tabulation (VT)"},
/* 000C */ { NULL,"	= FORM FEED (FF)"},
/* 000D */ { NULL,"	= CARRIAGE RETURN (CR)"},
/* 000E */ { NULL,"	= SHIFT OUT\n"
	"	* known as LOCKING-SHIFT ONE in 8-bit environments"},
/* 000F */ { NULL,"	= SHIFT IN\n"
	"	* known as LOCKING-SHIFT ZERO in 8-bit environments"},
/* 0010 */ { NULL,"	= DATA LINK ESCAPE"},
/* 0011 */ { NULL,"	= DEVICE CONTROL ONE"},
/* 0012 */ { NULL,"	= DEVICE CONTROL TWO"},
/* 0013 */ { NULL,"	= DEVICE CONTROL THREE"},
/* 0014 */ { NULL,"	= DEVICE CONTROL FOUR"},
/* 0015 */ { NULL,"	= NEGATIVE ACKNOWLEDGE"},
/* 0016 */ { NULL,"	= SYNCHRONOUS IDLE"},
/* 0017 */ { NULL,"	= END OF TRANSMISSION BLOCK"},
/* 0018 */ { NULL,"	= CANCEL"},
/* 0019 */ { NULL,"	= END OF MEDIUM"},
/* 001A */ { NULL,"	= SUBSTITUTE\n"
	"	x (replacement character - FFFD)"},
/* 001B */ { NULL,"	= ESCAPE"},
/* 001C */ { NULL,"	= INFORMATION SEPARATOR FOUR\n"
	"	= file separator (FS)"},
/* 001D */ { NULL,"	= INFORMATION SEPARATOR THREE\n"
	"	= group separator (GS)"},
/* 001E */ { NULL,"	= INFORMATION SEPARATOR TWO\n"
	"	= record separator (RS)"},
/* 001F */ { NULL,"	= INFORMATION SEPARATOR ONE\n"
	"	= unit separator (US)"},
/* 0020 */ { "SPACE","	* sometimes considered a control code\n"
	"	* other space characters: 2000-200A\n"
	"	x (no-break space - 00A0)\n"
	"	x (zero width space - 200B)\n"
	"	x (narrow no-break space - 202F)\n"
	"	x (word joiner - 2060)\n"
	"	x (symbol for space - 2420)\n"
	"	x (blank symbol - 2422)\n"
	"	x (open box - 2423)\n"
	"	x (ideographic space - 3000)\n"
	"	x (zero width no-break space - FEFF)"},
/* 0021 */ { "EXCLAMATION MARK","	= factorial\n"
	"	= bang\n"
	"	x (inverted exclamation mark - 00A1)\n"
	"	x (latin letter retroflex click - 01C3)\n"
	"	x (double exclamation mark - 203C)\n"
	"	x (interrobang - 203D)\n"
	"	x (warning sign - 26A0)\n"
	"	x (heavy exclamation mark symbol - 2757)\n"
	"	x (heavy exclamation mark ornament - 2762)\n"
	"	x (medieval exclamation mark - 2E53)\n"
	"	x (modifier letter raised exclamation mark - A71D)"},
/* 0022 */ { "QUOTATION MARK","	= double quote\n"
	"	* neutral (vertical), used as opening or closing quotation mark\n"
	"	* preferred characters in English for paired quotation marks are 201C & 201D\n"
	"	* 05F4 is preferred for gershayim when writing Hebrew\n"
	"	x (modifier letter double prime - 02BA)\n"
	"	x (double acute accent - 02DD)\n"
	"	x (modifier letter double apostrophe - 02EE)\n"
	"	x (combining double acute accent - 030B)\n"
	"	x (combining double vertical line above - 030E)\n"
	"	x (hebrew punctuation gershayim - 05F4)\n"
	"	x (left double quotation mark - 201C)\n"
	"	x (right double quotation mark - 201D)\n"
	"	x (double prime - 2033)\n"
	"	x (ditto mark - 3003)"},
/* 0023 */ { "NUMBER SIGN","	= pound sign (weight)\n"
	"	= hashtag, hash\n"
	"	= crosshatch, octothorpe\n"
	"	* for denoting musical sharp 266F is preferred\n"
	"	x (l b bar symbol - 2114)\n"
	"	x (numero sign - 2116)\n"
	"	x (viewdata square - 2317)\n"
	"	x (music sharp sign - 266F)\n"
	"	x (equals sign and slanted parallel - 29E3)"},
/* 0024 */ { "DOLLAR SIGN","	= milréis, escudo\n"
	"	* used for many peso currencies in Latin America and elsewhere\n"
	"	* glyph may have one or two vertical bars\n"
	"	* other currency symbol characters start at 20A0\n"
	"	x (cent sign - 00A2)\n"
	"	x (currency sign - 00A4)\n"
	"	x (peso sign - 20B1)\n"
	"	x (heavy dollar sign - 1F4B2)"},
/* 0025 */ { "PERCENT SIGN","	x (arabic percent sign - 066A)\n"
	"	x (per mille sign - 2030)\n"
	"	x (per ten thousand sign - 2031)\n"
	"	x (commercial minus sign - 2052)"},
/* 0026 */ { "AMPERSAND","	= and\n"
	"	* originally derived from a ligature of 'e' and 't'\n"
	"	x (tironian sign et - 204A)\n"
	"	x (turned ampersand - 214B)\n"
	"	x (heavy ampersand ornament - 1F674)"},
/* 0027 */ { "APOSTROPHE","	= apostrophe-quote (1.0)\n"
	"	= single quote\n"
	"	= APL quote\n"
	"	* neutral (vertical) glyph with mixed usage\n"
	"	* 2019 is preferred for apostrophe\n"
	"	* preferred characters in English for paired quotation marks are 2018 & 2019\n"
	"	* 05F3 is preferred for geresh when writing Hebrew\n"
	"	x (modifier letter prime - 02B9)\n"
	"	x (modifier letter apostrophe - 02BC)\n"
	"	x (modifier letter vertical line - 02C8)\n"
	"	x (combining acute accent - 0301)\n"
	"	x (combining vertical line above - 030D)\n"
	"	x (hebrew punctuation geresh - 05F3)\n"
	"	x (left single quotation mark - 2018)\n"
	"	x (right single quotation mark - 2019)\n"
	"	x (prime - 2032)\n"
	"	x (latin small letter saltillo - A78C)"},
/* 0028 */ { "LEFT PARENTHESIS","	= opening parenthesis (1.0)"},
/* 0029 */ { "RIGHT PARENTHESIS","	= closing parenthesis (1.0)\n"
	"	* see discussion on semantics of paired bracketing characters"},
/* 002A */ { "ASTERISK","	= star\n"
	"	* can have five or six spokes\n"
	"	x (arabic five pointed star - 066D)\n"
	"	x (reference mark - 203B)\n"
	"	x (asterism - 2042)\n"
	"	x (low asterisk - 204E)\n"
	"	x (two asterisks aligned vertically - 2051)\n"
	"	x (combining asterisk above - 20F0)\n"
	"	x (asterisk operator - 2217)\n"
	"	x (sextile - 26B9)\n"
	"	x (heavy asterisk - 2731)\n"
	"	x (slavonic asterisk - A673)\n"
	"	x (medium six spoked asterisk - 1F7B6)"},
/* 002B */ { "PLUS SIGN","	x (modifier letter plus sign - 02D6)\n"
	"	x (minus sign - 2212)\n"
	"	x (heavy plus sign - 2795)\n"
	"	x (hebrew letter alternative plus sign - FB29)\n"
	"	x (light greek cross - 1F7A2)"},
/* 002C */ { "COMMA","	= the use as decimal or thousands separator is locale dependent\n"
	"	x (arabic comma - 060C)\n"
	"	x (arabic decimal separator - 066B)\n"
	"	x (single low-9 quotation mark - 201A)\n"
	"	x (hypodiastole - 2E12)\n"
	"	x (reversed comma - 2E41)\n"
	"	x (medieval comma - 2E4C)\n"
	"	x (ideographic comma - 3001)"},
/* 002D */ { "HYPHEN-MINUS","	= hyphen, dash\n"
	"	= minus sign\n"
	"	* used generically for hyphen, minus sign or en dash, all of which have dedicated alternatives\n"
	"	x (soft hyphen - 00AD)\n"
	"	x (modifier letter minus sign - 02D7)\n"
	"	x (hyphen - 2010)\n"
	"	x (non-breaking hyphen - 2011)\n"
	"	x (figure dash - 2012)\n"
	"	x (en dash - 2013)\n"
	"	x (hyphenation point - 2027)\n"
	"	x (hyphen bullet - 2043)\n"
	"	x (minus sign - 2212)\n"
	"	x (roman uncia sign - 10191)"},
/* 002E */ { "FULL STOP","	= period, dot, decimal point\n"
	"	* the use as decimal point is locale dependent\n"
	"	* may be rendered as a raised decimal point in old style numbers\n"
	"	x (middle dot - 00B7)\n"
	"	x (arabic full stop - 06D4)\n"
	"	x (one dot leader - 2024)\n"
	"	x (horizontal ellipsis - 2026)\n"
	"	x (raised dot - 2E33)\n"
	"	x (stenographic full stop - 2E3C)\n"
	"	x (ideographic full stop - 3002)"},
/* 002F */ { "SOLIDUS","	= slash, forward slash, virgule\n"
	"	x (combining long solidus overlay - 0338)\n"
	"	x (fraction slash - 2044)\n"
	"	x (division slash - 2215)\n"
	"	x (mathematical rising diagonal - 27CB)\n"
	"	x (big solidus - 29F8)\n"
	"	x (dotted solidus - 2E4A)"},
/* 0030 */ { "DIGIT ZERO","	~ 0030 FE00 short diagonal stroke form"},
/* 0031 */ { "DIGIT ONE",NULL},
/* 0032 */ { "DIGIT TWO","	x (latin letter two with stroke - 01BB)\n"
	"	x (turned digit two - 218A)"},
/* 0033 */ { "DIGIT THREE","	x (turned digit three - 218B)\n"
	"	x (latin capital letter reversed open e - A7AB)"},
/* 0034 */ { "DIGIT FOUR","	x (latin capital letter cuatrillo - A72C)"},
/* 0035 */ { "DIGIT FIVE","	x (latin capital letter tone five - 01BC)"},
/* 0036 */ { "DIGIT SIX",NULL},
/* 0037 */ { "DIGIT SEVEN",NULL},
/* 0038 */ { "DIGIT EIGHT",NULL},
/* 0039 */ { "DIGIT NINE",NULL},
/* 003A */ { "COLON","	* also used to denote division or scale; for that mathematical use 2236 is preferred\n"
	"	* in Finnish and Swedish, also used as intra-word punctation (abbreviation mark)\n"
	"	x (modifier letter triangular colon - 02D0)\n"
	"	x (modifier letter raised colon - 02F8)\n"
	"	x (armenian full stop - 0589)\n"
	"	x (hebrew punctuation sof pasuq - 05C3)\n"
	"	x (ethiopic wordspace - 1361)\n"
	"	x (ethiopic colon - 1365)\n"
	"	x (two dot punctuation - 205A)\n"
	"	x (tricolon - 205D)\n"
	"	x (ratio - 2236)\n"
	"	x (modifier letter colon - A789)\n"
	"	x (presentation form for vertical two dot leader - FE30)"},
/* 003B */ { "SEMICOLON","	* this, and not 037E, is the preferred character for \"Greek question mark\"\n"
	"	x (greek question mark - 037E)\n"
	"	x (arabic semicolon - 061B)\n"
	"	x (reversed semicolon - 204F)\n"
	"	x (turned semicolon - 2E35)"},
/* 003C */ { "LESS-THAN SIGN","	* paired with 003E for ASCII-based angle bracket markup conventions\n"
	"	x (modifier letter left arrowhead - 02C2)\n"
	"	x (single left-pointing angle quotation mark - 2039)\n"
	"	x (left-pointing angle bracket - 2329)\n"
	"	x (mathematical left angle bracket - 27E8)\n"
	"	x (left angle bracket - 3008)"},
/* 003D */ { "EQUALS SIGN","	* other related characters: 2241-2263\n"
	"	x (canadian syllabics hyphen - 1400)\n"
	"	x (almost equal to - 2248)\n"
	"	x (not equal to - 2260)\n"
	"	x (identical to - 2261)\n"
	"	x (double hyphen - 2E40)\n"
	"	x (katakana-hiragana double hyphen - 30A0)\n"
	"	x (modifier letter short equals sign - A78A)\n"
	"	x (small equals sign - FE66)\n"
	"	x (roman sextans sign - 10190)\n"
	"	x (heavy equals sign - 1F7F0)"},
/* 003E */ { "GREATER-THAN SIGN","	x (modifier letter right arrowhead - 02C3)\n"
	"	x (single right-pointing angle quotation mark - 203A)\n"
	"	x (right-pointing angle bracket - 232A)\n"
	"	x (mathematical right angle bracket - 27E9)\n"
	"	x (right angle bracket - 3009)"},
/* 003F */ { "QUESTION MARK","	x (inverted question mark - 00BF)\n"
	"	x (greek question mark - 037E)\n"
	"	x (arabic question mark - 061F)\n"
	"	x (interrobang - 203D)\n"
	"	x (double question mark - 2047)\n"
	"	x (black question mark ornament - 2753)\n"
	"	x (uncertainty sign - 2BD1)\n"
	"	x (reversed question mark - 2E2E)\n"
	"	x (medieval question mark - 2E54)\n"
	"	x (replacement character - FFFD)"},
/* 0040 */ { "COMMERCIAL AT","	= at sign\n"
	"	= arroba (old Spanish unit of weight)\n"
	"	x (circled latin small letter a - 24D0)"},
/* 0041 */ { "LATIN CAPITAL LETTER A",NULL},
/* 0042 */ { "LATIN CAPITAL LETTER B","	x (script capital b - 212C)"},
/* 0043 */ { "LATIN CAPITAL LETTER C","	x (greek capital lunate sigma symbol - 03F9)\n"
	"	x (double-struck capital c - 2102)\n"
	"	x (degree celsius - 2103)\n"
	"	x (black-letter capital c - 212D)\n"
	"	x (roman numeral one hundred - 216D)"},
/* 0044 */ { "LATIN CAPITAL LETTER D","	x (roman numeral five hundred - 216E)"},
/* 0045 */ { "LATIN CAPITAL LETTER E","	x (latin capital letter open e - 0190)\n"
	"	x (euler constant - 2107)\n"
	"	x (script capital e - 2130)"},
/* 0046 */ { "LATIN CAPITAL LETTER F","	x (degree fahrenheit - 2109)\n"
	"	x (script capital f - 2131)\n"
	"	x (turned capital f - 2132)"},
/* 0047 */ { "LATIN CAPITAL LETTER G",NULL},
/* 0048 */ { "LATIN CAPITAL LETTER H","	x (script capital h - 210B)\n"
	"	x (black-letter capital h - 210C)\n"
	"	x (double-struck capital h - 210D)"},
/* 0049 */ { "LATIN CAPITAL LETTER I","	* Turkish and Azerbaijani use 0131 for lowercase\n"
	"	x (latin capital letter i with dot above - 0130)\n"
	"	x (script capital i - 2110)\n"
	"	x (black-letter capital i - 2111)\n"
	"	x (roman numeral one - 2160)"},
/* 004A */ { "LATIN CAPITAL LETTER J",NULL},
/* 004B */ { "LATIN CAPITAL LETTER K","	x (kelvin sign - 212A)"},
/* 004C */ { "LATIN CAPITAL LETTER L","	x (script capital l - 2112)"},
/* 004D */ { "LATIN CAPITAL LETTER M","	x (script capital m - 2133)\n"
	"	x (roman numeral one thousand - 216F)"},
/* 004E */ { "LATIN CAPITAL LETTER N","	x (double-struck capital n - 2115)"},
/* 004F */ { "LATIN CAPITAL LETTER O",NULL},
/* 0050 */ { "LATIN CAPITAL LETTER P","	x (script capital p - 2118)\n"
	"	x (double-struck capital p - 2119)"},
/* 0051 */ { "LATIN CAPITAL LETTER Q","	x (cyrillic capital letter qa - 051A)\n"
	"	x (double-struck capital q - 211A)\n"
	"	x (rotated capital q - 213A)"},
/* 0052 */ { "LATIN CAPITAL LETTER R","	x (script capital r - 211B)\n"
	"	x (black-letter capital r - 211C)\n"
	"	x (double-struck capital r - 211D)"},
/* 0053 */ { "LATIN CAPITAL LETTER S",NULL},
/* 0054 */ { "LATIN CAPITAL LETTER T",NULL},
/* 0055 */ { "LATIN CAPITAL LETTER U",NULL},
/* 0056 */ { "LATIN CAPITAL LETTER V","	x (roman numeral five - 2164)"},
/* 0057 */ { "LATIN CAPITAL LETTER W","	x (cyrillic capital letter we - 051C)"},
/* 0058 */ { "LATIN CAPITAL LETTER X","	x (roman numeral ten - 2169)"},
/* 0059 */ { "LATIN CAPITAL LETTER Y",NULL},
/* 005A */ { "LATIN CAPITAL LETTER Z","	x (double-struck capital z - 2124)\n"
	"	x (black-letter capital z - 2128)"},
/* 005B */ { "LEFT SQUARE BRACKET","	= opening square bracket (1.0)\n"
	"	* other bracket characters: 27E6-27EB, 2983-2998, 3008-301B"},
/* 005C */ { "REVERSE SOLIDUS","	= backslash\n"
	"	x (combining reverse solidus overlay - 20E5)\n"
	"	x (set minus - 2216)\n"
	"	x (mathematical falling diagonal - 27CD)\n"
	"	x (big reverse solidus - 29F9)"},
/* 005D */ { "RIGHT SQUARE BRACKET","	= closing square bracket (1.0)"},
/* 005E */ { "CIRCUMFLEX ACCENT","	* this is a spacing character\n"
	"	* used in ASCII-based representation of exponentiation\n"
	"	x (modifier letter up arrowhead - 02C4)\n"
	"	x (modifier letter circumflex accent - 02C6)\n"
	"	x (combining circumflex accent - 0302)\n"
	"	x (caret - 2038)\n"
	"	x (logical and - 2227)\n"
	"	x (up arrowhead - 2303)"},
/* 005F */ { "LOW LINE","	= spacing underscore (1.0)\n"
	"	* this is a spacing character\n"
	"	* joins with adjacent instances of itself\n"
	"	x (modifier letter low macron - 02CD)\n"
	"	x (combining macron below - 0331)\n"
	"	x (combining low line - 0332)\n"
	"	x (double low line - 2017)\n"
	"	x (combining conjoining macron below - FE2D)"},
/* 0060 */ { "GRAVE ACCENT","	= backtick, backquote\n"
	"	* this is a spacing character\n"
	"	* in some technical contexts functions as opening quote, paired with apostrophe\n"
	"	x (acute accent - 00B4)\n"
	"	x (modifier letter grave accent - 02CB)\n"
	"	x (combining grave accent - 0300)\n"
	"	x (greek varia - 1FEF)\n"
	"	x (left single quotation mark - 2018)\n"
	"	x (reversed prime - 2035)"},
/* 0061 */ { "LATIN SMALL LETTER A","	x (latin small letter alpha - 0251)"},
/* 0062 */ { "LATIN SMALL LETTER B",NULL},
/* 0063 */ { "LATIN SMALL LETTER C","	x (greek lunate sigma symbol - 03F2)\n"
	"	x (latin letter small capital c - 1D04)"},
/* 0064 */ { "LATIN SMALL LETTER D","	x (cyrillic small letter komi de - 0501)"},
/* 0065 */ { "LATIN SMALL LETTER E","	x (estimated symbol - 212E)\n"
	"	x (script small e - 212F)\n"
	"	x (latin small letter blackletter e - AB32)"},
/* 0066 */ { "LATIN SMALL LETTER F","	x (latin small letter f with hook - 0192)\n"
	"	x (latin small letter lenis f - AB35)"},
/* 0067 */ { "LATIN SMALL LETTER G","	x (latin small letter script g - 0261)\n"
	"	x (script small g - 210A)"},
/* 0068 */ { "LATIN SMALL LETTER H","	x (cyrillic small letter shha - 04BB)\n"
	"	x (planck constant - 210E)"},
/* 0069 */ { "LATIN SMALL LETTER I","	* Turkish and Azerbaijani use 0130 for uppercase\n"
	"	x (latin small letter dotless i - 0131)\n"
	"	x (superscript latin small letter i - 2071)\n"
	"	x (mathematical italic small dotless i - 1D6A4)"},
/* 006A */ { "LATIN SMALL LETTER J","	x (latin small letter dotless j - 0237)\n"
	"	x (greek letter yot - 03F3)\n"
	"	x (mathematical italic small dotless j - 1D6A5)"},
/* 006B */ { "LATIN SMALL LETTER K",NULL},
/* 006C */ { "LATIN SMALL LETTER L","	x (script small l - 2113)\n"
	"	x (mathematical script small l - 1D4C1)"},
/* 006D */ { "LATIN SMALL LETTER M",NULL},
/* 006E */ { "LATIN SMALL LETTER N","	x (superscript latin small letter n - 207F)"},
/* 006F */ { "LATIN SMALL LETTER O","	x (latin letter small capital o - 1D0F)\n"
	"	x (script small o - 2134)\n"
	"	x (latin small letter blackletter o - AB3D)"},
/* 0070 */ { "LATIN SMALL LETTER P",NULL},
/* 0071 */ { "LATIN SMALL LETTER Q","	x (cyrillic small letter qa - 051B)"},
/* 0072 */ { "LATIN SMALL LETTER R",NULL},
/* 0073 */ { "LATIN SMALL LETTER S","	x (latin small letter long s - 017F)\n"
	"	x (latin letter small capital s - A731)"},
/* 0074 */ { "LATIN SMALL LETTER T",NULL},
/* 0075 */ { "LATIN SMALL LETTER U",NULL},
/* 0076 */ { "LATIN SMALL LETTER V",NULL},
/* 0077 */ { "LATIN SMALL LETTER W","	x (cyrillic small letter we - 051D)\n"
	"	x (latin letter small capital w - 1D21)"},
/* 0078 */ { "LATIN SMALL LETTER X","	x (multiplication sign - 00D7)"},
/* 0079 */ { "LATIN SMALL LETTER Y",NULL},
/* 007A */ { "LATIN SMALL LETTER Z","	x (latin small letter z with stroke - 01B6)\n"
	"	x (latin letter small capital z - 1D22)"},
/* 007B */ { "LEFT CURLY BRACKET","	= opening curly bracket (1.0)\n"
	"	= left brace"},
/* 007C */ { "VERTICAL LINE","	= vertical bar, pipe\n"
	"	* used in pairs to indicate absolute value\n"
	"	* also used as an unpaired separator or as a fence\n"
	"	x (broken bar - 00A6)\n"
	"	x (latin letter dental click - 01C0)\n"
	"	x (hebrew punctuation paseq - 05C0)\n"
	"	x (devanagari danda - 0964)\n"
	"	x (combining long vertical line overlay - 20D2)\n"
	"	x (divides - 2223)\n"
	"	x (light vertical bar - 2758)"},
/* 007D */ { "RIGHT CURLY BRACKET","	= closing curly bracket (1.0)\n"
	"	= right brace"},
/* 007E */ { "TILDE","	* this is a spacing character\n"
	"	x (small tilde - 02DC)\n"
	"	x (combining tilde - 0303)\n"
	"	x (combining tilde overlay - 0334)\n"
	"	x (swung dash - 2053)\n"
	"	x (tilde operator - 223C)\n"
	"	x (tilde with ring above - 2E1B)\n"
	"	x (vertical tilde - 2E2F)\n"
	"	x (wave dash - 301C)\n"
	"	x (fullwidth tilde - FF5E)"},
/* 007F */ { NULL,"	= DELETE"},
/* 0080 */ { NULL,NULL},
/* 0081 */ { NULL,NULL},
/* 0082 */ { NULL,"	= BREAK PERMITTED HERE\n"
	"	x (zero width space - 200B)"},
/* 0083 */ { NULL,"	= NO BREAK HERE\n"
	"	x (word joiner - 2060)"},
/* 0084 */ { NULL,"	* formerly known as INDEX"},
/* 0085 */ { NULL,"	= NEXT LINE (NEL)"},
/* 0086 */ { NULL,"	= START OF SELECTED AREA"},
/* 0087 */ { NULL,"	= END OF SELECTED AREA"},
/* 0088 */ { NULL,"	= CHARACTER TABULATION SET"},
/* 0089 */ { NULL,"	= CHARACTER TABULATION WITH JUSTIFICATION"},
/* 008A */ { NULL,"	= LINE TABULATION SET"},
/* 008B */ { NULL,"	= PARTIAL LINE FORWARD"},
/* 008C */ { NULL,"	= PARTIAL LINE BACKWARD"},
/* 008D */ { NULL,"	= REVERSE LINE FEED"},
/* 008E */ { NULL,"	= SINGLE SHIFT TWO"},
/* 008F */ { NULL,"	= SINGLE SHIFT THREE"},
/* 0090 */ { NULL,"	= DEVICE CONTROL STRING"},
/* 0091 */ { NULL,"	= PRIVATE USE ONE"},
/* 0092 */ { NULL,"	= PRIVATE USE TWO"},
/* 0093 */ { NULL,"	= SET TRANSMIT STATE"},
/* 0094 */ { NULL,"	= CANCEL CHARACTER"},
/* 0095 */ { NULL,"	= MESSAGE WAITING"},
/* 0096 */ { NULL,"	= START OF GUARDED AREA"},
/* 0097 */ { NULL,"	= END OF GUARDED AREA"},
/* 0098 */ { NULL,"	= START OF STRING"},
/* 0099 */ { NULL,NULL},
/* 009A */ { NULL,"	= SINGLE CHARACTER INTRODUCER"},
/* 009B */ { NULL,"	= CONTROL SEQUENCE INTRODUCER"},
/* 009C */ { NULL,"	= STRING TERMINATOR"},
/* 009D */ { NULL,"	= OPERATING SYSTEM COMMAND"},
/* 009E */ { NULL,"	= PRIVACY MESSAGE"},
/* 009F */ { NULL,"	= APPLICATION PROGRAM COMMAND"},
/* 00A0 */ { "NO-BREAK SPACE","	* commonly abbreviated as NBSP\n"
	"	* should be the same width as the space 0020\n"
	"	x (space - 0020)\n"
	"	x (figure space - 2007)\n"
	"	x (narrow no-break space - 202F)\n"
	"	x (word joiner - 2060)\n"
	"	x (shouldered open box - 237D)\n"
	"	x (zero width no-break space - FEFF)\n"
	"	# <noBreak> 0020"},
/* 00A1 */ { "INVERTED EXCLAMATION MARK","	* Spanish, Asturian, Galician\n"
	"	* used in extended IPA to represent sublaminal lower alveolar percussive\n"
	"	x (exclamation mark - 0021)\n"
	"	x (modifier letter raised inverted exclamation mark - A71E)"},
/* 00A2 */ { "CENT SIGN","	x (latin small letter c with stroke - 023C)\n"
	"	x (mill sign - 20A5)\n"
	"	x (cedi sign - 20B5)\n"
	"	x (musical symbol cut time - 1D135)"},
/* 00A3 */ { "POUND SIGN","	= pound sterling, Irish punt, lira, etc.\n"
	"	* not to be confused with the unit of weight\n"
	"	* glyph may have one or two crossbars, in distinction from 20A4\n"
	"	x (lira sign - 20A4)\n"
	"	x (turkish lira sign - 20BA)\n"
	"	x (roman semuncia sign - 10192)"},
/* 00A4 */ { "CURRENCY SIGN","	* generic or unknown currency\n"
	"	* other currency symbol characters start at 20A0\n"
	"	x (dollar sign - 0024)"},
/* 00A5 */ { "YEN SIGN","	= yuan sign (renminbi)\n"
	"	* glyph may have one or two crossbars, but the official symbol in Japan and China has two\n"
	"	* in native context, specific ideographs may be used for units of these currencies\n"
	"	x (latin capital letter y with stroke - 024E)\n"
	"	x (cyrillic capital letter straight u with stroke - 04B0)\n"
	"	x 5143\n"
	"	x 5186"},
/* 00A6 */ { "BROKEN BAR","	= broken vertical bar (1.0)\n"
	"	= parted rule (in typography)\n"
	"	x (vertical line - 007C)"},
/* 00A7 */ { "SECTION SIGN","	* used in referencing numbered sections or paragraphs\n"
	"	x (top half section sign - 2E39)"},
/* 00A8 */ { "DIAERESIS","	* this is a spacing character\n"
	"	x (combining diaeresis - 0308)\n"
	"	# 0020 0308"},
/* 00A9 */ { "COPYRIGHT SIGN","	x (sound recording copyright - 2117)\n"
	"	x (circled latin capital letter c - 24B8)\n"
	"	x (copyleft symbol - 1F12F)\n"
	"	x (mask work symbol - 1F1AD)"},
/* 00AA */ { "FEMININE ORDINAL INDICATOR","	* Spanish\n"
	"	x (modifier letter small a - 1D43)\n"
	"	# <super> 0061"},
/* 00AB */ { "LEFT-POINTING DOUBLE ANGLE QUOTATION MARK","	= left guillemet\n"
	"	= chevrons (in typography)\n"
	"	* usually opening, sometimes closing\n"
	"	x (much less-than - 226A)\n"
	"	x (left double angle bracket - 300A)"},
/* 00AC */ { "NOT SIGN","	= angled dash (in typography)\n"
	"	x (reversed not sign - 2310)\n"
	"	x (turned not sign - 2319)"},
/* 00AD */ { "SOFT HYPHEN","	= discretionary hyphen\n"
	"	* commonly abbreviated as SHY\n"
	"	* an invisible format character indicating a possible hyphenation location"},
/* 00AE */ { "REGISTERED SIGN","	= registered trade mark sign (1.0)\n"
	"	x (trade mark sign - 2122)\n"
	"	x (circled latin capital letter r - 24C7)\n"
	"	x (raised md sign - 1F16B)\n"
	"	x (raised mr sign - 1F16C)"},
/* 00AF */ { "MACRON","	= overline, APL overbar\n"
	"	* this is a spacing character\n"
	"	* unlike 203E, adjacent instances of this character do not join\n"
	"	x (modifier letter macron - 02C9)\n"
	"	x (combining macron - 0304)\n"
	"	x (combining overline - 0305)\n"
	"	x (overline - 203E)\n"
	"	x (combining conjoining macron - FE26)\n"
	"	# 0020 0304"},
/* 00B0 */ { "DEGREE SIGN","	* this is a spacing character\n"
	"	x (ring above - 02DA)\n"
	"	x (combining ring above - 030A)\n"
	"	x (superscript zero - 2070)\n"
	"	x (degree celsius - 2103)\n"
	"	x (degree fahrenheit - 2109)\n"
	"	x (ring operator - 2218)"},
/* 00B1 */ { "PLUS-MINUS SIGN","	= biquintile (astrological aspect: 144°)\n"
	"	x (minus-or-plus sign - 2213)\n"
	"	x (division times - 22C7)"},
/* 00B2 */ { "SUPERSCRIPT TWO","	= squared\n"
	"	* other superscript digit characters: 2070-2079\n"
	"	x (superscript one - 00B9)\n"
	"	# <super> 0032"},
/* 00B3 */ { "SUPERSCRIPT THREE","	= cubed\n"
	"	x (superscript one - 00B9)\n"
	"	# <super> 0033"},
/* 00B4 */ { "ACUTE ACCENT","	* this is a spacing character\n"
	"	x (grave accent - 0060)\n"
	"	x (modifier letter prime - 02B9)\n"
	"	x (modifier letter acute accent - 02CA)\n"
	"	x (double acute accent - 02DD)\n"
	"	x (combining acute accent - 0301)\n"
	"	x (greek tonos - 0384)\n"
	"	x (greek oxia - 1FFD)\n"
	"	x (prime - 2032)\n"
	"	# 0020 0301"},
/* 00B5 */ { "MICRO SIGN","	# 03BC greek small letter mu"},
/* 00B6 */ { "PILCROW SIGN","	= paragraph sign\n"
	"	* section sign in some European usage\n"
	"	x (reversed pilcrow sign - 204B)\n"
	"	x (curved stem paragraph sign ornament - 2761)\n"
	"	x (capitulum - 2E3F)"},
/* 00B7 */ { "MIDDLE DOT","	= midpoint (in typography)\n"
	"	= Georgian comma\n"
	"	= Greek middle dot (ano teleia)\n"
	"	* also used as a raised decimal point or to denote multiplication; for multiplication 22C5 is preferred\n"
	"	* used as a vowel length mark (part of words) in many Amerindian orthographies\n"
	"	x (full stop - 002E)\n"
	"	x (dot above - 02D9)\n"
	"	x (greek ano teleia - 0387)\n"
	"	x (bullet - 2022)\n"
	"	x (one dot leader - 2024)\n"
	"	x (hyphenation point - 2027)\n"
	"	x (bullet operator - 2219)\n"
	"	x (dot operator - 22C5)\n"
	"	x (word separator middle dot - 2E31)\n"
	"	x (raised dot - 2E33)\n"
	"	x (katakana middle dot - 30FB)\n"
	"	x (latin letter sinological dot - A78F)"},
/* 00B8 */ { "CEDILLA","	* this is a spacing character\n"
	"	* other spacing accent characters: 02D8-02DB\n"
	"	x (combining cedilla - 0327)\n"
	"	# 0020 0327"},
/* 00B9 */ { "SUPERSCRIPT ONE","	x (superscript two - 00B2)\n"
	"	x (superscript three - 00B3)\n"
	"	x (superscript zero - 2070)\n"
	"	# <super> 0031"},
/* 00BA */ { "MASCULINE ORDINAL INDICATOR","	* Spanish\n"
	"	x (modifier letter small o - 1D52)\n"
	"	x (superscript zero - 2070)\n"
	"	x (numero sign - 2116)\n"
	"	# <super> 006F"},
/* 00BB */ { "RIGHT-POINTING DOUBLE ANGLE QUOTATION MARK","	= right guillemet\n"
	"	* usually closing, sometimes opening\n"
	"	x (much greater-than - 226B)\n"
	"	x (right double angle bracket - 300B)"},
/* 00BC */ { "VULGAR FRACTION ONE QUARTER","	# <fraction> 0031 2044 0034"},
/* 00BD */ { "VULGAR FRACTION ONE HALF","	# <fraction> 0031 2044 0032"},
/* 00BE */ { "VULGAR FRACTION THREE QUARTERS","	# <fraction> 0033 2044 0034"},
/* 00BF */ { "INVERTED QUESTION MARK","	= turned question mark\n"
	"	* Spanish\n"
	"	x (question mark - 003F)\n"
	"	x (inverted interrobang - 2E18)\n"
	"	x (reversed question mark - 2E2E)"},
/* 00C0 */ { "LATIN CAPITAL LETTER A WITH GRAVE","	: 0041 0300"},
/* 00C1 */ { "LATIN CAPITAL LETTER A WITH ACUTE","	: 0041 0301"},
/* 00C2 */ { "LATIN CAPITAL LETTER A WITH CIRCUMFLEX","	: 0041 0302"},
/* 00C3 */ { "LATIN CAPITAL LETTER A WITH TILDE","	: 0041 0303"},
/* 00C4 */ { "LATIN CAPITAL LETTER A WITH DIAERESIS","	: 0041 0308"},
/* 00C5 */ { "LATIN CAPITAL LETTER A WITH RING ABOVE","	x (angstrom sign - 212B)\n"
	"	: 0041 030A"},
/* 00C6 */ { "LATIN CAPITAL LETTER AE","	= latin capital ligature ae (1.1)\n"
	"	x (cyrillic capital ligature a ie - 04D4)"},
/* 00C7 */ { "LATIN CAPITAL LETTER C WITH CEDILLA","	: 0043 0327"},
/* 00C8 */ { "LATIN CAPITAL LETTER E WITH GRAVE","	: 0045 0300"},
/* 00C9 */ { "LATIN CAPITAL LETTER E WITH ACUTE","	: 0045 0301"},
/* 00CA */ { "LATIN CAPITAL LETTER E WITH CIRCUMFLEX","	: 0045 0302"},
/* 00CB */ { "LATIN CAPITAL LETTER E WITH DIAERESIS","	: 0045 0308"},
/* 00CC */ { "LATIN CAPITAL LETTER I WITH GRAVE","	: 0049 0300"},
/* 00CD */ { "LATIN CAPITAL LETTER I WITH ACUTE","	: 0049 0301"},
/* 00CE */ { "LATIN CAPITAL LETTER I WITH CIRCUMFLEX","	: 0049 0302"},
/* 00CF */ { "LATIN CAPITAL LETTER I WITH DIAERESIS","	: 0049 0308"},
/* 00D0 */ { "LATIN CAPITAL LETTER ETH","	* lowercase is 00F0\n"
	"	x (latin capital letter d with stroke - 0110)\n"
	"	x (latin capital letter african d - 0189)\n"
	"	x (latin capital letter d with short stroke overlay - A7C7)"},
/* 00D1 */ { "LATIN CAPITAL LETTER N WITH TILDE","	: 004E 0303"},
/* 00D2 */ { "LATIN CAPITAL LETTER O WITH GRAVE","	: 004F 0300"},
/* 00D3 */ { "LATIN CAPITAL LETTER O WITH ACUTE","	: 004F 0301"},
/* 00D4 */ { "LATIN CAPITAL LETTER O WITH CIRCUMFLEX","	: 004F 0302"},
/* 00D5 */ { "LATIN CAPITAL LETTER O WITH TILDE","	: 004F 0303"},
/* 00D6 */ { "LATIN CAPITAL LETTER O WITH DIAERESIS","	: 004F 0308"},
/* 00D7 */ { "MULTIPLICATION SIGN","	= z notation Cartesian product\n"
	"	x (latin small letter x - 0078)\n"
	"	x (saltire - 2613)\n"
	"	x (multiplication x - 2715)\n"
	"	x (heavy ballot x - 2718)\n"
	"	x (cross mark - 274C)\n"
	"	x (vector or cross product - 2A2F)\n"
	"	x (cancellation x - 1F5D9)\n"
	"	x (light saltire - 1F7A9)"},
/* 00D8 */ { "LATIN CAPITAL LETTER O WITH STROKE","	= o slash\n"
	"	x (latin capital letter o with middle tilde - 019F)\n"
	"	x (empty set - 2205)\n"
	"	x (latin capital letter o with long stroke overlay - A74A)"},
/* 00D9 */ { "LATIN CAPITAL LETTER U WITH GRAVE","	: 0055 0300"},
/* 00DA */ { "LATIN CAPITAL LETTER U WITH ACUTE","	: 0055 0301"},
/* 00DB */ { "LATIN CAPITAL LETTER U WITH CIRCUMFLEX","	: 0055 0302"},
/* 00DC */ { "LATIN CAPITAL LETTER U WITH DIAERESIS","	: 0055 0308"},
/* 00DD */ { "LATIN CAPITAL LETTER Y WITH ACUTE","	: 0059 0301"},
/* 00DE */ { "LATIN CAPITAL LETTER THORN",NULL},
/* 00DF */ { "LATIN SMALL LETTER SHARP S","	= Eszett\n"
	"	* German\n"
	"	* not used in Swiss High German\n"
	"	* uppercase is \"SS\" (standard case mapping), alternatively 1E9E\n"
	"	* typographically the glyph for this character can be based on a ligature of 017F with either 0073 or with an old-style glyph for 007A (the latter similar in appearance to 0292). Both forms exist interchangeably today.\n"
	"	x (latin small letter long s - 017F)\n"
	"	x (latin small letter ezh - 0292)\n"
	"	x (greek small letter beta - 03B2)\n"
	"	x (latin capital letter sharp s - 1E9E)\n"
	"	x (latin small letter beta - A7B5)\n"
	"	x (latin small letter middle scots s - A7D7)"},
/* 00E0 */ { "LATIN SMALL LETTER A WITH GRAVE","	: 0061 0300"},
/* 00E1 */ { "LATIN SMALL LETTER A WITH ACUTE","	: 0061 0301"},
/* 00E2 */ { "LATIN SMALL LETTER A WITH CIRCUMFLEX","	: 0061 0302"},
/* 00E3 */ { "LATIN SMALL LETTER A WITH TILDE","	* Portuguese\n"
	"	: 0061 0303"},
/* 00E4 */ { "LATIN SMALL LETTER A WITH DIAERESIS","	: 0061 0308"},
/* 00E5 */ { "LATIN SMALL LETTER A WITH RING ABOVE","	* Danish, Norwegian, Swedish, Walloon\n"
	"	: 0061 030A"},
/* 00E6 */ { "LATIN SMALL LETTER AE","	= latin small ligature ae (1.1)\n"
	"	= ash (from Old English æsc)\n"
	"	* Danish, Norwegian, Icelandic, Faroese, Old English, French, IPA\n"
	"	x (latin small ligature oe - 0153)\n"
	"	x (cyrillic small ligature a ie - 04D5)\n"
	"	x (latin small letter turned ae - 1D02)\n"
	"	x (latin small letter a reversed-schwa - AB31)"},
/* 00E7 */ { "LATIN SMALL LETTER C WITH CEDILLA","	: 0063 0327"},
/* 00E8 */ { "LATIN SMALL LETTER E WITH GRAVE","	: 0065 0300"},
/* 00E9 */ { "LATIN SMALL LETTER E WITH ACUTE","	: 0065 0301"},
/* 00EA */ { "LATIN SMALL LETTER E WITH CIRCUMFLEX","	: 0065 0302"},
/* 00EB */ { "LATIN SMALL LETTER E WITH DIAERESIS","	: 0065 0308"},
/* 00EC */ { "LATIN SMALL LETTER I WITH GRAVE","	* Italian, Malagasy\n"
	"	: 0069 0300"},
/* 00ED */ { "LATIN SMALL LETTER I WITH ACUTE","	: 0069 0301"},
/* 00EE */ { "LATIN SMALL LETTER I WITH CIRCUMFLEX","	: 0069 0302"},
/* 00EF */ { "LATIN SMALL LETTER I WITH DIAERESIS","	: 0069 0308"},
/* 00F0 */ { "LATIN SMALL LETTER ETH","	* Icelandic, Faroese, Old English, IPA\n"
	"	* uppercase is 00D0\n"
	"	x (latin small letter d with stroke - 0111)\n"
	"	x (greek small letter delta - 03B4)\n"
	"	x (latin small letter delta - 1E9F)\n"
	"	x (partial differential - 2202)\n"
	"	x (latin small letter insular d - A77A)"},
/* 00F1 */ { "LATIN SMALL LETTER N WITH TILDE","	: 006E 0303"},
/* 00F2 */ { "LATIN SMALL LETTER O WITH GRAVE","	: 006F 0300"},
/* 00F3 */ { "LATIN SMALL LETTER O WITH ACUTE","	: 006F 0301"},
/* 00F4 */ { "LATIN SMALL LETTER O WITH CIRCUMFLEX","	: 006F 0302"},
/* 00F5 */ { "LATIN SMALL LETTER O WITH TILDE","	* Portuguese, Estonian, Livonian\n"
	"	: 006F 0303"},
/* 00F6 */ { "LATIN SMALL LETTER O WITH DIAERESIS","	: 006F 0308"},
/* 00F7 */ { "DIVISION SIGN","	= obelus\n"
	"	* occasionally used as an alternate, more visually distinct shape for a hyphen in some contexts\n"
	"	* historically used as a punctuation mark to denote questionable passages in manuscripts\n"
	"	x (syriac harklean obelus - 070B)\n"
	"	x (commercial minus sign - 2052)\n"
	"	x (division slash - 2215)\n"
	"	x (divides - 2223)\n"
	"	x (ratio - 2236)\n"
	"	x (heavy division sign - 2797)\n"
	"	x (long division - 27CC)\n"
	"	x (dotted obelos - 2E13)"},
/* 00F8 */ { "LATIN SMALL LETTER O WITH STROKE","	= o slash\n"
	"	* Danish, Norwegian, Faroese, IPA\n"
	"	x (latin small letter barred o - 0275)\n"
	"	x (diameter sign - 2300)\n"
	"	x (latin small letter o with long stroke overlay - A74B)\n"
	"	x (latin small letter old polish o - A7C1)\n"
	"	x (latin small letter blackletter o with stroke - AB3E)"},
/* 00F9 */ { "LATIN SMALL LETTER U WITH GRAVE","	* French, Italian\n"
	"	: 0075 0300"},
/* 00FA */ { "LATIN SMALL LETTER U WITH ACUTE","	: 0075 0301"},
/* 00FB */ { "LATIN SMALL LETTER U WITH CIRCUMFLEX","	: 0075 0302"},
/* 00FC */ { "LATIN SMALL LETTER U WITH DIAERESIS","	: 0075 0308"},
/* 00FD */ { "LATIN SMALL LETTER Y WITH ACUTE","	* Czech, Slovak, Icelandic, Faroese, Welsh, Malagasy\n"
	"	: 0079 0301"},
/* 00FE */ { "LATIN SMALL LETTER THORN","	* Icelandic, Old English, phonetics\n"
	"	* Runic letter borrowed into Latin script\n"
	"	* replaced by \"th\" in modern English\n"
	"	x (greek small letter sho - 03F8)\n"
	"	x (runic letter thurisaz thurs thorn - 16A6)\n"
	"	x (latin small letter double thorn - A7D3)"},
/* 00FF */ { "LATIN SMALL LETTER Y WITH DIAERESIS","	* French, medieval Hungarian orthography\n"
	"	* uppercase is 0178\n"
	"	: 0079 0308"}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_00_01[] = {
/* 0100 */ { "LATIN CAPITAL LETTER A WITH MACRON","	: 0041 0304"},
/* 0101 */ { "LATIN SMALL LETTER A WITH MACRON","	* Latvian, Latin, ...\n"
	"	: 0061 0304"},
/* 0102 */ { "LATIN CAPITAL LETTER A WITH BREVE","	: 0041 0306"},
/* 0103 */ { "LATIN SMALL LETTER A WITH BREVE","	* Romanian, Vietnamese, Latin, ...\n"
	"	: 0061 0306"},
/* 0104 */ { "LATIN CAPITAL LETTER A WITH OGONEK","	: 0041 0328"},
/* 0105 */ { "LATIN SMALL LETTER A WITH OGONEK","	* Polish, Lithuanian, ...\n"
	"	: 0061 0328"},
/* 0106 */ { "LATIN CAPITAL LETTER C WITH ACUTE","	: 0043 0301"},
/* 0107 */ { "LATIN SMALL LETTER C WITH ACUTE","	* Polish, Croatian, Serbian, ...\n"
	"	x (cyrillic small letter tshe - 045B)\n"
	"	: 0063 0301"},
/* 0108 */ { "LATIN CAPITAL LETTER C WITH CIRCUMFLEX","	: 0043 0302"},
/* 0109 */ { "LATIN SMALL LETTER C WITH CIRCUMFLEX","	* Esperanto\n"
	"	: 0063 0302"},
/* 010A */ { "LATIN CAPITAL LETTER C WITH DOT ABOVE","	: 0043 0307"},
/* 010B */ { "LATIN SMALL LETTER C WITH DOT ABOVE","	* Maltese, Irish Gaelic (old orthography)\n"
	"	: 0063 0307"},
/* 010C */ { "LATIN CAPITAL LETTER C WITH CARON","	: 0043 030C"},
/* 010D */ { "LATIN SMALL LETTER C WITH CARON","	* Czech, Slovak, Slovenian, and many other languages\n"
	"	: 0063 030C"},
/* 010E */ { "LATIN CAPITAL LETTER D WITH CARON","	* the form using caron/hacek is preferred in all contexts\n"
	"	: 0044 030C"},
/* 010F */ { "LATIN SMALL LETTER D WITH CARON","	* Czech, Slovak\n"
	"	* the form using apostrophe is preferred in typesetting\n"
	"	: 0064 030C"},
/* 0110 */ { "LATIN CAPITAL LETTER D WITH STROKE","	x (latin capital letter eth - 00D0)\n"
	"	x (latin capital letter african d - 0189)\n"
	"	x (latin capital letter d with short stroke overlay - A7C7)"},
/* 0111 */ { "LATIN SMALL LETTER D WITH STROKE","	* Croatian, Serbian, Vietnamese, Sami, Moro\n"
	"	* an alternate glyph with the stroke through the bowl is used in Americanist orthographies\n"
	"	x (latin small letter eth - 00F0)\n"
	"	x (cyrillic small letter dje - 0452)\n"
	"	x (latin small letter d with middle tilde - 1D6D)\n"
	"	x (dong sign - 20AB)\n"
	"	x (latin small letter d with short stroke overlay - A7C8)"},
/* 0112 */ { "LATIN CAPITAL LETTER E WITH MACRON","	: 0045 0304"},
/* 0113 */ { "LATIN SMALL LETTER E WITH MACRON","	* Latvian, Latin, ...\n"
	"	: 0065 0304"},
/* 0114 */ { "LATIN CAPITAL LETTER E WITH BREVE","	: 0045 0306"},
/* 0115 */ { "LATIN SMALL LETTER E WITH BREVE","	* Malay, Latin, ...\n"
	"	: 0065 0306"},
/* 0116 */ { "LATIN CAPITAL LETTER E WITH DOT ABOVE","	: 0045 0307"},
/* 0117 */ { "LATIN SMALL LETTER E WITH DOT ABOVE","	* Lithuanian\n"
	"	: 0065 0307"},
/* 0118 */ { "LATIN CAPITAL LETTER E WITH OGONEK","	: 0045 0328"},
/* 0119 */ { "LATIN SMALL LETTER E WITH OGONEK","	* Polish, Lithuanian, ...\n"
	"	: 0065 0328"},
/* 011A */ { "LATIN CAPITAL LETTER E WITH CARON","	: 0045 030C"},
/* 011B */ { "LATIN SMALL LETTER E WITH CARON","	* Czech, ...\n"
	"	: 0065 030C"},
/* 011C */ { "LATIN CAPITAL LETTER G WITH CIRCUMFLEX","	: 0047 0302"},
/* 011D */ { "LATIN SMALL LETTER G WITH CIRCUMFLEX","	* Esperanto\n"
	"	: 0067 0302"},
/* 011E */ { "LATIN CAPITAL LETTER G WITH BREVE","	: 0047 0306"},
/* 011F */ { "LATIN SMALL LETTER G WITH BREVE","	* Turkish, Azerbaijani\n"
	"	x (latin small letter g with caron - 01E7)\n"
	"	: 0067 0306"},
/* 0120 */ { "LATIN CAPITAL LETTER G WITH DOT ABOVE","	: 0047 0307"},
/* 0121 */ { "LATIN SMALL LETTER G WITH DOT ABOVE","	* Maltese, Irish Gaelic (old orthography)\n"
	"	: 0067 0307"},
/* 0122 */ { "LATIN CAPITAL LETTER G WITH CEDILLA","	: 0047 0327"},
/* 0123 */ { "LATIN SMALL LETTER G WITH CEDILLA","	* Latvian\n"
	"	* there are three major glyph variants\n"
	"	: 0067 0327"},
/* 0124 */ { "LATIN CAPITAL LETTER H WITH CIRCUMFLEX","	* lowercase in Nawdm is 0266\n"
	"	: 0048 0302"},
/* 0125 */ { "LATIN SMALL LETTER H WITH CIRCUMFLEX","	* Esperanto\n"
	"	: 0068 0302"},
/* 0126 */ { "LATIN CAPITAL LETTER H WITH STROKE","	x (modifier letter capital h with stroke - A7F8)"},
/* 0127 */ { "LATIN SMALL LETTER H WITH STROKE","	* Maltese, IPA, ...\n"
	"	x (cyrillic small letter tshe - 045B)\n"
	"	x (planck constant over two pi - 210F)"},
/* 0128 */ { "LATIN CAPITAL LETTER I WITH TILDE","	: 0049 0303"},
/* 0129 */ { "LATIN SMALL LETTER I WITH TILDE","	* Greenlandic (old orthography), Kikuyu\n"
	"	: 0069 0303"},
/* 012A */ { "LATIN CAPITAL LETTER I WITH MACRON","	: 0049 0304"},
/* 012B */ { "LATIN SMALL LETTER I WITH MACRON","	* Latvian, Latin, ...\n"
	"	: 0069 0304"},
/* 012C */ { "LATIN CAPITAL LETTER I WITH BREVE","	: 0049 0306"},
/* 012D */ { "LATIN SMALL LETTER I WITH BREVE","	* Latin, ...\n"
	"	: 0069 0306"},
/* 012E */ { "LATIN CAPITAL LETTER I WITH OGONEK","	: 0049 0328"},
/* 012F */ { "LATIN SMALL LETTER I WITH OGONEK","	* Lithuanian, ...\n"
	"	: 0069 0328"},
/* 0130 */ { "LATIN CAPITAL LETTER I WITH DOT ABOVE","	= i dot\n"
	"	* Turkish, Azerbaijani\n"
	"	* lowercase is 0069\n"
	"	x (latin capital letter i - 0049)\n"
	"	: 0049 0307"},
/* 0131 */ { "LATIN SMALL LETTER DOTLESS I","	* Turkish, Azerbaijani\n"
	"	* uppercase is 0049\n"
	"	x (latin small letter i - 0069)\n"
	"	x (latin small letter iota - 0269)\n"
	"	x (latin letter small capital i - 026A)\n"
	"	x (cyrillic small letter byelorussian-ukrainian i - 0456)\n"
	"	x (mathematical italic small dotless i - 1D6A4)"},
/* 0132 */ { "LATIN CAPITAL LIGATURE IJ","	# 0049 004A"},
/* 0133 */ { "LATIN SMALL LIGATURE IJ","	* Dutch\n"
	"	# 0069 006A"},
/* 0134 */ { "LATIN CAPITAL LETTER J WITH CIRCUMFLEX","	: 004A 0302"},
/* 0135 */ { "LATIN SMALL LETTER J WITH CIRCUMFLEX","	* Esperanto\n"
	"	: 006A 0302"},
/* 0136 */ { "LATIN CAPITAL LETTER K WITH CEDILLA","	: 004B 0327"},
/* 0137 */ { "LATIN SMALL LETTER K WITH CEDILLA","	* Latvian\n"
	"	* despite their names, this pair of characters should normally be displayed with a comma below\n"
	"	: 006B 0327"},
/* 0138 */ { "LATIN SMALL LETTER KRA","	* Greenlandic (old orthography), Labrador Inuttut\n"
	"	x (cyrillic small letter ka - 043A)\n"
	"	x (latin letter small capital k - 1D0B)"},
/* 0139 */ { "LATIN CAPITAL LETTER L WITH ACUTE","	: 004C 0301"},
/* 013A */ { "LATIN SMALL LETTER L WITH ACUTE","	* Slovak\n"
	"	: 006C 0301"},
/* 013B */ { "LATIN CAPITAL LETTER L WITH CEDILLA","	: 004C 0327"},
/* 013C */ { "LATIN SMALL LETTER L WITH CEDILLA","	* Latvian\n"
	"	* despite their names, this pair of characters should normally be displayed with a comma below\n"
	"	: 006C 0327"},
/* 013D */ { "LATIN CAPITAL LETTER L WITH CARON","	* the form using apostrophe is preferred in typesetting\n"
	"	: 004C 030C"},
/* 013E */ { "LATIN SMALL LETTER L WITH CARON","	* Slovak\n"
	"	* the form using apostrophe is preferred in typesetting\n"
	"	: 006C 030C"},
/* 013F */ { "LATIN CAPITAL LETTER L WITH MIDDLE DOT","	* some fonts show the middle dot inside the L, but the preferred form has the dot following the L\n"
	"	# 004C 00B7"},
/* 0140 */ { "LATIN SMALL LETTER L WITH MIDDLE DOT","	* Catalan legacy compatibility character for ISO/IEC 6937\n"
	"	* preferred representation for Catalan: 006C 00B7\n"
	"	# 006C 00B7"},
/* 0141 */ { "LATIN CAPITAL LETTER L WITH STROKE","	x (latin capital letter l with bar - 023D)\n"
	"	x (latin letter small capital l with stroke - 1D0C)\n"
	"	x (latin capital letter l with middle tilde - 2C62)\n"
	"	x (latin capital letter l with high stroke - A748)"},
/* 0142 */ { "LATIN SMALL LETTER L WITH STROKE","	* Polish, Sorbian, Iñupiaq, ...\n"
	"	* also used for Latin-based orthographies for Belarusian and Ukrainian\n"
	"	x (latin small letter l with bar - 019A)\n"
	"	x (latin small letter l with middle tilde - 026B)"},
/* 0143 */ { "LATIN CAPITAL LETTER N WITH ACUTE","	: 004E 0301"},
/* 0144 */ { "LATIN SMALL LETTER N WITH ACUTE","	* Polish, ...\n"
	"	: 006E 0301"},
/* 0145 */ { "LATIN CAPITAL LETTER N WITH CEDILLA","	: 004E 0327"},
/* 0146 */ { "LATIN SMALL LETTER N WITH CEDILLA","	* Latvian\n"
	"	* despite their names, this pair of characters should normally be displayed with a comma below\n"
	"	: 006E 0327"},
/* 0147 */ { "LATIN CAPITAL LETTER N WITH CARON","	: 004E 030C"},
/* 0148 */ { "LATIN SMALL LETTER N WITH CARON","	* Czech, Slovak\n"
	"	: 006E 030C"},
/* 0149 */ { "LATIN SMALL LETTER N PRECEDED BY APOSTROPHE","	= latin small letter apostrophe n (1.0)\n"
	"	* this character is deprecated and its use is strongly discouraged\n"
	"	* Afrikaans\n"
	"	* legacy compatibility character for ISO/IEC 6937\n"
	"	* uppercase is 02BC 004E\n"
	"	# 02BC 006E"},
/* 014A */ { "LATIN CAPITAL LETTER ENG","	* glyph may also have appearance of large form of the small letter\n"
	"	x (latin capital letter n with long right leg - 0220)\n"
	"	x (latin capital letter n with descender - A790)"},
/* 014B */ { "LATIN SMALL LETTER ENG","	= engma, angma\n"
	"	* Sami, Mende, IPA, ...\n"
	"	* velar nasal, nasalization\n"
	"	x (latin small letter n with long right leg - 019E)\n"
	"	x (latin small letter n with palatal hook - 1D87)\n"
	"	x (latin small letter n with descender - A791)"},
/* 014C */ { "LATIN CAPITAL LETTER O WITH MACRON","	: 004F 0304"},
/* 014D */ { "LATIN SMALL LETTER O WITH MACRON","	* Latvian, Latin, ...\n"
	"	: 006F 0304"},
/* 014E */ { "LATIN CAPITAL LETTER O WITH BREVE","	: 004F 0306"},
/* 014F */ { "LATIN SMALL LETTER O WITH BREVE","	* Latin\n"
	"	: 006F 0306"},
/* 0150 */ { "LATIN CAPITAL LETTER O WITH DOUBLE ACUTE","	: 004F 030B"},
/* 0151 */ { "LATIN SMALL LETTER O WITH DOUBLE ACUTE","	* Hungarian\n"
	"	: 006F 030B"},
/* 0152 */ { "LATIN CAPITAL LIGATURE OE",NULL},
/* 0153 */ { "LATIN SMALL LIGATURE OE","	= ethel (from Old English eðel)\n"
	"	* French, IPA, Old Icelandic, Old English, ...\n"
	"	x (latin small letter ae - 00E6)\n"
	"	x (latin letter small capital oe - 0276)\n"
	"	x (latin small letter turned oe - 1D14)\n"
	"	x (modifier letter small ligature oe - A7F9)\n"
	"	x (latin small letter inverted oe - AB40)\n"
	"	x (latin small letter open oe - AB62)"},
/* 0154 */ { "LATIN CAPITAL LETTER R WITH ACUTE","	: 0052 0301"},
/* 0155 */ { "LATIN SMALL LETTER R WITH ACUTE","	* Slovak, ...\n"
	"	: 0072 0301"},
/* 0156 */ { "LATIN CAPITAL LETTER R WITH CEDILLA","	: 0052 0327"},
/* 0157 */ { "LATIN SMALL LETTER R WITH CEDILLA","	* Livonian\n"
	"	* despite their names, this pair of characters should normally be displayed with a comma below\n"
	"	: 0072 0327"},
/* 0158 */ { "LATIN CAPITAL LETTER R WITH CARON","	: 0052 030C"},
/* 0159 */ { "LATIN SMALL LETTER R WITH CARON","	* Czech, ...\n"
	"	: 0072 030C"},
/* 015A */ { "LATIN CAPITAL LETTER S WITH ACUTE","	: 0053 0301"},
/* 015B */ { "LATIN SMALL LETTER S WITH ACUTE","	* Polish, Indic transliteration, ...\n"
	"	: 0073 0301"},
/* 015C */ { "LATIN CAPITAL LETTER S WITH CIRCUMFLEX","	: 0053 0302"},
/* 015D */ { "LATIN SMALL LETTER S WITH CIRCUMFLEX","	* Esperanto\n"
	"	: 0073 0302"},
/* 015E */ { "LATIN CAPITAL LETTER S WITH CEDILLA","	: 0053 0327"},
/* 015F */ { "LATIN SMALL LETTER S WITH CEDILLA","	* Turkish, Azerbaijani, ...\n"
	"	* the character 0219 should be used instead for Romanian\n"
	"	x (latin small letter s with comma below - 0219)\n"
	"	: 0073 0327"},
/* 0160 */ { "LATIN CAPITAL LETTER S WITH CARON","	: 0053 030C"},
/* 0161 */ { "LATIN SMALL LETTER S WITH CARON","	* Czech, Estonian, Finnish, Slovak, and many other languages\n"
	"	: 0073 030C"},
/* 0162 */ { "LATIN CAPITAL LETTER T WITH CEDILLA","	: 0054 0327"},
/* 0163 */ { "LATIN SMALL LETTER T WITH CEDILLA","	* Semitic transliteration, ...\n"
	"	* the character 021B should be used instead for Romanian\n"
	"	x (latin small letter t with comma below - 021B)\n"
	"	: 0074 0327"},
/* 0164 */ { "LATIN CAPITAL LETTER T WITH CARON","	* the form using caron/hacek is preferred in all contexts\n"
	"	: 0054 030C"},
/* 0165 */ { "LATIN SMALL LETTER T WITH CARON","	* Czech, Slovak\n"
	"	* the form using apostrophe is preferred in typesetting\n"
	"	: 0074 030C"},
/* 0166 */ { "LATIN CAPITAL LETTER T WITH STROKE",NULL},
/* 0167 */ { "LATIN SMALL LETTER T WITH STROKE","	* Sami\n"
	"	x (latin small letter t with middle tilde - 1D75)"},
/* 0168 */ { "LATIN CAPITAL LETTER U WITH TILDE","	: 0055 0303"},
/* 0169 */ { "LATIN SMALL LETTER U WITH TILDE","	* Greenlandic (old orthography), Kikuyu\n"
	"	: 0075 0303"},
/* 016A */ { "LATIN CAPITAL LETTER U WITH MACRON","	: 0055 0304"},
/* 016B */ { "LATIN SMALL LETTER U WITH MACRON","	* Latvian, Lithuanian, Latin, ...\n"
	"	: 0075 0304"},
/* 016C */ { "LATIN CAPITAL LETTER U WITH BREVE","	: 0055 0306"},
/* 016D */ { "LATIN SMALL LETTER U WITH BREVE","	* Latin, Esperanto, ...\n"
	"	: 0075 0306"},
/* 016E */ { "LATIN CAPITAL LETTER U WITH RING ABOVE","	: 0055 030A"},
/* 016F */ { "LATIN SMALL LETTER U WITH RING ABOVE","	* Czech, ...\n"
	"	: 0075 030A"},
/* 0170 */ { "LATIN CAPITAL LETTER U WITH DOUBLE ACUTE","	: 0055 030B"},
/* 0171 */ { "LATIN SMALL LETTER U WITH DOUBLE ACUTE","	* Hungarian\n"
	"	: 0075 030B"},
/* 0172 */ { "LATIN CAPITAL LETTER U WITH OGONEK","	: 0055 0328"},
/* 0173 */ { "LATIN SMALL LETTER U WITH OGONEK","	* Lithuanian\n"
	"	: 0075 0328"},
/* 0174 */ { "LATIN CAPITAL LETTER W WITH CIRCUMFLEX","	: 0057 0302"},
/* 0175 */ { "LATIN SMALL LETTER W WITH CIRCUMFLEX","	* Welsh\n"
	"	: 0077 0302"},
/* 0176 */ { "LATIN CAPITAL LETTER Y WITH CIRCUMFLEX","	: 0059 0302"},
/* 0177 */ { "LATIN SMALL LETTER Y WITH CIRCUMFLEX","	* Welsh\n"
	"	: 0079 0302"},
/* 0178 */ { "LATIN CAPITAL LETTER Y WITH DIAERESIS","	* French, Igbo\n"
	"	* lowercase is 00FF\n"
	"	: 0059 0308"},
/* 0179 */ { "LATIN CAPITAL LETTER Z WITH ACUTE","	: 005A 0301"},
/* 017A */ { "LATIN SMALL LETTER Z WITH ACUTE","	* Polish, ...\n"
	"	: 007A 0301"},
/* 017B */ { "LATIN CAPITAL LETTER Z WITH DOT ABOVE","	: 005A 0307"},
/* 017C */ { "LATIN SMALL LETTER Z WITH DOT ABOVE","	* Polish, ...\n"
	"	: 007A 0307"},
/* 017D */ { "LATIN CAPITAL LETTER Z WITH CARON","	: 005A 030C"},
/* 017E */ { "LATIN SMALL LETTER Z WITH CARON","	* Czech, Estonian, Finnish, Slovak, Slovenian, and many other languages\n"
	"	: 007A 030C"},
/* 017F */ { "LATIN SMALL LETTER LONG S","	* in common use in Roman types until the 18th century\n"
	"	* in current use in Fraktur and Gaelic types\n"
	"	x (latin small letter sharp s - 00DF)\n"
	"	x (latin small ligature long s t - FB05)\n"
	"	# 0073 latin small letter s"},
/* 0180 */ { "LATIN SMALL LETTER B WITH STROKE","	* Americanist and Indo-Europeanist usage for phonetic beta\n"
	"	* Americanist orthographies use an alternate glyph with the stroke through the bowl\n"
	"	* also used in Old Saxon manuscripts\n"
	"	* uppercase is 0243\n"
	"	x (greek small letter beta - 03B2)\n"
	"	x (latin small letter b with middle tilde - 1D6C)\n"
	"	x (blank symbol - 2422)"},
/* 0181 */ { "LATIN CAPITAL LETTER B WITH HOOK","	* African languages\n"
	"	* lowercase is 0253"},
/* 0182 */ { "LATIN CAPITAL LETTER B WITH TOPBAR","	x (cyrillic capital letter be - 0411)"},
/* 0183 */ { "LATIN SMALL LETTER B WITH TOPBAR","	* Zhuang (old orthography)\n"
	"	* former Soviet minority language scripts\n"
	"	x (latin small letter b with hook - 0253)\n"
	"	x (cyrillic small letter be - 0431)"},
/* 0184 */ { "LATIN CAPITAL LETTER TONE SIX",NULL},
/* 0185 */ { "LATIN SMALL LETTER TONE SIX","	* Zhuang (old orthography)\n"
	"	* Zhuang tone three is Cyrillic ze\n"
	"	* Zhuang tone four is Cyrillic che\n"
	"	x (latin small letter tone two - 01A8)\n"
	"	x (latin small letter tone five - 01BD)\n"
	"	x (cyrillic small letter ze - 0437)\n"
	"	x (cyrillic small letter che - 0447)\n"
	"	x (cyrillic small letter soft sign - 044C)"},
/* 0186 */ { "LATIN CAPITAL LETTER OPEN O","	* typographically a turned C\n"
	"	* African languages\n"
	"	* lowercase is 0254\n"
	"	x (latin letter small capital open o - 1D10)\n"
	"	x (roman numeral reversed one hundred - 2183)"},
/* 0187 */ { "LATIN CAPITAL LETTER C WITH HOOK",NULL},
/* 0188 */ { "LATIN SMALL LETTER C WITH HOOK","	* African"},
/* 0189 */ { "LATIN CAPITAL LETTER AFRICAN D","	* Ewe\n"
	"	* lowercase is 0256\n"
	"	x (latin capital letter eth - 00D0)\n"
	"	x (latin capital letter d with stroke - 0110)"},
/* 018A */ { "LATIN CAPITAL LETTER D WITH HOOK","	* Pan-Nigerian alphabet\n"
	"	* lowercase is 0257"},
/* 018B */ { "LATIN CAPITAL LETTER D WITH TOPBAR",NULL},
/* 018C */ { "LATIN SMALL LETTER D WITH TOPBAR","	* former-Soviet minority language scripts\n"
	"	* Zhuang (old orthography)"},
/* 018D */ { "LATIN SMALL LETTER TURNED DELTA","	= reversed Polish-hook o\n"
	"	* archaic phonetic for labialized alveolar fricative\n"
	"	* recommended spellings 007A 02B7 or 007A 032B"},
/* 018E */ { "LATIN CAPITAL LETTER REVERSED E","	= turned capital e\n"
	"	* Pan-Nigerian alphabet\n"
	"	* lowercase is 01DD\n"
	"	x (there exists - 2203)\n"
	"	x (latin letter small capital turned e - 2C7B)"},
/* 018F */ { "LATIN CAPITAL LETTER SCHWA","	* Azerbaijani, ...\n"
	"	* lowercase is 0259\n"
	"	x (cyrillic capital letter schwa - 04D8)"},
/* 0190 */ { "LATIN CAPITAL LETTER OPEN E","	= capital epsilon\n"
	"	* African languages\n"
	"	* lowercase is 025B\n"
	"	* not to be confused with glyph variants of capital E\n"
	"	x (euler constant - 2107)\n"
	"	x (turned digit three - 218B)\n"
	"	x (latin capital letter tresillo - A72A)"},
/* 0191 */ { "LATIN CAPITAL LETTER F WITH HOOK","	* African\n"
	"	x (latin capital letter f with stroke - A798)"},
/* 0192 */ { "LATIN SMALL LETTER F WITH HOOK","	= script f\n"
	"	= Florin currency symbol (Netherlands)\n"
	"	= function symbol\n"
	"	* used as abbreviation convention for folder"},
/* 0193 */ { "LATIN CAPITAL LETTER G WITH HOOK","	* African\n"
	"	* lowercase is 0260"},
/* 0194 */ { "LATIN CAPITAL LETTER GAMMA","	* African\n"
	"	* lowercase is 0263"},
/* 0195 */ { "LATIN SMALL LETTER HV","	= hwair\n"
	"	* Gothic transliteration\n"
	"	* uppercase is 01F6\n"
	"	x (gothic letter hwair - 10348)"},
/* 0196 */ { "LATIN CAPITAL LETTER IOTA","	* African languages\n"
	"	* lowercase is 0269\n"
	"	x (cyrillic capital letter iota - A646)"},
/* 0197 */ { "LATIN CAPITAL LETTER I WITH STROKE","	= barred i, i bar\n"
	"	* African languages\n"
	"	* lowercase is 0268\n"
	"	* ISO 6438 gives lowercase as 026A, not 0268\n"
	"	x (latin letter small capital i - 026A)\n"
	"	x (latin small capital letter i with stroke - 1D7B)"},
/* 0198 */ { "LATIN CAPITAL LETTER K WITH HOOK",NULL},
/* 0199 */ { "LATIN SMALL LETTER K WITH HOOK","	* Hausa, Pan-Nigerian alphabet"},
/* 019A */ { "LATIN SMALL LETTER L WITH BAR","	= barred l\n"
	"	* Americanist phonetic usage for IPA ɬ\n"
	"	* uppercase is 023D\n"
	"	x (latin small letter l with stroke - 0142)\n"
	"	x (latin small letter l with belt - 026C)\n"
	"	x (latin small letter l with double bar - 2C61)\n"
	"	x (latin small letter l with high stroke - A749)"},
/* 019B */ { "LATIN SMALL LETTER LAMBDA WITH STROKE","	= barred lambda, lambda bar\n"
	"	* Americanist phonetic usage for IPA tɬ\n"
	"	* uppercase is A7DC\n"
	"	x (greek small letter lamda - 03BB)"},
/* 019C */ { "LATIN CAPITAL LETTER TURNED M","	* Zhuang (old orthography)\n"
	"	* lowercase is 026F\n"
	"	x (latin letter small capital turned m - A7FA)\n"
	"	x (latin epigraphic letter inverted m - A7FD)"},
/* 019D */ { "LATIN CAPITAL LETTER N WITH LEFT HOOK","	* African\n"
	"	* lowercase is 0272"},
/* 019E */ { "LATIN SMALL LETTER N WITH LONG RIGHT LEG","	* archaic phonetic for Japanese 3093\n"
	"	* recommended spelling for syllabic n is 006E 0329\n"
	"	* Lakota (indicates nasalization of vowel), superseded by 014B\n"
	"	* uppercase is 0220\n"
	"	x (latin small letter eng - 014B)\n"
	"	x (hiragana letter n - 3093)"},
/* 019F */ { "LATIN CAPITAL LETTER O WITH MIDDLE TILDE","	= barred o, o bar\n"
	"	* African languages\n"
	"	* the formal name does not describe the glyph\n"
	"	* lowercase is 0275\n"
	"	x (cyrillic capital letter barred o - 04E8)"},
/* 01A0 */ { "LATIN CAPITAL LETTER O WITH HORN","	: 004F 031B"},
/* 01A1 */ { "LATIN SMALL LETTER O WITH HORN","	* Vietnamese\n"
	"	: 006F 031B"},
/* 01A2 */ { "LATIN CAPITAL LETTER OI","	% LATIN CAPITAL LETTER GHA"},
/* 01A3 */ { "LATIN SMALL LETTER OI","	% LATIN SMALL LETTER GHA\n"
	"	* Pan-Turkic Latin alphabets, Tajik"},
/* 01A4 */ { "LATIN CAPITAL LETTER P WITH HOOK",NULL},
/* 01A5 */ { "LATIN SMALL LETTER P WITH HOOK","	* African"},
/* 01A6 */ { "LATIN LETTER YR","	* Old Norse\n"
	"	* from German Standard DIN 31624 and ISO 5426-2\n"
	"	* lowercase is 0280"},
/* 01A7 */ { "LATIN CAPITAL LETTER TONE TWO","	x (latin letter voiced laryngeal spirant - 1D24)\n"
	"	x (cyrillic capital letter reversed dze - A644)\n"
	"	x (roman sextula sign - 10193)"},
/* 01A8 */ { "LATIN SMALL LETTER TONE TWO","	* Zhuang (old orthography)\n"
	"	* typographically a reversed S\n"
	"	x (latin small letter tone six - 0185)\n"
	"	x (cyrillic small letter reversed dze - A645)"},
/* 01A9 */ { "LATIN CAPITAL LETTER ESH","	* African languages\n"
	"	* lowercase is 0283\n"
	"	x (greek capital letter sigma - 03A3)\n"
	"	x (n-ary summation - 2211)"},
/* 01AA */ { "LATIN LETTER REVERSED ESH LOOP","	* archaic phonetic for labialized palatoalveolar or palatal fricative\n"
	"	* Twi\n"
	"	* recommended spellings 0283 02B7, 00E7 02B7, 0068 0265, etc."},
/* 01AB */ { "LATIN SMALL LETTER T WITH PALATAL HOOK","	* archaic phonetic for palatalized alveolar or dental stop\n"
	"	* recommended spelling 0074 02B2"},
/* 01AC */ { "LATIN CAPITAL LETTER T WITH HOOK","	* a glyph variant with hook at the right also occurs"},
/* 01AD */ { "LATIN SMALL LETTER T WITH HOOK","	* African languages"},
/* 01AE */ { "LATIN CAPITAL LETTER T WITH RETROFLEX HOOK","	* African languages\n"
	"	* lowercase is 0288"},
/* 01AF */ { "LATIN CAPITAL LETTER U WITH HORN","	: 0055 031B"},
/* 01B0 */ { "LATIN SMALL LETTER U WITH HORN","	* Vietnamese\n"
	"	: 0075 031B"},
/* 01B1 */ { "LATIN CAPITAL LETTER UPSILON","	* African languages\n"
	"	* typographically, turned capital Greek omega 03A9\n"
	"	* lowercase is 028A\n"
	"	x (inverted ohm sign - 2127)"},
/* 01B2 */ { "LATIN CAPITAL LETTER V WITH HOOK","	= script v\n"
	"	* African\n"
	"	* lowercase is 028B"},
/* 01B3 */ { "LATIN CAPITAL LETTER Y WITH HOOK","	* a glyph variant with hook at the left also occurs"},
/* 01B4 */ { "LATIN SMALL LETTER Y WITH HOOK","	* Bini, Esoko, and other Edo languages in West Africa"},
/* 01B5 */ { "LATIN CAPITAL LETTER Z WITH STROKE",NULL},
/* 01B6 */ { "LATIN SMALL LETTER Z WITH STROKE","	= barred z, z bar\n"
	"	* Pan-Turkic Latin orthography\n"
	"	* also a handwritten variant of Latin \"z\"\n"
	"	x (latin small letter z - 007A)\n"
	"	x (latin small letter z with middle tilde - 1D76)"},
/* 01B7 */ { "LATIN CAPITAL LETTER EZH","	* African, Skolt Sami\n"
	"	* lowercase is 0292\n"
	"	x (latin capital letter yogh - 021C)\n"
	"	x (cyrillic capital letter abkhasian dze - 04E0)\n"
	"	x (latin letter small capital ezh - 1D23)\n"
	"	x (latin capital letter reversed open e - A7AB)"},
/* 01B8 */ { "LATIN CAPITAL LETTER EZH REVERSED","	x (latin capital letter open e - 0190)"},
/* 01B9 */ { "LATIN SMALL LETTER EZH REVERSED","	* archaic phonetic for voiced pharyngeal fricative\n"
	"	* sometimes typographically rendered as a turned digit 3\n"
	"	* recommended spelling is 0295\n"
	"	x (latin letter pharyngeal voiced fricative - 0295)\n"
	"	x (arabic letter ain - 0639)"},
/* 01BA */ { "LATIN SMALL LETTER EZH WITH TAIL","	* archaic phonetic for labialized voiced palatoalveolar or palatal fricative\n"
	"	* Twi\n"
	"	* recommended spellings 0292 02B7 or 006A 02B7"},
/* 01BB */ { "LATIN LETTER TWO WITH STROKE","	* archaic phonetic for [dz] affricate\n"
	"	* recommended spellings 0292 or 0064 007A\n"
	"	x (latin capital letter tone two - 01A7)"},
/* 01BC */ { "LATIN CAPITAL LETTER TONE FIVE",NULL},
/* 01BD */ { "LATIN SMALL LETTER TONE FIVE","	* Zhuang (old orthography)\n"
	"	x (latin small letter tone six - 0185)"},
/* 01BE */ { "LATIN LETTER INVERTED GLOTTAL STOP WITH STROKE","	* archaic phonetic for [ts] affricate\n"
	"	* recommended spelling 0074 0073\n"
	"	* letter form is actually derived from ligation of ts, rather than inverted glottal stop\n"
	"	x (latin letter inverted glottal stop - 0296)\n"
	"	x (latin small letter ts digraph - 02A6)"},
/* 01BF */ { "LATIN LETTER WYNN","	= wen\n"
	"	* Runic letter borrowed into Latin script\n"
	"	* replaced by \"w\" in modern transcriptions of Old English\n"
	"	* uppercase is 01F7\n"
	"	x (runic letter wunjo wynn w - 16B9)"},
/* 01C0 */ { "LATIN LETTER DENTAL CLICK","	= pipe\n"
	"	* \"c\" in Zulu orthography\n"
	"	x (solidus - 002F)\n"
	"	x (vertical line - 007C)\n"
	"	x (latin small letter turned t - 0287)\n"
	"	x (divides - 2223)"},
/* 01C1 */ { "LATIN LETTER LATERAL CLICK","	= double pipe\n"
	"	* \"x\" in Zulu orthography\n"
	"	x (latin letter inverted glottal stop - 0296)\n"
	"	x (double vertical line - 2016)\n"
	"	x (parallel to - 2225)"},
/* 01C2 */ { "LATIN LETTER ALVEOLAR CLICK","	= double-barred pipe\n"
	"	* palatoalveolar click (IPA)\n"
	"	x (not equal to - 2260)\n"
	"	x (thermodynamic - 29E7)"},
/* 01C3 */ { "LATIN LETTER RETROFLEX CLICK","	= latin letter exclamation mark (1.0)\n"
	"	* (post)alveolar click (IPA)\n"
	"	* \"q\" in Zulu orthography\n"
	"	x (exclamation mark - 0021)\n"
	"	x (latin letter stretched c - 0297)\n"
	"	x (modifier letter raised exclamation mark - A71D)\n"
	"	x (latin letter retroflex click with retroflex hook - 1DF0A)"},
/* 01C4 */ { "LATIN CAPITAL LETTER DZ WITH CARON","	# 0044 017D"},
/* 01C5 */ { "LATIN CAPITAL LETTER D WITH SMALL LETTER Z WITH CARON","	# 0044 017E"},
/* 01C6 */ { "LATIN SMALL LETTER DZ WITH CARON","	x (cyrillic small letter dzhe - 045F)\n"
	"	# 0064 017E"},
/* 01C7 */ { "LATIN CAPITAL LETTER LJ","	# 004C 004A"},
/* 01C8 */ { "LATIN CAPITAL LETTER L WITH SMALL LETTER J","	# 004C 006A"},
/* 01C9 */ { "LATIN SMALL LETTER LJ","	x (cyrillic small letter lje - 0459)\n"
	"	# 006C 006A"},
/* 01CA */ { "LATIN CAPITAL LETTER NJ","	# 004E 004A"},
/* 01CB */ { "LATIN CAPITAL LETTER N WITH SMALL LETTER J","	# 004E 006A"},
/* 01CC */ { "LATIN SMALL LETTER NJ","	x (cyrillic small letter nje - 045A)\n"
	"	# 006E 006A"},
/* 01CD */ { "LATIN CAPITAL LETTER A WITH CARON","	: 0041 030C"},
/* 01CE */ { "LATIN SMALL LETTER A WITH CARON","	* Pinyin third tone\n"
	"	: 0061 030C"},
/* 01CF */ { "LATIN CAPITAL LETTER I WITH CARON","	: 0049 030C"},
/* 01D0 */ { "LATIN SMALL LETTER I WITH CARON","	* Pinyin third tone\n"
	"	: 0069 030C"},
/* 01D1 */ { "LATIN CAPITAL LETTER O WITH CARON","	: 004F 030C"},
/* 01D2 */ { "LATIN SMALL LETTER O WITH CARON","	* Pinyin third tone\n"
	"	: 006F 030C"},
/* 01D3 */ { "LATIN CAPITAL LETTER U WITH CARON","	: 0055 030C"},
/* 01D4 */ { "LATIN SMALL LETTER U WITH CARON","	* Pinyin third tone\n"
	"	: 0075 030C"},
/* 01D5 */ { "LATIN CAPITAL LETTER U WITH DIAERESIS AND MACRON","	: 00DC 0304"},
/* 01D6 */ { "LATIN SMALL LETTER U WITH DIAERESIS AND MACRON","	* Pinyin first tone\n"
	"	: 00FC 0304"},
/* 01D7 */ { "LATIN CAPITAL LETTER U WITH DIAERESIS AND ACUTE","	: 00DC 0301"},
/* 01D8 */ { "LATIN SMALL LETTER U WITH DIAERESIS AND ACUTE","	* Pinyin second tone\n"
	"	: 00FC 0301"},
/* 01D9 */ { "LATIN CAPITAL LETTER U WITH DIAERESIS AND CARON","	: 00DC 030C"},
/* 01DA */ { "LATIN SMALL LETTER U WITH DIAERESIS AND CARON","	* Pinyin third tone\n"
	"	: 00FC 030C"},
/* 01DB */ { "LATIN CAPITAL LETTER U WITH DIAERESIS AND GRAVE","	: 00DC 0300"},
/* 01DC */ { "LATIN SMALL LETTER U WITH DIAERESIS AND GRAVE","	* Pinyin fourth tone\n"
	"	: 00FC 0300"},
/* 01DD */ { "LATIN SMALL LETTER TURNED E","	* Pan-Nigerian alphabet\n"
	"	* all other usages of schwa are 0259\n"
	"	* uppercase is 018E\n"
	"	x (latin small letter schwa - 0259)"},
/* 01DE */ { "LATIN CAPITAL LETTER A WITH DIAERESIS AND MACRON","	: 00C4 0304"},
/* 01DF */ { "LATIN SMALL LETTER A WITH DIAERESIS AND MACRON","	* Livonian, Uralicist usage\n"
	"	: 00E4 0304"},
/* 01E0 */ { "LATIN CAPITAL LETTER A WITH DOT ABOVE AND MACRON","	: 0226 0304"},
/* 01E1 */ { "LATIN SMALL LETTER A WITH DOT ABOVE AND MACRON","	* Uralicist usage\n"
	"	: 0227 0304"},
/* 01E2 */ { "LATIN CAPITAL LETTER AE WITH MACRON","	: 00C6 0304"},
/* 01E3 */ { "LATIN SMALL LETTER AE WITH MACRON","	* Old Norse, Old English\n"
	"	: 00E6 0304"},
/* 01E4 */ { "LATIN CAPITAL LETTER G WITH STROKE",NULL},
/* 01E5 */ { "LATIN SMALL LETTER G WITH STROKE","	* Skolt Sami"},
/* 01E6 */ { "LATIN CAPITAL LETTER G WITH CARON","	: 0047 030C"},
/* 01E7 */ { "LATIN SMALL LETTER G WITH CARON","	* Skolt Sami\n"
	"	x (latin small letter g with breve - 011F)\n"
	"	: 0067 030C"},
/* 01E8 */ { "LATIN CAPITAL LETTER K WITH CARON","	: 004B 030C"},
/* 01E9 */ { "LATIN SMALL LETTER K WITH CARON","	* Skolt Sami\n"
	"	: 006B 030C"},
/* 01EA */ { "LATIN CAPITAL LETTER O WITH OGONEK","	: 004F 0328"},
/* 01EB */ { "LATIN SMALL LETTER O WITH OGONEK","	* Sami, Iroquoian, Old Icelandic\n"
	"	: 006F 0328"},
/* 01EC */ { "LATIN CAPITAL LETTER O WITH OGONEK AND MACRON","	: 01EA 0304"},
/* 01ED */ { "LATIN SMALL LETTER O WITH OGONEK AND MACRON","	* Old Icelandic, Livonian (in recent linguistic scholarship)\n"
	"	: 01EB 0304"},
/* 01EE */ { "LATIN CAPITAL LETTER EZH WITH CARON","	: 01B7 030C"},
/* 01EF */ { "LATIN SMALL LETTER EZH WITH CARON","	* Skolt Sami\n"
	"	: 0292 030C"},
/* 01F0 */ { "LATIN SMALL LETTER J WITH CARON","	* IPA and many languages\n"
	"	: 006A 030C"},
/* 01F1 */ { "LATIN CAPITAL LETTER DZ","	# 0044 005A"},
/* 01F2 */ { "LATIN CAPITAL LETTER D WITH SMALL LETTER Z","	# 0044 007A"},
/* 01F3 */ { "LATIN SMALL LETTER DZ","	# 0064 007A"},
/* 01F4 */ { "LATIN CAPITAL LETTER G WITH ACUTE","	: 0047 0301"},
/* 01F5 */ { "LATIN SMALL LETTER G WITH ACUTE","	* Macedonian and Serbian transliteration\n"
	"	: 0067 0301"},
/* 01F6 */ { "LATIN CAPITAL LETTER HWAIR","	* lowercase is 0195\n"
	"	x (cyrillic capital letter komi nje - 050A)\n"
	"	x (gothic letter hwair - 10348)"},
/* 01F7 */ { "LATIN CAPITAL LETTER WYNN","	= wen\n"
	"	* lowercase is 01BF"},
/* 01F8 */ { "LATIN CAPITAL LETTER N WITH GRAVE","	: 004E 0300"},
/* 01F9 */ { "LATIN SMALL LETTER N WITH GRAVE","	* Pinyin\n"
	"	: 006E 0300"},
/* 01FA */ { "LATIN CAPITAL LETTER A WITH RING ABOVE AND ACUTE","	: 00C5 0301"},
/* 01FB */ { "LATIN SMALL LETTER A WITH RING ABOVE AND ACUTE","	: 00E5 0301"},
/* 01FC */ { "LATIN CAPITAL LETTER AE WITH ACUTE","	: 00C6 0301"},
/* 01FD */ { "LATIN SMALL LETTER AE WITH ACUTE","	: 00E6 0301"},
/* 01FE */ { "LATIN CAPITAL LETTER O WITH STROKE AND ACUTE","	: 00D8 0301"},
/* 01FF */ { "LATIN SMALL LETTER O WITH STROKE AND ACUTE","	: 00F8 0301"}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_00_02[] = {
/* 0200 */ { "LATIN CAPITAL LETTER A WITH DOUBLE GRAVE","	: 0041 030F"},
/* 0201 */ { "LATIN SMALL LETTER A WITH DOUBLE GRAVE","	: 0061 030F"},
/* 0202 */ { "LATIN CAPITAL LETTER A WITH INVERTED BREVE","	: 0041 0311"},
/* 0203 */ { "LATIN SMALL LETTER A WITH INVERTED BREVE","	: 0061 0311"},
/* 0204 */ { "LATIN CAPITAL LETTER E WITH DOUBLE GRAVE","	: 0045 030F"},
/* 0205 */ { "LATIN SMALL LETTER E WITH DOUBLE GRAVE","	: 0065 030F"},
/* 0206 */ { "LATIN CAPITAL LETTER E WITH INVERTED BREVE","	: 0045 0311"},
/* 0207 */ { "LATIN SMALL LETTER E WITH INVERTED BREVE","	: 0065 0311"},
/* 0208 */ { "LATIN CAPITAL LETTER I WITH DOUBLE GRAVE","	: 0049 030F"},
/* 0209 */ { "LATIN SMALL LETTER I WITH DOUBLE GRAVE","	: 0069 030F"},
/* 020A */ { "LATIN CAPITAL LETTER I WITH INVERTED BREVE","	: 0049 0311"},
/* 020B */ { "LATIN SMALL LETTER I WITH INVERTED BREVE","	: 0069 0311"},
/* 020C */ { "LATIN CAPITAL LETTER O WITH DOUBLE GRAVE","	: 004F 030F"},
/* 020D */ { "LATIN SMALL LETTER O WITH DOUBLE GRAVE","	: 006F 030F"},
/* 020E */ { "LATIN CAPITAL LETTER O WITH INVERTED BREVE","	: 004F 0311"},
/* 020F */ { "LATIN SMALL LETTER O WITH INVERTED BREVE","	: 006F 0311"},
/* 0210 */ { "LATIN CAPITAL LETTER R WITH DOUBLE GRAVE","	: 0052 030F"},
/* 0211 */ { "LATIN SMALL LETTER R WITH DOUBLE GRAVE","	: 0072 030F"},
/* 0212 */ { "LATIN CAPITAL LETTER R WITH INVERTED BREVE","	: 0052 0311"},
/* 0213 */ { "LATIN SMALL LETTER R WITH INVERTED BREVE","	: 0072 0311"},
/* 0214 */ { "LATIN CAPITAL LETTER U WITH DOUBLE GRAVE","	: 0055 030F"},
/* 0215 */ { "LATIN SMALL LETTER U WITH DOUBLE GRAVE","	: 0075 030F"},
/* 0216 */ { "LATIN CAPITAL LETTER U WITH INVERTED BREVE","	: 0055 0311"},
/* 0217 */ { "LATIN SMALL LETTER U WITH INVERTED BREVE","	: 0075 0311"},
/* 0218 */ { "LATIN CAPITAL LETTER S WITH COMMA BELOW","	: 0053 0326"},
/* 0219 */ { "LATIN SMALL LETTER S WITH COMMA BELOW","	x (latin small letter s with cedilla - 015F)\n"
	"	: 0073 0326"},
/* 021A */ { "LATIN CAPITAL LETTER T WITH COMMA BELOW","	: 0054 0326"},
/* 021B */ { "LATIN SMALL LETTER T WITH COMMA BELOW","	x (latin small letter t with cedilla - 0163)\n"
	"	: 0074 0326"},
/* 021C */ { "LATIN CAPITAL LETTER YOGH","	x (latin capital letter ezh - 01B7)\n"
	"	x (cyrillic capital letter ze - 0417)\n"
	"	x (latin capital letter reversed open e - A7AB)"},
/* 021D */ { "LATIN SMALL LETTER YOGH","	* Middle English, Scots\n"
	"	x (latin small letter ezh - 0292)\n"
	"	x (latin small letter insular g - 1D79)\n"
	"	x (latin small letter et - A76B)"},
/* 021E */ { "LATIN CAPITAL LETTER H WITH CARON","	: 0048 030C"},
/* 021F */ { "LATIN SMALL LETTER H WITH CARON","	* Finnish Romany\n"
	"	: 0068 030C"},
/* 0220 */ { "LATIN CAPITAL LETTER N WITH LONG RIGHT LEG","	* Lakota (nasalization), superseded by 014A\n"
	"	* lowercase is 019E\n"
	"	x (latin capital letter eng - 014A)"},
/* 0221 */ { "LATIN SMALL LETTER D WITH CURL","	* phonetic use in Sinology"},
/* 0222 */ { "LATIN CAPITAL LETTER OU","	x (latin letter small capital ou - 1D15)"},
/* 0223 */ { "LATIN SMALL LETTER OU","	* Algonquin, Huron\n"
	"	x (digit eight - 0038)"},
/* 0224 */ { "LATIN CAPITAL LETTER Z WITH HOOK","	x (latin capital letter z with descender - 2C6B)"},
/* 0225 */ { "LATIN SMALL LETTER Z WITH HOOK","	* Middle High German"},
/* 0226 */ { "LATIN CAPITAL LETTER A WITH DOT ABOVE","	: 0041 0307"},
/* 0227 */ { "LATIN SMALL LETTER A WITH DOT ABOVE","	* Uralicist usage\n"
	"	: 0061 0307"},
/* 0228 */ { "LATIN CAPITAL LETTER E WITH CEDILLA","	: 0045 0327"},
/* 0229 */ { "LATIN SMALL LETTER E WITH CEDILLA","	: 0065 0327"},
/* 022A */ { "LATIN CAPITAL LETTER O WITH DIAERESIS AND MACRON","	: 00D6 0304"},
/* 022B */ { "LATIN SMALL LETTER O WITH DIAERESIS AND MACRON","	: 00F6 0304"},
/* 022C */ { "LATIN CAPITAL LETTER O WITH TILDE AND MACRON","	: 00D5 0304"},
/* 022D */ { "LATIN SMALL LETTER O WITH TILDE AND MACRON","	: 00F5 0304"},
/* 022E */ { "LATIN CAPITAL LETTER O WITH DOT ABOVE","	: 004F 0307"},
/* 022F */ { "LATIN SMALL LETTER O WITH DOT ABOVE","	: 006F 0307"},
/* 0230 */ { "LATIN CAPITAL LETTER O WITH DOT ABOVE AND MACRON","	: 022E 0304"},
/* 0231 */ { "LATIN SMALL LETTER O WITH DOT ABOVE AND MACRON","	: 022F 0304"},
/* 0232 */ { "LATIN CAPITAL LETTER Y WITH MACRON","	: 0059 0304"},
/* 0233 */ { "LATIN SMALL LETTER Y WITH MACRON","	* also Cornish\n"
	"	: 0079 0304"},
/* 0234 */ { "LATIN SMALL LETTER L WITH CURL",NULL},
/* 0235 */ { "LATIN SMALL LETTER N WITH CURL",NULL},
/* 0236 */ { "LATIN SMALL LETTER T WITH CURL",NULL},
/* 0237 */ { "LATIN SMALL LETTER DOTLESS J","	* this is a non-casing letter\n"
	"	x (greek letter yot - 03F3)\n"
	"	x (cyrillic small letter je - 0458)\n"
	"	x (mathematical italic small dotless j - 1D6A5)"},
/* 0238 */ { "LATIN SMALL LETTER DB DIGRAPH",NULL},
/* 0239 */ { "LATIN SMALL LETTER QP DIGRAPH",NULL},
/* 023A */ { "LATIN CAPITAL LETTER A WITH STROKE","	* lowercase is 2C65"},
/* 023B */ { "LATIN CAPITAL LETTER C WITH STROKE","	x (cedi sign - 20B5)"},
/* 023C */ { "LATIN SMALL LETTER C WITH STROKE","	* also used in Americanist linguistics\n"
	"	x (cent sign - 00A2)"},
/* 023D */ { "LATIN CAPITAL LETTER L WITH BAR","	* lowercase is 019A\n"
	"	x (latin capital letter l with stroke - 0141)\n"
	"	x (latin capital letter l with double bar - 2C60)\n"
	"	x (latin capital letter l with middle tilde - 2C62)\n"
	"	x (latin capital letter l with high stroke - A748)"},
/* 023E */ { "LATIN CAPITAL LETTER T WITH DIAGONAL STROKE","	* lowercase is 2C66"},
/* 023F */ { "LATIN SMALL LETTER S WITH SWASH TAIL","	* voiceless labio-alveolar fricative\n"
	"	* uppercase is 2C7E\n"
	"	x (latin small letter s with hook - 0282)"},
/* 0240 */ { "LATIN SMALL LETTER Z WITH SWASH TAIL","	* voiced labio-alveolar fricative\n"
	"	* uppercase is 2C7F\n"
	"	x (latin small letter z with retroflex hook - 0290)"},
/* 0241 */ { "LATIN CAPITAL LETTER GLOTTAL STOP",NULL},
/* 0242 */ { "LATIN SMALL LETTER GLOTTAL STOP","	* casing use in Chipewyan, Dogrib, Slavey (Canadian aboriginal orthographies)\n"
	"	x (latin letter glottal stop - 0294)\n"
	"	x (modifier letter glottal stop - 02C0)"},
/* 0243 */ { "LATIN CAPITAL LETTER B WITH STROKE","	* lowercase is 0180\n"
	"	x (latin letter small capital barred b - 1D03)"},
/* 0244 */ { "LATIN CAPITAL LETTER U BAR","	* lowercase is 0289"},
/* 0245 */ { "LATIN CAPITAL LETTER TURNED V","	* lowercase is 028C\n"
	"	x (greek capital letter lamda - 039B)"},
/* 0246 */ { "LATIN CAPITAL LETTER E WITH STROKE",NULL},
/* 0247 */ { "LATIN SMALL LETTER E WITH STROKE",NULL},
/* 0248 */ { "LATIN CAPITAL LETTER J WITH STROKE",NULL},
/* 0249 */ { "LATIN SMALL LETTER J WITH STROKE",NULL},
/* 024A */ { "LATIN CAPITAL LETTER SMALL Q WITH HOOK TAIL",NULL},
/* 024B */ { "LATIN SMALL LETTER Q WITH HOOK TAIL",NULL},
/* 024C */ { "LATIN CAPITAL LETTER R WITH STROKE",NULL},
/* 024D */ { "LATIN SMALL LETTER R WITH STROKE","	x (latin small letter r with middle tilde - 1D72)"},
/* 024E */ { "LATIN CAPITAL LETTER Y WITH STROKE",NULL},
/* 024F */ { "LATIN SMALL LETTER Y WITH STROKE",NULL},
/* 0250 */ { "LATIN SMALL LETTER TURNED A","	* low central unrounded vowel\n"
	"	* uppercase is 2C6F"},
/* 0251 */ { "LATIN SMALL LETTER ALPHA","	= latin small letter script a (1.0)\n"
	"	* low back unrounded vowel\n"
	"	* the representative glyph appears like an allograph of Latin \"a\", but sometimes the character is rendered more like a Greek \"α\"\n"
	"	* uppercase is 2C6D\n"
	"	x (greek small letter alpha - 03B1)"},
/* 0252 */ { "LATIN SMALL LETTER TURNED ALPHA","	* low back rounded vowel\n"
	"	* uppercase is 2C70\n"
	"	x (latin small letter inverted alpha - AB64)"},
/* 0253 */ { "LATIN SMALL LETTER B WITH HOOK","	* implosive bilabial stop\n"
	"	* uppercase is 0181\n"
	"	x (cyrillic small letter be - 0431)"},
/* 0254 */ { "LATIN SMALL LETTER OPEN O","	* typographically a turned c\n"
	"	* lower-mid back rounded vowel\n"
	"	* in older Danish usage \"ɔ:\" stands for \"that is\"\n"
	"	* uppercase is 0186\n"
	"	x (latin letter small capital open o - 1D10)\n"
	"	x (latin small letter reversed c - 2184)"},
/* 0255 */ { "LATIN SMALL LETTER C WITH CURL","	* voiceless alveolo-palatal laminal fricative\n"
	"	* used in transcription of Mandarin Chinese\n"
	"	* sound spelled with 015B in Polish"},
/* 0256 */ { "LATIN SMALL LETTER D WITH TAIL","	= d retroflex hook\n"
	"	* voiced retroflex stop\n"
	"	* uppercase is 0189"},
/* 0257 */ { "LATIN SMALL LETTER D WITH HOOK","	* implosive dental or alveolar stop\n"
	"	* Ewe, Pan-Nigerian alphabet\n"
	"	* uppercase is 018A"},
/* 0258 */ { "LATIN SMALL LETTER REVERSED E","	* upper-mid central unrounded vowel"},
/* 0259 */ { "LATIN SMALL LETTER SCHWA","	* mid-central unrounded vowel\n"
	"	* uppercase is 018F\n"
	"	* variant uppercase form 018E is associated with 01DD\n"
	"	x (latin small letter turned e - 01DD)\n"
	"	x (cyrillic small letter schwa - 04D9)"},
/* 025A */ { "LATIN SMALL LETTER SCHWA WITH HOOK","	* rhotacized schwa"},
/* 025B */ { "LATIN SMALL LETTER OPEN E","	= epsilon\n"
	"	* lower-mid front unrounded vowel\n"
	"	* uppercase is 0190\n"
	"	x (greek small letter epsilon - 03B5)\n"
	"	x (cyrillic small letter reversed ze - 0511)"},
/* 025C */ { "LATIN SMALL LETTER REVERSED OPEN E","	= reversed epsilon\n"
	"	* lower-mid central unrounded vowel\n"
	"	* uppercase is A7AB\n"
	"	x (cyrillic small letter ze - 0437)\n"
	"	x (latin small letter turned open e - 1D08)"},
/* 025D */ { "LATIN SMALL LETTER REVERSED OPEN E WITH HOOK","	* rhotacized lower-mid central vowel"},
/* 025E */ { "LATIN SMALL LETTER CLOSED REVERSED OPEN E","	= closed reversed epsilon\n"
	"	* lower-mid central rounded vowel\n"
	"	x (latin small letter closed open e - 029A)"},
/* 025F */ { "LATIN SMALL LETTER DOTLESS J WITH STROKE","	* voiced palatal stop\n"
	"	* typographically a turned f, but better thought of as a form of j\n"
	"	* \"gy\" in Hungarian orthography\n"
	"	* also archaic phonetic for palatoalveolar affricate 02A4"},
/* 0260 */ { "LATIN SMALL LETTER G WITH HOOK","	* implosive velar stop\n"
	"	* uppercase is 0193"},
/* 0261 */ { "LATIN SMALL LETTER SCRIPT G","	* voiced velar stop\n"
	"	* uppercase is A7AC\n"
	"	x (latin small letter g - 0067)\n"
	"	x (script small g - 210A)"},
/* 0262 */ { "LATIN LETTER SMALL CAPITAL G","	* voiced uvular stop"},
/* 0263 */ { "LATIN SMALL LETTER GAMMA","	* voiced velar fricative\n"
	"	* uppercase is 0194\n"
	"	x (greek small letter gamma - 03B3)"},
/* 0264 */ { "LATIN SMALL LETTER RAMS HORN","	= latin small letter baby gamma (1.0)\n"
	"	* upper-mid back unrounded vowel\n"
	"	* uppercase is A7CB"},
/* 0265 */ { "LATIN SMALL LETTER TURNED H","	* voiced rounded palatal approximant\n"
	"	* uppercase is A78D"},
/* 0266 */ { "LATIN SMALL LETTER H WITH HOOK","	* breathy-voiced glottal fricative\n"
	"	* uppercase is A7AA\n"
	"	* uppercase in Nawdm is 0124\n"
	"	x (modifier letter small h with hook - 02B1)"},
/* 0267 */ { "LATIN SMALL LETTER HENG WITH HOOK","	* voiceless coarticulated velar and palatoalveolar fricative\n"
	"	* \"sj\" in some Swedish dialects\n"
	"	x (latin small letter heng - A727)"},
/* 0268 */ { "LATIN SMALL LETTER I WITH STROKE","	= barred i, i bar\n"
	"	* high central unrounded vowel\n"
	"	* uppercase is 0197\n"
	"	* ISO 6438 gives lowercase of 0197 as 026A, not 0268\n"
	"	x (latin small capital letter i with stroke - 1D7B)"},
/* 0269 */ { "LATIN SMALL LETTER IOTA","	* semi-high front unrounded vowel\n"
	"	* obsoleted by IPA in 1989\n"
	"	* preferred use is 026A latin letter small capital i\n"
	"	* uppercase is 0196\n"
	"	x (latin small letter dotless i - 0131)\n"
	"	x (greek small letter iota - 03B9)\n"
	"	x (cyrillic small letter iota - A647)\n"
	"	x (mathematical italic small dotless i - 1D6A4)"},
/* 026A */ { "LATIN LETTER SMALL CAPITAL I","	* semi-high front unrounded vowel\n"
	"	* preferred IPA alternate for 0269\n"
	"	* uppercase is A7AE\n"
	"	* ISO 6438 gives this as lowercase of 0197 instead of 0268\n"
	"	* glyph should have top and bottom serifs even in sans serif IPA font designs, to avoid confusion with lowercase l\n"
	"	x (latin small letter dotless i - 0131)"},
/* 026B */ { "LATIN SMALL LETTER L WITH MIDDLE TILDE","	* velarized voiced alveolar lateral approximant\n"
	"	* uppercase is 2C62\n"
	"	x (latin small letter l with stroke - 0142)\n"
	"	x (latin small letter l with inverted lazy s - AB37)\n"
	"	x (latin small letter l with double middle tilde - AB38)"},
/* 026C */ { "LATIN SMALL LETTER L WITH BELT","	* voiceless alveolar lateral fricative\n"
	"	* uppercase is A7AD\n"
	"	x (latin small letter l with bar - 019A)"},
/* 026D */ { "LATIN SMALL LETTER L WITH RETROFLEX HOOK","	* voiced retroflex lateral\n"
	"	x (latin small letter l with retroflex hook and belt - A78E)"},
/* 026E */ { "LATIN SMALL LETTER LEZH","	* voiced lateral fricative\n"
	"	* \"dhl\" in Zulu orthography"},
/* 026F */ { "LATIN SMALL LETTER TURNED M","	* high back unrounded vowel\n"
	"	* uppercase is 019C\n"
	"	x (latin letter small capital turned m - A7FA)"},
/* 0270 */ { "LATIN SMALL LETTER TURNED M WITH LONG LEG","	* voiced velar approximant"},
/* 0271 */ { "LATIN SMALL LETTER M WITH HOOK","	* voiced labiodental nasal\n"
	"	* uppercase is 2C6E\n"
	"	x (latin small letter m with palatal hook - 1D86)"},
/* 0272 */ { "LATIN SMALL LETTER N WITH LEFT HOOK","	* voiced palatal nasal\n"
	"	* uppercase is 019D"},
/* 0273 */ { "LATIN SMALL LETTER N WITH RETROFLEX HOOK","	* voiced retroflex nasal"},
/* 0274 */ { "LATIN LETTER SMALL CAPITAL N","	* voiced uvular nasal"},
/* 0275 */ { "LATIN SMALL LETTER BARRED O","	= o bar\n"
	"	* rounded mid-central vowel, i.e. rounded schwa\n"
	"	* uppercase is 019F\n"
	"	x (greek small letter theta - 03B8)\n"
	"	x (cyrillic small letter fita - 0473)\n"
	"	x (cyrillic small letter barred o - 04E9)"},
/* 0276 */ { "LATIN LETTER SMALL CAPITAL OE","	* low front rounded vowel\n"
	"	x (latin small ligature oe - 0153)"},
/* 0277 */ { "LATIN SMALL LETTER CLOSED OMEGA","	* near-close near-back rounded vowel\n"
	"	* obsoleted by IPA in 1989\n"
	"	* preferred use is 028A latin small letter upsilon\n"
	"	x (latin small letter omega - A7B7)\n"
	"	x (greek letter small capital omega - AB65)"},
/* 0278 */ { "LATIN SMALL LETTER PHI","	* voiceless bilabial fricative\n"
	"	* this is a non-casing letter\n"
	"	x (greek small letter phi - 03C6)\n"
	"	x (greek phi symbol - 03D5)\n"
	"	x (latin small letter tailless phi - 2C77)"},
/* 0279 */ { "LATIN SMALL LETTER TURNED R","	* voiced alveolar approximant\n"
	"	x (modifier letter small turned r - 02B4)"},
/* 027A */ { "LATIN SMALL LETTER TURNED R WITH LONG LEG","	* voiced lateral flap"},
/* 027B */ { "LATIN SMALL LETTER TURNED R WITH HOOK","	* voiced retroflex approximant\n"
	"	x (modifier letter small turned r with hook - 02B5)"},
/* 027C */ { "LATIN SMALL LETTER R WITH LONG LEG","	* voiced strident apico-alveolar trill\n"
	"	* obsoleted by IPA in 1989\n"
	"	* this sound is spelled with 0159 in Czech\n"
	"	* preferred phonetic representation for Czech is 0072 031D\n"
	"	* in current use in Gaelic types (as glyph variant of 0072)\n"
	"	x (latin small letter insular r - A783)\n"
	"	x (latin small letter insular s - A785)"},
/* 027D */ { "LATIN SMALL LETTER R WITH TAIL","	* voiced retroflex flap\n"
	"	* uppercase is 2C64\n"
	"	x (latin small letter turned r with tail - 2C79)"},
/* 027E */ { "LATIN SMALL LETTER R WITH FISHHOOK","	* voiced alveolar flap or tap\n"
	"	x (latin small letter long s - 017F)"},
/* 027F */ { "LATIN SMALL LETTER REVERSED R WITH FISHHOOK","	= long i with left hook\n"
	"	= long leg turned iota (a misnomer)\n"
	"	* apical dental vowel\n"
	"	* IPA spelling - 007A 0329\n"
	"	* this character is not actually a reversed 027E\n"
	"	* preferred presentation is with a descender"},
/* 0280 */ { "LATIN LETTER SMALL CAPITAL R","	* voiced uvular trill\n"
	"	* Germanic, Old Norse\n"
	"	* uppercase is 01A6"},
/* 0281 */ { "LATIN LETTER SMALL CAPITAL INVERTED R","	* voiced uvular fricative or approximant\n"
	"	x (modifier letter small capital inverted r - 02B6)"},
/* 0282 */ { "LATIN SMALL LETTER S WITH HOOK","	* voiceless retroflex fricative\n"
	"	* uppercase is A7C5"},
/* 0283 */ { "LATIN SMALL LETTER ESH","	* voiceless postalveolar fricative\n"
	"	* uppercase is 01A9\n"
	"	x (integral - 222B)\n"
	"	x (latin small letter baseline esh - AB4D)"},
/* 0284 */ { "LATIN SMALL LETTER DOTLESS J WITH STROKE AND HOOK","	* implosive palatal stop\n"
	"	* typographically based on 025F, not on 0283"},
/* 0285 */ { "LATIN SMALL LETTER SQUAT REVERSED ESH","	= long i with left hook and tail\n"
	"	* apical retroflex vowel\n"
	"	* IPA spelling - 0290 0329\n"
	"	* this character is not actually a reversed esh\n"
	"	* preferred presentation is with a descender"},
/* 0286 */ { "LATIN SMALL LETTER ESH WITH CURL","	* palatalized voiceless postalveolar fricative\n"
	"	* suggested spelling - 0283 02B2"},
/* 0287 */ { "LATIN SMALL LETTER TURNED T","	* dental click (sound of \"tsk tsk\")\n"
	"	* uppercase is A7B1\n"
	"	x (latin letter dental click - 01C0)"},
/* 0288 */ { "LATIN SMALL LETTER T WITH RETROFLEX HOOK","	* voiceless retroflex stop\n"
	"	* uppercase is 01AE\n"
	"	x (latin small letter t with hook - 01AD)\n"
	"	x (latin small letter t with hook and retroflex hook - 1DF09)"},
/* 0289 */ { "LATIN SMALL LETTER U BAR","	* high central rounded vowel\n"
	"	* uppercase is 0244\n"
	"	x (latin small capital letter u with stroke - 1D7E)"},
/* 028A */ { "LATIN SMALL LETTER UPSILON","	* near-close near-back rounded vowel\n"
	"	* typographically, a turned Greek small capital omega AB65\n"
	"	* preferred IPA alternate to 0277\n"
	"	* uppercase is 01B1\n"
	"	x (greek small letter upsilon - 03C5)"},
/* 028B */ { "LATIN SMALL LETTER V WITH HOOK","	= latin small letter script v (1.0)\n"
	"	* voiced labiodental approximant\n"
	"	* uppercase is 01B2\n"
	"	x (greek small letter upsilon - 03C5)"},
/* 028C */ { "LATIN SMALL LETTER TURNED V","	= caret, wedge\n"
	"	* lower-mid back unrounded vowel\n"
	"	* uppercase is 0245\n"
	"	x (greek capital letter lamda - 039B)\n"
	"	x (greek letter small capital lamda - 1D27)\n"
	"	x (logical and - 2227)"},
/* 028D */ { "LATIN SMALL LETTER TURNED W","	* voiceless rounded labiovelar approximant\n"
	"	x (modifier letter small turned w - AB69)"},
/* 028E */ { "LATIN SMALL LETTER TURNED Y","	* voiced lateral approximant"},
/* 028F */ { "LATIN LETTER SMALL CAPITAL Y","	* semi-high front rounded vowel"},
/* 0290 */ { "LATIN SMALL LETTER Z WITH RETROFLEX HOOK","	* voiced retroflex fricative"},
/* 0291 */ { "LATIN SMALL LETTER Z WITH CURL","	* voiced alveolo-palatal laminal fricative\n"
	"	* sound spelled with 017A in Polish"},
/* 0292 */ { "LATIN SMALL LETTER EZH","	= dram sign\n"
	"	* voiced postalveolar fricative\n"
	"	* mistakenly named yogh in Unicode 1.0\n"
	"	* uppercase is 01B7\n"
	"	* Skolt Sami\n"
	"	x (latin small letter yogh - 021D)\n"
	"	x (cyrillic small letter abkhasian dze - 04E1)\n"
	"	x (ounce sign - 2125)\n"
	"	x (alchemical symbol for half dram - 1F772)\n"
	"	x 2CF01"},
/* 0293 */ { "LATIN SMALL LETTER EZH WITH CURL","	* palatalized voiced postalveolar fricative"},
/* 0294 */ { "LATIN LETTER GLOTTAL STOP","	* this is a caseless letter\n"
	"	* used in IPA, other phonetic notations, and those orthographies which use a caseless glottal stop\n"
	"	x (latin capital letter glottal stop - 0241)\n"
	"	x (modifier letter glottal stop - 02C0)"},
/* 0295 */ { "LATIN LETTER PHARYNGEAL VOICED FRICATIVE","	= reversed glottal stop\n"
	"	* voiced pharyngeal fricative\n"
	"	* ain\n"
	"	x (latin small letter ezh reversed - 01B9)\n"
	"	x (modifier letter reversed glottal stop - 02C1)\n"
	"	x (latin small letter pharyngeal voiced fricative - A7CF)"},
/* 0296 */ { "LATIN LETTER INVERTED GLOTTAL STOP","	* lateral click\n"
	"	x (latin letter lateral click - 01C1)"},
/* 0297 */ { "LATIN LETTER STRETCHED C","	* palatal (or alveolar) click\n"
	"	x (latin letter retroflex click - 01C3)\n"
	"	x (complement - 2201)"},
/* 0298 */ { "LATIN LETTER BILABIAL CLICK","	= bullseye\n"
	"	* this is a non-casing letter\n"
	"	x (circled dot operator - 2299)\n"
	"	x (cyrillic capital letter monocular o - A668)"},
/* 0299 */ { "LATIN LETTER SMALL CAPITAL B","	* bilabial trill\n"
	"	x (cyrillic small letter ve - 0432)"},
/* 029A */ { "LATIN SMALL LETTER CLOSED OPEN E","	= closed epsilon\n"
	"	* lower-mid front rounded vowel\n"
	"	* non-IPA alternate for the preferred 0153\n"
	"	x (latin small letter closed reversed open e - 025E)"},
/* 029B */ { "LATIN LETTER SMALL CAPITAL G WITH HOOK","	* voiced uvular implosive"},
/* 029C */ { "LATIN LETTER SMALL CAPITAL H","	* voiceless epiglottal fricative\n"
	"	x (cyrillic small letter en - 043D)\n"
	"	x (modifier letter capital h - 1D34)\n"
	"	x (modifier letter capital h with stroke - A7F8)"},
/* 029D */ { "LATIN SMALL LETTER J WITH CROSSED-TAIL","	* voiced palatal fricative\n"
	"	* uppercase is A7B2"},
/* 029E */ { "LATIN SMALL LETTER TURNED K","	* proposed for velar click\n"
	"	* uppercase is A7B0\n"
	"	* withdrawn by IPA in 1970\n"
	"	x (latin letter small capital turned k - 1DF10)"},
/* 029F */ { "LATIN LETTER SMALL CAPITAL L","	* velar lateral approximant"},
/* 02A0 */ { "LATIN SMALL LETTER Q WITH HOOK","	* voiceless uvular implosive"},
/* 02A1 */ { "LATIN LETTER GLOTTAL STOP WITH STROKE","	* voiced epiglottal stop"},
/* 02A2 */ { "LATIN LETTER REVERSED GLOTTAL STOP WITH STROKE","	* voiced epiglottal fricative"},
/* 02A3 */ { "LATIN SMALL LETTER DZ DIGRAPH","	* voiced dental affricate\n"
	"	x (latin small letter dz digraph with retroflex hook - AB66)"},
/* 02A4 */ { "LATIN SMALL LETTER DEZH DIGRAPH","	* voiced postalveolar affricate"},
/* 02A5 */ { "LATIN SMALL LETTER DZ DIGRAPH WITH CURL","	* voiced alveolo-palatal affricate"},
/* 02A6 */ { "LATIN SMALL LETTER TS DIGRAPH","	* voiceless dental affricate\n"
	"	x (latin letter inverted glottal stop with stroke - 01BE)\n"
	"	x (latin small letter ts digraph with retroflex hook - AB67)"},
/* 02A7 */ { "LATIN SMALL LETTER TESH DIGRAPH","	* voiceless postalveolar affricate\n"
	"	x (latin small letter tz - A729)"},
/* 02A8 */ { "LATIN SMALL LETTER TC DIGRAPH WITH CURL","	* voiceless alveolo-palatal affricate"},
/* 02A9 */ { "LATIN SMALL LETTER FENG DIGRAPH","	* velopharyngeal fricative"},
/* 02AA */ { "LATIN SMALL LETTER LS DIGRAPH","	* lateral alveolar fricative (lisp)"},
/* 02AB */ { "LATIN SMALL LETTER LZ DIGRAPH","	* voiced lateral alveolar fricative"},
/* 02AC */ { "LATIN LETTER BILABIAL PERCUSSIVE","	* audible lip smack"},
/* 02AD */ { "LATIN LETTER BIDENTAL PERCUSSIVE","	* audible teeth gnashing"},
/* 02AE */ { "LATIN SMALL LETTER TURNED H WITH FISHHOOK","	= turned h with left hook\n"
	"	* labialized apical dental vowel"},
/* 02AF */ { "LATIN SMALL LETTER TURNED H WITH FISHHOOK AND TAIL","	= turned h with left hook and tail\n"
	"	* labialized apical retroflex vowel"},
/* 02B0 */ { "MODIFIER LETTER SMALL H","	* aspiration\n"
	"	# <super> 0068"},
/* 02B1 */ { "MODIFIER LETTER SMALL H WITH HOOK","	* breathy voiced, murmured\n"
	"	x (latin small letter h with hook - 0266)\n"
	"	x (combining diaeresis below - 0324)\n"
	"	# <super> 0266"},
/* 02B2 */ { "MODIFIER LETTER SMALL J","	* palatalization\n"
	"	x (combining palatalized hook below - 0321)\n"
	"	# <super> 006A"},
/* 02B3 */ { "MODIFIER LETTER SMALL R","	# <super> 0072"},
/* 02B4 */ { "MODIFIER LETTER SMALL TURNED R","	x (latin small letter turned r - 0279)\n"
	"	# <super> 0279"},
/* 02B5 */ { "MODIFIER LETTER SMALL TURNED R WITH HOOK","	x (latin small letter turned r with hook - 027B)\n"
	"	# <super> 027B"},
/* 02B6 */ { "MODIFIER LETTER SMALL CAPITAL INVERTED R","	* preceding four used for r-coloring or r-offglides\n"
	"	x (latin letter small capital inverted r - 0281)\n"
	"	# <super> 0281"},
/* 02B7 */ { "MODIFIER LETTER SMALL W","	* labialization\n"
	"	x (combining inverted double arch below - 032B)\n"
	"	# <super> 0077"},
/* 02B8 */ { "MODIFIER LETTER SMALL Y","	* palatalization\n"
	"	* common Americanist usage for 02B2\n"
	"	# <super> 0079"},
/* 02B9 */ { "MODIFIER LETTER PRIME","	* stress, emphasis\n"
	"	* transliteration of mjagkij znak (Cyrillic soft sign: palatalization)\n"
	"	* transliteration of Hebrew geresh\n"
	"	x (apostrophe - 0027)\n"
	"	x (acute accent - 00B4)\n"
	"	x (modifier letter acute accent - 02CA)\n"
	"	x (combining acute accent - 0301)\n"
	"	x (greek numeral sign - 0374)\n"
	"	x (hebrew punctuation geresh - 05F3)\n"
	"	x (prime - 2032)"},
/* 02BA */ { "MODIFIER LETTER DOUBLE PRIME","	* exaggerated stress, contrastive stress\n"
	"	* transliteration of tverdyj znak (Cyrillic hard sign: no palatalization)\n"
	"	x (quotation mark - 0022)\n"
	"	x (combining double acute accent - 030B)\n"
	"	x (double prime - 2033)"},
/* 02BB */ { "MODIFIER LETTER TURNED COMMA","	* typographical alternate for 02BD or 02BF\n"
	"	* used in some Polynesian orthographies for glottal stop\n"
	"	* Hawaiʻian: ʻokina\n"
	"	* Tongan: fakauʻa\n"
	"	x (combining turned comma above - 0312)\n"
	"	x (nko low tone apostrophe - 07F5)\n"
	"	x (left single quotation mark - 2018)"},
/* 02BC */ { "MODIFIER LETTER APOSTROPHE","	= apostrophe\n"
	"	* glottal stop, glottalization, ejective\n"
	"	* many languages use this as a letter of their alphabets\n"
	"	* used as a tone marker in Bodo and Dogri\n"
	"	* indicates vowel elongation, or various truncations and ellipsis in Maithili\n"
	"	* used as a modifier letter in the Lisu script\n"
	"	* 2019 is the preferred character for a punctuation apostrophe\n"
	"	x (apostrophe - 0027)\n"
	"	x (combining comma above - 0313)\n"
	"	x (combining comma above right - 0315)\n"
	"	x (armenian apostrophe - 055A)\n"
	"	x (nko high tone apostrophe - 07F4)\n"
	"	x (greek psili - 1FBF)\n"
	"	x (right single quotation mark - 2019)"},
/* 02BD */ { "MODIFIER LETTER REVERSED COMMA","	* weak aspiration\n"
	"	x (combining reversed comma above - 0314)\n"
	"	x (armenian modifier letter left half ring - 0559)\n"
	"	x (greek dasia - 1FFE)\n"
	"	x (single high-reversed-9 quotation mark - 201B)"},
/* 02BE */ { "MODIFIER LETTER RIGHT HALF RING","	* transliteration of Arabic hamza (glottal stop)\n"
	"	* transliteration of Hebrew alef\n"
	"	x (armenian apostrophe - 055A)\n"
	"	x (hebrew letter alef - 05D0)\n"
	"	x (arabic letter hamza - 0621)"},
/* 02BF */ { "MODIFIER LETTER LEFT HALF RING","	* transliteration of Arabic ain (voiced pharyngeal fricative)\n"
	"	* transliteration of Hebrew ayin\n"
	"	x (armenian modifier letter left half ring - 0559)\n"
	"	x (hebrew letter ayin - 05E2)\n"
	"	x (arabic letter ain - 0639)"},
/* 02C0 */ { "MODIFIER LETTER GLOTTAL STOP","	* ejective or glottalized\n"
	"	* typographical alternate for 02BC or 02BE\n"
	"	x (latin letter glottal stop - 0294)\n"
	"	x (combining hook above - 0309)"},
/* 02C1 */ { "MODIFIER LETTER REVERSED GLOTTAL STOP","	* typographical alternate for 02BF\n"
	"	x (latin letter pharyngeal voiced fricative - 0295)"},
/* 02C2 */ { "MODIFIER LETTER LEFT ARROWHEAD","	* fronted articulation"},
/* 02C3 */ { "MODIFIER LETTER RIGHT ARROWHEAD","	* backed articulation"},
/* 02C4 */ { "MODIFIER LETTER UP ARROWHEAD","	* raised articulation\n"
	"	x (circumflex accent - 005E)\n"
	"	x (up arrowhead - 2303)"},
/* 02C5 */ { "MODIFIER LETTER DOWN ARROWHEAD","	* lowered articulation"},
/* 02C6 */ { "MODIFIER LETTER CIRCUMFLEX ACCENT","	* rising-falling tone, falling tone, secondary stress, etc.\n"
	"	x (circumflex accent - 005E)\n"
	"	x (combining circumflex accent - 0302)\n"
	"	x (modifier letter low circumflex accent - A788)"},
/* 02C7 */ { "CARON","	= hacek\n"
	"	* falling-rising tone\n"
	"	* Mandarin Chinese third tone\n"
	"	x (combining caron - 030C)"},
/* 02C8 */ { "MODIFIER LETTER VERTICAL LINE","	* primary stress, downstep\n"
	"	* precedes letter or syllable modified\n"
	"	x (apostrophe - 0027)\n"
	"	x (combining vertical line above - 030D)"},
/* 02C9 */ { "MODIFIER LETTER MACRON","	* high level tone\n"
	"	* precedes or follows letter or syllable modified\n"
	"	* Mandarin Chinese first tone\n"
	"	x (macron - 00AF)\n"
	"	x (combining macron - 0304)"},
/* 02CA */ { "MODIFIER LETTER ACUTE ACCENT","	* high-rising tone (IPA), high tone, primary stress\n"
	"	* Mandarin Chinese second tone\n"
	"	x (acute accent - 00B4)\n"
	"	x (modifier letter prime - 02B9)\n"
	"	x (combining acute accent - 0301)\n"
	"	x (greek numeral sign - 0374)\n"
	"	x (armenian emphasis mark - 055B)"},
/* 02CB */ { "MODIFIER LETTER GRAVE ACCENT","	* high-falling tone (IPA), low tone, secondary or tertiary stress\n"
	"	* Mandarin Chinese fourth tone\n"
	"	x (grave accent - 0060)\n"
	"	x (combining grave accent - 0300)\n"
	"	x (armenian comma - 055D)"},
/* 02CC */ { "MODIFIER LETTER LOW VERTICAL LINE","	* secondary stress\n"
	"	* precedes letter or syllable modified\n"
	"	x (combining vertical line below - 0329)"},
/* 02CD */ { "MODIFIER LETTER LOW MACRON","	* low level tone\n"
	"	* used as a modifier letter in the Lisu script\n"
	"	x (low line - 005F)\n"
	"	x (combining macron below - 0331)"},
/* 02CE */ { "MODIFIER LETTER LOW GRAVE ACCENT","	* low-falling tone"},
/* 02CF */ { "MODIFIER LETTER LOW ACUTE ACCENT","	* low-rising tone\n"
	"	x (greek lower numeral sign - 0375)"},
/* 02D0 */ { "MODIFIER LETTER TRIANGULAR COLON","	* length mark\n"
	"	x (colon - 003A)"},
/* 02D1 */ { "MODIFIER LETTER HALF TRIANGULAR COLON","	* half-length mark\n"
	"	x (middle dot - 00B7)"},
/* 02D2 */ { "MODIFIER LETTER CENTRED RIGHT HALF RING","	* more rounded articulation"},
/* 02D3 */ { "MODIFIER LETTER CENTRED LEFT HALF RING","	* less rounded articulation"},
/* 02D4 */ { "MODIFIER LETTER UP TACK","	* vowel raising or closing\n"
	"	x (combining up tack below - 031D)\n"
	"	x (combining dot below - 0323)"},
/* 02D5 */ { "MODIFIER LETTER DOWN TACK","	* vowel lowering or opening\n"
	"	x (combining left half ring below - 031C)\n"
	"	x (combining down tack below - 031E)"},
/* 02D6 */ { "MODIFIER LETTER PLUS SIGN","	* advanced or fronted articulation\n"
	"	x (combining plus sign below - 031F)"},
/* 02D7 */ { "MODIFIER LETTER MINUS SIGN","	* retracted or backed articulation\n"
	"	* glyph may have small end-serifs\n"
	"	x (combining minus sign below - 0320)\n"
	"	x (minus sign - 2212)"},
/* 02D8 */ { "BREVE","	x (combining breve - 0306)\n"
	"	# 0020 0306"},
/* 02D9 */ { "DOT ABOVE","	* Mandarin Chinese fifth tone (light or neutral)\n"
	"	x (combining dot above - 0307)\n"
	"	# 0020 0307"},
/* 02DA */ { "RING ABOVE","	x (degree sign - 00B0)\n"
	"	x (combining ring above - 030A)\n"
	"	# 0020 030A"},
/* 02DB */ { "OGONEK","	x (combining ogonek - 0328)\n"
	"	# 0020 0328"},
/* 02DC */ { "SMALL TILDE","	x (tilde - 007E)\n"
	"	x (combining tilde - 0303)\n"
	"	x (tilde operator - 223C)\n"
	"	# 0020 0303"},
/* 02DD */ { "DOUBLE ACUTE ACCENT","	x (combining double acute accent - 030B)\n"
	"	# 0020 030B"},
/* 02DE */ { "MODIFIER LETTER RHOTIC HOOK","	* rhotacization in vowel\n"
	"	* often ligated: 025A = 0259 + 02DE; 025D = 025C + 02DE"},
/* 02DF */ { "MODIFIER LETTER CROSS ACCENT","	* Swedish grave accent"},
/* 02E0 */ { "MODIFIER LETTER SMALL GAMMA","	* these modifier letters are occasionally used in transcription of affricates\n"
	"	# <super> 0263"},
/* 02E1 */ { "MODIFIER LETTER SMALL L","	# <super> 006C"},
/* 02E2 */ { "MODIFIER LETTER SMALL S","	# <super> 0073"},
/* 02E3 */ { "MODIFIER LETTER SMALL X","	# <super> 0078"},
/* 02E4 */ { "MODIFIER LETTER SMALL REVERSED GLOTTAL STOP","	# <super> 0295"},
/* 02E5 */ { "MODIFIER LETTER EXTRA-HIGH TONE BAR",NULL},
/* 02E6 */ { "MODIFIER LETTER HIGH TONE BAR",NULL},
/* 02E7 */ { "MODIFIER LETTER MID TONE BAR",NULL},
/* 02E8 */ { "MODIFIER LETTER LOW TONE BAR",NULL},
/* 02E9 */ { "MODIFIER LETTER EXTRA-LOW TONE BAR",NULL},
/* 02EA */ { "MODIFIER LETTER YIN DEPARTING TONE MARK",NULL},
/* 02EB */ { "MODIFIER LETTER YANG DEPARTING TONE MARK",NULL},
/* 02EC */ { "MODIFIER LETTER VOICING",NULL},
/* 02ED */ { "MODIFIER LETTER UNASPIRATED","	x (modifier letter short equals sign - A78A)"},
/* 02EE */ { "MODIFIER LETTER DOUBLE APOSTROPHE","	* Nenets"},
/* 02EF */ { "MODIFIER LETTER LOW DOWN ARROWHEAD",NULL},
/* 02F0 */ { "MODIFIER LETTER LOW UP ARROWHEAD",NULL},
/* 02F1 */ { "MODIFIER LETTER LOW LEFT ARROWHEAD",NULL},
/* 02F2 */ { "MODIFIER LETTER LOW RIGHT ARROWHEAD",NULL},
/* 02F3 */ { "MODIFIER LETTER LOW RING","	x (combining ring below - 0325)"},
/* 02F4 */ { "MODIFIER LETTER MIDDLE GRAVE ACCENT",NULL},
/* 02F5 */ { "MODIFIER LETTER MIDDLE DOUBLE GRAVE ACCENT",NULL},
/* 02F6 */ { "MODIFIER LETTER MIDDLE DOUBLE ACUTE ACCENT",NULL},
/* 02F7 */ { "MODIFIER LETTER LOW TILDE",NULL},
/* 02F8 */ { "MODIFIER LETTER RAISED COLON",NULL},
/* 02F9 */ { "MODIFIER LETTER BEGIN HIGH TONE",NULL},
/* 02FA */ { "MODIFIER LETTER END HIGH TONE",NULL},
/* 02FB */ { "MODIFIER LETTER BEGIN LOW TONE",NULL},
/* 02FC */ { "MODIFIER LETTER END LOW TONE",NULL},
/* 02FD */ { "MODIFIER LETTER SHELF",NULL},
/* 02FE */ { "MODIFIER LETTER OPEN SHELF",NULL},
/* 02FF */ { "MODIFIER LETTER LOW LEFT ARROW",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_00_03[] = {
/* 0300 */ { "COMBINING GRAVE ACCENT","	= Greek varia\n"
	"	* Pinyin: marks Mandarin Chinese fourth tone\n"
	"	x (grave accent - 0060)\n"
	"	x (modifier letter grave accent - 02CB)"},
/* 0301 */ { "COMBINING ACUTE ACCENT","	= stress mark\n"
	"	= Greek oxia, tonos\n"
	"	* Pinyin: marks Mandarin Chinese second tone\n"
	"	x (apostrophe - 0027)\n"
	"	x (acute accent - 00B4)\n"
	"	x (modifier letter prime - 02B9)\n"
	"	x (modifier letter acute accent - 02CA)\n"
	"	x (greek tonos - 0384)"},
/* 0302 */ { "COMBINING CIRCUMFLEX ACCENT","	= hat\n"
	"	x (circumflex accent - 005E)\n"
	"	x (modifier letter circumflex accent - 02C6)"},
/* 0303 */ { "COMBINING TILDE","	* IPA: nasalization\n"
	"	* Vietnamese tone mark\n"
	"	* distinguished from the Middle Vietnamese \"apex\" diacritic\n"
	"	x (tilde - 007E)\n"
	"	x (small tilde - 02DC)\n"
	"	x (combining macron-acute - 1DC4)"},
/* 0304 */ { "COMBINING MACRON","	= long\n"
	"	* Pinyin: marks Mandarin Chinese first tone\n"
	"	* distinguish from the following\n"
	"	x (macron - 00AF)\n"
	"	x (modifier letter macron - 02C9)\n"
	"	x (combining minus sign above - 1AE2)"},
/* 0305 */ { "COMBINING OVERLINE","	= overscore, vinculum\n"
	"	* connects on left and right\n"
	"	x (macron - 00AF)"},
/* 0306 */ { "COMBINING BREVE","	= short\n"
	"	= Greek vrachy\n"
	"	x (breve - 02D8)\n"
	"	x (combining cyrillic kavyka - A67C)"},
/* 0307 */ { "COMBINING DOT ABOVE","	= derivative (Newtonian notation)\n"
	"	* IPA (withdrawn in 1976): palatalization\n"
	"	x (dot above - 02D9)"},
/* 0308 */ { "COMBINING DIAERESIS","	= double dot above, umlaut\n"
	"	= Greek dialytika\n"
	"	= double derivative\n"
	"	x (diaeresis - 00A8)"},
/* 0309 */ { "COMBINING HOOK ABOVE","	= hoi\n"
	"	* kerns left or right of circumflex over vowels\n"
	"	* Vietnamese tone mark\n"
	"	x (modifier letter glottal stop - 02C0)"},
/* 030A */ { "COMBINING RING ABOVE","	x (degree sign - 00B0)\n"
	"	x (ring above - 02DA)"},
/* 030B */ { "COMBINING DOUBLE ACUTE ACCENT","	* Hungarian, Chuvash\n"
	"	x (quotation mark - 0022)\n"
	"	x (modifier letter double prime - 02BA)\n"
	"	x (double acute accent - 02DD)"},
/* 030C */ { "COMBINING CARON","	= hacek, V above\n"
	"	* Pinyin: marks Mandarin Chinese third tone\n"
	"	x (caron - 02C7)"},
/* 030D */ { "COMBINING VERTICAL LINE ABOVE","	* this is not the Greek tonos\n"
	"	* Marshallese\n"
	"	x (modifier letter vertical line - 02C8)"},
/* 030E */ { "COMBINING DOUBLE VERTICAL LINE ABOVE","	* Marshallese\n"
	"	x (quotation mark - 0022)"},
/* 030F */ { "COMBINING DOUBLE GRAVE ACCENT","	* Serbian and Croatian phonetics"},
/* 0310 */ { "COMBINING CANDRABINDU","	x (devanagari sign candrabindu - 0901)"},
/* 0311 */ { "COMBINING INVERTED BREVE","	x (combining cyrillic palatalization - 0484)\n"
	"	x (combining cyrillic pokrytie - 0487)"},
/* 0312 */ { "COMBINING TURNED COMMA ABOVE","	= cedilla above\n"
	"	* Latvian (but not used in decomposition)\n"
	"	x (modifier letter turned comma - 02BB)"},
/* 0313 */ { "COMBINING COMMA ABOVE","	= Greek psili, smooth breathing mark\n"
	"	* Americanist: ejective or glottalization\n"
	"	x (modifier letter apostrophe - 02BC)\n"
	"	x (combining cyrillic psili pneumata - 0486)\n"
	"	x (armenian apostrophe - 055A)"},
/* 0314 */ { "COMBINING REVERSED COMMA ABOVE","	= Greek dasia, rough breathing mark\n"
	"	x (modifier letter reversed comma - 02BD)\n"
	"	x (combining cyrillic dasia pneumata - 0485)\n"
	"	x (armenian modifier letter left half ring - 0559)"},
/* 0315 */ { "COMBINING COMMA ABOVE RIGHT","	x (modifier letter apostrophe - 02BC)"},
/* 0316 */ { "COMBINING GRAVE ACCENT BELOW",NULL},
/* 0317 */ { "COMBINING ACUTE ACCENT BELOW",NULL},
/* 0318 */ { "COMBINING LEFT TACK BELOW","	x (combining left tack above - 1AE0)\n"
	"	x (modifier letter left tack - AB6A)"},
/* 0319 */ { "COMBINING RIGHT TACK BELOW","	x (combining right tack above - 1AE1)\n"
	"	x (modifier letter right tack - AB6B)"},
/* 031A */ { "COMBINING LEFT ANGLE ABOVE","	* IPA: unreleased stop"},
/* 031B */ { "COMBINING HORN","	* Vietnamese"},
/* 031C */ { "COMBINING LEFT HALF RING BELOW","	* IPA: open variety of vowel\n"
	"	x (modifier letter down tack - 02D5)"},
/* 031D */ { "COMBINING UP TACK BELOW","	* IPA: vowel raising or closing\n"
	"	x (modifier letter up tack - 02D4)\n"
	"	x (combining up tack above - 1DF5)"},
/* 031E */ { "COMBINING DOWN TACK BELOW","	* IPA: vowel lowering or opening\n"
	"	x (modifier letter down tack - 02D5)\n"
	"	x (combining down tack above - 1ADB)"},
/* 031F */ { "COMBINING PLUS SIGN BELOW","	* IPA: advanced or fronted articulation\n"
	"	x (modifier letter plus sign - 02D6)\n"
	"	x (combining plus sign above - 1AC8)"},
/* 0320 */ { "COMBINING MINUS SIGN BELOW","	* IPA: retracted or backed articulation\n"
	"	* glyph may have small end-serifs\n"
	"	x (modifier letter minus sign - 02D7)\n"
	"	x (combining minus sign above - 1AE2)"},
/* 0321 */ { "COMBINING PALATALIZED HOOK BELOW","	* IPA: palatalization\n"
	"	x (modifier letter small j - 02B2)"},
/* 0322 */ { "COMBINING RETROFLEX HOOK BELOW","	* IPA: retroflexion"},
/* 0323 */ { "COMBINING DOT BELOW","	= nang\n"
	"	* IPA: closer variety of vowel\n"
	"	* Americanist and Indo-Europeanist: retraction or retroflexion\n"
	"	* Semiticist: velarization or pharyngealization\n"
	"	* Vietnamese tone mark\n"
	"	x (modifier letter up tack - 02D4)"},
/* 0324 */ { "COMBINING DIAERESIS BELOW","	* IPA: breathy-voice or murmur\n"
	"	x (modifier letter small h with hook - 02B1)"},
/* 0325 */ { "COMBINING RING BELOW","	* IPA: voiceless\n"
	"	* vocalic (in Latin transliteration of Indic sonorants)\n"
	"	* Madurese\n"
	"	x (modifier letter low ring - 02F3)"},
/* 0326 */ { "COMBINING COMMA BELOW","	* Romanian, Latvian, Livonian"},
/* 0327 */ { "COMBINING CEDILLA","	* French, Turkish, Azerbaijani\n"
	"	x (cedilla - 00B8)"},
/* 0328 */ { "COMBINING OGONEK","	= nasal hook\n"
	"	* Americanist: nasalization\n"
	"	* Polish, Lithuanian\n"
	"	x (ogonek - 02DB)\n"
	"	x (combining open mark below - 1AB7)"},
/* 0329 */ { "COMBINING VERTICAL LINE BELOW","	* IPA: syllabic\n"
	"	* Yoruba\n"
	"	* German dialectology\n"
	"	* may attach or not; shape may vary by local preferences\n"
	"	x (modifier letter low vertical line - 02CC)"},
/* 032A */ { "COMBINING BRIDGE BELOW","	* IPA: dental"},
/* 032B */ { "COMBINING INVERTED DOUBLE ARCH BELOW","	= omega below\n"
	"	* IPA: labialization\n"
	"	x (modifier letter small w - 02B7)\n"
	"	x (combining inverted double arch above - 1AC7)"},
/* 032C */ { "COMBINING CARON BELOW","	* IPA: voiced"},
/* 032D */ { "COMBINING CIRCUMFLEX ACCENT BELOW","	* Americanist: fronted articulation"},
/* 032E */ { "COMBINING BREVE BELOW","	* Hittite transcription"},
/* 032F */ { "COMBINING INVERTED BREVE BELOW","	* Americanist: fronted articulation (variant of 032D)\n"
	"	* Indo-Europeanist: semivowel"},
/* 0330 */ { "COMBINING TILDE BELOW","	* IPA: creaky voice"},
/* 0331 */ { "COMBINING MACRON BELOW","	x (low line - 005F)\n"
	"	x (modifier letter low macron - 02CD)"},
/* 0332 */ { "COMBINING LOW LINE","	= underline, underscore\n"
	"	* connects on left and right\n"
	"	x (low line - 005F)"},
/* 0333 */ { "COMBINING DOUBLE LOW LINE","	= double underline, double underscore\n"
	"	* connects on left and right\n"
	"	x (combining equals sign below - 0347)\n"
	"	x (double low line - 2017)"},
/* 0334 */ { "COMBINING TILDE OVERLAY","	* IPA: velarization or pharyngealization"},
/* 0335 */ { "COMBINING SHORT STROKE OVERLAY",NULL},
/* 0336 */ { "COMBINING LONG STROKE OVERLAY","	= strikethrough\n"
	"	* connects on left and right"},
/* 0337 */ { "COMBINING SHORT SOLIDUS OVERLAY","	= short slash overlay"},
/* 0338 */ { "COMBINING LONG SOLIDUS OVERLAY","	= long slash overlay"},
/* 0339 */ { "COMBINING RIGHT HALF RING BELOW",NULL},
/* 033A */ { "COMBINING INVERTED BRIDGE BELOW","	* IPA: apical\n"
	"	x (combining inverted bridge above - 1AE3)\n"
	"	x (combining wide inverted bridge below - 1DF9)"},
/* 033B */ { "COMBINING SQUARE BELOW","	* IPA: laminal\n"
	"	* preferred glyph shape is a horizontal rectangle for IPA usage\n"
	"	x (combining square above - 1AE4)"},
/* 033C */ { "COMBINING SEAGULL BELOW","	* IPA: linguolabial\n"
	"	x (combining seagull above - 1AE5)"},
/* 033D */ { "COMBINING X ABOVE",NULL},
/* 033E */ { "COMBINING VERTICAL TILDE","	= yerik\n"
	"	* used for Cyrillic yerik, indicates an omitted jer\n"
	"	* this is not a palatalization mark\n"
	"	x (combining cyrillic palatalization - 0484)\n"
	"	x (vertical tilde - 2E2F)\n"
	"	x (combining cyrillic payerok - A67D)"},
/* 033F */ { "COMBINING DOUBLE OVERLINE","	* connects on left and right"},
/* 0340 */ { "COMBINING GRAVE TONE MARK","	: 0300 combining grave accent"},
/* 0341 */ { "COMBINING ACUTE TONE MARK","	: 0301 combining acute accent"},
/* 0342 */ { "COMBINING GREEK PERISPOMENI","	* Greek-specific form of circumflex for rising-falling accent\n"
	"	* alternative glyphs may be similar to an inverted breve, a circumflex, a tilde, or occasionally a macron\n"
	"	x (combining tilde - 0303)\n"
	"	x (combining inverted breve - 0311)"},
/* 0343 */ { "COMBINING GREEK KORONIS","	: 0313 combining comma above"},
/* 0344 */ { "COMBINING GREEK DIALYTIKA TONOS","	* use of this character is discouraged\n"
	"	: 0308 0301"},
/* 0345 */ { "COMBINING GREEK YPOGEGRAMMENI","	= greek non-spacing iota below (1.0)\n"
	"	= iota subscript\n"
	"	* note special casing issues\n"
	"	x (greek ypogegrammeni - 037A)\n"
	"	x (greek capital letter iota - 0399)"},
/* 0346 */ { "COMBINING BRIDGE ABOVE","	* ExtIPA: dentolabial\n"
	"	x (combining wide bridge above - 20E9)"},
/* 0347 */ { "COMBINING EQUALS SIGN BELOW","	* IPA: alveolar\n"
	"	x (combining equals sign above - 1AE8)"},
/* 0348 */ { "COMBINING DOUBLE VERTICAL LINE BELOW","	* IPA: strong articulation"},
/* 0349 */ { "COMBINING LEFT ANGLE BELOW","	* IPA: weak articulation\n"
	"	x (combining left angle centred above - 1AE9)"},
/* 034A */ { "COMBINING NOT TILDE ABOVE","	* IPA: denasal"},
/* 034B */ { "COMBINING HOMOTHETIC ABOVE","	* IPA: nasal escape"},
/* 034C */ { "COMBINING ALMOST EQUAL TO ABOVE","	* IPA: velopharyngeal friction"},
/* 034D */ { "COMBINING LEFT RIGHT ARROW BELOW","	* IPA: labial spreading\n"
	"	x (combining left right arrow above - 20E1)"},
/* 034E */ { "COMBINING UPWARDS ARROW BELOW","	* IPA: whistled articulation\n"
	"	x (combining upwards arrow above - 1AEA)"},
/* 034F */ { "COMBINING GRAPHEME JOINER","	* commonly abbreviated as CGJ\n"
	"	* has no visible glyph"},
/* 0350 */ { "COMBINING RIGHT ARROWHEAD ABOVE",NULL},
/* 0351 */ { "COMBINING LEFT HALF RING ABOVE",NULL},
/* 0352 */ { "COMBINING FERMATA",NULL},
/* 0353 */ { "COMBINING X BELOW",NULL},
/* 0354 */ { "COMBINING LEFT ARROWHEAD BELOW","	x (combining left arrowhead above - 1DFE)"},
/* 0355 */ { "COMBINING RIGHT ARROWHEAD BELOW",NULL},
/* 0356 */ { "COMBINING RIGHT ARROWHEAD AND UP ARROWHEAD BELOW",NULL},
/* 0357 */ { "COMBINING RIGHT HALF RING ABOVE",NULL},
/* 0358 */ { "COMBINING DOT ABOVE RIGHT","	* Latin transliterations of the Southern Min dialects of Chinese\n"
	"	x (combining dot above left - 1DF8)"},
/* 0359 */ { "COMBINING ASTERISK BELOW","	x (low asterisk - 204E)"},
/* 035A */ { "COMBINING DOUBLE RING BELOW","	* Kharoshthi transliteration"},
/* 035B */ { "COMBINING ZIGZAG ABOVE","	* Latin abbreviation, Lithuanian phonetics and medievalist transcriptions"},
/* 035C */ { "COMBINING DOUBLE BREVE BELOW","	= ligature tie below, papyrological hyphen\n"
	"	* a common glyph alternate connects the horizontal midpoints of the characters\n"
	"	x (combining double breve - 035D)\n"
	"	x (combining double inverted breve - 0361)\n"
	"	x (combining ligature left half below - FE27)"},
/* 035D */ { "COMBINING DOUBLE BREVE",NULL},
/* 035E */ { "COMBINING DOUBLE MACRON",NULL},
/* 035F */ { "COMBINING DOUBLE MACRON BELOW",NULL},
/* 0360 */ { "COMBINING DOUBLE TILDE","	x (combining double tilde left half - FE22)"},
/* 0361 */ { "COMBINING DOUBLE INVERTED BREVE","	= ligature tie\n"
	"	x (combining ligature left half - FE20)"},
/* 0362 */ { "COMBINING DOUBLE RIGHTWARDS ARROW BELOW","	* IPA: sliding articulation\n"
	"	x (combining double rightwards arrow above - 1AEB)"},
/* 0363 */ { "COMBINING LATIN SMALL LETTER A",NULL},
/* 0364 */ { "COMBINING LATIN SMALL LETTER E",NULL},
/* 0365 */ { "COMBINING LATIN SMALL LETTER I",NULL},
/* 0366 */ { "COMBINING LATIN SMALL LETTER O",NULL},
/* 0367 */ { "COMBINING LATIN SMALL LETTER U",NULL},
/* 0368 */ { "COMBINING LATIN SMALL LETTER C",NULL},
/* 0369 */ { "COMBINING LATIN SMALL LETTER D",NULL},
/* 036A */ { "COMBINING LATIN SMALL LETTER H",NULL},
/* 036B */ { "COMBINING LATIN SMALL LETTER M",NULL},
/* 036C */ { "COMBINING LATIN SMALL LETTER R",NULL},
/* 036D */ { "COMBINING LATIN SMALL LETTER T",NULL},
/* 036E */ { "COMBINING LATIN SMALL LETTER V",NULL},
/* 036F */ { "COMBINING LATIN SMALL LETTER X",NULL},
/* 0370 */ { "GREEK CAPITAL LETTER HETA","	x (latin capital letter half h - 2C75)"},
/* 0371 */ { "GREEK SMALL LETTER HETA","	x (latin small letter half h - 2C76)"},
/* 0372 */ { "GREEK CAPITAL LETTER ARCHAIC SAMPI",NULL},
/* 0373 */ { "GREEK SMALL LETTER ARCHAIC SAMPI",NULL},
/* 0374 */ { "GREEK NUMERAL SIGN","	= dexia keraia\n"
	"	* indicates numeric use of letters\n"
	"	x (modifier letter acute accent - 02CA)\n"
	"	: 02B9 modifier letter prime"},
/* 0375 */ { "GREEK LOWER NUMERAL SIGN","	= aristeri keraia\n"
	"	* indicates numeric use of letters\n"
	"	x (modifier letter low acute accent - 02CF)"},
/* 0376 */ { "GREEK CAPITAL LETTER PAMPHYLIAN DIGAMMA",NULL},
/* 0377 */ { "GREEK SMALL LETTER PAMPHYLIAN DIGAMMA",NULL},
/* 0378 */ { NULL,NULL},
/* 0379 */ { NULL,NULL},
/* 037A */ { "GREEK YPOGEGRAMMENI","	= iota subscript\n"
	"	x (combining greek ypogegrammeni - 0345)\n"
	"	# 0020 0345"},
/* 037B */ { "GREEK SMALL REVERSED LUNATE SIGMA SYMBOL",NULL},
/* 037C */ { "GREEK SMALL DOTTED LUNATE SIGMA SYMBOL",NULL},
/* 037D */ { "GREEK SMALL REVERSED DOTTED LUNATE SIGMA SYMBOL",NULL},
/* 037E */ { "GREEK QUESTION MARK","	= erotimatiko\n"
	"	* sentence-final punctuation\n"
	"	* 003B is the preferred character\n"
	"	x (question mark - 003F)\n"
	"	: 003B semicolon"},
/* 037F */ { "GREEK CAPITAL LETTER YOT","	* lowercase is 03F3"},
/* 0380 */ { NULL,NULL},
/* 0381 */ { NULL,NULL},
/* 0382 */ { NULL,NULL},
/* 0383 */ { NULL,NULL},
/* 0384 */ { "GREEK TONOS","	x (acute accent - 00B4)\n"
	"	x (combining vertical line above - 030D)\n"
	"	# 0020 0301"},
/* 0385 */ { "GREEK DIALYTIKA TONOS","	* compatibility decomposition (NFKD) is 0020 0308 0301\n"
	"	: 00A8 0301"},
/* 0386 */ { "GREEK CAPITAL LETTER ALPHA WITH TONOS","	: 0391 0301"},
/* 0387 */ { "GREEK ANO TELEIA","	* functions in Greek like a semicolon\n"
	"	* 00B7 is the preferred character\n"
	"	: 00B7 middle dot"},
/* 0388 */ { "GREEK CAPITAL LETTER EPSILON WITH TONOS","	: 0395 0301"},
/* 0389 */ { "GREEK CAPITAL LETTER ETA WITH TONOS","	: 0397 0301"},
/* 038A */ { "GREEK CAPITAL LETTER IOTA WITH TONOS","	: 0399 0301"},
/* 038B */ { NULL,NULL},
/* 038C */ { "GREEK CAPITAL LETTER OMICRON WITH TONOS","	: 039F 0301"},
/* 038D */ { NULL,NULL},
/* 038E */ { "GREEK CAPITAL LETTER UPSILON WITH TONOS","	: 03A5 0301"},
/* 038F */ { "GREEK CAPITAL LETTER OMEGA WITH TONOS","	: 03A9 0301"},
/* 0390 */ { "GREEK SMALL LETTER IOTA WITH DIALYTIKA AND TONOS","	: 03CA 0301"},
/* 0391 */ { "GREEK CAPITAL LETTER ALPHA",NULL},
/* 0392 */ { "GREEK CAPITAL LETTER BETA",NULL},
/* 0393 */ { "GREEK CAPITAL LETTER GAMMA","	= gamma function\n"
	"	x (double-struck capital gamma - 213E)"},
/* 0394 */ { "GREEK CAPITAL LETTER DELTA","	x (increment - 2206)"},
/* 0395 */ { "GREEK CAPITAL LETTER EPSILON",NULL},
/* 0396 */ { "GREEK CAPITAL LETTER ZETA",NULL},
/* 0397 */ { "GREEK CAPITAL LETTER ETA",NULL},
/* 0398 */ { "GREEK CAPITAL LETTER THETA",NULL},
/* 0399 */ { "GREEK CAPITAL LETTER IOTA","	= iota adscript"},
/* 039A */ { "GREEK CAPITAL LETTER KAPPA",NULL},
/* 039B */ { "GREEK CAPITAL LETTER LAMDA",NULL},
/* 039C */ { "GREEK CAPITAL LETTER MU",NULL},
/* 039D */ { "GREEK CAPITAL LETTER NU",NULL},
/* 039E */ { "GREEK CAPITAL LETTER XI",NULL},
/* 039F */ { "GREEK CAPITAL LETTER OMICRON",NULL},
/* 03A0 */ { "GREEK CAPITAL LETTER PI","	x (double-struck capital pi - 213F)\n"
	"	x (n-ary product - 220F)"},
/* 03A1 */ { "GREEK CAPITAL LETTER RHO",NULL},
/* 03A2 */ { NULL,NULL},
/* 03A3 */ { "GREEK CAPITAL LETTER SIGMA","	x (latin capital letter esh - 01A9)\n"
	"	x (n-ary summation - 2211)"},
/* 03A4 */ { "GREEK CAPITAL LETTER TAU",NULL},
/* 03A5 */ { "GREEK CAPITAL LETTER UPSILON",NULL},
/* 03A6 */ { "GREEK CAPITAL LETTER PHI",NULL},
/* 03A7 */ { "GREEK CAPITAL LETTER CHI",NULL},
/* 03A8 */ { "GREEK CAPITAL LETTER PSI",NULL},
/* 03A9 */ { "GREEK CAPITAL LETTER OMEGA","	x (ohm sign - 2126)\n"
	"	x (inverted ohm sign - 2127)"},
/* 03AA */ { "GREEK CAPITAL LETTER IOTA WITH DIALYTIKA","	: 0399 0308"},
/* 03AB */ { "GREEK CAPITAL LETTER UPSILON WITH DIALYTIKA","	: 03A5 0308"},
/* 03AC */ { "GREEK SMALL LETTER ALPHA WITH TONOS","	: 03B1 0301"},
/* 03AD */ { "GREEK SMALL LETTER EPSILON WITH TONOS","	: 03B5 0301"},
/* 03AE */ { "GREEK SMALL LETTER ETA WITH TONOS","	: 03B7 0301"},
/* 03AF */ { "GREEK SMALL LETTER IOTA WITH TONOS","	: 03B9 0301"},
/* 03B0 */ { "GREEK SMALL LETTER UPSILON WITH DIALYTIKA AND TONOS","	: 03CB 0301"},
/* 03B1 */ { "GREEK SMALL LETTER ALPHA","	x (latin small letter alpha - 0251)\n"
	"	x (proportional to - 221D)"},
/* 03B2 */ { "GREEK SMALL LETTER BETA","	x (latin small letter sharp s - 00DF)\n"
	"	x (latin small letter b with stroke - 0180)\n"
	"	x (latin small letter beta - A7B5)"},
/* 03B3 */ { "GREEK SMALL LETTER GAMMA","	x (latin small letter gamma - 0263)\n"
	"	x (double-struck small gamma - 213D)"},
/* 03B4 */ { "GREEK SMALL LETTER DELTA",NULL},
/* 03B5 */ { "GREEK SMALL LETTER EPSILON","	x (latin small letter open e - 025B)"},
/* 03B6 */ { "GREEK SMALL LETTER ZETA",NULL},
/* 03B7 */ { "GREEK SMALL LETTER ETA",NULL},
/* 03B8 */ { "GREEK SMALL LETTER THETA","	x (latin small letter barred o - 0275)\n"
	"	x (cyrillic small letter fita - 0473)"},
/* 03B9 */ { "GREEK SMALL LETTER IOTA","	x (latin small letter iota - 0269)\n"
	"	x (turned greek small letter iota - 2129)"},
/* 03BA */ { "GREEK SMALL LETTER KAPPA",NULL},
/* 03BB */ { "GREEK SMALL LETTER LAMDA","	= lambda\n"
	"	x (latin small letter lambda - A7DB)"},
/* 03BC */ { "GREEK SMALL LETTER MU","	x (micro sign - 00B5)"},
/* 03BD */ { "GREEK SMALL LETTER NU",NULL},
/* 03BE */ { "GREEK SMALL LETTER XI",NULL},
/* 03BF */ { "GREEK SMALL LETTER OMICRON",NULL},
/* 03C0 */ { "GREEK SMALL LETTER PI","	* math constant 3.141592..."},
/* 03C1 */ { "GREEK SMALL LETTER RHO",NULL},
/* 03C2 */ { "GREEK SMALL LETTER FINAL SIGMA","	= stigma (the Modern Greek name for this letterform)\n"
	"	* not to be confused with the actual stigma letter\n"
	"	x (greek small letter stigma - 03DB)"},
/* 03C3 */ { "GREEK SMALL LETTER SIGMA","	* used symbolically with a numeric value 200"},
/* 03C4 */ { "GREEK SMALL LETTER TAU",NULL},
/* 03C5 */ { "GREEK SMALL LETTER UPSILON","	x (latin small letter upsilon - 028A)\n"
	"	x (latin small letter v with hook - 028B)"},
/* 03C6 */ { "GREEK SMALL LETTER PHI","	* the ordinary Greek letter, showing considerable glyph variation\n"
	"	* in mathematical contexts, the loopy glyph is preferred, to contrast with 03D5\n"
	"	x (latin small letter phi - 0278)\n"
	"	x (greek phi symbol - 03D5)"},
/* 03C7 */ { "GREEK SMALL LETTER CHI","	x (latin small letter chi - AB53)"},
/* 03C8 */ { "GREEK SMALL LETTER PSI",NULL},
/* 03C9 */ { "GREEK SMALL LETTER OMEGA","	x (latin small letter omega - A7B7)"},
/* 03CA */ { "GREEK SMALL LETTER IOTA WITH DIALYTIKA","	: 03B9 0308"},
/* 03CB */ { "GREEK SMALL LETTER UPSILON WITH DIALYTIKA","	: 03C5 0308"},
/* 03CC */ { "GREEK SMALL LETTER OMICRON WITH TONOS","	: 03BF 0301"},
/* 03CD */ { "GREEK SMALL LETTER UPSILON WITH TONOS","	: 03C5 0301"},
/* 03CE */ { "GREEK SMALL LETTER OMEGA WITH TONOS","	: 03C9 0301"},
/* 03CF */ { "GREEK CAPITAL KAI SYMBOL","	x (greek kai symbol - 03D7)"},
/* 03D0 */ { "GREEK BETA SYMBOL","	= curled beta\n"
	"	# 03B2 greek small letter beta"},
/* 03D1 */ { "GREEK THETA SYMBOL","	= script theta\n"
	"	* used as a technical symbol\n"
	"	# 03B8 greek small letter theta"},
/* 03D2 */ { "GREEK UPSILON WITH HOOK SYMBOL","	# 03A5 greek capital letter upsilon"},
/* 03D3 */ { "GREEK UPSILON WITH ACUTE AND HOOK SYMBOL","	: 03D2 0301"},
/* 03D4 */ { "GREEK UPSILON WITH DIAERESIS AND HOOK SYMBOL","	: 03D2 0308"},
/* 03D5 */ { "GREEK PHI SYMBOL","	* used as a technical symbol, with a stroked glyph\n"
	"	* maps to \"phi1\" symbol entities\n"
	"	# 03C6 greek small letter phi"},
/* 03D6 */ { "GREEK PI SYMBOL","	= omega pi\n"
	"	* used as a technical symbol\n"
	"	* a variant of pi, looking like omega\n"
	"	# 03C0 greek small letter pi"},
/* 03D7 */ { "GREEK KAI SYMBOL","	* used as an ampersand\n"
	"	x (coptic symbol kai - 2CE4)"},
/* 03D8 */ { "GREEK LETTER ARCHAIC KOPPA",NULL},
/* 03D9 */ { "GREEK SMALL LETTER ARCHAIC KOPPA","	* the Q-shaped archaic koppas are the ordinary alphabetic letters and can also be used as symbols with a numeric value of 90 in classical and pre-classical texts"},
/* 03DA */ { "GREEK LETTER STIGMA","	* apparently in origin a cursive form of digamma\n"
	"	* the name \"stigma\" originally applied to a medieval sigma-tau ligature, whose shape was confusably similar to the cursive digamma\n"
	"	* used as a symbol with a numeric value of 6\n"
	"	x (roman numeral six late form - 2185)"},
/* 03DB */ { "GREEK SMALL LETTER STIGMA","	x (greek small letter final sigma - 03C2)"},
/* 03DC */ { "GREEK LETTER DIGAMMA",NULL},
/* 03DD */ { "GREEK SMALL LETTER DIGAMMA","	* used as a symbol with a numeric value of 6"},
/* 03DE */ { "GREEK LETTER KOPPA",NULL},
/* 03DF */ { "GREEK SMALL LETTER KOPPA","	* used in modern Greek as a symbol with a numeric value of 90, as in the dating of legal documentation"},
/* 03E0 */ { "GREEK LETTER SAMPI",NULL},
/* 03E1 */ { "GREEK SMALL LETTER SAMPI","	* used as a symbol with a numeric value of 900"},
/* 03E2 */ { "COPTIC CAPITAL LETTER SHEI",NULL},
/* 03E3 */ { "COPTIC SMALL LETTER SHEI",NULL},
/* 03E4 */ { "COPTIC CAPITAL LETTER FEI",NULL},
/* 03E5 */ { "COPTIC SMALL LETTER FEI",NULL},
/* 03E6 */ { "COPTIC CAPITAL LETTER KHEI",NULL},
/* 03E7 */ { "COPTIC SMALL LETTER KHEI",NULL},
/* 03E8 */ { "COPTIC CAPITAL LETTER HORI",NULL},
/* 03E9 */ { "COPTIC SMALL LETTER HORI",NULL},
/* 03EA */ { "COPTIC CAPITAL LETTER GANGIA",NULL},
/* 03EB */ { "COPTIC SMALL LETTER GANGIA",NULL},
/* 03EC */ { "COPTIC CAPITAL LETTER SHIMA",NULL},
/* 03ED */ { "COPTIC SMALL LETTER SHIMA",NULL},
/* 03EE */ { "COPTIC CAPITAL LETTER DEI",NULL},
/* 03EF */ { "COPTIC SMALL LETTER DEI",NULL},
/* 03F0 */ { "GREEK KAPPA SYMBOL","	= script kappa\n"
	"	* used as technical symbol\n"
	"	# 03BA greek small letter kappa"},
/* 03F1 */ { "GREEK RHO SYMBOL","	= tailed rho\n"
	"	* used as technical symbol\n"
	"	# 03C1 greek small letter rho"},
/* 03F2 */ { "GREEK LUNATE SIGMA SYMBOL","	= greek small letter lunate sigma (1.0)\n"
	"	# 03C2 greek small letter final sigma"},
/* 03F3 */ { "GREEK LETTER YOT","	* uppercase is 037F"},
/* 03F4 */ { "GREEK CAPITAL THETA SYMBOL","	x (cyrillic capital letter fita - 0472)\n"
	"	# 0398 greek capital letter theta"},
/* 03F5 */ { "GREEK LUNATE EPSILON SYMBOL","	= straight epsilon\n"
	"	x (small element of - 220A)\n"
	"	# 03B5 greek small letter epsilon"},
/* 03F6 */ { "GREEK REVERSED LUNATE EPSILON SYMBOL","	= reversed straight epsilon\n"
	"	x (small contains as member - 220D)"},
/* 03F7 */ { "GREEK CAPITAL LETTER SHO",NULL},
/* 03F8 */ { "GREEK SMALL LETTER SHO",NULL},
/* 03F9 */ { "GREEK CAPITAL LUNATE SIGMA SYMBOL","	# 03A3 greek capital letter sigma"},
/* 03FA */ { "GREEK CAPITAL LETTER SAN",NULL},
/* 03FB */ { "GREEK SMALL LETTER SAN",NULL},
/* 03FC */ { "GREEK RHO WITH STROKE SYMBOL","	* used with abbreviations containing 03C1"},
/* 03FD */ { "GREEK CAPITAL REVERSED LUNATE SIGMA SYMBOL","	= antisigma"},
/* 03FE */ { "GREEK CAPITAL DOTTED LUNATE SIGMA SYMBOL","	= sigma periestigmenon"},
/* 03FF */ { "GREEK CAPITAL REVERSED DOTTED LUNATE SIGMA SYMBOL","	= antisigma periestigmenon"}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_00_04[] = {
/* 0400 */ { "CYRILLIC CAPITAL LETTER IE WITH GRAVE","	: 0415 0300"},
/* 0401 */ { "CYRILLIC CAPITAL LETTER IO","	: 0415 0308"},
/* 0402 */ { "CYRILLIC CAPITAL LETTER DJE",NULL},
/* 0403 */ { "CYRILLIC CAPITAL LETTER GJE","	: 0413 0301"},
/* 0404 */ { "CYRILLIC CAPITAL LETTER UKRAINIAN IE",NULL},
/* 0405 */ { "CYRILLIC CAPITAL LETTER DZE",NULL},
/* 0406 */ { "CYRILLIC CAPITAL LETTER BYELORUSSIAN-UKRAINIAN I","	x (latin capital letter i - 0049)\n"
	"	x (cyrillic small letter byelorussian-ukrainian i - 0456)\n"
	"	x (cyrillic letter palochka - 04C0)"},
/* 0407 */ { "CYRILLIC CAPITAL LETTER YI","	: 0406 0308"},
/* 0408 */ { "CYRILLIC CAPITAL LETTER JE",NULL},
/* 0409 */ { "CYRILLIC CAPITAL LETTER LJE",NULL},
/* 040A */ { "CYRILLIC CAPITAL LETTER NJE",NULL},
/* 040B */ { "CYRILLIC CAPITAL LETTER TSHE",NULL},
/* 040C */ { "CYRILLIC CAPITAL LETTER KJE","	: 041A 0301"},
/* 040D */ { "CYRILLIC CAPITAL LETTER I WITH GRAVE","	: 0418 0300"},
/* 040E */ { "CYRILLIC CAPITAL LETTER SHORT U","	: 0423 0306"},
/* 040F */ { "CYRILLIC CAPITAL LETTER DZHE",NULL},
/* 0410 */ { "CYRILLIC CAPITAL LETTER A",NULL},
/* 0411 */ { "CYRILLIC CAPITAL LETTER BE","	x (latin small letter b with topbar - 0183)"},
/* 0412 */ { "CYRILLIC CAPITAL LETTER VE",NULL},
/* 0413 */ { "CYRILLIC CAPITAL LETTER GHE",NULL},
/* 0414 */ { "CYRILLIC CAPITAL LETTER DE",NULL},
/* 0415 */ { "CYRILLIC CAPITAL LETTER IE",NULL},
/* 0416 */ { "CYRILLIC CAPITAL LETTER ZHE",NULL},
/* 0417 */ { "CYRILLIC CAPITAL LETTER ZE",NULL},
/* 0418 */ { "CYRILLIC CAPITAL LETTER I","		This letter is also used to represent electrolarynx phonation in the Voice Quality Symbols for extended IPA."},
/* 0419 */ { "CYRILLIC CAPITAL LETTER SHORT I","	: 0418 0306"},
/* 041A */ { "CYRILLIC CAPITAL LETTER KA",NULL},
/* 041B */ { "CYRILLIC CAPITAL LETTER EL",NULL},
/* 041C */ { "CYRILLIC CAPITAL LETTER EM",NULL},
/* 041D */ { "CYRILLIC CAPITAL LETTER EN",NULL},
/* 041E */ { "CYRILLIC CAPITAL LETTER O",NULL},
/* 041F */ { "CYRILLIC CAPITAL LETTER PE",NULL},
/* 0420 */ { "CYRILLIC CAPITAL LETTER ER",NULL},
/* 0421 */ { "CYRILLIC CAPITAL LETTER ES",NULL},
/* 0422 */ { "CYRILLIC CAPITAL LETTER TE",NULL},
/* 0423 */ { "CYRILLIC CAPITAL LETTER U","	x (cyrillic capital letter uk - 0478)\n"
	"	x (cyrillic small letter straight u - 04AF)\n"
	"	x (cyrillic capital letter monograph uk - A64A)"},
/* 0424 */ { "CYRILLIC CAPITAL LETTER EF",NULL},
/* 0425 */ { "CYRILLIC CAPITAL LETTER HA",NULL},
/* 0426 */ { "CYRILLIC CAPITAL LETTER TSE",NULL},
/* 0427 */ { "CYRILLIC CAPITAL LETTER CHE",NULL},
/* 0428 */ { "CYRILLIC CAPITAL LETTER SHA",NULL},
/* 0429 */ { "CYRILLIC CAPITAL LETTER SHCHA",NULL},
/* 042A */ { "CYRILLIC CAPITAL LETTER HARD SIGN",NULL},
/* 042B */ { "CYRILLIC CAPITAL LETTER YERU",NULL},
/* 042C */ { "CYRILLIC CAPITAL LETTER SOFT SIGN",NULL},
/* 042D */ { "CYRILLIC CAPITAL LETTER E",NULL},
/* 042E */ { "CYRILLIC CAPITAL LETTER YU",NULL},
/* 042F */ { "CYRILLIC CAPITAL LETTER YA",NULL},
/* 0430 */ { "CYRILLIC SMALL LETTER A",NULL},
/* 0431 */ { "CYRILLIC SMALL LETTER BE",NULL},
/* 0432 */ { "CYRILLIC SMALL LETTER VE",NULL},
/* 0433 */ { "CYRILLIC SMALL LETTER GHE",NULL},
/* 0434 */ { "CYRILLIC SMALL LETTER DE",NULL},
/* 0435 */ { "CYRILLIC SMALL LETTER IE",NULL},
/* 0436 */ { "CYRILLIC SMALL LETTER ZHE",NULL},
/* 0437 */ { "CYRILLIC SMALL LETTER ZE",NULL},
/* 0438 */ { "CYRILLIC SMALL LETTER I",NULL},
/* 0439 */ { "CYRILLIC SMALL LETTER SHORT I","	: 0438 0306"},
/* 043A */ { "CYRILLIC SMALL LETTER KA",NULL},
/* 043B */ { "CYRILLIC SMALL LETTER EL",NULL},
/* 043C */ { "CYRILLIC SMALL LETTER EM",NULL},
/* 043D */ { "CYRILLIC SMALL LETTER EN",NULL},
/* 043E */ { "CYRILLIC SMALL LETTER O",NULL},
/* 043F */ { "CYRILLIC SMALL LETTER PE",NULL},
/* 0440 */ { "CYRILLIC SMALL LETTER ER",NULL},
/* 0441 */ { "CYRILLIC SMALL LETTER ES",NULL},
/* 0442 */ { "CYRILLIC SMALL LETTER TE",NULL},
/* 0443 */ { "CYRILLIC SMALL LETTER U",NULL},
/* 0444 */ { "CYRILLIC SMALL LETTER EF",NULL},
/* 0445 */ { "CYRILLIC SMALL LETTER HA",NULL},
/* 0446 */ { "CYRILLIC SMALL LETTER TSE",NULL},
/* 0447 */ { "CYRILLIC SMALL LETTER CHE",NULL},
/* 0448 */ { "CYRILLIC SMALL LETTER SHA",NULL},
/* 0449 */ { "CYRILLIC SMALL LETTER SHCHA",NULL},
/* 044A */ { "CYRILLIC SMALL LETTER HARD SIGN",NULL},
/* 044B */ { "CYRILLIC SMALL LETTER YERU","	x (cyrillic small letter yeru with back yer - A651)"},
/* 044C */ { "CYRILLIC SMALL LETTER SOFT SIGN","	x (latin small letter tone six - 0185)\n"
	"	x (cyrillic small letter neutral yer - A64F)"},
/* 044D */ { "CYRILLIC SMALL LETTER E",NULL},
/* 044E */ { "CYRILLIC SMALL LETTER YU","	x (cyrillic small letter reversed yu - A655)"},
/* 044F */ { "CYRILLIC SMALL LETTER YA",NULL},
/* 0450 */ { "CYRILLIC SMALL LETTER IE WITH GRAVE","	* Macedonian\n"
	"	: 0435 0300"},
/* 0451 */ { "CYRILLIC SMALL LETTER IO","	* Russian, ...\n"
	"	: 0435 0308"},
/* 0452 */ { "CYRILLIC SMALL LETTER DJE","	* Serbian\n"
	"	x (latin small letter d with stroke - 0111)"},
/* 0453 */ { "CYRILLIC SMALL LETTER GJE","	* Macedonian\n"
	"	: 0433 0301"},
/* 0454 */ { "CYRILLIC SMALL LETTER UKRAINIAN IE","	= Old Cyrillic yest"},
/* 0455 */ { "CYRILLIC SMALL LETTER DZE","	* Macedonian\n"
	"	x (cyrillic small letter dzelo - A643)"},
/* 0456 */ { "CYRILLIC SMALL LETTER BYELORUSSIAN-UKRAINIAN I","	= Old Cyrillic i"},
/* 0457 */ { "CYRILLIC SMALL LETTER YI","	* Ukrainian\n"
	"	: 0456 0308"},
/* 0458 */ { "CYRILLIC SMALL LETTER JE","	* Serbian, Azerbaijani, Altay"},
/* 0459 */ { "CYRILLIC SMALL LETTER LJE","	* Serbian, Macedonian\n"
	"	x (latin small letter lj - 01C9)"},
/* 045A */ { "CYRILLIC SMALL LETTER NJE","	* Serbian, Macedonian\n"
	"	x (latin small letter nj - 01CC)"},
/* 045B */ { "CYRILLIC SMALL LETTER TSHE","	* Serbian\n"
	"	x (latin small letter c with acute - 0107)\n"
	"	x (latin small letter h with stroke - 0127)\n"
	"	x (cyrillic capital letter tshe - 040B)\n"
	"	x (planck constant over two pi - 210F)\n"
	"	x (cyrillic small letter djerv - A649)"},
/* 045C */ { "CYRILLIC SMALL LETTER KJE","	* Macedonian\n"
	"	: 043A 0301"},
/* 045D */ { "CYRILLIC SMALL LETTER I WITH GRAVE","	* Macedonian, Bulgarian\n"
	"	: 0438 0300"},
/* 045E */ { "CYRILLIC SMALL LETTER SHORT U","	* Byelorussian, Uzbek\n"
	"	: 0443 0306"},
/* 045F */ { "CYRILLIC SMALL LETTER DZHE","	* Serbian, Macedonian, Abkhasian\n"
	"	x (latin small letter dz with caron - 01C6)"},
/* 0460 */ { "CYRILLIC CAPITAL LETTER OMEGA",NULL},
/* 0461 */ { "CYRILLIC SMALL LETTER OMEGA","	x (cyrillic small letter broad omega - A64D)"},
/* 0462 */ { "CYRILLIC CAPITAL LETTER YAT",NULL},
/* 0463 */ { "CYRILLIC SMALL LETTER YAT","	x (cyrillic small letter iotified yat - A653)\n"
	"	x (latin small letter sakha yat - AB60)"},
/* 0464 */ { "CYRILLIC CAPITAL LETTER IOTIFIED E",NULL},
/* 0465 */ { "CYRILLIC SMALL LETTER IOTIFIED E","	x (latin small letter iotified e - AB61)"},
/* 0466 */ { "CYRILLIC CAPITAL LETTER LITTLE YUS",NULL},
/* 0467 */ { "CYRILLIC SMALL LETTER LITTLE YUS","	x (cyrillic small letter closed little yus - A659)\n"
	"	x (cyrillic small letter blended yus - A65B)"},
/* 0468 */ { "CYRILLIC CAPITAL LETTER IOTIFIED LITTLE YUS",NULL},
/* 0469 */ { "CYRILLIC SMALL LETTER IOTIFIED LITTLE YUS","	x (cyrillic small letter ya - 044F)\n"
	"	x (cyrillic small letter iotified closed little yus - A65D)"},
/* 046A */ { "CYRILLIC CAPITAL LETTER BIG YUS",NULL},
/* 046B */ { "CYRILLIC SMALL LETTER BIG YUS","	x (cyrillic small letter blended yus - A65B)"},
/* 046C */ { "CYRILLIC CAPITAL LETTER IOTIFIED BIG YUS",NULL},
/* 046D */ { "CYRILLIC SMALL LETTER IOTIFIED BIG YUS",NULL},
/* 046E */ { "CYRILLIC CAPITAL LETTER KSI",NULL},
/* 046F */ { "CYRILLIC SMALL LETTER KSI",NULL},
/* 0470 */ { "CYRILLIC CAPITAL LETTER PSI",NULL},
/* 0471 */ { "CYRILLIC SMALL LETTER PSI",NULL},
/* 0472 */ { "CYRILLIC CAPITAL LETTER FITA",NULL},
/* 0473 */ { "CYRILLIC SMALL LETTER FITA","	x (latin small letter barred o - 0275)\n"
	"	x (greek small letter theta - 03B8)"},
/* 0474 */ { "CYRILLIC CAPITAL LETTER IZHITSA",NULL},
/* 0475 */ { "CYRILLIC SMALL LETTER IZHITSA",NULL},
/* 0476 */ { "CYRILLIC CAPITAL LETTER IZHITSA WITH DOUBLE GRAVE ACCENT","	: 0474 030F"},
/* 0477 */ { "CYRILLIC SMALL LETTER IZHITSA WITH DOUBLE GRAVE ACCENT","	: 0475 030F"},
/* 0478 */ { "CYRILLIC CAPITAL LETTER UK","	* for \"digraph onik\" the preferred spelling is 041E 0443\n"
	"	* for \"monograph uk\" the preferred character is A64A\n"
	"	x (cyrillic capital letter u - 0423)"},
/* 0479 */ { "CYRILLIC SMALL LETTER UK","	* for \"digraph onik\" the preferred spelling is 043E 0443\n"
	"	* for \"monograph uk\" the preferred character is A64B"},
/* 047A */ { "CYRILLIC CAPITAL LETTER ROUND OMEGA",NULL},
/* 047B */ { "CYRILLIC SMALL LETTER ROUND OMEGA",NULL},
/* 047C */ { "CYRILLIC CAPITAL LETTER OMEGA WITH TITLO","	= Cyrillic \"beautiful omega\"\n"
	"	* despite its name, this character does not have a titlo, nor is it composed of an omega plus a diacritic\n"
	"	x (cyrillic capital letter broad omega - A64C)"},
/* 047D */ { "CYRILLIC SMALL LETTER OMEGA WITH TITLO","	x (greek small letter omega with psili and perispomeni - 1F66)"},
/* 047E */ { "CYRILLIC CAPITAL LETTER OT",NULL},
/* 047F */ { "CYRILLIC SMALL LETTER OT",NULL},
/* 0480 */ { "CYRILLIC CAPITAL LETTER KOPPA",NULL},
/* 0481 */ { "CYRILLIC SMALL LETTER KOPPA",NULL},
/* 0482 */ { "CYRILLIC THOUSANDS SIGN",NULL},
/* 0483 */ { "COMBINING CYRILLIC TITLO","	* not used with titlo letters\n"
	"	x (combining cyrillic vzmet - A66F)"},
/* 0484 */ { "COMBINING CYRILLIC PALATALIZATION","	* not used for kamora\n"
	"	x (modifier letter apostrophe - 02BC)\n"
	"	x (combining inverted breve - 0311)"},
/* 0485 */ { "COMBINING CYRILLIC DASIA PNEUMATA","	x (combining reversed comma above - 0314)\n"
	"	x (combining right tack above - 1AE1)\n"
	"	x (coptic combining spiritus asper - 2CF0)"},
/* 0486 */ { "COMBINING CYRILLIC PSILI PNEUMATA","	x (combining comma above - 0313)\n"
	"	x (combining left tack above - 1AE0)\n"
	"	x (coptic combining spiritus lenis - 2CF1)"},
/* 0487 */ { "COMBINING CYRILLIC POKRYTIE","	* used only with titlo letters\n"
	"	* also attested in Glagolitic\n"
	"	x (combining inverted breve - 0311)\n"
	"	x (combining cyrillic vzmet - A66F)"},
/* 0488 */ { "COMBINING CYRILLIC HUNDRED THOUSANDS SIGN","	* use 20DD for ten thousands sign"},
/* 0489 */ { "COMBINING CYRILLIC MILLIONS SIGN","	x (combining cyrillic ten millions sign - A670)"},
/* 048A */ { "CYRILLIC CAPITAL LETTER SHORT I WITH TAIL",NULL},
/* 048B */ { "CYRILLIC SMALL LETTER SHORT I WITH TAIL","	* Kildin Sami"},
/* 048C */ { "CYRILLIC CAPITAL LETTER SEMISOFT SIGN",NULL},
/* 048D */ { "CYRILLIC SMALL LETTER SEMISOFT SIGN","	* Kildin Sami"},
/* 048E */ { "CYRILLIC CAPITAL LETTER ER WITH TICK",NULL},
/* 048F */ { "CYRILLIC SMALL LETTER ER WITH TICK","	* Kildin Sami"},
/* 0490 */ { "CYRILLIC CAPITAL LETTER GHE WITH UPTURN",NULL},
/* 0491 */ { "CYRILLIC SMALL LETTER GHE WITH UPTURN","	* Ukrainian"},
/* 0492 */ { "CYRILLIC CAPITAL LETTER GHE WITH STROKE",NULL},
/* 0493 */ { "CYRILLIC SMALL LETTER GHE WITH STROKE","	* Azerbaijani, Bashkir, ...\n"
	"	* full bar form preferred over half-barred \"F\"-type"},
/* 0494 */ { "CYRILLIC CAPITAL LETTER GHE WITH MIDDLE HOOK",NULL},
/* 0495 */ { "CYRILLIC SMALL LETTER GHE WITH MIDDLE HOOK","	* Yakut, older orthographies for Abkhasian"},
/* 0496 */ { "CYRILLIC CAPITAL LETTER ZHE WITH DESCENDER",NULL},
/* 0497 */ { "CYRILLIC SMALL LETTER ZHE WITH DESCENDER","	* Tatar, ..."},
/* 0498 */ { "CYRILLIC CAPITAL LETTER ZE WITH DESCENDER",NULL},
/* 0499 */ { "CYRILLIC SMALL LETTER ZE WITH DESCENDER","	* Bashkir\n"
	"	* letterforms with right hooks are preferred, although occasional variants with left hooks occur"},
/* 049A */ { "CYRILLIC CAPITAL LETTER KA WITH DESCENDER",NULL},
/* 049B */ { "CYRILLIC SMALL LETTER KA WITH DESCENDER","	* Abkhasian, Tajik, ..."},
/* 049C */ { "CYRILLIC CAPITAL LETTER KA WITH VERTICAL STROKE",NULL},
/* 049D */ { "CYRILLIC SMALL LETTER KA WITH VERTICAL STROKE","	* Azerbaijani"},
/* 049E */ { "CYRILLIC CAPITAL LETTER KA WITH STROKE",NULL},
/* 049F */ { "CYRILLIC SMALL LETTER KA WITH STROKE","	* Abkhasian"},
/* 04A0 */ { "CYRILLIC CAPITAL LETTER BASHKIR KA",NULL},
/* 04A1 */ { "CYRILLIC SMALL LETTER BASHKIR KA",NULL},
/* 04A2 */ { "CYRILLIC CAPITAL LETTER EN WITH DESCENDER",NULL},
/* 04A3 */ { "CYRILLIC SMALL LETTER EN WITH DESCENDER","	* Bashkir, ..."},
/* 04A4 */ { "CYRILLIC CAPITAL LIGATURE EN GHE",NULL},
/* 04A5 */ { "CYRILLIC SMALL LIGATURE EN GHE","	* Altay, Mari, Yakut\n"
	"	* also used for soft en in Old Church Slavonic\n"
	"	* this is not a decomposable ligature"},
/* 04A6 */ { "CYRILLIC CAPITAL LETTER PE WITH MIDDLE HOOK",NULL},
/* 04A7 */ { "CYRILLIC SMALL LETTER PE WITH MIDDLE HOOK","	* older orthographies for Abkhasian"},
/* 04A8 */ { "CYRILLIC CAPITAL LETTER ABKHASIAN HA",NULL},
/* 04A9 */ { "CYRILLIC SMALL LETTER ABKHASIAN HA",NULL},
/* 04AA */ { "CYRILLIC CAPITAL LETTER ES WITH DESCENDER",NULL},
/* 04AB */ { "CYRILLIC SMALL LETTER ES WITH DESCENDER","	* Bashkir, Chuvash\n"
	"	* letterforms with right hooks are preferred, although occasional variants with left hooks occur\n"
	"	* in Chuvashia, letterforms identical to or similar in form to 00E7 regularly occur"},
/* 04AC */ { "CYRILLIC CAPITAL LETTER TE WITH DESCENDER",NULL},
/* 04AD */ { "CYRILLIC SMALL LETTER TE WITH DESCENDER","	* Abkhasian"},
/* 04AE */ { "CYRILLIC CAPITAL LETTER STRAIGHT U",NULL},
/* 04AF */ { "CYRILLIC SMALL LETTER STRAIGHT U","	* stem is straight, unlike LETTER U\n"
	"	* Azerbaijani, Bashkir, ...\n"
	"	x (cyrillic capital letter u - 0423)"},
/* 04B0 */ { "CYRILLIC CAPITAL LETTER STRAIGHT U WITH STROKE",NULL},
/* 04B1 */ { "CYRILLIC SMALL LETTER STRAIGHT U WITH STROKE","	* Kazakh"},
/* 04B2 */ { "CYRILLIC CAPITAL LETTER HA WITH DESCENDER",NULL},
/* 04B3 */ { "CYRILLIC SMALL LETTER HA WITH DESCENDER","	* Abkhasian, Tajik, Uzbek"},
/* 04B4 */ { "CYRILLIC CAPITAL LIGATURE TE TSE",NULL},
/* 04B5 */ { "CYRILLIC SMALL LIGATURE TE TSE","	* Abkhasian\n"
	"	* this is not a decomposable ligature"},
/* 04B6 */ { "CYRILLIC CAPITAL LETTER CHE WITH DESCENDER",NULL},
/* 04B7 */ { "CYRILLIC SMALL LETTER CHE WITH DESCENDER","	* Abkhasian, Tajik"},
/* 04B8 */ { "CYRILLIC CAPITAL LETTER CHE WITH VERTICAL STROKE",NULL},
/* 04B9 */ { "CYRILLIC SMALL LETTER CHE WITH VERTICAL STROKE","	* Azerbaijani"},
/* 04BA */ { "CYRILLIC CAPITAL LETTER SHHA",NULL},
/* 04BB */ { "CYRILLIC SMALL LETTER SHHA","	* originally derived from Latin \"h\", but uppercase form 04BA is closer to an inverted che (0427)\n"
	"	* Azerbaijani, Bashkir, ...\n"
	"	x (latin small letter h - 0068)"},
/* 04BC */ { "CYRILLIC CAPITAL LETTER ABKHASIAN CHE",NULL},
/* 04BD */ { "CYRILLIC SMALL LETTER ABKHASIAN CHE",NULL},
/* 04BE */ { "CYRILLIC CAPITAL LETTER ABKHASIAN CHE WITH DESCENDER",NULL},
/* 04BF */ { "CYRILLIC SMALL LETTER ABKHASIAN CHE WITH DESCENDER","	* some older Abkhaz fonts show a descender shaped like a right hook (ogonek or reversed comma shape)"},
/* 04C0 */ { "CYRILLIC LETTER PALOCHKA","	* aspiration sign in many Caucasian languages\n"
	"	* is usually not cased, but the formal lowercase is 04CF\n"
	"	x (latin capital letter i - 0049)\n"
	"	x (cyrillic capital letter byelorussian-ukrainian i - 0406)"},
/* 04C1 */ { "CYRILLIC CAPITAL LETTER ZHE WITH BREVE","	: 0416 0306"},
/* 04C2 */ { "CYRILLIC SMALL LETTER ZHE WITH BREVE","	* Moldavian\n"
	"	: 0436 0306"},
/* 04C3 */ { "CYRILLIC CAPITAL LETTER KA WITH HOOK",NULL},
/* 04C4 */ { "CYRILLIC SMALL LETTER KA WITH HOOK","	* Chukchi"},
/* 04C5 */ { "CYRILLIC CAPITAL LETTER EL WITH TAIL",NULL},
/* 04C6 */ { "CYRILLIC SMALL LETTER EL WITH TAIL","	* Kildin Sami"},
/* 04C7 */ { "CYRILLIC CAPITAL LETTER EN WITH HOOK",NULL},
/* 04C8 */ { "CYRILLIC SMALL LETTER EN WITH HOOK","	* Chukchi"},
/* 04C9 */ { "CYRILLIC CAPITAL LETTER EN WITH TAIL",NULL},
/* 04CA */ { "CYRILLIC SMALL LETTER EN WITH TAIL","	* Kildin Sami"},
/* 04CB */ { "CYRILLIC CAPITAL LETTER KHAKASSIAN CHE",NULL},
/* 04CC */ { "CYRILLIC SMALL LETTER KHAKASSIAN CHE",NULL},
/* 04CD */ { "CYRILLIC CAPITAL LETTER EM WITH TAIL",NULL},
/* 04CE */ { "CYRILLIC SMALL LETTER EM WITH TAIL","	* Kildin Sami"},
/* 04CF */ { "CYRILLIC SMALL LETTER PALOCHKA",NULL},
/* 04D0 */ { "CYRILLIC CAPITAL LETTER A WITH BREVE","	: 0410 0306"},
/* 04D1 */ { "CYRILLIC SMALL LETTER A WITH BREVE","	: 0430 0306"},
/* 04D2 */ { "CYRILLIC CAPITAL LETTER A WITH DIAERESIS","	: 0410 0308"},
/* 04D3 */ { "CYRILLIC SMALL LETTER A WITH DIAERESIS","	: 0430 0308"},
/* 04D4 */ { "CYRILLIC CAPITAL LIGATURE A IE",NULL},
/* 04D5 */ { "CYRILLIC SMALL LIGATURE A IE","	* this is not a decomposable ligature\n"
	"	x (latin small letter ae - 00E6)"},
/* 04D6 */ { "CYRILLIC CAPITAL LETTER IE WITH BREVE","	: 0415 0306"},
/* 04D7 */ { "CYRILLIC SMALL LETTER IE WITH BREVE","	: 0435 0306"},
/* 04D8 */ { "CYRILLIC CAPITAL LETTER SCHWA",NULL},
/* 04D9 */ { "CYRILLIC SMALL LETTER SCHWA","	x (latin small letter schwa - 0259)"},
/* 04DA */ { "CYRILLIC CAPITAL LETTER SCHWA WITH DIAERESIS","	: 04D8 0308"},
/* 04DB */ { "CYRILLIC SMALL LETTER SCHWA WITH DIAERESIS","	: 04D9 0308"},
/* 04DC */ { "CYRILLIC CAPITAL LETTER ZHE WITH DIAERESIS","	: 0416 0308"},
/* 04DD */ { "CYRILLIC SMALL LETTER ZHE WITH DIAERESIS","	: 0436 0308"},
/* 04DE */ { "CYRILLIC CAPITAL LETTER ZE WITH DIAERESIS","	: 0417 0308"},
/* 04DF */ { "CYRILLIC SMALL LETTER ZE WITH DIAERESIS","	: 0437 0308"},
/* 04E0 */ { "CYRILLIC CAPITAL LETTER ABKHASIAN DZE",NULL},
/* 04E1 */ { "CYRILLIC SMALL LETTER ABKHASIAN DZE","	x (latin small letter ezh - 0292)"},
/* 04E2 */ { "CYRILLIC CAPITAL LETTER I WITH MACRON","	: 0418 0304"},
/* 04E3 */ { "CYRILLIC SMALL LETTER I WITH MACRON","	: 0438 0304"},
/* 04E4 */ { "CYRILLIC CAPITAL LETTER I WITH DIAERESIS","	: 0418 0308"},
/* 04E5 */ { "CYRILLIC SMALL LETTER I WITH DIAERESIS","	: 0438 0308"},
/* 04E6 */ { "CYRILLIC CAPITAL LETTER O WITH DIAERESIS","	: 041E 0308"},
/* 04E7 */ { "CYRILLIC SMALL LETTER O WITH DIAERESIS","	: 043E 0308"},
/* 04E8 */ { "CYRILLIC CAPITAL LETTER BARRED O",NULL},
/* 04E9 */ { "CYRILLIC SMALL LETTER BARRED O","	x (latin small letter barred o - 0275)"},
/* 04EA */ { "CYRILLIC CAPITAL LETTER BARRED O WITH DIAERESIS","	: 04E8 0308"},
/* 04EB */ { "CYRILLIC SMALL LETTER BARRED O WITH DIAERESIS","	: 04E9 0308"},
/* 04EC */ { "CYRILLIC CAPITAL LETTER E WITH DIAERESIS","	: 042D 0308"},
/* 04ED */ { "CYRILLIC SMALL LETTER E WITH DIAERESIS","	* Kildin Sami\n"
	"	: 044D 0308"},
/* 04EE */ { "CYRILLIC CAPITAL LETTER U WITH MACRON","	: 0423 0304"},
/* 04EF */ { "CYRILLIC SMALL LETTER U WITH MACRON","	: 0443 0304"},
/* 04F0 */ { "CYRILLIC CAPITAL LETTER U WITH DIAERESIS","	: 0423 0308"},
/* 04F1 */ { "CYRILLIC SMALL LETTER U WITH DIAERESIS","	: 0443 0308"},
/* 04F2 */ { "CYRILLIC CAPITAL LETTER U WITH DOUBLE ACUTE","	: 0423 030B"},
/* 04F3 */ { "CYRILLIC SMALL LETTER U WITH DOUBLE ACUTE","	: 0443 030B"},
/* 04F4 */ { "CYRILLIC CAPITAL LETTER CHE WITH DIAERESIS","	: 0427 0308"},
/* 04F5 */ { "CYRILLIC SMALL LETTER CHE WITH DIAERESIS","	: 0447 0308"},
/* 04F6 */ { "CYRILLIC CAPITAL LETTER GHE WITH DESCENDER",NULL},
/* 04F7 */ { "CYRILLIC SMALL LETTER GHE WITH DESCENDER","	* Yupik"},
/* 04F8 */ { "CYRILLIC CAPITAL LETTER YERU WITH DIAERESIS","	: 042B 0308"},
/* 04F9 */ { "CYRILLIC SMALL LETTER YERU WITH DIAERESIS","	: 044B 0308"},
/* 04FA */ { "CYRILLIC CAPITAL LETTER GHE WITH STROKE AND HOOK",NULL},
/* 04FB */ { "CYRILLIC SMALL LETTER GHE WITH STROKE AND HOOK",NULL},
/* 04FC */ { "CYRILLIC CAPITAL LETTER HA WITH HOOK",NULL},
/* 04FD */ { "CYRILLIC SMALL LETTER HA WITH HOOK",NULL},
/* 04FE */ { "CYRILLIC CAPITAL LETTER HA WITH STROKE",NULL},
/* 04FF */ { "CYRILLIC SMALL LETTER HA WITH STROKE",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_00_05[] = {
/* 0500 */ { "CYRILLIC CAPITAL LETTER KOMI DE",NULL},
/* 0501 */ { "CYRILLIC SMALL LETTER KOMI DE",NULL},
/* 0502 */ { "CYRILLIC CAPITAL LETTER KOMI DJE",NULL},
/* 0503 */ { "CYRILLIC SMALL LETTER KOMI DJE",NULL},
/* 0504 */ { "CYRILLIC CAPITAL LETTER KOMI ZJE",NULL},
/* 0505 */ { "CYRILLIC SMALL LETTER KOMI ZJE",NULL},
/* 0506 */ { "CYRILLIC CAPITAL LETTER KOMI DZJE",NULL},
/* 0507 */ { "CYRILLIC SMALL LETTER KOMI DZJE",NULL},
/* 0508 */ { "CYRILLIC CAPITAL LETTER KOMI LJE",NULL},
/* 0509 */ { "CYRILLIC SMALL LETTER KOMI LJE",NULL},
/* 050A */ { "CYRILLIC CAPITAL LETTER KOMI NJE",NULL},
/* 050B */ { "CYRILLIC SMALL LETTER KOMI NJE",NULL},
/* 050C */ { "CYRILLIC CAPITAL LETTER KOMI SJE",NULL},
/* 050D */ { "CYRILLIC SMALL LETTER KOMI SJE",NULL},
/* 050E */ { "CYRILLIC CAPITAL LETTER KOMI TJE",NULL},
/* 050F */ { "CYRILLIC SMALL LETTER KOMI TJE","	x (cyrillic small letter tje - 1C8A)\n"
	"		These letters are for the obsolete Molodtsov alphabet, used in the 1920s."},
/* 0510 */ { "CYRILLIC CAPITAL LETTER REVERSED ZE",NULL},
/* 0511 */ { "CYRILLIC SMALL LETTER REVERSED ZE","	* also used for Enets"},
/* 0512 */ { "CYRILLIC CAPITAL LETTER EL WITH HOOK",NULL},
/* 0513 */ { "CYRILLIC SMALL LETTER EL WITH HOOK","	* also used for Itelmen"},
/* 0514 */ { "CYRILLIC CAPITAL LETTER LHA",NULL},
/* 0515 */ { "CYRILLIC SMALL LETTER LHA","	= voiceless l"},
/* 0516 */ { "CYRILLIC CAPITAL LETTER RHA",NULL},
/* 0517 */ { "CYRILLIC SMALL LETTER RHA","	= voiceless r"},
/* 0518 */ { "CYRILLIC CAPITAL LETTER YAE",NULL},
/* 0519 */ { "CYRILLIC SMALL LETTER YAE",NULL},
/* 051A */ { "CYRILLIC CAPITAL LETTER QA",NULL},
/* 051B */ { "CYRILLIC SMALL LETTER QA",NULL},
/* 051C */ { "CYRILLIC CAPITAL LETTER WE",NULL},
/* 051D */ { "CYRILLIC SMALL LETTER WE",NULL},
/* 051E */ { "CYRILLIC CAPITAL LETTER ALEUT KA",NULL},
/* 051F */ { "CYRILLIC SMALL LETTER ALEUT KA","	* used for [q] in Aleut"},
/* 0520 */ { "CYRILLIC CAPITAL LETTER EL WITH MIDDLE HOOK",NULL},
/* 0521 */ { "CYRILLIC SMALL LETTER EL WITH MIDDLE HOOK","	= palatalized l"},
/* 0522 */ { "CYRILLIC CAPITAL LETTER EN WITH MIDDLE HOOK",NULL},
/* 0523 */ { "CYRILLIC SMALL LETTER EN WITH MIDDLE HOOK","	= palatalized n"},
/* 0524 */ { "CYRILLIC CAPITAL LETTER PE WITH DESCENDER",NULL},
/* 0525 */ { "CYRILLIC SMALL LETTER PE WITH DESCENDER","	* used in modern Abkhaz orthography\n"
	"	x (cyrillic small letter pe with middle hook - 04A7)"},
/* 0526 */ { "CYRILLIC CAPITAL LETTER SHHA WITH DESCENDER",NULL},
/* 0527 */ { "CYRILLIC SMALL LETTER SHHA WITH DESCENDER",NULL},
/* 0528 */ { "CYRILLIC CAPITAL LETTER EN WITH LEFT HOOK",NULL},
/* 0529 */ { "CYRILLIC SMALL LETTER EN WITH LEFT HOOK",NULL},
/* 052A */ { "CYRILLIC CAPITAL LETTER DZZHE",NULL},
/* 052B */ { "CYRILLIC SMALL LETTER DZZHE","	* also used for Ossetian until 1924"},
/* 052C */ { "CYRILLIC CAPITAL LETTER DCHE",NULL},
/* 052D */ { "CYRILLIC SMALL LETTER DCHE",NULL},
/* 052E */ { "CYRILLIC CAPITAL LETTER EL WITH DESCENDER",NULL},
/* 052F */ { "CYRILLIC SMALL LETTER EL WITH DESCENDER","	* also used for Nenets"},
/* 0530 */ { NULL,NULL},
/* 0531 */ { "ARMENIAN CAPITAL LETTER AYB",NULL},
/* 0532 */ { "ARMENIAN CAPITAL LETTER BEN",NULL},
/* 0533 */ { "ARMENIAN CAPITAL LETTER GIM",NULL},
/* 0534 */ { "ARMENIAN CAPITAL LETTER DA",NULL},
/* 0535 */ { "ARMENIAN CAPITAL LETTER ECH",NULL},
/* 0536 */ { "ARMENIAN CAPITAL LETTER ZA",NULL},
/* 0537 */ { "ARMENIAN CAPITAL LETTER EH",NULL},
/* 0538 */ { "ARMENIAN CAPITAL LETTER ET",NULL},
/* 0539 */ { "ARMENIAN CAPITAL LETTER TO",NULL},
/* 053A */ { "ARMENIAN CAPITAL LETTER ZHE",NULL},
/* 053B */ { "ARMENIAN CAPITAL LETTER INI",NULL},
/* 053C */ { "ARMENIAN CAPITAL LETTER LIWN",NULL},
/* 053D */ { "ARMENIAN CAPITAL LETTER XEH",NULL},
/* 053E */ { "ARMENIAN CAPITAL LETTER CA",NULL},
/* 053F */ { "ARMENIAN CAPITAL LETTER KEN",NULL},
/* 0540 */ { "ARMENIAN CAPITAL LETTER HO",NULL},
/* 0541 */ { "ARMENIAN CAPITAL LETTER JA",NULL},
/* 0542 */ { "ARMENIAN CAPITAL LETTER GHAD",NULL},
/* 0543 */ { "ARMENIAN CAPITAL LETTER CHEH",NULL},
/* 0544 */ { "ARMENIAN CAPITAL LETTER MEN",NULL},
/* 0545 */ { "ARMENIAN CAPITAL LETTER YI",NULL},
/* 0546 */ { "ARMENIAN CAPITAL LETTER NOW",NULL},
/* 0547 */ { "ARMENIAN CAPITAL LETTER SHA",NULL},
/* 0548 */ { "ARMENIAN CAPITAL LETTER VO",NULL},
/* 0549 */ { "ARMENIAN CAPITAL LETTER CHA",NULL},
/* 054A */ { "ARMENIAN CAPITAL LETTER PEH",NULL},
/* 054B */ { "ARMENIAN CAPITAL LETTER JHEH",NULL},
/* 054C */ { "ARMENIAN CAPITAL LETTER RA",NULL},
/* 054D */ { "ARMENIAN CAPITAL LETTER SEH",NULL},
/* 054E */ { "ARMENIAN CAPITAL LETTER VEW",NULL},
/* 054F */ { "ARMENIAN CAPITAL LETTER TIWN",NULL},
/* 0550 */ { "ARMENIAN CAPITAL LETTER REH",NULL},
/* 0551 */ { "ARMENIAN CAPITAL LETTER CO",NULL},
/* 0552 */ { "ARMENIAN CAPITAL LETTER YIWN",NULL},
/* 0553 */ { "ARMENIAN CAPITAL LETTER PIWR",NULL},
/* 0554 */ { "ARMENIAN CAPITAL LETTER KEH",NULL},
/* 0555 */ { "ARMENIAN CAPITAL LETTER OH",NULL},
/* 0556 */ { "ARMENIAN CAPITAL LETTER FEH",NULL},
/* 0557 */ { NULL,NULL},
/* 0558 */ { NULL,NULL},
/* 0559 */ { "ARMENIAN MODIFIER LETTER LEFT HALF RING","	x (modifier letter reversed comma - 02BD)\n"
	"	x (modifier letter left half ring - 02BF)\n"
	"	x (combining reversed comma above - 0314)"},
/* 055A */ { "ARMENIAN APOSTROPHE","	= armenian modifier letter right half ring (1.0)\n"
	"	x (modifier letter apostrophe - 02BC)\n"
	"	x (modifier letter right half ring - 02BE)\n"
	"	x (combining comma above - 0313)"},
/* 055B */ { "ARMENIAN EMPHASIS MARK","	= shesht\n"
	"	x (modifier letter acute accent - 02CA)"},
/* 055C */ { "ARMENIAN EXCLAMATION MARK","	= batsaganchakan nshan\n"
	"	* marks intonation on word, rather than occurring finally"},
/* 055D */ { "ARMENIAN COMMA","	= bowt\n"
	"	x (modifier letter grave accent - 02CB)"},
/* 055E */ { "ARMENIAN QUESTION MARK","	= hartsakan nshan\n"
	"	* marks intonation on word, rather than occurring finally"},
/* 055F */ { "ARMENIAN ABBREVIATION MARK","	= patiw"},
/* 0560 */ { "ARMENIAN SMALL LETTER TURNED AYB","	* used for phonetic notation"},
/* 0561 */ { "ARMENIAN SMALL LETTER AYB",NULL},
/* 0562 */ { "ARMENIAN SMALL LETTER BEN",NULL},
/* 0563 */ { "ARMENIAN SMALL LETTER GIM",NULL},
/* 0564 */ { "ARMENIAN SMALL LETTER DA",NULL},
/* 0565 */ { "ARMENIAN SMALL LETTER ECH",NULL},
/* 0566 */ { "ARMENIAN SMALL LETTER ZA",NULL},
/* 0567 */ { "ARMENIAN SMALL LETTER EH",NULL},
/* 0568 */ { "ARMENIAN SMALL LETTER ET",NULL},
/* 0569 */ { "ARMENIAN SMALL LETTER TO",NULL},
/* 056A */ { "ARMENIAN SMALL LETTER ZHE",NULL},
/* 056B */ { "ARMENIAN SMALL LETTER INI",NULL},
/* 056C */ { "ARMENIAN SMALL LETTER LIWN",NULL},
/* 056D */ { "ARMENIAN SMALL LETTER XEH",NULL},
/* 056E */ { "ARMENIAN SMALL LETTER CA",NULL},
/* 056F */ { "ARMENIAN SMALL LETTER KEN",NULL},
/* 0570 */ { "ARMENIAN SMALL LETTER HO",NULL},
/* 0571 */ { "ARMENIAN SMALL LETTER JA",NULL},
/* 0572 */ { "ARMENIAN SMALL LETTER GHAD",NULL},
/* 0573 */ { "ARMENIAN SMALL LETTER CHEH",NULL},
/* 0574 */ { "ARMENIAN SMALL LETTER MEN",NULL},
/* 0575 */ { "ARMENIAN SMALL LETTER YI",NULL},
/* 0576 */ { "ARMENIAN SMALL LETTER NOW",NULL},
/* 0577 */ { "ARMENIAN SMALL LETTER SHA",NULL},
/* 0578 */ { "ARMENIAN SMALL LETTER VO",NULL},
/* 0579 */ { "ARMENIAN SMALL LETTER CHA",NULL},
/* 057A */ { "ARMENIAN SMALL LETTER PEH",NULL},
/* 057B */ { "ARMENIAN SMALL LETTER JHEH",NULL},
/* 057C */ { "ARMENIAN SMALL LETTER RA",NULL},
/* 057D */ { "ARMENIAN SMALL LETTER SEH",NULL},
/* 057E */ { "ARMENIAN SMALL LETTER VEW",NULL},
/* 057F */ { "ARMENIAN SMALL LETTER TIWN",NULL},
/* 0580 */ { "ARMENIAN SMALL LETTER REH",NULL},
/* 0581 */ { "ARMENIAN SMALL LETTER CO",NULL},
/* 0582 */ { "ARMENIAN SMALL LETTER YIWN",NULL},
/* 0583 */ { "ARMENIAN SMALL LETTER PIWR",NULL},
/* 0584 */ { "ARMENIAN SMALL LETTER KEH",NULL},
/* 0585 */ { "ARMENIAN SMALL LETTER OH",NULL},
/* 0586 */ { "ARMENIAN SMALL LETTER FEH",NULL},
/* 0587 */ { "ARMENIAN SMALL LIGATURE ECH YIWN","	# 0565 0582"},
/* 0588 */ { "ARMENIAN SMALL LETTER YI WITH STROKE","	* used for phonetic notation"},
/* 0589 */ { "ARMENIAN FULL STOP","	= vertsaket\n"
	"	* may also be used for historic Georgian texts\n"
	"	x (colon - 003A)"},
/* 058A */ { "ARMENIAN HYPHEN","	= yentamna"},
/* 058B */ { NULL,NULL},
/* 058C */ { NULL,NULL},
/* 058D */ { "RIGHT-FACING ARMENIAN ETERNITY SIGN",NULL},
/* 058E */ { "LEFT-FACING ARMENIAN ETERNITY SIGN","	* maps to AST 34.005:1997"},
/* 058F */ { "ARMENIAN DRAM SIGN",NULL},
/* 0590 */ { NULL,NULL},
/* 0591 */ { "HEBREW ACCENT ETNAHTA","	= atnah"},
/* 0592 */ { "HEBREW ACCENT SEGOL","	= segolta"},
/* 0593 */ { "HEBREW ACCENT SHALSHELET",NULL},
/* 0594 */ { "HEBREW ACCENT ZAQEF QATAN",NULL},
/* 0595 */ { "HEBREW ACCENT ZAQEF GADOL",NULL},
/* 0596 */ { "HEBREW ACCENT TIPEHA","	= tarha, me'ayla ~ mayla"},
/* 0597 */ { "HEBREW ACCENT REVIA",NULL},
/* 0598 */ { "HEBREW ACCENT ZARQA","	= tsinorit, zinorit; tsinor, zinor\n"
	"	* This character is to be used when Zarqa or Tsinor are placed above, and also for Tsinorit.\n"
	"	x (hebrew accent zinor - 05AE)"},
/* 0599 */ { "HEBREW ACCENT PASHTA",NULL},
/* 059A */ { "HEBREW ACCENT YETIV",NULL},
/* 059B */ { "HEBREW ACCENT TEVIR",NULL},
/* 059C */ { "HEBREW ACCENT GERESH","	= teres"},
/* 059D */ { "HEBREW ACCENT GERESH MUQDAM",NULL},
/* 059E */ { "HEBREW ACCENT GERSHAYIM",NULL},
/* 059F */ { "HEBREW ACCENT QARNEY PARA","	= pazer gadol"},
/* 05A0 */ { "HEBREW ACCENT TELISHA GEDOLA",NULL},
/* 05A1 */ { "HEBREW ACCENT PAZER","	= pazer qatan"},
/* 05A2 */ { "HEBREW ACCENT ATNAH HAFUKH","	x (hebrew accent yerah ben yomo - 05AA)"},
/* 05A3 */ { "HEBREW ACCENT MUNAH",NULL},
/* 05A4 */ { "HEBREW ACCENT MAHAPAKH",NULL},
/* 05A5 */ { "HEBREW ACCENT MERKHA","	= yored"},
/* 05A6 */ { "HEBREW ACCENT MERKHA KEFULA",NULL},
/* 05A7 */ { "HEBREW ACCENT DARGA",NULL},
/* 05A8 */ { "HEBREW ACCENT QADMA","	= azla"},
/* 05A9 */ { "HEBREW ACCENT TELISHA QETANA",NULL},
/* 05AA */ { "HEBREW ACCENT YERAH BEN YOMO","	= galgal\n"
	"	x (hebrew accent atnah hafukh - 05A2)"},
/* 05AB */ { "HEBREW ACCENT OLE",NULL},
/* 05AC */ { "HEBREW ACCENT ILUY",NULL},
/* 05AD */ { "HEBREW ACCENT DEHI",NULL},
/* 05AE */ { "HEBREW ACCENT ZINOR","	= tsinor; zarqa\n"
	"	* This character is to be used when Zarqa or Tsinor are placed above left.\n"
	"	x (hebrew accent zarqa - 0598)"},
/* 05AF */ { "HEBREW MARK MASORA CIRCLE",NULL},
/* 05B0 */ { "HEBREW POINT SHEVA",NULL},
/* 05B1 */ { "HEBREW POINT HATAF SEGOL",NULL},
/* 05B2 */ { "HEBREW POINT HATAF PATAH",NULL},
/* 05B3 */ { "HEBREW POINT HATAF QAMATS",NULL},
/* 05B4 */ { "HEBREW POINT HIRIQ",NULL},
/* 05B5 */ { "HEBREW POINT TSERE",NULL},
/* 05B6 */ { "HEBREW POINT SEGOL",NULL},
/* 05B7 */ { "HEBREW POINT PATAH","	* furtive patah is not a distinct character"},
/* 05B8 */ { "HEBREW POINT QAMATS","	* used generically or as qamats gadol in orthography which distinguishes that from qamats qatan\n"
	"	x (hebrew point qamats qatan - 05C7)"},
/* 05B9 */ { "HEBREW POINT HOLAM",NULL},
/* 05BA */ { "HEBREW POINT HOLAM HASER FOR VAV",NULL},
/* 05BB */ { "HEBREW POINT QUBUTS",NULL},
/* 05BC */ { "HEBREW POINT DAGESH OR MAPIQ","	= shuruq\n"
	"	* falls within the base letter"},
/* 05BD */ { "HEBREW POINT METEG","	= siluq\n"
	"	* may be used as a Hebrew accent sof pasuq"},
/* 05BE */ { "HEBREW PUNCTUATION MAQAF",NULL},
/* 05BF */ { "HEBREW POINT RAFE","	x (hebrew point judeo-spanish varika - FB1E)"},
/* 05C0 */ { "HEBREW PUNCTUATION PASEQ","	= legarmeh\n"
	"	* may be treated as spacing punctuation, not as a point\n"
	"	x (vertical line - 007C)"},
/* 05C1 */ { "HEBREW POINT SHIN DOT",NULL},
/* 05C2 */ { "HEBREW POINT SIN DOT",NULL},
/* 05C3 */ { "HEBREW PUNCTUATION SOF PASUQ","	* may be used as a Hebrew punctuation colon\n"
	"	x (colon - 003A)"},
/* 05C4 */ { "HEBREW MARK UPPER DOT",NULL},
/* 05C5 */ { "HEBREW MARK LOWER DOT","	* punctum extraordinarium (Psalms 27:13)\n"
	"	x (hebrew point hiriq - 05B4)"},
/* 05C6 */ { "HEBREW PUNCTUATION NUN HAFUKHA","	* does not historically derive from the letter nun\n"
	"	x (hebrew letter nun - 05E0)"},
/* 05C7 */ { "HEBREW POINT QAMATS QATAN","	x (hebrew point qamats - 05B8)"},
/* 05C8 */ { NULL,NULL},
/* 05C9 */ { NULL,NULL},
/* 05CA */ { NULL,NULL},
/* 05CB */ { NULL,NULL},
/* 05CC */ { NULL,NULL},
/* 05CD */ { NULL,NULL},
/* 05CE */ { NULL,NULL},
/* 05CF */ { NULL,NULL},
/* 05D0 */ { "HEBREW LETTER ALEF","	= aleph\n"
	"	x (alef symbol - 2135)"},
/* 05D1 */ { "HEBREW LETTER BET","	x (bet symbol - 2136)"},
/* 05D2 */ { "HEBREW LETTER GIMEL","	x (gimel symbol - 2137)"},
/* 05D3 */ { "HEBREW LETTER DALET","	x (dalet symbol - 2138)"},
/* 05D4 */ { "HEBREW LETTER HE",NULL},
/* 05D5 */ { "HEBREW LETTER VAV",NULL},
/* 05D6 */ { "HEBREW LETTER ZAYIN",NULL},
/* 05D7 */ { "HEBREW LETTER HET",NULL},
/* 05D8 */ { "HEBREW LETTER TET",NULL},
/* 05D9 */ { "HEBREW LETTER YOD",NULL},
/* 05DA */ { "HEBREW LETTER FINAL KAF",NULL},
/* 05DB */ { "HEBREW LETTER KAF",NULL},
/* 05DC */ { "HEBREW LETTER LAMED",NULL},
/* 05DD */ { "HEBREW LETTER FINAL MEM",NULL},
/* 05DE */ { "HEBREW LETTER MEM",NULL},
/* 05DF */ { "HEBREW LETTER FINAL NUN",NULL},
/* 05E0 */ { "HEBREW LETTER NUN",NULL},
/* 05E1 */ { "HEBREW LETTER SAMEKH",NULL},
/* 05E2 */ { "HEBREW LETTER AYIN",NULL},
/* 05E3 */ { "HEBREW LETTER FINAL PE",NULL},
/* 05E4 */ { "HEBREW LETTER PE",NULL},
/* 05E5 */ { "HEBREW LETTER FINAL TSADI",NULL},
/* 05E6 */ { "HEBREW LETTER TSADI","	= zade"},
/* 05E7 */ { "HEBREW LETTER QOF",NULL},
/* 05E8 */ { "HEBREW LETTER RESH",NULL},
/* 05E9 */ { "HEBREW LETTER SHIN",NULL},
/* 05EA */ { "HEBREW LETTER TAV",NULL},
/* 05EB */ { NULL,NULL},
/* 05EC */ { NULL,NULL},
/* 05ED */ { NULL,NULL},
/* 05EE */ { NULL,NULL},
/* 05EF */ { "HEBREW YOD TRIANGLE",NULL},
/* 05F0 */ { "HEBREW LIGATURE YIDDISH DOUBLE VAV","	= tsvey vovn"},
/* 05F1 */ { "HEBREW LIGATURE YIDDISH VAV YOD",NULL},
/* 05F2 */ { "HEBREW LIGATURE YIDDISH DOUBLE YOD","	= tsvey yudn"},
/* 05F3 */ { "HEBREW PUNCTUATION GERESH","	x (apostrophe - 0027)"},
/* 05F4 */ { "HEBREW PUNCTUATION GERSHAYIM","	x (quotation mark - 0022)"},
/* 05F5 */ { NULL,NULL},
/* 05F6 */ { NULL,NULL},
/* 05F7 */ { NULL,NULL},
/* 05F8 */ { NULL,NULL},
/* 05F9 */ { NULL,NULL},
/* 05FA */ { NULL,NULL},
/* 05FB */ { NULL,NULL},
/* 05FC */ { NULL,NULL},
/* 05FD */ { NULL,NULL},
/* 05FE */ { NULL,NULL},
/* 05FF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_00_06[] = {
/* 0600 */ { "ARABIC NUMBER SIGN",NULL},
/* 0601 */ { "ARABIC SIGN SANAH",NULL},
/* 0602 */ { "ARABIC FOOTNOTE MARKER",NULL},
/* 0603 */ { "ARABIC SIGN SAFHA",NULL},
/* 0604 */ { "ARABIC SIGN SAMVAT","	* used for writing Samvat era dates in Urdu"},
/* 0605 */ { "ARABIC NUMBER MARK ABOVE","	* may be used with Coptic Epact numbers"},
/* 0606 */ { "ARABIC-INDIC CUBE ROOT","	x (cube root - 221B)"},
/* 0607 */ { "ARABIC-INDIC FOURTH ROOT","	x (fourth root - 221C)"},
/* 0608 */ { "ARABIC RAY",NULL},
/* 0609 */ { "ARABIC-INDIC PER MILLE SIGN","	x (per mille sign - 2030)"},
/* 060A */ { "ARABIC-INDIC PER TEN THOUSAND SIGN","	x (per ten thousand sign - 2031)"},
/* 060B */ { "AFGHANI SIGN",NULL},
/* 060C */ { "ARABIC COMMA","	* also used with Thaana and Syriac in modern text\n"
	"	x (comma - 002C)\n"
	"	x (turned comma - 2E32)\n"
	"	x (reversed comma - 2E41)"},
/* 060D */ { "ARABIC DATE SEPARATOR",NULL},
/* 060E */ { "ARABIC POETIC VERSE SIGN",NULL},
/* 060F */ { "ARABIC SIGN MISRA",NULL},
/* 0610 */ { "ARABIC SIGN SALLALLAHOU ALAYHE WASSALLAM","	* represents sallallahu alayhe wasallam \"may God's peace and blessings be upon him\""},
/* 0611 */ { "ARABIC SIGN ALAYHE ASSALLAM","	* represents alayhe assalam \"upon him be peace\"\n"
	"	x (arabic ligature alayhi as-salaam - FD47)"},
/* 0612 */ { "ARABIC SIGN RAHMATULLAH ALAYHE","	* represents rahmatullah alayhe \"may God have mercy upon him\"\n"
	"	x (arabic ligature rahimahu allaah - FD40)"},
/* 0613 */ { "ARABIC SIGN RADI ALLAHOU ANHU","	* represents radi allahu 'anhu \"may God be pleased with him\"\n"
	"	x (arabic ligature radi allaahu anh - FD41)"},
/* 0614 */ { "ARABIC SIGN TAKHALLUS","	* sign placed over the name or nom-de-plume of a poet, or in some writings used to mark all proper names"},
/* 0615 */ { "ARABIC SMALL HIGH TAH","	* marks a recommended pause position in some Qurans published in Iran and Pakistan\n"
	"	* should not be confused with the small TAH sign used as a diacritic for some letters such as 0679"},
/* 0616 */ { "ARABIC SMALL HIGH LIGATURE ALEF WITH LAM WITH YEH","	% ARABIC SMALL HIGH LIGATURE ALEF WITH YEH BARREE\n"
	"	* early Persian"},
/* 0617 */ { "ARABIC SMALL HIGH ZAIN",NULL},
/* 0618 */ { "ARABIC SMALL FATHA","	* should not be confused with 064E FATHA"},
/* 0619 */ { "ARABIC SMALL DAMMA","	* should not be confused with 064F DAMMA"},
/* 061A */ { "ARABIC SMALL KASRA","	* should not be confused with 0650 KASRA"},
/* 061B */ { "ARABIC SEMICOLON","	* also used with Thaana and Syriac in modern text\n"
	"	x (semicolon - 003B)\n"
	"	x (reversed semicolon - 204F)\n"
	"	x (turned semicolon - 2E35)"},
/* 061C */ { "ARABIC LETTER MARK","	* commonly abbreviated ALM\n"
	"	x (right-to-left mark - 200F)"},
/* 061D */ { "ARABIC END OF TEXT MARK",NULL},
/* 061E */ { "ARABIC TRIPLE DOT PUNCTUATION MARK",NULL},
/* 061F */ { "ARABIC QUESTION MARK","	* also used with Thaana and Syriac in modern text\n"
	"	x (question mark - 003F)\n"
	"	x (reversed question mark - 2E2E)"},
/* 0620 */ { "ARABIC LETTER KASHMIRI YEH","	* used in Kashmiri to represent half ye / taler ye"},
/* 0621 */ { "ARABIC LETTER HAMZA","	x (modifier letter right half ring - 02BE)"},
/* 0622 */ { "ARABIC LETTER ALEF WITH MADDA ABOVE","	: 0627 0653"},
/* 0623 */ { "ARABIC LETTER ALEF WITH HAMZA ABOVE","	: 0627 0654"},
/* 0624 */ { "ARABIC LETTER WAW WITH HAMZA ABOVE","	: 0648 0654"},
/* 0625 */ { "ARABIC LETTER ALEF WITH HAMZA BELOW","	: 0627 0655"},
/* 0626 */ { "ARABIC LETTER YEH WITH HAMZA ABOVE","	* in Kyrgyz the hamza is consistently positioned to the top right in isolate and final forms\n"
	"	: 064A 0654"},
/* 0627 */ { "ARABIC LETTER ALEF",NULL},
/* 0628 */ { "ARABIC LETTER BEH",NULL},
/* 0629 */ { "ARABIC LETTER TEH MARBUTA",NULL},
/* 062A */ { "ARABIC LETTER TEH",NULL},
/* 062B */ { "ARABIC LETTER THEH",NULL},
/* 062C */ { "ARABIC LETTER JEEM",NULL},
/* 062D */ { "ARABIC LETTER HAH",NULL},
/* 062E */ { "ARABIC LETTER KHAH",NULL},
/* 062F */ { "ARABIC LETTER DAL",NULL},
/* 0630 */ { "ARABIC LETTER THAL",NULL},
/* 0631 */ { "ARABIC LETTER REH",NULL},
/* 0632 */ { "ARABIC LETTER ZAIN",NULL},
/* 0633 */ { "ARABIC LETTER SEEN",NULL},
/* 0634 */ { "ARABIC LETTER SHEEN",NULL},
/* 0635 */ { "ARABIC LETTER SAD",NULL},
/* 0636 */ { "ARABIC LETTER DAD",NULL},
/* 0637 */ { "ARABIC LETTER TAH",NULL},
/* 0638 */ { "ARABIC LETTER ZAH",NULL},
/* 0639 */ { "ARABIC LETTER AIN","	x (latin small letter ezh reversed - 01B9)\n"
	"	x (modifier letter left half ring - 02BF)"},
/* 063A */ { "ARABIC LETTER GHAIN",NULL},
/* 063B */ { "ARABIC LETTER KEHEH WITH TWO DOTS ABOVE",NULL},
/* 063C */ { "ARABIC LETTER KEHEH WITH THREE DOTS BELOW",NULL},
/* 063D */ { "ARABIC LETTER FARSI YEH WITH INVERTED V","	* Azerbaijani"},
/* 063E */ { "ARABIC LETTER FARSI YEH WITH TWO DOTS ABOVE",NULL},
/* 063F */ { "ARABIC LETTER FARSI YEH WITH THREE DOTS ABOVE",NULL},
/* 0640 */ { "ARABIC TATWEEL","	= kashida\n"
	"	* inserted to stretch characters or to carry tashkil with no base letter\n"
	"	* also used with Adlam, Hanifi Rohingya, Mandaic, Manichaean, Psalter Pahlavi, Sogdian, and Syriac"},
/* 0641 */ { "ARABIC LETTER FEH",NULL},
/* 0642 */ { "ARABIC LETTER QAF",NULL},
/* 0643 */ { "ARABIC LETTER KAF",NULL},
/* 0644 */ { "ARABIC LETTER LAM",NULL},
/* 0645 */ { "ARABIC LETTER MEEM","	* Sindhi uses a shape with a short tail"},
/* 0646 */ { "ARABIC LETTER NOON",NULL},
/* 0647 */ { "ARABIC LETTER HEH",NULL},
/* 0648 */ { "ARABIC LETTER WAW",NULL},
/* 0649 */ { "ARABIC LETTER ALEF MAKSURA","	* represents YEH-shaped dual-joining letter with no dots in any positional form\n"
	"	* not intended for use in combination with 0654\n"
	"	x (arabic letter yeh with hamza above - 0626)"},
/* 064A */ { "ARABIC LETTER YEH","	* loses its dots when used in combination with 0654\n"
	"	* retains its dots when used in combination with other combining marks\n"
	"	x (arabic letter yeh with two dots below and hamza above - 08A8)"},
/* 064B */ { "ARABIC FATHATAN",NULL},
/* 064C */ { "ARABIC DAMMATAN","	* a common alternative form is written as two intertwined dammas, one of which is turned 180 degrees"},
/* 064D */ { "ARABIC KASRATAN","	x (arabic double vertical bar below - 10EFA)"},
/* 064E */ { "ARABIC FATHA",NULL},
/* 064F */ { "ARABIC DAMMA",NULL},
/* 0650 */ { "ARABIC KASRA",NULL},
/* 0651 */ { "ARABIC SHADDA",NULL},
/* 0652 */ { "ARABIC SUKUN","	* marks absence of a vowel after the base consonant\n"
	"	* used in some Qurans to mark a long vowel as ignored\n"
	"	* can have a variety of shapes, including a circular one and a shape that looks like '06E1'\n"
	"	x (arabic small high dotless head of khah - 06E1)"},
/* 0653 */ { "ARABIC MADDAH ABOVE","	* used for madd jaa'iz in South Asian and Indonesian orthographies\n"
	"	x (arabic pepet - 0897)\n"
	"	x (arabic madda waajib - 089C)\n"
	"	x (arabic doubled madda - 089E)\n"
	"	x (arabic half madda over madda - 089F)"},
/* 0654 */ { "ARABIC HAMZA ABOVE","	* restricted to hamza and ezafe semantics\n"
	"	* is not used as a diacritic to form new letters"},
/* 0655 */ { "ARABIC HAMZA BELOW",NULL},
/* 0656 */ { "ARABIC SUBSCRIPT ALEF",NULL},
/* 0657 */ { "ARABIC INVERTED DAMMA","	= ulta pesh\n"
	"	* Kashmiri, Urdu"},
/* 0658 */ { "ARABIC MARK NOON GHUNNA","	* Baluchi\n"
	"	* indicates nasalization in Urdu"},
/* 0659 */ { "ARABIC ZWARAKAY","	* Pashto"},
/* 065A */ { "ARABIC VOWEL SIGN SMALL V ABOVE","	* African languages"},
/* 065B */ { "ARABIC VOWEL SIGN INVERTED SMALL V ABOVE","	* African languages"},
/* 065C */ { "ARABIC VOWEL SIGN DOT BELOW","	* African languages\n"
	"	* also used in Quranic text in African and other orthographies"},
/* 065D */ { "ARABIC REVERSED DAMMA","	* African languages"},
/* 065E */ { "ARABIC FATHA WITH TWO DOTS","	* Kalami"},
/* 065F */ { "ARABIC WAVY HAMZA BELOW","	* Kashmiri"},
/* 0660 */ { "ARABIC-INDIC DIGIT ZERO",NULL},
/* 0661 */ { "ARABIC-INDIC DIGIT ONE",NULL},
/* 0662 */ { "ARABIC-INDIC DIGIT TWO",NULL},
/* 0663 */ { "ARABIC-INDIC DIGIT THREE",NULL},
/* 0664 */ { "ARABIC-INDIC DIGIT FOUR",NULL},
/* 0665 */ { "ARABIC-INDIC DIGIT FIVE",NULL},
/* 0666 */ { "ARABIC-INDIC DIGIT SIX",NULL},
/* 0667 */ { "ARABIC-INDIC DIGIT SEVEN",NULL},
/* 0668 */ { "ARABIC-INDIC DIGIT EIGHT",NULL},
/* 0669 */ { "ARABIC-INDIC DIGIT NINE",NULL},
/* 066A */ { "ARABIC PERCENT SIGN","	x (percent sign - 0025)"},
/* 066B */ { "ARABIC DECIMAL SEPARATOR",NULL},
/* 066C */ { "ARABIC THOUSANDS SEPARATOR","	x (apostrophe - 0027)\n"
	"	x (right single quotation mark - 2019)"},
/* 066D */ { "ARABIC FIVE POINTED STAR","	* appearance rather variable\n"
	"	x (asterisk - 002A)"},
/* 066E */ { "ARABIC LETTER DOTLESS BEH",NULL},
/* 066F */ { "ARABIC LETTER DOTLESS QAF",NULL},
/* 0670 */ { "ARABIC LETTER SUPERSCRIPT ALEF","	* actually a vowel sign, despite the name"},
/* 0671 */ { "ARABIC LETTER ALEF WASLA","	* Quranic Arabic"},
/* 0672 */ { "ARABIC LETTER ALEF WITH WAVY HAMZA ABOVE","	* Baluchi, Kashmiri"},
/* 0673 */ { "ARABIC LETTER ALEF WITH WAVY HAMZA BELOW","	* Kashmiri\n"
	"	* this character is deprecated and its use is strongly discouraged\n"
	"	* use the sequence 0627 065F instead"},
/* 0674 */ { "ARABIC LETTER HIGH HAMZA","	* Kazakh, Jawi\n"
	"	* forms digraphs\n"
	"	* in Jawi this character uses the fullsize hamza shape positioned at three-quarter height"},
/* 0675 */ { "ARABIC LETTER HIGH HAMZA ALEF","	* preferred spelling is 0674 0627\n"
	"	# 0627 0674"},
/* 0676 */ { "ARABIC LETTER HIGH HAMZA WAW","	* preferred spelling is 0674 0648\n"
	"	# 0648 0674"},
/* 0677 */ { "ARABIC LETTER U WITH HAMZA ABOVE","	* preferred spelling is 0674 06C7\n"
	"	# 06C7 0674"},
/* 0678 */ { "ARABIC LETTER HIGH HAMZA YEH","	* preferred spelling is 0674 0649\n"
	"	# 064A 0674"},
/* 0679 */ { "ARABIC LETTER TTEH","	* Urdu"},
/* 067A */ { "ARABIC LETTER TTEHEH","	* Sindhi"},
/* 067B */ { "ARABIC LETTER BEEH","	* Sindhi"},
/* 067C */ { "ARABIC LETTER TEH WITH RING","	* Pashto"},
/* 067D */ { "ARABIC LETTER TEH WITH THREE DOTS ABOVE DOWNWARDS","	* Sindhi"},
/* 067E */ { "ARABIC LETTER PEH","	* Persian, Urdu, ..."},
/* 067F */ { "ARABIC LETTER TEHEH","	* Sindhi"},
/* 0680 */ { "ARABIC LETTER BEHEH","	* Sindhi"},
/* 0681 */ { "ARABIC LETTER HAH WITH HAMZA ABOVE","	* Pashto\n"
	"	* represents the phoneme /dz/"},
/* 0682 */ { "ARABIC LETTER HAH WITH TWO DOTS VERTICAL ABOVE","	* not used in modern Pashto"},
/* 0683 */ { "ARABIC LETTER NYEH","	* Sindhi"},
/* 0684 */ { "ARABIC LETTER DYEH","	* Sindhi, Bosnian"},
/* 0685 */ { "ARABIC LETTER HAH WITH THREE DOTS ABOVE","	* Pashto, Khwarazmian\n"
	"	* represents the phoneme /ts/ in Pashto"},
/* 0686 */ { "ARABIC LETTER TCHEH","	* Persian, Urdu, ..."},
/* 0687 */ { "ARABIC LETTER TCHEHEH","	* Sindhi"},
/* 0688 */ { "ARABIC LETTER DDAL","	* Urdu"},
/* 0689 */ { "ARABIC LETTER DAL WITH RING","	* Pashto"},
/* 068A */ { "ARABIC LETTER DAL WITH DOT BELOW","	* Sindhi, early Persian, Pegon, Malagasy"},
/* 068B */ { "ARABIC LETTER DAL WITH DOT BELOW AND SMALL TAH","	* Lahnda"},
/* 068C */ { "ARABIC LETTER DAHAL","	* Sindhi"},
/* 068D */ { "ARABIC LETTER DDAHAL","	* Sindhi"},
/* 068E */ { "ARABIC LETTER DUL","	* older shape for DUL, now obsolete in Sindhi\n"
	"	* Burushaski"},
/* 068F */ { "ARABIC LETTER DAL WITH THREE DOTS ABOVE DOWNWARDS","	* Sindhi\n"
	"	* current shape used for DUL"},
/* 0690 */ { "ARABIC LETTER DAL WITH FOUR DOTS ABOVE","	* Old Urdu, not in current use"},
/* 0691 */ { "ARABIC LETTER RREH","	* Urdu"},
/* 0692 */ { "ARABIC LETTER REH WITH SMALL V","	* Kurdish"},
/* 0693 */ { "ARABIC LETTER REH WITH RING","	* Pashto"},
/* 0694 */ { "ARABIC LETTER REH WITH DOT BELOW","	* Kurdish, early Persian"},
/* 0695 */ { "ARABIC LETTER REH WITH SMALL V BELOW","	* Kurdish"},
/* 0696 */ { "ARABIC LETTER REH WITH DOT BELOW AND DOT ABOVE","	* Pashto"},
/* 0697 */ { "ARABIC LETTER REH WITH TWO DOTS ABOVE","	* Dargwa"},
/* 0698 */ { "ARABIC LETTER JEH","	* Persian, Urdu, ..."},
/* 0699 */ { "ARABIC LETTER REH WITH FOUR DOTS ABOVE","	* Sindhi"},
/* 069A */ { "ARABIC LETTER SEEN WITH DOT BELOW AND DOT ABOVE","	* Pashto"},
/* 069B */ { "ARABIC LETTER SEEN WITH THREE DOTS BELOW","	* early Persian"},
/* 069C */ { "ARABIC LETTER SEEN WITH THREE DOTS BELOW AND THREE DOTS ABOVE","	* Moroccan Arabic"},
/* 069D */ { "ARABIC LETTER SAD WITH TWO DOTS BELOW","	* Turkic"},
/* 069E */ { "ARABIC LETTER SAD WITH THREE DOTS ABOVE","	* Berber, Burushaski"},
/* 069F */ { "ARABIC LETTER TAH WITH THREE DOTS ABOVE","	* Old Hausa"},
/* 06A0 */ { "ARABIC LETTER AIN WITH THREE DOTS ABOVE","	* Jawi"},
/* 06A1 */ { "ARABIC LETTER DOTLESS FEH","	* Adighe"},
/* 06A2 */ { "ARABIC LETTER FEH WITH DOT MOVED BELOW","	* Maghrib Arabic"},
/* 06A3 */ { "ARABIC LETTER FEH WITH DOT BELOW","	* Ingush"},
/* 06A4 */ { "ARABIC LETTER VEH","	* Middle Eastern Arabic for foreign words\n"
	"	* Kurdish, Khwarazmian, early Persian, Jawi"},
/* 06A5 */ { "ARABIC LETTER FEH WITH THREE DOTS BELOW","	* North African Arabic for foreign words"},
/* 06A6 */ { "ARABIC LETTER PEHEH","	* Sindhi"},
/* 06A7 */ { "ARABIC LETTER QAF WITH DOT ABOVE","	* Maghrib Arabic, Uyghur"},
/* 06A8 */ { "ARABIC LETTER QAF WITH THREE DOTS ABOVE","	* Tunisian Arabic"},
/* 06A9 */ { "ARABIC LETTER KEHEH","	= kaf mashkula\n"
	"	* Persian, Urdu, Sindhi, ..."},
/* 06AA */ { "ARABIC LETTER SWASH KAF","	* represents a letter distinct from Arabic KAF (0643) in Sindhi"},
/* 06AB */ { "ARABIC LETTER KAF WITH RING","	* Pashto\n"
	"	* may appear like an Arabic KAF (0643) with a ring below the base"},
/* 06AC */ { "ARABIC LETTER KAF WITH DOT ABOVE","	* use for the Jawi gaf is not recommended, although it may be found in some existing text data; recommended character for Jawi gaf is 0762\n"
	"	x (arabic letter keheh with dot above - 0762)"},
/* 06AD */ { "ARABIC LETTER NG","	* Uyghur, Kazakh, Moroccan Arabic, early Jawi, early Persian, ..."},
/* 06AE */ { "ARABIC LETTER KAF WITH THREE DOTS BELOW","	* Berber, early Persian\n"
	"	* Pegon alternative for 08B4"},
/* 06AF */ { "ARABIC LETTER GAF","	* Persian, Urdu, ..."},
/* 06B0 */ { "ARABIC LETTER GAF WITH RING","	* Lahnda"},
/* 06B1 */ { "ARABIC LETTER NGOEH","	* Sindhi"},
/* 06B2 */ { "ARABIC LETTER GAF WITH TWO DOTS BELOW","	* not used in Sindhi"},
/* 06B3 */ { "ARABIC LETTER GUEH","	* Sindhi"},
/* 06B4 */ { "ARABIC LETTER GAF WITH THREE DOTS ABOVE","	* not used in Sindhi"},
/* 06B5 */ { "ARABIC LETTER LAM WITH SMALL V","	* Kurdish, Bosnian"},
/* 06B6 */ { "ARABIC LETTER LAM WITH DOT ABOVE","	* Kurdish"},
/* 06B7 */ { "ARABIC LETTER LAM WITH THREE DOTS ABOVE","	* Kurdish"},
/* 06B8 */ { "ARABIC LETTER LAM WITH THREE DOTS BELOW",NULL},
/* 06B9 */ { "ARABIC LETTER NOON WITH DOT BELOW",NULL},
/* 06BA */ { "ARABIC LETTER NOON GHUNNA","	* Urdu, archaic Arabic\n"
	"	* dotless in all four contextual forms"},
/* 06BB */ { "ARABIC LETTER RNOON","	* Sindhi"},
/* 06BC */ { "ARABIC LETTER NOON WITH RING","	* Pashto"},
/* 06BD */ { "ARABIC LETTER NOON WITH THREE DOTS ABOVE","	* Jawi"},
/* 06BE */ { "ARABIC LETTER HEH DOACHASHMEE","	* forms aspirate digraphs in Urdu and other languages of South Asia\n"
	"	* represents the glottal fricative /h/ in Uyghur"},
/* 06BF */ { "ARABIC LETTER TCHEH WITH DOT ABOVE",NULL},
/* 06C0 */ { "ARABIC LETTER HEH WITH YEH ABOVE","	= arabic letter hamzah on ha (1.0)\n"
	"	* for Persian ezafe, Urdu izāfat, or similar cases, instead use 0654 over the language-appropriate base letter\n"
	"	* actually a ligature, not an independent letter\n"
	"	: 06D5 0654"},
/* 06C1 */ { "ARABIC LETTER HEH GOAL","	* Urdu"},
/* 06C2 */ { "ARABIC LETTER HEH GOAL WITH HAMZA ABOVE","	* Urdu\n"
	"	* actually a ligature, not an independent letter\n"
	"	: 06C1 0654"},
/* 06C3 */ { "ARABIC LETTER TEH MARBUTA GOAL","	* Urdu"},
/* 06C4 */ { "ARABIC LETTER WAW WITH RING","	* Kashmiri"},
/* 06C5 */ { "ARABIC LETTER KIRGHIZ OE","	* Kyrgyz\n"
	"	* a glyph variant occurs which replaces the looped tail with a horizontal bar through the tail"},
/* 06C6 */ { "ARABIC LETTER OE","	* Uyghur, Kurdish, Kazakh, Azerbaijani, Bosnian"},
/* 06C7 */ { "ARABIC LETTER U","	* Azerbaijani, Kazakh, Kyrgyz, Uyghur"},
/* 06C8 */ { "ARABIC LETTER YU","	* Uyghur"},
/* 06C9 */ { "ARABIC LETTER KIRGHIZ YU","	* Kazakh, Kyrgyz, Bosnian"},
/* 06CA */ { "ARABIC LETTER WAW WITH TWO DOTS ABOVE","	* Kurdish"},
/* 06CB */ { "ARABIC LETTER VE","	* Uyghur, Kazakh"},
/* 06CC */ { "ARABIC LETTER FARSI YEH","	* Arabic, Persian, Urdu, Kashmiri, ...\n"
	"	* initial and medial forms of this letter have two horizontal dots below\n"
	"	* retains its dots in initial and medial forms when used in combination with 0654\n"
	"	x (arabic letter alef maksura - 0649)\n"
	"	x (arabic letter yeh - 064A)"},
/* 06CD */ { "ARABIC LETTER YEH WITH TAIL","	* Pashto, Sindhi\n"
	"	* should not be used in Kashmiri to represent half ye /taler ye\n"
	"	x (arabic letter kashmiri yeh - 0620)"},
/* 06CE */ { "ARABIC LETTER YEH WITH SMALL V","	* Kurdish"},
/* 06CF */ { "ARABIC LETTER WAW WITH DOT ABOVE",NULL},
/* 06D0 */ { "ARABIC LETTER E","	* Pashto, Uyghur\n"
	"	* used as the letter bbeh in Sindhi"},
/* 06D1 */ { "ARABIC LETTER YEH WITH THREE DOTS BELOW","	* Mende languages, Hausa"},
/* 06D2 */ { "ARABIC LETTER YEH BARREE","	* Urdu"},
/* 06D3 */ { "ARABIC LETTER YEH BARREE WITH HAMZA ABOVE","	* Urdu\n"
	"	* actually a ligature, not an independent letter\n"
	"	: 06D2 0654"},
/* 06D4 */ { "ARABIC FULL STOP","	* Urdu"},
/* 06D5 */ { "ARABIC LETTER AE","	* Uyghur, Kazakh, Kyrgyz"},
/* 06D6 */ { "ARABIC SMALL HIGH LIGATURE SAD WITH LAM WITH ALEF MAKSURA",NULL},
/* 06D7 */ { "ARABIC SMALL HIGH LIGATURE QAF WITH LAM WITH ALEF MAKSURA",NULL},
/* 06D8 */ { "ARABIC SMALL HIGH MEEM INITIAL FORM",NULL},
/* 06D9 */ { "ARABIC SMALL HIGH LAM ALEF",NULL},
/* 06DA */ { "ARABIC SMALL HIGH JEEM",NULL},
/* 06DB */ { "ARABIC SMALL HIGH THREE DOTS",NULL},
/* 06DC */ { "ARABIC SMALL HIGH SEEN",NULL},
/* 06DD */ { "ARABIC END OF AYAH",NULL},
/* 06DE */ { "ARABIC START OF RUB EL HIZB","	* indicates boundaries of parts of sections\n"
	"	* typically depicted as an eight-sided symbol, which may or may not appear starlike"},
/* 06DF */ { "ARABIC SMALL HIGH ROUNDED ZERO","	* smaller than the typical circular shape used for 0652"},
/* 06E0 */ { "ARABIC SMALL HIGH UPRIGHT RECTANGULAR ZERO","	* the term \"rectangular zero\" is a translation of the Arabic name of this sign"},
/* 06E1 */ { "ARABIC SMALL HIGH DOTLESS HEAD OF KHAH","	= Arabic jazm\n"
	"	* presentation form of 0652, using font technology to select the variant is preferred\n"
	"	* used in some Qurans to mark absence of a vowel\n"
	"	x (arabic sukun - 0652)"},
/* 06E2 */ { "ARABIC SMALL HIGH MEEM ISOLATED FORM",NULL},
/* 06E3 */ { "ARABIC SMALL LOW SEEN",NULL},
/* 06E4 */ { "ARABIC SMALL HIGH MADDA","	* typically used with 06E5, 06E6, 06E7, and 08F3"},
/* 06E5 */ { "ARABIC SMALL WAW","	x (arabic small low waw - 08D3)\n"
	"	x (arabic small high waw - 08F3)"},
/* 06E6 */ { "ARABIC SMALL YEH",NULL},
/* 06E7 */ { "ARABIC SMALL HIGH YEH",NULL},
/* 06E8 */ { "ARABIC SMALL HIGH NOON",NULL},
/* 06E9 */ { "ARABIC PLACE OF SAJDAH","	* there is a range of acceptable glyphs for this character"},
/* 06EA */ { "ARABIC EMPTY CENTRE LOW STOP",NULL},
/* 06EB */ { "ARABIC EMPTY CENTRE HIGH STOP",NULL},
/* 06EC */ { "ARABIC ROUNDED HIGH STOP WITH FILLED CENTRE","	* also used in Quranic text in African and other orthographies to represent wasla, ikhtilas, etc."},
/* 06ED */ { "ARABIC SMALL LOW MEEM",NULL},
/* 06EE */ { "ARABIC LETTER DAL WITH INVERTED V",NULL},
/* 06EF */ { "ARABIC LETTER REH WITH INVERTED V","	* also used in early Persian"},
/* 06F0 */ { "EXTENDED ARABIC-INDIC DIGIT ZERO",NULL},
/* 06F1 */ { "EXTENDED ARABIC-INDIC DIGIT ONE",NULL},
/* 06F2 */ { "EXTENDED ARABIC-INDIC DIGIT TWO",NULL},
/* 06F3 */ { "EXTENDED ARABIC-INDIC DIGIT THREE",NULL},
/* 06F4 */ { "EXTENDED ARABIC-INDIC DIGIT FOUR","	* Urdu and Kashmiri have a different glyph than Persian"},
/* 06F5 */ { "EXTENDED ARABIC-INDIC DIGIT FIVE",NULL},
/* 06F6 */ { "EXTENDED ARABIC-INDIC DIGIT SIX","	* Sindhi, Urdu, and Kashmiri have a different glyph than Persian"},
/* 06F7 */ { "EXTENDED ARABIC-INDIC DIGIT SEVEN","	* Sindhi, Urdu, and Kashmiri have a different glyph than Persian"},
/* 06F8 */ { "EXTENDED ARABIC-INDIC DIGIT EIGHT",NULL},
/* 06F9 */ { "EXTENDED ARABIC-INDIC DIGIT NINE",NULL},
/* 06FA */ { "ARABIC LETTER SHEEN WITH DOT BELOW",NULL},
/* 06FB */ { "ARABIC LETTER DAD WITH DOT BELOW",NULL},
/* 06FC */ { "ARABIC LETTER GHAIN WITH DOT BELOW",NULL},
/* 06FD */ { "ARABIC SIGN SINDHI AMPERSAND",NULL},
/* 06FE */ { "ARABIC SIGN SINDHI POSTPOSITION MEN",NULL},
/* 06FF */ { "ARABIC LETTER HEH WITH INVERTED V",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_00_07[] = {
/* 0700 */ { "SYRIAC END OF PARAGRAPH","	* marks the end of a paragraph"},
/* 0701 */ { "SYRIAC SUPRALINEAR FULL STOP","	* marks interrogations, imperatives, and pauses, especially in Biblical texts"},
/* 0702 */ { "SYRIAC SUBLINEAR FULL STOP","	* marks subordinate clauses and minor pauses, especially in Biblical texts"},
/* 0703 */ { "SYRIAC SUPRALINEAR COLON","	* marks expressions of wonder and has a distinct pausal value in Biblical texts"},
/* 0704 */ { "SYRIAC SUBLINEAR COLON","	* used at the end of verses of supplications"},
/* 0705 */ { "SYRIAC HORIZONTAL COLON","	* joins two words closely together in a context to which a rising tone is suitable"},
/* 0706 */ { "SYRIAC COLON SKEWED LEFT","	* marks a dependent clause"},
/* 0707 */ { "SYRIAC COLON SKEWED RIGHT","	* marks the end of a subdivision of the apodosis, or latter part of a Biblical verse"},
/* 0708 */ { "SYRIAC SUPRALINEAR COLON SKEWED LEFT","	* marks a minor phrase division"},
/* 0709 */ { "SYRIAC SUBLINEAR COLON SKEWED RIGHT","	% SYRIAC SUBLINEAR COLON SKEWED LEFT\n"
	"	* marks the end of a real or rhetorical question\n"
	"	* character name is a misnomer"},
/* 070A */ { "SYRIAC CONTRACTION","	* a contraction mark, mostly used in East Syriac\n"
	"	* placed at the end of an incomplete word"},
/* 070B */ { "SYRIAC HARKLEAN OBELUS","	* marks the beginning of a phrase, word, or morpheme that has a marginal note\n"
	"	x (division sign - 00F7)"},
/* 070C */ { "SYRIAC HARKLEAN METOBELUS","	* marks the end of a section with a marginal note"},
/* 070D */ { "SYRIAC HARKLEAN ASTERISCUS","	* marks the beginning of a phrase, word, or morpheme that has a marginal note"},
/* 070E */ { NULL,NULL},
/* 070F */ { "SYRIAC ABBREVIATION MARK","	= SAM\n"
	"	* marks the beginning of a Syriac abbreviation"},
/* 0710 */ { "SYRIAC LETTER ALAPH",NULL},
/* 0711 */ { "SYRIAC LETTER SUPERSCRIPT ALAPH","	* used in East Syriac texts to indicate an etymological Alaph"},
/* 0712 */ { "SYRIAC LETTER BETH",NULL},
/* 0713 */ { "SYRIAC LETTER GAMAL",NULL},
/* 0714 */ { "SYRIAC LETTER GAMAL GARSHUNI","	* used in Garshuni documents"},
/* 0715 */ { "SYRIAC LETTER DALATH",NULL},
/* 0716 */ { "SYRIAC LETTER DOTLESS DALATH RISH","	* ambiguous form for undifferentiated early dalath/rish"},
/* 0717 */ { "SYRIAC LETTER HE",NULL},
/* 0718 */ { "SYRIAC LETTER WAW",NULL},
/* 0719 */ { "SYRIAC LETTER ZAIN",NULL},
/* 071A */ { "SYRIAC LETTER HETH",NULL},
/* 071B */ { "SYRIAC LETTER TETH",NULL},
/* 071C */ { "SYRIAC LETTER TETH GARSHUNI","	* used in Garshuni documents"},
/* 071D */ { "SYRIAC LETTER YUDH",NULL},
/* 071E */ { "SYRIAC LETTER YUDH HE","	* mostly used in East Syriac texts"},
/* 071F */ { "SYRIAC LETTER KAPH",NULL},
/* 0720 */ { "SYRIAC LETTER LAMADH",NULL},
/* 0721 */ { "SYRIAC LETTER MIM",NULL},
/* 0722 */ { "SYRIAC LETTER NUN",NULL},
/* 0723 */ { "SYRIAC LETTER SEMKATH",NULL},
/* 0724 */ { "SYRIAC LETTER FINAL SEMKATH",NULL},
/* 0725 */ { "SYRIAC LETTER E",NULL},
/* 0726 */ { "SYRIAC LETTER PE",NULL},
/* 0727 */ { "SYRIAC LETTER REVERSED PE","	* used in Christian Palestinian Aramaic"},
/* 0728 */ { "SYRIAC LETTER SADHE",NULL},
/* 0729 */ { "SYRIAC LETTER QAPH",NULL},
/* 072A */ { "SYRIAC LETTER RISH",NULL},
/* 072B */ { "SYRIAC LETTER SHIN",NULL},
/* 072C */ { "SYRIAC LETTER TAW",NULL},
/* 072D */ { "SYRIAC LETTER PERSIAN BHETH",NULL},
/* 072E */ { "SYRIAC LETTER PERSIAN GHAMAL",NULL},
/* 072F */ { "SYRIAC LETTER PERSIAN DHALATH",NULL},
/* 0730 */ { "SYRIAC PTHAHA ABOVE",NULL},
/* 0731 */ { "SYRIAC PTHAHA BELOW",NULL},
/* 0732 */ { "SYRIAC PTHAHA DOTTED",NULL},
/* 0733 */ { "SYRIAC ZQAPHA ABOVE",NULL},
/* 0734 */ { "SYRIAC ZQAPHA BELOW",NULL},
/* 0735 */ { "SYRIAC ZQAPHA DOTTED",NULL},
/* 0736 */ { "SYRIAC RBASA ABOVE",NULL},
/* 0737 */ { "SYRIAC RBASA BELOW",NULL},
/* 0738 */ { "SYRIAC DOTTED ZLAMA HORIZONTAL",NULL},
/* 0739 */ { "SYRIAC DOTTED ZLAMA ANGULAR",NULL},
/* 073A */ { "SYRIAC HBASA ABOVE",NULL},
/* 073B */ { "SYRIAC HBASA BELOW",NULL},
/* 073C */ { "SYRIAC HBASA-ESASA DOTTED",NULL},
/* 073D */ { "SYRIAC ESASA ABOVE",NULL},
/* 073E */ { "SYRIAC ESASA BELOW",NULL},
/* 073F */ { "SYRIAC RWAHA",NULL},
/* 0740 */ { "SYRIAC FEMININE DOT","	* feminine marker used with the Taw feminine suffix\n"
	"	x (combining dot above left - 1DF8)"},
/* 0741 */ { "SYRIAC QUSHSHAYA","	* indicates a plosive pronunciation"},
/* 0742 */ { "SYRIAC RUKKAKHA","	* indicates an aspirated (spirantized) pronunciation"},
/* 0743 */ { "SYRIAC TWO VERTICAL DOTS ABOVE","	* accent mark used in ancient manuscripts"},
/* 0744 */ { "SYRIAC TWO VERTICAL DOTS BELOW","	* accent mark used in ancient manuscripts"},
/* 0745 */ { "SYRIAC THREE DOTS ABOVE","	* diacritic used in Turoyo for letters not found in Syriac"},
/* 0746 */ { "SYRIAC THREE DOTS BELOW","	* diacritic used in Turoyo for letters not found in Syriac"},
/* 0747 */ { "SYRIAC OBLIQUE LINE ABOVE","	* indication of a silent letter"},
/* 0748 */ { "SYRIAC OBLIQUE LINE BELOW","	* indication of a silent letter\n"
	"	* also used to indicate numbers multiplied by a certain constant"},
/* 0749 */ { "SYRIAC MUSIC","	* a music mark\n"
	"	* also used in the Syrian Orthodox Anaphora book to mark the breaking of the Eucharist bread"},
/* 074A */ { "SYRIAC BARREKH","	* a diacritic cross used in liturgical texts"},
/* 074B */ { NULL,NULL},
/* 074C */ { NULL,NULL},
/* 074D */ { "SYRIAC LETTER SOGDIAN ZHAIN",NULL},
/* 074E */ { "SYRIAC LETTER SOGDIAN KHAPH",NULL},
/* 074F */ { "SYRIAC LETTER SOGDIAN FE",NULL},
/* 0750 */ { "ARABIC LETTER BEH WITH THREE DOTS HORIZONTALLY BELOW",NULL},
/* 0751 */ { "ARABIC LETTER BEH WITH DOT BELOW AND THREE DOTS ABOVE",NULL},
/* 0752 */ { "ARABIC LETTER BEH WITH THREE DOTS POINTING UPWARDS BELOW",NULL},
/* 0753 */ { "ARABIC LETTER BEH WITH THREE DOTS POINTING UPWARDS BELOW AND TWO DOTS ABOVE",NULL},
/* 0754 */ { "ARABIC LETTER BEH WITH TWO DOTS BELOW AND DOT ABOVE",NULL},
/* 0755 */ { "ARABIC LETTER BEH WITH INVERTED SMALL V BELOW",NULL},
/* 0756 */ { "ARABIC LETTER BEH WITH SMALL V",NULL},
/* 0757 */ { "ARABIC LETTER HAH WITH TWO DOTS ABOVE",NULL},
/* 0758 */ { "ARABIC LETTER HAH WITH THREE DOTS POINTING UPWARDS BELOW",NULL},
/* 0759 */ { "ARABIC LETTER DAL WITH TWO DOTS VERTICALLY BELOW AND SMALL TAH","	* Saraiki"},
/* 075A */ { "ARABIC LETTER DAL WITH INVERTED SMALL V BELOW",NULL},
/* 075B */ { "ARABIC LETTER REH WITH STROKE",NULL},
/* 075C */ { "ARABIC LETTER SEEN WITH FOUR DOTS ABOVE","	* Shina"},
/* 075D */ { "ARABIC LETTER AIN WITH TWO DOTS ABOVE",NULL},
/* 075E */ { "ARABIC LETTER AIN WITH THREE DOTS POINTING DOWNWARDS ABOVE",NULL},
/* 075F */ { "ARABIC LETTER AIN WITH TWO DOTS VERTICALLY ABOVE",NULL},
/* 0760 */ { "ARABIC LETTER FEH WITH TWO DOTS BELOW",NULL},
/* 0761 */ { "ARABIC LETTER FEH WITH THREE DOTS POINTING UPWARDS BELOW",NULL},
/* 0762 */ { "ARABIC LETTER KEHEH WITH DOT ABOVE","	* Jawi, preferred to 06AC\n"
	"	x (arabic letter kaf with dot above - 06AC)"},
/* 0763 */ { "ARABIC LETTER KEHEH WITH THREE DOTS ABOVE","	* Moroccan Arabic, Amazigh, Burushaski\n"
	"	x (arabic letter ng - 06AD)"},
/* 0764 */ { "ARABIC LETTER KEHEH WITH THREE DOTS POINTING UPWARDS BELOW",NULL},
/* 0765 */ { "ARABIC LETTER MEEM WITH DOT ABOVE",NULL},
/* 0766 */ { "ARABIC LETTER MEEM WITH DOT BELOW","	* Maba"},
/* 0767 */ { "ARABIC LETTER NOON WITH TWO DOTS BELOW","	* Arwi"},
/* 0768 */ { "ARABIC LETTER NOON WITH SMALL TAH","	* Saraiki, Pathwari"},
/* 0769 */ { "ARABIC LETTER NOON WITH SMALL V","	* Gojri"},
/* 076A */ { "ARABIC LETTER LAM WITH BAR",NULL},
/* 076B */ { "ARABIC LETTER REH WITH TWO DOTS VERTICALLY ABOVE","	* Torwali, Ormuri"},
/* 076C */ { "ARABIC LETTER REH WITH HAMZA ABOVE","	* Ormuri\n"
	"	* represents a voiced alveolo-palatal laminal fricative\n"
	"	x (latin small letter z with curl - 0291)"},
/* 076D */ { "ARABIC LETTER SEEN WITH TWO DOTS VERTICALLY ABOVE","	* Kalami, Ormuri"},
/* 076E */ { "ARABIC LETTER HAH WITH SMALL ARABIC LETTER TAH BELOW",NULL},
/* 076F */ { "ARABIC LETTER HAH WITH SMALL ARABIC LETTER TAH AND TWO DOTS",NULL},
/* 0770 */ { "ARABIC LETTER SEEN WITH SMALL ARABIC LETTER TAH AND TWO DOTS",NULL},
/* 0771 */ { "ARABIC LETTER REH WITH SMALL ARABIC LETTER TAH AND TWO DOTS",NULL},
/* 0772 */ { "ARABIC LETTER HAH WITH SMALL ARABIC LETTER TAH ABOVE",NULL},
/* 0773 */ { "ARABIC LETTER ALEF WITH EXTENDED ARABIC-INDIC DIGIT TWO ABOVE",NULL},
/* 0774 */ { "ARABIC LETTER ALEF WITH EXTENDED ARABIC-INDIC DIGIT THREE ABOVE",NULL},
/* 0775 */ { "ARABIC LETTER FARSI YEH WITH EXTENDED ARABIC-INDIC DIGIT TWO ABOVE",NULL},
/* 0776 */ { "ARABIC LETTER FARSI YEH WITH EXTENDED ARABIC-INDIC DIGIT THREE ABOVE",NULL},
/* 0777 */ { "ARABIC LETTER FARSI YEH WITH EXTENDED ARABIC-INDIC DIGIT FOUR BELOW",NULL},
/* 0778 */ { "ARABIC LETTER WAW WITH EXTENDED ARABIC-INDIC DIGIT TWO ABOVE",NULL},
/* 0779 */ { "ARABIC LETTER WAW WITH EXTENDED ARABIC-INDIC DIGIT THREE ABOVE",NULL},
/* 077A */ { "ARABIC LETTER YEH BARREE WITH EXTENDED ARABIC-INDIC DIGIT TWO ABOVE",NULL},
/* 077B */ { "ARABIC LETTER YEH BARREE WITH EXTENDED ARABIC-INDIC DIGIT THREE ABOVE",NULL},
/* 077C */ { "ARABIC LETTER HAH WITH EXTENDED ARABIC-INDIC DIGIT FOUR BELOW",NULL},
/* 077D */ { "ARABIC LETTER SEEN WITH EXTENDED ARABIC-INDIC DIGIT FOUR ABOVE",NULL},
/* 077E */ { "ARABIC LETTER SEEN WITH INVERTED V",NULL},
/* 077F */ { "ARABIC LETTER KAF WITH TWO DOTS ABOVE",NULL},
/* 0780 */ { "THAANA LETTER HAA",NULL},
/* 0781 */ { "THAANA LETTER SHAVIYANI",NULL},
/* 0782 */ { "THAANA LETTER NOONU",NULL},
/* 0783 */ { "THAANA LETTER RAA",NULL},
/* 0784 */ { "THAANA LETTER BAA",NULL},
/* 0785 */ { "THAANA LETTER LHAVIYANI",NULL},
/* 0786 */ { "THAANA LETTER KAAFU",NULL},
/* 0787 */ { "THAANA LETTER ALIFU",NULL},
/* 0788 */ { "THAANA LETTER VAAVU",NULL},
/* 0789 */ { "THAANA LETTER MEEMU",NULL},
/* 078A */ { "THAANA LETTER FAAFU",NULL},
/* 078B */ { "THAANA LETTER DHAALU",NULL},
/* 078C */ { "THAANA LETTER THAA",NULL},
/* 078D */ { "THAANA LETTER LAAMU",NULL},
/* 078E */ { "THAANA LETTER GAAFU",NULL},
/* 078F */ { "THAANA LETTER GNAVIYANI",NULL},
/* 0790 */ { "THAANA LETTER SEENU",NULL},
/* 0791 */ { "THAANA LETTER DAVIYANI",NULL},
/* 0792 */ { "THAANA LETTER ZAVIYANI",NULL},
/* 0793 */ { "THAANA LETTER TAVIYANI",NULL},
/* 0794 */ { "THAANA LETTER YAA",NULL},
/* 0795 */ { "THAANA LETTER PAVIYANI",NULL},
/* 0796 */ { "THAANA LETTER JAVIYANI",NULL},
/* 0797 */ { "THAANA LETTER CHAVIYANI",NULL},
/* 0798 */ { "THAANA LETTER TTAA",NULL},
/* 0799 */ { "THAANA LETTER HHAA",NULL},
/* 079A */ { "THAANA LETTER KHAA",NULL},
/* 079B */ { "THAANA LETTER THAALU",NULL},
/* 079C */ { "THAANA LETTER ZAA",NULL},
/* 079D */ { "THAANA LETTER SHEENU",NULL},
/* 079E */ { "THAANA LETTER SAADHU",NULL},
/* 079F */ { "THAANA LETTER DAADHU",NULL},
/* 07A0 */ { "THAANA LETTER TO",NULL},
/* 07A1 */ { "THAANA LETTER ZO",NULL},
/* 07A2 */ { "THAANA LETTER AINU",NULL},
/* 07A3 */ { "THAANA LETTER GHAINU",NULL},
/* 07A4 */ { "THAANA LETTER QAAFU",NULL},
/* 07A5 */ { "THAANA LETTER WAAVU",NULL},
/* 07A6 */ { "THAANA ABAFILI",NULL},
/* 07A7 */ { "THAANA AABAAFILI",NULL},
/* 07A8 */ { "THAANA IBIFILI",NULL},
/* 07A9 */ { "THAANA EEBEEFILI",NULL},
/* 07AA */ { "THAANA UBUFILI",NULL},
/* 07AB */ { "THAANA OOBOOFILI",NULL},
/* 07AC */ { "THAANA EBEFILI",NULL},
/* 07AD */ { "THAANA EYBEYFILI",NULL},
/* 07AE */ { "THAANA OBOFILI",NULL},
/* 07AF */ { "THAANA OABOAFILI",NULL},
/* 07B0 */ { "THAANA SUKUN",NULL},
/* 07B1 */ { "THAANA LETTER NAA",NULL},
/* 07B2 */ { NULL,NULL},
/* 07B3 */ { NULL,NULL},
/* 07B4 */ { NULL,NULL},
/* 07B5 */ { NULL,NULL},
/* 07B6 */ { NULL,NULL},
/* 07B7 */ { NULL,NULL},
/* 07B8 */ { NULL,NULL},
/* 07B9 */ { NULL,NULL},
/* 07BA */ { NULL,NULL},
/* 07BB */ { NULL,NULL},
/* 07BC */ { NULL,NULL},
/* 07BD */ { NULL,NULL},
/* 07BE */ { NULL,NULL},
/* 07BF */ { NULL,NULL},
/* 07C0 */ { "NKO DIGIT ZERO",NULL},
/* 07C1 */ { "NKO DIGIT ONE",NULL},
/* 07C2 */ { "NKO DIGIT TWO",NULL},
/* 07C3 */ { "NKO DIGIT THREE",NULL},
/* 07C4 */ { "NKO DIGIT FOUR",NULL},
/* 07C5 */ { "NKO DIGIT FIVE",NULL},
/* 07C6 */ { "NKO DIGIT SIX",NULL},
/* 07C7 */ { "NKO DIGIT SEVEN",NULL},
/* 07C8 */ { "NKO DIGIT EIGHT",NULL},
/* 07C9 */ { "NKO DIGIT NINE",NULL},
/* 07CA */ { "NKO LETTER A",NULL},
/* 07CB */ { "NKO LETTER EE",NULL},
/* 07CC */ { "NKO LETTER I",NULL},
/* 07CD */ { "NKO LETTER E",NULL},
/* 07CE */ { "NKO LETTER U",NULL},
/* 07CF */ { "NKO LETTER OO",NULL},
/* 07D0 */ { "NKO LETTER O",NULL},
/* 07D1 */ { "NKO LETTER DAGBASINNA",NULL},
/* 07D2 */ { "NKO LETTER N",NULL},
/* 07D3 */ { "NKO LETTER BA",NULL},
/* 07D4 */ { "NKO LETTER PA",NULL},
/* 07D5 */ { "NKO LETTER TA",NULL},
/* 07D6 */ { "NKO LETTER JA",NULL},
/* 07D7 */ { "NKO LETTER CHA",NULL},
/* 07D8 */ { "NKO LETTER DA",NULL},
/* 07D9 */ { "NKO LETTER RA",NULL},
/* 07DA */ { "NKO LETTER RRA",NULL},
/* 07DB */ { "NKO LETTER SA",NULL},
/* 07DC */ { "NKO LETTER GBA",NULL},
/* 07DD */ { "NKO LETTER FA",NULL},
/* 07DE */ { "NKO LETTER KA",NULL},
/* 07DF */ { "NKO LETTER LA",NULL},
/* 07E0 */ { "NKO LETTER NA WOLOSO",NULL},
/* 07E1 */ { "NKO LETTER MA",NULL},
/* 07E2 */ { "NKO LETTER NYA",NULL},
/* 07E3 */ { "NKO LETTER NA",NULL},
/* 07E4 */ { "NKO LETTER HA",NULL},
/* 07E5 */ { "NKO LETTER WA",NULL},
/* 07E6 */ { "NKO LETTER YA",NULL},
/* 07E7 */ { "NKO LETTER NYA WOLOSO",NULL},
/* 07E8 */ { "NKO LETTER JONA JA",NULL},
/* 07E9 */ { "NKO LETTER JONA CHA",NULL},
/* 07EA */ { "NKO LETTER JONA RA","	x (nko letter ra - 07D9)"},
/* 07EB */ { "NKO COMBINING SHORT HIGH TONE","	x (combining macron - 0304)"},
/* 07EC */ { "NKO COMBINING SHORT LOW TONE","	x (combining tilde - 0303)"},
/* 07ED */ { "NKO COMBINING SHORT RISING TONE","	x (combining dot above - 0307)"},
/* 07EE */ { "NKO COMBINING LONG DESCENDING TONE","	x (combining circumflex accent - 0302)"},
/* 07EF */ { "NKO COMBINING LONG HIGH TONE",NULL},
/* 07F0 */ { "NKO COMBINING LONG LOW TONE",NULL},
/* 07F1 */ { "NKO COMBINING LONG RISING TONE",NULL},
/* 07F2 */ { "NKO COMBINING NASALIZATION MARK","	x (combining dot below - 0323)"},
/* 07F3 */ { "NKO COMBINING DOUBLE DOT ABOVE","	x (combining diaeresis - 0308)"},
/* 07F4 */ { "NKO HIGH TONE APOSTROPHE","	x (modifier letter apostrophe - 02BC)"},
/* 07F5 */ { "NKO LOW TONE APOSTROPHE","	x (modifier letter turned comma - 02BB)"},
/* 07F6 */ { "NKO SYMBOL OO DENNEN","	* indicates remote future placement of the topic under discussion"},
/* 07F7 */ { "NKO SYMBOL GBAKURUNEN","	* marks end of a major section of text\n"
	"	* symbol represents the three stones holding a cooking pot over a fire"},
/* 07F8 */ { "NKO COMMA",NULL},
/* 07F9 */ { "NKO EXCLAMATION MARK",NULL},
/* 07FA */ { "NKO LAJANYALAN","	x (low line - 005F)\n"
	"	x (arabic tatweel - 0640)"},
/* 07FB */ { NULL,NULL},
/* 07FC */ { NULL,NULL},
/* 07FD */ { "NKO DANTAYALAN","	* used to abbreviate units of measure\n"
	"	x (combining bridge below - 032A)"},
/* 07FE */ { "NKO DOROME SIGN","	x (nko letter da - 07D8)"},
/* 07FF */ { "NKO TAMAN SIGN","	x (nko letter ta - 07D5)"}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_00_08[] = {
/* 0800 */ { "SAMARITAN LETTER ALAF",NULL},
/* 0801 */ { "SAMARITAN LETTER BIT",NULL},
/* 0802 */ { "SAMARITAN LETTER GAMAN",NULL},
/* 0803 */ { "SAMARITAN LETTER DALAT",NULL},
/* 0804 */ { "SAMARITAN LETTER IY",NULL},
/* 0805 */ { "SAMARITAN LETTER BAA",NULL},
/* 0806 */ { "SAMARITAN LETTER ZEN",NULL},
/* 0807 */ { "SAMARITAN LETTER IT",NULL},
/* 0808 */ { "SAMARITAN LETTER TIT",NULL},
/* 0809 */ { "SAMARITAN LETTER YUT",NULL},
/* 080A */ { "SAMARITAN LETTER KAAF",NULL},
/* 080B */ { "SAMARITAN LETTER LABAT",NULL},
/* 080C */ { "SAMARITAN LETTER MIM",NULL},
/* 080D */ { "SAMARITAN LETTER NUN",NULL},
/* 080E */ { "SAMARITAN LETTER SINGAAT",NULL},
/* 080F */ { "SAMARITAN LETTER IN",NULL},
/* 0810 */ { "SAMARITAN LETTER FI",NULL},
/* 0811 */ { "SAMARITAN LETTER TSAADIY",NULL},
/* 0812 */ { "SAMARITAN LETTER QUF",NULL},
/* 0813 */ { "SAMARITAN LETTER RISH",NULL},
/* 0814 */ { "SAMARITAN LETTER SHAN",NULL},
/* 0815 */ { "SAMARITAN LETTER TAAF",NULL},
/* 0816 */ { "SAMARITAN MARK IN",NULL},
/* 0817 */ { "SAMARITAN MARK IN-ALAF",NULL},
/* 0818 */ { "SAMARITAN MARK OCCLUSION",NULL},
/* 0819 */ { "SAMARITAN MARK DAGESH",NULL},
/* 081A */ { "SAMARITAN MODIFIER LETTER EPENTHETIC YUT",NULL},
/* 081B */ { "SAMARITAN MARK EPENTHETIC YUT",NULL},
/* 081C */ { "SAMARITAN VOWEL SIGN LONG E","	= fatha al-nida"},
/* 081D */ { "SAMARITAN VOWEL SIGN E",NULL},
/* 081E */ { "SAMARITAN VOWEL SIGN OVERLONG AA","	= fatha al-ima"},
/* 081F */ { "SAMARITAN VOWEL SIGN LONG AA",NULL},
/* 0820 */ { "SAMARITAN VOWEL SIGN AA",NULL},
/* 0821 */ { "SAMARITAN VOWEL SIGN OVERLONG A","	= fatha al-iha"},
/* 0822 */ { "SAMARITAN VOWEL SIGN LONG A",NULL},
/* 0823 */ { "SAMARITAN VOWEL SIGN A",NULL},
/* 0824 */ { "SAMARITAN MODIFIER LETTER SHORT A",NULL},
/* 0825 */ { "SAMARITAN VOWEL SIGN SHORT A","	= fatha"},
/* 0826 */ { "SAMARITAN VOWEL SIGN LONG U","	= damma"},
/* 0827 */ { "SAMARITAN VOWEL SIGN U",NULL},
/* 0828 */ { "SAMARITAN MODIFIER LETTER I",NULL},
/* 0829 */ { "SAMARITAN VOWEL SIGN LONG I","	= kasra"},
/* 082A */ { "SAMARITAN VOWEL SIGN I",NULL},
/* 082B */ { "SAMARITAN VOWEL SIGN O",NULL},
/* 082C */ { "SAMARITAN VOWEL SIGN SUKUN",NULL},
/* 082D */ { "SAMARITAN MARK NEQUDAA",NULL},
/* 082E */ { NULL,NULL},
/* 082F */ { NULL,NULL},
/* 0830 */ { "SAMARITAN PUNCTUATION NEQUDAA","	= word separator"},
/* 0831 */ { "SAMARITAN PUNCTUATION AFSAAQ","	= interruption"},
/* 0832 */ { "SAMARITAN PUNCTUATION ANGED","	= restraint"},
/* 0833 */ { "SAMARITAN PUNCTUATION BAU","	= prayer"},
/* 0834 */ { "SAMARITAN PUNCTUATION ATMAAU","	= surprise"},
/* 0835 */ { "SAMARITAN PUNCTUATION SHIYYAALAA","	= question"},
/* 0836 */ { "SAMARITAN ABBREVIATION MARK",NULL},
/* 0837 */ { "SAMARITAN PUNCTUATION MELODIC QITSA",NULL},
/* 0838 */ { "SAMARITAN PUNCTUATION ZIQAA","	= shouting"},
/* 0839 */ { "SAMARITAN PUNCTUATION QITSA","	= end of section"},
/* 083A */ { "SAMARITAN PUNCTUATION ZAEF","	= outburst"},
/* 083B */ { "SAMARITAN PUNCTUATION TURU","	= teaching"},
/* 083C */ { "SAMARITAN PUNCTUATION ARKAANU","	= submissiveness"},
/* 083D */ { "SAMARITAN PUNCTUATION SOF MASHFAAT","	= full stop"},
/* 083E */ { "SAMARITAN PUNCTUATION ANNAAU","	= rest"},
/* 083F */ { NULL,NULL},
/* 0840 */ { "MANDAIC LETTER HALQA","	= a"},
/* 0841 */ { "MANDAIC LETTER AB",NULL},
/* 0842 */ { "MANDAIC LETTER AG",NULL},
/* 0843 */ { "MANDAIC LETTER AD",NULL},
/* 0844 */ { "MANDAIC LETTER AH",NULL},
/* 0845 */ { "MANDAIC LETTER USHENNA","	= u"},
/* 0846 */ { "MANDAIC LETTER AZ",NULL},
/* 0847 */ { "MANDAIC LETTER IT","	= pharyngeal hu"},
/* 0848 */ { "MANDAIC LETTER ATT",NULL},
/* 0849 */ { "MANDAIC LETTER AKSA","	= i"},
/* 084A */ { "MANDAIC LETTER AK",NULL},
/* 084B */ { "MANDAIC LETTER AL",NULL},
/* 084C */ { "MANDAIC LETTER AM",NULL},
/* 084D */ { "MANDAIC LETTER AN",NULL},
/* 084E */ { "MANDAIC LETTER AS",NULL},
/* 084F */ { "MANDAIC LETTER IN",NULL},
/* 0850 */ { "MANDAIC LETTER AP",NULL},
/* 0851 */ { "MANDAIC LETTER ASZ",NULL},
/* 0852 */ { "MANDAIC LETTER AQ",NULL},
/* 0853 */ { "MANDAIC LETTER AR",NULL},
/* 0854 */ { "MANDAIC LETTER ASH",NULL},
/* 0855 */ { "MANDAIC LETTER AT",NULL},
/* 0856 */ { "MANDAIC LETTER DUSHENNA","	= di"},
/* 0857 */ { "MANDAIC LETTER KAD",NULL},
/* 0858 */ { "MANDAIC LETTER AIN",NULL},
/* 0859 */ { "MANDAIC AFFRICATION MARK",NULL},
/* 085A */ { "MANDAIC VOCALIZATION MARK",NULL},
/* 085B */ { "MANDAIC GEMINATION MARK",NULL},
/* 085C */ { NULL,NULL},
/* 085D */ { NULL,NULL},
/* 085E */ { "MANDAIC PUNCTUATION",NULL},
/* 085F */ { NULL,NULL},
/* 0860 */ { "SYRIAC LETTER MALAYALAM NGA","	x (malayalam letter nga - 0D19)"},
/* 0861 */ { "SYRIAC LETTER MALAYALAM JA","	x (malayalam letter ja - 0D1C)"},
/* 0862 */ { "SYRIAC LETTER MALAYALAM NYA","	x (malayalam letter nya - 0D1E)"},
/* 0863 */ { "SYRIAC LETTER MALAYALAM TTA","	x (malayalam letter tta - 0D1F)"},
/* 0864 */ { "SYRIAC LETTER MALAYALAM NNA","	x (malayalam letter nna - 0D23)"},
/* 0865 */ { "SYRIAC LETTER MALAYALAM NNNA","	x (malayalam letter nnna - 0D29)"},
/* 0866 */ { "SYRIAC LETTER MALAYALAM BHA","	x (malayalam letter bha - 0D2D)"},
/* 0867 */ { "SYRIAC LETTER MALAYALAM RA","	x (malayalam letter ra - 0D30)"},
/* 0868 */ { "SYRIAC LETTER MALAYALAM LLA","	x (malayalam letter lla - 0D33)"},
/* 0869 */ { "SYRIAC LETTER MALAYALAM LLLA","	x (malayalam letter llla - 0D34)"},
/* 086A */ { "SYRIAC LETTER MALAYALAM SSA","	x (malayalam letter ssa - 0D37)"},
/* 086B */ { NULL,NULL},
/* 086C */ { NULL,NULL},
/* 086D */ { NULL,NULL},
/* 086E */ { NULL,NULL},
/* 086F */ { NULL,NULL},
/* 0870 */ { "ARABIC LETTER ALEF WITH ATTACHED FATHA",NULL},
/* 0871 */ { "ARABIC LETTER ALEF WITH ATTACHED TOP RIGHT FATHA",NULL},
/* 0872 */ { "ARABIC LETTER ALEF WITH RIGHT MIDDLE STROKE",NULL},
/* 0873 */ { "ARABIC LETTER ALEF WITH LEFT MIDDLE STROKE",NULL},
/* 0874 */ { "ARABIC LETTER ALEF WITH ATTACHED KASRA",NULL},
/* 0875 */ { "ARABIC LETTER ALEF WITH ATTACHED BOTTOM RIGHT KASRA",NULL},
/* 0876 */ { "ARABIC LETTER ALEF WITH ATTACHED ROUND DOT ABOVE",NULL},
/* 0877 */ { "ARABIC LETTER ALEF WITH ATTACHED RIGHT ROUND DOT",NULL},
/* 0878 */ { "ARABIC LETTER ALEF WITH ATTACHED LEFT ROUND DOT",NULL},
/* 0879 */ { "ARABIC LETTER ALEF WITH ATTACHED ROUND DOT BELOW",NULL},
/* 087A */ { "ARABIC LETTER ALEF WITH DOT ABOVE",NULL},
/* 087B */ { "ARABIC LETTER ALEF WITH ATTACHED TOP RIGHT FATHA AND DOT ABOVE",NULL},
/* 087C */ { "ARABIC LETTER ALEF WITH RIGHT MIDDLE STROKE AND DOT ABOVE",NULL},
/* 087D */ { "ARABIC LETTER ALEF WITH ATTACHED BOTTOM RIGHT KASRA AND DOT ABOVE",NULL},
/* 087E */ { "ARABIC LETTER ALEF WITH ATTACHED TOP RIGHT FATHA AND LEFT RING",NULL},
/* 087F */ { "ARABIC LETTER ALEF WITH RIGHT MIDDLE STROKE AND LEFT RING",NULL},
/* 0880 */ { "ARABIC LETTER ALEF WITH ATTACHED BOTTOM RIGHT KASRA AND LEFT RING",NULL},
/* 0881 */ { "ARABIC LETTER ALEF WITH ATTACHED RIGHT HAMZA",NULL},
/* 0882 */ { "ARABIC LETTER ALEF WITH ATTACHED LEFT HAMZA",NULL},
/* 0883 */ { "ARABIC TATWEEL WITH OVERSTRUCK HAMZA",NULL},
/* 0884 */ { "ARABIC TATWEEL WITH OVERSTRUCK WAW",NULL},
/* 0885 */ { "ARABIC TATWEEL WITH TWO DOTS BELOW",NULL},
/* 0886 */ { "ARABIC LETTER THIN YEH","	* no final or isolated forms are attested"},
/* 0887 */ { "ARABIC BASELINE ROUND DOT",NULL},
/* 0888 */ { "ARABIC RAISED ROUND DOT",NULL},
/* 0889 */ { "ARABIC LETTER NOON WITH INVERTED SMALL V",NULL},
/* 088A */ { "ARABIC LETTER HAH WITH INVERTED SMALL V BELOW",NULL},
/* 088B */ { "ARABIC LETTER TAH WITH DOT BELOW","	* Pegon, Malagasy"},
/* 088C */ { "ARABIC LETTER TAH WITH THREE DOTS BELOW","	* Pegon alternative for 088B"},
/* 088D */ { "ARABIC LETTER KEHEH WITH TWO DOTS VERTICALLY BELOW","	* Sundanese Pegon"},
/* 088E */ { "ARABIC VERTICAL TAIL","	* mark used to indicate abbreviations in early movable type texts from Iran \n"
	"	* only attested in final form"},
/* 088F */ { "ARABIC LETTER NOON WITH RING ABOVE","	= arnoon"},
/* 0890 */ { "ARABIC POUND MARK ABOVE","	* Egyptian pound"},
/* 0891 */ { "ARABIC PIASTRE MARK ABOVE","	* Egyptian piastre"},
/* 0892 */ { NULL,NULL},
/* 0893 */ { NULL,NULL},
/* 0894 */ { NULL,NULL},
/* 0895 */ { NULL,NULL},
/* 0896 */ { NULL,NULL},
/* 0897 */ { "ARABIC PEPET","	x (arabic maddah above - 0653)"},
/* 0898 */ { "ARABIC SMALL HIGH WORD AL-JUZ",NULL},
/* 0899 */ { "ARABIC SMALL LOW WORD ISHMAAM",NULL},
/* 089A */ { "ARABIC SMALL LOW WORD IMAALA",NULL},
/* 089B */ { "ARABIC SMALL LOW WORD TASHEEL",NULL},
/* 089C */ { "ARABIC MADDA WAAJIB","	x (arabic maddah above - 0653)"},
/* 089D */ { "ARABIC SUPERSCRIPT ALEF MOKHASSAS",NULL},
/* 089E */ { "ARABIC DOUBLED MADDA",NULL},
/* 089F */ { "ARABIC HALF MADDA OVER MADDA",NULL},
/* 08A0 */ { "ARABIC LETTER BEH WITH SMALL V BELOW",NULL},
/* 08A1 */ { "ARABIC LETTER BEH WITH HAMZA ABOVE","	* Adamawa Fulfulde (Cameroon)\n"
	"	* used for the implosive bilabial stop\n"
	"	x (latin small letter b with hook - 0253)"},
/* 08A2 */ { "ARABIC LETTER JEEM WITH TWO DOTS ABOVE",NULL},
/* 08A3 */ { "ARABIC LETTER TAH WITH TWO DOTS ABOVE",NULL},
/* 08A4 */ { "ARABIC LETTER FEH WITH DOT BELOW AND THREE DOTS ABOVE",NULL},
/* 08A5 */ { "ARABIC LETTER QAF WITH DOT BELOW",NULL},
/* 08A6 */ { "ARABIC LETTER LAM WITH DOUBLE BAR",NULL},
/* 08A7 */ { "ARABIC LETTER MEEM WITH THREE DOTS ABOVE",NULL},
/* 08A8 */ { "ARABIC LETTER YEH WITH TWO DOTS BELOW AND HAMZA ABOVE","	* Adamawa Fulfulde\n"
	"	* used for the implosive palatal approximant, realized as pharyngealization of the approximant\n"
	"	x (latin small letter y with hook - 01B4)"},
/* 08A9 */ { "ARABIC LETTER YEH WITH TWO DOTS BELOW AND DOT ABOVE","	* Adamawa Fulfulde\n"
	"	* used for the voiced palatal nasal\n"
	"	x (latin small letter n with left hook - 0272)"},
/* 08AA */ { "ARABIC LETTER REH WITH LOOP","	= bottya-reh"},
/* 08AB */ { "ARABIC LETTER WAW WITH DOT WITHIN","	= nota-wa"},
/* 08AC */ { "ARABIC LETTER ROHINGYA YEH","	= bottya-yeh"},
/* 08AD */ { "ARABIC LETTER LOW ALEF","	* Bashkir, Tatar"},
/* 08AE */ { "ARABIC LETTER DAL WITH THREE DOTS BELOW","	* Belarusian\n"
	"	* Pegon alternative for 068A"},
/* 08AF */ { "ARABIC LETTER SAD WITH THREE DOTS BELOW","	* Belarusian"},
/* 08B0 */ { "ARABIC LETTER GAF WITH INVERTED STROKE","	* Crimean Tatar, Chechen, Lak"},
/* 08B1 */ { "ARABIC LETTER STRAIGHT WAW","	* Tatar"},
/* 08B2 */ { "ARABIC LETTER ZAIN WITH INVERTED V ABOVE",NULL},
/* 08B3 */ { "ARABIC LETTER AIN WITH THREE DOTS BELOW",NULL},
/* 08B4 */ { "ARABIC LETTER KAF WITH DOT BELOW","	* also used in Pegon\n"
	"	x (arabic letter kaf with three dots below - 06AE)"},
/* 08B5 */ { "ARABIC LETTER QAF WITH DOT BELOW AND NO DOTS ABOVE",NULL},
/* 08B6 */ { "ARABIC LETTER BEH WITH SMALL MEEM ABOVE",NULL},
/* 08B7 */ { "ARABIC LETTER PEH WITH SMALL MEEM ABOVE",NULL},
/* 08B8 */ { "ARABIC LETTER TEH WITH SMALL TEH ABOVE",NULL},
/* 08B9 */ { "ARABIC LETTER REH WITH SMALL NOON ABOVE",NULL},
/* 08BA */ { "ARABIC LETTER YEH WITH TWO DOTS BELOW AND SMALL NOON ABOVE",NULL},
/* 08BB */ { "ARABIC LETTER AFRICAN FEH","	* initial and medial forms have one dot below\n"
	"	x (arabic letter dotless feh - 06A1)\n"
	"	x (arabic letter feh with dot moved below - 06A2)"},
/* 08BC */ { "ARABIC LETTER AFRICAN QAF","	* initial and medial forms have one dot above\n"
	"	x (arabic letter dotless qaf - 066F)\n"
	"	x (arabic letter qaf with dot above - 06A7)\n"
	"	x (arabic letter african qaf with three dots above - 08C4)"},
/* 08BD */ { "ARABIC LETTER AFRICAN NOON","	* initial and medial forms have one dot above\n"
	"	x (arabic letter noon ghunna - 06BA)\n"
	"	x (arabic letter noon - 0646)"},
/* 08BE */ { "ARABIC LETTER PEH WITH SMALL V",NULL},
/* 08BF */ { "ARABIC LETTER TEH WITH SMALL V",NULL},
/* 08C0 */ { "ARABIC LETTER TTEH WITH SMALL V",NULL},
/* 08C1 */ { "ARABIC LETTER TCHEH WITH SMALL V",NULL},
/* 08C2 */ { "ARABIC LETTER KEHEH WITH SMALL V",NULL},
/* 08C3 */ { "ARABIC LETTER GHAIN WITH THREE DOTS ABOVE",NULL},
/* 08C4 */ { "ARABIC LETTER AFRICAN QAF WITH THREE DOTS ABOVE","	* this letter shows an additional single dot above for the qaf only in initial and medial forms\n"
	"	x (arabic letter african qaf - 08BC)"},
/* 08C5 */ { "ARABIC LETTER JEEM WITH THREE DOTS ABOVE",NULL},
/* 08C6 */ { "ARABIC LETTER JEEM WITH THREE DOTS BELOW",NULL},
/* 08C7 */ { "ARABIC LETTER LAM WITH SMALL ARABIC LETTER TAH ABOVE",NULL},
/* 08C8 */ { "ARABIC LETTER GRAF",NULL},
/* 08C9 */ { "ARABIC SMALL FARSI YEH",NULL},
/* 08CA */ { "ARABIC SMALL HIGH FARSI YEH",NULL},
/* 08CB */ { "ARABIC SMALL HIGH YEH BARREE WITH TWO DOTS BELOW","	x (arabic small yeh barree with two dots below - 10EC5)"},
/* 08CC */ { "ARABIC SMALL HIGH WORD SAH","	= sign of waqf"},
/* 08CD */ { "ARABIC SMALL HIGH ZAH",NULL},
/* 08CE */ { "ARABIC LARGE ROUND DOT ABOVE",NULL},
/* 08CF */ { "ARABIC LARGE ROUND DOT BELOW",NULL},
/* 08D0 */ { "ARABIC SUKUN BELOW",NULL},
/* 08D1 */ { "ARABIC LARGE CIRCLE BELOW",NULL},
/* 08D2 */ { "ARABIC LARGE ROUND DOT INSIDE CIRCLE BELOW",NULL},
/* 08D3 */ { "ARABIC SMALL LOW WAW",NULL},
/* 08D4 */ { "ARABIC SMALL HIGH WORD AR-RUB",NULL},
/* 08D5 */ { "ARABIC SMALL HIGH SAD",NULL},
/* 08D6 */ { "ARABIC SMALL HIGH AIN",NULL},
/* 08D7 */ { "ARABIC SMALL HIGH QAF",NULL},
/* 08D8 */ { "ARABIC SMALL HIGH NOON WITH KASRA",NULL},
/* 08D9 */ { "ARABIC SMALL LOW NOON WITH KASRA","	x (arabic small low noon - 10EFB)"},
/* 08DA */ { "ARABIC SMALL HIGH WORD ATH-THALATHA",NULL},
/* 08DB */ { "ARABIC SMALL HIGH WORD AS-SAJDA",NULL},
/* 08DC */ { "ARABIC SMALL HIGH WORD AN-NISF",NULL},
/* 08DD */ { "ARABIC SMALL HIGH WORD SAKTA","	x (arabic small low word sakta - 10EFD)"},
/* 08DE */ { "ARABIC SMALL HIGH WORD QIF",NULL},
/* 08DF */ { "ARABIC SMALL HIGH WORD WAQFA",NULL},
/* 08E0 */ { "ARABIC SMALL HIGH FOOTNOTE MARKER",NULL},
/* 08E1 */ { "ARABIC SMALL HIGH SIGN SAFHA",NULL},
/* 08E2 */ { "ARABIC DISPUTED END OF AYAH",NULL},
/* 08E3 */ { "ARABIC TURNED DAMMA BELOW",NULL},
/* 08E4 */ { "ARABIC CURLY FATHA",NULL},
/* 08E5 */ { "ARABIC CURLY DAMMA",NULL},
/* 08E6 */ { "ARABIC CURLY KASRA",NULL},
/* 08E7 */ { "ARABIC CURLY FATHATAN",NULL},
/* 08E8 */ { "ARABIC CURLY DAMMATAN",NULL},
/* 08E9 */ { "ARABIC CURLY KASRATAN",NULL},
/* 08EA */ { "ARABIC TONE ONE DOT ABOVE",NULL},
/* 08EB */ { "ARABIC TONE TWO DOTS ABOVE",NULL},
/* 08EC */ { "ARABIC TONE LOOP ABOVE",NULL},
/* 08ED */ { "ARABIC TONE ONE DOT BELOW",NULL},
/* 08EE */ { "ARABIC TONE TWO DOTS BELOW",NULL},
/* 08EF */ { "ARABIC TONE LOOP BELOW",NULL},
/* 08F0 */ { "ARABIC OPEN FATHATAN","	= successive fathatan"},
/* 08F1 */ { "ARABIC OPEN DAMMATAN","	= successive dammatan"},
/* 08F2 */ { "ARABIC OPEN KASRATAN","	= successive kasratan"},
/* 08F3 */ { "ARABIC SMALL HIGH WAW",NULL},
/* 08F4 */ { "ARABIC FATHA WITH RING",NULL},
/* 08F5 */ { "ARABIC FATHA WITH DOT ABOVE",NULL},
/* 08F6 */ { "ARABIC KASRA WITH DOT BELOW","	* also used in Philippine languages"},
/* 08F7 */ { "ARABIC LEFT ARROWHEAD ABOVE",NULL},
/* 08F8 */ { "ARABIC RIGHT ARROWHEAD ABOVE","	* also used in Quranic text in African and other orthographies to represent damma"},
/* 08F9 */ { "ARABIC LEFT ARROWHEAD BELOW",NULL},
/* 08FA */ { "ARABIC RIGHT ARROWHEAD BELOW",NULL},
/* 08FB */ { "ARABIC DOUBLE RIGHT ARROWHEAD ABOVE","	* also used in Quranic text in African and other orthographies to represent dammatan"},
/* 08FC */ { "ARABIC DOUBLE RIGHT ARROWHEAD ABOVE WITH DOT",NULL},
/* 08FD */ { "ARABIC RIGHT ARROWHEAD ABOVE WITH DOT",NULL},
/* 08FE */ { "ARABIC DAMMA WITH DOT","	* Philippine languages"},
/* 08FF */ { "ARABIC MARK SIDEWAYS NOON GHUNNA",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_00_09[] = {
/* 0900 */ { "DEVANAGARI SIGN INVERTED CANDRABINDU","	= vaidika adhomukha candrabindu"},
/* 0901 */ { "DEVANAGARI SIGN CANDRABINDU","	= anunasika\n"
	"	x (combining candrabindu - 0310)"},
/* 0902 */ { "DEVANAGARI SIGN ANUSVARA","	= bindu"},
/* 0903 */ { "DEVANAGARI SIGN VISARGA",NULL},
/* 0904 */ { "DEVANAGARI LETTER SHORT A","	* used for short e in Awadhi\n"
	"	* also used in Devanagari transliterations of some South Indian and Kashmiri languages by a publisher in Lucknow"},
/* 0905 */ { "DEVANAGARI LETTER A",NULL},
/* 0906 */ { "DEVANAGARI LETTER AA",NULL},
/* 0907 */ { "DEVANAGARI LETTER I",NULL},
/* 0908 */ { "DEVANAGARI LETTER II",NULL},
/* 0909 */ { "DEVANAGARI LETTER U",NULL},
/* 090A */ { "DEVANAGARI LETTER UU",NULL},
/* 090B */ { "DEVANAGARI LETTER VOCALIC R",NULL},
/* 090C */ { "DEVANAGARI LETTER VOCALIC L",NULL},
/* 090D */ { "DEVANAGARI LETTER CANDRA E",NULL},
/* 090E */ { "DEVANAGARI LETTER SHORT E","	* Kashmiri, Bihari languages\n"
	"	* also used for transcribing Dravidian short e"},
/* 090F */ { "DEVANAGARI LETTER E",NULL},
/* 0910 */ { "DEVANAGARI LETTER AI",NULL},
/* 0911 */ { "DEVANAGARI LETTER CANDRA O",NULL},
/* 0912 */ { "DEVANAGARI LETTER SHORT O","	* Kashmiri, Bihari languages\n"
	"	* also used for transcribing Dravidian short o"},
/* 0913 */ { "DEVANAGARI LETTER O",NULL},
/* 0914 */ { "DEVANAGARI LETTER AU",NULL},
/* 0915 */ { "DEVANAGARI LETTER KA",NULL},
/* 0916 */ { "DEVANAGARI LETTER KHA",NULL},
/* 0917 */ { "DEVANAGARI LETTER GA",NULL},
/* 0918 */ { "DEVANAGARI LETTER GHA",NULL},
/* 0919 */ { "DEVANAGARI LETTER NGA",NULL},
/* 091A */ { "DEVANAGARI LETTER CA",NULL},
/* 091B */ { "DEVANAGARI LETTER CHA",NULL},
/* 091C */ { "DEVANAGARI LETTER JA",NULL},
/* 091D */ { "DEVANAGARI LETTER JHA",NULL},
/* 091E */ { "DEVANAGARI LETTER NYA",NULL},
/* 091F */ { "DEVANAGARI LETTER TTA",NULL},
/* 0920 */ { "DEVANAGARI LETTER TTHA",NULL},
/* 0921 */ { "DEVANAGARI LETTER DDA",NULL},
/* 0922 */ { "DEVANAGARI LETTER DDHA",NULL},
/* 0923 */ { "DEVANAGARI LETTER NNA",NULL},
/* 0924 */ { "DEVANAGARI LETTER TA",NULL},
/* 0925 */ { "DEVANAGARI LETTER THA",NULL},
/* 0926 */ { "DEVANAGARI LETTER DA",NULL},
/* 0927 */ { "DEVANAGARI LETTER DHA",NULL},
/* 0928 */ { "DEVANAGARI LETTER NA",NULL},
/* 0929 */ { "DEVANAGARI LETTER NNNA","	* for transcribing Dravidian alveolar n\n"
	"	: 0928 093C"},
/* 092A */ { "DEVANAGARI LETTER PA",NULL},
/* 092B */ { "DEVANAGARI LETTER PHA",NULL},
/* 092C */ { "DEVANAGARI LETTER BA",NULL},
/* 092D */ { "DEVANAGARI LETTER BHA",NULL},
/* 092E */ { "DEVANAGARI LETTER MA",NULL},
/* 092F */ { "DEVANAGARI LETTER YA",NULL},
/* 0930 */ { "DEVANAGARI LETTER RA",NULL},
/* 0931 */ { "DEVANAGARI LETTER RRA","	* for transcribing Dravidian alveolar r\n"
	"	* half form is represented as \"Eyelash RA\"\n"
	"	: 0930 093C"},
/* 0932 */ { "DEVANAGARI LETTER LA",NULL},
/* 0933 */ { "DEVANAGARI LETTER LLA",NULL},
/* 0934 */ { "DEVANAGARI LETTER LLLA","	* for transcribing Dravidian l\n"
	"	: 0933 093C"},
/* 0935 */ { "DEVANAGARI LETTER VA",NULL},
/* 0936 */ { "DEVANAGARI LETTER SHA",NULL},
/* 0937 */ { "DEVANAGARI LETTER SSA",NULL},
/* 0938 */ { "DEVANAGARI LETTER SA",NULL},
/* 0939 */ { "DEVANAGARI LETTER HA",NULL},
/* 093A */ { "DEVANAGARI VOWEL SIGN OE",NULL},
/* 093B */ { "DEVANAGARI VOWEL SIGN OOE",NULL},
/* 093C */ { "DEVANAGARI SIGN NUKTA","	* for extending the alphabet to new letters"},
/* 093D */ { "DEVANAGARI SIGN AVAGRAHA",NULL},
/* 093E */ { "DEVANAGARI VOWEL SIGN AA",NULL},
/* 093F */ { "DEVANAGARI VOWEL SIGN I","	* stands to the left of the consonant"},
/* 0940 */ { "DEVANAGARI VOWEL SIGN II",NULL},
/* 0941 */ { "DEVANAGARI VOWEL SIGN U",NULL},
/* 0942 */ { "DEVANAGARI VOWEL SIGN UU",NULL},
/* 0943 */ { "DEVANAGARI VOWEL SIGN VOCALIC R",NULL},
/* 0944 */ { "DEVANAGARI VOWEL SIGN VOCALIC RR",NULL},
/* 0945 */ { "DEVANAGARI VOWEL SIGN CANDRA E","	= candra"},
/* 0946 */ { "DEVANAGARI VOWEL SIGN SHORT E","	* Kashmiri, Bihari languages\n"
	"	* also used for transcribing Dravidian short e"},
/* 0947 */ { "DEVANAGARI VOWEL SIGN E",NULL},
/* 0948 */ { "DEVANAGARI VOWEL SIGN AI",NULL},
/* 0949 */ { "DEVANAGARI VOWEL SIGN CANDRA O",NULL},
/* 094A */ { "DEVANAGARI VOWEL SIGN SHORT O","	* Kashmiri, Bihari languages\n"
	"	* also used for transcribing Dravidian short o"},
/* 094B */ { "DEVANAGARI VOWEL SIGN O",NULL},
/* 094C */ { "DEVANAGARI VOWEL SIGN AU",NULL},
/* 094D */ { "DEVANAGARI SIGN VIRAMA","	= halant (the preferred Hindi name)\n"
	"	* suppresses inherent vowel"},
/* 094E */ { "DEVANAGARI VOWEL SIGN PRISHTHAMATRA E","	* character has historic use only\n"
	"	* combines with E to form AI, with AA to form O, and with O to form AU"},
/* 094F */ { "DEVANAGARI VOWEL SIGN AW","	* Kashmiri, Bihari languages"},
/* 0950 */ { "DEVANAGARI OM","	x (om symbol - 1F549)"},
/* 0951 */ { "DEVANAGARI STRESS SIGN UDATTA","	= Vedic tone svarita\n"
	"	* mostly used for svarita, with rare use for udatta\n"
	"	* used also in Vedic texts written in other scripts\n"
	"	x (vedic tone double svarita - 1CDA)"},
/* 0952 */ { "DEVANAGARI STRESS SIGN ANUDATTA","	= Vedic tone anudatta\n"
	"	* used also in Vedic texts written in other scripts\n"
	"	x (vedic tone kathaka anudatta - 1CDC)"},
/* 0953 */ { "DEVANAGARI GRAVE ACCENT","	x (combining grave accent - 0300)"},
/* 0954 */ { "DEVANAGARI ACUTE ACCENT","	x (combining acute accent - 0301)"},
/* 0955 */ { "DEVANAGARI VOWEL SIGN CANDRA LONG E","	* used in transliteration of Avestan"},
/* 0956 */ { "DEVANAGARI VOWEL SIGN UE",NULL},
/* 0957 */ { "DEVANAGARI VOWEL SIGN UUE",NULL},
/* 0958 */ { "DEVANAGARI LETTER QA","	: 0915 093C"},
/* 0959 */ { "DEVANAGARI LETTER KHHA","	: 0916 093C"},
/* 095A */ { "DEVANAGARI LETTER GHHA","	: 0917 093C"},
/* 095B */ { "DEVANAGARI LETTER ZA","	: 091C 093C"},
/* 095C */ { "DEVANAGARI LETTER DDDHA","	: 0921 093C"},
/* 095D */ { "DEVANAGARI LETTER RHA","	: 0922 093C"},
/* 095E */ { "DEVANAGARI LETTER FA","	: 092B 093C"},
/* 095F */ { "DEVANAGARI LETTER YYA","	: 092F 093C"},
/* 0960 */ { "DEVANAGARI LETTER VOCALIC RR",NULL},
/* 0961 */ { "DEVANAGARI LETTER VOCALIC LL",NULL},
/* 0962 */ { "DEVANAGARI VOWEL SIGN VOCALIC L",NULL},
/* 0963 */ { "DEVANAGARI VOWEL SIGN VOCALIC LL",NULL},
/* 0964 */ { "DEVANAGARI DANDA","	= purna viram\n"
	"	* phrase separator"},
/* 0965 */ { "DEVANAGARI DOUBLE DANDA","	= deergh viram"},
/* 0966 */ { "DEVANAGARI DIGIT ZERO","	* also used to represent an anusvara following digits indicating secondary svara-s in Samavedic texts"},
/* 0967 */ { "DEVANAGARI DIGIT ONE",NULL},
/* 0968 */ { "DEVANAGARI DIGIT TWO",NULL},
/* 0969 */ { "DEVANAGARI DIGIT THREE",NULL},
/* 096A */ { "DEVANAGARI DIGIT FOUR",NULL},
/* 096B */ { "DEVANAGARI DIGIT FIVE",NULL},
/* 096C */ { "DEVANAGARI DIGIT SIX",NULL},
/* 096D */ { "DEVANAGARI DIGIT SEVEN",NULL},
/* 096E */ { "DEVANAGARI DIGIT EIGHT",NULL},
/* 096F */ { "DEVANAGARI DIGIT NINE",NULL},
/* 0970 */ { "DEVANAGARI ABBREVIATION SIGN","	* intended for Devanagari-specific abbreviations"},
/* 0971 */ { "DEVANAGARI SIGN HIGH SPACING DOT",NULL},
/* 0972 */ { "DEVANAGARI LETTER CANDRA A",NULL},
/* 0973 */ { "DEVANAGARI LETTER OE",NULL},
/* 0974 */ { "DEVANAGARI LETTER OOE",NULL},
/* 0975 */ { "DEVANAGARI LETTER AW",NULL},
/* 0976 */ { "DEVANAGARI LETTER UE",NULL},
/* 0977 */ { "DEVANAGARI LETTER UUE",NULL},
/* 0978 */ { "DEVANAGARI LETTER MARWARI DDA",NULL},
/* 0979 */ { "DEVANAGARI LETTER ZHA","	* used in transliteration of Avestan\n"
	"	x (gujarati letter zha - 0AF9)"},
/* 097A */ { "DEVANAGARI LETTER HEAVY YA","	* used for an affricated glide JJYA"},
/* 097B */ { "DEVANAGARI LETTER GGA",NULL},
/* 097C */ { "DEVANAGARI LETTER JJA",NULL},
/* 097D */ { "DEVANAGARI LETTER GLOTTAL STOP","	* used for writing Limbu in Devanagari\n"
	"	* a glyph variant has the connecting top bar"},
/* 097E */ { "DEVANAGARI LETTER DDDA",NULL},
/* 097F */ { "DEVANAGARI LETTER BBA",NULL},
/* 0980 */ { "BENGALI ANJI","	= siddham, siddhirastu\n"
	"	* used at the beginning of texts as an invocation"},
/* 0981 */ { "BENGALI SIGN CANDRABINDU",NULL},
/* 0982 */ { "BENGALI SIGN ANUSVARA",NULL},
/* 0983 */ { "BENGALI SIGN VISARGA",NULL},
/* 0984 */ { NULL,NULL},
/* 0985 */ { "BENGALI LETTER A",NULL},
/* 0986 */ { "BENGALI LETTER AA",NULL},
/* 0987 */ { "BENGALI LETTER I",NULL},
/* 0988 */ { "BENGALI LETTER II",NULL},
/* 0989 */ { "BENGALI LETTER U",NULL},
/* 098A */ { "BENGALI LETTER UU",NULL},
/* 098B */ { "BENGALI LETTER VOCALIC R",NULL},
/* 098C */ { "BENGALI LETTER VOCALIC L",NULL},
/* 098D */ { NULL,NULL},
/* 098E */ { NULL,NULL},
/* 098F */ { "BENGALI LETTER E",NULL},
/* 0990 */ { "BENGALI LETTER AI",NULL},
/* 0991 */ { NULL,NULL},
/* 0992 */ { NULL,NULL},
/* 0993 */ { "BENGALI LETTER O",NULL},
/* 0994 */ { "BENGALI LETTER AU",NULL},
/* 0995 */ { "BENGALI LETTER KA",NULL},
/* 0996 */ { "BENGALI LETTER KHA",NULL},
/* 0997 */ { "BENGALI LETTER GA",NULL},
/* 0998 */ { "BENGALI LETTER GHA",NULL},
/* 0999 */ { "BENGALI LETTER NGA",NULL},
/* 099A */ { "BENGALI LETTER CA",NULL},
/* 099B */ { "BENGALI LETTER CHA",NULL},
/* 099C */ { "BENGALI LETTER JA",NULL},
/* 099D */ { "BENGALI LETTER JHA",NULL},
/* 099E */ { "BENGALI LETTER NYA",NULL},
/* 099F */ { "BENGALI LETTER TTA",NULL},
/* 09A0 */ { "BENGALI LETTER TTHA",NULL},
/* 09A1 */ { "BENGALI LETTER DDA",NULL},
/* 09A2 */ { "BENGALI LETTER DDHA",NULL},
/* 09A3 */ { "BENGALI LETTER NNA",NULL},
/* 09A4 */ { "BENGALI LETTER TA",NULL},
/* 09A5 */ { "BENGALI LETTER THA",NULL},
/* 09A6 */ { "BENGALI LETTER DA",NULL},
/* 09A7 */ { "BENGALI LETTER DHA",NULL},
/* 09A8 */ { "BENGALI LETTER NA",NULL},
/* 09A9 */ { NULL,NULL},
/* 09AA */ { "BENGALI LETTER PA",NULL},
/* 09AB */ { "BENGALI LETTER PHA",NULL},
/* 09AC */ { "BENGALI LETTER BA","	= Bengali va, wa"},
/* 09AD */ { "BENGALI LETTER BHA",NULL},
/* 09AE */ { "BENGALI LETTER MA",NULL},
/* 09AF */ { "BENGALI LETTER YA",NULL},
/* 09B0 */ { "BENGALI LETTER RA",NULL},
/* 09B1 */ { NULL,NULL},
/* 09B2 */ { "BENGALI LETTER LA",NULL},
/* 09B3 */ { NULL,NULL},
/* 09B4 */ { NULL,NULL},
/* 09B5 */ { NULL,NULL},
/* 09B6 */ { "BENGALI LETTER SHA",NULL},
/* 09B7 */ { "BENGALI LETTER SSA",NULL},
/* 09B8 */ { "BENGALI LETTER SA",NULL},
/* 09B9 */ { "BENGALI LETTER HA",NULL},
/* 09BA */ { NULL,NULL},
/* 09BB */ { NULL,NULL},
/* 09BC */ { "BENGALI SIGN NUKTA","	* for extending the alphabet to new letters"},
/* 09BD */ { "BENGALI SIGN AVAGRAHA",NULL},
/* 09BE */ { "BENGALI VOWEL SIGN AA",NULL},
/* 09BF */ { "BENGALI VOWEL SIGN I","	* stands to the left of the consonant"},
/* 09C0 */ { "BENGALI VOWEL SIGN II",NULL},
/* 09C1 */ { "BENGALI VOWEL SIGN U",NULL},
/* 09C2 */ { "BENGALI VOWEL SIGN UU",NULL},
/* 09C3 */ { "BENGALI VOWEL SIGN VOCALIC R",NULL},
/* 09C4 */ { "BENGALI VOWEL SIGN VOCALIC RR",NULL},
/* 09C5 */ { NULL,NULL},
/* 09C6 */ { NULL,NULL},
/* 09C7 */ { "BENGALI VOWEL SIGN E","	* stands to the left of the consonant"},
/* 09C8 */ { "BENGALI VOWEL SIGN AI","	* stands to the left of the consonant"},
/* 09C9 */ { NULL,NULL},
/* 09CA */ { NULL,NULL},
/* 09CB */ { "BENGALI VOWEL SIGN O","	: 09C7 09BE"},
/* 09CC */ { "BENGALI VOWEL SIGN AU","	: 09C7 09D7"},
/* 09CD */ { "BENGALI SIGN VIRAMA","	= hasant (Bengali term for halant)"},
/* 09CE */ { "BENGALI LETTER KHANDA TA","	* a dead consonant form of ta, without implicit vowel, used in some sequences"},
/* 09CF */ { NULL,NULL},
/* 09D0 */ { NULL,NULL},
/* 09D1 */ { NULL,NULL},
/* 09D2 */ { NULL,NULL},
/* 09D3 */ { NULL,NULL},
/* 09D4 */ { NULL,NULL},
/* 09D5 */ { NULL,NULL},
/* 09D6 */ { NULL,NULL},
/* 09D7 */ { "BENGALI AU LENGTH MARK",NULL},
/* 09D8 */ { NULL,NULL},
/* 09D9 */ { NULL,NULL},
/* 09DA */ { NULL,NULL},
/* 09DB */ { NULL,NULL},
/* 09DC */ { "BENGALI LETTER RRA","	: 09A1 09BC"},
/* 09DD */ { "BENGALI LETTER RHA","	: 09A2 09BC"},
/* 09DE */ { NULL,NULL},
/* 09DF */ { "BENGALI LETTER YYA","	: 09AF 09BC"},
/* 09E0 */ { "BENGALI LETTER VOCALIC RR",NULL},
/* 09E1 */ { "BENGALI LETTER VOCALIC LL",NULL},
/* 09E2 */ { "BENGALI VOWEL SIGN VOCALIC L",NULL},
/* 09E3 */ { "BENGALI VOWEL SIGN VOCALIC LL",NULL},
/* 09E4 */ { NULL,"	x (devanagari danda - 0964)"},
/* 09E5 */ { NULL,"	x (devanagari double danda - 0965)"},
/* 09E6 */ { "BENGALI DIGIT ZERO",NULL},
/* 09E7 */ { "BENGALI DIGIT ONE",NULL},
/* 09E8 */ { "BENGALI DIGIT TWO",NULL},
/* 09E9 */ { "BENGALI DIGIT THREE",NULL},
/* 09EA */ { "BENGALI DIGIT FOUR",NULL},
/* 09EB */ { "BENGALI DIGIT FIVE",NULL},
/* 09EC */ { "BENGALI DIGIT SIX",NULL},
/* 09ED */ { "BENGALI DIGIT SEVEN",NULL},
/* 09EE */ { "BENGALI DIGIT EIGHT",NULL},
/* 09EF */ { "BENGALI DIGIT NINE",NULL},
/* 09F0 */ { "BENGALI LETTER RA WITH MIDDLE DIAGONAL","	= Assamese letter ra"},
/* 09F1 */ { "BENGALI LETTER RA WITH LOWER DIAGONAL","	= Assamese letter wa\n"
	"	= bengali letter va with lower diagonal (1.0)"},
/* 09F2 */ { "BENGALI RUPEE MARK","	= taka\n"
	"	* historic currency sign"},
/* 09F3 */ { "BENGALI RUPEE SIGN","	= Bangladeshi taka"},
/* 09F4 */ { "BENGALI CURRENCY NUMERATOR ONE","	* not in current usage"},
/* 09F5 */ { "BENGALI CURRENCY NUMERATOR TWO","	* not in current usage"},
/* 09F6 */ { "BENGALI CURRENCY NUMERATOR THREE","	* not in current usage"},
/* 09F7 */ { "BENGALI CURRENCY NUMERATOR FOUR",NULL},
/* 09F8 */ { "BENGALI CURRENCY NUMERATOR ONE LESS THAN THE DENOMINATOR",NULL},
/* 09F9 */ { "BENGALI CURRENCY DENOMINATOR SIXTEEN",NULL},
/* 09FA */ { "BENGALI ISSHAR","	= ishvar\n"
	"	* represents the name of a deity\n"
	"	= svargiya\n"
	"	* written before the name of a deceased person"},
/* 09FB */ { "BENGALI GANDA MARK",NULL},
/* 09FC */ { "BENGALI LETTER VEDIC ANUSVARA",NULL},
/* 09FD */ { "BENGALI ABBREVIATION SIGN",NULL},
/* 09FE */ { "BENGALI SANDHI MARK","	* indicates external sandhi in Sanskrit documents\n"
	"	x (bengali sign avagraha - 09BD)\n"
	"	x (sharada sandhi mark - 111C9)\n"
	"	x (newa sandhi mark - 1145E)"},
/* 09FF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_00_0A[] = {
/* 0A00 */ { NULL,NULL},
/* 0A01 */ { "GURMUKHI SIGN ADAK BINDI",NULL},
/* 0A02 */ { "GURMUKHI SIGN BINDI",NULL},
/* 0A03 */ { "GURMUKHI SIGN VISARGA",NULL},
/* 0A04 */ { NULL,NULL},
/* 0A05 */ { "GURMUKHI LETTER A","	= aira"},
/* 0A06 */ { "GURMUKHI LETTER AA",NULL},
/* 0A07 */ { "GURMUKHI LETTER I",NULL},
/* 0A08 */ { "GURMUKHI LETTER II",NULL},
/* 0A09 */ { "GURMUKHI LETTER U",NULL},
/* 0A0A */ { "GURMUKHI LETTER UU",NULL},
/* 0A0B */ { NULL,NULL},
/* 0A0C */ { NULL,NULL},
/* 0A0D */ { NULL,NULL},
/* 0A0E */ { NULL,NULL},
/* 0A0F */ { "GURMUKHI LETTER EE",NULL},
/* 0A10 */ { "GURMUKHI LETTER AI",NULL},
/* 0A11 */ { NULL,NULL},
/* 0A12 */ { NULL,NULL},
/* 0A13 */ { "GURMUKHI LETTER OO",NULL},
/* 0A14 */ { "GURMUKHI LETTER AU",NULL},
/* 0A15 */ { "GURMUKHI LETTER KA",NULL},
/* 0A16 */ { "GURMUKHI LETTER KHA",NULL},
/* 0A17 */ { "GURMUKHI LETTER GA",NULL},
/* 0A18 */ { "GURMUKHI LETTER GHA",NULL},
/* 0A19 */ { "GURMUKHI LETTER NGA",NULL},
/* 0A1A */ { "GURMUKHI LETTER CA",NULL},
/* 0A1B */ { "GURMUKHI LETTER CHA",NULL},
/* 0A1C */ { "GURMUKHI LETTER JA",NULL},
/* 0A1D */ { "GURMUKHI LETTER JHA",NULL},
/* 0A1E */ { "GURMUKHI LETTER NYA",NULL},
/* 0A1F */ { "GURMUKHI LETTER TTA",NULL},
/* 0A20 */ { "GURMUKHI LETTER TTHA",NULL},
/* 0A21 */ { "GURMUKHI LETTER DDA",NULL},
/* 0A22 */ { "GURMUKHI LETTER DDHA",NULL},
/* 0A23 */ { "GURMUKHI LETTER NNA",NULL},
/* 0A24 */ { "GURMUKHI LETTER TA",NULL},
/* 0A25 */ { "GURMUKHI LETTER THA",NULL},
/* 0A26 */ { "GURMUKHI LETTER DA",NULL},
/* 0A27 */ { "GURMUKHI LETTER DHA",NULL},
/* 0A28 */ { "GURMUKHI LETTER NA",NULL},
/* 0A29 */ { NULL,NULL},
/* 0A2A */ { "GURMUKHI LETTER PA",NULL},
/* 0A2B */ { "GURMUKHI LETTER PHA",NULL},
/* 0A2C */ { "GURMUKHI LETTER BA",NULL},
/* 0A2D */ { "GURMUKHI LETTER BHA",NULL},
/* 0A2E */ { "GURMUKHI LETTER MA",NULL},
/* 0A2F */ { "GURMUKHI LETTER YA",NULL},
/* 0A30 */ { "GURMUKHI LETTER RA",NULL},
/* 0A31 */ { NULL,NULL},
/* 0A32 */ { "GURMUKHI LETTER LA",NULL},
/* 0A33 */ { "GURMUKHI LETTER LLA","	: 0A32 0A3C\n"
	"		This consonant with nukta is listed in CompositionExclusions.txt. That means that it does not recompose during normalization. The NFC form is the same as the decomposed sequence."},
/* 0A34 */ { NULL,NULL},
/* 0A35 */ { "GURMUKHI LETTER VA",NULL},
/* 0A36 */ { "GURMUKHI LETTER SHA","	: 0A38 0A3C\n"
	"		This consonant with nukta is listed in CompositionExclusions.txt. That means that it does not recompose during normalization. The NFC form is the same as the decomposed sequence."},
/* 0A37 */ { NULL,NULL},
/* 0A38 */ { "GURMUKHI LETTER SA",NULL},
/* 0A39 */ { "GURMUKHI LETTER HA",NULL},
/* 0A3A */ { NULL,NULL},
/* 0A3B */ { NULL,NULL},
/* 0A3C */ { "GURMUKHI SIGN NUKTA","	= pairin bindi\n"
	"	* for extending the alphabet to new letters"},
/* 0A3D */ { NULL,NULL},
/* 0A3E */ { "GURMUKHI VOWEL SIGN AA","	= kanna"},
/* 0A3F */ { "GURMUKHI VOWEL SIGN I","	= sihari\n"
	"	* stands to the left of the consonant"},
/* 0A40 */ { "GURMUKHI VOWEL SIGN II","	= bihari"},
/* 0A41 */ { "GURMUKHI VOWEL SIGN U","	= aunkar"},
/* 0A42 */ { "GURMUKHI VOWEL SIGN UU","	= dulainkar"},
/* 0A43 */ { NULL,NULL},
/* 0A44 */ { NULL,NULL},
/* 0A45 */ { NULL,NULL},
/* 0A46 */ { NULL,NULL},
/* 0A47 */ { "GURMUKHI VOWEL SIGN EE","	= lanvan"},
/* 0A48 */ { "GURMUKHI VOWEL SIGN AI","	= dulanvan"},
/* 0A49 */ { NULL,NULL},
/* 0A4A */ { NULL,NULL},
/* 0A4B */ { "GURMUKHI VOWEL SIGN OO","	= hora"},
/* 0A4C */ { "GURMUKHI VOWEL SIGN AU","	= kanaura"},
/* 0A4D */ { "GURMUKHI SIGN VIRAMA",NULL},
/* 0A4E */ { NULL,NULL},
/* 0A4F */ { NULL,NULL},
/* 0A50 */ { NULL,NULL},
/* 0A51 */ { "GURMUKHI SIGN UDAAT",NULL},
/* 0A52 */ { NULL,NULL},
/* 0A53 */ { NULL,NULL},
/* 0A54 */ { NULL,NULL},
/* 0A55 */ { NULL,NULL},
/* 0A56 */ { NULL,NULL},
/* 0A57 */ { NULL,NULL},
/* 0A58 */ { NULL,NULL},
/* 0A59 */ { "GURMUKHI LETTER KHHA","	: 0A16 0A3C"},
/* 0A5A */ { "GURMUKHI LETTER GHHA","	: 0A17 0A3C"},
/* 0A5B */ { "GURMUKHI LETTER ZA","	: 0A1C 0A3C"},
/* 0A5C */ { "GURMUKHI LETTER RRA",NULL},
/* 0A5D */ { NULL,NULL},
/* 0A5E */ { "GURMUKHI LETTER FA","	: 0A2B 0A3C"},
/* 0A5F */ { NULL,NULL},
/* 0A60 */ { NULL,NULL},
/* 0A61 */ { NULL,NULL},
/* 0A62 */ { NULL,NULL},
/* 0A63 */ { NULL,NULL},
/* 0A64 */ { NULL,"	x (devanagari danda - 0964)"},
/* 0A65 */ { NULL,"	x (devanagari double danda - 0965)"},
/* 0A66 */ { "GURMUKHI DIGIT ZERO",NULL},
/* 0A67 */ { "GURMUKHI DIGIT ONE",NULL},
/* 0A68 */ { "GURMUKHI DIGIT TWO",NULL},
/* 0A69 */ { "GURMUKHI DIGIT THREE",NULL},
/* 0A6A */ { "GURMUKHI DIGIT FOUR",NULL},
/* 0A6B */ { "GURMUKHI DIGIT FIVE",NULL},
/* 0A6C */ { "GURMUKHI DIGIT SIX",NULL},
/* 0A6D */ { "GURMUKHI DIGIT SEVEN",NULL},
/* 0A6E */ { "GURMUKHI DIGIT EIGHT",NULL},
/* 0A6F */ { "GURMUKHI DIGIT NINE",NULL},
/* 0A70 */ { "GURMUKHI TIPPI","	* nasalization"},
/* 0A71 */ { "GURMUKHI ADDAK","	* doubles following consonant"},
/* 0A72 */ { "GURMUKHI IRI",NULL},
/* 0A73 */ { "GURMUKHI URA",NULL},
/* 0A74 */ { "GURMUKHI EK ONKAR","	* God is One"},
/* 0A75 */ { "GURMUKHI SIGN YAKASH","	* some fonts use an alternate glyph shaped more like the lower part of 0A2F"},
/* 0A76 */ { "GURMUKHI ABBREVIATION SIGN","	x (sharada abbreviation sign - 111C7)"},
/* 0A77 */ { NULL,NULL},
/* 0A78 */ { NULL,NULL},
/* 0A79 */ { NULL,NULL},
/* 0A7A */ { NULL,NULL},
/* 0A7B */ { NULL,NULL},
/* 0A7C */ { NULL,NULL},
/* 0A7D */ { NULL,NULL},
/* 0A7E */ { NULL,NULL},
/* 0A7F */ { NULL,NULL},
/* 0A80 */ { NULL,NULL},
/* 0A81 */ { "GUJARATI SIGN CANDRABINDU",NULL},
/* 0A82 */ { "GUJARATI SIGN ANUSVARA",NULL},
/* 0A83 */ { "GUJARATI SIGN VISARGA",NULL},
/* 0A84 */ { NULL,NULL},
/* 0A85 */ { "GUJARATI LETTER A",NULL},
/* 0A86 */ { "GUJARATI LETTER AA",NULL},
/* 0A87 */ { "GUJARATI LETTER I",NULL},
/* 0A88 */ { "GUJARATI LETTER II",NULL},
/* 0A89 */ { "GUJARATI LETTER U",NULL},
/* 0A8A */ { "GUJARATI LETTER UU",NULL},
/* 0A8B */ { "GUJARATI LETTER VOCALIC R",NULL},
/* 0A8C */ { "GUJARATI LETTER VOCALIC L","	* used with Sanskrit text"},
/* 0A8D */ { "GUJARATI VOWEL CANDRA E",NULL},
/* 0A8E */ { NULL,NULL},
/* 0A8F */ { "GUJARATI LETTER E",NULL},
/* 0A90 */ { "GUJARATI LETTER AI",NULL},
/* 0A91 */ { "GUJARATI VOWEL CANDRA O",NULL},
/* 0A92 */ { NULL,NULL},
/* 0A93 */ { "GUJARATI LETTER O",NULL},
/* 0A94 */ { "GUJARATI LETTER AU",NULL},
/* 0A95 */ { "GUJARATI LETTER KA",NULL},
/* 0A96 */ { "GUJARATI LETTER KHA",NULL},
/* 0A97 */ { "GUJARATI LETTER GA",NULL},
/* 0A98 */ { "GUJARATI LETTER GHA",NULL},
/* 0A99 */ { "GUJARATI LETTER NGA",NULL},
/* 0A9A */ { "GUJARATI LETTER CA",NULL},
/* 0A9B */ { "GUJARATI LETTER CHA",NULL},
/* 0A9C */ { "GUJARATI LETTER JA",NULL},
/* 0A9D */ { "GUJARATI LETTER JHA",NULL},
/* 0A9E */ { "GUJARATI LETTER NYA",NULL},
/* 0A9F */ { "GUJARATI LETTER TTA",NULL},
/* 0AA0 */ { "GUJARATI LETTER TTHA",NULL},
/* 0AA1 */ { "GUJARATI LETTER DDA",NULL},
/* 0AA2 */ { "GUJARATI LETTER DDHA",NULL},
/* 0AA3 */ { "GUJARATI LETTER NNA",NULL},
/* 0AA4 */ { "GUJARATI LETTER TA",NULL},
/* 0AA5 */ { "GUJARATI LETTER THA",NULL},
/* 0AA6 */ { "GUJARATI LETTER DA",NULL},
/* 0AA7 */ { "GUJARATI LETTER DHA",NULL},
/* 0AA8 */ { "GUJARATI LETTER NA",NULL},
/* 0AA9 */ { NULL,NULL},
/* 0AAA */ { "GUJARATI LETTER PA",NULL},
/* 0AAB */ { "GUJARATI LETTER PHA",NULL},
/* 0AAC */ { "GUJARATI LETTER BA",NULL},
/* 0AAD */ { "GUJARATI LETTER BHA",NULL},
/* 0AAE */ { "GUJARATI LETTER MA",NULL},
/* 0AAF */ { "GUJARATI LETTER YA",NULL},
/* 0AB0 */ { "GUJARATI LETTER RA",NULL},
/* 0AB1 */ { NULL,NULL},
/* 0AB2 */ { "GUJARATI LETTER LA",NULL},
/* 0AB3 */ { "GUJARATI LETTER LLA",NULL},
/* 0AB4 */ { NULL,NULL},
/* 0AB5 */ { "GUJARATI LETTER VA",NULL},
/* 0AB6 */ { "GUJARATI LETTER SHA",NULL},
/* 0AB7 */ { "GUJARATI LETTER SSA",NULL},
/* 0AB8 */ { "GUJARATI LETTER SA",NULL},
/* 0AB9 */ { "GUJARATI LETTER HA",NULL},
/* 0ABA */ { NULL,NULL},
/* 0ABB */ { NULL,NULL},
/* 0ABC */ { "GUJARATI SIGN NUKTA","	* for extending the alphabet to new letters"},
/* 0ABD */ { "GUJARATI SIGN AVAGRAHA",NULL},
/* 0ABE */ { "GUJARATI VOWEL SIGN AA",NULL},
/* 0ABF */ { "GUJARATI VOWEL SIGN I","	* stands to the left of the consonant"},
/* 0AC0 */ { "GUJARATI VOWEL SIGN II",NULL},
/* 0AC1 */ { "GUJARATI VOWEL SIGN U",NULL},
/* 0AC2 */ { "GUJARATI VOWEL SIGN UU",NULL},
/* 0AC3 */ { "GUJARATI VOWEL SIGN VOCALIC R",NULL},
/* 0AC4 */ { "GUJARATI VOWEL SIGN VOCALIC RR",NULL},
/* 0AC5 */ { "GUJARATI VOWEL SIGN CANDRA E",NULL},
/* 0AC6 */ { NULL,NULL},
/* 0AC7 */ { "GUJARATI VOWEL SIGN E",NULL},
/* 0AC8 */ { "GUJARATI VOWEL SIGN AI",NULL},
/* 0AC9 */ { "GUJARATI VOWEL SIGN CANDRA O",NULL},
/* 0ACA */ { NULL,NULL},
/* 0ACB */ { "GUJARATI VOWEL SIGN O",NULL},
/* 0ACC */ { "GUJARATI VOWEL SIGN AU",NULL},
/* 0ACD */ { "GUJARATI SIGN VIRAMA",NULL},
/* 0ACE */ { NULL,NULL},
/* 0ACF */ { NULL,NULL},
/* 0AD0 */ { "GUJARATI OM",NULL},
/* 0AD1 */ { NULL,NULL},
/* 0AD2 */ { NULL,NULL},
/* 0AD3 */ { NULL,NULL},
/* 0AD4 */ { NULL,NULL},
/* 0AD5 */ { NULL,NULL},
/* 0AD6 */ { NULL,NULL},
/* 0AD7 */ { NULL,NULL},
/* 0AD8 */ { NULL,NULL},
/* 0AD9 */ { NULL,NULL},
/* 0ADA */ { NULL,NULL},
/* 0ADB */ { NULL,NULL},
/* 0ADC */ { NULL,NULL},
/* 0ADD */ { NULL,NULL},
/* 0ADE */ { NULL,NULL},
/* 0ADF */ { NULL,NULL},
/* 0AE0 */ { "GUJARATI LETTER VOCALIC RR",NULL},
/* 0AE1 */ { "GUJARATI LETTER VOCALIC LL",NULL},
/* 0AE2 */ { "GUJARATI VOWEL SIGN VOCALIC L",NULL},
/* 0AE3 */ { "GUJARATI VOWEL SIGN VOCALIC LL",NULL},
/* 0AE4 */ { NULL,"	x (devanagari danda - 0964)"},
/* 0AE5 */ { NULL,"	x (devanagari double danda - 0965)"},
/* 0AE6 */ { "GUJARATI DIGIT ZERO",NULL},
/* 0AE7 */ { "GUJARATI DIGIT ONE",NULL},
/* 0AE8 */ { "GUJARATI DIGIT TWO",NULL},
/* 0AE9 */ { "GUJARATI DIGIT THREE",NULL},
/* 0AEA */ { "GUJARATI DIGIT FOUR",NULL},
/* 0AEB */ { "GUJARATI DIGIT FIVE",NULL},
/* 0AEC */ { "GUJARATI DIGIT SIX",NULL},
/* 0AED */ { "GUJARATI DIGIT SEVEN",NULL},
/* 0AEE */ { "GUJARATI DIGIT EIGHT",NULL},
/* 0AEF */ { "GUJARATI DIGIT NINE",NULL},
/* 0AF0 */ { "GUJARATI ABBREVIATION SIGN",NULL},
/* 0AF1 */ { "GUJARATI RUPEE SIGN","	* preferred spelling is 0AB0 0AC2 0AF0"},
/* 0AF2 */ { NULL,NULL},
/* 0AF3 */ { NULL,NULL},
/* 0AF4 */ { NULL,NULL},
/* 0AF5 */ { NULL,NULL},
/* 0AF6 */ { NULL,NULL},
/* 0AF7 */ { NULL,NULL},
/* 0AF8 */ { NULL,NULL},
/* 0AF9 */ { "GUJARATI LETTER ZHA","	* used in transliteration of Avestan\n"
	"	x (devanagari letter zha - 0979)"},
/* 0AFA */ { "GUJARATI SIGN SUKUN",NULL},
/* 0AFB */ { "GUJARATI SIGN SHADDA",NULL},
/* 0AFC */ { "GUJARATI SIGN MADDAH",NULL},
/* 0AFD */ { "GUJARATI SIGN THREE-DOT NUKTA ABOVE",NULL},
/* 0AFE */ { "GUJARATI SIGN CIRCLE NUKTA ABOVE",NULL},
/* 0AFF */ { "GUJARATI SIGN TWO-CIRCLE NUKTA ABOVE",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_00_0B[] = {
/* 0B00 */ { NULL,NULL},
/* 0B01 */ { "ORIYA SIGN CANDRABINDU",NULL},
/* 0B02 */ { "ORIYA SIGN ANUSVARA",NULL},
/* 0B03 */ { "ORIYA SIGN VISARGA",NULL},
/* 0B04 */ { NULL,NULL},
/* 0B05 */ { "ORIYA LETTER A",NULL},
/* 0B06 */ { "ORIYA LETTER AA",NULL},
/* 0B07 */ { "ORIYA LETTER I",NULL},
/* 0B08 */ { "ORIYA LETTER II",NULL},
/* 0B09 */ { "ORIYA LETTER U",NULL},
/* 0B0A */ { "ORIYA LETTER UU",NULL},
/* 0B0B */ { "ORIYA LETTER VOCALIC R",NULL},
/* 0B0C */ { "ORIYA LETTER VOCALIC L",NULL},
/* 0B0D */ { NULL,NULL},
/* 0B0E */ { NULL,NULL},
/* 0B0F */ { "ORIYA LETTER E",NULL},
/* 0B10 */ { "ORIYA LETTER AI",NULL},
/* 0B11 */ { NULL,NULL},
/* 0B12 */ { NULL,NULL},
/* 0B13 */ { "ORIYA LETTER O",NULL},
/* 0B14 */ { "ORIYA LETTER AU",NULL},
/* 0B15 */ { "ORIYA LETTER KA",NULL},
/* 0B16 */ { "ORIYA LETTER KHA",NULL},
/* 0B17 */ { "ORIYA LETTER GA",NULL},
/* 0B18 */ { "ORIYA LETTER GHA",NULL},
/* 0B19 */ { "ORIYA LETTER NGA",NULL},
/* 0B1A */ { "ORIYA LETTER CA",NULL},
/* 0B1B */ { "ORIYA LETTER CHA",NULL},
/* 0B1C */ { "ORIYA LETTER JA",NULL},
/* 0B1D */ { "ORIYA LETTER JHA",NULL},
/* 0B1E */ { "ORIYA LETTER NYA",NULL},
/* 0B1F */ { "ORIYA LETTER TTA",NULL},
/* 0B20 */ { "ORIYA LETTER TTHA",NULL},
/* 0B21 */ { "ORIYA LETTER DDA",NULL},
/* 0B22 */ { "ORIYA LETTER DDHA",NULL},
/* 0B23 */ { "ORIYA LETTER NNA",NULL},
/* 0B24 */ { "ORIYA LETTER TA",NULL},
/* 0B25 */ { "ORIYA LETTER THA",NULL},
/* 0B26 */ { "ORIYA LETTER DA",NULL},
/* 0B27 */ { "ORIYA LETTER DHA",NULL},
/* 0B28 */ { "ORIYA LETTER NA",NULL},
/* 0B29 */ { NULL,NULL},
/* 0B2A */ { "ORIYA LETTER PA",NULL},
/* 0B2B */ { "ORIYA LETTER PHA",NULL},
/* 0B2C */ { "ORIYA LETTER BA","	x (oriya letter va - 0B35)"},
/* 0B2D */ { "ORIYA LETTER BHA",NULL},
/* 0B2E */ { "ORIYA LETTER MA",NULL},
/* 0B2F */ { "ORIYA LETTER YA","	= ja"},
/* 0B30 */ { "ORIYA LETTER RA",NULL},
/* 0B31 */ { NULL,NULL},
/* 0B32 */ { "ORIYA LETTER LA",NULL},
/* 0B33 */ { "ORIYA LETTER LLA",NULL},
/* 0B34 */ { NULL,NULL},
/* 0B35 */ { "ORIYA LETTER VA","	* Kui uses an alternate glyph with the dot above the small circle\n"
	"	x (oriya letter ba - 0B2C)"},
/* 0B36 */ { "ORIYA LETTER SHA",NULL},
/* 0B37 */ { "ORIYA LETTER SSA",NULL},
/* 0B38 */ { "ORIYA LETTER SA",NULL},
/* 0B39 */ { "ORIYA LETTER HA",NULL},
/* 0B3A */ { NULL,NULL},
/* 0B3B */ { NULL,NULL},
/* 0B3C */ { "ORIYA SIGN NUKTA","	* for extending the alphabet to new letters"},
/* 0B3D */ { "ORIYA SIGN AVAGRAHA",NULL},
/* 0B3E */ { "ORIYA VOWEL SIGN AA",NULL},
/* 0B3F */ { "ORIYA VOWEL SIGN I",NULL},
/* 0B40 */ { "ORIYA VOWEL SIGN II",NULL},
/* 0B41 */ { "ORIYA VOWEL SIGN U",NULL},
/* 0B42 */ { "ORIYA VOWEL SIGN UU",NULL},
/* 0B43 */ { "ORIYA VOWEL SIGN VOCALIC R",NULL},
/* 0B44 */ { "ORIYA VOWEL SIGN VOCALIC RR",NULL},
/* 0B45 */ { NULL,NULL},
/* 0B46 */ { NULL,NULL},
/* 0B47 */ { "ORIYA VOWEL SIGN E","	* stands to the left of the consonant"},
/* 0B48 */ { "ORIYA VOWEL SIGN AI","	* pieces left of and above the consonant\n"
	"	: 0B47 0B56"},
/* 0B49 */ { NULL,NULL},
/* 0B4A */ { NULL,NULL},
/* 0B4B */ { "ORIYA VOWEL SIGN O","	: 0B47 0B3E"},
/* 0B4C */ { "ORIYA VOWEL SIGN AU","	: 0B47 0B57"},
/* 0B4D */ { "ORIYA SIGN VIRAMA",NULL},
/* 0B4E */ { NULL,NULL},
/* 0B4F */ { NULL,NULL},
/* 0B50 */ { NULL,NULL},
/* 0B51 */ { NULL,NULL},
/* 0B52 */ { NULL,NULL},
/* 0B53 */ { NULL,NULL},
/* 0B54 */ { NULL,NULL},
/* 0B55 */ { "ORIYA SIGN OVERLINE","	* Kuvi, Kui"},
/* 0B56 */ { "ORIYA AI LENGTH MARK",NULL},
/* 0B57 */ { "ORIYA AU LENGTH MARK",NULL},
/* 0B58 */ { NULL,NULL},
/* 0B59 */ { NULL,NULL},
/* 0B5A */ { NULL,NULL},
/* 0B5B */ { NULL,NULL},
/* 0B5C */ { "ORIYA LETTER RRA","	= dda\n"
	"	: 0B21 0B3C"},
/* 0B5D */ { "ORIYA LETTER RHA","	= ddha\n"
	"	: 0B22 0B3C"},
/* 0B5E */ { NULL,NULL},
/* 0B5F */ { "ORIYA LETTER YYA","	= ya"},
/* 0B60 */ { "ORIYA LETTER VOCALIC RR",NULL},
/* 0B61 */ { "ORIYA LETTER VOCALIC LL",NULL},
/* 0B62 */ { "ORIYA VOWEL SIGN VOCALIC L",NULL},
/* 0B63 */ { "ORIYA VOWEL SIGN VOCALIC LL",NULL},
/* 0B64 */ { NULL,"	x (devanagari danda - 0964)"},
/* 0B65 */ { NULL,"	x (devanagari double danda - 0965)"},
/* 0B66 */ { "ORIYA DIGIT ZERO",NULL},
/* 0B67 */ { "ORIYA DIGIT ONE",NULL},
/* 0B68 */ { "ORIYA DIGIT TWO",NULL},
/* 0B69 */ { "ORIYA DIGIT THREE",NULL},
/* 0B6A */ { "ORIYA DIGIT FOUR",NULL},
/* 0B6B */ { "ORIYA DIGIT FIVE",NULL},
/* 0B6C */ { "ORIYA DIGIT SIX",NULL},
/* 0B6D */ { "ORIYA DIGIT SEVEN",NULL},
/* 0B6E */ { "ORIYA DIGIT EIGHT",NULL},
/* 0B6F */ { "ORIYA DIGIT NINE",NULL},
/* 0B70 */ { "ORIYA ISSHAR",NULL},
/* 0B71 */ { "ORIYA LETTER WA","	x (oriya letter o - 0B13)\n"
	"	x (oriya letter va - 0B35)"},
/* 0B72 */ { "ORIYA FRACTION ONE QUARTER",NULL},
/* 0B73 */ { "ORIYA FRACTION ONE HALF",NULL},
/* 0B74 */ { "ORIYA FRACTION THREE QUARTERS",NULL},
/* 0B75 */ { "ORIYA FRACTION ONE SIXTEENTH",NULL},
/* 0B76 */ { "ORIYA FRACTION ONE EIGHTH",NULL},
/* 0B77 */ { "ORIYA FRACTION THREE SIXTEENTHS",NULL},
/* 0B78 */ { NULL,NULL},
/* 0B79 */ { NULL,NULL},
/* 0B7A */ { NULL,NULL},
/* 0B7B */ { NULL,NULL},
/* 0B7C */ { NULL,NULL},
/* 0B7D */ { NULL,NULL},
/* 0B7E */ { NULL,NULL},
/* 0B7F */ { NULL,NULL},
/* 0B80 */ { NULL,NULL},
/* 0B81 */ { NULL,NULL},
/* 0B82 */ { "TAMIL SIGN ANUSVARA","	* not used in Tamil"},
/* 0B83 */ { "TAMIL SIGN VISARGA","	= aytham\n"
	"	* just as for the Tamil pulli, the glyph for aytham may use either dots or rings"},
/* 0B84 */ { NULL,NULL},
/* 0B85 */ { "TAMIL LETTER A",NULL},
/* 0B86 */ { "TAMIL LETTER AA",NULL},
/* 0B87 */ { "TAMIL LETTER I",NULL},
/* 0B88 */ { "TAMIL LETTER II",NULL},
/* 0B89 */ { "TAMIL LETTER U",NULL},
/* 0B8A */ { "TAMIL LETTER UU",NULL},
/* 0B8B */ { NULL,NULL},
/* 0B8C */ { NULL,NULL},
/* 0B8D */ { NULL,NULL},
/* 0B8E */ { "TAMIL LETTER E",NULL},
/* 0B8F */ { "TAMIL LETTER EE",NULL},
/* 0B90 */ { "TAMIL LETTER AI",NULL},
/* 0B91 */ { NULL,NULL},
/* 0B92 */ { "TAMIL LETTER O",NULL},
/* 0B93 */ { "TAMIL LETTER OO",NULL},
/* 0B94 */ { "TAMIL LETTER AU","	: 0B92 0BD7"},
/* 0B95 */ { "TAMIL LETTER KA",NULL},
/* 0B96 */ { NULL,NULL},
/* 0B97 */ { NULL,NULL},
/* 0B98 */ { NULL,NULL},
/* 0B99 */ { "TAMIL LETTER NGA","	* also denotes the measure kuruni/marakkaal\n"
	"	x (tamil sign kuruni - 11FDA)"},
/* 0B9A */ { "TAMIL LETTER CA",NULL},
/* 0B9B */ { NULL,NULL},
/* 0B9C */ { "TAMIL LETTER JA",NULL},
/* 0B9D */ { NULL,NULL},
/* 0B9E */ { "TAMIL LETTER NYA",NULL},
/* 0B9F */ { "TAMIL LETTER TTA",NULL},
/* 0BA0 */ { NULL,NULL},
/* 0BA1 */ { NULL,NULL},
/* 0BA2 */ { NULL,NULL},
/* 0BA3 */ { "TAMIL LETTER NNA",NULL},
/* 0BA4 */ { "TAMIL LETTER TA","	* also denotes the measure thuuni\n"
	"	x (tamil sign mukkuruni - 11FDC)"},
/* 0BA5 */ { NULL,NULL},
/* 0BA6 */ { NULL,NULL},
/* 0BA7 */ { NULL,NULL},
/* 0BA8 */ { "TAMIL LETTER NA",NULL},
/* 0BA9 */ { "TAMIL LETTER NNNA",NULL},
/* 0BAA */ { "TAMIL LETTER PA","	= maa\n"
	"	x (tamil fraction one twentieth - 11FC8)"},
/* 0BAB */ { NULL,NULL},
/* 0BAC */ { NULL,NULL},
/* 0BAD */ { NULL,NULL},
/* 0BAE */ { "TAMIL LETTER MA",NULL},
/* 0BAF */ { "TAMIL LETTER YA",NULL},
/* 0BB0 */ { "TAMIL LETTER RA",NULL},
/* 0BB1 */ { "TAMIL LETTER RRA",NULL},
/* 0BB2 */ { "TAMIL LETTER LA",NULL},
/* 0BB3 */ { "TAMIL LETTER LLA","	* also denotes the measure kalam\n"
	"	x (tamil sign mukkuruni - 11FDC)"},
/* 0BB4 */ { "TAMIL LETTER LLLA",NULL},
/* 0BB5 */ { "TAMIL LETTER VA","	x (tamil fraction one quarter - 11FD0)"},
/* 0BB6 */ { "TAMIL LETTER SHA",NULL},
/* 0BB7 */ { "TAMIL LETTER SSA",NULL},
/* 0BB8 */ { "TAMIL LETTER SA",NULL},
/* 0BB9 */ { "TAMIL LETTER HA",NULL},
/* 0BBA */ { NULL,NULL},
/* 0BBB */ { NULL,NULL},
/* 0BBC */ { NULL,NULL},
/* 0BBD */ { NULL,NULL},
/* 0BBE */ { "TAMIL VOWEL SIGN AA",NULL},
/* 0BBF */ { "TAMIL VOWEL SIGN I",NULL},
/* 0BC0 */ { "TAMIL VOWEL SIGN II",NULL},
/* 0BC1 */ { "TAMIL VOWEL SIGN U",NULL},
/* 0BC2 */ { "TAMIL VOWEL SIGN UU",NULL},
/* 0BC3 */ { NULL,NULL},
/* 0BC4 */ { NULL,NULL},
/* 0BC5 */ { NULL,NULL},
/* 0BC6 */ { "TAMIL VOWEL SIGN E","	* stands to the left of the consonant"},
/* 0BC7 */ { "TAMIL VOWEL SIGN EE","	* stands to the left of the consonant"},
/* 0BC8 */ { "TAMIL VOWEL SIGN AI","	* stands to the left of the consonant"},
/* 0BC9 */ { NULL,NULL},
/* 0BCA */ { "TAMIL VOWEL SIGN O","	: 0BC6 0BBE"},
/* 0BCB */ { "TAMIL VOWEL SIGN OO","	: 0BC7 0BBE"},
/* 0BCC */ { "TAMIL VOWEL SIGN AU","	: 0BC6 0BD7"},
/* 0BCD */ { "TAMIL SIGN VIRAMA","	= pulli"},
/* 0BCE */ { NULL,NULL},
/* 0BCF */ { NULL,NULL},
/* 0BD0 */ { "TAMIL OM",NULL},
/* 0BD1 */ { NULL,NULL},
/* 0BD2 */ { NULL,NULL},
/* 0BD3 */ { NULL,NULL},
/* 0BD4 */ { NULL,NULL},
/* 0BD5 */ { NULL,NULL},
/* 0BD6 */ { NULL,NULL},
/* 0BD7 */ { "TAMIL AU LENGTH MARK",NULL},
/* 0BD8 */ { NULL,NULL},
/* 0BD9 */ { NULL,NULL},
/* 0BDA */ { NULL,NULL},
/* 0BDB */ { NULL,NULL},
/* 0BDC */ { NULL,NULL},
/* 0BDD */ { NULL,NULL},
/* 0BDE */ { NULL,NULL},
/* 0BDF */ { NULL,NULL},
/* 0BE0 */ { NULL,NULL},
/* 0BE1 */ { NULL,NULL},
/* 0BE2 */ { NULL,NULL},
/* 0BE3 */ { NULL,NULL},
/* 0BE4 */ { NULL,"	x (devanagari danda - 0964)"},
/* 0BE5 */ { NULL,"	x (devanagari double danda - 0965)"},
/* 0BE6 */ { "TAMIL DIGIT ZERO",NULL},
/* 0BE7 */ { "TAMIL DIGIT ONE",NULL},
/* 0BE8 */ { "TAMIL DIGIT TWO",NULL},
/* 0BE9 */ { "TAMIL DIGIT THREE",NULL},
/* 0BEA */ { "TAMIL DIGIT FOUR",NULL},
/* 0BEB */ { "TAMIL DIGIT FIVE",NULL},
/* 0BEC */ { "TAMIL DIGIT SIX",NULL},
/* 0BED */ { "TAMIL DIGIT SEVEN",NULL},
/* 0BEE */ { "TAMIL DIGIT EIGHT",NULL},
/* 0BEF */ { "TAMIL DIGIT NINE",NULL},
/* 0BF0 */ { "TAMIL NUMBER TEN",NULL},
/* 0BF1 */ { "TAMIL NUMBER ONE HUNDRED",NULL},
/* 0BF2 */ { "TAMIL NUMBER ONE THOUSAND",NULL},
/* 0BF3 */ { "TAMIL DAY SIGN","	= naal, naali/padi\n"
	"	* denotes a measure of grain that equals 2 uri or 4 ulakku\n"
	"	x (tamil sign muuvuzhakku - 11FD9)\n"
	"	= pillaiyaar suli\n"
	"	* denotes auspiciousness"},
/* 0BF4 */ { "TAMIL MONTH SIGN","	= maatham"},
/* 0BF5 */ { "TAMIL YEAR SIGN","	= varudam"},
/* 0BF6 */ { "TAMIL DEBIT SIGN","	= patru"},
/* 0BF7 */ { "TAMIL CREDIT SIGN","	= eduppu\n"
	"	* denotes incoming cash which is set aside for unknown expenses\n"
	"	* sometimes used as the credit sign; the traditional credit sign is distinct\n"
	"	x (tamil traditional credit sign - 11FE8)"},
/* 0BF8 */ { "TAMIL AS ABOVE SIGN","	= merpadi"},
/* 0BF9 */ { "TAMIL RUPEE SIGN","	= rupai\n"
	"	x (tamil land sign - 11FE6)"},
/* 0BFA */ { "TAMIL NUMBER SIGN","	= enn, niluvai\n"
	"	* denotes balance\n"
	"	* sometimes used as the number sign; the traditional number sign is distinct\n"
	"	x (tamil traditional number sign - 11FE9)"},
/* 0BFB */ { NULL,NULL},
/* 0BFC */ { NULL,NULL},
/* 0BFD */ { NULL,NULL},
/* 0BFE */ { NULL,NULL},
/* 0BFF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_00_0C[] = {
/* 0C00 */ { "TELUGU SIGN COMBINING CANDRABINDU ABOVE",NULL},
/* 0C01 */ { "TELUGU SIGN CANDRABINDU","	= arasunna\n"
	"	* indicates a contextually elided nasal"},
/* 0C02 */ { "TELUGU SIGN ANUSVARA","	= sunna\n"
	"	* used in Prakrit language texts to indicate gemination of the following consonant"},
/* 0C03 */ { "TELUGU SIGN VISARGA",NULL},
/* 0C04 */ { "TELUGU SIGN COMBINING ANUSVARA ABOVE","	* used in Prakrit language texts for the linguistic anusvara"},
/* 0C05 */ { "TELUGU LETTER A",NULL},
/* 0C06 */ { "TELUGU LETTER AA",NULL},
/* 0C07 */ { "TELUGU LETTER I",NULL},
/* 0C08 */ { "TELUGU LETTER II",NULL},
/* 0C09 */ { "TELUGU LETTER U",NULL},
/* 0C0A */ { "TELUGU LETTER UU",NULL},
/* 0C0B */ { "TELUGU LETTER VOCALIC R",NULL},
/* 0C0C */ { "TELUGU LETTER VOCALIC L",NULL},
/* 0C0D */ { NULL,NULL},
/* 0C0E */ { "TELUGU LETTER E",NULL},
/* 0C0F */ { "TELUGU LETTER EE",NULL},
/* 0C10 */ { "TELUGU LETTER AI",NULL},
/* 0C11 */ { NULL,NULL},
/* 0C12 */ { "TELUGU LETTER O",NULL},
/* 0C13 */ { "TELUGU LETTER OO",NULL},
/* 0C14 */ { "TELUGU LETTER AU",NULL},
/* 0C15 */ { "TELUGU LETTER KA",NULL},
/* 0C16 */ { "TELUGU LETTER KHA",NULL},
/* 0C17 */ { "TELUGU LETTER GA",NULL},
/* 0C18 */ { "TELUGU LETTER GHA",NULL},
/* 0C19 */ { "TELUGU LETTER NGA",NULL},
/* 0C1A */ { "TELUGU LETTER CA",NULL},
/* 0C1B */ { "TELUGU LETTER CHA",NULL},
/* 0C1C */ { "TELUGU LETTER JA",NULL},
/* 0C1D */ { "TELUGU LETTER JHA",NULL},
/* 0C1E */ { "TELUGU LETTER NYA",NULL},
/* 0C1F */ { "TELUGU LETTER TTA",NULL},
/* 0C20 */ { "TELUGU LETTER TTHA",NULL},
/* 0C21 */ { "TELUGU LETTER DDA",NULL},
/* 0C22 */ { "TELUGU LETTER DDHA",NULL},
/* 0C23 */ { "TELUGU LETTER NNA",NULL},
/* 0C24 */ { "TELUGU LETTER TA",NULL},
/* 0C25 */ { "TELUGU LETTER THA",NULL},
/* 0C26 */ { "TELUGU LETTER DA",NULL},
/* 0C27 */ { "TELUGU LETTER DHA",NULL},
/* 0C28 */ { "TELUGU LETTER NA",NULL},
/* 0C29 */ { NULL,NULL},
/* 0C2A */ { "TELUGU LETTER PA",NULL},
/* 0C2B */ { "TELUGU LETTER PHA",NULL},
/* 0C2C */ { "TELUGU LETTER BA",NULL},
/* 0C2D */ { "TELUGU LETTER BHA",NULL},
/* 0C2E */ { "TELUGU LETTER MA",NULL},
/* 0C2F */ { "TELUGU LETTER YA",NULL},
/* 0C30 */ { "TELUGU LETTER RA",NULL},
/* 0C31 */ { "TELUGU LETTER RRA",NULL},
/* 0C32 */ { "TELUGU LETTER LA",NULL},
/* 0C33 */ { "TELUGU LETTER LLA",NULL},
/* 0C34 */ { "TELUGU LETTER LLLA",NULL},
/* 0C35 */ { "TELUGU LETTER VA",NULL},
/* 0C36 */ { "TELUGU LETTER SHA",NULL},
/* 0C37 */ { "TELUGU LETTER SSA",NULL},
/* 0C38 */ { "TELUGU LETTER SA",NULL},
/* 0C39 */ { "TELUGU LETTER HA",NULL},
/* 0C3A */ { NULL,NULL},
/* 0C3B */ { NULL,NULL},
/* 0C3C */ { "TELUGU SIGN NUKTA","	* used for Tamil transliteration and Perso-Arabic phonemes\n"
	"	* can also appear as a large dot, should be placed sufficiently below the baseline of a consonant to avoid confusion/collision with the aspiration marker"},
/* 0C3D */ { "TELUGU SIGN AVAGRAHA",NULL},
/* 0C3E */ { "TELUGU VOWEL SIGN AA",NULL},
/* 0C3F */ { "TELUGU VOWEL SIGN I",NULL},
/* 0C40 */ { "TELUGU VOWEL SIGN II",NULL},
/* 0C41 */ { "TELUGU VOWEL SIGN U",NULL},
/* 0C42 */ { "TELUGU VOWEL SIGN UU",NULL},
/* 0C43 */ { "TELUGU VOWEL SIGN VOCALIC R",NULL},
/* 0C44 */ { "TELUGU VOWEL SIGN VOCALIC RR",NULL},
/* 0C45 */ { NULL,NULL},
/* 0C46 */ { "TELUGU VOWEL SIGN E",NULL},
/* 0C47 */ { "TELUGU VOWEL SIGN EE",NULL},
/* 0C48 */ { "TELUGU VOWEL SIGN AI","	: 0C46 0C56"},
/* 0C49 */ { NULL,NULL},
/* 0C4A */ { "TELUGU VOWEL SIGN O",NULL},
/* 0C4B */ { "TELUGU VOWEL SIGN OO",NULL},
/* 0C4C */ { "TELUGU VOWEL SIGN AU",NULL},
/* 0C4D */ { "TELUGU SIGN VIRAMA","	= halant (the preferred name)"},
/* 0C4E */ { NULL,NULL},
/* 0C4F */ { NULL,NULL},
/* 0C50 */ { NULL,NULL},
/* 0C51 */ { NULL,NULL},
/* 0C52 */ { NULL,NULL},
/* 0C53 */ { NULL,NULL},
/* 0C54 */ { NULL,NULL},
/* 0C55 */ { "TELUGU LENGTH MARK",NULL},
/* 0C56 */ { "TELUGU AI LENGTH MARK",NULL},
/* 0C57 */ { NULL,NULL},
/* 0C58 */ { "TELUGU LETTER TSA",NULL},
/* 0C59 */ { "TELUGU LETTER DZA",NULL},
/* 0C5A */ { "TELUGU LETTER RRRA","	* letter for an alveolar consonant whose exact phonetic value is not known"},
/* 0C5B */ { NULL,NULL},
/* 0C5C */ { "TELUGU ARCHAIC SHRII","	* auspicious word shrii\n"
	"	* does not combine with other letters"},
/* 0C5D */ { "TELUGU LETTER NAKAARA POLLU","	* vowelless form of na\n"
	"	x (kannada letter nakaara pollu - 0CDD)\n"
	"	x (malayalam letter chillu n - 0D7B)"},
/* 0C5E */ { NULL,NULL},
/* 0C5F */ { NULL,NULL},
/* 0C60 */ { "TELUGU LETTER VOCALIC RR",NULL},
/* 0C61 */ { "TELUGU LETTER VOCALIC LL",NULL},
/* 0C62 */ { "TELUGU VOWEL SIGN VOCALIC L",NULL},
/* 0C63 */ { "TELUGU VOWEL SIGN VOCALIC LL",NULL},
/* 0C64 */ { NULL,"	x (devanagari danda - 0964)"},
/* 0C65 */ { NULL,"	x (devanagari double danda - 0965)"},
/* 0C66 */ { "TELUGU DIGIT ZERO",NULL},
/* 0C67 */ { "TELUGU DIGIT ONE",NULL},
/* 0C68 */ { "TELUGU DIGIT TWO",NULL},
/* 0C69 */ { "TELUGU DIGIT THREE",NULL},
/* 0C6A */ { "TELUGU DIGIT FOUR",NULL},
/* 0C6B */ { "TELUGU DIGIT FIVE",NULL},
/* 0C6C */ { "TELUGU DIGIT SIX",NULL},
/* 0C6D */ { "TELUGU DIGIT SEVEN",NULL},
/* 0C6E */ { "TELUGU DIGIT EIGHT",NULL},
/* 0C6F */ { "TELUGU DIGIT NINE",NULL},
/* 0C70 */ { NULL,NULL},
/* 0C71 */ { NULL,NULL},
/* 0C72 */ { NULL,NULL},
/* 0C73 */ { NULL,NULL},
/* 0C74 */ { NULL,NULL},
/* 0C75 */ { NULL,NULL},
/* 0C76 */ { NULL,NULL},
/* 0C77 */ { "TELUGU SIGN SIDDHAM","	= siddhirastu\n"
	"	* used at the beginning of texts as an invocation\n"
	"	x (devanagari sign siddham - A8FC)\n"
	"	x (sharada sign siddham - 111DB)"},
/* 0C78 */ { "TELUGU FRACTION DIGIT ZERO FOR ODD POWERS OF FOUR",NULL},
/* 0C79 */ { "TELUGU FRACTION DIGIT ONE FOR ODD POWERS OF FOUR",NULL},
/* 0C7A */ { "TELUGU FRACTION DIGIT TWO FOR ODD POWERS OF FOUR",NULL},
/* 0C7B */ { "TELUGU FRACTION DIGIT THREE FOR ODD POWERS OF FOUR",NULL},
/* 0C7C */ { "TELUGU FRACTION DIGIT ONE FOR EVEN POWERS OF FOUR",NULL},
/* 0C7D */ { "TELUGU FRACTION DIGIT TWO FOR EVEN POWERS OF FOUR",NULL},
/* 0C7E */ { "TELUGU FRACTION DIGIT THREE FOR EVEN POWERS OF FOUR",NULL},
/* 0C7F */ { "TELUGU SIGN TUUMU",NULL},
/* 0C80 */ { "KANNADA SIGN SPACING CANDRABINDU",NULL},
/* 0C81 */ { "KANNADA SIGN CANDRABINDU",NULL},
/* 0C82 */ { "KANNADA SIGN ANUSVARA","	* used in Konkani, Havyaka Kannada (Havigannada) and Awadhi texts to indicate regular anusvara"},
/* 0C83 */ { "KANNADA SIGN VISARGA",NULL},
/* 0C84 */ { "KANNADA SIGN SIDDHAM","	= siddhirastu\n"
	"	* used at the beginning of texts as an invocation\n"
	"	x (devanagari sign siddham - A8FC)\n"
	"	x (sharada sign siddham - 111DB)"},
/* 0C85 */ { "KANNADA LETTER A",NULL},
/* 0C86 */ { "KANNADA LETTER AA",NULL},
/* 0C87 */ { "KANNADA LETTER I",NULL},
/* 0C88 */ { "KANNADA LETTER II",NULL},
/* 0C89 */ { "KANNADA LETTER U",NULL},
/* 0C8A */ { "KANNADA LETTER UU",NULL},
/* 0C8B */ { "KANNADA LETTER VOCALIC R",NULL},
/* 0C8C */ { "KANNADA LETTER VOCALIC L",NULL},
/* 0C8D */ { NULL,NULL},
/* 0C8E */ { "KANNADA LETTER E",NULL},
/* 0C8F */ { "KANNADA LETTER EE",NULL},
/* 0C90 */ { "KANNADA LETTER AI",NULL},
/* 0C91 */ { NULL,NULL},
/* 0C92 */ { "KANNADA LETTER O",NULL},
/* 0C93 */ { "KANNADA LETTER OO",NULL},
/* 0C94 */ { "KANNADA LETTER AU",NULL},
/* 0C95 */ { "KANNADA LETTER KA",NULL},
/* 0C96 */ { "KANNADA LETTER KHA",NULL},
/* 0C97 */ { "KANNADA LETTER GA",NULL},
/* 0C98 */ { "KANNADA LETTER GHA",NULL},
/* 0C99 */ { "KANNADA LETTER NGA",NULL},
/* 0C9A */ { "KANNADA LETTER CA",NULL},
/* 0C9B */ { "KANNADA LETTER CHA",NULL},
/* 0C9C */ { "KANNADA LETTER JA",NULL},
/* 0C9D */ { "KANNADA LETTER JHA",NULL},
/* 0C9E */ { "KANNADA LETTER NYA",NULL},
/* 0C9F */ { "KANNADA LETTER TTA",NULL},
/* 0CA0 */ { "KANNADA LETTER TTHA",NULL},
/* 0CA1 */ { "KANNADA LETTER DDA",NULL},
/* 0CA2 */ { "KANNADA LETTER DDHA",NULL},
/* 0CA3 */ { "KANNADA LETTER NNA",NULL},
/* 0CA4 */ { "KANNADA LETTER TA",NULL},
/* 0CA5 */ { "KANNADA LETTER THA",NULL},
/* 0CA6 */ { "KANNADA LETTER DA",NULL},
/* 0CA7 */ { "KANNADA LETTER DHA",NULL},
/* 0CA8 */ { "KANNADA LETTER NA",NULL},
/* 0CA9 */ { NULL,NULL},
/* 0CAA */ { "KANNADA LETTER PA",NULL},
/* 0CAB */ { "KANNADA LETTER PHA",NULL},
/* 0CAC */ { "KANNADA LETTER BA",NULL},
/* 0CAD */ { "KANNADA LETTER BHA",NULL},
/* 0CAE */ { "KANNADA LETTER MA",NULL},
/* 0CAF */ { "KANNADA LETTER YA",NULL},
/* 0CB0 */ { "KANNADA LETTER RA",NULL},
/* 0CB1 */ { "KANNADA LETTER RRA",NULL},
/* 0CB2 */ { "KANNADA LETTER LA",NULL},
/* 0CB3 */ { "KANNADA LETTER LLA",NULL},
/* 0CB4 */ { NULL,NULL},
/* 0CB5 */ { "KANNADA LETTER VA",NULL},
/* 0CB6 */ { "KANNADA LETTER SHA",NULL},
/* 0CB7 */ { "KANNADA LETTER SSA",NULL},
/* 0CB8 */ { "KANNADA LETTER SA",NULL},
/* 0CB9 */ { "KANNADA LETTER HA",NULL},
/* 0CBA */ { NULL,NULL},
/* 0CBB */ { NULL,NULL},
/* 0CBC */ { "KANNADA SIGN NUKTA",NULL},
/* 0CBD */ { "KANNADA SIGN AVAGRAHA",NULL},
/* 0CBE */ { "KANNADA VOWEL SIGN AA",NULL},
/* 0CBF */ { "KANNADA VOWEL SIGN I",NULL},
/* 0CC0 */ { "KANNADA VOWEL SIGN II","	: 0CBF 0CD5"},
/* 0CC1 */ { "KANNADA VOWEL SIGN U",NULL},
/* 0CC2 */ { "KANNADA VOWEL SIGN UU",NULL},
/* 0CC3 */ { "KANNADA VOWEL SIGN VOCALIC R",NULL},
/* 0CC4 */ { "KANNADA VOWEL SIGN VOCALIC RR",NULL},
/* 0CC5 */ { NULL,NULL},
/* 0CC6 */ { "KANNADA VOWEL SIGN E",NULL},
/* 0CC7 */ { "KANNADA VOWEL SIGN EE","	: 0CC6 0CD5"},
/* 0CC8 */ { "KANNADA VOWEL SIGN AI","	: 0CC6 0CD6"},
/* 0CC9 */ { NULL,NULL},
/* 0CCA */ { "KANNADA VOWEL SIGN O","	: 0CC6 0CC2"},
/* 0CCB */ { "KANNADA VOWEL SIGN OO","	: 0CCA 0CD5"},
/* 0CCC */ { "KANNADA VOWEL SIGN AU",NULL},
/* 0CCD */ { "KANNADA SIGN VIRAMA","	* preferred name is halant"},
/* 0CCE */ { NULL,NULL},
/* 0CCF */ { NULL,NULL},
/* 0CD0 */ { NULL,NULL},
/* 0CD1 */ { NULL,NULL},
/* 0CD2 */ { NULL,NULL},
/* 0CD3 */ { NULL,NULL},
/* 0CD4 */ { NULL,NULL},
/* 0CD5 */ { "KANNADA LENGTH MARK",NULL},
/* 0CD6 */ { "KANNADA AI LENGTH MARK",NULL},
/* 0CD7 */ { NULL,NULL},
/* 0CD8 */ { NULL,NULL},
/* 0CD9 */ { NULL,NULL},
/* 0CDA */ { NULL,NULL},
/* 0CDB */ { NULL,NULL},
/* 0CDC */ { "KANNADA ARCHAIC SHRII","	* auspicious word shrii\n"
	"	* does not combine with other letters"},
/* 0CDD */ { "KANNADA LETTER NAKAARA POLLU","	* vowelless form of na\n"
	"	x (telugu letter nakaara pollu - 0C5D)\n"
	"	x (malayalam letter chillu n - 0D7B)"},
/* 0CDE */ { "KANNADA LETTER FA","	% KANNADA LETTER LLLA\n"
	"	* obsolete historic letter\n"
	"	* name is a mistake for LLLA"},
/* 0CDF */ { NULL,NULL},
/* 0CE0 */ { "KANNADA LETTER VOCALIC RR",NULL},
/* 0CE1 */ { "KANNADA LETTER VOCALIC LL",NULL},
/* 0CE2 */ { "KANNADA VOWEL SIGN VOCALIC L",NULL},
/* 0CE3 */ { "KANNADA VOWEL SIGN VOCALIC LL",NULL},
/* 0CE4 */ { NULL,"	x (devanagari danda - 0964)"},
/* 0CE5 */ { NULL,"	x (devanagari double danda - 0965)"},
/* 0CE6 */ { "KANNADA DIGIT ZERO",NULL},
/* 0CE7 */ { "KANNADA DIGIT ONE",NULL},
/* 0CE8 */ { "KANNADA DIGIT TWO",NULL},
/* 0CE9 */ { "KANNADA DIGIT THREE",NULL},
/* 0CEA */ { "KANNADA DIGIT FOUR",NULL},
/* 0CEB */ { "KANNADA DIGIT FIVE",NULL},
/* 0CEC */ { "KANNADA DIGIT SIX",NULL},
/* 0CED */ { "KANNADA DIGIT SEVEN",NULL},
/* 0CEE */ { "KANNADA DIGIT EIGHT",NULL},
/* 0CEF */ { "KANNADA DIGIT NINE",NULL},
/* 0CF0 */ { NULL,NULL},
/* 0CF1 */ { "KANNADA SIGN JIHVAMULIYA","	x (vedic sign jihvamuliya - 1CF5)"},
/* 0CF2 */ { "KANNADA SIGN UPADHMANIYA","	x (vedic sign upadhmaniya - 1CF6)"},
/* 0CF3 */ { "KANNADA SIGN COMBINING ANUSVARA ABOVE RIGHT","	* used in Konkani, Havyaka Kannada (Havigannada) and Awadhi texts to indicate anunāsikā"},
/* 0CF4 */ { NULL,NULL},
/* 0CF5 */ { NULL,NULL},
/* 0CF6 */ { NULL,NULL},
/* 0CF7 */ { NULL,NULL},
/* 0CF8 */ { NULL,NULL},
/* 0CF9 */ { NULL,NULL},
/* 0CFA */ { NULL,NULL},
/* 0CFB */ { NULL,NULL},
/* 0CFC */ { NULL,NULL},
/* 0CFD */ { NULL,NULL},
/* 0CFE */ { NULL,NULL},
/* 0CFF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_00_0D[] = {
/* 0D00 */ { "MALAYALAM SIGN COMBINING ANUSVARA ABOVE",NULL},
/* 0D01 */ { "MALAYALAM SIGN CANDRABINDU",NULL},
/* 0D02 */ { "MALAYALAM SIGN ANUSVARA","	* used in Prakrit language texts to indicate gemination of the following consonant"},
/* 0D03 */ { "MALAYALAM SIGN VISARGA",NULL},
/* 0D04 */ { "MALAYALAM LETTER VEDIC ANUSVARA",NULL},
/* 0D05 */ { "MALAYALAM LETTER A",NULL},
/* 0D06 */ { "MALAYALAM LETTER AA",NULL},
/* 0D07 */ { "MALAYALAM LETTER I",NULL},
/* 0D08 */ { "MALAYALAM LETTER II",NULL},
/* 0D09 */ { "MALAYALAM LETTER U",NULL},
/* 0D0A */ { "MALAYALAM LETTER UU",NULL},
/* 0D0B */ { "MALAYALAM LETTER VOCALIC R",NULL},
/* 0D0C */ { "MALAYALAM LETTER VOCALIC L",NULL},
/* 0D0D */ { NULL,NULL},
/* 0D0E */ { "MALAYALAM LETTER E",NULL},
/* 0D0F */ { "MALAYALAM LETTER EE",NULL},
/* 0D10 */ { "MALAYALAM LETTER AI",NULL},
/* 0D11 */ { NULL,NULL},
/* 0D12 */ { "MALAYALAM LETTER O",NULL},
/* 0D13 */ { "MALAYALAM LETTER OO",NULL},
/* 0D14 */ { "MALAYALAM LETTER AU",NULL},
/* 0D15 */ { "MALAYALAM LETTER KA",NULL},
/* 0D16 */ { "MALAYALAM LETTER KHA",NULL},
/* 0D17 */ { "MALAYALAM LETTER GA",NULL},
/* 0D18 */ { "MALAYALAM LETTER GHA",NULL},
/* 0D19 */ { "MALAYALAM LETTER NGA",NULL},
/* 0D1A */ { "MALAYALAM LETTER CA","	= cha"},
/* 0D1B */ { "MALAYALAM LETTER CHA","	= chha"},
/* 0D1C */ { "MALAYALAM LETTER JA",NULL},
/* 0D1D */ { "MALAYALAM LETTER JHA",NULL},
/* 0D1E */ { "MALAYALAM LETTER NYA","	= nha"},
/* 0D1F */ { "MALAYALAM LETTER TTA","	= ta"},
/* 0D20 */ { "MALAYALAM LETTER TTHA","	= tta"},
/* 0D21 */ { "MALAYALAM LETTER DDA","	= hard da"},
/* 0D22 */ { "MALAYALAM LETTER DDHA","	= hard dda"},
/* 0D23 */ { "MALAYALAM LETTER NNA","	= hard na"},
/* 0D24 */ { "MALAYALAM LETTER TA","	= tha"},
/* 0D25 */ { "MALAYALAM LETTER THA","	= ttha"},
/* 0D26 */ { "MALAYALAM LETTER DA","	= soft da"},
/* 0D27 */ { "MALAYALAM LETTER DHA","	= soft dda"},
/* 0D28 */ { "MALAYALAM LETTER NA",NULL},
/* 0D29 */ { "MALAYALAM LETTER NNNA","	* scholarly use only"},
/* 0D2A */ { "MALAYALAM LETTER PA",NULL},
/* 0D2B */ { "MALAYALAM LETTER PHA",NULL},
/* 0D2C */ { "MALAYALAM LETTER BA",NULL},
/* 0D2D */ { "MALAYALAM LETTER BHA",NULL},
/* 0D2E */ { "MALAYALAM LETTER MA","	* also used to denote the fraction one eightieth (kaani)"},
/* 0D2F */ { "MALAYALAM LETTER YA",NULL},
/* 0D30 */ { "MALAYALAM LETTER RA",NULL},
/* 0D31 */ { "MALAYALAM LETTER RRA",NULL},
/* 0D32 */ { "MALAYALAM LETTER LA",NULL},
/* 0D33 */ { "MALAYALAM LETTER LLA",NULL},
/* 0D34 */ { "MALAYALAM LETTER LLLA","	= zha"},
/* 0D35 */ { "MALAYALAM LETTER VA",NULL},
/* 0D36 */ { "MALAYALAM LETTER SHA","	= soft sha"},
/* 0D37 */ { "MALAYALAM LETTER SSA","	= sha"},
/* 0D38 */ { "MALAYALAM LETTER SA",NULL},
/* 0D39 */ { "MALAYALAM LETTER HA",NULL},
/* 0D3A */ { "MALAYALAM LETTER TTTA","	* scholarly use only"},
/* 0D3B */ { "MALAYALAM SIGN VERTICAL BAR VIRAMA",NULL},
/* 0D3C */ { "MALAYALAM SIGN CIRCULAR VIRAMA",NULL},
/* 0D3D */ { "MALAYALAM SIGN AVAGRAHA","	= praslesham"},
/* 0D3E */ { "MALAYALAM VOWEL SIGN AA",NULL},
/* 0D3F */ { "MALAYALAM VOWEL SIGN I",NULL},
/* 0D40 */ { "MALAYALAM VOWEL SIGN II",NULL},
/* 0D41 */ { "MALAYALAM VOWEL SIGN U",NULL},
/* 0D42 */ { "MALAYALAM VOWEL SIGN UU",NULL},
/* 0D43 */ { "MALAYALAM VOWEL SIGN VOCALIC R",NULL},
/* 0D44 */ { "MALAYALAM VOWEL SIGN VOCALIC RR",NULL},
/* 0D45 */ { NULL,NULL},
/* 0D46 */ { "MALAYALAM VOWEL SIGN E","	* stands to the left of the consonant"},
/* 0D47 */ { "MALAYALAM VOWEL SIGN EE","	* stands to the left of the consonant"},
/* 0D48 */ { "MALAYALAM VOWEL SIGN AI","	* stands to the left of the consonant"},
/* 0D49 */ { NULL,NULL},
/* 0D4A */ { "MALAYALAM VOWEL SIGN O","	: 0D46 0D3E"},
/* 0D4B */ { "MALAYALAM VOWEL SIGN OO","	: 0D47 0D3E"},
/* 0D4C */ { "MALAYALAM VOWEL SIGN AU","	* archaic form of the /au/ dependent vowel\n"
	"	x (malayalam au length mark - 0D57)\n"
	"	: 0D46 0D57"},
/* 0D4D */ { "MALAYALAM SIGN VIRAMA","	= candrakkala (the preferred name)\n"
	"	= vowel half-u"},
/* 0D4E */ { "MALAYALAM LETTER DOT REPH","	* not used in reformed modern Malayalam orthography"},
/* 0D4F */ { "MALAYALAM SIGN PARA","	* used historically to measure rice"},
/* 0D50 */ { NULL,NULL},
/* 0D51 */ { NULL,NULL},
/* 0D52 */ { NULL,NULL},
/* 0D53 */ { NULL,NULL},
/* 0D54 */ { "MALAYALAM LETTER CHILLU M",NULL},
/* 0D55 */ { "MALAYALAM LETTER CHILLU Y",NULL},
/* 0D56 */ { "MALAYALAM LETTER CHILLU LLL",NULL},
/* 0D57 */ { "MALAYALAM AU LENGTH MARK","	* used alone to write the /au/ dependent vowel in modern texts\n"
	"	x (malayalam vowel sign au - 0D4C)"},
/* 0D58 */ { "MALAYALAM FRACTION ONE ONE-HUNDRED-AND-SIXTIETH","	= arakaani"},
/* 0D59 */ { "MALAYALAM FRACTION ONE FORTIETH","	= aramaa"},
/* 0D5A */ { "MALAYALAM FRACTION THREE EIGHTIETHS","	= muunnukaani"},
/* 0D5B */ { "MALAYALAM FRACTION ONE TWENTIETH","	= orumaa"},
/* 0D5C */ { "MALAYALAM FRACTION ONE TENTH","	= rantumaa"},
/* 0D5D */ { "MALAYALAM FRACTION THREE TWENTIETHS","	= muunnumaa"},
/* 0D5E */ { "MALAYALAM FRACTION ONE FIFTH","	= naalumaa"},
/* 0D5F */ { "MALAYALAM LETTER ARCHAIC II",NULL},
/* 0D60 */ { "MALAYALAM LETTER VOCALIC RR",NULL},
/* 0D61 */ { "MALAYALAM LETTER VOCALIC LL",NULL},
/* 0D62 */ { "MALAYALAM VOWEL SIGN VOCALIC L",NULL},
/* 0D63 */ { "MALAYALAM VOWEL SIGN VOCALIC LL",NULL},
/* 0D64 */ { NULL,"	x (devanagari danda - 0964)"},
/* 0D65 */ { NULL,"	x (devanagari double danda - 0965)"},
/* 0D66 */ { "MALAYALAM DIGIT ZERO",NULL},
/* 0D67 */ { "MALAYALAM DIGIT ONE",NULL},
/* 0D68 */ { "MALAYALAM DIGIT TWO",NULL},
/* 0D69 */ { "MALAYALAM DIGIT THREE",NULL},
/* 0D6A */ { "MALAYALAM DIGIT FOUR",NULL},
/* 0D6B */ { "MALAYALAM DIGIT FIVE",NULL},
/* 0D6C */ { "MALAYALAM DIGIT SIX",NULL},
/* 0D6D */ { "MALAYALAM DIGIT SEVEN",NULL},
/* 0D6E */ { "MALAYALAM DIGIT EIGHT",NULL},
/* 0D6F */ { "MALAYALAM DIGIT NINE",NULL},
/* 0D70 */ { "MALAYALAM NUMBER TEN",NULL},
/* 0D71 */ { "MALAYALAM NUMBER ONE HUNDRED",NULL},
/* 0D72 */ { "MALAYALAM NUMBER ONE THOUSAND",NULL},
/* 0D73 */ { "MALAYALAM FRACTION ONE QUARTER","	= kaal\n"
	"	x (north indic fraction one quarter - A830)"},
/* 0D74 */ { "MALAYALAM FRACTION ONE HALF","	= ara\n"
	"	x (north indic fraction one half - A831)"},
/* 0D75 */ { "MALAYALAM FRACTION THREE QUARTERS","	= mukkaal\n"
	"	x (north indic fraction three quarters - A832)"},
/* 0D76 */ { "MALAYALAM FRACTION ONE SIXTEENTH","	= maakaani"},
/* 0D77 */ { "MALAYALAM FRACTION ONE EIGHTH","	= arakkaal"},
/* 0D78 */ { "MALAYALAM FRACTION THREE SIXTEENTHS","	= muntaani"},
/* 0D79 */ { "MALAYALAM DATE MARK",NULL},
/* 0D7A */ { "MALAYALAM LETTER CHILLU NN",NULL},
/* 0D7B */ { "MALAYALAM LETTER CHILLU N",NULL},
/* 0D7C */ { "MALAYALAM LETTER CHILLU RR","	* historically derived from the full letter ra\n"
	"	* also used for chillu r"},
/* 0D7D */ { "MALAYALAM LETTER CHILLU L","	* historically derived from the full letter ta\n"
	"	* used for chillu t and chillu d"},
/* 0D7E */ { "MALAYALAM LETTER CHILLU LL",NULL},
/* 0D7F */ { "MALAYALAM LETTER CHILLU K",NULL},
/* 0D80 */ { NULL,NULL},
/* 0D81 */ { "SINHALA SIGN CANDRABINDU","	* used in Sanskrit"},
/* 0D82 */ { "SINHALA SIGN ANUSVARAYA","	= anusvara"},
/* 0D83 */ { "SINHALA SIGN VISARGAYA","	= visarga"},
/* 0D84 */ { NULL,NULL},
/* 0D85 */ { "SINHALA LETTER AYANNA","	= sinhala letter a"},
/* 0D86 */ { "SINHALA LETTER AAYANNA","	= sinhala letter aa"},
/* 0D87 */ { "SINHALA LETTER AEYANNA","	= sinhala letter ae"},
/* 0D88 */ { "SINHALA LETTER AEEYANNA","	= sinhala letter aae"},
/* 0D89 */ { "SINHALA LETTER IYANNA","	= sinhala letter i"},
/* 0D8A */ { "SINHALA LETTER IIYANNA","	= sinhala letter ii"},
/* 0D8B */ { "SINHALA LETTER UYANNA","	= sinhala letter u"},
/* 0D8C */ { "SINHALA LETTER UUYANNA","	= sinhala letter uu"},
/* 0D8D */ { "SINHALA LETTER IRUYANNA","	= sinhala letter vocalic r"},
/* 0D8E */ { "SINHALA LETTER IRUUYANNA","	= sinhala letter vocalic rr"},
/* 0D8F */ { "SINHALA LETTER ILUYANNA","	= sinhala letter vocalic l"},
/* 0D90 */ { "SINHALA LETTER ILUUYANNA","	= sinhala letter vocalic ll"},
/* 0D91 */ { "SINHALA LETTER EYANNA","	= sinhala letter e"},
/* 0D92 */ { "SINHALA LETTER EEYANNA","	= sinhala letter ee"},
/* 0D93 */ { "SINHALA LETTER AIYANNA","	= sinhala letter ai"},
/* 0D94 */ { "SINHALA LETTER OYANNA","	= sinhala letter o"},
/* 0D95 */ { "SINHALA LETTER OOYANNA","	= sinhala letter oo"},
/* 0D96 */ { "SINHALA LETTER AUYANNA","	= sinhala letter au"},
/* 0D97 */ { NULL,NULL},
/* 0D98 */ { NULL,NULL},
/* 0D99 */ { NULL,NULL},
/* 0D9A */ { "SINHALA LETTER ALPAPRAANA KAYANNA","	= sinhala letter ka"},
/* 0D9B */ { "SINHALA LETTER MAHAAPRAANA KAYANNA","	= sinhala letter kha"},
/* 0D9C */ { "SINHALA LETTER ALPAPRAANA GAYANNA","	= sinhala letter ga"},
/* 0D9D */ { "SINHALA LETTER MAHAAPRAANA GAYANNA","	= sinhala letter gha"},
/* 0D9E */ { "SINHALA LETTER KANTAJA NAASIKYAYA","	= sinhala letter nga"},
/* 0D9F */ { "SINHALA LETTER SANYAKA GAYANNA","	= sinhala letter nnga"},
/* 0DA0 */ { "SINHALA LETTER ALPAPRAANA CAYANNA","	= sinhala letter ca"},
/* 0DA1 */ { "SINHALA LETTER MAHAAPRAANA CAYANNA","	= sinhala letter cha"},
/* 0DA2 */ { "SINHALA LETTER ALPAPRAANA JAYANNA","	= sinhala letter ja"},
/* 0DA3 */ { "SINHALA LETTER MAHAAPRAANA JAYANNA","	= sinhala letter jha"},
/* 0DA4 */ { "SINHALA LETTER TAALUJA NAASIKYAYA","	= sinhala letter nya"},
/* 0DA5 */ { "SINHALA LETTER TAALUJA SANYOOGA NAAKSIKYAYA","	= sinhala letter jnya"},
/* 0DA6 */ { "SINHALA LETTER SANYAKA JAYANNA","	= sinhala letter nyja"},
/* 0DA7 */ { "SINHALA LETTER ALPAPRAANA TTAYANNA","	= sinhala letter tta"},
/* 0DA8 */ { "SINHALA LETTER MAHAAPRAANA TTAYANNA","	= sinhala letter ttha"},
/* 0DA9 */ { "SINHALA LETTER ALPAPRAANA DDAYANNA","	= sinhala letter dda"},
/* 0DAA */ { "SINHALA LETTER MAHAAPRAANA DDAYANNA","	= sinhala letter ddha"},
/* 0DAB */ { "SINHALA LETTER MUURDHAJA NAYANNA","	= sinhala letter nna"},
/* 0DAC */ { "SINHALA LETTER SANYAKA DDAYANNA","	= sinhala letter nndda"},
/* 0DAD */ { "SINHALA LETTER ALPAPRAANA TAYANNA","	= sinhala letter ta"},
/* 0DAE */ { "SINHALA LETTER MAHAAPRAANA TAYANNA","	= sinhala letter tha"},
/* 0DAF */ { "SINHALA LETTER ALPAPRAANA DAYANNA","	= sinhala letter da"},
/* 0DB0 */ { "SINHALA LETTER MAHAAPRAANA DAYANNA","	= sinhala letter dha"},
/* 0DB1 */ { "SINHALA LETTER DANTAJA NAYANNA","	= sinhala letter na"},
/* 0DB2 */ { NULL,NULL},
/* 0DB3 */ { "SINHALA LETTER SANYAKA DAYANNA","	= sinhala letter nda"},
/* 0DB4 */ { "SINHALA LETTER ALPAPRAANA PAYANNA","	= sinhala letter pa"},
/* 0DB5 */ { "SINHALA LETTER MAHAAPRAANA PAYANNA","	= sinhala letter pha"},
/* 0DB6 */ { "SINHALA LETTER ALPAPRAANA BAYANNA","	= sinhala letter ba"},
/* 0DB7 */ { "SINHALA LETTER MAHAAPRAANA BAYANNA","	= sinhala letter bha"},
/* 0DB8 */ { "SINHALA LETTER MAYANNA","	= sinhala letter ma"},
/* 0DB9 */ { "SINHALA LETTER AMBA BAYANNA","	= sinhala letter mba"},
/* 0DBA */ { "SINHALA LETTER YAYANNA","	= sinhala letter ya"},
/* 0DBB */ { "SINHALA LETTER RAYANNA","	= sinhala letter ra"},
/* 0DBC */ { NULL,NULL},
/* 0DBD */ { "SINHALA LETTER DANTAJA LAYANNA","	= sinhala letter la\n"
	"	* dental"},
/* 0DBE */ { NULL,NULL},
/* 0DBF */ { NULL,NULL},
/* 0DC0 */ { "SINHALA LETTER VAYANNA","	= sinhala letter va"},
/* 0DC1 */ { "SINHALA LETTER TAALUJA SAYANNA","	= sinhala letter sha"},
/* 0DC2 */ { "SINHALA LETTER MUURDHAJA SAYANNA","	= sinhala letter ssa\n"
	"	* retroflex"},
/* 0DC3 */ { "SINHALA LETTER DANTAJA SAYANNA","	= sinhala letter sa\n"
	"	* dental"},
/* 0DC4 */ { "SINHALA LETTER HAYANNA","	= sinhala letter ha"},
/* 0DC5 */ { "SINHALA LETTER MUURDHAJA LAYANNA","	= sinhala letter lla\n"
	"	* retroflex"},
/* 0DC6 */ { "SINHALA LETTER FAYANNA","	= sinhala letter fa"},
/* 0DC7 */ { NULL,NULL},
/* 0DC8 */ { NULL,NULL},
/* 0DC9 */ { NULL,NULL},
/* 0DCA */ { "SINHALA SIGN AL-LAKUNA","	= virama"},
/* 0DCB */ { NULL,NULL},
/* 0DCC */ { NULL,NULL},
/* 0DCD */ { NULL,NULL},
/* 0DCE */ { NULL,NULL},
/* 0DCF */ { "SINHALA VOWEL SIGN AELA-PILLA","	= sinhala vowel sign aa"},
/* 0DD0 */ { "SINHALA VOWEL SIGN KETTI AEDA-PILLA","	= sinhala vowel sign ae"},
/* 0DD1 */ { "SINHALA VOWEL SIGN DIGA AEDA-PILLA","	= sinhala vowel sign aae"},
/* 0DD2 */ { "SINHALA VOWEL SIGN KETTI IS-PILLA","	= sinhala vowel sign i"},
/* 0DD3 */ { "SINHALA VOWEL SIGN DIGA IS-PILLA","	= sinhala vowel sign ii"},
/* 0DD4 */ { "SINHALA VOWEL SIGN KETTI PAA-PILLA","	= sinhala vowel sign u"},
/* 0DD5 */ { NULL,NULL},
/* 0DD6 */ { "SINHALA VOWEL SIGN DIGA PAA-PILLA","	= sinhala vowel sign uu"},
/* 0DD7 */ { NULL,NULL},
/* 0DD8 */ { "SINHALA VOWEL SIGN GAETTA-PILLA","	= sinhala vowel sign vocalic r"},
/* 0DD9 */ { "SINHALA VOWEL SIGN KOMBUVA","	= sinhala vowel sign e"},
/* 0DDA */ { "SINHALA VOWEL SIGN DIGA KOMBUVA","	= sinhala vowel sign ee\n"
	"	: 0DD9 0DCA"},
/* 0DDB */ { "SINHALA VOWEL SIGN KOMBU DEKA","	= sinhala vowel sign ai"},
/* 0DDC */ { "SINHALA VOWEL SIGN KOMBUVA HAA AELA-PILLA","	= sinhala vowel sign o\n"
	"	: 0DD9 0DCF"},
/* 0DDD */ { "SINHALA VOWEL SIGN KOMBUVA HAA DIGA AELA-PILLA","	= sinhala vowel sign oo\n"
	"	: 0DDC 0DCA"},
/* 0DDE */ { "SINHALA VOWEL SIGN KOMBUVA HAA GAYANUKITTA","	= sinhala vowel sign au\n"
	"	: 0DD9 0DDF"},
/* 0DDF */ { "SINHALA VOWEL SIGN GAYANUKITTA","	= sinhala vowel sign vocalic l"},
/* 0DE0 */ { NULL,NULL},
/* 0DE1 */ { NULL,NULL},
/* 0DE2 */ { NULL,NULL},
/* 0DE3 */ { NULL,NULL},
/* 0DE4 */ { NULL,NULL},
/* 0DE5 */ { NULL,NULL},
/* 0DE6 */ { "SINHALA LITH DIGIT ZERO",NULL},
/* 0DE7 */ { "SINHALA LITH DIGIT ONE",NULL},
/* 0DE8 */ { "SINHALA LITH DIGIT TWO",NULL},
/* 0DE9 */ { "SINHALA LITH DIGIT THREE",NULL},
/* 0DEA */ { "SINHALA LITH DIGIT FOUR",NULL},
/* 0DEB */ { "SINHALA LITH DIGIT FIVE",NULL},
/* 0DEC */ { "SINHALA LITH DIGIT SIX",NULL},
/* 0DED */ { "SINHALA LITH DIGIT SEVEN",NULL},
/* 0DEE */ { "SINHALA LITH DIGIT EIGHT",NULL},
/* 0DEF */ { "SINHALA LITH DIGIT NINE",NULL},
/* 0DF0 */ { NULL,NULL},
/* 0DF1 */ { NULL,NULL},
/* 0DF2 */ { "SINHALA VOWEL SIGN DIGA GAETTA-PILLA","	= sinhala vowel sign vocalic rr"},
/* 0DF3 */ { "SINHALA VOWEL SIGN DIGA GAYANUKITTA","	= sinhala vowel sign vocalic ll"},
/* 0DF4 */ { "SINHALA PUNCTUATION KUNDDALIYA","	x (tamil punctuation end of text - 11FFF)"},
/* 0DF5 */ { NULL,NULL},
/* 0DF6 */ { NULL,NULL},
/* 0DF7 */ { NULL,NULL},
/* 0DF8 */ { NULL,NULL},
/* 0DF9 */ { NULL,NULL},
/* 0DFA */ { NULL,NULL},
/* 0DFB */ { NULL,NULL},
/* 0DFC */ { NULL,NULL},
/* 0DFD */ { NULL,NULL},
/* 0DFE */ { NULL,NULL},
/* 0DFF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_00_0E[] = {
/* 0E00 */ { NULL,NULL},
/* 0E01 */ { "THAI CHARACTER KO KAI",NULL},
/* 0E02 */ { "THAI CHARACTER KHO KHAI",NULL},
/* 0E03 */ { "THAI CHARACTER KHO KHUAT",NULL},
/* 0E04 */ { "THAI CHARACTER KHO KHWAI",NULL},
/* 0E05 */ { "THAI CHARACTER KHO KHON",NULL},
/* 0E06 */ { "THAI CHARACTER KHO RAKHANG",NULL},
/* 0E07 */ { "THAI CHARACTER NGO NGU",NULL},
/* 0E08 */ { "THAI CHARACTER CHO CHAN",NULL},
/* 0E09 */ { "THAI CHARACTER CHO CHING",NULL},
/* 0E0A */ { "THAI CHARACTER CHO CHANG",NULL},
/* 0E0B */ { "THAI CHARACTER SO SO",NULL},
/* 0E0C */ { "THAI CHARACTER CHO CHOE",NULL},
/* 0E0D */ { "THAI CHARACTER YO YING",NULL},
/* 0E0E */ { "THAI CHARACTER DO CHADA",NULL},
/* 0E0F */ { "THAI CHARACTER TO PATAK",NULL},
/* 0E10 */ { "THAI CHARACTER THO THAN",NULL},
/* 0E11 */ { "THAI CHARACTER THO NANGMONTHO",NULL},
/* 0E12 */ { "THAI CHARACTER THO PHUTHAO",NULL},
/* 0E13 */ { "THAI CHARACTER NO NEN",NULL},
/* 0E14 */ { "THAI CHARACTER DO DEK",NULL},
/* 0E15 */ { "THAI CHARACTER TO TAO",NULL},
/* 0E16 */ { "THAI CHARACTER THO THUNG",NULL},
/* 0E17 */ { "THAI CHARACTER THO THAHAN",NULL},
/* 0E18 */ { "THAI CHARACTER THO THONG",NULL},
/* 0E19 */ { "THAI CHARACTER NO NU",NULL},
/* 0E1A */ { "THAI CHARACTER BO BAIMAI",NULL},
/* 0E1B */ { "THAI CHARACTER PO PLA",NULL},
/* 0E1C */ { "THAI CHARACTER PHO PHUNG",NULL},
/* 0E1D */ { "THAI CHARACTER FO FA",NULL},
/* 0E1E */ { "THAI CHARACTER PHO PHAN",NULL},
/* 0E1F */ { "THAI CHARACTER FO FAN",NULL},
/* 0E20 */ { "THAI CHARACTER PHO SAMPHAO",NULL},
/* 0E21 */ { "THAI CHARACTER MO MA",NULL},
/* 0E22 */ { "THAI CHARACTER YO YAK",NULL},
/* 0E23 */ { "THAI CHARACTER RO RUA",NULL},
/* 0E24 */ { "THAI CHARACTER RU","	* independent vowel letter used to write Sanskrit"},
/* 0E25 */ { "THAI CHARACTER LO LING",NULL},
/* 0E26 */ { "THAI CHARACTER LU","	* independent vowel letter used to write Sanskrit"},
/* 0E27 */ { "THAI CHARACTER WO WAEN",NULL},
/* 0E28 */ { "THAI CHARACTER SO SALA",NULL},
/* 0E29 */ { "THAI CHARACTER SO RUSI",NULL},
/* 0E2A */ { "THAI CHARACTER SO SUA",NULL},
/* 0E2B */ { "THAI CHARACTER HO HIP",NULL},
/* 0E2C */ { "THAI CHARACTER LO CHULA",NULL},
/* 0E2D */ { "THAI CHARACTER O ANG",NULL},
/* 0E2E */ { "THAI CHARACTER HO NOKHUK","	= ho nok huk"},
/* 0E2F */ { "THAI CHARACTER PAIYANNOI","	= paiyan noi\n"
	"	* ellipsis, abbreviation"},
/* 0E30 */ { "THAI CHARACTER SARA A",NULL},
/* 0E31 */ { "THAI CHARACTER MAI HAN-AKAT",NULL},
/* 0E32 */ { "THAI CHARACTER SARA AA","	x (thai character lakkhangyao - 0E45)"},
/* 0E33 */ { "THAI CHARACTER SARA AM","	# 0E4D 0E32"},
/* 0E34 */ { "THAI CHARACTER SARA I",NULL},
/* 0E35 */ { "THAI CHARACTER SARA II",NULL},
/* 0E36 */ { "THAI CHARACTER SARA UE",NULL},
/* 0E37 */ { "THAI CHARACTER SARA UEE","	= sara uue"},
/* 0E38 */ { "THAI CHARACTER SARA U",NULL},
/* 0E39 */ { "THAI CHARACTER SARA UU",NULL},
/* 0E3A */ { "THAI CHARACTER PHINTHU","	* Pali virama"},
/* 0E3B */ { NULL,NULL},
/* 0E3C */ { NULL,NULL},
/* 0E3D */ { NULL,NULL},
/* 0E3E */ { NULL,NULL},
/* 0E3F */ { "THAI CURRENCY SYMBOL BAHT",NULL},
/* 0E40 */ { "THAI CHARACTER SARA E",NULL},
/* 0E41 */ { "THAI CHARACTER SARA AE",NULL},
/* 0E42 */ { "THAI CHARACTER SARA O",NULL},
/* 0E43 */ { "THAI CHARACTER SARA AI MAIMUAN","	= sara ai mai muan"},
/* 0E44 */ { "THAI CHARACTER SARA AI MAIMALAI","	= sara ai mai malai"},
/* 0E45 */ { "THAI CHARACTER LAKKHANGYAO","	= lakkhang yao\n"
	"	* special vowel length indication used with 0E24 or 0E26\n"
	"	x (thai character sara aa - 0E32)"},
/* 0E46 */ { "THAI CHARACTER MAIYAMOK","	= mai yamok\n"
	"	* repetition"},
/* 0E47 */ { "THAI CHARACTER MAITAIKHU","	= mai taikhu"},
/* 0E48 */ { "THAI CHARACTER MAI EK",NULL},
/* 0E49 */ { "THAI CHARACTER MAI THO",NULL},
/* 0E4A */ { "THAI CHARACTER MAI TRI",NULL},
/* 0E4B */ { "THAI CHARACTER MAI CHATTAWA",NULL},
/* 0E4C */ { "THAI CHARACTER THANTHAKHAT","	* cancellation mark\n"
	"	x (khmer sign toandakhiat - 17CD)"},
/* 0E4D */ { "THAI CHARACTER NIKHAHIT","	= nikkhahit\n"
	"	* final nasal"},
/* 0E4E */ { "THAI CHARACTER YAMAKKAN","	x (lao yamakkan - 0ECE)"},
/* 0E4F */ { "THAI CHARACTER FONGMAN","	* used as a bullet\n"
	"	x (khmer sign phnaek muan - 17D9)"},
/* 0E50 */ { "THAI DIGIT ZERO",NULL},
/* 0E51 */ { "THAI DIGIT ONE",NULL},
/* 0E52 */ { "THAI DIGIT TWO",NULL},
/* 0E53 */ { "THAI DIGIT THREE",NULL},
/* 0E54 */ { "THAI DIGIT FOUR",NULL},
/* 0E55 */ { "THAI DIGIT FIVE",NULL},
/* 0E56 */ { "THAI DIGIT SIX",NULL},
/* 0E57 */ { "THAI DIGIT SEVEN",NULL},
/* 0E58 */ { "THAI DIGIT EIGHT",NULL},
/* 0E59 */ { "THAI DIGIT NINE",NULL},
/* 0E5A */ { "THAI CHARACTER ANGKHANKHU","	* used to mark end of long sections\n"
	"	* used in combination with 0E30 to mark end of a verse"},
/* 0E5B */ { "THAI CHARACTER KHOMUT","	* used to mark end of chapter or document\n"
	"	x (khmer sign koomuut - 17DA)"},
/* 0E5C */ { NULL,NULL},
/* 0E5D */ { NULL,NULL},
/* 0E5E */ { NULL,NULL},
/* 0E5F */ { NULL,NULL},
/* 0E60 */ { NULL,NULL},
/* 0E61 */ { NULL,NULL},
/* 0E62 */ { NULL,NULL},
/* 0E63 */ { NULL,NULL},
/* 0E64 */ { NULL,NULL},
/* 0E65 */ { NULL,NULL},
/* 0E66 */ { NULL,NULL},
/* 0E67 */ { NULL,NULL},
/* 0E68 */ { NULL,NULL},
/* 0E69 */ { NULL,NULL},
/* 0E6A */ { NULL,NULL},
/* 0E6B */ { NULL,NULL},
/* 0E6C */ { NULL,NULL},
/* 0E6D */ { NULL,NULL},
/* 0E6E */ { NULL,NULL},
/* 0E6F */ { NULL,NULL},
/* 0E70 */ { NULL,NULL},
/* 0E71 */ { NULL,NULL},
/* 0E72 */ { NULL,NULL},
/* 0E73 */ { NULL,NULL},
/* 0E74 */ { NULL,NULL},
/* 0E75 */ { NULL,NULL},
/* 0E76 */ { NULL,NULL},
/* 0E77 */ { NULL,NULL},
/* 0E78 */ { NULL,NULL},
/* 0E79 */ { NULL,NULL},
/* 0E7A */ { NULL,NULL},
/* 0E7B */ { NULL,NULL},
/* 0E7C */ { NULL,NULL},
/* 0E7D */ { NULL,NULL},
/* 0E7E */ { NULL,NULL},
/* 0E7F */ { NULL,NULL},
/* 0E80 */ { NULL,NULL},
/* 0E81 */ { "LAO LETTER KO","	= ko kay"},
/* 0E82 */ { "LAO LETTER KHO SUNG","	= kho khay"},
/* 0E83 */ { NULL,NULL},
/* 0E84 */ { "LAO LETTER KHO TAM","	= kho khuay"},
/* 0E85 */ { NULL,NULL},
/* 0E86 */ { "LAO LETTER PALI GHA",NULL},
/* 0E87 */ { "LAO LETTER NGO","	= ngo ngu, ngo ngua"},
/* 0E88 */ { "LAO LETTER CO","	= co cok, co cua"},
/* 0E89 */ { "LAO LETTER PALI CHA",NULL},
/* 0E8A */ { "LAO LETTER SO TAM","	= so sang"},
/* 0E8B */ { NULL,NULL},
/* 0E8C */ { "LAO LETTER PALI JHA",NULL},
/* 0E8D */ { "LAO LETTER NYO","	= nyo nyung"},
/* 0E8E */ { "LAO LETTER PALI NYA",NULL},
/* 0E8F */ { "LAO LETTER PALI TTA",NULL},
/* 0E90 */ { "LAO LETTER PALI TTHA",NULL},
/* 0E91 */ { "LAO LETTER PALI DDA",NULL},
/* 0E92 */ { "LAO LETTER PALI DDHA",NULL},
/* 0E93 */ { "LAO LETTER PALI NNA",NULL},
/* 0E94 */ { "LAO LETTER DO","	= do dek"},
/* 0E95 */ { "LAO LETTER TO","	= to ta"},
/* 0E96 */ { "LAO LETTER THO SUNG","	= tho thong"},
/* 0E97 */ { "LAO LETTER THO TAM","	= tho thung"},
/* 0E98 */ { "LAO LETTER PALI DHA",NULL},
/* 0E99 */ { "LAO LETTER NO","	= no nok"},
/* 0E9A */ { "LAO LETTER BO","	= bo be, bo bet"},
/* 0E9B */ { "LAO LETTER PO","	= po pa"},
/* 0E9C */ { "LAO LETTER PHO SUNG","	= pho pheng"},
/* 0E9D */ { "LAO LETTER FO TAM","	% LAO LETTER FO FON\n"
	"	= fo fa\n"
	"	* name is a mistake for fo sung"},
/* 0E9E */ { "LAO LETTER PHO TAM","	= pho phu"},
/* 0E9F */ { "LAO LETTER FO SUNG","	% LAO LETTER FO FAY\n"
	"	* name is a mistake for fo tam"},
/* 0EA0 */ { "LAO LETTER PALI BHA",NULL},
/* 0EA1 */ { "LAO LETTER MO","	= mo mew, mo ma"},
/* 0EA2 */ { "LAO LETTER YO","	= yo ya"},
/* 0EA3 */ { "LAO LETTER LO LING","	% LAO LETTER RO\n"
	"	= ro rot\n"
	"	* name is a mistake, lo ling is the mnemonic for 0EA5"},
/* 0EA4 */ { NULL,NULL},
/* 0EA5 */ { "LAO LETTER LO LOOT","	% LAO LETTER LO\n"
	"	= lo ling\n"
	"	* name is a mistake, lo loot is the mnemonic for 0EA3"},
/* 0EA6 */ { NULL,NULL},
/* 0EA7 */ { "LAO LETTER WO","	= wo wi"},
/* 0EA8 */ { "LAO LETTER SANSKRIT SHA",NULL},
/* 0EA9 */ { "LAO LETTER SANSKRIT SSA",NULL},
/* 0EAA */ { "LAO LETTER SO SUNG","	= so sya"},
/* 0EAB */ { "LAO LETTER HO SUNG","	= ho hay, ho han"},
/* 0EAC */ { "LAO LETTER PALI LLA",NULL},
/* 0EAD */ { "LAO LETTER O","	= o o"},
/* 0EAE */ { "LAO LETTER HO TAM","	= ho hya, ho hyan"},
/* 0EAF */ { "LAO ELLIPSIS",NULL},
/* 0EB0 */ { "LAO VOWEL SIGN A",NULL},
/* 0EB1 */ { "LAO VOWEL SIGN MAI KAN","	* vowel shortener"},
/* 0EB2 */ { "LAO VOWEL SIGN AA",NULL},
/* 0EB3 */ { "LAO VOWEL SIGN AM","	# 0ECD 0EB2"},
/* 0EB4 */ { "LAO VOWEL SIGN I",NULL},
/* 0EB5 */ { "LAO VOWEL SIGN II",NULL},
/* 0EB6 */ { "LAO VOWEL SIGN Y",NULL},
/* 0EB7 */ { "LAO VOWEL SIGN YY",NULL},
/* 0EB8 */ { "LAO VOWEL SIGN U",NULL},
/* 0EB9 */ { "LAO VOWEL SIGN UU",NULL},
/* 0EBA */ { "LAO SIGN PALI VIRAMA",NULL},
/* 0EBB */ { "LAO VOWEL SIGN MAI KON","	= mai kong"},
/* 0EBC */ { "LAO SEMIVOWEL SIGN LO",NULL},
/* 0EBD */ { "LAO SEMIVOWEL SIGN NYO","	= nyo fyang"},
/* 0EBE */ { NULL,NULL},
/* 0EBF */ { NULL,NULL},
/* 0EC0 */ { "LAO VOWEL SIGN E",NULL},
/* 0EC1 */ { "LAO VOWEL SIGN EI",NULL},
/* 0EC2 */ { "LAO VOWEL SIGN O",NULL},
/* 0EC3 */ { "LAO VOWEL SIGN AY","	= mai muan"},
/* 0EC4 */ { "LAO VOWEL SIGN AI","	= mai may"},
/* 0EC5 */ { NULL,NULL},
/* 0EC6 */ { "LAO KO LA","	* repetition"},
/* 0EC7 */ { NULL,NULL},
/* 0EC8 */ { "LAO TONE MAI EK",NULL},
/* 0EC9 */ { "LAO TONE MAI THO",NULL},
/* 0ECA */ { "LAO TONE MAI TI",NULL},
/* 0ECB */ { "LAO TONE MAI CATAWA",NULL},
/* 0ECC */ { "LAO CANCELLATION MARK",NULL},
/* 0ECD */ { "LAO NIGGAHITA","	* final nasal or long o vowel"},
/* 0ECE */ { "LAO YAMAKKAN","	* marks a consonant that is simultaneously a part of two consonant clusters in Pali text\n"
	"	x (thai character yamakkan - 0E4E)"},
/* 0ECF */ { NULL,NULL},
/* 0ED0 */ { "LAO DIGIT ZERO",NULL},
/* 0ED1 */ { "LAO DIGIT ONE",NULL},
/* 0ED2 */ { "LAO DIGIT TWO",NULL},
/* 0ED3 */ { "LAO DIGIT THREE",NULL},
/* 0ED4 */ { "LAO DIGIT FOUR",NULL},
/* 0ED5 */ { "LAO DIGIT FIVE",NULL},
/* 0ED6 */ { "LAO DIGIT SIX",NULL},
/* 0ED7 */ { "LAO DIGIT SEVEN",NULL},
/* 0ED8 */ { "LAO DIGIT EIGHT",NULL},
/* 0ED9 */ { "LAO DIGIT NINE",NULL},
/* 0EDA */ { NULL,NULL},
/* 0EDB */ { NULL,NULL},
/* 0EDC */ { "LAO HO NO","	# 0EAB 0E99"},
/* 0EDD */ { "LAO HO MO","	# 0EAB 0EA1"},
/* 0EDE */ { "LAO LETTER KHMU GO",NULL},
/* 0EDF */ { "LAO LETTER KHMU NYO",NULL},
/* 0EE0 */ { NULL,NULL},
/* 0EE1 */ { NULL,NULL},
/* 0EE2 */ { NULL,NULL},
/* 0EE3 */ { NULL,NULL},
/* 0EE4 */ { NULL,NULL},
/* 0EE5 */ { NULL,NULL},
/* 0EE6 */ { NULL,NULL},
/* 0EE7 */ { NULL,NULL},
/* 0EE8 */ { NULL,NULL},
/* 0EE9 */ { NULL,NULL},
/* 0EEA */ { NULL,NULL},
/* 0EEB */ { NULL,NULL},
/* 0EEC */ { NULL,NULL},
/* 0EED */ { NULL,NULL},
/* 0EEE */ { NULL,NULL},
/* 0EEF */ { NULL,NULL},
/* 0EF0 */ { NULL,NULL},
/* 0EF1 */ { NULL,NULL},
/* 0EF2 */ { NULL,NULL},
/* 0EF3 */ { NULL,NULL},
/* 0EF4 */ { NULL,NULL},
/* 0EF5 */ { NULL,NULL},
/* 0EF6 */ { NULL,NULL},
/* 0EF7 */ { NULL,NULL},
/* 0EF8 */ { NULL,NULL},
/* 0EF9 */ { NULL,NULL},
/* 0EFA */ { NULL,NULL},
/* 0EFB */ { NULL,NULL},
/* 0EFC */ { NULL,NULL},
/* 0EFD */ { NULL,NULL},
/* 0EFE */ { NULL,NULL},
/* 0EFF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_00_0F[] = {
/* 0F00 */ { "TIBETAN SYLLABLE OM",NULL},
/* 0F01 */ { "TIBETAN MARK GTER YIG MGO TRUNCATED A",NULL},
/* 0F02 */ { "TIBETAN MARK GTER YIG MGO -UM RNAM BCAD MA",NULL},
/* 0F03 */ { "TIBETAN MARK GTER YIG MGO -UM GTER TSHEG MA",NULL},
/* 0F04 */ { "TIBETAN MARK INITIAL YIG MGO MDUN MA","	* honorific; marks beginning of text or start of new folio\n"
	"	x (mongolian birga - 1800)"},
/* 0F05 */ { "TIBETAN MARK CLOSING YIG MGO SGAB MA","	* follows and ligates with initial yig-mgo"},
/* 0F06 */ { "TIBETAN MARK CARET YIG MGO PHUR SHAD MA",NULL},
/* 0F07 */ { "TIBETAN MARK YIG MGO TSHEG SHAD MA",NULL},
/* 0F08 */ { "TIBETAN MARK SBRUL SHAD","	* separates sections of meaning equivalent to topics and sub-topics"},
/* 0F09 */ { "TIBETAN MARK BSKUR YIG MGO","	* list enumerator, used in Bhutan"},
/* 0F0A */ { "TIBETAN MARK BKA- SHOG YIG MGO","	* petition honorific, used in Bhutan"},
/* 0F0B */ { "TIBETAN MARK INTERSYLLABIC TSHEG","	= tsek\n"
	"	* morpheme delimiter (approximate meaning)\n"
	"	* the normal tsheg; provides a break opportunity\n"
	"	* character name is a misnomer"},
/* 0F0C */ { "TIBETAN MARK DELIMITER TSHEG BSTAR","	* a non-breaking tsheg; inhibits line breaking\n"
	"	* character name is a misnomer\n"
	"	# <noBreak> 0F0B"},
/* 0F0D */ { "TIBETAN MARK SHAD","	= shey\n"
	"	* marks end of a section of text (tshig-grub)\n"
	"	x (devanagari danda - 0964)"},
/* 0F0E */ { "TIBETAN MARK NYIS SHAD","	* marks end of a whole topic (don-tshan)\n"
	"	x (devanagari double danda - 0965)"},
/* 0F0F */ { "TIBETAN MARK TSHEG SHAD",NULL},
/* 0F10 */ { "TIBETAN MARK NYIS TSHEG SHAD",NULL},
/* 0F11 */ { "TIBETAN MARK RIN CHEN SPUNGS SHAD","	* shad which follows a tsheg-bar that starts a new line"},
/* 0F12 */ { "TIBETAN MARK RGYA GRAM SHAD",NULL},
/* 0F13 */ { "TIBETAN MARK CARET -DZUD RTAGS ME LONG CAN",NULL},
/* 0F14 */ { "TIBETAN MARK GTER TSHEG","	* used as a comma-like text delimiter\n"
	"	x (khmer sign camnuc pii kuuh - 17D6)"},
/* 0F15 */ { "TIBETAN LOGOTYPE SIGN CHAD RTAGS",NULL},
/* 0F16 */ { "TIBETAN LOGOTYPE SIGN LHAG RTAGS",NULL},
/* 0F17 */ { "TIBETAN ASTROLOGICAL SIGN SGRA GCAN -CHAR RTAGS",NULL},
/* 0F18 */ { "TIBETAN ASTROLOGICAL SIGN -KHYUD PA","	* combines with digits"},
/* 0F19 */ { "TIBETAN ASTROLOGICAL SIGN SDONG TSHUGS","	* combines with digits"},
/* 0F1A */ { "TIBETAN SIGN RDEL DKAR GCIG",NULL},
/* 0F1B */ { "TIBETAN SIGN RDEL DKAR GNYIS",NULL},
/* 0F1C */ { "TIBETAN SIGN RDEL DKAR GSUM","	x (alchemical symbol for oil - 1F746)"},
/* 0F1D */ { "TIBETAN SIGN RDEL NAG GCIG",NULL},
/* 0F1E */ { "TIBETAN SIGN RDEL NAG GNYIS",NULL},
/* 0F1F */ { "TIBETAN SIGN RDEL DKAR RDEL NAG","	= deka dena\n"
	"	* normally indicates a neutral fortune\n"
	"	* may also signify good luck earlier, bad luck later\n"
	"	x (tibetan sign rdel nag rdel dkar - 0FCE)"},
/* 0F20 */ { "TIBETAN DIGIT ZERO",NULL},
/* 0F21 */ { "TIBETAN DIGIT ONE",NULL},
/* 0F22 */ { "TIBETAN DIGIT TWO",NULL},
/* 0F23 */ { "TIBETAN DIGIT THREE",NULL},
/* 0F24 */ { "TIBETAN DIGIT FOUR",NULL},
/* 0F25 */ { "TIBETAN DIGIT FIVE",NULL},
/* 0F26 */ { "TIBETAN DIGIT SIX",NULL},
/* 0F27 */ { "TIBETAN DIGIT SEVEN",NULL},
/* 0F28 */ { "TIBETAN DIGIT EIGHT",NULL},
/* 0F29 */ { "TIBETAN DIGIT NINE",NULL},
/* 0F2A */ { "TIBETAN DIGIT HALF ONE",NULL},
/* 0F2B */ { "TIBETAN DIGIT HALF TWO",NULL},
/* 0F2C */ { "TIBETAN DIGIT HALF THREE",NULL},
/* 0F2D */ { "TIBETAN DIGIT HALF FOUR",NULL},
/* 0F2E */ { "TIBETAN DIGIT HALF FIVE",NULL},
/* 0F2F */ { "TIBETAN DIGIT HALF SIX",NULL},
/* 0F30 */ { "TIBETAN DIGIT HALF SEVEN",NULL},
/* 0F31 */ { "TIBETAN DIGIT HALF EIGHT",NULL},
/* 0F32 */ { "TIBETAN DIGIT HALF NINE",NULL},
/* 0F33 */ { "TIBETAN DIGIT HALF ZERO",NULL},
/* 0F34 */ { "TIBETAN MARK BSDUS RTAGS","	* repetition"},
/* 0F35 */ { "TIBETAN MARK NGAS BZUNG NYI ZLA","	* honorific, emphasis; used like underlining"},
/* 0F36 */ { "TIBETAN MARK CARET -DZUD RTAGS BZHI MIG CAN","	* marks point of text insertion or annotation"},
/* 0F37 */ { "TIBETAN MARK NGAS BZUNG SGOR RTAGS","	* emphasis; used like underlining"},
/* 0F38 */ { "TIBETAN MARK CHE MGO",NULL},
/* 0F39 */ { "TIBETAN MARK TSA -PHRU","	* a lenition mark"},
/* 0F3A */ { "TIBETAN MARK GUG RTAGS GYON",NULL},
/* 0F3B */ { "TIBETAN MARK GUG RTAGS GYAS","	* brackets"},
/* 0F3C */ { "TIBETAN MARK ANG KHANG GYON",NULL},
/* 0F3D */ { "TIBETAN MARK ANG KHANG GYAS","	* used for bracketing with a roof over"},
/* 0F3E */ { "TIBETAN SIGN YAR TSHES",NULL},
/* 0F3F */ { "TIBETAN SIGN MAR TSHES","	* marks which combine with digits"},
/* 0F40 */ { "TIBETAN LETTER KA",NULL},
/* 0F41 */ { "TIBETAN LETTER KHA",NULL},
/* 0F42 */ { "TIBETAN LETTER GA",NULL},
/* 0F43 */ { "TIBETAN LETTER GHA","	: 0F42 0FB7"},
/* 0F44 */ { "TIBETAN LETTER NGA",NULL},
/* 0F45 */ { "TIBETAN LETTER CA",NULL},
/* 0F46 */ { "TIBETAN LETTER CHA",NULL},
/* 0F47 */ { "TIBETAN LETTER JA",NULL},
/* 0F48 */ { NULL,NULL},
/* 0F49 */ { "TIBETAN LETTER NYA",NULL},
/* 0F4A */ { "TIBETAN LETTER TTA",NULL},
/* 0F4B */ { "TIBETAN LETTER TTHA",NULL},
/* 0F4C */ { "TIBETAN LETTER DDA",NULL},
/* 0F4D */ { "TIBETAN LETTER DDHA","	: 0F4C 0FB7"},
/* 0F4E */ { "TIBETAN LETTER NNA",NULL},
/* 0F4F */ { "TIBETAN LETTER TA",NULL},
/* 0F50 */ { "TIBETAN LETTER THA",NULL},
/* 0F51 */ { "TIBETAN LETTER DA",NULL},
/* 0F52 */ { "TIBETAN LETTER DHA","	: 0F51 0FB7"},
/* 0F53 */ { "TIBETAN LETTER NA",NULL},
/* 0F54 */ { "TIBETAN LETTER PA",NULL},
/* 0F55 */ { "TIBETAN LETTER PHA",NULL},
/* 0F56 */ { "TIBETAN LETTER BA",NULL},
/* 0F57 */ { "TIBETAN LETTER BHA","	: 0F56 0FB7"},
/* 0F58 */ { "TIBETAN LETTER MA",NULL},
/* 0F59 */ { "TIBETAN LETTER TSA",NULL},
/* 0F5A */ { "TIBETAN LETTER TSHA",NULL},
/* 0F5B */ { "TIBETAN LETTER DZA",NULL},
/* 0F5C */ { "TIBETAN LETTER DZHA","	: 0F5B 0FB7"},
/* 0F5D */ { "TIBETAN LETTER WA",NULL},
/* 0F5E */ { "TIBETAN LETTER ZHA",NULL},
/* 0F5F */ { "TIBETAN LETTER ZA",NULL},
/* 0F60 */ { "TIBETAN LETTER -A",NULL},
/* 0F61 */ { "TIBETAN LETTER YA",NULL},
/* 0F62 */ { "TIBETAN LETTER RA","	* when followed by a subjoined letter = ra mgo"},
/* 0F63 */ { "TIBETAN LETTER LA",NULL},
/* 0F64 */ { "TIBETAN LETTER SHA",NULL},
/* 0F65 */ { "TIBETAN LETTER SSA","	= reversed sha"},
/* 0F66 */ { "TIBETAN LETTER SA",NULL},
/* 0F67 */ { "TIBETAN LETTER HA",NULL},
/* 0F68 */ { "TIBETAN LETTER A","	* base for dependent vowels"},
/* 0F69 */ { "TIBETAN LETTER KSSA","	: 0F40 0FB5"},
/* 0F6A */ { "TIBETAN LETTER FIXED-FORM RA","	* fixed-form letter not showing the shape variation of the ordinary ra\n"
	"	* used only in transliteration and transcription\n"
	"	x (tibetan letter ra - 0F62)"},
/* 0F6B */ { "TIBETAN LETTER KKA",NULL},
/* 0F6C */ { "TIBETAN LETTER RRA",NULL},
/* 0F6D */ { NULL,NULL},
/* 0F6E */ { NULL,NULL},
/* 0F6F */ { NULL,NULL},
/* 0F70 */ { NULL,NULL},
/* 0F71 */ { "TIBETAN VOWEL SIGN AA","	= a-chung\n"
	"	* common, vowel-lengthening mark"},
/* 0F72 */ { "TIBETAN VOWEL SIGN I",NULL},
/* 0F73 */ { "TIBETAN VOWEL SIGN II","	* use of this character is discouraged\n"
	"	: 0F71 0F72"},
/* 0F74 */ { "TIBETAN VOWEL SIGN U",NULL},
/* 0F75 */ { "TIBETAN VOWEL SIGN UU","	* use of this character is discouraged\n"
	"	: 0F71 0F74"},
/* 0F76 */ { "TIBETAN VOWEL SIGN VOCALIC R","	: 0FB2 0F80"},
/* 0F77 */ { "TIBETAN VOWEL SIGN VOCALIC RR","	* this character is deprecated and its use is strongly discouraged\n"
	"	# 0FB2 0F81"},
/* 0F78 */ { "TIBETAN VOWEL SIGN VOCALIC L","	: 0FB3 0F80"},
/* 0F79 */ { "TIBETAN VOWEL SIGN VOCALIC LL","	* this character is deprecated and its use is strongly discouraged\n"
	"	# 0FB3 0F81"},
/* 0F7A */ { "TIBETAN VOWEL SIGN E",NULL},
/* 0F7B */ { "TIBETAN VOWEL SIGN EE",NULL},
/* 0F7C */ { "TIBETAN VOWEL SIGN O",NULL},
/* 0F7D */ { "TIBETAN VOWEL SIGN OO",NULL},
/* 0F7E */ { "TIBETAN SIGN RJES SU NGA RO","	= anusvara"},
/* 0F7F */ { "TIBETAN SIGN RNAM BCAD","	= visarga"},
/* 0F80 */ { "TIBETAN VOWEL SIGN REVERSED I",NULL},
/* 0F81 */ { "TIBETAN VOWEL SIGN REVERSED II","	* use of this character is discouraged\n"
	"	: 0F71 0F80"},
/* 0F82 */ { "TIBETAN SIGN NYI ZLA NAA DA",NULL},
/* 0F83 */ { "TIBETAN SIGN SNA LDAN","	x (devanagari sign candrabindu - 0901)"},
/* 0F84 */ { "TIBETAN MARK HALANTA","	= srog med\n"
	"	x (devanagari sign virama - 094D)"},
/* 0F85 */ { "TIBETAN MARK PALUTA","	* transliteration of Sanskrit avagraha\n"
	"	x (devanagari sign avagraha - 093D)"},
/* 0F86 */ { "TIBETAN SIGN LCI RTAGS",NULL},
/* 0F87 */ { "TIBETAN SIGN YANG RTAGS",NULL},
/* 0F88 */ { "TIBETAN SIGN LCE TSA CAN","	x (vedic sign jihvamuliya - 1CF5)\n"
	"	x (mongolian letter ali gali damaru - 1882)"},
/* 0F89 */ { "TIBETAN SIGN MCHU CAN","	x (vedic sign upadhmaniya - 1CF6)\n"
	"	x (mongolian letter ali gali inverted ubadama - 1884)"},
/* 0F8A */ { "TIBETAN SIGN GRU CAN RGYINGS","	* always followed by 0F82"},
/* 0F8B */ { "TIBETAN SIGN GRU MED RGYINGS",NULL},
/* 0F8C */ { "TIBETAN SIGN INVERTED MCHU CAN","	x (mongolian letter ali gali ubadama - 1883)"},
/* 0F8D */ { "TIBETAN SUBJOINED SIGN LCE TSA CAN",NULL},
/* 0F8E */ { "TIBETAN SUBJOINED SIGN MCHU CAN",NULL},
/* 0F8F */ { "TIBETAN SUBJOINED SIGN INVERTED MCHU CAN",NULL},
/* 0F90 */ { "TIBETAN SUBJOINED LETTER KA",NULL},
/* 0F91 */ { "TIBETAN SUBJOINED LETTER KHA",NULL},
/* 0F92 */ { "TIBETAN SUBJOINED LETTER GA",NULL},
/* 0F93 */ { "TIBETAN SUBJOINED LETTER GHA","	: 0F92 0FB7"},
/* 0F94 */ { "TIBETAN SUBJOINED LETTER NGA",NULL},
/* 0F95 */ { "TIBETAN SUBJOINED LETTER CA",NULL},
/* 0F96 */ { "TIBETAN SUBJOINED LETTER CHA",NULL},
/* 0F97 */ { "TIBETAN SUBJOINED LETTER JA",NULL},
/* 0F98 */ { NULL,NULL},
/* 0F99 */ { "TIBETAN SUBJOINED LETTER NYA",NULL},
/* 0F9A */ { "TIBETAN SUBJOINED LETTER TTA",NULL},
/* 0F9B */ { "TIBETAN SUBJOINED LETTER TTHA",NULL},
/* 0F9C */ { "TIBETAN SUBJOINED LETTER DDA",NULL},
/* 0F9D */ { "TIBETAN SUBJOINED LETTER DDHA","	: 0F9C 0FB7"},
/* 0F9E */ { "TIBETAN SUBJOINED LETTER NNA",NULL},
/* 0F9F */ { "TIBETAN SUBJOINED LETTER TA",NULL},
/* 0FA0 */ { "TIBETAN SUBJOINED LETTER THA",NULL},
/* 0FA1 */ { "TIBETAN SUBJOINED LETTER DA",NULL},
/* 0FA2 */ { "TIBETAN SUBJOINED LETTER DHA","	: 0FA1 0FB7"},
/* 0FA3 */ { "TIBETAN SUBJOINED LETTER NA",NULL},
/* 0FA4 */ { "TIBETAN SUBJOINED LETTER PA",NULL},
/* 0FA5 */ { "TIBETAN SUBJOINED LETTER PHA",NULL},
/* 0FA6 */ { "TIBETAN SUBJOINED LETTER BA",NULL},
/* 0FA7 */ { "TIBETAN SUBJOINED LETTER BHA","	: 0FA6 0FB7"},
/* 0FA8 */ { "TIBETAN SUBJOINED LETTER MA",NULL},
/* 0FA9 */ { "TIBETAN SUBJOINED LETTER TSA",NULL},
/* 0FAA */ { "TIBETAN SUBJOINED LETTER TSHA",NULL},
/* 0FAB */ { "TIBETAN SUBJOINED LETTER DZA",NULL},
/* 0FAC */ { "TIBETAN SUBJOINED LETTER DZHA","	: 0FAB 0FB7"},
/* 0FAD */ { "TIBETAN SUBJOINED LETTER WA","	= wa-zur, wa-btags (wa ta)"},
/* 0FAE */ { "TIBETAN SUBJOINED LETTER ZHA",NULL},
/* 0FAF */ { "TIBETAN SUBJOINED LETTER ZA",NULL},
/* 0FB0 */ { "TIBETAN SUBJOINED LETTER -A","	= a-chung\n"
	"	* rare, only used for full-sized subjoined letter\n"
	"	x (tibetan vowel sign aa - 0F71)"},
/* 0FB1 */ { "TIBETAN SUBJOINED LETTER YA","	= ya-btags (ya ta)"},
/* 0FB2 */ { "TIBETAN SUBJOINED LETTER RA","	= ra-btags (ra ta)"},
/* 0FB3 */ { "TIBETAN SUBJOINED LETTER LA",NULL},
/* 0FB4 */ { "TIBETAN SUBJOINED LETTER SHA",NULL},
/* 0FB5 */ { "TIBETAN SUBJOINED LETTER SSA","	= reversed subjoined sha"},
/* 0FB6 */ { "TIBETAN SUBJOINED LETTER SA",NULL},
/* 0FB7 */ { "TIBETAN SUBJOINED LETTER HA",NULL},
/* 0FB8 */ { "TIBETAN SUBJOINED LETTER A",NULL},
/* 0FB9 */ { "TIBETAN SUBJOINED LETTER KSSA","	: 0F90 0FB5"},
/* 0FBA */ { "TIBETAN SUBJOINED LETTER FIXED-FORM WA",NULL},
/* 0FBB */ { "TIBETAN SUBJOINED LETTER FIXED-FORM YA",NULL},
/* 0FBC */ { "TIBETAN SUBJOINED LETTER FIXED-FORM RA",NULL},
/* 0FBD */ { NULL,NULL},
/* 0FBE */ { "TIBETAN KU RU KHA","	* often repeated three times; indicates a refrain"},
/* 0FBF */ { "TIBETAN KU RU KHA BZHI MIG CAN","	* marks point of text insertion or annotation\n"
	"	x (reference mark - 203B)"},
/* 0FC0 */ { "TIBETAN CANTILLATION SIGN HEAVY BEAT","	* marks a heavy drum beat"},
/* 0FC1 */ { "TIBETAN CANTILLATION SIGN LIGHT BEAT","	* marks a light drum beat"},
/* 0FC2 */ { "TIBETAN CANTILLATION SIGN CANG TE-U","	* symbol of a small Tibetan hand drum"},
/* 0FC3 */ { "TIBETAN CANTILLATION SIGN SBUB -CHAL","	* symbol of a Tibetan cymbal"},
/* 0FC4 */ { "TIBETAN SYMBOL DRIL BU","	* symbol of a Tibetan hand bell\n"
	"	x (bell - 1F514)"},
/* 0FC5 */ { "TIBETAN SYMBOL RDO RJE",NULL},
/* 0FC6 */ { "TIBETAN SYMBOL PADMA GDAN",NULL},
/* 0FC7 */ { "TIBETAN SYMBOL RDO RJE RGYA GRAM",NULL},
/* 0FC8 */ { "TIBETAN SYMBOL PHUR PA",NULL},
/* 0FC9 */ { "TIBETAN SYMBOL NOR BU",NULL},
/* 0FCA */ { "TIBETAN SYMBOL NOR BU NYIS -KHYIL","	* the double body symbol\n"
	"	x (yin yang - 262F)"},
/* 0FCB */ { "TIBETAN SYMBOL NOR BU GSUM -KHYIL","	* the tri-kaya or triple body symbol"},
/* 0FCC */ { "TIBETAN SYMBOL NOR BU BZHI -KHYIL","	* the quadruple body symbol, a form of the svasti sign\n"
	"	x (left-facing svasti sign - 0FD6)"},
/* 0FCD */ { NULL,NULL},
/* 0FCE */ { "TIBETAN SIGN RDEL NAG RDEL DKAR","	= dena deka\n"
	"	* signifies bad luck earlier, good luck later\n"
	"	x (tibetan sign rdel dkar rdel nag - 0F1F)"},
/* 0FCF */ { "TIBETAN SIGN RDEL NAG GSUM",NULL},
/* 0FD0 */ { "TIBETAN MARK BSKA- SHOG GI MGO RGYAN","	% TIBETAN MARK BKA- SHOG GI MGO RGYAN\n"
	"	* used in Bhutan"},
/* 0FD1 */ { "TIBETAN MARK MNYAM YIG GI MGO RGYAN","	* used in Bhutan"},
/* 0FD2 */ { "TIBETAN MARK NYIS TSHEG","	= nyi tsek"},
/* 0FD3 */ { "TIBETAN MARK INITIAL BRDA RNYING YIG MGO MDUN MA","	= da nying yik go dun ma"},
/* 0FD4 */ { "TIBETAN MARK CLOSING BRDA RNYING YIG MGO SGAB MA","	= da nying yik go kab ma"},
/* 0FD5 */ { "RIGHT-FACING SVASTI SIGN","	= gyung drung nang -khor\n"
	"	* symbol of good luck and well-being in India\n"
	"	x 5350"},
/* 0FD6 */ { "LEFT-FACING SVASTI SIGN","	= gyung drung phyi -khor\n"
	"	x 534D"},
/* 0FD7 */ { "RIGHT-FACING SVASTI SIGN WITH DOTS","	= gyung drung nang -khor bzhi mig can"},
/* 0FD8 */ { "LEFT-FACING SVASTI SIGN WITH DOTS","	= gyung drung phyi -khor bzhi mig can"},
/* 0FD9 */ { "TIBETAN MARK LEADING MCHAN RTAGS",NULL},
/* 0FDA */ { "TIBETAN MARK TRAILING MCHAN RTAGS",NULL},
/* 0FDB */ { NULL,NULL},
/* 0FDC */ { NULL,NULL},
/* 0FDD */ { NULL,NULL},
/* 0FDE */ { NULL,NULL},
/* 0FDF */ { NULL,NULL},
/* 0FE0 */ { NULL,NULL},
/* 0FE1 */ { NULL,NULL},
/* 0FE2 */ { NULL,NULL},
/* 0FE3 */ { NULL,NULL},
/* 0FE4 */ { NULL,NULL},
/* 0FE5 */ { NULL,NULL},
/* 0FE6 */ { NULL,NULL},
/* 0FE7 */ { NULL,NULL},
/* 0FE8 */ { NULL,NULL},
/* 0FE9 */ { NULL,NULL},
/* 0FEA */ { NULL,NULL},
/* 0FEB */ { NULL,NULL},
/* 0FEC */ { NULL,NULL},
/* 0FED */ { NULL,NULL},
/* 0FEE */ { NULL,NULL},
/* 0FEF */ { NULL,NULL},
/* 0FF0 */ { NULL,NULL},
/* 0FF1 */ { NULL,NULL},
/* 0FF2 */ { NULL,NULL},
/* 0FF3 */ { NULL,NULL},
/* 0FF4 */ { NULL,NULL},
/* 0FF5 */ { NULL,NULL},
/* 0FF6 */ { NULL,NULL},
/* 0FF7 */ { NULL,NULL},
/* 0FF8 */ { NULL,NULL},
/* 0FF9 */ { NULL,NULL},
/* 0FFA */ { NULL,NULL},
/* 0FFB */ { NULL,NULL},
/* 0FFC */ { NULL,NULL},
/* 0FFD */ { NULL,NULL},
/* 0FFE */ { NULL,NULL},
/* 0FFF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_00_10[] = {
/* 1000 */ { "MYANMAR LETTER KA","	~ 1000 FE00 dotted form"},
/* 1001 */ { "MYANMAR LETTER KHA",NULL},
/* 1002 */ { "MYANMAR LETTER GA","	~ 1002 FE00 dotted form"},
/* 1003 */ { "MYANMAR LETTER GHA",NULL},
/* 1004 */ { "MYANMAR LETTER NGA","	~ 1004 FE00 dotted form"},
/* 1005 */ { "MYANMAR LETTER CA",NULL},
/* 1006 */ { "MYANMAR LETTER CHA",NULL},
/* 1007 */ { "MYANMAR LETTER JA",NULL},
/* 1008 */ { "MYANMAR LETTER JHA",NULL},
/* 1009 */ { "MYANMAR LETTER NYA",NULL},
/* 100A */ { "MYANMAR LETTER NNYA",NULL},
/* 100B */ { "MYANMAR LETTER TTA",NULL},
/* 100C */ { "MYANMAR LETTER TTHA",NULL},
/* 100D */ { "MYANMAR LETTER DDA",NULL},
/* 100E */ { "MYANMAR LETTER DDHA",NULL},
/* 100F */ { "MYANMAR LETTER NNA",NULL},
/* 1010 */ { "MYANMAR LETTER TA","	~ 1010 FE00 dotted form"},
/* 1011 */ { "MYANMAR LETTER THA","	~ 1011 FE00 dotted form"},
/* 1012 */ { "MYANMAR LETTER DA",NULL},
/* 1013 */ { "MYANMAR LETTER DHA",NULL},
/* 1014 */ { "MYANMAR LETTER NA",NULL},
/* 1015 */ { "MYANMAR LETTER PA","	~ 1015 FE00 dotted form"},
/* 1016 */ { "MYANMAR LETTER PHA",NULL},
/* 1017 */ { "MYANMAR LETTER BA",NULL},
/* 1018 */ { "MYANMAR LETTER BHA",NULL},
/* 1019 */ { "MYANMAR LETTER MA","	~ 1019 FE00 dotted form"},
/* 101A */ { "MYANMAR LETTER YA","	~ 101A FE00 dotted form"},
/* 101B */ { "MYANMAR LETTER RA",NULL},
/* 101C */ { "MYANMAR LETTER LA","	~ 101C FE00 dotted form"},
/* 101D */ { "MYANMAR LETTER WA","	~ 101D FE00 dotted form"},
/* 101E */ { "MYANMAR LETTER SA",NULL},
/* 101F */ { "MYANMAR LETTER HA",NULL},
/* 1020 */ { "MYANMAR LETTER LLA",NULL},
/* 1021 */ { "MYANMAR LETTER A","	* also represents the glottal stop as a consonant"},
/* 1022 */ { "MYANMAR LETTER SHAN A","	~ 1022 FE00 dotted form"},
/* 1023 */ { "MYANMAR LETTER I",NULL},
/* 1024 */ { "MYANMAR LETTER II",NULL},
/* 1025 */ { "MYANMAR LETTER U",NULL},
/* 1026 */ { "MYANMAR LETTER UU","	: 1025 102E"},
/* 1027 */ { "MYANMAR LETTER E",NULL},
/* 1028 */ { "MYANMAR LETTER MON E",NULL},
/* 1029 */ { "MYANMAR LETTER O",NULL},
/* 102A */ { "MYANMAR LETTER AU",NULL},
/* 102B */ { "MYANMAR VOWEL SIGN TALL AA",NULL},
/* 102C */ { "MYANMAR VOWEL SIGN AA",NULL},
/* 102D */ { "MYANMAR VOWEL SIGN I",NULL},
/* 102E */ { "MYANMAR VOWEL SIGN II",NULL},
/* 102F */ { "MYANMAR VOWEL SIGN U",NULL},
/* 1030 */ { "MYANMAR VOWEL SIGN UU",NULL},
/* 1031 */ { "MYANMAR VOWEL SIGN E","	* stands to the left of the consonant\n"
	"	~ 1031 FE00 dotted form"},
/* 1032 */ { "MYANMAR VOWEL SIGN AI",NULL},
/* 1033 */ { "MYANMAR VOWEL SIGN MON II",NULL},
/* 1034 */ { "MYANMAR VOWEL SIGN MON O",NULL},
/* 1035 */ { "MYANMAR VOWEL SIGN E ABOVE",NULL},
/* 1036 */ { "MYANMAR SIGN ANUSVARA",NULL},
/* 1037 */ { "MYANMAR SIGN DOT BELOW","	= aukmyit\n"
	"	* a tone mark"},
/* 1038 */ { "MYANMAR SIGN VISARGA",NULL},
/* 1039 */ { "MYANMAR SIGN VIRAMA",NULL},
/* 103A */ { "MYANMAR SIGN ASAT","	= killer (always rendered visibly)"},
/* 103B */ { "MYANMAR CONSONANT SIGN MEDIAL YA",NULL},
/* 103C */ { "MYANMAR CONSONANT SIGN MEDIAL RA",NULL},
/* 103D */ { "MYANMAR CONSONANT SIGN MEDIAL WA",NULL},
/* 103E */ { "MYANMAR CONSONANT SIGN MEDIAL HA",NULL},
/* 103F */ { "MYANMAR LETTER GREAT SA",NULL},
/* 1040 */ { "MYANMAR DIGIT ZERO",NULL},
/* 1041 */ { "MYANMAR DIGIT ONE",NULL},
/* 1042 */ { "MYANMAR DIGIT TWO",NULL},
/* 1043 */ { "MYANMAR DIGIT THREE",NULL},
/* 1044 */ { "MYANMAR DIGIT FOUR",NULL},
/* 1045 */ { "MYANMAR DIGIT FIVE",NULL},
/* 1046 */ { "MYANMAR DIGIT SIX",NULL},
/* 1047 */ { "MYANMAR DIGIT SEVEN",NULL},
/* 1048 */ { "MYANMAR DIGIT EIGHT",NULL},
/* 1049 */ { "MYANMAR DIGIT NINE",NULL},
/* 104A */ { "MYANMAR SIGN LITTLE SECTION","	x (devanagari danda - 0964)"},
/* 104B */ { "MYANMAR SIGN SECTION","	x (devanagari double danda - 0965)"},
/* 104C */ { "MYANMAR SYMBOL LOCATIVE",NULL},
/* 104D */ { "MYANMAR SYMBOL COMPLETED",NULL},
/* 104E */ { "MYANMAR SYMBOL AFOREMENTIONED",NULL},
/* 104F */ { "MYANMAR SYMBOL GENITIVE",NULL},
/* 1050 */ { "MYANMAR LETTER SHA",NULL},
/* 1051 */ { "MYANMAR LETTER SSA",NULL},
/* 1052 */ { "MYANMAR LETTER VOCALIC R",NULL},
/* 1053 */ { "MYANMAR LETTER VOCALIC RR",NULL},
/* 1054 */ { "MYANMAR LETTER VOCALIC L",NULL},
/* 1055 */ { "MYANMAR LETTER VOCALIC LL",NULL},
/* 1056 */ { "MYANMAR VOWEL SIGN VOCALIC R",NULL},
/* 1057 */ { "MYANMAR VOWEL SIGN VOCALIC RR",NULL},
/* 1058 */ { "MYANMAR VOWEL SIGN VOCALIC L",NULL},
/* 1059 */ { "MYANMAR VOWEL SIGN VOCALIC LL",NULL},
/* 105A */ { "MYANMAR LETTER MON NGA",NULL},
/* 105B */ { "MYANMAR LETTER MON JHA",NULL},
/* 105C */ { "MYANMAR LETTER MON BBA",NULL},
/* 105D */ { "MYANMAR LETTER MON BBE",NULL},
/* 105E */ { "MYANMAR CONSONANT SIGN MON MEDIAL NA",NULL},
/* 105F */ { "MYANMAR CONSONANT SIGN MON MEDIAL MA",NULL},
/* 1060 */ { "MYANMAR CONSONANT SIGN MON MEDIAL LA",NULL},
/* 1061 */ { "MYANMAR LETTER SGAW KAREN SHA",NULL},
/* 1062 */ { "MYANMAR VOWEL SIGN SGAW KAREN EU",NULL},
/* 1063 */ { "MYANMAR TONE MARK SGAW KAREN HATHI",NULL},
/* 1064 */ { "MYANMAR TONE MARK SGAW KAREN KE PHO",NULL},
/* 1065 */ { "MYANMAR LETTER WESTERN PWO KAREN THA",NULL},
/* 1066 */ { "MYANMAR LETTER WESTERN PWO KAREN PWA",NULL},
/* 1067 */ { "MYANMAR VOWEL SIGN WESTERN PWO KAREN EU",NULL},
/* 1068 */ { "MYANMAR VOWEL SIGN WESTERN PWO KAREN UE",NULL},
/* 1069 */ { "MYANMAR SIGN WESTERN PWO KAREN TONE-1",NULL},
/* 106A */ { "MYANMAR SIGN WESTERN PWO KAREN TONE-2",NULL},
/* 106B */ { "MYANMAR SIGN WESTERN PWO KAREN TONE-3",NULL},
/* 106C */ { "MYANMAR SIGN WESTERN PWO KAREN TONE-4",NULL},
/* 106D */ { "MYANMAR SIGN WESTERN PWO KAREN TONE-5",NULL},
/* 106E */ { "MYANMAR LETTER EASTERN PWO KAREN NNA",NULL},
/* 106F */ { "MYANMAR LETTER EASTERN PWO KAREN YWA",NULL},
/* 1070 */ { "MYANMAR LETTER EASTERN PWO KAREN GHWA",NULL},
/* 1071 */ { "MYANMAR VOWEL SIGN GEBA KAREN I",NULL},
/* 1072 */ { "MYANMAR VOWEL SIGN KAYAH OE",NULL},
/* 1073 */ { "MYANMAR VOWEL SIGN KAYAH U",NULL},
/* 1074 */ { "MYANMAR VOWEL SIGN KAYAH EE",NULL},
/* 1075 */ { "MYANMAR LETTER SHAN KA","	~ 1075 FE00 dotted form"},
/* 1076 */ { "MYANMAR LETTER SHAN KHA",NULL},
/* 1077 */ { "MYANMAR LETTER SHAN GA",NULL},
/* 1078 */ { "MYANMAR LETTER SHAN CA","	~ 1078 FE00 dotted form"},
/* 1079 */ { "MYANMAR LETTER SHAN ZA",NULL},
/* 107A */ { "MYANMAR LETTER SHAN NYA","	~ 107A FE00 dotted form"},
/* 107B */ { "MYANMAR LETTER SHAN DA",NULL},
/* 107C */ { "MYANMAR LETTER SHAN NA",NULL},
/* 107D */ { "MYANMAR LETTER SHAN PHA",NULL},
/* 107E */ { "MYANMAR LETTER SHAN FA",NULL},
/* 107F */ { "MYANMAR LETTER SHAN BA",NULL},
/* 1080 */ { "MYANMAR LETTER SHAN THA","	~ 1080 FE00 dotted form"},
/* 1081 */ { "MYANMAR LETTER SHAN HA",NULL},
/* 1082 */ { "MYANMAR CONSONANT SIGN SHAN MEDIAL WA",NULL},
/* 1083 */ { "MYANMAR VOWEL SIGN SHAN AA",NULL},
/* 1084 */ { "MYANMAR VOWEL SIGN SHAN E",NULL},
/* 1085 */ { "MYANMAR VOWEL SIGN SHAN E ABOVE",NULL},
/* 1086 */ { "MYANMAR VOWEL SIGN SHAN FINAL Y",NULL},
/* 1087 */ { "MYANMAR SIGN SHAN TONE-2",NULL},
/* 1088 */ { "MYANMAR SIGN SHAN TONE-3",NULL},
/* 1089 */ { "MYANMAR SIGN SHAN TONE-5",NULL},
/* 108A */ { "MYANMAR SIGN SHAN TONE-6",NULL},
/* 108B */ { "MYANMAR SIGN SHAN COUNCIL TONE-2",NULL},
/* 108C */ { "MYANMAR SIGN SHAN COUNCIL TONE-3",NULL},
/* 108D */ { "MYANMAR SIGN SHAN COUNCIL EMPHATIC TONE",NULL},
/* 108E */ { "MYANMAR LETTER RUMAI PALAUNG FA",NULL},
/* 108F */ { "MYANMAR SIGN RUMAI PALAUNG TONE-5",NULL},
/* 1090 */ { "MYANMAR SHAN DIGIT ZERO",NULL},
/* 1091 */ { "MYANMAR SHAN DIGIT ONE",NULL},
/* 1092 */ { "MYANMAR SHAN DIGIT TWO",NULL},
/* 1093 */ { "MYANMAR SHAN DIGIT THREE",NULL},
/* 1094 */ { "MYANMAR SHAN DIGIT FOUR",NULL},
/* 1095 */ { "MYANMAR SHAN DIGIT FIVE",NULL},
/* 1096 */ { "MYANMAR SHAN DIGIT SIX",NULL},
/* 1097 */ { "MYANMAR SHAN DIGIT SEVEN",NULL},
/* 1098 */ { "MYANMAR SHAN DIGIT EIGHT",NULL},
/* 1099 */ { "MYANMAR SHAN DIGIT NINE",NULL},
/* 109A */ { "MYANMAR SIGN KHAMTI TONE-1",NULL},
/* 109B */ { "MYANMAR SIGN KHAMTI TONE-3",NULL},
/* 109C */ { "MYANMAR VOWEL SIGN AITON A",NULL},
/* 109D */ { "MYANMAR VOWEL SIGN AITON AI",NULL},
/* 109E */ { "MYANMAR SYMBOL SHAN ONE",NULL},
/* 109F */ { "MYANMAR SYMBOL SHAN EXCLAMATION",NULL},
/* 10A0 */ { "GEORGIAN CAPITAL LETTER AN","	x (georgian small letter an - 2D00)"},
/* 10A1 */ { "GEORGIAN CAPITAL LETTER BAN",NULL},
/* 10A2 */ { "GEORGIAN CAPITAL LETTER GAN",NULL},
/* 10A3 */ { "GEORGIAN CAPITAL LETTER DON",NULL},
/* 10A4 */ { "GEORGIAN CAPITAL LETTER EN",NULL},
/* 10A5 */ { "GEORGIAN CAPITAL LETTER VIN",NULL},
/* 10A6 */ { "GEORGIAN CAPITAL LETTER ZEN",NULL},
/* 10A7 */ { "GEORGIAN CAPITAL LETTER TAN",NULL},
/* 10A8 */ { "GEORGIAN CAPITAL LETTER IN",NULL},
/* 10A9 */ { "GEORGIAN CAPITAL LETTER KAN",NULL},
/* 10AA */ { "GEORGIAN CAPITAL LETTER LAS",NULL},
/* 10AB */ { "GEORGIAN CAPITAL LETTER MAN",NULL},
/* 10AC */ { "GEORGIAN CAPITAL LETTER NAR",NULL},
/* 10AD */ { "GEORGIAN CAPITAL LETTER ON",NULL},
/* 10AE */ { "GEORGIAN CAPITAL LETTER PAR",NULL},
/* 10AF */ { "GEORGIAN CAPITAL LETTER ZHAR",NULL},
/* 10B0 */ { "GEORGIAN CAPITAL LETTER RAE",NULL},
/* 10B1 */ { "GEORGIAN CAPITAL LETTER SAN",NULL},
/* 10B2 */ { "GEORGIAN CAPITAL LETTER TAR",NULL},
/* 10B3 */ { "GEORGIAN CAPITAL LETTER UN",NULL},
/* 10B4 */ { "GEORGIAN CAPITAL LETTER PHAR",NULL},
/* 10B5 */ { "GEORGIAN CAPITAL LETTER KHAR",NULL},
/* 10B6 */ { "GEORGIAN CAPITAL LETTER GHAN",NULL},
/* 10B7 */ { "GEORGIAN CAPITAL LETTER QAR",NULL},
/* 10B8 */ { "GEORGIAN CAPITAL LETTER SHIN",NULL},
/* 10B9 */ { "GEORGIAN CAPITAL LETTER CHIN",NULL},
/* 10BA */ { "GEORGIAN CAPITAL LETTER CAN",NULL},
/* 10BB */ { "GEORGIAN CAPITAL LETTER JIL",NULL},
/* 10BC */ { "GEORGIAN CAPITAL LETTER CIL",NULL},
/* 10BD */ { "GEORGIAN CAPITAL LETTER CHAR",NULL},
/* 10BE */ { "GEORGIAN CAPITAL LETTER XAN",NULL},
/* 10BF */ { "GEORGIAN CAPITAL LETTER JHAN",NULL},
/* 10C0 */ { "GEORGIAN CAPITAL LETTER HAE",NULL},
/* 10C1 */ { "GEORGIAN CAPITAL LETTER HE",NULL},
/* 10C2 */ { "GEORGIAN CAPITAL LETTER HIE",NULL},
/* 10C3 */ { "GEORGIAN CAPITAL LETTER WE",NULL},
/* 10C4 */ { "GEORGIAN CAPITAL LETTER HAR",NULL},
/* 10C5 */ { "GEORGIAN CAPITAL LETTER HOE",NULL},
/* 10C6 */ { NULL,NULL},
/* 10C7 */ { "GEORGIAN CAPITAL LETTER YN",NULL},
/* 10C8 */ { NULL,NULL},
/* 10C9 */ { NULL,NULL},
/* 10CA */ { NULL,NULL},
/* 10CB */ { NULL,NULL},
/* 10CC */ { NULL,NULL},
/* 10CD */ { "GEORGIAN CAPITAL LETTER AEN",NULL},
/* 10CE */ { NULL,NULL},
/* 10CF */ { NULL,NULL},
/* 10D0 */ { "GEORGIAN LETTER AN","	x (georgian mtavruli capital letter an - 1C90)"},
/* 10D1 */ { "GEORGIAN LETTER BAN",NULL},
/* 10D2 */ { "GEORGIAN LETTER GAN",NULL},
/* 10D3 */ { "GEORGIAN LETTER DON",NULL},
/* 10D4 */ { "GEORGIAN LETTER EN",NULL},
/* 10D5 */ { "GEORGIAN LETTER VIN",NULL},
/* 10D6 */ { "GEORGIAN LETTER ZEN",NULL},
/* 10D7 */ { "GEORGIAN LETTER TAN",NULL},
/* 10D8 */ { "GEORGIAN LETTER IN",NULL},
/* 10D9 */ { "GEORGIAN LETTER KAN",NULL},
/* 10DA */ { "GEORGIAN LETTER LAS",NULL},
/* 10DB */ { "GEORGIAN LETTER MAN",NULL},
/* 10DC */ { "GEORGIAN LETTER NAR",NULL},
/* 10DD */ { "GEORGIAN LETTER ON",NULL},
/* 10DE */ { "GEORGIAN LETTER PAR",NULL},
/* 10DF */ { "GEORGIAN LETTER ZHAR",NULL},
/* 10E0 */ { "GEORGIAN LETTER RAE",NULL},
/* 10E1 */ { "GEORGIAN LETTER SAN",NULL},
/* 10E2 */ { "GEORGIAN LETTER TAR",NULL},
/* 10E3 */ { "GEORGIAN LETTER UN",NULL},
/* 10E4 */ { "GEORGIAN LETTER PHAR",NULL},
/* 10E5 */ { "GEORGIAN LETTER KHAR",NULL},
/* 10E6 */ { "GEORGIAN LETTER GHAN",NULL},
/* 10E7 */ { "GEORGIAN LETTER QAR",NULL},
/* 10E8 */ { "GEORGIAN LETTER SHIN",NULL},
/* 10E9 */ { "GEORGIAN LETTER CHIN",NULL},
/* 10EA */ { "GEORGIAN LETTER CAN",NULL},
/* 10EB */ { "GEORGIAN LETTER JIL",NULL},
/* 10EC */ { "GEORGIAN LETTER CIL",NULL},
/* 10ED */ { "GEORGIAN LETTER CHAR",NULL},
/* 10EE */ { "GEORGIAN LETTER XAN",NULL},
/* 10EF */ { "GEORGIAN LETTER JHAN",NULL},
/* 10F0 */ { "GEORGIAN LETTER HAE",NULL},
/* 10F1 */ { "GEORGIAN LETTER HE",NULL},
/* 10F2 */ { "GEORGIAN LETTER HIE",NULL},
/* 10F3 */ { "GEORGIAN LETTER WE",NULL},
/* 10F4 */ { "GEORGIAN LETTER HAR",NULL},
/* 10F5 */ { "GEORGIAN LETTER HOE",NULL},
/* 10F6 */ { "GEORGIAN LETTER FI",NULL},
/* 10F7 */ { "GEORGIAN LETTER YN",NULL},
/* 10F8 */ { "GEORGIAN LETTER ELIFI",NULL},
/* 10F9 */ { "GEORGIAN LETTER TURNED GAN",NULL},
/* 10FA */ { "GEORGIAN LETTER AIN",NULL},
/* 10FB */ { "GEORGIAN PARAGRAPH SEPARATOR","	x (three dot punctuation - 2056)"},
/* 10FC */ { "MODIFIER LETTER GEORGIAN NAR","	# <super> 10DC"},
/* 10FD */ { "GEORGIAN LETTER AEN",NULL},
/* 10FE */ { "GEORGIAN LETTER HARD SIGN",NULL},
/* 10FF */ { "GEORGIAN LETTER LABIAL SIGN",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_00_11[] = {
/* 1100 */ { "HANGUL CHOSEONG KIYEOK","	= G"},
/* 1101 */ { "HANGUL CHOSEONG SSANGKIYEOK","	= GG"},
/* 1102 */ { "HANGUL CHOSEONG NIEUN","	= N"},
/* 1103 */ { "HANGUL CHOSEONG TIKEUT","	= D"},
/* 1104 */ { "HANGUL CHOSEONG SSANGTIKEUT","	= DD"},
/* 1105 */ { "HANGUL CHOSEONG RIEUL","	= R"},
/* 1106 */ { "HANGUL CHOSEONG MIEUM","	= M"},
/* 1107 */ { "HANGUL CHOSEONG PIEUP","	= B"},
/* 1108 */ { "HANGUL CHOSEONG SSANGPIEUP","	= BB"},
/* 1109 */ { "HANGUL CHOSEONG SIOS","	= S\n"
	"	* voiceless lenis alveolar fricative"},
/* 110A */ { "HANGUL CHOSEONG SSANGSIOS","	= SS\n"
	"	* voiceless fortis alveolar fricative"},
/* 110B */ { "HANGUL CHOSEONG IEUNG","	* zero sound"},
/* 110C */ { "HANGUL CHOSEONG CIEUC","	= J\n"
	"	* voiceless or voiced lenis alveolar affricate"},
/* 110D */ { "HANGUL CHOSEONG SSANGCIEUC","	= JJ\n"
	"	* voiceless unaspirated fortis alveolar affricate"},
/* 110E */ { "HANGUL CHOSEONG CHIEUCH","	= C\n"
	"	* voiceless aspirated alveolar affricate"},
/* 110F */ { "HANGUL CHOSEONG KHIEUKH","	= K"},
/* 1110 */ { "HANGUL CHOSEONG THIEUTH","	= T"},
/* 1111 */ { "HANGUL CHOSEONG PHIEUPH","	= P"},
/* 1112 */ { "HANGUL CHOSEONG HIEUH","	= H\n"
	"	* voiceless glottal fricative"},
/* 1113 */ { "HANGUL CHOSEONG NIEUN-KIYEOK",NULL},
/* 1114 */ { "HANGUL CHOSEONG SSANGNIEUN",NULL},
/* 1115 */ { "HANGUL CHOSEONG NIEUN-TIKEUT",NULL},
/* 1116 */ { "HANGUL CHOSEONG NIEUN-PIEUP",NULL},
/* 1117 */ { "HANGUL CHOSEONG TIKEUT-KIYEOK",NULL},
/* 1118 */ { "HANGUL CHOSEONG RIEUL-NIEUN",NULL},
/* 1119 */ { "HANGUL CHOSEONG SSANGRIEUL",NULL},
/* 111A */ { "HANGUL CHOSEONG RIEUL-HIEUH",NULL},
/* 111B */ { "HANGUL CHOSEONG KAPYEOUNRIEUL",NULL},
/* 111C */ { "HANGUL CHOSEONG MIEUM-PIEUP",NULL},
/* 111D */ { "HANGUL CHOSEONG KAPYEOUNMIEUM",NULL},
/* 111E */ { "HANGUL CHOSEONG PIEUP-KIYEOK",NULL},
/* 111F */ { "HANGUL CHOSEONG PIEUP-NIEUN",NULL},
/* 1120 */ { "HANGUL CHOSEONG PIEUP-TIKEUT",NULL},
/* 1121 */ { "HANGUL CHOSEONG PIEUP-SIOS",NULL},
/* 1122 */ { "HANGUL CHOSEONG PIEUP-SIOS-KIYEOK",NULL},
/* 1123 */ { "HANGUL CHOSEONG PIEUP-SIOS-TIKEUT",NULL},
/* 1124 */ { "HANGUL CHOSEONG PIEUP-SIOS-PIEUP",NULL},
/* 1125 */ { "HANGUL CHOSEONG PIEUP-SSANGSIOS",NULL},
/* 1126 */ { "HANGUL CHOSEONG PIEUP-SIOS-CIEUC",NULL},
/* 1127 */ { "HANGUL CHOSEONG PIEUP-CIEUC",NULL},
/* 1128 */ { "HANGUL CHOSEONG PIEUP-CHIEUCH",NULL},
/* 1129 */ { "HANGUL CHOSEONG PIEUP-THIEUTH",NULL},
/* 112A */ { "HANGUL CHOSEONG PIEUP-PHIEUPH",NULL},
/* 112B */ { "HANGUL CHOSEONG KAPYEOUNPIEUP",NULL},
/* 112C */ { "HANGUL CHOSEONG KAPYEOUNSSANGPIEUP",NULL},
/* 112D */ { "HANGUL CHOSEONG SIOS-KIYEOK",NULL},
/* 112E */ { "HANGUL CHOSEONG SIOS-NIEUN",NULL},
/* 112F */ { "HANGUL CHOSEONG SIOS-TIKEUT",NULL},
/* 1130 */ { "HANGUL CHOSEONG SIOS-RIEUL",NULL},
/* 1131 */ { "HANGUL CHOSEONG SIOS-MIEUM",NULL},
/* 1132 */ { "HANGUL CHOSEONG SIOS-PIEUP",NULL},
/* 1133 */ { "HANGUL CHOSEONG SIOS-PIEUP-KIYEOK",NULL},
/* 1134 */ { "HANGUL CHOSEONG SIOS-SSANGSIOS",NULL},
/* 1135 */ { "HANGUL CHOSEONG SIOS-IEUNG",NULL},
/* 1136 */ { "HANGUL CHOSEONG SIOS-CIEUC",NULL},
/* 1137 */ { "HANGUL CHOSEONG SIOS-CHIEUCH",NULL},
/* 1138 */ { "HANGUL CHOSEONG SIOS-KHIEUKH",NULL},
/* 1139 */ { "HANGUL CHOSEONG SIOS-THIEUTH",NULL},
/* 113A */ { "HANGUL CHOSEONG SIOS-PHIEUPH",NULL},
/* 113B */ { "HANGUL CHOSEONG SIOS-HIEUH",NULL},
/* 113C */ { "HANGUL CHOSEONG CHITUEUMSIOS","	* voiceless lenis dental fricative"},
/* 113D */ { "HANGUL CHOSEONG CHITUEUMSSANGSIOS","	* voiceless fortis dental fricative"},
/* 113E */ { "HANGUL CHOSEONG CEONGCHIEUMSIOS","	* voiceless lenis retroflex fricative"},
/* 113F */ { "HANGUL CHOSEONG CEONGCHIEUMSSANGSIOS","	* voiceless fortis retroflex fricative"},
/* 1140 */ { "HANGUL CHOSEONG PANSIOS","	* voiced alveolar fricative"},
/* 1141 */ { "HANGUL CHOSEONG IEUNG-KIYEOK",NULL},
/* 1142 */ { "HANGUL CHOSEONG IEUNG-TIKEUT",NULL},
/* 1143 */ { "HANGUL CHOSEONG IEUNG-MIEUM",NULL},
/* 1144 */ { "HANGUL CHOSEONG IEUNG-PIEUP",NULL},
/* 1145 */ { "HANGUL CHOSEONG IEUNG-SIOS",NULL},
/* 1146 */ { "HANGUL CHOSEONG IEUNG-PANSIOS",NULL},
/* 1147 */ { "HANGUL CHOSEONG SSANGIEUNG",NULL},
/* 1148 */ { "HANGUL CHOSEONG IEUNG-CIEUC",NULL},
/* 1149 */ { "HANGUL CHOSEONG IEUNG-CHIEUCH",NULL},
/* 114A */ { "HANGUL CHOSEONG IEUNG-THIEUTH",NULL},
/* 114B */ { "HANGUL CHOSEONG IEUNG-PHIEUPH",NULL},
/* 114C */ { "HANGUL CHOSEONG YESIEUNG","	* velar nasal consonant"},
/* 114D */ { "HANGUL CHOSEONG CIEUC-IEUNG",NULL},
/* 114E */ { "HANGUL CHOSEONG CHITUEUMCIEUC","	* voiceless or voiced lenis dental affricate"},
/* 114F */ { "HANGUL CHOSEONG CHITUEUMSSANGCIEUC","	* voiceless unaspirated fortis dental affricate"},
/* 1150 */ { "HANGUL CHOSEONG CEONGCHIEUMCIEUC","	* voiceless or voiced lenis retroflex affricate"},
/* 1151 */ { "HANGUL CHOSEONG CEONGCHIEUMSSANGCIEUC","	* voiceless unaspirated fortis retroflex affricate"},
/* 1152 */ { "HANGUL CHOSEONG CHIEUCH-KHIEUKH",NULL},
/* 1153 */ { "HANGUL CHOSEONG CHIEUCH-HIEUH",NULL},
/* 1154 */ { "HANGUL CHOSEONG CHITUEUMCHIEUCH","	* voiceless aspirated dental affricate"},
/* 1155 */ { "HANGUL CHOSEONG CEONGCHIEUMCHIEUCH","	* voiceless aspirated retroflex affricate"},
/* 1156 */ { "HANGUL CHOSEONG PHIEUPH-PIEUP",NULL},
/* 1157 */ { "HANGUL CHOSEONG KAPYEOUNPHIEUPH",NULL},
/* 1158 */ { "HANGUL CHOSEONG SSANGHIEUH",NULL},
/* 1159 */ { "HANGUL CHOSEONG YEORINHIEUH","	* glottal stop"},
/* 115A */ { "HANGUL CHOSEONG KIYEOK-TIKEUT",NULL},
/* 115B */ { "HANGUL CHOSEONG NIEUN-SIOS",NULL},
/* 115C */ { "HANGUL CHOSEONG NIEUN-CIEUC",NULL},
/* 115D */ { "HANGUL CHOSEONG NIEUN-HIEUH",NULL},
/* 115E */ { "HANGUL CHOSEONG TIKEUT-RIEUL",NULL},
/* 115F */ { "HANGUL CHOSEONG FILLER",NULL},
/* 1160 */ { "HANGUL JUNGSEONG FILLER",NULL},
/* 1161 */ { "HANGUL JUNGSEONG A","	= A"},
/* 1162 */ { "HANGUL JUNGSEONG AE","	= AE"},
/* 1163 */ { "HANGUL JUNGSEONG YA","	= YA"},
/* 1164 */ { "HANGUL JUNGSEONG YAE","	= YAE"},
/* 1165 */ { "HANGUL JUNGSEONG EO","	= EO"},
/* 1166 */ { "HANGUL JUNGSEONG E","	= E"},
/* 1167 */ { "HANGUL JUNGSEONG YEO","	= YEO"},
/* 1168 */ { "HANGUL JUNGSEONG YE","	= YE"},
/* 1169 */ { "HANGUL JUNGSEONG O","	= O"},
/* 116A */ { "HANGUL JUNGSEONG WA","	= WA"},
/* 116B */ { "HANGUL JUNGSEONG WAE","	= WAE"},
/* 116C */ { "HANGUL JUNGSEONG OE","	= OE"},
/* 116D */ { "HANGUL JUNGSEONG YO","	= YO"},
/* 116E */ { "HANGUL JUNGSEONG U","	= U"},
/* 116F */ { "HANGUL JUNGSEONG WEO","	= WEO"},
/* 1170 */ { "HANGUL JUNGSEONG WE","	= WE"},
/* 1171 */ { "HANGUL JUNGSEONG WI","	= WI"},
/* 1172 */ { "HANGUL JUNGSEONG YU","	= YU"},
/* 1173 */ { "HANGUL JUNGSEONG EU","	= EU"},
/* 1174 */ { "HANGUL JUNGSEONG YI","	= YI"},
/* 1175 */ { "HANGUL JUNGSEONG I","	= I"},
/* 1176 */ { "HANGUL JUNGSEONG A-O",NULL},
/* 1177 */ { "HANGUL JUNGSEONG A-U",NULL},
/* 1178 */ { "HANGUL JUNGSEONG YA-O",NULL},
/* 1179 */ { "HANGUL JUNGSEONG YA-YO",NULL},
/* 117A */ { "HANGUL JUNGSEONG EO-O",NULL},
/* 117B */ { "HANGUL JUNGSEONG EO-U",NULL},
/* 117C */ { "HANGUL JUNGSEONG EO-EU",NULL},
/* 117D */ { "HANGUL JUNGSEONG YEO-O",NULL},
/* 117E */ { "HANGUL JUNGSEONG YEO-U",NULL},
/* 117F */ { "HANGUL JUNGSEONG O-EO",NULL},
/* 1180 */ { "HANGUL JUNGSEONG O-E",NULL},
/* 1181 */ { "HANGUL JUNGSEONG O-YE",NULL},
/* 1182 */ { "HANGUL JUNGSEONG O-O",NULL},
/* 1183 */ { "HANGUL JUNGSEONG O-U",NULL},
/* 1184 */ { "HANGUL JUNGSEONG YO-YA",NULL},
/* 1185 */ { "HANGUL JUNGSEONG YO-YAE",NULL},
/* 1186 */ { "HANGUL JUNGSEONG YO-YEO",NULL},
/* 1187 */ { "HANGUL JUNGSEONG YO-O",NULL},
/* 1188 */ { "HANGUL JUNGSEONG YO-I",NULL},
/* 1189 */ { "HANGUL JUNGSEONG U-A",NULL},
/* 118A */ { "HANGUL JUNGSEONG U-AE",NULL},
/* 118B */ { "HANGUL JUNGSEONG U-EO-EU",NULL},
/* 118C */ { "HANGUL JUNGSEONG U-YE",NULL},
/* 118D */ { "HANGUL JUNGSEONG U-U",NULL},
/* 118E */ { "HANGUL JUNGSEONG YU-A",NULL},
/* 118F */ { "HANGUL JUNGSEONG YU-EO",NULL},
/* 1190 */ { "HANGUL JUNGSEONG YU-E",NULL},
/* 1191 */ { "HANGUL JUNGSEONG YU-YEO",NULL},
/* 1192 */ { "HANGUL JUNGSEONG YU-YE",NULL},
/* 1193 */ { "HANGUL JUNGSEONG YU-U",NULL},
/* 1194 */ { "HANGUL JUNGSEONG YU-I",NULL},
/* 1195 */ { "HANGUL JUNGSEONG EU-U",NULL},
/* 1196 */ { "HANGUL JUNGSEONG EU-EU",NULL},
/* 1197 */ { "HANGUL JUNGSEONG YI-U",NULL},
/* 1198 */ { "HANGUL JUNGSEONG I-A",NULL},
/* 1199 */ { "HANGUL JUNGSEONG I-YA",NULL},
/* 119A */ { "HANGUL JUNGSEONG I-O",NULL},
/* 119B */ { "HANGUL JUNGSEONG I-U",NULL},
/* 119C */ { "HANGUL JUNGSEONG I-EU",NULL},
/* 119D */ { "HANGUL JUNGSEONG I-ARAEA",NULL},
/* 119E */ { "HANGUL JUNGSEONG ARAEA","	* rounded open-mid back vowel"},
/* 119F */ { "HANGUL JUNGSEONG ARAEA-EO",NULL},
/* 11A0 */ { "HANGUL JUNGSEONG ARAEA-U",NULL},
/* 11A1 */ { "HANGUL JUNGSEONG ARAEA-I",NULL},
/* 11A2 */ { "HANGUL JUNGSEONG SSANGARAEA",NULL},
/* 11A3 */ { "HANGUL JUNGSEONG A-EU",NULL},
/* 11A4 */ { "HANGUL JUNGSEONG YA-U",NULL},
/* 11A5 */ { "HANGUL JUNGSEONG YEO-YA",NULL},
/* 11A6 */ { "HANGUL JUNGSEONG O-YA",NULL},
/* 11A7 */ { "HANGUL JUNGSEONG O-YAE",NULL},
/* 11A8 */ { "HANGUL JONGSEONG KIYEOK","	= G"},
/* 11A9 */ { "HANGUL JONGSEONG SSANGKIYEOK","	= GG"},
/* 11AA */ { "HANGUL JONGSEONG KIYEOK-SIOS","	= GS"},
/* 11AB */ { "HANGUL JONGSEONG NIEUN","	= N"},
/* 11AC */ { "HANGUL JONGSEONG NIEUN-CIEUC","	= NJ"},
/* 11AD */ { "HANGUL JONGSEONG NIEUN-HIEUH","	= NH"},
/* 11AE */ { "HANGUL JONGSEONG TIKEUT","	= D"},
/* 11AF */ { "HANGUL JONGSEONG RIEUL","	= L"},
/* 11B0 */ { "HANGUL JONGSEONG RIEUL-KIYEOK","	= LG"},
/* 11B1 */ { "HANGUL JONGSEONG RIEUL-MIEUM","	= LM"},
/* 11B2 */ { "HANGUL JONGSEONG RIEUL-PIEUP","	= LB"},
/* 11B3 */ { "HANGUL JONGSEONG RIEUL-SIOS","	= LS"},
/* 11B4 */ { "HANGUL JONGSEONG RIEUL-THIEUTH","	= LT"},
/* 11B5 */ { "HANGUL JONGSEONG RIEUL-PHIEUPH","	= LP"},
/* 11B6 */ { "HANGUL JONGSEONG RIEUL-HIEUH","	= LH"},
/* 11B7 */ { "HANGUL JONGSEONG MIEUM","	= M"},
/* 11B8 */ { "HANGUL JONGSEONG PIEUP","	= B"},
/* 11B9 */ { "HANGUL JONGSEONG PIEUP-SIOS","	= BS"},
/* 11BA */ { "HANGUL JONGSEONG SIOS","	= S"},
/* 11BB */ { "HANGUL JONGSEONG SSANGSIOS","	= SS"},
/* 11BC */ { "HANGUL JONGSEONG IEUNG","	= NG\n"
	"	* velar nasal consonant"},
/* 11BD */ { "HANGUL JONGSEONG CIEUC","	= J"},
/* 11BE */ { "HANGUL JONGSEONG CHIEUCH","	= C"},
/* 11BF */ { "HANGUL JONGSEONG KHIEUKH","	= K"},
/* 11C0 */ { "HANGUL JONGSEONG THIEUTH","	= T"},
/* 11C1 */ { "HANGUL JONGSEONG PHIEUPH","	= P"},
/* 11C2 */ { "HANGUL JONGSEONG HIEUH","	= H"},
/* 11C3 */ { "HANGUL JONGSEONG KIYEOK-RIEUL",NULL},
/* 11C4 */ { "HANGUL JONGSEONG KIYEOK-SIOS-KIYEOK",NULL},
/* 11C5 */ { "HANGUL JONGSEONG NIEUN-KIYEOK",NULL},
/* 11C6 */ { "HANGUL JONGSEONG NIEUN-TIKEUT",NULL},
/* 11C7 */ { "HANGUL JONGSEONG NIEUN-SIOS",NULL},
/* 11C8 */ { "HANGUL JONGSEONG NIEUN-PANSIOS",NULL},
/* 11C9 */ { "HANGUL JONGSEONG NIEUN-THIEUTH",NULL},
/* 11CA */ { "HANGUL JONGSEONG TIKEUT-KIYEOK",NULL},
/* 11CB */ { "HANGUL JONGSEONG TIKEUT-RIEUL",NULL},
/* 11CC */ { "HANGUL JONGSEONG RIEUL-KIYEOK-SIOS",NULL},
/* 11CD */ { "HANGUL JONGSEONG RIEUL-NIEUN",NULL},
/* 11CE */ { "HANGUL JONGSEONG RIEUL-TIKEUT",NULL},
/* 11CF */ { "HANGUL JONGSEONG RIEUL-TIKEUT-HIEUH",NULL},
/* 11D0 */ { "HANGUL JONGSEONG SSANGRIEUL",NULL},
/* 11D1 */ { "HANGUL JONGSEONG RIEUL-MIEUM-KIYEOK",NULL},
/* 11D2 */ { "HANGUL JONGSEONG RIEUL-MIEUM-SIOS",NULL},
/* 11D3 */ { "HANGUL JONGSEONG RIEUL-PIEUP-SIOS",NULL},
/* 11D4 */ { "HANGUL JONGSEONG RIEUL-PIEUP-HIEUH",NULL},
/* 11D5 */ { "HANGUL JONGSEONG RIEUL-KAPYEOUNPIEUP",NULL},
/* 11D6 */ { "HANGUL JONGSEONG RIEUL-SSANGSIOS",NULL},
/* 11D7 */ { "HANGUL JONGSEONG RIEUL-PANSIOS",NULL},
/* 11D8 */ { "HANGUL JONGSEONG RIEUL-KHIEUKH",NULL},
/* 11D9 */ { "HANGUL JONGSEONG RIEUL-YEORINHIEUH",NULL},
/* 11DA */ { "HANGUL JONGSEONG MIEUM-KIYEOK",NULL},
/* 11DB */ { "HANGUL JONGSEONG MIEUM-RIEUL",NULL},
/* 11DC */ { "HANGUL JONGSEONG MIEUM-PIEUP",NULL},
/* 11DD */ { "HANGUL JONGSEONG MIEUM-SIOS",NULL},
/* 11DE */ { "HANGUL JONGSEONG MIEUM-SSANGSIOS",NULL},
/* 11DF */ { "HANGUL JONGSEONG MIEUM-PANSIOS",NULL},
/* 11E0 */ { "HANGUL JONGSEONG MIEUM-CHIEUCH",NULL},
/* 11E1 */ { "HANGUL JONGSEONG MIEUM-HIEUH",NULL},
/* 11E2 */ { "HANGUL JONGSEONG KAPYEOUNMIEUM",NULL},
/* 11E3 */ { "HANGUL JONGSEONG PIEUP-RIEUL",NULL},
/* 11E4 */ { "HANGUL JONGSEONG PIEUP-PHIEUPH",NULL},
/* 11E5 */ { "HANGUL JONGSEONG PIEUP-HIEUH",NULL},
/* 11E6 */ { "HANGUL JONGSEONG KAPYEOUNPIEUP",NULL},
/* 11E7 */ { "HANGUL JONGSEONG SIOS-KIYEOK",NULL},
/* 11E8 */ { "HANGUL JONGSEONG SIOS-TIKEUT",NULL},
/* 11E9 */ { "HANGUL JONGSEONG SIOS-RIEUL",NULL},
/* 11EA */ { "HANGUL JONGSEONG SIOS-PIEUP",NULL},
/* 11EB */ { "HANGUL JONGSEONG PANSIOS",NULL},
/* 11EC */ { "HANGUL JONGSEONG IEUNG-KIYEOK","	% HANGUL JONGSEONG YESIEUNG-KIYEOK"},
/* 11ED */ { "HANGUL JONGSEONG IEUNG-SSANGKIYEOK","	% HANGUL JONGSEONG YESIEUNG-SSANGKIYEOK"},
/* 11EE */ { "HANGUL JONGSEONG SSANGIEUNG","	% HANGUL JONGSEONG SSANGYESIEUNG"},
/* 11EF */ { "HANGUL JONGSEONG IEUNG-KHIEUKH","	% HANGUL JONGSEONG YESIEUNG-KHIEUKH"},
/* 11F0 */ { "HANGUL JONGSEONG YESIEUNG",NULL},
/* 11F1 */ { "HANGUL JONGSEONG YESIEUNG-SIOS",NULL},
/* 11F2 */ { "HANGUL JONGSEONG YESIEUNG-PANSIOS",NULL},
/* 11F3 */ { "HANGUL JONGSEONG PHIEUPH-PIEUP",NULL},
/* 11F4 */ { "HANGUL JONGSEONG KAPYEOUNPHIEUPH",NULL},
/* 11F5 */ { "HANGUL JONGSEONG HIEUH-NIEUN",NULL},
/* 11F6 */ { "HANGUL JONGSEONG HIEUH-RIEUL",NULL},
/* 11F7 */ { "HANGUL JONGSEONG HIEUH-MIEUM",NULL},
/* 11F8 */ { "HANGUL JONGSEONG HIEUH-PIEUP",NULL},
/* 11F9 */ { "HANGUL JONGSEONG YEORINHIEUH",NULL},
/* 11FA */ { "HANGUL JONGSEONG KIYEOK-NIEUN",NULL},
/* 11FB */ { "HANGUL JONGSEONG KIYEOK-PIEUP",NULL},
/* 11FC */ { "HANGUL JONGSEONG KIYEOK-CHIEUCH",NULL},
/* 11FD */ { "HANGUL JONGSEONG KIYEOK-KHIEUKH",NULL},
/* 11FE */ { "HANGUL JONGSEONG KIYEOK-HIEUH",NULL},
/* 11FF */ { "HANGUL JONGSEONG SSANGNIEUN",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_00_12[] = {
/* 1200 */ { "ETHIOPIC SYLLABLE HA",NULL},
/* 1201 */ { "ETHIOPIC SYLLABLE HU",NULL},
/* 1202 */ { "ETHIOPIC SYLLABLE HI",NULL},
/* 1203 */ { "ETHIOPIC SYLLABLE HAA",NULL},
/* 1204 */ { "ETHIOPIC SYLLABLE HEE",NULL},
/* 1205 */ { "ETHIOPIC SYLLABLE HE",NULL},
/* 1206 */ { "ETHIOPIC SYLLABLE HO",NULL},
/* 1207 */ { "ETHIOPIC SYLLABLE HOA",NULL},
/* 1208 */ { "ETHIOPIC SYLLABLE LA",NULL},
/* 1209 */ { "ETHIOPIC SYLLABLE LU",NULL},
/* 120A */ { "ETHIOPIC SYLLABLE LI",NULL},
/* 120B */ { "ETHIOPIC SYLLABLE LAA",NULL},
/* 120C */ { "ETHIOPIC SYLLABLE LEE",NULL},
/* 120D */ { "ETHIOPIC SYLLABLE LE",NULL},
/* 120E */ { "ETHIOPIC SYLLABLE LO",NULL},
/* 120F */ { "ETHIOPIC SYLLABLE LWA",NULL},
/* 1210 */ { "ETHIOPIC SYLLABLE HHA",NULL},
/* 1211 */ { "ETHIOPIC SYLLABLE HHU",NULL},
/* 1212 */ { "ETHIOPIC SYLLABLE HHI",NULL},
/* 1213 */ { "ETHIOPIC SYLLABLE HHAA",NULL},
/* 1214 */ { "ETHIOPIC SYLLABLE HHEE",NULL},
/* 1215 */ { "ETHIOPIC SYLLABLE HHE",NULL},
/* 1216 */ { "ETHIOPIC SYLLABLE HHO",NULL},
/* 1217 */ { "ETHIOPIC SYLLABLE HHWA",NULL},
/* 1218 */ { "ETHIOPIC SYLLABLE MA",NULL},
/* 1219 */ { "ETHIOPIC SYLLABLE MU",NULL},
/* 121A */ { "ETHIOPIC SYLLABLE MI",NULL},
/* 121B */ { "ETHIOPIC SYLLABLE MAA",NULL},
/* 121C */ { "ETHIOPIC SYLLABLE MEE",NULL},
/* 121D */ { "ETHIOPIC SYLLABLE ME",NULL},
/* 121E */ { "ETHIOPIC SYLLABLE MO",NULL},
/* 121F */ { "ETHIOPIC SYLLABLE MWA",NULL},
/* 1220 */ { "ETHIOPIC SYLLABLE SZA",NULL},
/* 1221 */ { "ETHIOPIC SYLLABLE SZU",NULL},
/* 1222 */ { "ETHIOPIC SYLLABLE SZI",NULL},
/* 1223 */ { "ETHIOPIC SYLLABLE SZAA",NULL},
/* 1224 */ { "ETHIOPIC SYLLABLE SZEE",NULL},
/* 1225 */ { "ETHIOPIC SYLLABLE SZE",NULL},
/* 1226 */ { "ETHIOPIC SYLLABLE SZO",NULL},
/* 1227 */ { "ETHIOPIC SYLLABLE SZWA",NULL},
/* 1228 */ { "ETHIOPIC SYLLABLE RA",NULL},
/* 1229 */ { "ETHIOPIC SYLLABLE RU",NULL},
/* 122A */ { "ETHIOPIC SYLLABLE RI",NULL},
/* 122B */ { "ETHIOPIC SYLLABLE RAA",NULL},
/* 122C */ { "ETHIOPIC SYLLABLE REE",NULL},
/* 122D */ { "ETHIOPIC SYLLABLE RE",NULL},
/* 122E */ { "ETHIOPIC SYLLABLE RO",NULL},
/* 122F */ { "ETHIOPIC SYLLABLE RWA",NULL},
/* 1230 */ { "ETHIOPIC SYLLABLE SA",NULL},
/* 1231 */ { "ETHIOPIC SYLLABLE SU",NULL},
/* 1232 */ { "ETHIOPIC SYLLABLE SI",NULL},
/* 1233 */ { "ETHIOPIC SYLLABLE SAA",NULL},
/* 1234 */ { "ETHIOPIC SYLLABLE SEE",NULL},
/* 1235 */ { "ETHIOPIC SYLLABLE SE",NULL},
/* 1236 */ { "ETHIOPIC SYLLABLE SO",NULL},
/* 1237 */ { "ETHIOPIC SYLLABLE SWA",NULL},
/* 1238 */ { "ETHIOPIC SYLLABLE SHA",NULL},
/* 1239 */ { "ETHIOPIC SYLLABLE SHU",NULL},
/* 123A */ { "ETHIOPIC SYLLABLE SHI",NULL},
/* 123B */ { "ETHIOPIC SYLLABLE SHAA",NULL},
/* 123C */ { "ETHIOPIC SYLLABLE SHEE",NULL},
/* 123D */ { "ETHIOPIC SYLLABLE SHE",NULL},
/* 123E */ { "ETHIOPIC SYLLABLE SHO",NULL},
/* 123F */ { "ETHIOPIC SYLLABLE SHWA",NULL},
/* 1240 */ { "ETHIOPIC SYLLABLE QA",NULL},
/* 1241 */ { "ETHIOPIC SYLLABLE QU",NULL},
/* 1242 */ { "ETHIOPIC SYLLABLE QI",NULL},
/* 1243 */ { "ETHIOPIC SYLLABLE QAA",NULL},
/* 1244 */ { "ETHIOPIC SYLLABLE QEE",NULL},
/* 1245 */ { "ETHIOPIC SYLLABLE QE",NULL},
/* 1246 */ { "ETHIOPIC SYLLABLE QO",NULL},
/* 1247 */ { "ETHIOPIC SYLLABLE QOA",NULL},
/* 1248 */ { "ETHIOPIC SYLLABLE QWA",NULL},
/* 1249 */ { NULL,NULL},
/* 124A */ { "ETHIOPIC SYLLABLE QWI","	x (ethiopic syllable gurage qwi - 1E7F0)"},
/* 124B */ { "ETHIOPIC SYLLABLE QWAA",NULL},
/* 124C */ { "ETHIOPIC SYLLABLE QWEE","	x (ethiopic syllable gurage qwee - 1E7F1)"},
/* 124D */ { "ETHIOPIC SYLLABLE QWE","	x (ethiopic syllable gurage qwe - 1E7F2)"},
/* 124E */ { NULL,NULL},
/* 124F */ { NULL,NULL},
/* 1250 */ { "ETHIOPIC SYLLABLE QHA",NULL},
/* 1251 */ { "ETHIOPIC SYLLABLE QHU",NULL},
/* 1252 */ { "ETHIOPIC SYLLABLE QHI",NULL},
/* 1253 */ { "ETHIOPIC SYLLABLE QHAA",NULL},
/* 1254 */ { "ETHIOPIC SYLLABLE QHEE",NULL},
/* 1255 */ { "ETHIOPIC SYLLABLE QHE",NULL},
/* 1256 */ { "ETHIOPIC SYLLABLE QHO",NULL},
/* 1257 */ { NULL,NULL},
/* 1258 */ { "ETHIOPIC SYLLABLE QHWA",NULL},
/* 1259 */ { NULL,NULL},
/* 125A */ { "ETHIOPIC SYLLABLE QHWI",NULL},
/* 125B */ { "ETHIOPIC SYLLABLE QHWAA",NULL},
/* 125C */ { "ETHIOPIC SYLLABLE QHWEE",NULL},
/* 125D */ { "ETHIOPIC SYLLABLE QHWE",NULL},
/* 125E */ { NULL,NULL},
/* 125F */ { NULL,NULL},
/* 1260 */ { "ETHIOPIC SYLLABLE BA",NULL},
/* 1261 */ { "ETHIOPIC SYLLABLE BU",NULL},
/* 1262 */ { "ETHIOPIC SYLLABLE BI",NULL},
/* 1263 */ { "ETHIOPIC SYLLABLE BAA",NULL},
/* 1264 */ { "ETHIOPIC SYLLABLE BEE",NULL},
/* 1265 */ { "ETHIOPIC SYLLABLE BE",NULL},
/* 1266 */ { "ETHIOPIC SYLLABLE BO",NULL},
/* 1267 */ { "ETHIOPIC SYLLABLE BWA",NULL},
/* 1268 */ { "ETHIOPIC SYLLABLE VA",NULL},
/* 1269 */ { "ETHIOPIC SYLLABLE VU",NULL},
/* 126A */ { "ETHIOPIC SYLLABLE VI",NULL},
/* 126B */ { "ETHIOPIC SYLLABLE VAA",NULL},
/* 126C */ { "ETHIOPIC SYLLABLE VEE",NULL},
/* 126D */ { "ETHIOPIC SYLLABLE VE",NULL},
/* 126E */ { "ETHIOPIC SYLLABLE VO",NULL},
/* 126F */ { "ETHIOPIC SYLLABLE VWA",NULL},
/* 1270 */ { "ETHIOPIC SYLLABLE TA",NULL},
/* 1271 */ { "ETHIOPIC SYLLABLE TU",NULL},
/* 1272 */ { "ETHIOPIC SYLLABLE TI",NULL},
/* 1273 */ { "ETHIOPIC SYLLABLE TAA",NULL},
/* 1274 */ { "ETHIOPIC SYLLABLE TEE",NULL},
/* 1275 */ { "ETHIOPIC SYLLABLE TE",NULL},
/* 1276 */ { "ETHIOPIC SYLLABLE TO",NULL},
/* 1277 */ { "ETHIOPIC SYLLABLE TWA",NULL},
/* 1278 */ { "ETHIOPIC SYLLABLE CA",NULL},
/* 1279 */ { "ETHIOPIC SYLLABLE CU",NULL},
/* 127A */ { "ETHIOPIC SYLLABLE CI",NULL},
/* 127B */ { "ETHIOPIC SYLLABLE CAA",NULL},
/* 127C */ { "ETHIOPIC SYLLABLE CEE",NULL},
/* 127D */ { "ETHIOPIC SYLLABLE CE",NULL},
/* 127E */ { "ETHIOPIC SYLLABLE CO",NULL},
/* 127F */ { "ETHIOPIC SYLLABLE CWA",NULL},
/* 1280 */ { "ETHIOPIC SYLLABLE XA",NULL},
/* 1281 */ { "ETHIOPIC SYLLABLE XU",NULL},
/* 1282 */ { "ETHIOPIC SYLLABLE XI",NULL},
/* 1283 */ { "ETHIOPIC SYLLABLE XAA",NULL},
/* 1284 */ { "ETHIOPIC SYLLABLE XEE",NULL},
/* 1285 */ { "ETHIOPIC SYLLABLE XE",NULL},
/* 1286 */ { "ETHIOPIC SYLLABLE XO",NULL},
/* 1287 */ { "ETHIOPIC SYLLABLE XOA",NULL},
/* 1288 */ { "ETHIOPIC SYLLABLE XWA",NULL},
/* 1289 */ { NULL,NULL},
/* 128A */ { "ETHIOPIC SYLLABLE XWI",NULL},
/* 128B */ { "ETHIOPIC SYLLABLE XWAA",NULL},
/* 128C */ { "ETHIOPIC SYLLABLE XWEE",NULL},
/* 128D */ { "ETHIOPIC SYLLABLE XWE",NULL},
/* 128E */ { NULL,NULL},
/* 128F */ { NULL,NULL},
/* 1290 */ { "ETHIOPIC SYLLABLE NA",NULL},
/* 1291 */ { "ETHIOPIC SYLLABLE NU",NULL},
/* 1292 */ { "ETHIOPIC SYLLABLE NI",NULL},
/* 1293 */ { "ETHIOPIC SYLLABLE NAA",NULL},
/* 1294 */ { "ETHIOPIC SYLLABLE NEE",NULL},
/* 1295 */ { "ETHIOPIC SYLLABLE NE",NULL},
/* 1296 */ { "ETHIOPIC SYLLABLE NO",NULL},
/* 1297 */ { "ETHIOPIC SYLLABLE NWA",NULL},
/* 1298 */ { "ETHIOPIC SYLLABLE NYA",NULL},
/* 1299 */ { "ETHIOPIC SYLLABLE NYU",NULL},
/* 129A */ { "ETHIOPIC SYLLABLE NYI",NULL},
/* 129B */ { "ETHIOPIC SYLLABLE NYAA",NULL},
/* 129C */ { "ETHIOPIC SYLLABLE NYEE",NULL},
/* 129D */ { "ETHIOPIC SYLLABLE NYE",NULL},
/* 129E */ { "ETHIOPIC SYLLABLE NYO",NULL},
/* 129F */ { "ETHIOPIC SYLLABLE NYWA",NULL},
/* 12A0 */ { "ETHIOPIC SYLLABLE GLOTTAL A",NULL},
/* 12A1 */ { "ETHIOPIC SYLLABLE GLOTTAL U",NULL},
/* 12A2 */ { "ETHIOPIC SYLLABLE GLOTTAL I",NULL},
/* 12A3 */ { "ETHIOPIC SYLLABLE GLOTTAL AA",NULL},
/* 12A4 */ { "ETHIOPIC SYLLABLE GLOTTAL EE",NULL},
/* 12A5 */ { "ETHIOPIC SYLLABLE GLOTTAL E",NULL},
/* 12A6 */ { "ETHIOPIC SYLLABLE GLOTTAL O",NULL},
/* 12A7 */ { "ETHIOPIC SYLLABLE GLOTTAL WA",NULL},
/* 12A8 */ { "ETHIOPIC SYLLABLE KA",NULL},
/* 12A9 */ { "ETHIOPIC SYLLABLE KU",NULL},
/* 12AA */ { "ETHIOPIC SYLLABLE KI",NULL},
/* 12AB */ { "ETHIOPIC SYLLABLE KAA",NULL},
/* 12AC */ { "ETHIOPIC SYLLABLE KEE",NULL},
/* 12AD */ { "ETHIOPIC SYLLABLE KE",NULL},
/* 12AE */ { "ETHIOPIC SYLLABLE KO",NULL},
/* 12AF */ { "ETHIOPIC SYLLABLE KOA",NULL},
/* 12B0 */ { "ETHIOPIC SYLLABLE KWA",NULL},
/* 12B1 */ { NULL,NULL},
/* 12B2 */ { "ETHIOPIC SYLLABLE KWI","	x (ethiopic syllable gurage kwi - 1E7F5)"},
/* 12B3 */ { "ETHIOPIC SYLLABLE KWAA",NULL},
/* 12B4 */ { "ETHIOPIC SYLLABLE KWEE","	x (ethiopic syllable gurage kwee - 1E7F6)"},
/* 12B5 */ { "ETHIOPIC SYLLABLE KWE","	x (ethiopic syllable gurage kwe - 1E7F7)"},
/* 12B6 */ { NULL,NULL},
/* 12B7 */ { NULL,NULL},
/* 12B8 */ { "ETHIOPIC SYLLABLE KXA",NULL},
/* 12B9 */ { "ETHIOPIC SYLLABLE KXU",NULL},
/* 12BA */ { "ETHIOPIC SYLLABLE KXI",NULL},
/* 12BB */ { "ETHIOPIC SYLLABLE KXAA",NULL},
/* 12BC */ { "ETHIOPIC SYLLABLE KXEE",NULL},
/* 12BD */ { "ETHIOPIC SYLLABLE KXE",NULL},
/* 12BE */ { "ETHIOPIC SYLLABLE KXO",NULL},
/* 12BF */ { NULL,NULL},
/* 12C0 */ { "ETHIOPIC SYLLABLE KXWA","	x (ethiopic syllable gurage hhwa - 1E7E8)"},
/* 12C1 */ { NULL,NULL},
/* 12C2 */ { "ETHIOPIC SYLLABLE KXWI","	x (ethiopic syllable hhwi - 1E7E9)"},
/* 12C3 */ { "ETHIOPIC SYLLABLE KXWAA",NULL},
/* 12C4 */ { "ETHIOPIC SYLLABLE KXWEE","	x (ethiopic syllable hhwee - 1E7EA)"},
/* 12C5 */ { "ETHIOPIC SYLLABLE KXWE","	x (ethiopic syllable hhwe - 1E7EB)"},
/* 12C6 */ { NULL,NULL},
/* 12C7 */ { NULL,NULL},
/* 12C8 */ { "ETHIOPIC SYLLABLE WA",NULL},
/* 12C9 */ { "ETHIOPIC SYLLABLE WU",NULL},
/* 12CA */ { "ETHIOPIC SYLLABLE WI",NULL},
/* 12CB */ { "ETHIOPIC SYLLABLE WAA",NULL},
/* 12CC */ { "ETHIOPIC SYLLABLE WEE",NULL},
/* 12CD */ { "ETHIOPIC SYLLABLE WE",NULL},
/* 12CE */ { "ETHIOPIC SYLLABLE WO",NULL},
/* 12CF */ { "ETHIOPIC SYLLABLE WOA",NULL},
/* 12D0 */ { "ETHIOPIC SYLLABLE PHARYNGEAL A",NULL},
/* 12D1 */ { "ETHIOPIC SYLLABLE PHARYNGEAL U",NULL},
/* 12D2 */ { "ETHIOPIC SYLLABLE PHARYNGEAL I",NULL},
/* 12D3 */ { "ETHIOPIC SYLLABLE PHARYNGEAL AA",NULL},
/* 12D4 */ { "ETHIOPIC SYLLABLE PHARYNGEAL EE",NULL},
/* 12D5 */ { "ETHIOPIC SYLLABLE PHARYNGEAL E",NULL},
/* 12D6 */ { "ETHIOPIC SYLLABLE PHARYNGEAL O",NULL},
/* 12D7 */ { NULL,NULL},
/* 12D8 */ { "ETHIOPIC SYLLABLE ZA",NULL},
/* 12D9 */ { "ETHIOPIC SYLLABLE ZU",NULL},
/* 12DA */ { "ETHIOPIC SYLLABLE ZI",NULL},
/* 12DB */ { "ETHIOPIC SYLLABLE ZAA",NULL},
/* 12DC */ { "ETHIOPIC SYLLABLE ZEE",NULL},
/* 12DD */ { "ETHIOPIC SYLLABLE ZE",NULL},
/* 12DE */ { "ETHIOPIC SYLLABLE ZO",NULL},
/* 12DF */ { "ETHIOPIC SYLLABLE ZWA",NULL},
/* 12E0 */ { "ETHIOPIC SYLLABLE ZHA",NULL},
/* 12E1 */ { "ETHIOPIC SYLLABLE ZHU",NULL},
/* 12E2 */ { "ETHIOPIC SYLLABLE ZHI",NULL},
/* 12E3 */ { "ETHIOPIC SYLLABLE ZHAA",NULL},
/* 12E4 */ { "ETHIOPIC SYLLABLE ZHEE",NULL},
/* 12E5 */ { "ETHIOPIC SYLLABLE ZHE",NULL},
/* 12E6 */ { "ETHIOPIC SYLLABLE ZHO",NULL},
/* 12E7 */ { "ETHIOPIC SYLLABLE ZHWA",NULL},
/* 12E8 */ { "ETHIOPIC SYLLABLE YA",NULL},
/* 12E9 */ { "ETHIOPIC SYLLABLE YU",NULL},
/* 12EA */ { "ETHIOPIC SYLLABLE YI",NULL},
/* 12EB */ { "ETHIOPIC SYLLABLE YAA",NULL},
/* 12EC */ { "ETHIOPIC SYLLABLE YEE",NULL},
/* 12ED */ { "ETHIOPIC SYLLABLE YE",NULL},
/* 12EE */ { "ETHIOPIC SYLLABLE YO",NULL},
/* 12EF */ { "ETHIOPIC SYLLABLE YOA",NULL},
/* 12F0 */ { "ETHIOPIC SYLLABLE DA",NULL},
/* 12F1 */ { "ETHIOPIC SYLLABLE DU",NULL},
/* 12F2 */ { "ETHIOPIC SYLLABLE DI",NULL},
/* 12F3 */ { "ETHIOPIC SYLLABLE DAA",NULL},
/* 12F4 */ { "ETHIOPIC SYLLABLE DEE",NULL},
/* 12F5 */ { "ETHIOPIC SYLLABLE DE",NULL},
/* 12F6 */ { "ETHIOPIC SYLLABLE DO",NULL},
/* 12F7 */ { "ETHIOPIC SYLLABLE DWA",NULL},
/* 12F8 */ { "ETHIOPIC SYLLABLE DDA",NULL},
/* 12F9 */ { "ETHIOPIC SYLLABLE DDU",NULL},
/* 12FA */ { "ETHIOPIC SYLLABLE DDI",NULL},
/* 12FB */ { "ETHIOPIC SYLLABLE DDAA",NULL},
/* 12FC */ { "ETHIOPIC SYLLABLE DDEE",NULL},
/* 12FD */ { "ETHIOPIC SYLLABLE DDE",NULL},
/* 12FE */ { "ETHIOPIC SYLLABLE DDO",NULL},
/* 12FF */ { "ETHIOPIC SYLLABLE DDWA",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_00_13[] = {
/* 1300 */ { "ETHIOPIC SYLLABLE JA",NULL},
/* 1301 */ { "ETHIOPIC SYLLABLE JU",NULL},
/* 1302 */ { "ETHIOPIC SYLLABLE JI",NULL},
/* 1303 */ { "ETHIOPIC SYLLABLE JAA",NULL},
/* 1304 */ { "ETHIOPIC SYLLABLE JEE",NULL},
/* 1305 */ { "ETHIOPIC SYLLABLE JE",NULL},
/* 1306 */ { "ETHIOPIC SYLLABLE JO",NULL},
/* 1307 */ { "ETHIOPIC SYLLABLE JWA",NULL},
/* 1308 */ { "ETHIOPIC SYLLABLE GA",NULL},
/* 1309 */ { "ETHIOPIC SYLLABLE GU",NULL},
/* 130A */ { "ETHIOPIC SYLLABLE GI",NULL},
/* 130B */ { "ETHIOPIC SYLLABLE GAA",NULL},
/* 130C */ { "ETHIOPIC SYLLABLE GEE",NULL},
/* 130D */ { "ETHIOPIC SYLLABLE GE",NULL},
/* 130E */ { "ETHIOPIC SYLLABLE GO",NULL},
/* 130F */ { "ETHIOPIC SYLLABLE GOA",NULL},
/* 1310 */ { "ETHIOPIC SYLLABLE GWA",NULL},
/* 1311 */ { NULL,NULL},
/* 1312 */ { "ETHIOPIC SYLLABLE GWI","	x (ethiopic syllable gurage gwi - 1E7F8)"},
/* 1313 */ { "ETHIOPIC SYLLABLE GWAA",NULL},
/* 1314 */ { "ETHIOPIC SYLLABLE GWEE","	x (ethiopic syllable gurage gwee - 1E7F9)"},
/* 1315 */ { "ETHIOPIC SYLLABLE GWE","	x (ethiopic syllable gurage gwe - 1E7FA)"},
/* 1316 */ { NULL,NULL},
/* 1317 */ { NULL,NULL},
/* 1318 */ { "ETHIOPIC SYLLABLE GGA",NULL},
/* 1319 */ { "ETHIOPIC SYLLABLE GGU",NULL},
/* 131A */ { "ETHIOPIC SYLLABLE GGI",NULL},
/* 131B */ { "ETHIOPIC SYLLABLE GGAA",NULL},
/* 131C */ { "ETHIOPIC SYLLABLE GGEE",NULL},
/* 131D */ { "ETHIOPIC SYLLABLE GGE",NULL},
/* 131E */ { "ETHIOPIC SYLLABLE GGO",NULL},
/* 131F */ { "ETHIOPIC SYLLABLE GGWAA",NULL},
/* 1320 */ { "ETHIOPIC SYLLABLE THA",NULL},
/* 1321 */ { "ETHIOPIC SYLLABLE THU",NULL},
/* 1322 */ { "ETHIOPIC SYLLABLE THI",NULL},
/* 1323 */ { "ETHIOPIC SYLLABLE THAA",NULL},
/* 1324 */ { "ETHIOPIC SYLLABLE THEE",NULL},
/* 1325 */ { "ETHIOPIC SYLLABLE THE",NULL},
/* 1326 */ { "ETHIOPIC SYLLABLE THO",NULL},
/* 1327 */ { "ETHIOPIC SYLLABLE THWA",NULL},
/* 1328 */ { "ETHIOPIC SYLLABLE CHA",NULL},
/* 1329 */ { "ETHIOPIC SYLLABLE CHU",NULL},
/* 132A */ { "ETHIOPIC SYLLABLE CHI",NULL},
/* 132B */ { "ETHIOPIC SYLLABLE CHAA",NULL},
/* 132C */ { "ETHIOPIC SYLLABLE CHEE",NULL},
/* 132D */ { "ETHIOPIC SYLLABLE CHE",NULL},
/* 132E */ { "ETHIOPIC SYLLABLE CHO",NULL},
/* 132F */ { "ETHIOPIC SYLLABLE CHWA",NULL},
/* 1330 */ { "ETHIOPIC SYLLABLE PHA",NULL},
/* 1331 */ { "ETHIOPIC SYLLABLE PHU",NULL},
/* 1332 */ { "ETHIOPIC SYLLABLE PHI",NULL},
/* 1333 */ { "ETHIOPIC SYLLABLE PHAA",NULL},
/* 1334 */ { "ETHIOPIC SYLLABLE PHEE",NULL},
/* 1335 */ { "ETHIOPIC SYLLABLE PHE",NULL},
/* 1336 */ { "ETHIOPIC SYLLABLE PHO",NULL},
/* 1337 */ { "ETHIOPIC SYLLABLE PHWA",NULL},
/* 1338 */ { "ETHIOPIC SYLLABLE TSA",NULL},
/* 1339 */ { "ETHIOPIC SYLLABLE TSU",NULL},
/* 133A */ { "ETHIOPIC SYLLABLE TSI",NULL},
/* 133B */ { "ETHIOPIC SYLLABLE TSAA",NULL},
/* 133C */ { "ETHIOPIC SYLLABLE TSEE",NULL},
/* 133D */ { "ETHIOPIC SYLLABLE TSE",NULL},
/* 133E */ { "ETHIOPIC SYLLABLE TSO",NULL},
/* 133F */ { "ETHIOPIC SYLLABLE TSWA",NULL},
/* 1340 */ { "ETHIOPIC SYLLABLE TZA",NULL},
/* 1341 */ { "ETHIOPIC SYLLABLE TZU",NULL},
/* 1342 */ { "ETHIOPIC SYLLABLE TZI",NULL},
/* 1343 */ { "ETHIOPIC SYLLABLE TZAA",NULL},
/* 1344 */ { "ETHIOPIC SYLLABLE TZEE",NULL},
/* 1345 */ { "ETHIOPIC SYLLABLE TZE",NULL},
/* 1346 */ { "ETHIOPIC SYLLABLE TZO",NULL},
/* 1347 */ { "ETHIOPIC SYLLABLE TZOA",NULL},
/* 1348 */ { "ETHIOPIC SYLLABLE FA",NULL},
/* 1349 */ { "ETHIOPIC SYLLABLE FU",NULL},
/* 134A */ { "ETHIOPIC SYLLABLE FI",NULL},
/* 134B */ { "ETHIOPIC SYLLABLE FAA",NULL},
/* 134C */ { "ETHIOPIC SYLLABLE FEE",NULL},
/* 134D */ { "ETHIOPIC SYLLABLE FE",NULL},
/* 134E */ { "ETHIOPIC SYLLABLE FO",NULL},
/* 134F */ { "ETHIOPIC SYLLABLE FWA",NULL},
/* 1350 */ { "ETHIOPIC SYLLABLE PA",NULL},
/* 1351 */ { "ETHIOPIC SYLLABLE PU",NULL},
/* 1352 */ { "ETHIOPIC SYLLABLE PI",NULL},
/* 1353 */ { "ETHIOPIC SYLLABLE PAA",NULL},
/* 1354 */ { "ETHIOPIC SYLLABLE PEE",NULL},
/* 1355 */ { "ETHIOPIC SYLLABLE PE",NULL},
/* 1356 */ { "ETHIOPIC SYLLABLE PO",NULL},
/* 1357 */ { "ETHIOPIC SYLLABLE PWA",NULL},
/* 1358 */ { "ETHIOPIC SYLLABLE RYA",NULL},
/* 1359 */ { "ETHIOPIC SYLLABLE MYA",NULL},
/* 135A */ { "ETHIOPIC SYLLABLE FYA",NULL},
/* 135B */ { NULL,NULL},
/* 135C */ { NULL,NULL},
/* 135D */ { "ETHIOPIC COMBINING GEMINATION AND VOWEL LENGTH MARK","	* Basketo"},
/* 135E */ { "ETHIOPIC COMBINING VOWEL LENGTH MARK","	* Basketo"},
/* 135F */ { "ETHIOPIC COMBINING GEMINATION MARK",NULL},
/* 1360 */ { "ETHIOPIC SECTION MARK",NULL},
/* 1361 */ { "ETHIOPIC WORDSPACE",NULL},
/* 1362 */ { "ETHIOPIC FULL STOP",NULL},
/* 1363 */ { "ETHIOPIC COMMA",NULL},
/* 1364 */ { "ETHIOPIC SEMICOLON",NULL},
/* 1365 */ { "ETHIOPIC COLON",NULL},
/* 1366 */ { "ETHIOPIC PREFACE COLON",NULL},
/* 1367 */ { "ETHIOPIC QUESTION MARK",NULL},
/* 1368 */ { "ETHIOPIC PARAGRAPH SEPARATOR",NULL},
/* 1369 */ { "ETHIOPIC DIGIT ONE",NULL},
/* 136A */ { "ETHIOPIC DIGIT TWO",NULL},
/* 136B */ { "ETHIOPIC DIGIT THREE",NULL},
/* 136C */ { "ETHIOPIC DIGIT FOUR",NULL},
/* 136D */ { "ETHIOPIC DIGIT FIVE",NULL},
/* 136E */ { "ETHIOPIC DIGIT SIX",NULL},
/* 136F */ { "ETHIOPIC DIGIT SEVEN",NULL},
/* 1370 */ { "ETHIOPIC DIGIT EIGHT",NULL},
/* 1371 */ { "ETHIOPIC DIGIT NINE",NULL},
/* 1372 */ { "ETHIOPIC NUMBER TEN",NULL},
/* 1373 */ { "ETHIOPIC NUMBER TWENTY",NULL},
/* 1374 */ { "ETHIOPIC NUMBER THIRTY",NULL},
/* 1375 */ { "ETHIOPIC NUMBER FORTY",NULL},
/* 1376 */ { "ETHIOPIC NUMBER FIFTY",NULL},
/* 1377 */ { "ETHIOPIC NUMBER SIXTY",NULL},
/* 1378 */ { "ETHIOPIC NUMBER SEVENTY",NULL},
/* 1379 */ { "ETHIOPIC NUMBER EIGHTY",NULL},
/* 137A */ { "ETHIOPIC NUMBER NINETY",NULL},
/* 137B */ { "ETHIOPIC NUMBER HUNDRED",NULL},
/* 137C */ { "ETHIOPIC NUMBER TEN THOUSAND",NULL},
/* 137D */ { NULL,NULL},
/* 137E */ { NULL,NULL},
/* 137F */ { NULL,NULL},
/* 1380 */ { "ETHIOPIC SYLLABLE SEBATBEIT MWA",NULL},
/* 1381 */ { "ETHIOPIC SYLLABLE MWI","	x (ethiopic syllable gurage mwi - 1E7ED)"},
/* 1382 */ { "ETHIOPIC SYLLABLE MWEE","	x (ethiopic syllable gurage mwee - 1E7EE)"},
/* 1383 */ { "ETHIOPIC SYLLABLE MWE",NULL},
/* 1384 */ { "ETHIOPIC SYLLABLE SEBATBEIT BWA",NULL},
/* 1385 */ { "ETHIOPIC SYLLABLE BWI","	x (ethiopic syllable gurage bwi - 1E7F3)"},
/* 1386 */ { "ETHIOPIC SYLLABLE BWEE","	x (ethiopic syllable gurage bwee - 1E7F4)"},
/* 1387 */ { "ETHIOPIC SYLLABLE BWE",NULL},
/* 1388 */ { "ETHIOPIC SYLLABLE SEBATBEIT FWA",NULL},
/* 1389 */ { "ETHIOPIC SYLLABLE FWI","	x (ethiopic syllable gurage fwi - 1E7FB)"},
/* 138A */ { "ETHIOPIC SYLLABLE FWEE","	x (ethiopic syllable gurage fwee - 1E7FC)"},
/* 138B */ { "ETHIOPIC SYLLABLE FWE",NULL},
/* 138C */ { "ETHIOPIC SYLLABLE SEBATBEIT PWA",NULL},
/* 138D */ { "ETHIOPIC SYLLABLE PWI","	x (ethiopic syllable gurage pwi - 1E7FD)"},
/* 138E */ { "ETHIOPIC SYLLABLE PWEE","	x (ethiopic syllable gurage pwee - 1E7FE)"},
/* 138F */ { "ETHIOPIC SYLLABLE PWE",NULL},
/* 1390 */ { "ETHIOPIC TONAL MARK YIZET",NULL},
/* 1391 */ { "ETHIOPIC TONAL MARK DERET",NULL},
/* 1392 */ { "ETHIOPIC TONAL MARK RIKRIK",NULL},
/* 1393 */ { "ETHIOPIC TONAL MARK SHORT RIKRIK",NULL},
/* 1394 */ { "ETHIOPIC TONAL MARK DIFAT",NULL},
/* 1395 */ { "ETHIOPIC TONAL MARK KENAT",NULL},
/* 1396 */ { "ETHIOPIC TONAL MARK CHIRET",NULL},
/* 1397 */ { "ETHIOPIC TONAL MARK HIDET",NULL},
/* 1398 */ { "ETHIOPIC TONAL MARK DERET-HIDET",NULL},
/* 1399 */ { "ETHIOPIC TONAL MARK KURT",NULL},
/* 139A */ { NULL,NULL},
/* 139B */ { NULL,NULL},
/* 139C */ { NULL,NULL},
/* 139D */ { NULL,NULL},
/* 139E */ { NULL,NULL},
/* 139F */ { NULL,NULL},
/* 13A0 */ { "CHEROKEE LETTER A",NULL},
/* 13A1 */ { "CHEROKEE LETTER E",NULL},
/* 13A2 */ { "CHEROKEE LETTER I",NULL},
/* 13A3 */ { "CHEROKEE LETTER O",NULL},
/* 13A4 */ { "CHEROKEE LETTER U",NULL},
/* 13A5 */ { "CHEROKEE LETTER V",NULL},
/* 13A6 */ { "CHEROKEE LETTER GA",NULL},
/* 13A7 */ { "CHEROKEE LETTER KA",NULL},
/* 13A8 */ { "CHEROKEE LETTER GE",NULL},
/* 13A9 */ { "CHEROKEE LETTER GI",NULL},
/* 13AA */ { "CHEROKEE LETTER GO",NULL},
/* 13AB */ { "CHEROKEE LETTER GU",NULL},
/* 13AC */ { "CHEROKEE LETTER GV",NULL},
/* 13AD */ { "CHEROKEE LETTER HA",NULL},
/* 13AE */ { "CHEROKEE LETTER HE",NULL},
/* 13AF */ { "CHEROKEE LETTER HI",NULL},
/* 13B0 */ { "CHEROKEE LETTER HO",NULL},
/* 13B1 */ { "CHEROKEE LETTER HU",NULL},
/* 13B2 */ { "CHEROKEE LETTER HV",NULL},
/* 13B3 */ { "CHEROKEE LETTER LA",NULL},
/* 13B4 */ { "CHEROKEE LETTER LE",NULL},
/* 13B5 */ { "CHEROKEE LETTER LI",NULL},
/* 13B6 */ { "CHEROKEE LETTER LO",NULL},
/* 13B7 */ { "CHEROKEE LETTER LU",NULL},
/* 13B8 */ { "CHEROKEE LETTER LV",NULL},
/* 13B9 */ { "CHEROKEE LETTER MA",NULL},
/* 13BA */ { "CHEROKEE LETTER ME",NULL},
/* 13BB */ { "CHEROKEE LETTER MI",NULL},
/* 13BC */ { "CHEROKEE LETTER MO",NULL},
/* 13BD */ { "CHEROKEE LETTER MU",NULL},
/* 13BE */ { "CHEROKEE LETTER NA",NULL},
/* 13BF */ { "CHEROKEE LETTER HNA",NULL},
/* 13C0 */ { "CHEROKEE LETTER NAH",NULL},
/* 13C1 */ { "CHEROKEE LETTER NE",NULL},
/* 13C2 */ { "CHEROKEE LETTER NI",NULL},
/* 13C3 */ { "CHEROKEE LETTER NO",NULL},
/* 13C4 */ { "CHEROKEE LETTER NU",NULL},
/* 13C5 */ { "CHEROKEE LETTER NV",NULL},
/* 13C6 */ { "CHEROKEE LETTER QUA",NULL},
/* 13C7 */ { "CHEROKEE LETTER QUE",NULL},
/* 13C8 */ { "CHEROKEE LETTER QUI",NULL},
/* 13C9 */ { "CHEROKEE LETTER QUO",NULL},
/* 13CA */ { "CHEROKEE LETTER QUU",NULL},
/* 13CB */ { "CHEROKEE LETTER QUV",NULL},
/* 13CC */ { "CHEROKEE LETTER SA",NULL},
/* 13CD */ { "CHEROKEE LETTER S",NULL},
/* 13CE */ { "CHEROKEE LETTER SE",NULL},
/* 13CF */ { "CHEROKEE LETTER SI",NULL},
/* 13D0 */ { "CHEROKEE LETTER SO",NULL},
/* 13D1 */ { "CHEROKEE LETTER SU",NULL},
/* 13D2 */ { "CHEROKEE LETTER SV",NULL},
/* 13D3 */ { "CHEROKEE LETTER DA",NULL},
/* 13D4 */ { "CHEROKEE LETTER TA",NULL},
/* 13D5 */ { "CHEROKEE LETTER DE",NULL},
/* 13D6 */ { "CHEROKEE LETTER TE",NULL},
/* 13D7 */ { "CHEROKEE LETTER DI",NULL},
/* 13D8 */ { "CHEROKEE LETTER TI",NULL},
/* 13D9 */ { "CHEROKEE LETTER DO",NULL},
/* 13DA */ { "CHEROKEE LETTER DU",NULL},
/* 13DB */ { "CHEROKEE LETTER DV",NULL},
/* 13DC */ { "CHEROKEE LETTER DLA",NULL},
/* 13DD */ { "CHEROKEE LETTER TLA",NULL},
/* 13DE */ { "CHEROKEE LETTER TLE",NULL},
/* 13DF */ { "CHEROKEE LETTER TLI",NULL},
/* 13E0 */ { "CHEROKEE LETTER TLO",NULL},
/* 13E1 */ { "CHEROKEE LETTER TLU",NULL},
/* 13E2 */ { "CHEROKEE LETTER TLV",NULL},
/* 13E3 */ { "CHEROKEE LETTER TSA",NULL},
/* 13E4 */ { "CHEROKEE LETTER TSE",NULL},
/* 13E5 */ { "CHEROKEE LETTER TSI",NULL},
/* 13E6 */ { "CHEROKEE LETTER TSO",NULL},
/* 13E7 */ { "CHEROKEE LETTER TSU",NULL},
/* 13E8 */ { "CHEROKEE LETTER TSV",NULL},
/* 13E9 */ { "CHEROKEE LETTER WA",NULL},
/* 13EA */ { "CHEROKEE LETTER WE",NULL},
/* 13EB */ { "CHEROKEE LETTER WI",NULL},
/* 13EC */ { "CHEROKEE LETTER WO",NULL},
/* 13ED */ { "CHEROKEE LETTER WU",NULL},
/* 13EE */ { "CHEROKEE LETTER WV",NULL},
/* 13EF */ { "CHEROKEE LETTER YA",NULL},
/* 13F0 */ { "CHEROKEE LETTER YE",NULL},
/* 13F1 */ { "CHEROKEE LETTER YI",NULL},
/* 13F2 */ { "CHEROKEE LETTER YO",NULL},
/* 13F3 */ { "CHEROKEE LETTER YU",NULL},
/* 13F4 */ { "CHEROKEE LETTER YV",NULL},
/* 13F5 */ { "CHEROKEE LETTER MV",NULL},
/* 13F6 */ { NULL,NULL},
/* 13F7 */ { NULL,NULL},
/* 13F8 */ { "CHEROKEE SMALL LETTER YE",NULL},
/* 13F9 */ { "CHEROKEE SMALL LETTER YI",NULL},
/* 13FA */ { "CHEROKEE SMALL LETTER YO",NULL},
/* 13FB */ { "CHEROKEE SMALL LETTER YU",NULL},
/* 13FC */ { "CHEROKEE SMALL LETTER YV",NULL},
/* 13FD */ { "CHEROKEE SMALL LETTER MV",NULL},
/* 13FE */ { NULL,NULL},
/* 13FF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_00_14[] = {
/* 1400 */ { "CANADIAN SYLLABICS HYPHEN",NULL},
/* 1401 */ { "CANADIAN SYLLABICS E","	* Inuktitut (AI), Carrier (U)"},
/* 1402 */ { "CANADIAN SYLLABICS AAI","	* Inuktitut"},
/* 1403 */ { "CANADIAN SYLLABICS I","	* Carrier (O)"},
/* 1404 */ { "CANADIAN SYLLABICS II",NULL},
/* 1405 */ { "CANADIAN SYLLABICS O","	* Inuktitut (U), Carrier (E)"},
/* 1406 */ { "CANADIAN SYLLABICS OO","	* Inuktitut (UU)"},
/* 1407 */ { "CANADIAN SYLLABICS Y-CREE OO",NULL},
/* 1408 */ { "CANADIAN SYLLABICS CARRIER EE",NULL},
/* 1409 */ { "CANADIAN SYLLABICS CARRIER I",NULL},
/* 140A */ { "CANADIAN SYLLABICS A",NULL},
/* 140B */ { "CANADIAN SYLLABICS AA",NULL},
/* 140C */ { "CANADIAN SYLLABICS WE",NULL},
/* 140D */ { "CANADIAN SYLLABICS WEST-CREE WE",NULL},
/* 140E */ { "CANADIAN SYLLABICS WI",NULL},
/* 140F */ { "CANADIAN SYLLABICS WEST-CREE WI",NULL},
/* 1410 */ { "CANADIAN SYLLABICS WII",NULL},
/* 1411 */ { "CANADIAN SYLLABICS WEST-CREE WII",NULL},
/* 1412 */ { "CANADIAN SYLLABICS WO",NULL},
/* 1413 */ { "CANADIAN SYLLABICS WEST-CREE WO",NULL},
/* 1414 */ { "CANADIAN SYLLABICS WOO",NULL},
/* 1415 */ { "CANADIAN SYLLABICS WEST-CREE WOO",NULL},
/* 1416 */ { "CANADIAN SYLLABICS NASKAPI WOO",NULL},
/* 1417 */ { "CANADIAN SYLLABICS WA",NULL},
/* 1418 */ { "CANADIAN SYLLABICS WEST-CREE WA",NULL},
/* 1419 */ { "CANADIAN SYLLABICS WAA",NULL},
/* 141A */ { "CANADIAN SYLLABICS WEST-CREE WAA",NULL},
/* 141B */ { "CANADIAN SYLLABICS NASKAPI WAA",NULL},
/* 141C */ { "CANADIAN SYLLABICS AI","	* East Cree"},
/* 141D */ { "CANADIAN SYLLABICS Y-CREE W",NULL},
/* 141E */ { "CANADIAN SYLLABICS GLOTTAL STOP","	* Moose Cree (Y), Algonquian (GLOTTAL STOP)"},
/* 141F */ { "CANADIAN SYLLABICS FINAL ACUTE","	* West Cree (T), East Cree (Y), Inuktitut (GLOTTAL STOP)\n"
	"	* Athapascan (B/P), Sayisi (I), Carrier (G)"},
/* 1420 */ { "CANADIAN SYLLABICS FINAL GRAVE","	* West Cree (K), Athapascan (K), Carrier (KH)"},
/* 1421 */ { "CANADIAN SYLLABICS FINAL BOTTOM HALF RING","	* N Cree (SH), Sayisi (R), Carrier (NG)"},
/* 1422 */ { "CANADIAN SYLLABICS FINAL TOP HALF RING","	* Algonquian (S), Chipewyan (R), Sayisi (S)"},
/* 1423 */ { "CANADIAN SYLLABICS FINAL RIGHT HALF RING","	* West Cree (N), Athapascan (D/T), Sayisi (N), Carrier (N)"},
/* 1424 */ { "CANADIAN SYLLABICS FINAL RING","	* West Cree (W), Sayisi (O)"},
/* 1425 */ { "CANADIAN SYLLABICS FINAL DOUBLE ACUTE","	* Chipewyan (TT), South Slavey (GH)"},
/* 1426 */ { "CANADIAN SYLLABICS FINAL DOUBLE SHORT VERTICAL STROKES","	* Algonquian (H), Carrier (R)"},
/* 1427 */ { "CANADIAN SYLLABICS FINAL MIDDLE DOT","	* Moose Cree (W), Athapascan (Y), Sayisi (YU), Blackfoot (S)"},
/* 1428 */ { "CANADIAN SYLLABICS FINAL SHORT HORIZONTAL STROKE","	* West Cree (C), Sayisi (D)"},
/* 1429 */ { "CANADIAN SYLLABICS FINAL PLUS","	* Athapascan (N), Sayisi (AI)"},
/* 142A */ { "CANADIAN SYLLABICS FINAL DOWN TACK","	* N Cree (L), Carrier (D)\n"
	"	x (down tack - 22A4)"},
/* 142B */ { "CANADIAN SYLLABICS EN",NULL},
/* 142C */ { "CANADIAN SYLLABICS IN",NULL},
/* 142D */ { "CANADIAN SYLLABICS ON",NULL},
/* 142E */ { "CANADIAN SYLLABICS AN",NULL},
/* 142F */ { "CANADIAN SYLLABICS PE","	* Inuktitut (PAI), Athapascan (BE), Carrier (HU)"},
/* 1430 */ { "CANADIAN SYLLABICS PAAI","	* Inuktitut"},
/* 1431 */ { "CANADIAN SYLLABICS PI",NULL},
/* 1432 */ { "CANADIAN SYLLABICS PII",NULL},
/* 1433 */ { "CANADIAN SYLLABICS PO","	* Inuktitut (PU), Athapascan (BO), Carrier (HE)"},
/* 1434 */ { "CANADIAN SYLLABICS POO","	* Inuktitut (PUU)"},
/* 1435 */ { "CANADIAN SYLLABICS Y-CREE POO",NULL},
/* 1436 */ { "CANADIAN SYLLABICS CARRIER HEE",NULL},
/* 1437 */ { "CANADIAN SYLLABICS CARRIER HI",NULL},
/* 1438 */ { "CANADIAN SYLLABICS PA","	* Athapascan (BA), Carrier (HA)"},
/* 1439 */ { "CANADIAN SYLLABICS PAA",NULL},
/* 143A */ { "CANADIAN SYLLABICS PWE",NULL},
/* 143B */ { "CANADIAN SYLLABICS WEST-CREE PWE",NULL},
/* 143C */ { "CANADIAN SYLLABICS PWI",NULL},
/* 143D */ { "CANADIAN SYLLABICS WEST-CREE PWI",NULL},
/* 143E */ { "CANADIAN SYLLABICS PWII",NULL},
/* 143F */ { "CANADIAN SYLLABICS WEST-CREE PWII",NULL},
/* 1440 */ { "CANADIAN SYLLABICS PWO",NULL},
/* 1441 */ { "CANADIAN SYLLABICS WEST-CREE PWO",NULL},
/* 1442 */ { "CANADIAN SYLLABICS PWOO",NULL},
/* 1443 */ { "CANADIAN SYLLABICS WEST-CREE PWOO",NULL},
/* 1444 */ { "CANADIAN SYLLABICS PWA",NULL},
/* 1445 */ { "CANADIAN SYLLABICS WEST-CREE PWA",NULL},
/* 1446 */ { "CANADIAN SYLLABICS PWAA",NULL},
/* 1447 */ { "CANADIAN SYLLABICS WEST-CREE PWAA",NULL},
/* 1448 */ { "CANADIAN SYLLABICS Y-CREE PWAA",NULL},
/* 1449 */ { "CANADIAN SYLLABICS P","	* Blackfoot (Y)"},
/* 144A */ { "CANADIAN SYLLABICS WEST-CREE P","	* Sayisi (G)"},
/* 144B */ { "CANADIAN SYLLABICS CARRIER H",NULL},
/* 144C */ { "CANADIAN SYLLABICS TE","	* Inuktitut (TAI), Athapascan (DI), Carrier (DU)"},
/* 144D */ { "CANADIAN SYLLABICS TAAI","	* Inuktitut"},
/* 144E */ { "CANADIAN SYLLABICS TI","	* Athapascan (DE), Carrier (DO)"},
/* 144F */ { "CANADIAN SYLLABICS TII",NULL},
/* 1450 */ { "CANADIAN SYLLABICS TO","	* Inuktitut (TU), Athapascan (DO), Carrier (DE), Sayisi (DU)"},
/* 1451 */ { "CANADIAN SYLLABICS TOO","	* Inuktitut (TUU)"},
/* 1452 */ { "CANADIAN SYLLABICS Y-CREE TOO",NULL},
/* 1453 */ { "CANADIAN SYLLABICS CARRIER DEE",NULL},
/* 1454 */ { "CANADIAN SYLLABICS CARRIER DI",NULL},
/* 1455 */ { "CANADIAN SYLLABICS TA","	* Athapascan (DA)"},
/* 1456 */ { "CANADIAN SYLLABICS TAA",NULL},
/* 1457 */ { "CANADIAN SYLLABICS TWE",NULL},
/* 1458 */ { "CANADIAN SYLLABICS WEST-CREE TWE",NULL},
/* 1459 */ { "CANADIAN SYLLABICS TWI",NULL},
/* 145A */ { "CANADIAN SYLLABICS WEST-CREE TWI",NULL},
/* 145B */ { "CANADIAN SYLLABICS TWII",NULL},
/* 145C */ { "CANADIAN SYLLABICS WEST-CREE TWII",NULL},
/* 145D */ { "CANADIAN SYLLABICS TWO",NULL},
/* 145E */ { "CANADIAN SYLLABICS WEST-CREE TWO",NULL},
/* 145F */ { "CANADIAN SYLLABICS TWOO",NULL},
/* 1460 */ { "CANADIAN SYLLABICS WEST-CREE TWOO",NULL},
/* 1461 */ { "CANADIAN SYLLABICS TWA",NULL},
/* 1462 */ { "CANADIAN SYLLABICS WEST-CREE TWA",NULL},
/* 1463 */ { "CANADIAN SYLLABICS TWAA",NULL},
/* 1464 */ { "CANADIAN SYLLABICS WEST-CREE TWAA",NULL},
/* 1465 */ { "CANADIAN SYLLABICS NASKAPI TWAA",NULL},
/* 1466 */ { "CANADIAN SYLLABICS T",NULL},
/* 1467 */ { "CANADIAN SYLLABICS TTE","	* South Slavey (DEH)"},
/* 1468 */ { "CANADIAN SYLLABICS TTI","	* South Slavey (DIH)"},
/* 1469 */ { "CANADIAN SYLLABICS TTO","	* South Slavey (DOH)"},
/* 146A */ { "CANADIAN SYLLABICS TTA","	* South Slavey (DAH)"},
/* 146B */ { "CANADIAN SYLLABICS KE","	* Inuktitut (KAI), Blackfoot (PA)"},
/* 146C */ { "CANADIAN SYLLABICS KAAI","	* Inuktitut"},
/* 146D */ { "CANADIAN SYLLABICS KI","	* Blackfoot (PE)"},
/* 146E */ { "CANADIAN SYLLABICS KII",NULL},
/* 146F */ { "CANADIAN SYLLABICS KO","	* Inuktitut (KU), Sayisi (KU), Blackfoot (PI)"},
/* 1470 */ { "CANADIAN SYLLABICS KOO","	* Inuktitut (KUU)"},
/* 1471 */ { "CANADIAN SYLLABICS Y-CREE KOO",NULL},
/* 1472 */ { "CANADIAN SYLLABICS KA","	* Blackfoot (PO)"},
/* 1473 */ { "CANADIAN SYLLABICS KAA",NULL},
/* 1474 */ { "CANADIAN SYLLABICS KWE",NULL},
/* 1475 */ { "CANADIAN SYLLABICS WEST-CREE KWE",NULL},
/* 1476 */ { "CANADIAN SYLLABICS KWI",NULL},
/* 1477 */ { "CANADIAN SYLLABICS WEST-CREE KWI",NULL},
/* 1478 */ { "CANADIAN SYLLABICS KWII",NULL},
/* 1479 */ { "CANADIAN SYLLABICS WEST-CREE KWII",NULL},
/* 147A */ { "CANADIAN SYLLABICS KWO",NULL},
/* 147B */ { "CANADIAN SYLLABICS WEST-CREE KWO",NULL},
/* 147C */ { "CANADIAN SYLLABICS KWOO",NULL},
/* 147D */ { "CANADIAN SYLLABICS WEST-CREE KWOO",NULL},
/* 147E */ { "CANADIAN SYLLABICS KWA",NULL},
/* 147F */ { "CANADIAN SYLLABICS WEST-CREE KWA",NULL},
/* 1480 */ { "CANADIAN SYLLABICS KWAA",NULL},
/* 1481 */ { "CANADIAN SYLLABICS WEST-CREE KWAA",NULL},
/* 1482 */ { "CANADIAN SYLLABICS NASKAPI KWAA",NULL},
/* 1483 */ { "CANADIAN SYLLABICS K",NULL},
/* 1484 */ { "CANADIAN SYLLABICS KW","	* East Cree"},
/* 1485 */ { "CANADIAN SYLLABICS SOUTH-SLAVEY KEH",NULL},
/* 1486 */ { "CANADIAN SYLLABICS SOUTH-SLAVEY KIH",NULL},
/* 1487 */ { "CANADIAN SYLLABICS SOUTH-SLAVEY KOH",NULL},
/* 1488 */ { "CANADIAN SYLLABICS SOUTH-SLAVEY KAH",NULL},
/* 1489 */ { "CANADIAN SYLLABICS CE","	* Inuktitut (GAI), Athapascan (DHE), Sayisi (THE), Blackfoot (MA)"},
/* 148A */ { "CANADIAN SYLLABICS CAAI","	* Inuktitut (GAAI)"},
/* 148B */ { "CANADIAN SYLLABICS CI","	* Inuktitut (GI), Athapascan (DHI), Sayisi (THI), Blackfoot (ME)"},
/* 148C */ { "CANADIAN SYLLABICS CII","	* Inuktitut (GII)"},
/* 148D */ { "CANADIAN SYLLABICS CO","	* Inuktitut (GU), Athapascan (DHO), Sayisi (THO), Blackfoot (MI)"},
/* 148E */ { "CANADIAN SYLLABICS COO","	* Inuktitut (GUU)"},
/* 148F */ { "CANADIAN SYLLABICS Y-CREE COO",NULL},
/* 1490 */ { "CANADIAN SYLLABICS CA","	* Inuktitut (GA), Athapascan (DHA), Sayisi (THA), Blackfoot (MO)"},
/* 1491 */ { "CANADIAN SYLLABICS CAA","	* Inuktitut (GAA)"},
/* 1492 */ { "CANADIAN SYLLABICS CWE",NULL},
/* 1493 */ { "CANADIAN SYLLABICS WEST-CREE CWE",NULL},
/* 1494 */ { "CANADIAN SYLLABICS CWI",NULL},
/* 1495 */ { "CANADIAN SYLLABICS WEST-CREE CWI",NULL},
/* 1496 */ { "CANADIAN SYLLABICS CWII",NULL},
/* 1497 */ { "CANADIAN SYLLABICS WEST-CREE CWII",NULL},
/* 1498 */ { "CANADIAN SYLLABICS CWO",NULL},
/* 1499 */ { "CANADIAN SYLLABICS WEST-CREE CWO",NULL},
/* 149A */ { "CANADIAN SYLLABICS CWOO",NULL},
/* 149B */ { "CANADIAN SYLLABICS WEST-CREE CWOO",NULL},
/* 149C */ { "CANADIAN SYLLABICS CWA",NULL},
/* 149D */ { "CANADIAN SYLLABICS WEST-CREE CWA",NULL},
/* 149E */ { "CANADIAN SYLLABICS CWAA",NULL},
/* 149F */ { "CANADIAN SYLLABICS WEST-CREE CWAA",NULL},
/* 14A0 */ { "CANADIAN SYLLABICS NASKAPI CWAA",NULL},
/* 14A1 */ { "CANADIAN SYLLABICS C","	* Inuktitut (G), Sayisi (T)"},
/* 14A2 */ { "CANADIAN SYLLABICS SAYISI TH","	* Athapascan (DH)"},
/* 14A3 */ { "CANADIAN SYLLABICS ME","	* Inuktitut (MAI), Blackfoot (TA)"},
/* 14A4 */ { "CANADIAN SYLLABICS MAAI","	* Inuktitut"},
/* 14A5 */ { "CANADIAN SYLLABICS MI","	* Blackfoot (TE)"},
/* 14A6 */ { "CANADIAN SYLLABICS MII",NULL},
/* 14A7 */ { "CANADIAN SYLLABICS MO","	* Inuktitut (MU), Sayisi (MU), Blackfoot (TI)"},
/* 14A8 */ { "CANADIAN SYLLABICS MOO","	* Inuktitut (MUU)"},
/* 14A9 */ { "CANADIAN SYLLABICS Y-CREE MOO",NULL},
/* 14AA */ { "CANADIAN SYLLABICS MA","	* Blackfoot (TO)"},
/* 14AB */ { "CANADIAN SYLLABICS MAA",NULL},
/* 14AC */ { "CANADIAN SYLLABICS MWE",NULL},
/* 14AD */ { "CANADIAN SYLLABICS WEST-CREE MWE",NULL},
/* 14AE */ { "CANADIAN SYLLABICS MWI",NULL},
/* 14AF */ { "CANADIAN SYLLABICS WEST-CREE MWI",NULL},
/* 14B0 */ { "CANADIAN SYLLABICS MWII",NULL},
/* 14B1 */ { "CANADIAN SYLLABICS WEST-CREE MWII",NULL},
/* 14B2 */ { "CANADIAN SYLLABICS MWO",NULL},
/* 14B3 */ { "CANADIAN SYLLABICS WEST-CREE MWO",NULL},
/* 14B4 */ { "CANADIAN SYLLABICS MWOO",NULL},
/* 14B5 */ { "CANADIAN SYLLABICS WEST-CREE MWOO",NULL},
/* 14B6 */ { "CANADIAN SYLLABICS MWA",NULL},
/* 14B7 */ { "CANADIAN SYLLABICS WEST-CREE MWA",NULL},
/* 14B8 */ { "CANADIAN SYLLABICS MWAA",NULL},
/* 14B9 */ { "CANADIAN SYLLABICS WEST-CREE MWAA",NULL},
/* 14BA */ { "CANADIAN SYLLABICS NASKAPI MWAA",NULL},
/* 14BB */ { "CANADIAN SYLLABICS M",NULL},
/* 14BC */ { "CANADIAN SYLLABICS WEST-CREE M","	* Carrier (M)"},
/* 14BD */ { "CANADIAN SYLLABICS MH",NULL},
/* 14BE */ { "CANADIAN SYLLABICS ATHAPASCAN M",NULL},
/* 14BF */ { "CANADIAN SYLLABICS SAYISI M",NULL},
/* 14C0 */ { "CANADIAN SYLLABICS NE","	* Inuktitut (NAI)"},
/* 14C1 */ { "CANADIAN SYLLABICS NAAI","	* Inuktitut"},
/* 14C2 */ { "CANADIAN SYLLABICS NI",NULL},
/* 14C3 */ { "CANADIAN SYLLABICS NII",NULL},
/* 14C4 */ { "CANADIAN SYLLABICS NO","	* Inuktitut (NU), Sayisi (NU)"},
/* 14C5 */ { "CANADIAN SYLLABICS NOO","	* Inuktitut (NUU)"},
/* 14C6 */ { "CANADIAN SYLLABICS Y-CREE NOO",NULL},
/* 14C7 */ { "CANADIAN SYLLABICS NA",NULL},
/* 14C8 */ { "CANADIAN SYLLABICS NAA",NULL},
/* 14C9 */ { "CANADIAN SYLLABICS NWE",NULL},
/* 14CA */ { "CANADIAN SYLLABICS WEST-CREE NWE",NULL},
/* 14CB */ { "CANADIAN SYLLABICS NWA",NULL},
/* 14CC */ { "CANADIAN SYLLABICS WEST-CREE NWA",NULL},
/* 14CD */ { "CANADIAN SYLLABICS NWAA",NULL},
/* 14CE */ { "CANADIAN SYLLABICS WEST-CREE NWAA",NULL},
/* 14CF */ { "CANADIAN SYLLABICS NASKAPI NWAA",NULL},
/* 14D0 */ { "CANADIAN SYLLABICS N",NULL},
/* 14D1 */ { "CANADIAN SYLLABICS CARRIER NG",NULL},
/* 14D2 */ { "CANADIAN SYLLABICS NH",NULL},
/* 14D3 */ { "CANADIAN SYLLABICS LE","	* Inuktitut (LAI)"},
/* 14D4 */ { "CANADIAN SYLLABICS LAAI","	* Inuktitut"},
/* 14D5 */ { "CANADIAN SYLLABICS LI",NULL},
/* 14D6 */ { "CANADIAN SYLLABICS LII",NULL},
/* 14D7 */ { "CANADIAN SYLLABICS LO","	* Inuktitut (LU)"},
/* 14D8 */ { "CANADIAN SYLLABICS LOO","	* Inuktitut (LUU)"},
/* 14D9 */ { "CANADIAN SYLLABICS Y-CREE LOO",NULL},
/* 14DA */ { "CANADIAN SYLLABICS LA",NULL},
/* 14DB */ { "CANADIAN SYLLABICS LAA",NULL},
/* 14DC */ { "CANADIAN SYLLABICS LWE",NULL},
/* 14DD */ { "CANADIAN SYLLABICS WEST-CREE LWE",NULL},
/* 14DE */ { "CANADIAN SYLLABICS LWI",NULL},
/* 14DF */ { "CANADIAN SYLLABICS WEST-CREE LWI",NULL},
/* 14E0 */ { "CANADIAN SYLLABICS LWII",NULL},
/* 14E1 */ { "CANADIAN SYLLABICS WEST-CREE LWII",NULL},
/* 14E2 */ { "CANADIAN SYLLABICS LWO",NULL},
/* 14E3 */ { "CANADIAN SYLLABICS WEST-CREE LWO",NULL},
/* 14E4 */ { "CANADIAN SYLLABICS LWOO",NULL},
/* 14E5 */ { "CANADIAN SYLLABICS WEST-CREE LWOO",NULL},
/* 14E6 */ { "CANADIAN SYLLABICS LWA",NULL},
/* 14E7 */ { "CANADIAN SYLLABICS WEST-CREE LWA",NULL},
/* 14E8 */ { "CANADIAN SYLLABICS LWAA",NULL},
/* 14E9 */ { "CANADIAN SYLLABICS WEST-CREE LWAA",NULL},
/* 14EA */ { "CANADIAN SYLLABICS L",NULL},
/* 14EB */ { "CANADIAN SYLLABICS WEST-CREE L",NULL},
/* 14EC */ { "CANADIAN SYLLABICS MEDIAL L",NULL},
/* 14ED */ { "CANADIAN SYLLABICS SE","	* Inuktitut (SAI), Blackfoot (SA)"},
/* 14EE */ { "CANADIAN SYLLABICS SAAI","	* Inuktitut"},
/* 14EF */ { "CANADIAN SYLLABICS SI","	* Blackfoot (SE)"},
/* 14F0 */ { "CANADIAN SYLLABICS SII",NULL},
/* 14F1 */ { "CANADIAN SYLLABICS SO","	* Inuktitut (SU), Sayisi (SU), Blackfoot (SI)"},
/* 14F2 */ { "CANADIAN SYLLABICS SOO","	* Inuktitut (SUU)"},
/* 14F3 */ { "CANADIAN SYLLABICS Y-CREE SOO",NULL},
/* 14F4 */ { "CANADIAN SYLLABICS SA","	* Blackfoot (SO)"},
/* 14F5 */ { "CANADIAN SYLLABICS SAA",NULL},
/* 14F6 */ { "CANADIAN SYLLABICS SWE",NULL},
/* 14F7 */ { "CANADIAN SYLLABICS WEST-CREE SWE",NULL},
/* 14F8 */ { "CANADIAN SYLLABICS SWI",NULL},
/* 14F9 */ { "CANADIAN SYLLABICS WEST-CREE SWI",NULL},
/* 14FA */ { "CANADIAN SYLLABICS SWII",NULL},
/* 14FB */ { "CANADIAN SYLLABICS WEST-CREE SWII",NULL},
/* 14FC */ { "CANADIAN SYLLABICS SWO",NULL},
/* 14FD */ { "CANADIAN SYLLABICS WEST-CREE SWO",NULL},
/* 14FE */ { "CANADIAN SYLLABICS SWOO",NULL},
/* 14FF */ { "CANADIAN SYLLABICS WEST-CREE SWOO",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_00_15[] = {
/* 1500 */ { "CANADIAN SYLLABICS SWA",NULL},
/* 1501 */ { "CANADIAN SYLLABICS WEST-CREE SWA",NULL},
/* 1502 */ { "CANADIAN SYLLABICS SWAA",NULL},
/* 1503 */ { "CANADIAN SYLLABICS WEST-CREE SWAA",NULL},
/* 1504 */ { "CANADIAN SYLLABICS NASKAPI SWAA",NULL},
/* 1505 */ { "CANADIAN SYLLABICS S",NULL},
/* 1506 */ { "CANADIAN SYLLABICS ATHAPASCAN S",NULL},
/* 1507 */ { "CANADIAN SYLLABICS SW",NULL},
/* 1508 */ { "CANADIAN SYLLABICS BLACKFOOT S",NULL},
/* 1509 */ { "CANADIAN SYLLABICS MOOSE-CREE SK",NULL},
/* 150A */ { "CANADIAN SYLLABICS NASKAPI SKW",NULL},
/* 150B */ { "CANADIAN SYLLABICS NASKAPI S-W",NULL},
/* 150C */ { "CANADIAN SYLLABICS NASKAPI SPWA",NULL},
/* 150D */ { "CANADIAN SYLLABICS NASKAPI STWA",NULL},
/* 150E */ { "CANADIAN SYLLABICS NASKAPI SKWA",NULL},
/* 150F */ { "CANADIAN SYLLABICS NASKAPI SCWA",NULL},
/* 1510 */ { "CANADIAN SYLLABICS SHE",NULL},
/* 1511 */ { "CANADIAN SYLLABICS SHI",NULL},
/* 1512 */ { "CANADIAN SYLLABICS SHII",NULL},
/* 1513 */ { "CANADIAN SYLLABICS SHO",NULL},
/* 1514 */ { "CANADIAN SYLLABICS SHOO",NULL},
/* 1515 */ { "CANADIAN SYLLABICS SHA",NULL},
/* 1516 */ { "CANADIAN SYLLABICS SHAA",NULL},
/* 1517 */ { "CANADIAN SYLLABICS SHWE",NULL},
/* 1518 */ { "CANADIAN SYLLABICS WEST-CREE SHWE",NULL},
/* 1519 */ { "CANADIAN SYLLABICS SHWI",NULL},
/* 151A */ { "CANADIAN SYLLABICS WEST-CREE SHWI",NULL},
/* 151B */ { "CANADIAN SYLLABICS SHWII",NULL},
/* 151C */ { "CANADIAN SYLLABICS WEST-CREE SHWII",NULL},
/* 151D */ { "CANADIAN SYLLABICS SHWO",NULL},
/* 151E */ { "CANADIAN SYLLABICS WEST-CREE SHWO",NULL},
/* 151F */ { "CANADIAN SYLLABICS SHWOO",NULL},
/* 1520 */ { "CANADIAN SYLLABICS WEST-CREE SHWOO",NULL},
/* 1521 */ { "CANADIAN SYLLABICS SHWA",NULL},
/* 1522 */ { "CANADIAN SYLLABICS WEST-CREE SHWA",NULL},
/* 1523 */ { "CANADIAN SYLLABICS SHWAA",NULL},
/* 1524 */ { "CANADIAN SYLLABICS WEST-CREE SHWAA",NULL},
/* 1525 */ { "CANADIAN SYLLABICS SH",NULL},
/* 1526 */ { "CANADIAN SYLLABICS YE","	* Inuktitut (YAI), Blackfoot (YA)"},
/* 1527 */ { "CANADIAN SYLLABICS YAAI","	* Inuktitut"},
/* 1528 */ { "CANADIAN SYLLABICS YI","	* Blackfoot (YE)"},
/* 1529 */ { "CANADIAN SYLLABICS YII",NULL},
/* 152A */ { "CANADIAN SYLLABICS YO","	* Inuktitut (YU), Blackfoot (YI)"},
/* 152B */ { "CANADIAN SYLLABICS YOO","	* Inuktitut (YUU)"},
/* 152C */ { "CANADIAN SYLLABICS Y-CREE YOO",NULL},
/* 152D */ { "CANADIAN SYLLABICS YA","	* Blackfoot (YO)"},
/* 152E */ { "CANADIAN SYLLABICS YAA",NULL},
/* 152F */ { "CANADIAN SYLLABICS YWE",NULL},
/* 1530 */ { "CANADIAN SYLLABICS WEST-CREE YWE",NULL},
/* 1531 */ { "CANADIAN SYLLABICS YWI",NULL},
/* 1532 */ { "CANADIAN SYLLABICS WEST-CREE YWI",NULL},
/* 1533 */ { "CANADIAN SYLLABICS YWII",NULL},
/* 1534 */ { "CANADIAN SYLLABICS WEST-CREE YWII",NULL},
/* 1535 */ { "CANADIAN SYLLABICS YWO",NULL},
/* 1536 */ { "CANADIAN SYLLABICS WEST-CREE YWO",NULL},
/* 1537 */ { "CANADIAN SYLLABICS YWOO",NULL},
/* 1538 */ { "CANADIAN SYLLABICS WEST-CREE YWOO",NULL},
/* 1539 */ { "CANADIAN SYLLABICS YWA",NULL},
/* 153A */ { "CANADIAN SYLLABICS WEST-CREE YWA",NULL},
/* 153B */ { "CANADIAN SYLLABICS YWAA",NULL},
/* 153C */ { "CANADIAN SYLLABICS WEST-CREE YWAA",NULL},
/* 153D */ { "CANADIAN SYLLABICS NASKAPI YWAA",NULL},
/* 153E */ { "CANADIAN SYLLABICS Y",NULL},
/* 153F */ { "CANADIAN SYLLABICS BIBLE-CREE Y",NULL},
/* 1540 */ { "CANADIAN SYLLABICS WEST-CREE Y",NULL},
/* 1541 */ { "CANADIAN SYLLABICS SAYISI YI",NULL},
/* 1542 */ { "CANADIAN SYLLABICS RE","	* Inuktitut (RAI)"},
/* 1543 */ { "CANADIAN SYLLABICS R-CREE RE","	* Athapascan (LE)"},
/* 1544 */ { "CANADIAN SYLLABICS WEST-CREE LE","	* Athapascan (LI)"},
/* 1545 */ { "CANADIAN SYLLABICS RAAI","	* Inuktitut"},
/* 1546 */ { "CANADIAN SYLLABICS RI",NULL},
/* 1547 */ { "CANADIAN SYLLABICS RII",NULL},
/* 1548 */ { "CANADIAN SYLLABICS RO","	* Inuktitut (RU)"},
/* 1549 */ { "CANADIAN SYLLABICS ROO","	* Inuktitut (RUU)"},
/* 154A */ { "CANADIAN SYLLABICS WEST-CREE LO","	* Sayisi (LU)"},
/* 154B */ { "CANADIAN SYLLABICS RA",NULL},
/* 154C */ { "CANADIAN SYLLABICS RAA",NULL},
/* 154D */ { "CANADIAN SYLLABICS WEST-CREE LA",NULL},
/* 154E */ { "CANADIAN SYLLABICS RWAA",NULL},
/* 154F */ { "CANADIAN SYLLABICS WEST-CREE RWAA",NULL},
/* 1550 */ { "CANADIAN SYLLABICS R",NULL},
/* 1551 */ { "CANADIAN SYLLABICS WEST-CREE R",NULL},
/* 1552 */ { "CANADIAN SYLLABICS MEDIAL R",NULL},
/* 1553 */ { "CANADIAN SYLLABICS FE","	* Inuktitut (FAI)"},
/* 1554 */ { "CANADIAN SYLLABICS FAAI","	* Inuktitut"},
/* 1555 */ { "CANADIAN SYLLABICS FI",NULL},
/* 1556 */ { "CANADIAN SYLLABICS FII",NULL},
/* 1557 */ { "CANADIAN SYLLABICS FO",NULL},
/* 1558 */ { "CANADIAN SYLLABICS FOO",NULL},
/* 1559 */ { "CANADIAN SYLLABICS FA",NULL},
/* 155A */ { "CANADIAN SYLLABICS FAA",NULL},
/* 155B */ { "CANADIAN SYLLABICS FWAA",NULL},
/* 155C */ { "CANADIAN SYLLABICS WEST-CREE FWAA",NULL},
/* 155D */ { "CANADIAN SYLLABICS F",NULL},
/* 155E */ { "CANADIAN SYLLABICS THE","	* Sayisi (TE)"},
/* 155F */ { "CANADIAN SYLLABICS N-CREE THE",NULL},
/* 1560 */ { "CANADIAN SYLLABICS THI","	* Sayisi (TI)"},
/* 1561 */ { "CANADIAN SYLLABICS N-CREE THI",NULL},
/* 1562 */ { "CANADIAN SYLLABICS THII",NULL},
/* 1563 */ { "CANADIAN SYLLABICS N-CREE THII",NULL},
/* 1564 */ { "CANADIAN SYLLABICS THO","	* Sayisi (TU)"},
/* 1565 */ { "CANADIAN SYLLABICS THOO",NULL},
/* 1566 */ { "CANADIAN SYLLABICS THA","	* Sayisi (TA)"},
/* 1567 */ { "CANADIAN SYLLABICS THAA",NULL},
/* 1568 */ { "CANADIAN SYLLABICS THWAA",NULL},
/* 1569 */ { "CANADIAN SYLLABICS WEST-CREE THWAA",NULL},
/* 156A */ { "CANADIAN SYLLABICS TH",NULL},
/* 156B */ { "CANADIAN SYLLABICS TTHE",NULL},
/* 156C */ { "CANADIAN SYLLABICS TTHI",NULL},
/* 156D */ { "CANADIAN SYLLABICS TTHO","	* Sayisi (TTHU)"},
/* 156E */ { "CANADIAN SYLLABICS TTHA",NULL},
/* 156F */ { "CANADIAN SYLLABICS TTH","	* probably a mistaken interpretation of an asterisk used to mark a proper noun\n"
	"	x (asterisk - 002A)"},
/* 1570 */ { "CANADIAN SYLLABICS TYE",NULL},
/* 1571 */ { "CANADIAN SYLLABICS TYI",NULL},
/* 1572 */ { "CANADIAN SYLLABICS TYO",NULL},
/* 1573 */ { "CANADIAN SYLLABICS TYA",NULL},
/* 1574 */ { "CANADIAN SYLLABICS NUNAVIK HE",NULL},
/* 1575 */ { "CANADIAN SYLLABICS NUNAVIK HI",NULL},
/* 1576 */ { "CANADIAN SYLLABICS NUNAVIK HII",NULL},
/* 1577 */ { "CANADIAN SYLLABICS NUNAVIK HO",NULL},
/* 1578 */ { "CANADIAN SYLLABICS NUNAVIK HOO",NULL},
/* 1579 */ { "CANADIAN SYLLABICS NUNAVIK HA",NULL},
/* 157A */ { "CANADIAN SYLLABICS NUNAVIK HAA",NULL},
/* 157B */ { "CANADIAN SYLLABICS NUNAVIK H",NULL},
/* 157C */ { "CANADIAN SYLLABICS NUNAVUT H",NULL},
/* 157D */ { "CANADIAN SYLLABICS HK","	* Algonquian"},
/* 157E */ { "CANADIAN SYLLABICS QAAI","	* Inuktitut"},
/* 157F */ { "CANADIAN SYLLABICS QI",NULL},
/* 1580 */ { "CANADIAN SYLLABICS QII",NULL},
/* 1581 */ { "CANADIAN SYLLABICS QO","	* Inuktitut (QU)"},
/* 1582 */ { "CANADIAN SYLLABICS QOO","	* Inuktitut (QUU)"},
/* 1583 */ { "CANADIAN SYLLABICS QA",NULL},
/* 1584 */ { "CANADIAN SYLLABICS QAA",NULL},
/* 1585 */ { "CANADIAN SYLLABICS Q",NULL},
/* 1586 */ { "CANADIAN SYLLABICS TLHE","	* Sayisi (KLE)"},
/* 1587 */ { "CANADIAN SYLLABICS TLHI","	* Sayisi (KLI)"},
/* 1588 */ { "CANADIAN SYLLABICS TLHO","	* Sayisi (KLU)"},
/* 1589 */ { "CANADIAN SYLLABICS TLHA","	* Sayisi (KLA)"},
/* 158A */ { "CANADIAN SYLLABICS WEST-CREE RE",NULL},
/* 158B */ { "CANADIAN SYLLABICS WEST-CREE RI",NULL},
/* 158C */ { "CANADIAN SYLLABICS WEST-CREE RO",NULL},
/* 158D */ { "CANADIAN SYLLABICS WEST-CREE RA",NULL},
/* 158E */ { "CANADIAN SYLLABICS NGAAI","	* Inuktitut"},
/* 158F */ { "CANADIAN SYLLABICS NGI",NULL},
/* 1590 */ { "CANADIAN SYLLABICS NGII",NULL},
/* 1591 */ { "CANADIAN SYLLABICS NGO","	* Inuktitut (NGU)"},
/* 1592 */ { "CANADIAN SYLLABICS NGOO","	* Inuktitut (NGUU)"},
/* 1593 */ { "CANADIAN SYLLABICS NGA",NULL},
/* 1594 */ { "CANADIAN SYLLABICS NGAA",NULL},
/* 1595 */ { "CANADIAN SYLLABICS NG",NULL},
/* 1596 */ { "CANADIAN SYLLABICS NNG",NULL},
/* 1597 */ { "CANADIAN SYLLABICS SAYISI SHE",NULL},
/* 1598 */ { "CANADIAN SYLLABICS SAYISI SHI",NULL},
/* 1599 */ { "CANADIAN SYLLABICS SAYISI SHO","	* Sayisi (SHU)"},
/* 159A */ { "CANADIAN SYLLABICS SAYISI SHA",NULL},
/* 159B */ { "CANADIAN SYLLABICS WOODS-CREE THE",NULL},
/* 159C */ { "CANADIAN SYLLABICS WOODS-CREE THI",NULL},
/* 159D */ { "CANADIAN SYLLABICS WOODS-CREE THO",NULL},
/* 159E */ { "CANADIAN SYLLABICS WOODS-CREE THA",NULL},
/* 159F */ { "CANADIAN SYLLABICS WOODS-CREE TH",NULL},
/* 15A0 */ { "CANADIAN SYLLABICS LHI",NULL},
/* 15A1 */ { "CANADIAN SYLLABICS LHII",NULL},
/* 15A2 */ { "CANADIAN SYLLABICS LHO","	* Inuktitut (LHU)"},
/* 15A3 */ { "CANADIAN SYLLABICS LHOO","	* Inuktitut (LHUU)"},
/* 15A4 */ { "CANADIAN SYLLABICS LHA",NULL},
/* 15A5 */ { "CANADIAN SYLLABICS LHAA",NULL},
/* 15A6 */ { "CANADIAN SYLLABICS LH",NULL},
/* 15A7 */ { "CANADIAN SYLLABICS TH-CREE THE",NULL},
/* 15A8 */ { "CANADIAN SYLLABICS TH-CREE THI",NULL},
/* 15A9 */ { "CANADIAN SYLLABICS TH-CREE THII",NULL},
/* 15AA */ { "CANADIAN SYLLABICS TH-CREE THO",NULL},
/* 15AB */ { "CANADIAN SYLLABICS TH-CREE THOO",NULL},
/* 15AC */ { "CANADIAN SYLLABICS TH-CREE THA",NULL},
/* 15AD */ { "CANADIAN SYLLABICS TH-CREE THAA",NULL},
/* 15AE */ { "CANADIAN SYLLABICS TH-CREE TH",NULL},
/* 15AF */ { "CANADIAN SYLLABICS AIVILIK B",NULL},
/* 15B0 */ { "CANADIAN SYLLABICS BLACKFOOT E",NULL},
/* 15B1 */ { "CANADIAN SYLLABICS BLACKFOOT I",NULL},
/* 15B2 */ { "CANADIAN SYLLABICS BLACKFOOT O",NULL},
/* 15B3 */ { "CANADIAN SYLLABICS BLACKFOOT A",NULL},
/* 15B4 */ { "CANADIAN SYLLABICS BLACKFOOT WE",NULL},
/* 15B5 */ { "CANADIAN SYLLABICS BLACKFOOT WI",NULL},
/* 15B6 */ { "CANADIAN SYLLABICS BLACKFOOT WO",NULL},
/* 15B7 */ { "CANADIAN SYLLABICS BLACKFOOT WA",NULL},
/* 15B8 */ { "CANADIAN SYLLABICS BLACKFOOT NE",NULL},
/* 15B9 */ { "CANADIAN SYLLABICS BLACKFOOT NI",NULL},
/* 15BA */ { "CANADIAN SYLLABICS BLACKFOOT NO",NULL},
/* 15BB */ { "CANADIAN SYLLABICS BLACKFOOT NA",NULL},
/* 15BC */ { "CANADIAN SYLLABICS BLACKFOOT KE",NULL},
/* 15BD */ { "CANADIAN SYLLABICS BLACKFOOT KI",NULL},
/* 15BE */ { "CANADIAN SYLLABICS BLACKFOOT KO",NULL},
/* 15BF */ { "CANADIAN SYLLABICS BLACKFOOT KA",NULL},
/* 15C0 */ { "CANADIAN SYLLABICS SAYISI HE",NULL},
/* 15C1 */ { "CANADIAN SYLLABICS SAYISI HI",NULL},
/* 15C2 */ { "CANADIAN SYLLABICS SAYISI HO","	* Sayisi (HU)"},
/* 15C3 */ { "CANADIAN SYLLABICS SAYISI HA",NULL},
/* 15C4 */ { "CANADIAN SYLLABICS CARRIER GHU",NULL},
/* 15C5 */ { "CANADIAN SYLLABICS CARRIER GHO",NULL},
/* 15C6 */ { "CANADIAN SYLLABICS CARRIER GHE",NULL},
/* 15C7 */ { "CANADIAN SYLLABICS CARRIER GHEE",NULL},
/* 15C8 */ { "CANADIAN SYLLABICS CARRIER GHI",NULL},
/* 15C9 */ { "CANADIAN SYLLABICS CARRIER GHA",NULL},
/* 15CA */ { "CANADIAN SYLLABICS CARRIER RU",NULL},
/* 15CB */ { "CANADIAN SYLLABICS CARRIER RO",NULL},
/* 15CC */ { "CANADIAN SYLLABICS CARRIER RE",NULL},
/* 15CD */ { "CANADIAN SYLLABICS CARRIER REE",NULL},
/* 15CE */ { "CANADIAN SYLLABICS CARRIER RI",NULL},
/* 15CF */ { "CANADIAN SYLLABICS CARRIER RA",NULL},
/* 15D0 */ { "CANADIAN SYLLABICS CARRIER WU",NULL},
/* 15D1 */ { "CANADIAN SYLLABICS CARRIER WO",NULL},
/* 15D2 */ { "CANADIAN SYLLABICS CARRIER WE",NULL},
/* 15D3 */ { "CANADIAN SYLLABICS CARRIER WEE",NULL},
/* 15D4 */ { "CANADIAN SYLLABICS CARRIER WI",NULL},
/* 15D5 */ { "CANADIAN SYLLABICS CARRIER WA",NULL},
/* 15D6 */ { "CANADIAN SYLLABICS CARRIER HWU",NULL},
/* 15D7 */ { "CANADIAN SYLLABICS CARRIER HWO",NULL},
/* 15D8 */ { "CANADIAN SYLLABICS CARRIER HWE",NULL},
/* 15D9 */ { "CANADIAN SYLLABICS CARRIER HWEE",NULL},
/* 15DA */ { "CANADIAN SYLLABICS CARRIER HWI",NULL},
/* 15DB */ { "CANADIAN SYLLABICS CARRIER HWA",NULL},
/* 15DC */ { "CANADIAN SYLLABICS CARRIER THU",NULL},
/* 15DD */ { "CANADIAN SYLLABICS CARRIER THO",NULL},
/* 15DE */ { "CANADIAN SYLLABICS CARRIER THE",NULL},
/* 15DF */ { "CANADIAN SYLLABICS CARRIER THEE",NULL},
/* 15E0 */ { "CANADIAN SYLLABICS CARRIER THI",NULL},
/* 15E1 */ { "CANADIAN SYLLABICS CARRIER THA",NULL},
/* 15E2 */ { "CANADIAN SYLLABICS CARRIER TTU",NULL},
/* 15E3 */ { "CANADIAN SYLLABICS CARRIER TTO",NULL},
/* 15E4 */ { "CANADIAN SYLLABICS CARRIER TTE",NULL},
/* 15E5 */ { "CANADIAN SYLLABICS CARRIER TTEE",NULL},
/* 15E6 */ { "CANADIAN SYLLABICS CARRIER TTI",NULL},
/* 15E7 */ { "CANADIAN SYLLABICS CARRIER TTA",NULL},
/* 15E8 */ { "CANADIAN SYLLABICS CARRIER PU",NULL},
/* 15E9 */ { "CANADIAN SYLLABICS CARRIER PO",NULL},
/* 15EA */ { "CANADIAN SYLLABICS CARRIER PE",NULL},
/* 15EB */ { "CANADIAN SYLLABICS CARRIER PEE",NULL},
/* 15EC */ { "CANADIAN SYLLABICS CARRIER PI",NULL},
/* 15ED */ { "CANADIAN SYLLABICS CARRIER PA",NULL},
/* 15EE */ { "CANADIAN SYLLABICS CARRIER P",NULL},
/* 15EF */ { "CANADIAN SYLLABICS CARRIER GU",NULL},
/* 15F0 */ { "CANADIAN SYLLABICS CARRIER GO",NULL},
/* 15F1 */ { "CANADIAN SYLLABICS CARRIER GE",NULL},
/* 15F2 */ { "CANADIAN SYLLABICS CARRIER GEE",NULL},
/* 15F3 */ { "CANADIAN SYLLABICS CARRIER GI",NULL},
/* 15F4 */ { "CANADIAN SYLLABICS CARRIER GA",NULL},
/* 15F5 */ { "CANADIAN SYLLABICS CARRIER KHU",NULL},
/* 15F6 */ { "CANADIAN SYLLABICS CARRIER KHO",NULL},
/* 15F7 */ { "CANADIAN SYLLABICS CARRIER KHE",NULL},
/* 15F8 */ { "CANADIAN SYLLABICS CARRIER KHEE",NULL},
/* 15F9 */ { "CANADIAN SYLLABICS CARRIER KHI",NULL},
/* 15FA */ { "CANADIAN SYLLABICS CARRIER KHA",NULL},
/* 15FB */ { "CANADIAN SYLLABICS CARRIER KKU",NULL},
/* 15FC */ { "CANADIAN SYLLABICS CARRIER KKO",NULL},
/* 15FD */ { "CANADIAN SYLLABICS CARRIER KKE",NULL},
/* 15FE */ { "CANADIAN SYLLABICS CARRIER KKEE",NULL},
/* 15FF */ { "CANADIAN SYLLABICS CARRIER KKI",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_00_16[] = {
/* 1600 */ { "CANADIAN SYLLABICS CARRIER KKA",NULL},
/* 1601 */ { "CANADIAN SYLLABICS CARRIER KK",NULL},
/* 1602 */ { "CANADIAN SYLLABICS CARRIER NU",NULL},
/* 1603 */ { "CANADIAN SYLLABICS CARRIER NO",NULL},
/* 1604 */ { "CANADIAN SYLLABICS CARRIER NE",NULL},
/* 1605 */ { "CANADIAN SYLLABICS CARRIER NEE",NULL},
/* 1606 */ { "CANADIAN SYLLABICS CARRIER NI",NULL},
/* 1607 */ { "CANADIAN SYLLABICS CARRIER NA",NULL},
/* 1608 */ { "CANADIAN SYLLABICS CARRIER MU",NULL},
/* 1609 */ { "CANADIAN SYLLABICS CARRIER MO",NULL},
/* 160A */ { "CANADIAN SYLLABICS CARRIER ME",NULL},
/* 160B */ { "CANADIAN SYLLABICS CARRIER MEE",NULL},
/* 160C */ { "CANADIAN SYLLABICS CARRIER MI",NULL},
/* 160D */ { "CANADIAN SYLLABICS CARRIER MA",NULL},
/* 160E */ { "CANADIAN SYLLABICS CARRIER YU",NULL},
/* 160F */ { "CANADIAN SYLLABICS CARRIER YO",NULL},
/* 1610 */ { "CANADIAN SYLLABICS CARRIER YE",NULL},
/* 1611 */ { "CANADIAN SYLLABICS CARRIER YEE",NULL},
/* 1612 */ { "CANADIAN SYLLABICS CARRIER YI",NULL},
/* 1613 */ { "CANADIAN SYLLABICS CARRIER YA",NULL},
/* 1614 */ { "CANADIAN SYLLABICS CARRIER JU","	* Athapascan (ZA), Sayisi (TZO), South Slavey (DHA)"},
/* 1615 */ { "CANADIAN SYLLABICS SAYISI JU","	* Athapascan (ZO), Sayisi (TZU), South Slavey (DHO)"},
/* 1616 */ { "CANADIAN SYLLABICS CARRIER JO",NULL},
/* 1617 */ { "CANADIAN SYLLABICS CARRIER JE",NULL},
/* 1618 */ { "CANADIAN SYLLABICS CARRIER JEE",NULL},
/* 1619 */ { "CANADIAN SYLLABICS CARRIER JI",NULL},
/* 161A */ { "CANADIAN SYLLABICS SAYISI JI","	* Athapascan (ZE), Sayisi (TZE), South Slavey (DHE)"},
/* 161B */ { "CANADIAN SYLLABICS CARRIER JA","	* Athapascan (ZI), Sayisi (TZI), South Slavey (DHI)"},
/* 161C */ { "CANADIAN SYLLABICS CARRIER JJU",NULL},
/* 161D */ { "CANADIAN SYLLABICS CARRIER JJO",NULL},
/* 161E */ { "CANADIAN SYLLABICS CARRIER JJE",NULL},
/* 161F */ { "CANADIAN SYLLABICS CARRIER JJEE",NULL},
/* 1620 */ { "CANADIAN SYLLABICS CARRIER JJI",NULL},
/* 1621 */ { "CANADIAN SYLLABICS CARRIER JJA",NULL},
/* 1622 */ { "CANADIAN SYLLABICS CARRIER LU",NULL},
/* 1623 */ { "CANADIAN SYLLABICS CARRIER LO",NULL},
/* 1624 */ { "CANADIAN SYLLABICS CARRIER LE",NULL},
/* 1625 */ { "CANADIAN SYLLABICS CARRIER LEE",NULL},
/* 1626 */ { "CANADIAN SYLLABICS CARRIER LI",NULL},
/* 1627 */ { "CANADIAN SYLLABICS CARRIER LA",NULL},
/* 1628 */ { "CANADIAN SYLLABICS CARRIER DLU",NULL},
/* 1629 */ { "CANADIAN SYLLABICS CARRIER DLO",NULL},
/* 162A */ { "CANADIAN SYLLABICS CARRIER DLE",NULL},
/* 162B */ { "CANADIAN SYLLABICS CARRIER DLEE",NULL},
/* 162C */ { "CANADIAN SYLLABICS CARRIER DLI",NULL},
/* 162D */ { "CANADIAN SYLLABICS CARRIER DLA",NULL},
/* 162E */ { "CANADIAN SYLLABICS CARRIER LHU",NULL},
/* 162F */ { "CANADIAN SYLLABICS CARRIER LHO",NULL},
/* 1630 */ { "CANADIAN SYLLABICS CARRIER LHE",NULL},
/* 1631 */ { "CANADIAN SYLLABICS CARRIER LHEE",NULL},
/* 1632 */ { "CANADIAN SYLLABICS CARRIER LHI",NULL},
/* 1633 */ { "CANADIAN SYLLABICS CARRIER LHA",NULL},
/* 1634 */ { "CANADIAN SYLLABICS CARRIER TLHU",NULL},
/* 1635 */ { "CANADIAN SYLLABICS CARRIER TLHO",NULL},
/* 1636 */ { "CANADIAN SYLLABICS CARRIER TLHE",NULL},
/* 1637 */ { "CANADIAN SYLLABICS CARRIER TLHEE",NULL},
/* 1638 */ { "CANADIAN SYLLABICS CARRIER TLHI",NULL},
/* 1639 */ { "CANADIAN SYLLABICS CARRIER TLHA",NULL},
/* 163A */ { "CANADIAN SYLLABICS CARRIER TLU",NULL},
/* 163B */ { "CANADIAN SYLLABICS CARRIER TLO",NULL},
/* 163C */ { "CANADIAN SYLLABICS CARRIER TLE",NULL},
/* 163D */ { "CANADIAN SYLLABICS CARRIER TLEE",NULL},
/* 163E */ { "CANADIAN SYLLABICS CARRIER TLI",NULL},
/* 163F */ { "CANADIAN SYLLABICS CARRIER TLA",NULL},
/* 1640 */ { "CANADIAN SYLLABICS CARRIER ZU",NULL},
/* 1641 */ { "CANADIAN SYLLABICS CARRIER ZO",NULL},
/* 1642 */ { "CANADIAN SYLLABICS CARRIER ZE",NULL},
/* 1643 */ { "CANADIAN SYLLABICS CARRIER ZEE",NULL},
/* 1644 */ { "CANADIAN SYLLABICS CARRIER ZI",NULL},
/* 1645 */ { "CANADIAN SYLLABICS CARRIER ZA",NULL},
/* 1646 */ { "CANADIAN SYLLABICS CARRIER Z",NULL},
/* 1647 */ { "CANADIAN SYLLABICS CARRIER INITIAL Z",NULL},
/* 1648 */ { "CANADIAN SYLLABICS CARRIER DZU",NULL},
/* 1649 */ { "CANADIAN SYLLABICS CARRIER DZO",NULL},
/* 164A */ { "CANADIAN SYLLABICS CARRIER DZE",NULL},
/* 164B */ { "CANADIAN SYLLABICS CARRIER DZEE",NULL},
/* 164C */ { "CANADIAN SYLLABICS CARRIER DZI",NULL},
/* 164D */ { "CANADIAN SYLLABICS CARRIER DZA",NULL},
/* 164E */ { "CANADIAN SYLLABICS CARRIER SU",NULL},
/* 164F */ { "CANADIAN SYLLABICS CARRIER SO",NULL},
/* 1650 */ { "CANADIAN SYLLABICS CARRIER SE",NULL},
/* 1651 */ { "CANADIAN SYLLABICS CARRIER SEE",NULL},
/* 1652 */ { "CANADIAN SYLLABICS CARRIER SI",NULL},
/* 1653 */ { "CANADIAN SYLLABICS CARRIER SA",NULL},
/* 1654 */ { "CANADIAN SYLLABICS CARRIER SHU",NULL},
/* 1655 */ { "CANADIAN SYLLABICS CARRIER SHO",NULL},
/* 1656 */ { "CANADIAN SYLLABICS CARRIER SHE",NULL},
/* 1657 */ { "CANADIAN SYLLABICS CARRIER SHEE",NULL},
/* 1658 */ { "CANADIAN SYLLABICS CARRIER SHI",NULL},
/* 1659 */ { "CANADIAN SYLLABICS CARRIER SHA",NULL},
/* 165A */ { "CANADIAN SYLLABICS CARRIER SH",NULL},
/* 165B */ { "CANADIAN SYLLABICS CARRIER TSU",NULL},
/* 165C */ { "CANADIAN SYLLABICS CARRIER TSO",NULL},
/* 165D */ { "CANADIAN SYLLABICS CARRIER TSE",NULL},
/* 165E */ { "CANADIAN SYLLABICS CARRIER TSEE",NULL},
/* 165F */ { "CANADIAN SYLLABICS CARRIER TSI",NULL},
/* 1660 */ { "CANADIAN SYLLABICS CARRIER TSA",NULL},
/* 1661 */ { "CANADIAN SYLLABICS CARRIER CHU",NULL},
/* 1662 */ { "CANADIAN SYLLABICS CARRIER CHO",NULL},
/* 1663 */ { "CANADIAN SYLLABICS CARRIER CHE",NULL},
/* 1664 */ { "CANADIAN SYLLABICS CARRIER CHEE",NULL},
/* 1665 */ { "CANADIAN SYLLABICS CARRIER CHI",NULL},
/* 1666 */ { "CANADIAN SYLLABICS CARRIER CHA",NULL},
/* 1667 */ { "CANADIAN SYLLABICS CARRIER TTSU",NULL},
/* 1668 */ { "CANADIAN SYLLABICS CARRIER TTSO",NULL},
/* 1669 */ { "CANADIAN SYLLABICS CARRIER TTSE",NULL},
/* 166A */ { "CANADIAN SYLLABICS CARRIER TTSEE",NULL},
/* 166B */ { "CANADIAN SYLLABICS CARRIER TTSI",NULL},
/* 166C */ { "CANADIAN SYLLABICS CARRIER TTSA",NULL},
/* 166D */ { "CANADIAN SYLLABICS CHI SIGN","	* Algonquian\n"
	"	* used as a symbol to denote Christ\n"
	"	x (chi rho - 2627)"},
/* 166E */ { "CANADIAN SYLLABICS FULL STOP","	x (stenographic full stop - 2E3C)"},
/* 166F */ { "CANADIAN SYLLABICS QAI",NULL},
/* 1670 */ { "CANADIAN SYLLABICS NGAI",NULL},
/* 1671 */ { "CANADIAN SYLLABICS NNGI",NULL},
/* 1672 */ { "CANADIAN SYLLABICS NNGII",NULL},
/* 1673 */ { "CANADIAN SYLLABICS NNGO","	* Inuktitut (NNGU)"},
/* 1674 */ { "CANADIAN SYLLABICS NNGOO","	* Inuktitut (NNGUU)"},
/* 1675 */ { "CANADIAN SYLLABICS NNGA",NULL},
/* 1676 */ { "CANADIAN SYLLABICS NNGAA",NULL},
/* 1677 */ { "CANADIAN SYLLABICS WOODS-CREE THWEE",NULL},
/* 1678 */ { "CANADIAN SYLLABICS WOODS-CREE THWI",NULL},
/* 1679 */ { "CANADIAN SYLLABICS WOODS-CREE THWII",NULL},
/* 167A */ { "CANADIAN SYLLABICS WOODS-CREE THWO",NULL},
/* 167B */ { "CANADIAN SYLLABICS WOODS-CREE THWOO",NULL},
/* 167C */ { "CANADIAN SYLLABICS WOODS-CREE THWA",NULL},
/* 167D */ { "CANADIAN SYLLABICS WOODS-CREE THWAA",NULL},
/* 167E */ { "CANADIAN SYLLABICS WOODS-CREE FINAL TH",NULL},
/* 167F */ { "CANADIAN SYLLABICS BLACKFOOT W",NULL},
/* 1680 */ { "OGHAM SPACE MARK","	* glyph is blank in \"stemless\" style fonts\n"
	"	x (space - 0020)"},
/* 1681 */ { "OGHAM LETTER BEITH",NULL},
/* 1682 */ { "OGHAM LETTER LUIS",NULL},
/* 1683 */ { "OGHAM LETTER FEARN",NULL},
/* 1684 */ { "OGHAM LETTER SAIL",NULL},
/* 1685 */ { "OGHAM LETTER NION",NULL},
/* 1686 */ { "OGHAM LETTER UATH",NULL},
/* 1687 */ { "OGHAM LETTER DAIR",NULL},
/* 1688 */ { "OGHAM LETTER TINNE",NULL},
/* 1689 */ { "OGHAM LETTER COLL",NULL},
/* 168A */ { "OGHAM LETTER CEIRT",NULL},
/* 168B */ { "OGHAM LETTER MUIN",NULL},
/* 168C */ { "OGHAM LETTER GORT",NULL},
/* 168D */ { "OGHAM LETTER NGEADAL",NULL},
/* 168E */ { "OGHAM LETTER STRAIF",NULL},
/* 168F */ { "OGHAM LETTER RUIS",NULL},
/* 1690 */ { "OGHAM LETTER AILM",NULL},
/* 1691 */ { "OGHAM LETTER ONN",NULL},
/* 1692 */ { "OGHAM LETTER UR",NULL},
/* 1693 */ { "OGHAM LETTER EADHADH",NULL},
/* 1694 */ { "OGHAM LETTER IODHADH",NULL},
/* 1695 */ { "OGHAM LETTER EABHADH",NULL},
/* 1696 */ { "OGHAM LETTER OR",NULL},
/* 1697 */ { "OGHAM LETTER UILLEANN",NULL},
/* 1698 */ { "OGHAM LETTER IFIN",NULL},
/* 1699 */ { "OGHAM LETTER EAMHANCHOLL",NULL},
/* 169A */ { "OGHAM LETTER PEITH",NULL},
/* 169B */ { "OGHAM FEATHER MARK","	* marks beginning of Ogham text"},
/* 169C */ { "OGHAM REVERSED FEATHER MARK","	* marks end of Ogham text"},
/* 169D */ { NULL,NULL},
/* 169E */ { NULL,NULL},
/* 169F */ { NULL,NULL},
/* 16A0 */ { "RUNIC LETTER FEHU FEOH FE F",NULL},
/* 16A1 */ { "RUNIC LETTER V",NULL},
/* 16A2 */ { "RUNIC LETTER URUZ UR U",NULL},
/* 16A3 */ { "RUNIC LETTER YR",NULL},
/* 16A4 */ { "RUNIC LETTER Y",NULL},
/* 16A5 */ { "RUNIC LETTER W",NULL},
/* 16A6 */ { "RUNIC LETTER THURISAZ THURS THORN","	x (latin small letter thorn - 00FE)"},
/* 16A7 */ { "RUNIC LETTER ETH",NULL},
/* 16A8 */ { "RUNIC LETTER ANSUZ A",NULL},
/* 16A9 */ { "RUNIC LETTER OS O",NULL},
/* 16AA */ { "RUNIC LETTER AC A",NULL},
/* 16AB */ { "RUNIC LETTER AESC",NULL},
/* 16AC */ { "RUNIC LETTER LONG-BRANCH-OSS O",NULL},
/* 16AD */ { "RUNIC LETTER SHORT-TWIG-OSS O",NULL},
/* 16AE */ { "RUNIC LETTER O",NULL},
/* 16AF */ { "RUNIC LETTER OE",NULL},
/* 16B0 */ { "RUNIC LETTER ON",NULL},
/* 16B1 */ { "RUNIC LETTER RAIDO RAD REID R",NULL},
/* 16B2 */ { "RUNIC LETTER KAUNA",NULL},
/* 16B3 */ { "RUNIC LETTER CEN",NULL},
/* 16B4 */ { "RUNIC LETTER KAUN K",NULL},
/* 16B5 */ { "RUNIC LETTER G",NULL},
/* 16B6 */ { "RUNIC LETTER ENG",NULL},
/* 16B7 */ { "RUNIC LETTER GEBO GYFU G",NULL},
/* 16B8 */ { "RUNIC LETTER GAR",NULL},
/* 16B9 */ { "RUNIC LETTER WUNJO WYNN W","	x (latin letter wynn - 01BF)"},
/* 16BA */ { "RUNIC LETTER HAGLAZ H",NULL},
/* 16BB */ { "RUNIC LETTER HAEGL H",NULL},
/* 16BC */ { "RUNIC LETTER LONG-BRANCH-HAGALL H",NULL},
/* 16BD */ { "RUNIC LETTER SHORT-TWIG-HAGALL H",NULL},
/* 16BE */ { "RUNIC LETTER NAUDIZ NYD NAUD N",NULL},
/* 16BF */ { "RUNIC LETTER SHORT-TWIG-NAUD N",NULL},
/* 16C0 */ { "RUNIC LETTER DOTTED-N",NULL},
/* 16C1 */ { "RUNIC LETTER ISAZ IS ISS I",NULL},
/* 16C2 */ { "RUNIC LETTER E",NULL},
/* 16C3 */ { "RUNIC LETTER JERAN J",NULL},
/* 16C4 */ { "RUNIC LETTER GER",NULL},
/* 16C5 */ { "RUNIC LETTER LONG-BRANCH-AR AE",NULL},
/* 16C6 */ { "RUNIC LETTER SHORT-TWIG-AR A",NULL},
/* 16C7 */ { "RUNIC LETTER IWAZ EOH",NULL},
/* 16C8 */ { "RUNIC LETTER PERTHO PEORTH P",NULL},
/* 16C9 */ { "RUNIC LETTER ALGIZ EOLHX",NULL},
/* 16CA */ { "RUNIC LETTER SOWILO S",NULL},
/* 16CB */ { "RUNIC LETTER SIGEL LONG-BRANCH-SOL S",NULL},
/* 16CC */ { "RUNIC LETTER SHORT-TWIG-SOL S",NULL},
/* 16CD */ { "RUNIC LETTER C",NULL},
/* 16CE */ { "RUNIC LETTER Z",NULL},
/* 16CF */ { "RUNIC LETTER TIWAZ TIR TYR T",NULL},
/* 16D0 */ { "RUNIC LETTER SHORT-TWIG-TYR T",NULL},
/* 16D1 */ { "RUNIC LETTER D",NULL},
/* 16D2 */ { "RUNIC LETTER BERKANAN BEORC BJARKAN B",NULL},
/* 16D3 */ { "RUNIC LETTER SHORT-TWIG-BJARKAN B",NULL},
/* 16D4 */ { "RUNIC LETTER DOTTED-P",NULL},
/* 16D5 */ { "RUNIC LETTER OPEN-P",NULL},
/* 16D6 */ { "RUNIC LETTER EHWAZ EH E",NULL},
/* 16D7 */ { "RUNIC LETTER MANNAZ MAN M",NULL},
/* 16D8 */ { "RUNIC LETTER LONG-BRANCH-MADR M",NULL},
/* 16D9 */ { "RUNIC LETTER SHORT-TWIG-MADR M",NULL},
/* 16DA */ { "RUNIC LETTER LAUKAZ LAGU LOGR L",NULL},
/* 16DB */ { "RUNIC LETTER DOTTED-L",NULL},
/* 16DC */ { "RUNIC LETTER INGWAZ",NULL},
/* 16DD */ { "RUNIC LETTER ING",NULL},
/* 16DE */ { "RUNIC LETTER DAGAZ DAEG D",NULL},
/* 16DF */ { "RUNIC LETTER OTHALAN ETHEL O",NULL},
/* 16E0 */ { "RUNIC LETTER EAR",NULL},
/* 16E1 */ { "RUNIC LETTER IOR",NULL},
/* 16E2 */ { "RUNIC LETTER CWEORTH",NULL},
/* 16E3 */ { "RUNIC LETTER CALC",NULL},
/* 16E4 */ { "RUNIC LETTER CEALC",NULL},
/* 16E5 */ { "RUNIC LETTER STAN",NULL},
/* 16E6 */ { "RUNIC LETTER LONG-BRANCH-YR",NULL},
/* 16E7 */ { "RUNIC LETTER SHORT-TWIG-YR",NULL},
/* 16E8 */ { "RUNIC LETTER ICELANDIC-YR",NULL},
/* 16E9 */ { "RUNIC LETTER Q",NULL},
/* 16EA */ { "RUNIC LETTER X",NULL},
/* 16EB */ { "RUNIC SINGLE PUNCTUATION",NULL},
/* 16EC */ { "RUNIC MULTIPLE PUNCTUATION",NULL},
/* 16ED */ { "RUNIC CROSS PUNCTUATION",NULL},
/* 16EE */ { "RUNIC ARLAUG SYMBOL","	* golden number 17"},
/* 16EF */ { "RUNIC TVIMADUR SYMBOL","	* golden number 18"},
/* 16F0 */ { "RUNIC BELGTHOR SYMBOL","	* golden number 19"},
/* 16F1 */ { "RUNIC LETTER K",NULL},
/* 16F2 */ { "RUNIC LETTER SH",NULL},
/* 16F3 */ { "RUNIC LETTER OO",NULL},
/* 16F4 */ { "RUNIC LETTER FRANKS CASKET OS",NULL},
/* 16F5 */ { "RUNIC LETTER FRANKS CASKET IS",NULL},
/* 16F6 */ { "RUNIC LETTER FRANKS CASKET EH",NULL},
/* 16F7 */ { "RUNIC LETTER FRANKS CASKET AC",NULL},
/* 16F8 */ { "RUNIC LETTER FRANKS CASKET AESC",NULL},
/* 16F9 */ { NULL,NULL},
/* 16FA */ { NULL,NULL},
/* 16FB */ { NULL,NULL},
/* 16FC */ { NULL,NULL},
/* 16FD */ { NULL,NULL},
/* 16FE */ { NULL,NULL},
/* 16FF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_00_17[] = {
/* 1700 */ { "TAGALOG LETTER A",NULL},
/* 1701 */ { "TAGALOG LETTER I",NULL},
/* 1702 */ { "TAGALOG LETTER U",NULL},
/* 1703 */ { "TAGALOG LETTER KA",NULL},
/* 1704 */ { "TAGALOG LETTER GA",NULL},
/* 1705 */ { "TAGALOG LETTER NGA",NULL},
/* 1706 */ { "TAGALOG LETTER TA",NULL},
/* 1707 */ { "TAGALOG LETTER DA",NULL},
/* 1708 */ { "TAGALOG LETTER NA",NULL},
/* 1709 */ { "TAGALOG LETTER PA",NULL},
/* 170A */ { "TAGALOG LETTER BA",NULL},
/* 170B */ { "TAGALOG LETTER MA",NULL},
/* 170C */ { "TAGALOG LETTER YA",NULL},
/* 170D */ { "TAGALOG LETTER RA","	* modern adaptation, not found in Old Tagalog"},
/* 170E */ { "TAGALOG LETTER LA",NULL},
/* 170F */ { "TAGALOG LETTER WA",NULL},
/* 1710 */ { "TAGALOG LETTER SA",NULL},
/* 1711 */ { "TAGALOG LETTER HA",NULL},
/* 1712 */ { "TAGALOG VOWEL SIGN I",NULL},
/* 1713 */ { "TAGALOG VOWEL SIGN U",NULL},
/* 1714 */ { "TAGALOG SIGN VIRAMA",NULL},
/* 1715 */ { "TAGALOG SIGN PAMUDPOD","	x (hanunoo sign pamudpod - 1734)"},
/* 1716 */ { NULL,NULL},
/* 1717 */ { NULL,NULL},
/* 1718 */ { NULL,NULL},
/* 1719 */ { NULL,NULL},
/* 171A */ { NULL,NULL},
/* 171B */ { NULL,NULL},
/* 171C */ { NULL,NULL},
/* 171D */ { NULL,NULL},
/* 171E */ { NULL,NULL},
/* 171F */ { "TAGALOG LETTER ARCHAIC RA","	= Zambales ra\n"
	"	* modern adaptation, not found in Old Tagalog"},
/* 1720 */ { "HANUNOO LETTER A",NULL},
/* 1721 */ { "HANUNOO LETTER I",NULL},
/* 1722 */ { "HANUNOO LETTER U",NULL},
/* 1723 */ { "HANUNOO LETTER KA",NULL},
/* 1724 */ { "HANUNOO LETTER GA",NULL},
/* 1725 */ { "HANUNOO LETTER NGA",NULL},
/* 1726 */ { "HANUNOO LETTER TA",NULL},
/* 1727 */ { "HANUNOO LETTER DA",NULL},
/* 1728 */ { "HANUNOO LETTER NA",NULL},
/* 1729 */ { "HANUNOO LETTER PA",NULL},
/* 172A */ { "HANUNOO LETTER BA",NULL},
/* 172B */ { "HANUNOO LETTER MA",NULL},
/* 172C */ { "HANUNOO LETTER YA",NULL},
/* 172D */ { "HANUNOO LETTER RA",NULL},
/* 172E */ { "HANUNOO LETTER LA",NULL},
/* 172F */ { "HANUNOO LETTER WA",NULL},
/* 1730 */ { "HANUNOO LETTER SA",NULL},
/* 1731 */ { "HANUNOO LETTER HA",NULL},
/* 1732 */ { "HANUNOO VOWEL SIGN I",NULL},
/* 1733 */ { "HANUNOO VOWEL SIGN U",NULL},
/* 1734 */ { "HANUNOO SIGN PAMUDPOD","	x (tagalog sign pamudpod - 1715)"},
/* 1735 */ { "PHILIPPINE SINGLE PUNCTUATION","	x (devanagari danda - 0964)"},
/* 1736 */ { "PHILIPPINE DOUBLE PUNCTUATION","	x (devanagari double danda - 0965)"},
/* 1737 */ { NULL,NULL},
/* 1738 */ { NULL,NULL},
/* 1739 */ { NULL,NULL},
/* 173A */ { NULL,NULL},
/* 173B */ { NULL,NULL},
/* 173C */ { NULL,NULL},
/* 173D */ { NULL,NULL},
/* 173E */ { NULL,NULL},
/* 173F */ { NULL,NULL},
/* 1740 */ { "BUHID LETTER A",NULL},
/* 1741 */ { "BUHID LETTER I",NULL},
/* 1742 */ { "BUHID LETTER U",NULL},
/* 1743 */ { "BUHID LETTER KA",NULL},
/* 1744 */ { "BUHID LETTER GA",NULL},
/* 1745 */ { "BUHID LETTER NGA",NULL},
/* 1746 */ { "BUHID LETTER TA",NULL},
/* 1747 */ { "BUHID LETTER DA",NULL},
/* 1748 */ { "BUHID LETTER NA",NULL},
/* 1749 */ { "BUHID LETTER PA",NULL},
/* 174A */ { "BUHID LETTER BA",NULL},
/* 174B */ { "BUHID LETTER MA",NULL},
/* 174C */ { "BUHID LETTER YA",NULL},
/* 174D */ { "BUHID LETTER RA",NULL},
/* 174E */ { "BUHID LETTER LA",NULL},
/* 174F */ { "BUHID LETTER WA",NULL},
/* 1750 */ { "BUHID LETTER SA",NULL},
/* 1751 */ { "BUHID LETTER HA",NULL},
/* 1752 */ { "BUHID VOWEL SIGN I",NULL},
/* 1753 */ { "BUHID VOWEL SIGN U",NULL},
/* 1754 */ { NULL,NULL},
/* 1755 */ { NULL,NULL},
/* 1756 */ { NULL,NULL},
/* 1757 */ { NULL,NULL},
/* 1758 */ { NULL,NULL},
/* 1759 */ { NULL,NULL},
/* 175A */ { NULL,NULL},
/* 175B */ { NULL,NULL},
/* 175C */ { NULL,NULL},
/* 175D */ { NULL,NULL},
/* 175E */ { NULL,NULL},
/* 175F */ { NULL,NULL},
/* 1760 */ { "TAGBANWA LETTER A",NULL},
/* 1761 */ { "TAGBANWA LETTER I",NULL},
/* 1762 */ { "TAGBANWA LETTER U",NULL},
/* 1763 */ { "TAGBANWA LETTER KA",NULL},
/* 1764 */ { "TAGBANWA LETTER GA",NULL},
/* 1765 */ { "TAGBANWA LETTER NGA",NULL},
/* 1766 */ { "TAGBANWA LETTER TA",NULL},
/* 1767 */ { "TAGBANWA LETTER DA",NULL},
/* 1768 */ { "TAGBANWA LETTER NA",NULL},
/* 1769 */ { "TAGBANWA LETTER PA",NULL},
/* 176A */ { "TAGBANWA LETTER BA",NULL},
/* 176B */ { "TAGBANWA LETTER MA",NULL},
/* 176C */ { "TAGBANWA LETTER YA",NULL},
/* 176D */ { NULL,NULL},
/* 176E */ { "TAGBANWA LETTER LA",NULL},
/* 176F */ { "TAGBANWA LETTER WA",NULL},
/* 1770 */ { "TAGBANWA LETTER SA",NULL},
/* 1771 */ { NULL,NULL},
/* 1772 */ { "TAGBANWA VOWEL SIGN I",NULL},
/* 1773 */ { "TAGBANWA VOWEL SIGN U",NULL},
/* 1774 */ { NULL,NULL},
/* 1775 */ { NULL,NULL},
/* 1776 */ { NULL,NULL},
/* 1777 */ { NULL,NULL},
/* 1778 */ { NULL,NULL},
/* 1779 */ { NULL,NULL},
/* 177A */ { NULL,NULL},
/* 177B */ { NULL,NULL},
/* 177C */ { NULL,NULL},
/* 177D */ { NULL,NULL},
/* 177E */ { NULL,NULL},
/* 177F */ { NULL,NULL},
/* 1780 */ { "KHMER LETTER KA",NULL},
/* 1781 */ { "KHMER LETTER KHA",NULL},
/* 1782 */ { "KHMER LETTER KO",NULL},
/* 1783 */ { "KHMER LETTER KHO",NULL},
/* 1784 */ { "KHMER LETTER NGO",NULL},
/* 1785 */ { "KHMER LETTER CA",NULL},
/* 1786 */ { "KHMER LETTER CHA",NULL},
/* 1787 */ { "KHMER LETTER CO",NULL},
/* 1788 */ { "KHMER LETTER CHO",NULL},
/* 1789 */ { "KHMER LETTER NYO",NULL},
/* 178A */ { "KHMER LETTER DA",NULL},
/* 178B */ { "KHMER LETTER TTHA",NULL},
/* 178C */ { "KHMER LETTER DO",NULL},
/* 178D */ { "KHMER LETTER TTHO",NULL},
/* 178E */ { "KHMER LETTER NNO","	* as this character belongs to the first register, its correct transliteration is nna, not nno"},
/* 178F */ { "KHMER LETTER TA",NULL},
/* 1790 */ { "KHMER LETTER THA",NULL},
/* 1791 */ { "KHMER LETTER TO",NULL},
/* 1792 */ { "KHMER LETTER THO",NULL},
/* 1793 */ { "KHMER LETTER NO",NULL},
/* 1794 */ { "KHMER LETTER BA",NULL},
/* 1795 */ { "KHMER LETTER PHA",NULL},
/* 1796 */ { "KHMER LETTER PO",NULL},
/* 1797 */ { "KHMER LETTER PHO",NULL},
/* 1798 */ { "KHMER LETTER MO",NULL},
/* 1799 */ { "KHMER LETTER YO",NULL},
/* 179A */ { "KHMER LETTER RO",NULL},
/* 179B */ { "KHMER LETTER LO",NULL},
/* 179C */ { "KHMER LETTER VO",NULL},
/* 179D */ { "KHMER LETTER SHA","	* used only for Pali/Sanskrit transliteration"},
/* 179E */ { "KHMER LETTER SSO","	* used only for Pali/Sanskrit transliteration\n"
	"	* as this character belongs to the first register, its correct transliteration is ssa, not sso"},
/* 179F */ { "KHMER LETTER SA",NULL},
/* 17A0 */ { "KHMER LETTER HA",NULL},
/* 17A1 */ { "KHMER LETTER LA",NULL},
/* 17A2 */ { "KHMER LETTER QA","	* glottal stop"},
/* 17A3 */ { "KHMER INDEPENDENT VOWEL QAQ","	* use of this character is strongly discouraged; 17A2 should be used instead"},
/* 17A4 */ { "KHMER INDEPENDENT VOWEL QAA","	* use of this character is strongly discouraged; the sequence 17A2 17B6 should be used instead"},
/* 17A5 */ { "KHMER INDEPENDENT VOWEL QI",NULL},
/* 17A6 */ { "KHMER INDEPENDENT VOWEL QII",NULL},
/* 17A7 */ { "KHMER INDEPENDENT VOWEL QU",NULL},
/* 17A8 */ { "KHMER INDEPENDENT VOWEL QUK","	* obsolete ligature for the sequence 17A7 1780\n"
	"	* use of the sequence is now preferred"},
/* 17A9 */ { "KHMER INDEPENDENT VOWEL QUU",NULL},
/* 17AA */ { "KHMER INDEPENDENT VOWEL QUUV",NULL},
/* 17AB */ { "KHMER INDEPENDENT VOWEL RY",NULL},
/* 17AC */ { "KHMER INDEPENDENT VOWEL RYY",NULL},
/* 17AD */ { "KHMER INDEPENDENT VOWEL LY",NULL},
/* 17AE */ { "KHMER INDEPENDENT VOWEL LYY",NULL},
/* 17AF */ { "KHMER INDEPENDENT VOWEL QE",NULL},
/* 17B0 */ { "KHMER INDEPENDENT VOWEL QAI",NULL},
/* 17B1 */ { "KHMER INDEPENDENT VOWEL QOO TYPE ONE",NULL},
/* 17B2 */ { "KHMER INDEPENDENT VOWEL QOO TYPE TWO","	* this is a variant for 17B1, used in only two words\n"
	"	* 17B1 is the normal variant of this vowel"},
/* 17B3 */ { "KHMER INDEPENDENT VOWEL QAU",NULL},
/* 17B4 */ { "KHMER VOWEL INHERENT AQ",NULL},
/* 17B5 */ { "KHMER VOWEL INHERENT AA",NULL},
/* 17B6 */ { "KHMER VOWEL SIGN AA",NULL},
/* 17B7 */ { "KHMER VOWEL SIGN I",NULL},
/* 17B8 */ { "KHMER VOWEL SIGN II",NULL},
/* 17B9 */ { "KHMER VOWEL SIGN Y",NULL},
/* 17BA */ { "KHMER VOWEL SIGN YY",NULL},
/* 17BB */ { "KHMER VOWEL SIGN U",NULL},
/* 17BC */ { "KHMER VOWEL SIGN UU",NULL},
/* 17BD */ { "KHMER VOWEL SIGN UA",NULL},
/* 17BE */ { "KHMER VOWEL SIGN OE",NULL},
/* 17BF */ { "KHMER VOWEL SIGN YA",NULL},
/* 17C0 */ { "KHMER VOWEL SIGN IE",NULL},
/* 17C1 */ { "KHMER VOWEL SIGN E",NULL},
/* 17C2 */ { "KHMER VOWEL SIGN AE",NULL},
/* 17C3 */ { "KHMER VOWEL SIGN AI",NULL},
/* 17C4 */ { "KHMER VOWEL SIGN OO",NULL},
/* 17C5 */ { "KHMER VOWEL SIGN AU",NULL},
/* 17C6 */ { "KHMER SIGN NIKAHIT","	= srak am\n"
	"	= anusvara\n"
	"	* final nasalization\n"
	"	* this character is usually regarded as a vowel sign am, along with om and aam\n"
	"	x (thai character nikhahit - 0E4D)\n"
	"	x (myanmar sign anusvara - 1036)"},
/* 17C7 */ { "KHMER SIGN REAHMUK","	= srak ah\n"
	"	= visarga\n"
	"	x (myanmar sign visarga - 1038)"},
/* 17C8 */ { "KHMER SIGN YUUKALEAPINTU","	* inserts a short inherent vowel with abrupt glottal stop\n"
	"	* the preferred transliteration is yukaleakpintu"},
/* 17C9 */ { "KHMER SIGN MUUSIKATOAN","	* changes the second register to the first\n"
	"	* the preferred transliteration is muusekatoan"},
/* 17CA */ { "KHMER SIGN TRIISAP","	* changes the first register to the second\n"
	"	* the preferred transliteration is treisap"},
/* 17CB */ { "KHMER SIGN BANTOC","	* shortens the vowel sound in the previous orthographic syllable\n"
	"	* the preferred transliteration is bantak"},
/* 17CC */ { "KHMER SIGN ROBAT","	* a diacritic historically corresponding to the repha form of ra in Devanagari"},
/* 17CD */ { "KHMER SIGN TOANDAKHIAT","	* indicates that the base character is not pronounced\n"
	"	x (thai character thanthakhat - 0E4C)"},
/* 17CE */ { "KHMER SIGN KAKABAT","	* sign used with some exclamations"},
/* 17CF */ { "KHMER SIGN AHSDA","	* denotes stressed intonation in some single-consonant words"},
/* 17D0 */ { "KHMER SIGN SAMYOK SANNYA","	* denotes deviation from the general rules of pronunciation, mostly used in loan words from Pali/Sanskrit, French, and so on"},
/* 17D1 */ { "KHMER SIGN VIRIAM","	* mostly obsolete, a \"killer\"\n"
	"	* indicates that the base character is the final consonant of a word without its inherent vowel sound"},
/* 17D2 */ { "KHMER SIGN COENG","	* functions to indicate that the following Khmer letter is to be rendered subscripted\n"
	"	* shape shown is arbitrary and is not visibly rendered"},
/* 17D3 */ { "KHMER SIGN BATHAMASAT","	* originally intended as part of lunar date symbols\n"
	"	* use of this character is discouraged in favor of the complete set of lunar date symbols\n"
	"	x (khmer symbol pathamasat - 19E0)"},
/* 17D4 */ { "KHMER SIGN KHAN","	* functions as a full stop, period\n"
	"	x (thai character paiyannoi - 0E2F)\n"
	"	x (myanmar sign little section - 104A)"},
/* 17D5 */ { "KHMER SIGN BARIYOOSAN","	* indicates the end of a section or a text\n"
	"	x (thai character angkhankhu - 0E5A)\n"
	"	x (myanmar sign section - 104B)"},
/* 17D6 */ { "KHMER SIGN CAMNUC PII KUUH","	* functions as colon\n"
	"	* the preferred transliteration is camnoc pii kuuh\n"
	"	x (division sign - 00F7)\n"
	"	x (tibetan mark gter tsheg - 0F14)"},
/* 17D7 */ { "KHMER SIGN LEK TOO","	* repetition sign\n"
	"	x (thai character maiyamok - 0E46)"},
/* 17D8 */ { "KHMER SIGN BEYYAL","	* et cetera\n"
	"	* use of this character is discouraged; other abbreviations for et cetera also exist\n"
	"	* preferred spelling: 17D4 179B 17D4"},
/* 17D9 */ { "KHMER SIGN PHNAEK MUAN","	* indicates the beginning of a book or a treatise\n"
	"	* the preferred transliteration is phnek moan\n"
	"	x (thai character fongman - 0E4F)"},
/* 17DA */ { "KHMER SIGN KOOMUUT","	* indicates the end of a book or treatise\n"
	"	* this forms a pair with 17D9\n"
	"	* the preferred transliteration is koomoot\n"
	"	x (thai character khomut - 0E5B)"},
/* 17DB */ { "KHMER CURRENCY SYMBOL RIEL",NULL},
/* 17DC */ { "KHMER SIGN AVAKRAHASANYA","	* rare, shows an omitted Sanskrit vowel, like an apostrophe\n"
	"	* the preferred transliteration is avakraha sannya\n"
	"	x (devanagari sign avagraha - 093D)"},
/* 17DD */ { "KHMER SIGN ATTHACAN","	* mostly obsolete\n"
	"	* indicates that the base character is the final consonant of a word with its inherent vowel sound\n"
	"	x (khmer sign viriam - 17D1)"},
/* 17DE */ { NULL,NULL},
/* 17DF */ { NULL,NULL},
/* 17E0 */ { "KHMER DIGIT ZERO",NULL},
/* 17E1 */ { "KHMER DIGIT ONE",NULL},
/* 17E2 */ { "KHMER DIGIT TWO",NULL},
/* 17E3 */ { "KHMER DIGIT THREE",NULL},
/* 17E4 */ { "KHMER DIGIT FOUR",NULL},
/* 17E5 */ { "KHMER DIGIT FIVE",NULL},
/* 17E6 */ { "KHMER DIGIT SIX",NULL},
/* 17E7 */ { "KHMER DIGIT SEVEN",NULL},
/* 17E8 */ { "KHMER DIGIT EIGHT",NULL},
/* 17E9 */ { "KHMER DIGIT NINE",NULL},
/* 17EA */ { NULL,NULL},
/* 17EB */ { NULL,NULL},
/* 17EC */ { NULL,NULL},
/* 17ED */ { NULL,NULL},
/* 17EE */ { NULL,NULL},
/* 17EF */ { NULL,NULL},
/* 17F0 */ { "KHMER SYMBOL LEK ATTAK SON",NULL},
/* 17F1 */ { "KHMER SYMBOL LEK ATTAK MUOY",NULL},
/* 17F2 */ { "KHMER SYMBOL LEK ATTAK PII",NULL},
/* 17F3 */ { "KHMER SYMBOL LEK ATTAK BEI",NULL},
/* 17F4 */ { "KHMER SYMBOL LEK ATTAK BUON",NULL},
/* 17F5 */ { "KHMER SYMBOL LEK ATTAK PRAM",NULL},
/* 17F6 */ { "KHMER SYMBOL LEK ATTAK PRAM-MUOY",NULL},
/* 17F7 */ { "KHMER SYMBOL LEK ATTAK PRAM-PII",NULL},
/* 17F8 */ { "KHMER SYMBOL LEK ATTAK PRAM-BEI",NULL},
/* 17F9 */ { "KHMER SYMBOL LEK ATTAK PRAM-BUON",NULL},
/* 17FA */ { NULL,NULL},
/* 17FB */ { NULL,NULL},
/* 17FC */ { NULL,NULL},
/* 17FD */ { NULL,NULL},
/* 17FE */ { NULL,NULL},
/* 17FF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_00_18[] = {
/* 1800 */ { "MONGOLIAN BIRGA","	x (tibetan mark initial yig mgo mdun ma - 0F04)"},
/* 1801 */ { "MONGOLIAN ELLIPSIS",NULL},
/* 1802 */ { "MONGOLIAN COMMA",NULL},
/* 1803 */ { "MONGOLIAN FULL STOP",NULL},
/* 1804 */ { "MONGOLIAN COLON",NULL},
/* 1805 */ { "MONGOLIAN FOUR DOTS","	* marks the end of a chapter"},
/* 1806 */ { "MONGOLIAN TODO SOFT HYPHEN","	* not a format control character, but simply a hyphen for Todo\n"
	"	* also used in the Hudum (modern Mongolian) writing system\n"
	"	x (soft hyphen - 00AD)"},
/* 1807 */ { "MONGOLIAN SIBE SYLLABLE BOUNDARY MARKER",NULL},
/* 1808 */ { "MONGOLIAN MANCHU COMMA",NULL},
/* 1809 */ { "MONGOLIAN MANCHU FULL STOP",NULL},
/* 180A */ { "MONGOLIAN NIRUGU",NULL},
/* 180B */ { "MONGOLIAN FREE VARIATION SELECTOR ONE","	* abbreviated FVS1"},
/* 180C */ { "MONGOLIAN FREE VARIATION SELECTOR TWO","	* abbreviated FVS2"},
/* 180D */ { "MONGOLIAN FREE VARIATION SELECTOR THREE","	* abbreviated FVS3"},
/* 180E */ { "MONGOLIAN VOWEL SEPARATOR","	* abbreviated MVS"},
/* 180F */ { "MONGOLIAN FREE VARIATION SELECTOR FOUR","	* abbreviated FVS4"},
/* 1810 */ { "MONGOLIAN DIGIT ZERO",NULL},
/* 1811 */ { "MONGOLIAN DIGIT ONE",NULL},
/* 1812 */ { "MONGOLIAN DIGIT TWO",NULL},
/* 1813 */ { "MONGOLIAN DIGIT THREE",NULL},
/* 1814 */ { "MONGOLIAN DIGIT FOUR",NULL},
/* 1815 */ { "MONGOLIAN DIGIT FIVE",NULL},
/* 1816 */ { "MONGOLIAN DIGIT SIX",NULL},
/* 1817 */ { "MONGOLIAN DIGIT SEVEN",NULL},
/* 1818 */ { "MONGOLIAN DIGIT EIGHT",NULL},
/* 1819 */ { "MONGOLIAN DIGIT NINE",NULL},
/* 181A */ { NULL,NULL},
/* 181B */ { NULL,NULL},
/* 181C */ { NULL,NULL},
/* 181D */ { NULL,NULL},
/* 181E */ { NULL,NULL},
/* 181F */ { NULL,NULL},
/* 1820 */ { "MONGOLIAN LETTER A","	x (cyrillic small letter a - 0430)"},
/* 1821 */ { "MONGOLIAN LETTER E","	x (cyrillic small letter e - 044D)"},
/* 1822 */ { "MONGOLIAN LETTER I","	x (cyrillic small letter i - 0438)"},
/* 1823 */ { "MONGOLIAN LETTER O","	x (cyrillic small letter o - 043E)"},
/* 1824 */ { "MONGOLIAN LETTER U","	x (cyrillic small letter u - 0443)"},
/* 1825 */ { "MONGOLIAN LETTER OE","	x (cyrillic small letter barred o - 04E9)"},
/* 1826 */ { "MONGOLIAN LETTER UE","	x (cyrillic small letter straight u - 04AF)"},
/* 1827 */ { "MONGOLIAN LETTER EE",NULL},
/* 1828 */ { "MONGOLIAN LETTER NA","	x (cyrillic small letter en - 043D)"},
/* 1829 */ { "MONGOLIAN LETTER ANG",NULL},
/* 182A */ { "MONGOLIAN LETTER BA","	x (cyrillic small letter be - 0431)"},
/* 182B */ { "MONGOLIAN LETTER PA","	x (cyrillic small letter pe - 043F)"},
/* 182C */ { "MONGOLIAN LETTER QA","	x (cyrillic small letter ha - 0445)"},
/* 182D */ { "MONGOLIAN LETTER GA","	x (cyrillic small letter ghe - 0433)"},
/* 182E */ { "MONGOLIAN LETTER MA","	x (cyrillic small letter em - 043C)"},
/* 182F */ { "MONGOLIAN LETTER LA","	x (cyrillic small letter el - 043B)"},
/* 1830 */ { "MONGOLIAN LETTER SA","	x (cyrillic small letter es - 0441)"},
/* 1831 */ { "MONGOLIAN LETTER SHA","	x (cyrillic small letter sha - 0448)"},
/* 1832 */ { "MONGOLIAN LETTER TA","	x (cyrillic small letter te - 0442)"},
/* 1833 */ { "MONGOLIAN LETTER DA","	x (cyrillic small letter de - 0434)"},
/* 1834 */ { "MONGOLIAN LETTER CHA","	x (cyrillic small letter che - 0447)"},
/* 1835 */ { "MONGOLIAN LETTER JA","	x (cyrillic small letter zhe - 0436)"},
/* 1836 */ { "MONGOLIAN LETTER YA","	x (cyrillic small letter short i - 0439)"},
/* 1837 */ { "MONGOLIAN LETTER RA","	x (cyrillic small letter er - 0440)"},
/* 1838 */ { "MONGOLIAN LETTER WA","	x (cyrillic small letter ve - 0432)"},
/* 1839 */ { "MONGOLIAN LETTER FA","	x (cyrillic small letter ef - 0444)"},
/* 183A */ { "MONGOLIAN LETTER KA","	x (cyrillic small letter ha - 0445)"},
/* 183B */ { "MONGOLIAN LETTER KHA","	x (cyrillic small letter ka - 043A)"},
/* 183C */ { "MONGOLIAN LETTER TSA","	x (cyrillic small letter tse - 0446)"},
/* 183D */ { "MONGOLIAN LETTER ZA","	x (cyrillic small letter ze - 0437)"},
/* 183E */ { "MONGOLIAN LETTER HAA","	x (cyrillic small letter ha - 0445)"},
/* 183F */ { "MONGOLIAN LETTER ZRA","	x (cyrillic small letter zhe - 0436)"},
/* 1840 */ { "MONGOLIAN LETTER LHA",NULL},
/* 1841 */ { "MONGOLIAN LETTER ZHI",NULL},
/* 1842 */ { "MONGOLIAN LETTER CHI",NULL},
/* 1843 */ { "MONGOLIAN LETTER TODO LONG VOWEL SIGN",NULL},
/* 1844 */ { "MONGOLIAN LETTER TODO E",NULL},
/* 1845 */ { "MONGOLIAN LETTER TODO I",NULL},
/* 1846 */ { "MONGOLIAN LETTER TODO O",NULL},
/* 1847 */ { "MONGOLIAN LETTER TODO U",NULL},
/* 1848 */ { "MONGOLIAN LETTER TODO OE",NULL},
/* 1849 */ { "MONGOLIAN LETTER TODO UE",NULL},
/* 184A */ { "MONGOLIAN LETTER TODO ANG",NULL},
/* 184B */ { "MONGOLIAN LETTER TODO BA",NULL},
/* 184C */ { "MONGOLIAN LETTER TODO PA",NULL},
/* 184D */ { "MONGOLIAN LETTER TODO QA",NULL},
/* 184E */ { "MONGOLIAN LETTER TODO GA",NULL},
/* 184F */ { "MONGOLIAN LETTER TODO MA",NULL},
/* 1850 */ { "MONGOLIAN LETTER TODO TA",NULL},
/* 1851 */ { "MONGOLIAN LETTER TODO DA",NULL},
/* 1852 */ { "MONGOLIAN LETTER TODO CHA",NULL},
/* 1853 */ { "MONGOLIAN LETTER TODO JA",NULL},
/* 1854 */ { "MONGOLIAN LETTER TODO TSA",NULL},
/* 1855 */ { "MONGOLIAN LETTER TODO YA",NULL},
/* 1856 */ { "MONGOLIAN LETTER TODO WA",NULL},
/* 1857 */ { "MONGOLIAN LETTER TODO KA",NULL},
/* 1858 */ { "MONGOLIAN LETTER TODO GAA",NULL},
/* 1859 */ { "MONGOLIAN LETTER TODO HAA",NULL},
/* 185A */ { "MONGOLIAN LETTER TODO JIA",NULL},
/* 185B */ { "MONGOLIAN LETTER TODO NIA",NULL},
/* 185C */ { "MONGOLIAN LETTER TODO DZA",NULL},
/* 185D */ { "MONGOLIAN LETTER SIBE E",NULL},
/* 185E */ { "MONGOLIAN LETTER SIBE I",NULL},
/* 185F */ { "MONGOLIAN LETTER SIBE IY",NULL},
/* 1860 */ { "MONGOLIAN LETTER SIBE UE",NULL},
/* 1861 */ { "MONGOLIAN LETTER SIBE U",NULL},
/* 1862 */ { "MONGOLIAN LETTER SIBE ANG",NULL},
/* 1863 */ { "MONGOLIAN LETTER SIBE KA",NULL},
/* 1864 */ { "MONGOLIAN LETTER SIBE GA",NULL},
/* 1865 */ { "MONGOLIAN LETTER SIBE HA",NULL},
/* 1866 */ { "MONGOLIAN LETTER SIBE PA",NULL},
/* 1867 */ { "MONGOLIAN LETTER SIBE SHA",NULL},
/* 1868 */ { "MONGOLIAN LETTER SIBE TA",NULL},
/* 1869 */ { "MONGOLIAN LETTER SIBE DA",NULL},
/* 186A */ { "MONGOLIAN LETTER SIBE JA",NULL},
/* 186B */ { "MONGOLIAN LETTER SIBE FA",NULL},
/* 186C */ { "MONGOLIAN LETTER SIBE GAA",NULL},
/* 186D */ { "MONGOLIAN LETTER SIBE HAA",NULL},
/* 186E */ { "MONGOLIAN LETTER SIBE TSA",NULL},
/* 186F */ { "MONGOLIAN LETTER SIBE ZA",NULL},
/* 1870 */ { "MONGOLIAN LETTER SIBE RAA",NULL},
/* 1871 */ { "MONGOLIAN LETTER SIBE CHA",NULL},
/* 1872 */ { "MONGOLIAN LETTER SIBE ZHA",NULL},
/* 1873 */ { "MONGOLIAN LETTER MANCHU I",NULL},
/* 1874 */ { "MONGOLIAN LETTER MANCHU KA",NULL},
/* 1875 */ { "MONGOLIAN LETTER MANCHU RA",NULL},
/* 1876 */ { "MONGOLIAN LETTER MANCHU FA",NULL},
/* 1877 */ { "MONGOLIAN LETTER MANCHU ZHA",NULL},
/* 1878 */ { "MONGOLIAN LETTER CHA WITH TWO DOTS",NULL},
/* 1879 */ { NULL,NULL},
/* 187A */ { NULL,NULL},
/* 187B */ { NULL,NULL},
/* 187C */ { NULL,NULL},
/* 187D */ { NULL,NULL},
/* 187E */ { NULL,NULL},
/* 187F */ { NULL,NULL},
/* 1880 */ { "MONGOLIAN LETTER ALI GALI ANUSVARA ONE","	x (tibetan sign sna ldan - 0F83)"},
/* 1881 */ { "MONGOLIAN LETTER ALI GALI VISARGA ONE","	x (tibetan sign rnam bcad - 0F7F)"},
/* 1882 */ { "MONGOLIAN LETTER ALI GALI DAMARU","	x (tibetan sign lce tsa can - 0F88)"},
/* 1883 */ { "MONGOLIAN LETTER ALI GALI UBADAMA",NULL},
/* 1884 */ { "MONGOLIAN LETTER ALI GALI INVERTED UBADAMA","	x (tibetan sign mchu can - 0F89)"},
/* 1885 */ { "MONGOLIAN LETTER ALI GALI BALUDA","	x (tibetan mark paluta - 0F85)"},
/* 1886 */ { "MONGOLIAN LETTER ALI GALI THREE BALUDA",NULL},
/* 1887 */ { "MONGOLIAN LETTER ALI GALI A",NULL},
/* 1888 */ { "MONGOLIAN LETTER ALI GALI I",NULL},
/* 1889 */ { "MONGOLIAN LETTER ALI GALI KA",NULL},
/* 188A */ { "MONGOLIAN LETTER ALI GALI NGA",NULL},
/* 188B */ { "MONGOLIAN LETTER ALI GALI CA",NULL},
/* 188C */ { "MONGOLIAN LETTER ALI GALI TTA",NULL},
/* 188D */ { "MONGOLIAN LETTER ALI GALI TTHA",NULL},
/* 188E */ { "MONGOLIAN LETTER ALI GALI DDA",NULL},
/* 188F */ { "MONGOLIAN LETTER ALI GALI NNA",NULL},
/* 1890 */ { "MONGOLIAN LETTER ALI GALI TA",NULL},
/* 1891 */ { "MONGOLIAN LETTER ALI GALI DA",NULL},
/* 1892 */ { "MONGOLIAN LETTER ALI GALI PA",NULL},
/* 1893 */ { "MONGOLIAN LETTER ALI GALI PHA",NULL},
/* 1894 */ { "MONGOLIAN LETTER ALI GALI SSA",NULL},
/* 1895 */ { "MONGOLIAN LETTER ALI GALI ZHA",NULL},
/* 1896 */ { "MONGOLIAN LETTER ALI GALI ZA",NULL},
/* 1897 */ { "MONGOLIAN LETTER ALI GALI AH",NULL},
/* 1898 */ { "MONGOLIAN LETTER TODO ALI GALI TA",NULL},
/* 1899 */ { "MONGOLIAN LETTER TODO ALI GALI ZHA",NULL},
/* 189A */ { "MONGOLIAN LETTER MANCHU ALI GALI GHA",NULL},
/* 189B */ { "MONGOLIAN LETTER MANCHU ALI GALI NGA",NULL},
/* 189C */ { "MONGOLIAN LETTER MANCHU ALI GALI CA",NULL},
/* 189D */ { "MONGOLIAN LETTER MANCHU ALI GALI JHA",NULL},
/* 189E */ { "MONGOLIAN LETTER MANCHU ALI GALI TTA",NULL},
/* 189F */ { "MONGOLIAN LETTER MANCHU ALI GALI DDHA",NULL},
/* 18A0 */ { "MONGOLIAN LETTER MANCHU ALI GALI TA",NULL},
/* 18A1 */ { "MONGOLIAN LETTER MANCHU ALI GALI DHA",NULL},
/* 18A2 */ { "MONGOLIAN LETTER MANCHU ALI GALI SSA",NULL},
/* 18A3 */ { "MONGOLIAN LETTER MANCHU ALI GALI CYA",NULL},
/* 18A4 */ { "MONGOLIAN LETTER MANCHU ALI GALI ZHA",NULL},
/* 18A5 */ { "MONGOLIAN LETTER MANCHU ALI GALI ZA",NULL},
/* 18A6 */ { "MONGOLIAN LETTER ALI GALI HALF U",NULL},
/* 18A7 */ { "MONGOLIAN LETTER ALI GALI HALF YA",NULL},
/* 18A8 */ { "MONGOLIAN LETTER MANCHU ALI GALI BHA",NULL},
/* 18A9 */ { "MONGOLIAN LETTER ALI GALI DAGALGA",NULL},
/* 18AA */ { "MONGOLIAN LETTER MANCHU ALI GALI LHA",NULL},
/* 18AB */ { NULL,NULL},
/* 18AC */ { NULL,NULL},
/* 18AD */ { NULL,NULL},
/* 18AE */ { NULL,NULL},
/* 18AF */ { NULL,NULL},
/* 18B0 */ { "CANADIAN SYLLABICS OY",NULL},
/* 18B1 */ { "CANADIAN SYLLABICS AY",NULL},
/* 18B2 */ { "CANADIAN SYLLABICS AAY",NULL},
/* 18B3 */ { "CANADIAN SYLLABICS WAY",NULL},
/* 18B4 */ { "CANADIAN SYLLABICS POY",NULL},
/* 18B5 */ { "CANADIAN SYLLABICS PAY",NULL},
/* 18B6 */ { "CANADIAN SYLLABICS PWOY",NULL},
/* 18B7 */ { "CANADIAN SYLLABICS TAY",NULL},
/* 18B8 */ { "CANADIAN SYLLABICS KAY",NULL},
/* 18B9 */ { "CANADIAN SYLLABICS KWAY",NULL},
/* 18BA */ { "CANADIAN SYLLABICS MAY",NULL},
/* 18BB */ { "CANADIAN SYLLABICS NOY",NULL},
/* 18BC */ { "CANADIAN SYLLABICS NAY",NULL},
/* 18BD */ { "CANADIAN SYLLABICS LAY",NULL},
/* 18BE */ { "CANADIAN SYLLABICS SOY",NULL},
/* 18BF */ { "CANADIAN SYLLABICS SAY",NULL},
/* 18C0 */ { "CANADIAN SYLLABICS SHOY",NULL},
/* 18C1 */ { "CANADIAN SYLLABICS SHAY",NULL},
/* 18C2 */ { "CANADIAN SYLLABICS SHWOY",NULL},
/* 18C3 */ { "CANADIAN SYLLABICS YOY",NULL},
/* 18C4 */ { "CANADIAN SYLLABICS YAY",NULL},
/* 18C5 */ { "CANADIAN SYLLABICS RAY",NULL},
/* 18C6 */ { "CANADIAN SYLLABICS NWI",NULL},
/* 18C7 */ { "CANADIAN SYLLABICS OJIBWAY NWI",NULL},
/* 18C8 */ { "CANADIAN SYLLABICS NWII",NULL},
/* 18C9 */ { "CANADIAN SYLLABICS OJIBWAY NWII",NULL},
/* 18CA */ { "CANADIAN SYLLABICS NWO",NULL},
/* 18CB */ { "CANADIAN SYLLABICS OJIBWAY NWO",NULL},
/* 18CC */ { "CANADIAN SYLLABICS NWOO",NULL},
/* 18CD */ { "CANADIAN SYLLABICS OJIBWAY NWOO",NULL},
/* 18CE */ { "CANADIAN SYLLABICS RWEE",NULL},
/* 18CF */ { "CANADIAN SYLLABICS RWI",NULL},
/* 18D0 */ { "CANADIAN SYLLABICS RWII",NULL},
/* 18D1 */ { "CANADIAN SYLLABICS RWO",NULL},
/* 18D2 */ { "CANADIAN SYLLABICS RWOO",NULL},
/* 18D3 */ { "CANADIAN SYLLABICS RWA",NULL},
/* 18D4 */ { "CANADIAN SYLLABICS OJIBWAY P",NULL},
/* 18D5 */ { "CANADIAN SYLLABICS OJIBWAY T",NULL},
/* 18D6 */ { "CANADIAN SYLLABICS OJIBWAY K",NULL},
/* 18D7 */ { "CANADIAN SYLLABICS OJIBWAY C",NULL},
/* 18D8 */ { "CANADIAN SYLLABICS OJIBWAY M",NULL},
/* 18D9 */ { "CANADIAN SYLLABICS OJIBWAY N",NULL},
/* 18DA */ { "CANADIAN SYLLABICS OJIBWAY S",NULL},
/* 18DB */ { "CANADIAN SYLLABICS OJIBWAY SH",NULL},
/* 18DC */ { "CANADIAN SYLLABICS EASTERN W",NULL},
/* 18DD */ { "CANADIAN SYLLABICS WESTERN W",NULL},
/* 18DE */ { "CANADIAN SYLLABICS FINAL SMALL RING",NULL},
/* 18DF */ { "CANADIAN SYLLABICS FINAL RAISED DOT","	* Carrier (GLOTTAL STOP)"},
/* 18E0 */ { "CANADIAN SYLLABICS R-CREE RWE","	* Beaver Dene (LYE)"},
/* 18E1 */ { "CANADIAN SYLLABICS WEST-CREE LOO","	* Chipewyan Dene (LU)"},
/* 18E2 */ { "CANADIAN SYLLABICS WEST-CREE LAA","	* Beaver Dene (LAI)"},
/* 18E3 */ { "CANADIAN SYLLABICS THWE","	* Beaver Dene (TYE)"},
/* 18E4 */ { "CANADIAN SYLLABICS THWA","	* Beaver Dene (TYA)"},
/* 18E5 */ { "CANADIAN SYLLABICS TTHWE","	* Beaver Dene (HYE)"},
/* 18E6 */ { "CANADIAN SYLLABICS TTHOO","	* Chipewyan Dene (TTHU)"},
/* 18E7 */ { "CANADIAN SYLLABICS TTHAA","	* Beaver Dene (HAI)"},
/* 18E8 */ { "CANADIAN SYLLABICS TLHWE","	* Beaver Dene (TLYE)"},
/* 18E9 */ { "CANADIAN SYLLABICS TLHOO","	* Chipewyan Dene (TLU)"},
/* 18EA */ { "CANADIAN SYLLABICS SAYISI SHWE","	* Beaver Dene (ZYE)"},
/* 18EB */ { "CANADIAN SYLLABICS SAYISI SHOO","	* Chipewyan Dene (SHU)"},
/* 18EC */ { "CANADIAN SYLLABICS SAYISI HOO","	* Chipewyan Dene (GU)"},
/* 18ED */ { "CANADIAN SYLLABICS CARRIER GWU","	* Beaver Dene (CHYE)"},
/* 18EE */ { "CANADIAN SYLLABICS CARRIER DENE GEE","	* Chipewyan Dene (CHU)"},
/* 18EF */ { "CANADIAN SYLLABICS CARRIER GAA","	* Beaver Dene (CHAI)"},
/* 18F0 */ { "CANADIAN SYLLABICS CARRIER GWA","	* Hare Dene (SHYA)"},
/* 18F1 */ { "CANADIAN SYLLABICS SAYISI JUU","	* Chipewyan Dene (TSU)"},
/* 18F2 */ { "CANADIAN SYLLABICS CARRIER JWA","	* Beaver Dene (TSYE)"},
/* 18F3 */ { "CANADIAN SYLLABICS BEAVER DENE L",NULL},
/* 18F4 */ { "CANADIAN SYLLABICS BEAVER DENE R",NULL},
/* 18F5 */ { "CANADIAN SYLLABICS CARRIER DENTAL S",NULL},
/* 18F6 */ { NULL,NULL},
/* 18F7 */ { NULL,NULL},
/* 18F8 */ { NULL,NULL},
/* 18F9 */ { NULL,NULL},
/* 18FA */ { NULL,NULL},
/* 18FB */ { NULL,NULL},
/* 18FC */ { NULL,NULL},
/* 18FD */ { NULL,NULL},
/* 18FE */ { NULL,NULL},
/* 18FF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_00_19[] = {
/* 1900 */ { "LIMBU VOWEL-CARRIER LETTER",NULL},
/* 1901 */ { "LIMBU LETTER KA",NULL},
/* 1902 */ { "LIMBU LETTER KHA",NULL},
/* 1903 */ { "LIMBU LETTER GA",NULL},
/* 1904 */ { "LIMBU LETTER GHA",NULL},
/* 1905 */ { "LIMBU LETTER NGA",NULL},
/* 1906 */ { "LIMBU LETTER CA",NULL},
/* 1907 */ { "LIMBU LETTER CHA",NULL},
/* 1908 */ { "LIMBU LETTER JA",NULL},
/* 1909 */ { "LIMBU LETTER JHA",NULL},
/* 190A */ { "LIMBU LETTER YAN",NULL},
/* 190B */ { "LIMBU LETTER TA",NULL},
/* 190C */ { "LIMBU LETTER THA",NULL},
/* 190D */ { "LIMBU LETTER DA",NULL},
/* 190E */ { "LIMBU LETTER DHA",NULL},
/* 190F */ { "LIMBU LETTER NA",NULL},
/* 1910 */ { "LIMBU LETTER PA",NULL},
/* 1911 */ { "LIMBU LETTER PHA",NULL},
/* 1912 */ { "LIMBU LETTER BA",NULL},
/* 1913 */ { "LIMBU LETTER BHA",NULL},
/* 1914 */ { "LIMBU LETTER MA",NULL},
/* 1915 */ { "LIMBU LETTER YA",NULL},
/* 1916 */ { "LIMBU LETTER RA",NULL},
/* 1917 */ { "LIMBU LETTER LA",NULL},
/* 1918 */ { "LIMBU LETTER WA",NULL},
/* 1919 */ { "LIMBU LETTER SHA",NULL},
/* 191A */ { "LIMBU LETTER SSA",NULL},
/* 191B */ { "LIMBU LETTER SA",NULL},
/* 191C */ { "LIMBU LETTER HA",NULL},
/* 191D */ { "LIMBU LETTER GYAN","	= jnya"},
/* 191E */ { "LIMBU LETTER TRA",NULL},
/* 191F */ { NULL,NULL},
/* 1920 */ { "LIMBU VOWEL SIGN A",NULL},
/* 1921 */ { "LIMBU VOWEL SIGN I",NULL},
/* 1922 */ { "LIMBU VOWEL SIGN U",NULL},
/* 1923 */ { "LIMBU VOWEL SIGN EE",NULL},
/* 1924 */ { "LIMBU VOWEL SIGN AI",NULL},
/* 1925 */ { "LIMBU VOWEL SIGN OO",NULL},
/* 1926 */ { "LIMBU VOWEL SIGN AU",NULL},
/* 1927 */ { "LIMBU VOWEL SIGN E",NULL},
/* 1928 */ { "LIMBU VOWEL SIGN O",NULL},
/* 1929 */ { "LIMBU SUBJOINED LETTER YA",NULL},
/* 192A */ { "LIMBU SUBJOINED LETTER RA",NULL},
/* 192B */ { "LIMBU SUBJOINED LETTER WA",NULL},
/* 192C */ { NULL,NULL},
/* 192D */ { NULL,NULL},
/* 192E */ { NULL,NULL},
/* 192F */ { NULL,NULL},
/* 1930 */ { "LIMBU SMALL LETTER KA",NULL},
/* 1931 */ { "LIMBU SMALL LETTER NGA",NULL},
/* 1932 */ { "LIMBU SMALL LETTER ANUSVARA",NULL},
/* 1933 */ { "LIMBU SMALL LETTER TA",NULL},
/* 1934 */ { "LIMBU SMALL LETTER NA",NULL},
/* 1935 */ { "LIMBU SMALL LETTER PA",NULL},
/* 1936 */ { "LIMBU SMALL LETTER MA",NULL},
/* 1937 */ { "LIMBU SMALL LETTER RA",NULL},
/* 1938 */ { "LIMBU SMALL LETTER LA",NULL},
/* 1939 */ { "LIMBU SIGN MUKPHRENG",NULL},
/* 193A */ { "LIMBU SIGN KEMPHRENG",NULL},
/* 193B */ { "LIMBU SIGN SA-I",NULL},
/* 193C */ { NULL,NULL},
/* 193D */ { NULL,NULL},
/* 193E */ { NULL,NULL},
/* 193F */ { NULL,NULL},
/* 1940 */ { "LIMBU SIGN LOO",NULL},
/* 1941 */ { NULL,NULL},
/* 1942 */ { NULL,NULL},
/* 1943 */ { NULL,NULL},
/* 1944 */ { "LIMBU EXCLAMATION MARK",NULL},
/* 1945 */ { "LIMBU QUESTION MARK",NULL},
/* 1946 */ { "LIMBU DIGIT ZERO",NULL},
/* 1947 */ { "LIMBU DIGIT ONE",NULL},
/* 1948 */ { "LIMBU DIGIT TWO",NULL},
/* 1949 */ { "LIMBU DIGIT THREE",NULL},
/* 194A */ { "LIMBU DIGIT FOUR",NULL},
/* 194B */ { "LIMBU DIGIT FIVE",NULL},
/* 194C */ { "LIMBU DIGIT SIX",NULL},
/* 194D */ { "LIMBU DIGIT SEVEN",NULL},
/* 194E */ { "LIMBU DIGIT EIGHT",NULL},
/* 194F */ { "LIMBU DIGIT NINE",NULL},
/* 1950 */ { "TAI LE LETTER KA",NULL},
/* 1951 */ { "TAI LE LETTER XA",NULL},
/* 1952 */ { "TAI LE LETTER NGA",NULL},
/* 1953 */ { "TAI LE LETTER TSA",NULL},
/* 1954 */ { "TAI LE LETTER SA",NULL},
/* 1955 */ { "TAI LE LETTER YA",NULL},
/* 1956 */ { "TAI LE LETTER TA",NULL},
/* 1957 */ { "TAI LE LETTER THA",NULL},
/* 1958 */ { "TAI LE LETTER LA",NULL},
/* 1959 */ { "TAI LE LETTER PA",NULL},
/* 195A */ { "TAI LE LETTER PHA",NULL},
/* 195B */ { "TAI LE LETTER MA",NULL},
/* 195C */ { "TAI LE LETTER FA",NULL},
/* 195D */ { "TAI LE LETTER VA",NULL},
/* 195E */ { "TAI LE LETTER HA",NULL},
/* 195F */ { "TAI LE LETTER QA",NULL},
/* 1960 */ { "TAI LE LETTER KHA",NULL},
/* 1961 */ { "TAI LE LETTER TSHA",NULL},
/* 1962 */ { "TAI LE LETTER NA",NULL},
/* 1963 */ { "TAI LE LETTER A",NULL},
/* 1964 */ { "TAI LE LETTER I",NULL},
/* 1965 */ { "TAI LE LETTER EE",NULL},
/* 1966 */ { "TAI LE LETTER EH",NULL},
/* 1967 */ { "TAI LE LETTER U",NULL},
/* 1968 */ { "TAI LE LETTER OO",NULL},
/* 1969 */ { "TAI LE LETTER O",NULL},
/* 196A */ { "TAI LE LETTER UE",NULL},
/* 196B */ { "TAI LE LETTER E",NULL},
/* 196C */ { "TAI LE LETTER AUE",NULL},
/* 196D */ { "TAI LE LETTER AI",NULL},
/* 196E */ { NULL,NULL},
/* 196F */ { NULL,NULL},
/* 1970 */ { "TAI LE LETTER TONE-2",NULL},
/* 1971 */ { "TAI LE LETTER TONE-3",NULL},
/* 1972 */ { "TAI LE LETTER TONE-4",NULL},
/* 1973 */ { "TAI LE LETTER TONE-5",NULL},
/* 1974 */ { "TAI LE LETTER TONE-6",NULL},
/* 1975 */ { NULL,NULL},
/* 1976 */ { NULL,NULL},
/* 1977 */ { NULL,NULL},
/* 1978 */ { NULL,NULL},
/* 1979 */ { NULL,NULL},
/* 197A */ { NULL,NULL},
/* 197B */ { NULL,NULL},
/* 197C */ { NULL,NULL},
/* 197D */ { NULL,NULL},
/* 197E */ { NULL,NULL},
/* 197F */ { NULL,NULL},
/* 1980 */ { "NEW TAI LUE LETTER HIGH QA",NULL},
/* 1981 */ { "NEW TAI LUE LETTER LOW QA",NULL},
/* 1982 */ { "NEW TAI LUE LETTER HIGH KA",NULL},
/* 1983 */ { "NEW TAI LUE LETTER HIGH XA",NULL},
/* 1984 */ { "NEW TAI LUE LETTER HIGH NGA",NULL},
/* 1985 */ { "NEW TAI LUE LETTER LOW KA",NULL},
/* 1986 */ { "NEW TAI LUE LETTER LOW XA",NULL},
/* 1987 */ { "NEW TAI LUE LETTER LOW NGA",NULL},
/* 1988 */ { "NEW TAI LUE LETTER HIGH TSA",NULL},
/* 1989 */ { "NEW TAI LUE LETTER HIGH SA",NULL},
/* 198A */ { "NEW TAI LUE LETTER HIGH YA",NULL},
/* 198B */ { "NEW TAI LUE LETTER LOW TSA",NULL},
/* 198C */ { "NEW TAI LUE LETTER LOW SA",NULL},
/* 198D */ { "NEW TAI LUE LETTER LOW YA",NULL},
/* 198E */ { "NEW TAI LUE LETTER HIGH TA",NULL},
/* 198F */ { "NEW TAI LUE LETTER HIGH THA",NULL},
/* 1990 */ { "NEW TAI LUE LETTER HIGH NA",NULL},
/* 1991 */ { "NEW TAI LUE LETTER LOW TA",NULL},
/* 1992 */ { "NEW TAI LUE LETTER LOW THA",NULL},
/* 1993 */ { "NEW TAI LUE LETTER LOW NA",NULL},
/* 1994 */ { "NEW TAI LUE LETTER HIGH PA",NULL},
/* 1995 */ { "NEW TAI LUE LETTER HIGH PHA",NULL},
/* 1996 */ { "NEW TAI LUE LETTER HIGH MA",NULL},
/* 1997 */ { "NEW TAI LUE LETTER LOW PA",NULL},
/* 1998 */ { "NEW TAI LUE LETTER LOW PHA",NULL},
/* 1999 */ { "NEW TAI LUE LETTER LOW MA",NULL},
/* 199A */ { "NEW TAI LUE LETTER HIGH FA",NULL},
/* 199B */ { "NEW TAI LUE LETTER HIGH VA",NULL},
/* 199C */ { "NEW TAI LUE LETTER HIGH LA",NULL},
/* 199D */ { "NEW TAI LUE LETTER LOW FA",NULL},
/* 199E */ { "NEW TAI LUE LETTER LOW VA",NULL},
/* 199F */ { "NEW TAI LUE LETTER LOW LA",NULL},
/* 19A0 */ { "NEW TAI LUE LETTER HIGH HA",NULL},
/* 19A1 */ { "NEW TAI LUE LETTER HIGH DA",NULL},
/* 19A2 */ { "NEW TAI LUE LETTER HIGH BA",NULL},
/* 19A3 */ { "NEW TAI LUE LETTER LOW HA",NULL},
/* 19A4 */ { "NEW TAI LUE LETTER LOW DA",NULL},
/* 19A5 */ { "NEW TAI LUE LETTER LOW BA",NULL},
/* 19A6 */ { "NEW TAI LUE LETTER HIGH KVA",NULL},
/* 19A7 */ { "NEW TAI LUE LETTER HIGH XVA",NULL},
/* 19A8 */ { "NEW TAI LUE LETTER LOW KVA",NULL},
/* 19A9 */ { "NEW TAI LUE LETTER LOW XVA",NULL},
/* 19AA */ { "NEW TAI LUE LETTER HIGH SUA",NULL},
/* 19AB */ { "NEW TAI LUE LETTER LOW SUA","	* a labialized consonant cluster"},
/* 19AC */ { NULL,NULL},
/* 19AD */ { NULL,NULL},
/* 19AE */ { NULL,NULL},
/* 19AF */ { NULL,NULL},
/* 19B0 */ { "NEW TAI LUE VOWEL SIGN VOWEL SHORTENER",NULL},
/* 19B1 */ { "NEW TAI LUE VOWEL SIGN AA",NULL},
/* 19B2 */ { "NEW TAI LUE VOWEL SIGN II",NULL},
/* 19B3 */ { "NEW TAI LUE VOWEL SIGN U",NULL},
/* 19B4 */ { "NEW TAI LUE VOWEL SIGN UU",NULL},
/* 19B5 */ { "NEW TAI LUE VOWEL SIGN E","	* precedes consonant in visual order"},
/* 19B6 */ { "NEW TAI LUE VOWEL SIGN AE","	* precedes consonant in visual order"},
/* 19B7 */ { "NEW TAI LUE VOWEL SIGN O","	* precedes consonant in visual order"},
/* 19B8 */ { "NEW TAI LUE VOWEL SIGN OA",NULL},
/* 19B9 */ { "NEW TAI LUE VOWEL SIGN UE",NULL},
/* 19BA */ { "NEW TAI LUE VOWEL SIGN AY","	* precedes consonant in visual order"},
/* 19BB */ { "NEW TAI LUE VOWEL SIGN AAY",NULL},
/* 19BC */ { "NEW TAI LUE VOWEL SIGN UY",NULL},
/* 19BD */ { "NEW TAI LUE VOWEL SIGN OY",NULL},
/* 19BE */ { "NEW TAI LUE VOWEL SIGN OAY",NULL},
/* 19BF */ { "NEW TAI LUE VOWEL SIGN UEY",NULL},
/* 19C0 */ { "NEW TAI LUE VOWEL SIGN IY",NULL},
/* 19C1 */ { "NEW TAI LUE LETTER FINAL V",NULL},
/* 19C2 */ { "NEW TAI LUE LETTER FINAL NG",NULL},
/* 19C3 */ { "NEW TAI LUE LETTER FINAL N",NULL},
/* 19C4 */ { "NEW TAI LUE LETTER FINAL M",NULL},
/* 19C5 */ { "NEW TAI LUE LETTER FINAL K",NULL},
/* 19C6 */ { "NEW TAI LUE LETTER FINAL D",NULL},
/* 19C7 */ { "NEW TAI LUE LETTER FINAL B",NULL},
/* 19C8 */ { "NEW TAI LUE TONE MARK-1",NULL},
/* 19C9 */ { "NEW TAI LUE TONE MARK-2",NULL},
/* 19CA */ { NULL,NULL},
/* 19CB */ { NULL,NULL},
/* 19CC */ { NULL,NULL},
/* 19CD */ { NULL,NULL},
/* 19CE */ { NULL,NULL},
/* 19CF */ { NULL,NULL},
/* 19D0 */ { "NEW TAI LUE DIGIT ZERO",NULL},
/* 19D1 */ { "NEW TAI LUE DIGIT ONE",NULL},
/* 19D2 */ { "NEW TAI LUE DIGIT TWO",NULL},
/* 19D3 */ { "NEW TAI LUE DIGIT THREE",NULL},
/* 19D4 */ { "NEW TAI LUE DIGIT FOUR",NULL},
/* 19D5 */ { "NEW TAI LUE DIGIT FIVE",NULL},
/* 19D6 */ { "NEW TAI LUE DIGIT SIX",NULL},
/* 19D7 */ { "NEW TAI LUE DIGIT SEVEN",NULL},
/* 19D8 */ { "NEW TAI LUE DIGIT EIGHT",NULL},
/* 19D9 */ { "NEW TAI LUE DIGIT NINE",NULL},
/* 19DA */ { "NEW TAI LUE THAM DIGIT ONE",NULL},
/* 19DB */ { NULL,NULL},
/* 19DC */ { NULL,NULL},
/* 19DD */ { NULL,NULL},
/* 19DE */ { "NEW TAI LUE SIGN LAE","	* conjunction: and"},
/* 19DF */ { "NEW TAI LUE SIGN LAEV","	* perfective"},
/* 19E0 */ { "KHMER SYMBOL PATHAMASAT","	* represents the first Ashadha (eighth month of the lunar calendar)\n"
	"		The following fifteen characters represent the first through the fifteenth waxing days, respectively."},
/* 19E1 */ { "KHMER SYMBOL MUOY KOET",NULL},
/* 19E2 */ { "KHMER SYMBOL PII KOET",NULL},
/* 19E3 */ { "KHMER SYMBOL BEI KOET",NULL},
/* 19E4 */ { "KHMER SYMBOL BUON KOET",NULL},
/* 19E5 */ { "KHMER SYMBOL PRAM KOET",NULL},
/* 19E6 */ { "KHMER SYMBOL PRAM-MUOY KOET",NULL},
/* 19E7 */ { "KHMER SYMBOL PRAM-PII KOET",NULL},
/* 19E8 */ { "KHMER SYMBOL PRAM-BEI KOET",NULL},
/* 19E9 */ { "KHMER SYMBOL PRAM-BUON KOET",NULL},
/* 19EA */ { "KHMER SYMBOL DAP KOET",NULL},
/* 19EB */ { "KHMER SYMBOL DAP-MUOY KOET",NULL},
/* 19EC */ { "KHMER SYMBOL DAP-PII KOET",NULL},
/* 19ED */ { "KHMER SYMBOL DAP-BEI KOET",NULL},
/* 19EE */ { "KHMER SYMBOL DAP-BUON KOET",NULL},
/* 19EF */ { "KHMER SYMBOL DAP-PRAM KOET",NULL},
/* 19F0 */ { "KHMER SYMBOL TUTEYASAT","	* represents the second Ashadha in the lunar calendar during the Adhikameas leap year\n"
	"		The following fifteen characters represent the first through the fifteenth waning days, respectively."},
/* 19F1 */ { "KHMER SYMBOL MUOY ROC",NULL},
/* 19F2 */ { "KHMER SYMBOL PII ROC",NULL},
/* 19F3 */ { "KHMER SYMBOL BEI ROC",NULL},
/* 19F4 */ { "KHMER SYMBOL BUON ROC",NULL},
/* 19F5 */ { "KHMER SYMBOL PRAM ROC",NULL},
/* 19F6 */ { "KHMER SYMBOL PRAM-MUOY ROC",NULL},
/* 19F7 */ { "KHMER SYMBOL PRAM-PII ROC",NULL},
/* 19F8 */ { "KHMER SYMBOL PRAM-BEI ROC",NULL},
/* 19F9 */ { "KHMER SYMBOL PRAM-BUON ROC",NULL},
/* 19FA */ { "KHMER SYMBOL DAP ROC",NULL},
/* 19FB */ { "KHMER SYMBOL DAP-MUOY ROC",NULL},
/* 19FC */ { "KHMER SYMBOL DAP-PII ROC",NULL},
/* 19FD */ { "KHMER SYMBOL DAP-BEI ROC",NULL},
/* 19FE */ { "KHMER SYMBOL DAP-BUON ROC",NULL},
/* 19FF */ { "KHMER SYMBOL DAP-PRAM ROC",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_00_1A[] = {
/* 1A00 */ { "BUGINESE LETTER KA",NULL},
/* 1A01 */ { "BUGINESE LETTER GA",NULL},
/* 1A02 */ { "BUGINESE LETTER NGA",NULL},
/* 1A03 */ { "BUGINESE LETTER NGKA",NULL},
/* 1A04 */ { "BUGINESE LETTER PA",NULL},
/* 1A05 */ { "BUGINESE LETTER BA",NULL},
/* 1A06 */ { "BUGINESE LETTER MA",NULL},
/* 1A07 */ { "BUGINESE LETTER MPA",NULL},
/* 1A08 */ { "BUGINESE LETTER TA",NULL},
/* 1A09 */ { "BUGINESE LETTER DA",NULL},
/* 1A0A */ { "BUGINESE LETTER NA",NULL},
/* 1A0B */ { "BUGINESE LETTER NRA",NULL},
/* 1A0C */ { "BUGINESE LETTER CA",NULL},
/* 1A0D */ { "BUGINESE LETTER JA",NULL},
/* 1A0E */ { "BUGINESE LETTER NYA",NULL},
/* 1A0F */ { "BUGINESE LETTER NYCA",NULL},
/* 1A10 */ { "BUGINESE LETTER YA",NULL},
/* 1A11 */ { "BUGINESE LETTER RA",NULL},
/* 1A12 */ { "BUGINESE LETTER LA",NULL},
/* 1A13 */ { "BUGINESE LETTER VA",NULL},
/* 1A14 */ { "BUGINESE LETTER SA",NULL},
/* 1A15 */ { "BUGINESE LETTER A",NULL},
/* 1A16 */ { "BUGINESE LETTER HA",NULL},
/* 1A17 */ { "BUGINESE VOWEL SIGN I",NULL},
/* 1A18 */ { "BUGINESE VOWEL SIGN U",NULL},
/* 1A19 */ { "BUGINESE VOWEL SIGN E",NULL},
/* 1A1A */ { "BUGINESE VOWEL SIGN O",NULL},
/* 1A1B */ { "BUGINESE VOWEL SIGN AE",NULL},
/* 1A1C */ { NULL,NULL},
/* 1A1D */ { NULL,NULL},
/* 1A1E */ { "BUGINESE PALLAWA",NULL},
/* 1A1F */ { "BUGINESE END OF SECTION",NULL},
/* 1A20 */ { "TAI THAM LETTER HIGH KA",NULL},
/* 1A21 */ { "TAI THAM LETTER HIGH KHA",NULL},
/* 1A22 */ { "TAI THAM LETTER HIGH KXA",NULL},
/* 1A23 */ { "TAI THAM LETTER LOW KA",NULL},
/* 1A24 */ { "TAI THAM LETTER LOW KXA",NULL},
/* 1A25 */ { "TAI THAM LETTER LOW KHA",NULL},
/* 1A26 */ { "TAI THAM LETTER NGA",NULL},
/* 1A27 */ { "TAI THAM LETTER HIGH CA",NULL},
/* 1A28 */ { "TAI THAM LETTER HIGH CHA",NULL},
/* 1A29 */ { "TAI THAM LETTER LOW CA",NULL},
/* 1A2A */ { "TAI THAM LETTER LOW SA",NULL},
/* 1A2B */ { "TAI THAM LETTER LOW CHA",NULL},
/* 1A2C */ { "TAI THAM LETTER NYA",NULL},
/* 1A2D */ { "TAI THAM LETTER RATA",NULL},
/* 1A2E */ { "TAI THAM LETTER HIGH RATHA","	* an alternative glyph with the upper part shaped like 1A33 is used in Thailand and Laos\n"
	"	* contrast the sequence 1A2D 1A5B"},
/* 1A2F */ { "TAI THAM LETTER DA",NULL},
/* 1A30 */ { "TAI THAM LETTER LOW RATHA",NULL},
/* 1A31 */ { "TAI THAM LETTER RANA",NULL},
/* 1A32 */ { "TAI THAM LETTER HIGH TA",NULL},
/* 1A33 */ { "TAI THAM LETTER HIGH THA",NULL},
/* 1A34 */ { "TAI THAM LETTER LOW TA",NULL},
/* 1A35 */ { "TAI THAM LETTER LOW THA",NULL},
/* 1A36 */ { "TAI THAM LETTER NA",NULL},
/* 1A37 */ { "TAI THAM LETTER BA",NULL},
/* 1A38 */ { "TAI THAM LETTER HIGH PA",NULL},
/* 1A39 */ { "TAI THAM LETTER HIGH PHA",NULL},
/* 1A3A */ { "TAI THAM LETTER HIGH FA",NULL},
/* 1A3B */ { "TAI THAM LETTER LOW PA",NULL},
/* 1A3C */ { "TAI THAM LETTER LOW FA",NULL},
/* 1A3D */ { "TAI THAM LETTER LOW PHA",NULL},
/* 1A3E */ { "TAI THAM LETTER MA",NULL},
/* 1A3F */ { "TAI THAM LETTER LOW YA",NULL},
/* 1A40 */ { "TAI THAM LETTER HIGH YA",NULL},
/* 1A41 */ { "TAI THAM LETTER RA",NULL},
/* 1A42 */ { "TAI THAM LETTER RUE",NULL},
/* 1A43 */ { "TAI THAM LETTER LA",NULL},
/* 1A44 */ { "TAI THAM LETTER LUE",NULL},
/* 1A45 */ { "TAI THAM LETTER WA",NULL},
/* 1A46 */ { "TAI THAM LETTER HIGH SHA",NULL},
/* 1A47 */ { "TAI THAM LETTER HIGH SSA",NULL},
/* 1A48 */ { "TAI THAM LETTER HIGH SA",NULL},
/* 1A49 */ { "TAI THAM LETTER HIGH HA",NULL},
/* 1A4A */ { "TAI THAM LETTER LLA",NULL},
/* 1A4B */ { "TAI THAM LETTER A","	* indicates a glottal consonant"},
/* 1A4C */ { "TAI THAM LETTER LOW HA",NULL},
/* 1A4D */ { "TAI THAM LETTER I",NULL},
/* 1A4E */ { "TAI THAM LETTER II",NULL},
/* 1A4F */ { "TAI THAM LETTER U",NULL},
/* 1A50 */ { "TAI THAM LETTER UU",NULL},
/* 1A51 */ { "TAI THAM LETTER EE",NULL},
/* 1A52 */ { "TAI THAM LETTER OO",NULL},
/* 1A53 */ { "TAI THAM LETTER LAE",NULL},
/* 1A54 */ { "TAI THAM LETTER GREAT SA",NULL},
/* 1A55 */ { "TAI THAM CONSONANT SIGN MEDIAL RA",NULL},
/* 1A56 */ { "TAI THAM CONSONANT SIGN MEDIAL LA",NULL},
/* 1A57 */ { "TAI THAM CONSONANT SIGN LA TANG LAI",NULL},
/* 1A58 */ { "TAI THAM SIGN MAI KANG LAI",NULL},
/* 1A59 */ { "TAI THAM CONSONANT SIGN FINAL NGA",NULL},
/* 1A5A */ { "TAI THAM CONSONANT SIGN LOW PA",NULL},
/* 1A5B */ { "TAI THAM CONSONANT SIGN HIGH RATHA OR LOW PA",NULL},
/* 1A5C */ { "TAI THAM CONSONANT SIGN MA",NULL},
/* 1A5D */ { "TAI THAM CONSONANT SIGN BA",NULL},
/* 1A5E */ { "TAI THAM CONSONANT SIGN SA",NULL},
/* 1A5F */ { NULL,NULL},
/* 1A60 */ { "TAI THAM SIGN SAKOT",NULL},
/* 1A61 */ { "TAI THAM VOWEL SIGN A",NULL},
/* 1A62 */ { "TAI THAM VOWEL SIGN MAI SAT",NULL},
/* 1A63 */ { "TAI THAM VOWEL SIGN AA",NULL},
/* 1A64 */ { "TAI THAM VOWEL SIGN TALL AA",NULL},
/* 1A65 */ { "TAI THAM VOWEL SIGN I",NULL},
/* 1A66 */ { "TAI THAM VOWEL SIGN II",NULL},
/* 1A67 */ { "TAI THAM VOWEL SIGN UE",NULL},
/* 1A68 */ { "TAI THAM VOWEL SIGN UUE",NULL},
/* 1A69 */ { "TAI THAM VOWEL SIGN U",NULL},
/* 1A6A */ { "TAI THAM VOWEL SIGN UU",NULL},
/* 1A6B */ { "TAI THAM VOWEL SIGN O",NULL},
/* 1A6C */ { "TAI THAM VOWEL SIGN OA BELOW",NULL},
/* 1A6D */ { "TAI THAM VOWEL SIGN OY",NULL},
/* 1A6E */ { "TAI THAM VOWEL SIGN E",NULL},
/* 1A6F */ { "TAI THAM VOWEL SIGN AE",NULL},
/* 1A70 */ { "TAI THAM VOWEL SIGN OO",NULL},
/* 1A71 */ { "TAI THAM VOWEL SIGN AI",NULL},
/* 1A72 */ { "TAI THAM VOWEL SIGN THAM AI",NULL},
/* 1A73 */ { "TAI THAM VOWEL SIGN OA ABOVE",NULL},
/* 1A74 */ { "TAI THAM SIGN MAI KANG",NULL},
/* 1A75 */ { "TAI THAM SIGN TONE-1",NULL},
/* 1A76 */ { "TAI THAM SIGN TONE-2",NULL},
/* 1A77 */ { "TAI THAM SIGN KHUEN TONE-3",NULL},
/* 1A78 */ { "TAI THAM SIGN KHUEN TONE-4",NULL},
/* 1A79 */ { "TAI THAM SIGN KHUEN TONE-5",NULL},
/* 1A7A */ { "TAI THAM SIGN RA HAAM","	* indicates following character(s) are not sounded"},
/* 1A7B */ { "TAI THAM SIGN MAI SAM",NULL},
/* 1A7C */ { "TAI THAM SIGN KHUEN-LUE KARAN",NULL},
/* 1A7D */ { NULL,NULL},
/* 1A7E */ { NULL,NULL},
/* 1A7F */ { "TAI THAM COMBINING CRYPTOGRAMMIC DOT",NULL},
/* 1A80 */ { "TAI THAM HORA DIGIT ZERO",NULL},
/* 1A81 */ { "TAI THAM HORA DIGIT ONE",NULL},
/* 1A82 */ { "TAI THAM HORA DIGIT TWO",NULL},
/* 1A83 */ { "TAI THAM HORA DIGIT THREE",NULL},
/* 1A84 */ { "TAI THAM HORA DIGIT FOUR",NULL},
/* 1A85 */ { "TAI THAM HORA DIGIT FIVE",NULL},
/* 1A86 */ { "TAI THAM HORA DIGIT SIX",NULL},
/* 1A87 */ { "TAI THAM HORA DIGIT SEVEN",NULL},
/* 1A88 */ { "TAI THAM HORA DIGIT EIGHT",NULL},
/* 1A89 */ { "TAI THAM HORA DIGIT NINE",NULL},
/* 1A8A */ { NULL,NULL},
/* 1A8B */ { NULL,NULL},
/* 1A8C */ { NULL,NULL},
/* 1A8D */ { NULL,NULL},
/* 1A8E */ { NULL,NULL},
/* 1A8F */ { NULL,NULL},
/* 1A90 */ { "TAI THAM THAM DIGIT ZERO",NULL},
/* 1A91 */ { "TAI THAM THAM DIGIT ONE",NULL},
/* 1A92 */ { "TAI THAM THAM DIGIT TWO",NULL},
/* 1A93 */ { "TAI THAM THAM DIGIT THREE",NULL},
/* 1A94 */ { "TAI THAM THAM DIGIT FOUR",NULL},
/* 1A95 */ { "TAI THAM THAM DIGIT FIVE",NULL},
/* 1A96 */ { "TAI THAM THAM DIGIT SIX",NULL},
/* 1A97 */ { "TAI THAM THAM DIGIT SEVEN",NULL},
/* 1A98 */ { "TAI THAM THAM DIGIT EIGHT",NULL},
/* 1A99 */ { "TAI THAM THAM DIGIT NINE",NULL},
/* 1A9A */ { NULL,NULL},
/* 1A9B */ { NULL,NULL},
/* 1A9C */ { NULL,NULL},
/* 1A9D */ { NULL,NULL},
/* 1A9E */ { NULL,NULL},
/* 1A9F */ { NULL,NULL},
/* 1AA0 */ { "TAI THAM SIGN WIANG","	* logograph for city"},
/* 1AA1 */ { "TAI THAM SIGN WIANGWAAK","	* logograph for village"},
/* 1AA2 */ { "TAI THAM SIGN SAWAN","	* logograph for heaven"},
/* 1AA3 */ { "TAI THAM SIGN KEOW","	= courtyard"},
/* 1AA4 */ { "TAI THAM SIGN HOY","	= oyster"},
/* 1AA5 */ { "TAI THAM SIGN DOKMAI","	= flower\n"
	"	x (flower punctuation mark - 2055)"},
/* 1AA6 */ { "TAI THAM SIGN REVERSED ROTATED RANA",NULL},
/* 1AA7 */ { "TAI THAM SIGN MAI YAMOK","	x (thai character maiyamok - 0E46)"},
/* 1AA8 */ { "TAI THAM SIGN KAAN","	* danda"},
/* 1AA9 */ { "TAI THAM SIGN KAANKUU","	* double danda"},
/* 1AAA */ { "TAI THAM SIGN SATKAAN",NULL},
/* 1AAB */ { "TAI THAM SIGN SATKAANKUU","	x (thai character angkhankhu - 0E5A)"},
/* 1AAC */ { "TAI THAM SIGN HANG","	* used in combinations with other punctuation marks at ends of sections"},
/* 1AAD */ { "TAI THAM SIGN CAANG",NULL},
/* 1AAE */ { NULL,NULL},
/* 1AAF */ { NULL,NULL},
/* 1AB0 */ { "COMBINING DOUBLED CIRCUMFLEX ACCENT",NULL},
/* 1AB1 */ { "COMBINING DIAERESIS-RING",NULL},
/* 1AB2 */ { "COMBINING INFINITY",NULL},
/* 1AB3 */ { "COMBINING DOWNWARDS ARROW","	* originally a misconstrual of a caron-acute sequence in Croatian dialectology\n"
	"	* for Croatian dialectology use the sequence 030C 0301, instead"},
/* 1AB4 */ { "COMBINING TRIPLE DOT",NULL},
/* 1AB5 */ { "COMBINING X-X BELOW",NULL},
/* 1AB6 */ { "COMBINING WIGGLY LINE BELOW",NULL},
/* 1AB7 */ { "COMBINING OPEN MARK BELOW","	x (combining ogonek - 0328)\n"
	"	x (combining greek ypogegrammeni - 0345)"},
/* 1AB8 */ { "COMBINING DOUBLE OPEN MARK BELOW",NULL},
/* 1AB9 */ { "COMBINING LIGHT CENTRALIZATION STROKE BELOW",NULL},
/* 1ABA */ { "COMBINING STRONG CENTRALIZATION STROKE BELOW",NULL},
/* 1ABB */ { "COMBINING PARENTHESES ABOVE","	* intended to surround a diacritic above"},
/* 1ABC */ { "COMBINING DOUBLE PARENTHESES ABOVE",NULL},
/* 1ABD */ { "COMBINING PARENTHESES BELOW","	* intended to surround a diacritic below"},
/* 1ABE */ { "COMBINING PARENTHESES OVERLAY","	* intended to surround a base letter\n"
	"	* exact placement is font dependent"},
/* 1ABF */ { "COMBINING LATIN SMALL LETTER W BELOW","	* indicates voiced labialization\n"
	"	x (modifier letter small w - 02B7)"},
/* 1AC0 */ { "COMBINING LATIN SMALL LETTER TURNED W BELOW","	* indicates voiceless labialization"},
/* 1AC1 */ { "COMBINING LEFT PARENTHESIS ABOVE LEFT",NULL},
/* 1AC2 */ { "COMBINING RIGHT PARENTHESIS ABOVE RIGHT",NULL},
/* 1AC3 */ { "COMBINING LEFT PARENTHESIS BELOW LEFT",NULL},
/* 1AC4 */ { "COMBINING RIGHT PARENTHESIS BELOW RIGHT",NULL},
/* 1AC5 */ { "COMBINING SQUARE BRACKETS ABOVE","	* intended to surround a diacritic above\n"
	"	* used to indicate cancellation of an accent in Japanese transliteration"},
/* 1AC6 */ { "COMBINING NUMBER SIGN ABOVE","	= superscript octothorp"},
/* 1AC7 */ { "COMBINING INVERTED DOUBLE ARCH ABOVE","	= omega above\n"
	"	x (combining inverted double arch below - 032B)\n"
	"	x (combining latin small letter w - 1DF1)"},
/* 1AC8 */ { "COMBINING PLUS SIGN ABOVE","	x (combining plus sign below - 031F)"},
/* 1AC9 */ { "COMBINING DOUBLE PLUS SIGN ABOVE",NULL},
/* 1ACA */ { "COMBINING DOUBLE PLUS SIGN BELOW",NULL},
/* 1ACB */ { "COMBINING TRIPLE ACUTE ACCENT","	x (combining double acute accent - 030B)"},
/* 1ACC */ { "COMBINING LATIN SMALL LETTER INSULAR G",NULL},
/* 1ACD */ { "COMBINING LATIN SMALL LETTER INSULAR R",NULL},
/* 1ACE */ { "COMBINING LATIN SMALL LETTER INSULAR T",NULL},
/* 1ACF */ { "COMBINING DOUBLE CARON",NULL},
/* 1AD0 */ { "COMBINING VERTICAL-LINE-ACUTE",NULL},
/* 1AD1 */ { "COMBINING GRAVE-VERTICAL-LINE",NULL},
/* 1AD2 */ { "COMBINING VERTICAL-LINE-GRAVE",NULL},
/* 1AD3 */ { "COMBINING ACUTE-VERTICAL-LINE",NULL},
/* 1AD4 */ { "COMBINING VERTICAL-LINE-MACRON",NULL},
/* 1AD5 */ { "COMBINING MACRON-VERTICAL-LINE",NULL},
/* 1AD6 */ { "COMBINING VERTICAL-LINE-ACUTE-GRAVE",NULL},
/* 1AD7 */ { "COMBINING VERTICAL-LINE-GRAVE-ACUTE",NULL},
/* 1AD8 */ { "COMBINING MACRON-ACUTE-GRAVE",NULL},
/* 1AD9 */ { "COMBINING SHARP SIGN",NULL},
/* 1ADA */ { "COMBINING FLAT SIGN",NULL},
/* 1ADB */ { "COMBINING DOWN TACK ABOVE","	x (combining down tack below - 031E)"},
/* 1ADC */ { "COMBINING DIAERESIS WITH RAISED LEFT DOT",NULL},
/* 1ADD */ { "COMBINING DOT-AND-RING BELOW",NULL},
/* 1ADE */ { NULL,NULL},
/* 1ADF */ { NULL,NULL},
/* 1AE0 */ { "COMBINING LEFT TACK ABOVE","	x (combining left tack below - 0318)\n"
	"	x (combining cyrillic psili pneumata - 0486)\n"
	"	x (coptic combining spiritus lenis - 2CF1)"},
/* 1AE1 */ { "COMBINING RIGHT TACK ABOVE","	x (combining right tack below - 0319)\n"
	"	x (combining cyrillic dasia pneumata - 0485)\n"
	"	x (coptic combining spiritus asper - 2CF0)"},
/* 1AE2 */ { "COMBINING MINUS SIGN ABOVE","	x (combining macron - 0304)\n"
	"	x (combining minus sign below - 0320)"},
/* 1AE3 */ { "COMBINING INVERTED BRIDGE ABOVE","	x (combining inverted bridge below - 033A)"},
/* 1AE4 */ { "COMBINING SQUARE ABOVE","	x (combining square below - 033B)"},
/* 1AE5 */ { "COMBINING SEAGULL ABOVE","	x (combining seagull below - 033C)"},
/* 1AE6 */ { "COMBINING DOUBLE ARCH BELOW","	= turned omega below\n"
	"	x (combining inverted double arch below - 032B)\n"
	"	x (combining seagull below - 033C)"},
/* 1AE7 */ { "COMBINING DOUBLE ARCH ABOVE","	= turned omega above"},
/* 1AE8 */ { "COMBINING EQUALS SIGN ABOVE","	x (combining equals sign below - 0347)"},
/* 1AE9 */ { "COMBINING LEFT ANGLE CENTRED ABOVE","	x (combining left angle above - 031A)\n"
	"	x (combining left angle below - 0349)"},
/* 1AEA */ { "COMBINING UPWARDS ARROW ABOVE","	x (combining upwards arrow below - 034E)"},
/* 1AEB */ { "COMBINING DOUBLE RIGHTWARDS ARROW ABOVE","	x (combining double rightwards arrow below - 0362)"},
/* 1AEC */ { NULL,NULL},
/* 1AED */ { NULL,NULL},
/* 1AEE */ { NULL,NULL},
/* 1AEF */ { NULL,NULL},
/* 1AF0 */ { NULL,NULL},
/* 1AF1 */ { NULL,NULL},
/* 1AF2 */ { NULL,NULL},
/* 1AF3 */ { NULL,NULL},
/* 1AF4 */ { NULL,NULL},
/* 1AF5 */ { NULL,NULL},
/* 1AF6 */ { NULL,NULL},
/* 1AF7 */ { NULL,NULL},
/* 1AF8 */ { NULL,NULL},
/* 1AF9 */ { NULL,NULL},
/* 1AFA */ { NULL,NULL},
/* 1AFB */ { NULL,NULL},
/* 1AFC */ { NULL,NULL},
/* 1AFD */ { NULL,NULL},
/* 1AFE */ { NULL,NULL},
/* 1AFF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_00_1B[] = {
/* 1B00 */ { "BALINESE SIGN ULU RICEM","	= ardhacandra"},
/* 1B01 */ { "BALINESE SIGN ULU CANDRA","	= candrabindu"},
/* 1B02 */ { "BALINESE SIGN CECEK","	= anusvara"},
/* 1B03 */ { "BALINESE SIGN SURANG","	= final r\n"
	"	* also used for repha in transliteration of Kawi\n"
	"	x (javanese sign layar - A982)"},
/* 1B04 */ { "BALINESE SIGN BISAH","	= visarga"},
/* 1B05 */ { "BALINESE LETTER AKARA","	= a"},
/* 1B06 */ { "BALINESE LETTER AKARA TEDUNG","	= aa\n"
	"	: 1B05 1B35"},
/* 1B07 */ { "BALINESE LETTER IKARA","	= i"},
/* 1B08 */ { "BALINESE LETTER IKARA TEDUNG","	= ii\n"
	"	: 1B07 1B35"},
/* 1B09 */ { "BALINESE LETTER UKARA","	= u"},
/* 1B0A */ { "BALINESE LETTER UKARA TEDUNG","	= uu\n"
	"	: 1B09 1B35"},
/* 1B0B */ { "BALINESE LETTER RA REPA","	= vocalic r"},
/* 1B0C */ { "BALINESE LETTER RA REPA TEDUNG","	= vocalic rr\n"
	"	: 1B0B 1B35"},
/* 1B0D */ { "BALINESE LETTER LA LENGA","	= vocalic l"},
/* 1B0E */ { "BALINESE LETTER LA LENGA TEDUNG","	= vocalic ll\n"
	"	: 1B0D 1B35"},
/* 1B0F */ { "BALINESE LETTER EKARA","	= e"},
/* 1B10 */ { "BALINESE LETTER AIKARA","	= ai"},
/* 1B11 */ { "BALINESE LETTER OKARA","	= o"},
/* 1B12 */ { "BALINESE LETTER OKARA TEDUNG","	= au\n"
	"	: 1B11 1B35"},
/* 1B13 */ { "BALINESE LETTER KA",NULL},
/* 1B14 */ { "BALINESE LETTER KA MAHAPRANA","	= kha"},
/* 1B15 */ { "BALINESE LETTER GA",NULL},
/* 1B16 */ { "BALINESE LETTER GA GORA","	= gha"},
/* 1B17 */ { "BALINESE LETTER NGA",NULL},
/* 1B18 */ { "BALINESE LETTER CA",NULL},
/* 1B19 */ { "BALINESE LETTER CA LACA","	= cha"},
/* 1B1A */ { "BALINESE LETTER JA",NULL},
/* 1B1B */ { "BALINESE LETTER JA JERA","	= jha"},
/* 1B1C */ { "BALINESE LETTER NYA",NULL},
/* 1B1D */ { "BALINESE LETTER TA LATIK","	= tta"},
/* 1B1E */ { "BALINESE LETTER TA MURDA MAHAPRANA","	= ttha"},
/* 1B1F */ { "BALINESE LETTER DA MURDA ALPAPRANA","	= dda"},
/* 1B20 */ { "BALINESE LETTER DA MURDA MAHAPRANA","	= ddha"},
/* 1B21 */ { "BALINESE LETTER NA RAMBAT","	= nna"},
/* 1B22 */ { "BALINESE LETTER TA",NULL},
/* 1B23 */ { "BALINESE LETTER TA TAWA","	= tha"},
/* 1B24 */ { "BALINESE LETTER DA",NULL},
/* 1B25 */ { "BALINESE LETTER DA MADU","	= dha"},
/* 1B26 */ { "BALINESE LETTER NA",NULL},
/* 1B27 */ { "BALINESE LETTER PA",NULL},
/* 1B28 */ { "BALINESE LETTER PA KAPAL","	= pha"},
/* 1B29 */ { "BALINESE LETTER BA",NULL},
/* 1B2A */ { "BALINESE LETTER BA KEMBANG","	= bha"},
/* 1B2B */ { "BALINESE LETTER MA",NULL},
/* 1B2C */ { "BALINESE LETTER YA",NULL},
/* 1B2D */ { "BALINESE LETTER RA",NULL},
/* 1B2E */ { "BALINESE LETTER LA",NULL},
/* 1B2F */ { "BALINESE LETTER WA",NULL},
/* 1B30 */ { "BALINESE LETTER SA SAGA","	= sha"},
/* 1B31 */ { "BALINESE LETTER SA SAPA","	= ssa"},
/* 1B32 */ { "BALINESE LETTER SA",NULL},
/* 1B33 */ { "BALINESE LETTER HA",NULL},
/* 1B34 */ { "BALINESE SIGN REREKAN","	= nukta"},
/* 1B35 */ { "BALINESE VOWEL SIGN TEDUNG","	= aa"},
/* 1B36 */ { "BALINESE VOWEL SIGN ULU","	= i"},
/* 1B37 */ { "BALINESE VOWEL SIGN ULU SARI","	= ii"},
/* 1B38 */ { "BALINESE VOWEL SIGN SUKU","	= u"},
/* 1B39 */ { "BALINESE VOWEL SIGN SUKU ILUT","	= uu"},
/* 1B3A */ { "BALINESE VOWEL SIGN RA REPA","	= vocalic r"},
/* 1B3B */ { "BALINESE VOWEL SIGN RA REPA TEDUNG","	= vocalic rr\n"
	"	: 1B3A 1B35"},
/* 1B3C */ { "BALINESE VOWEL SIGN LA LENGA","	= vocalic l"},
/* 1B3D */ { "BALINESE VOWEL SIGN LA LENGA TEDUNG","	= vocalic ll\n"
	"	: 1B3C 1B35"},
/* 1B3E */ { "BALINESE VOWEL SIGN TALING","	= e"},
/* 1B3F */ { "BALINESE VOWEL SIGN TALING REPA","	= ai"},
/* 1B40 */ { "BALINESE VOWEL SIGN TALING TEDUNG","	= o\n"
	"	: 1B3E 1B35"},
/* 1B41 */ { "BALINESE VOWEL SIGN TALING REPA TEDUNG","	= au\n"
	"	: 1B3F 1B35"},
/* 1B42 */ { "BALINESE VOWEL SIGN PEPET","	= ae"},
/* 1B43 */ { "BALINESE VOWEL SIGN PEPET TEDUNG","	= oe\n"
	"	: 1B42 1B35"},
/* 1B44 */ { "BALINESE ADEG ADEG","	= virama"},
/* 1B45 */ { "BALINESE LETTER KAF SASAK",NULL},
/* 1B46 */ { "BALINESE LETTER KHOT SASAK",NULL},
/* 1B47 */ { "BALINESE LETTER TZIR SASAK",NULL},
/* 1B48 */ { "BALINESE LETTER EF SASAK",NULL},
/* 1B49 */ { "BALINESE LETTER VE SASAK",NULL},
/* 1B4A */ { "BALINESE LETTER ZAL SASAK",NULL},
/* 1B4B */ { "BALINESE LETTER ASYURA SASAK",NULL},
/* 1B4C */ { "BALINESE LETTER ARCHAIC JNYA","	* used in older texts in place of the ja + nya conjunct\n"
	"	x (javanese letter nya murda - A998)"},
/* 1B4D */ { NULL,NULL},
/* 1B4E */ { "BALINESE INVERTED CARIK SIKI",NULL},
/* 1B4F */ { "BALINESE INVERTED CARIK PAREREN",NULL},
/* 1B50 */ { "BALINESE DIGIT ZERO",NULL},
/* 1B51 */ { "BALINESE DIGIT ONE",NULL},
/* 1B52 */ { "BALINESE DIGIT TWO",NULL},
/* 1B53 */ { "BALINESE DIGIT THREE",NULL},
/* 1B54 */ { "BALINESE DIGIT FOUR",NULL},
/* 1B55 */ { "BALINESE DIGIT FIVE",NULL},
/* 1B56 */ { "BALINESE DIGIT SIX",NULL},
/* 1B57 */ { "BALINESE DIGIT SEVEN",NULL},
/* 1B58 */ { "BALINESE DIGIT EIGHT",NULL},
/* 1B59 */ { "BALINESE DIGIT NINE",NULL},
/* 1B5A */ { "BALINESE PANTI","	= section"},
/* 1B5B */ { "BALINESE PAMADA","	= honorific section"},
/* 1B5C */ { "BALINESE WINDU","	= punctuation ring"},
/* 1B5D */ { "BALINESE CARIK PAMUNGKAH","	= colon"},
/* 1B5E */ { "BALINESE CARIK SIKI","	= danda\n"
	"	x (devanagari danda - 0964)"},
/* 1B5F */ { "BALINESE CARIK PAREREN","	= double danda\n"
	"	x (devanagari double danda - 0965)"},
/* 1B60 */ { "BALINESE PAMENENG","	= line-breaking hyphen"},
/* 1B61 */ { "BALINESE MUSICAL SYMBOL DONG",NULL},
/* 1B62 */ { "BALINESE MUSICAL SYMBOL DENG",NULL},
/* 1B63 */ { "BALINESE MUSICAL SYMBOL DUNG",NULL},
/* 1B64 */ { "BALINESE MUSICAL SYMBOL DANG",NULL},
/* 1B65 */ { "BALINESE MUSICAL SYMBOL DANG SURANG",NULL},
/* 1B66 */ { "BALINESE MUSICAL SYMBOL DING",NULL},
/* 1B67 */ { "BALINESE MUSICAL SYMBOL DAENG",NULL},
/* 1B68 */ { "BALINESE MUSICAL SYMBOL DEUNG",NULL},
/* 1B69 */ { "BALINESE MUSICAL SYMBOL DAING",NULL},
/* 1B6A */ { "BALINESE MUSICAL SYMBOL DANG GEDE",NULL},
/* 1B6B */ { "BALINESE MUSICAL SYMBOL COMBINING TEGEH",NULL},
/* 1B6C */ { "BALINESE MUSICAL SYMBOL COMBINING ENDEP",NULL},
/* 1B6D */ { "BALINESE MUSICAL SYMBOL COMBINING KEMPUL",NULL},
/* 1B6E */ { "BALINESE MUSICAL SYMBOL COMBINING KEMPLI",NULL},
/* 1B6F */ { "BALINESE MUSICAL SYMBOL COMBINING JEGOGAN",NULL},
/* 1B70 */ { "BALINESE MUSICAL SYMBOL COMBINING KEMPUL WITH JEGOGAN",NULL},
/* 1B71 */ { "BALINESE MUSICAL SYMBOL COMBINING KEMPLI WITH JEGOGAN",NULL},
/* 1B72 */ { "BALINESE MUSICAL SYMBOL COMBINING BENDE",NULL},
/* 1B73 */ { "BALINESE MUSICAL SYMBOL COMBINING GONG",NULL},
/* 1B74 */ { "BALINESE MUSICAL SYMBOL RIGHT-HAND OPEN DUG",NULL},
/* 1B75 */ { "BALINESE MUSICAL SYMBOL RIGHT-HAND OPEN DAG",NULL},
/* 1B76 */ { "BALINESE MUSICAL SYMBOL RIGHT-HAND CLOSED TUK",NULL},
/* 1B77 */ { "BALINESE MUSICAL SYMBOL RIGHT-HAND CLOSED TAK",NULL},
/* 1B78 */ { "BALINESE MUSICAL SYMBOL LEFT-HAND OPEN PANG",NULL},
/* 1B79 */ { "BALINESE MUSICAL SYMBOL LEFT-HAND OPEN PUNG",NULL},
/* 1B7A */ { "BALINESE MUSICAL SYMBOL LEFT-HAND CLOSED PLAK",NULL},
/* 1B7B */ { "BALINESE MUSICAL SYMBOL LEFT-HAND CLOSED PLUK",NULL},
/* 1B7C */ { "BALINESE MUSICAL SYMBOL LEFT-HAND OPEN PING",NULL},
/* 1B7D */ { "BALINESE PANTI LANTANG","	= end of text"},
/* 1B7E */ { "BALINESE PAMADA LANTANG","	= end of text"},
/* 1B7F */ { "BALINESE PANTI BAWAK","	* truncated form of panti\n"
	"	x (balinese panti - 1B5A)"},
/* 1B80 */ { "SUNDANESE SIGN PANYECEK","	= anusvara"},
/* 1B81 */ { "SUNDANESE SIGN PANGLAYAR","	= final r"},
/* 1B82 */ { "SUNDANESE SIGN PANGWISAD","	= visarga"},
/* 1B83 */ { "SUNDANESE LETTER A",NULL},
/* 1B84 */ { "SUNDANESE LETTER I",NULL},
/* 1B85 */ { "SUNDANESE LETTER U",NULL},
/* 1B86 */ { "SUNDANESE LETTER AE",NULL},
/* 1B87 */ { "SUNDANESE LETTER O",NULL},
/* 1B88 */ { "SUNDANESE LETTER E",NULL},
/* 1B89 */ { "SUNDANESE LETTER EU",NULL},
/* 1B8A */ { "SUNDANESE LETTER KA",NULL},
/* 1B8B */ { "SUNDANESE LETTER QA",NULL},
/* 1B8C */ { "SUNDANESE LETTER GA",NULL},
/* 1B8D */ { "SUNDANESE LETTER NGA",NULL},
/* 1B8E */ { "SUNDANESE LETTER CA",NULL},
/* 1B8F */ { "SUNDANESE LETTER JA",NULL},
/* 1B90 */ { "SUNDANESE LETTER ZA",NULL},
/* 1B91 */ { "SUNDANESE LETTER NYA",NULL},
/* 1B92 */ { "SUNDANESE LETTER TA",NULL},
/* 1B93 */ { "SUNDANESE LETTER DA",NULL},
/* 1B94 */ { "SUNDANESE LETTER NA",NULL},
/* 1B95 */ { "SUNDANESE LETTER PA",NULL},
/* 1B96 */ { "SUNDANESE LETTER FA",NULL},
/* 1B97 */ { "SUNDANESE LETTER VA",NULL},
/* 1B98 */ { "SUNDANESE LETTER BA",NULL},
/* 1B99 */ { "SUNDANESE LETTER MA",NULL},
/* 1B9A */ { "SUNDANESE LETTER YA",NULL},
/* 1B9B */ { "SUNDANESE LETTER RA",NULL},
/* 1B9C */ { "SUNDANESE LETTER LA",NULL},
/* 1B9D */ { "SUNDANESE LETTER WA",NULL},
/* 1B9E */ { "SUNDANESE LETTER SA",NULL},
/* 1B9F */ { "SUNDANESE LETTER XA",NULL},
/* 1BA0 */ { "SUNDANESE LETTER HA",NULL},
/* 1BA1 */ { "SUNDANESE CONSONANT SIGN PAMINGKAL","	= subjoined ya"},
/* 1BA2 */ { "SUNDANESE CONSONANT SIGN PANYAKRA","	= subjoined ra"},
/* 1BA3 */ { "SUNDANESE CONSONANT SIGN PANYIKU","	= subjoined la"},
/* 1BA4 */ { "SUNDANESE VOWEL SIGN PANGHULU","	= i"},
/* 1BA5 */ { "SUNDANESE VOWEL SIGN PANYUKU","	= u"},
/* 1BA6 */ { "SUNDANESE VOWEL SIGN PANAELAENG","	= ae"},
/* 1BA7 */ { "SUNDANESE VOWEL SIGN PANOLONG","	= o"},
/* 1BA8 */ { "SUNDANESE VOWEL SIGN PAMEPET","	= e"},
/* 1BA9 */ { "SUNDANESE VOWEL SIGN PANEULEUNG","	= eu"},
/* 1BAA */ { "SUNDANESE SIGN PAMAAEH","	= virama\n"
	"	* does not form conjuncts"},
/* 1BAB */ { "SUNDANESE SIGN VIRAMA","	* forms conjuncts in older orthography"},
/* 1BAC */ { "SUNDANESE CONSONANT SIGN PASANGAN MA","	= subjoined ma"},
/* 1BAD */ { "SUNDANESE CONSONANT SIGN PASANGAN WA","	= subjoined wa"},
/* 1BAE */ { "SUNDANESE LETTER KHA",NULL},
/* 1BAF */ { "SUNDANESE LETTER SYA",NULL},
/* 1BB0 */ { "SUNDANESE DIGIT ZERO",NULL},
/* 1BB1 */ { "SUNDANESE DIGIT ONE",NULL},
/* 1BB2 */ { "SUNDANESE DIGIT TWO",NULL},
/* 1BB3 */ { "SUNDANESE DIGIT THREE",NULL},
/* 1BB4 */ { "SUNDANESE DIGIT FOUR",NULL},
/* 1BB5 */ { "SUNDANESE DIGIT FIVE",NULL},
/* 1BB6 */ { "SUNDANESE DIGIT SIX",NULL},
/* 1BB7 */ { "SUNDANESE DIGIT SEVEN",NULL},
/* 1BB8 */ { "SUNDANESE DIGIT EIGHT",NULL},
/* 1BB9 */ { "SUNDANESE DIGIT NINE",NULL},
/* 1BBA */ { "SUNDANESE AVAGRAHA","	= gemination mark"},
/* 1BBB */ { "SUNDANESE LETTER REU","	* vocalic r"},
/* 1BBC */ { "SUNDANESE LETTER LEU","	* vocalic l"},
/* 1BBD */ { "SUNDANESE LETTER BHA","	% SUNDANESE LETTER ARCHAIC I\n"
	"	* character was originally misidentified, so its name is a misnomer"},
/* 1BBE */ { "SUNDANESE LETTER FINAL K",NULL},
/* 1BBF */ { "SUNDANESE LETTER FINAL M","	* used in a 21st century document\n"
	"	* for actual final m, use the sequence 1B99 1BAA"},
/* 1BC0 */ { "BATAK LETTER A","	* letter a or ha for Karo and Pakpak"},
/* 1BC1 */ { "BATAK LETTER SIMALUNGUN A",NULL},
/* 1BC2 */ { "BATAK LETTER HA","	* Toba letter ha or ka\n"
	"	* also known as letter ka for Karo and Pakpak"},
/* 1BC3 */ { "BATAK LETTER SIMALUNGUN HA","	* also known as Simalungun letter ka"},
/* 1BC4 */ { "BATAK LETTER MANDAILING HA",NULL},
/* 1BC5 */ { "BATAK LETTER BA",NULL},
/* 1BC6 */ { "BATAK LETTER KARO BA","	* also used in Toba"},
/* 1BC7 */ { "BATAK LETTER PA",NULL},
/* 1BC8 */ { "BATAK LETTER SIMALUNGUN PA",NULL},
/* 1BC9 */ { "BATAK LETTER NA",NULL},
/* 1BCA */ { "BATAK LETTER MANDAILING NA",NULL},
/* 1BCB */ { "BATAK LETTER WA","	* Toba letter wa can be represented by either 1BCB or 1BCD"},
/* 1BCC */ { "BATAK LETTER SIMALUNGUN WA",NULL},
/* 1BCD */ { "BATAK LETTER PAKPAK WA",NULL},
/* 1BCE */ { "BATAK LETTER GA",NULL},
/* 1BCF */ { "BATAK LETTER SIMALUNGUN GA",NULL},
/* 1BD0 */ { "BATAK LETTER JA",NULL},
/* 1BD1 */ { "BATAK LETTER DA",NULL},
/* 1BD2 */ { "BATAK LETTER RA",NULL},
/* 1BD3 */ { "BATAK LETTER SIMALUNGUN RA",NULL},
/* 1BD4 */ { "BATAK LETTER MA",NULL},
/* 1BD5 */ { "BATAK LETTER SIMALUNGUN MA",NULL},
/* 1BD6 */ { "BATAK LETTER SOUTHERN TA","	* Toba letter ta can be represented by either 1BD6 or 1BD7"},
/* 1BD7 */ { "BATAK LETTER NORTHERN TA",NULL},
/* 1BD8 */ { "BATAK LETTER SA","	* Pakpak letter sa or ca"},
/* 1BD9 */ { "BATAK LETTER SIMALUNGUN SA",NULL},
/* 1BDA */ { "BATAK LETTER MANDAILING SA",NULL},
/* 1BDB */ { "BATAK LETTER YA",NULL},
/* 1BDC */ { "BATAK LETTER SIMALUNGUN YA",NULL},
/* 1BDD */ { "BATAK LETTER NGA",NULL},
/* 1BDE */ { "BATAK LETTER LA",NULL},
/* 1BDF */ { "BATAK LETTER SIMALUNGUN LA",NULL},
/* 1BE0 */ { "BATAK LETTER NYA","	* Karo letter ca can be represented by either 1BE0 or 1BE1"},
/* 1BE1 */ { "BATAK LETTER CA",NULL},
/* 1BE2 */ { "BATAK LETTER NDA",NULL},
/* 1BE3 */ { "BATAK LETTER MBA",NULL},
/* 1BE4 */ { "BATAK LETTER I",NULL},
/* 1BE5 */ { "BATAK LETTER U",NULL},
/* 1BE6 */ { "BATAK SIGN TOMPI",NULL},
/* 1BE7 */ { "BATAK VOWEL SIGN E","	= kebereten"},
/* 1BE8 */ { "BATAK VOWEL SIGN PAKPAK E","	= ketolongen"},
/* 1BE9 */ { "BATAK VOWEL SIGN EE","	= talinga"},
/* 1BEA */ { "BATAK VOWEL SIGN I","	= ulua"},
/* 1BEB */ { "BATAK VOWEL SIGN KARO I","	= haluan"},
/* 1BEC */ { "BATAK VOWEL SIGN O","	= siala ulu"},
/* 1BED */ { "BATAK VOWEL SIGN KARO O","	= hatulungan"},
/* 1BEE */ { "BATAK VOWEL SIGN U","	= boruta"},
/* 1BEF */ { "BATAK VOWEL SIGN U FOR SIMALUNGUN SA","	= haboritan for simalungun sa"},
/* 1BF0 */ { "BATAK CONSONANT SIGN NG","	= amisara"},
/* 1BF1 */ { "BATAK CONSONANT SIGN H","	= hajoringan"},
/* 1BF2 */ { "BATAK PANGOLAT","	= virama\n"
	"	* cannot follow a vowel sign"},
/* 1BF3 */ { "BATAK PANONGONAN","	= virama"},
/* 1BF4 */ { NULL,NULL},
/* 1BF5 */ { NULL,NULL},
/* 1BF6 */ { NULL,NULL},
/* 1BF7 */ { NULL,NULL},
/* 1BF8 */ { NULL,NULL},
/* 1BF9 */ { NULL,NULL},
/* 1BFA */ { NULL,NULL},
/* 1BFB */ { NULL,NULL},
/* 1BFC */ { "BATAK SYMBOL BINDU NA METEK",NULL},
/* 1BFD */ { "BATAK SYMBOL BINDU PINARBORAS",NULL},
/* 1BFE */ { "BATAK SYMBOL BINDU JUDUL",NULL},
/* 1BFF */ { "BATAK SYMBOL BINDU PANGOLAT",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_00_1C[] = {
/* 1C00 */ { "LEPCHA LETTER KA",NULL},
/* 1C01 */ { "LEPCHA LETTER KLA",NULL},
/* 1C02 */ { "LEPCHA LETTER KHA",NULL},
/* 1C03 */ { "LEPCHA LETTER GA",NULL},
/* 1C04 */ { "LEPCHA LETTER GLA",NULL},
/* 1C05 */ { "LEPCHA LETTER NGA",NULL},
/* 1C06 */ { "LEPCHA LETTER CA",NULL},
/* 1C07 */ { "LEPCHA LETTER CHA",NULL},
/* 1C08 */ { "LEPCHA LETTER JA",NULL},
/* 1C09 */ { "LEPCHA LETTER NYA",NULL},
/* 1C0A */ { "LEPCHA LETTER TA",NULL},
/* 1C0B */ { "LEPCHA LETTER THA",NULL},
/* 1C0C */ { "LEPCHA LETTER DA",NULL},
/* 1C0D */ { "LEPCHA LETTER NA",NULL},
/* 1C0E */ { "LEPCHA LETTER PA",NULL},
/* 1C0F */ { "LEPCHA LETTER PLA",NULL},
/* 1C10 */ { "LEPCHA LETTER PHA",NULL},
/* 1C11 */ { "LEPCHA LETTER FA",NULL},
/* 1C12 */ { "LEPCHA LETTER FLA",NULL},
/* 1C13 */ { "LEPCHA LETTER BA",NULL},
/* 1C14 */ { "LEPCHA LETTER BLA",NULL},
/* 1C15 */ { "LEPCHA LETTER MA",NULL},
/* 1C16 */ { "LEPCHA LETTER MLA",NULL},
/* 1C17 */ { "LEPCHA LETTER TSA",NULL},
/* 1C18 */ { "LEPCHA LETTER TSHA",NULL},
/* 1C19 */ { "LEPCHA LETTER DZA",NULL},
/* 1C1A */ { "LEPCHA LETTER YA",NULL},
/* 1C1B */ { "LEPCHA LETTER RA",NULL},
/* 1C1C */ { "LEPCHA LETTER LA",NULL},
/* 1C1D */ { "LEPCHA LETTER HA",NULL},
/* 1C1E */ { "LEPCHA LETTER HLA",NULL},
/* 1C1F */ { "LEPCHA LETTER VA",NULL},
/* 1C20 */ { "LEPCHA LETTER SA",NULL},
/* 1C21 */ { "LEPCHA LETTER SHA",NULL},
/* 1C22 */ { "LEPCHA LETTER WA",NULL},
/* 1C23 */ { "LEPCHA LETTER A",NULL},
/* 1C24 */ { "LEPCHA SUBJOINED LETTER YA",NULL},
/* 1C25 */ { "LEPCHA SUBJOINED LETTER RA",NULL},
/* 1C26 */ { "LEPCHA VOWEL SIGN AA",NULL},
/* 1C27 */ { "LEPCHA VOWEL SIGN I",NULL},
/* 1C28 */ { "LEPCHA VOWEL SIGN O",NULL},
/* 1C29 */ { "LEPCHA VOWEL SIGN OO",NULL},
/* 1C2A */ { "LEPCHA VOWEL SIGN U",NULL},
/* 1C2B */ { "LEPCHA VOWEL SIGN UU",NULL},
/* 1C2C */ { "LEPCHA VOWEL SIGN E",NULL},
/* 1C2D */ { "LEPCHA CONSONANT SIGN K",NULL},
/* 1C2E */ { "LEPCHA CONSONANT SIGN M",NULL},
/* 1C2F */ { "LEPCHA CONSONANT SIGN L",NULL},
/* 1C30 */ { "LEPCHA CONSONANT SIGN N",NULL},
/* 1C31 */ { "LEPCHA CONSONANT SIGN P",NULL},
/* 1C32 */ { "LEPCHA CONSONANT SIGN R",NULL},
/* 1C33 */ { "LEPCHA CONSONANT SIGN T",NULL},
/* 1C34 */ { "LEPCHA CONSONANT SIGN NYIN-DO",NULL},
/* 1C35 */ { "LEPCHA CONSONANT SIGN KANG",NULL},
/* 1C36 */ { "LEPCHA SIGN RAN",NULL},
/* 1C37 */ { "LEPCHA SIGN NUKTA",NULL},
/* 1C38 */ { NULL,NULL},
/* 1C39 */ { NULL,NULL},
/* 1C3A */ { NULL,NULL},
/* 1C3B */ { "LEPCHA PUNCTUATION TA-ROL",NULL},
/* 1C3C */ { "LEPCHA PUNCTUATION NYET THYOOM TA-ROL",NULL},
/* 1C3D */ { "LEPCHA PUNCTUATION CER-WA",NULL},
/* 1C3E */ { "LEPCHA PUNCTUATION TSHOOK CER-WA",NULL},
/* 1C3F */ { "LEPCHA PUNCTUATION TSHOOK",NULL},
/* 1C40 */ { "LEPCHA DIGIT ZERO",NULL},
/* 1C41 */ { "LEPCHA DIGIT ONE",NULL},
/* 1C42 */ { "LEPCHA DIGIT TWO",NULL},
/* 1C43 */ { "LEPCHA DIGIT THREE",NULL},
/* 1C44 */ { "LEPCHA DIGIT FOUR",NULL},
/* 1C45 */ { "LEPCHA DIGIT FIVE",NULL},
/* 1C46 */ { "LEPCHA DIGIT SIX",NULL},
/* 1C47 */ { "LEPCHA DIGIT SEVEN",NULL},
/* 1C48 */ { "LEPCHA DIGIT EIGHT",NULL},
/* 1C49 */ { "LEPCHA DIGIT NINE",NULL},
/* 1C4A */ { NULL,NULL},
/* 1C4B */ { NULL,NULL},
/* 1C4C */ { NULL,NULL},
/* 1C4D */ { "LEPCHA LETTER TTA",NULL},
/* 1C4E */ { "LEPCHA LETTER TTHA",NULL},
/* 1C4F */ { "LEPCHA LETTER DDA",NULL},
/* 1C50 */ { "OL CHIKI DIGIT ZERO",NULL},
/* 1C51 */ { "OL CHIKI DIGIT ONE",NULL},
/* 1C52 */ { "OL CHIKI DIGIT TWO",NULL},
/* 1C53 */ { "OL CHIKI DIGIT THREE",NULL},
/* 1C54 */ { "OL CHIKI DIGIT FOUR",NULL},
/* 1C55 */ { "OL CHIKI DIGIT FIVE",NULL},
/* 1C56 */ { "OL CHIKI DIGIT SIX",NULL},
/* 1C57 */ { "OL CHIKI DIGIT SEVEN",NULL},
/* 1C58 */ { "OL CHIKI DIGIT EIGHT",NULL},
/* 1C59 */ { "OL CHIKI DIGIT NINE",NULL},
/* 1C5A */ { "OL CHIKI LETTER LA",NULL},
/* 1C5B */ { "OL CHIKI LETTER AT",NULL},
/* 1C5C */ { "OL CHIKI LETTER AG",NULL},
/* 1C5D */ { "OL CHIKI LETTER ANG",NULL},
/* 1C5E */ { "OL CHIKI LETTER AL",NULL},
/* 1C5F */ { "OL CHIKI LETTER LAA",NULL},
/* 1C60 */ { "OL CHIKI LETTER AAK",NULL},
/* 1C61 */ { "OL CHIKI LETTER AAJ",NULL},
/* 1C62 */ { "OL CHIKI LETTER AAM",NULL},
/* 1C63 */ { "OL CHIKI LETTER AAW",NULL},
/* 1C64 */ { "OL CHIKI LETTER LI",NULL},
/* 1C65 */ { "OL CHIKI LETTER IS",NULL},
/* 1C66 */ { "OL CHIKI LETTER IH",NULL},
/* 1C67 */ { "OL CHIKI LETTER INY",NULL},
/* 1C68 */ { "OL CHIKI LETTER IR",NULL},
/* 1C69 */ { "OL CHIKI LETTER LU",NULL},
/* 1C6A */ { "OL CHIKI LETTER UC",NULL},
/* 1C6B */ { "OL CHIKI LETTER UD",NULL},
/* 1C6C */ { "OL CHIKI LETTER UNN",NULL},
/* 1C6D */ { "OL CHIKI LETTER UY",NULL},
/* 1C6E */ { "OL CHIKI LETTER LE",NULL},
/* 1C6F */ { "OL CHIKI LETTER EP",NULL},
/* 1C70 */ { "OL CHIKI LETTER EDD",NULL},
/* 1C71 */ { "OL CHIKI LETTER EN",NULL},
/* 1C72 */ { "OL CHIKI LETTER ERR",NULL},
/* 1C73 */ { "OL CHIKI LETTER LO",NULL},
/* 1C74 */ { "OL CHIKI LETTER OTT",NULL},
/* 1C75 */ { "OL CHIKI LETTER OB",NULL},
/* 1C76 */ { "OL CHIKI LETTER OV",NULL},
/* 1C77 */ { "OL CHIKI LETTER OH",NULL},
/* 1C78 */ { "OL CHIKI MU TTUDDAG","	* nasalization mark"},
/* 1C79 */ { "OL CHIKI GAAHLAA TTUDDAAG","	* vowel modifier"},
/* 1C7A */ { "OL CHIKI MU-GAAHLAA TTUDDAAG",NULL},
/* 1C7B */ { "OL CHIKI RELAA","	* length mark"},
/* 1C7C */ { "OL CHIKI PHAARKAA","	* glottal protector"},
/* 1C7D */ { "OL CHIKI AHAD","	* deglottalizes consonants"},
/* 1C7E */ { "OL CHIKI PUNCTUATION MUCAAD",NULL},
/* 1C7F */ { "OL CHIKI PUNCTUATION DOUBLE MUCAAD",NULL},
/* 1C80 */ { "CYRILLIC SMALL LETTER ROUNDED VE","	x (cyrillic small letter ve - 0432)"},
/* 1C81 */ { "CYRILLIC SMALL LETTER LONG-LEGGED DE","	x (cyrillic small letter de - 0434)"},
/* 1C82 */ { "CYRILLIC SMALL LETTER NARROW O","	x (cyrillic small letter o - 043E)"},
/* 1C83 */ { "CYRILLIC SMALL LETTER WIDE ES","	x (cyrillic small letter es - 0441)"},
/* 1C84 */ { "CYRILLIC SMALL LETTER TALL TE",NULL},
/* 1C85 */ { "CYRILLIC SMALL LETTER THREE-LEGGED TE","	x (cyrillic small letter te - 0442)"},
/* 1C86 */ { "CYRILLIC SMALL LETTER TALL HARD SIGN","	x (cyrillic small letter hard sign - 044A)"},
/* 1C87 */ { "CYRILLIC SMALL LETTER TALL YAT","	x (cyrillic small letter yat - 0463)"},
/* 1C88 */ { "CYRILLIC SMALL LETTER UNBLENDED UK","	x (cyrillic small letter uk - 0479)\n"
	"	x (cyrillic small letter monograph uk - A64B)"},
/* 1C89 */ { "CYRILLIC CAPITAL LETTER TJE",NULL},
/* 1C8A */ { "CYRILLIC SMALL LETTER TJE","	x (cyrillic small letter komi tje - 050F)"},
/* 1C8B */ { NULL,NULL},
/* 1C8C */ { NULL,NULL},
/* 1C8D */ { NULL,NULL},
/* 1C8E */ { NULL,NULL},
/* 1C8F */ { NULL,NULL},
/* 1C90 */ { "GEORGIAN MTAVRULI CAPITAL LETTER AN","	x (georgian letter an - 10D0)"},
/* 1C91 */ { "GEORGIAN MTAVRULI CAPITAL LETTER BAN",NULL},
/* 1C92 */ { "GEORGIAN MTAVRULI CAPITAL LETTER GAN",NULL},
/* 1C93 */ { "GEORGIAN MTAVRULI CAPITAL LETTER DON",NULL},
/* 1C94 */ { "GEORGIAN MTAVRULI CAPITAL LETTER EN",NULL},
/* 1C95 */ { "GEORGIAN MTAVRULI CAPITAL LETTER VIN",NULL},
/* 1C96 */ { "GEORGIAN MTAVRULI CAPITAL LETTER ZEN",NULL},
/* 1C97 */ { "GEORGIAN MTAVRULI CAPITAL LETTER TAN",NULL},
/* 1C98 */ { "GEORGIAN MTAVRULI CAPITAL LETTER IN",NULL},
/* 1C99 */ { "GEORGIAN MTAVRULI CAPITAL LETTER KAN",NULL},
/* 1C9A */ { "GEORGIAN MTAVRULI CAPITAL LETTER LAS",NULL},
/* 1C9B */ { "GEORGIAN MTAVRULI CAPITAL LETTER MAN",NULL},
/* 1C9C */ { "GEORGIAN MTAVRULI CAPITAL LETTER NAR",NULL},
/* 1C9D */ { "GEORGIAN MTAVRULI CAPITAL LETTER ON",NULL},
/* 1C9E */ { "GEORGIAN MTAVRULI CAPITAL LETTER PAR",NULL},
/* 1C9F */ { "GEORGIAN MTAVRULI CAPITAL LETTER ZHAR",NULL},
/* 1CA0 */ { "GEORGIAN MTAVRULI CAPITAL LETTER RAE",NULL},
/* 1CA1 */ { "GEORGIAN MTAVRULI CAPITAL LETTER SAN",NULL},
/* 1CA2 */ { "GEORGIAN MTAVRULI CAPITAL LETTER TAR",NULL},
/* 1CA3 */ { "GEORGIAN MTAVRULI CAPITAL LETTER UN",NULL},
/* 1CA4 */ { "GEORGIAN MTAVRULI CAPITAL LETTER PHAR",NULL},
/* 1CA5 */ { "GEORGIAN MTAVRULI CAPITAL LETTER KHAR",NULL},
/* 1CA6 */ { "GEORGIAN MTAVRULI CAPITAL LETTER GHAN",NULL},
/* 1CA7 */ { "GEORGIAN MTAVRULI CAPITAL LETTER QAR",NULL},
/* 1CA8 */ { "GEORGIAN MTAVRULI CAPITAL LETTER SHIN",NULL},
/* 1CA9 */ { "GEORGIAN MTAVRULI CAPITAL LETTER CHIN",NULL},
/* 1CAA */ { "GEORGIAN MTAVRULI CAPITAL LETTER CAN",NULL},
/* 1CAB */ { "GEORGIAN MTAVRULI CAPITAL LETTER JIL",NULL},
/* 1CAC */ { "GEORGIAN MTAVRULI CAPITAL LETTER CIL",NULL},
/* 1CAD */ { "GEORGIAN MTAVRULI CAPITAL LETTER CHAR",NULL},
/* 1CAE */ { "GEORGIAN MTAVRULI CAPITAL LETTER XAN",NULL},
/* 1CAF */ { "GEORGIAN MTAVRULI CAPITAL LETTER JHAN",NULL},
/* 1CB0 */ { "GEORGIAN MTAVRULI CAPITAL LETTER HAE",NULL},
/* 1CB1 */ { "GEORGIAN MTAVRULI CAPITAL LETTER HE",NULL},
/* 1CB2 */ { "GEORGIAN MTAVRULI CAPITAL LETTER HIE",NULL},
/* 1CB3 */ { "GEORGIAN MTAVRULI CAPITAL LETTER WE",NULL},
/* 1CB4 */ { "GEORGIAN MTAVRULI CAPITAL LETTER HAR",NULL},
/* 1CB5 */ { "GEORGIAN MTAVRULI CAPITAL LETTER HOE",NULL},
/* 1CB6 */ { "GEORGIAN MTAVRULI CAPITAL LETTER FI",NULL},
/* 1CB7 */ { "GEORGIAN MTAVRULI CAPITAL LETTER YN",NULL},
/* 1CB8 */ { "GEORGIAN MTAVRULI CAPITAL LETTER ELIFI",NULL},
/* 1CB9 */ { "GEORGIAN MTAVRULI CAPITAL LETTER TURNED GAN",NULL},
/* 1CBA */ { "GEORGIAN MTAVRULI CAPITAL LETTER AIN",NULL},
/* 1CBB */ { NULL,NULL},
/* 1CBC */ { NULL,NULL},
/* 1CBD */ { "GEORGIAN MTAVRULI CAPITAL LETTER AEN",NULL},
/* 1CBE */ { "GEORGIAN MTAVRULI CAPITAL LETTER HARD SIGN",NULL},
/* 1CBF */ { "GEORGIAN MTAVRULI CAPITAL LETTER LABIAL SIGN",NULL},
/* 1CC0 */ { "SUNDANESE PUNCTUATION BINDU SURYA","	* sun"},
/* 1CC1 */ { "SUNDANESE PUNCTUATION BINDU PANGLONG","	* half moon"},
/* 1CC2 */ { "SUNDANESE PUNCTUATION BINDU PURNAMA","	* full moon"},
/* 1CC3 */ { "SUNDANESE PUNCTUATION BINDU CAKRA","	* wheel"},
/* 1CC4 */ { "SUNDANESE PUNCTUATION BINDU LEU SATANGA",NULL},
/* 1CC5 */ { "SUNDANESE PUNCTUATION BINDU KA SATANGA",NULL},
/* 1CC6 */ { "SUNDANESE PUNCTUATION BINDU DA SATANGA",NULL},
/* 1CC7 */ { "SUNDANESE PUNCTUATION BINDU BA SATANGA",NULL},
/* 1CC8 */ { NULL,NULL},
/* 1CC9 */ { NULL,NULL},
/* 1CCA */ { NULL,NULL},
/* 1CCB */ { NULL,NULL},
/* 1CCC */ { NULL,NULL},
/* 1CCD */ { NULL,NULL},
/* 1CCE */ { NULL,NULL},
/* 1CCF */ { NULL,NULL},
/* 1CD0 */ { "VEDIC TONE KARSHANA","	= vaidika saamasvara karshanna"},
/* 1CD1 */ { "VEDIC TONE SHARA","	= vaidika svarita uurdhva shara"},
/* 1CD2 */ { "VEDIC TONE PRENKHA","	* indicates vibrato\n"
	"	= vaidika saamasvara prenkha"},
/* 1CD3 */ { "VEDIC SIGN NIHSHVASA","	= vaidika saamagaana yogakaala\n"
	"	* separates sections between which a pause is disallowed"},
/* 1CD4 */ { "VEDIC SIGN YAJURVEDIC MIDLINE SVARITA","	* used predominantly in the Maitrayani Samhita and in some manuscripts of the Vajasaneyi Madhyandina Samhita"},
/* 1CD5 */ { "VEDIC TONE YAJURVEDIC AGGRAVATED INDEPENDENT SVARITA","	= vaidika svarita adho nyubja"},
/* 1CD6 */ { "VEDIC TONE YAJURVEDIC INDEPENDENT SVARITA","	= vaidika svarita adhah konna"},
/* 1CD7 */ { "VEDIC TONE YAJURVEDIC KATHAKA INDEPENDENT SVARITA","	= vaidika svarita adho vakra rekhaa"},
/* 1CD8 */ { "VEDIC TONE CANDRA BELOW","	= vaidika svarita adho'rdha vakra"},
/* 1CD9 */ { "VEDIC TONE YAJURVEDIC KATHAKA INDEPENDENT SVARITA SCHROEDER","	= vaidika svarita adhah samyukta rekhaa"},
/* 1CDA */ { "VEDIC TONE DOUBLE SVARITA","	= vaidika svarita uurdhva dvi rekhaa\n"
	"	x (devanagari stress sign udatta - 0951)"},
/* 1CDB */ { "VEDIC TONE TRIPLE SVARITA","	= vaidika svarita uurdhva tri rekhaa"},
/* 1CDC */ { "VEDIC TONE KATHAKA ANUDATTA","	= vaidika svarita adho rekhaa\n"
	"	x (devanagari stress sign anudatta - 0952)"},
/* 1CDD */ { "VEDIC TONE DOT BELOW","	= vaidika svarita adho bindu"},
/* 1CDE */ { "VEDIC TONE TWO DOTS BELOW","	= vaidika svarita adho dvi bindu"},
/* 1CDF */ { "VEDIC TONE THREE DOTS BELOW","	= vaidika svarita adhas tri bindu"},
/* 1CE0 */ { "VEDIC TONE RIGVEDIC KASHMIRI INDEPENDENT SVARITA","	= vaidika uurdhva vakra rekhaa"},
/* 1CE1 */ { "VEDIC TONE ATHARVAVEDIC INDEPENDENT SVARITA","	= vaidika svarita dvi vakra khannda"},
/* 1CE2 */ { "VEDIC SIGN VISARGA SVARITA","	= vaidika madhyarekhaa"},
/* 1CE3 */ { "VEDIC SIGN VISARGA UDATTA","	= vaidika visarga dakshinnatah uurdhvaga"},
/* 1CE4 */ { "VEDIC SIGN REVERSED VISARGA UDATTA","	= vaidika visarga vaamatah uurdhvaga"},
/* 1CE5 */ { "VEDIC SIGN VISARGA ANUDATTA","	= vaidika visarga vaamatah adhoga"},
/* 1CE6 */ { "VEDIC SIGN REVERSED VISARGA ANUDATTA","	= vaidika visarga dakshinnatah adhoga"},
/* 1CE7 */ { "VEDIC SIGN VISARGA UDATTA WITH TAIL","	= vaidika visarga dakshinnatah uurdhva vakra"},
/* 1CE8 */ { "VEDIC SIGN VISARGA ANUDATTA WITH TAIL","	= vaidika visarga vaamatah adho vakra"},
/* 1CE9 */ { "VEDIC SIGN ANUSVARA ANTARGOMUKHA","	= vaidika anusvaara antarmukha"},
/* 1CEA */ { "VEDIC SIGN ANUSVARA BAHIRGOMUKHA","	= vaidika anusvaara naagaphanna"},
/* 1CEB */ { "VEDIC SIGN ANUSVARA VAMAGOMUKHA","	= vaidika anusvaara vaamagomukha"},
/* 1CEC */ { "VEDIC SIGN ANUSVARA VAMAGOMUKHA WITH TAIL","	= vaidika anusvaara vaamagomukha sa-vakra"},
/* 1CED */ { "VEDIC SIGN TIRYAK","	= vaidika tiryak"},
/* 1CEE */ { "VEDIC SIGN HEXIFORM LONG ANUSVARA","	= vaidika anusvaara anugaamii"},
/* 1CEF */ { "VEDIC SIGN LONG ANUSVARA","	= vaidika anusvaara dakshinnamukha"},
/* 1CF0 */ { "VEDIC SIGN RTHANG LONG ANUSVARA","	= vaidika anusvaara ttha-sadrisha"},
/* 1CF1 */ { "VEDIC SIGN ANUSVARA UBHAYATO MUKHA","	= vaidika anusvaara ubhayato mukha"},
/* 1CF2 */ { "VEDIC SIGN ARDHAVISARGA","	= vaidika jihvaamuuliiya upadhmaaniiya"},
/* 1CF3 */ { "VEDIC SIGN ROTATED ARDHAVISARGA",NULL},
/* 1CF4 */ { "VEDIC TONE CANDRA ABOVE",NULL},
/* 1CF5 */ { "VEDIC SIGN JIHVAMULIYA","	* marks a velar fricative occurring only before unvoiced velar stops\n"
	"	x (kannada sign jihvamuliya - 0CF1)\n"
	"	x (tibetan sign lce tsa can - 0F88)\n"
	"	x (brahmi sign jihvamuliya - 11003)\n"
	"	x (sharada sign jihvamuliya - 111C2)\n"
	"	x (newa sign jihvamuliya - 11460)\n"
	"	x (soyombo sign jihvamuliya - 11A84)"},
/* 1CF6 */ { "VEDIC SIGN UPADHMANIYA","	* marks a bilabial fricative occurring only before unvoiced labial stops\n"
	"	x (kannada sign upadhmaniya - 0CF2)\n"
	"	x (tibetan sign mchu can - 0F89)\n"
	"	x (brahmi sign upadhmaniya - 11004)\n"
	"	x (sharada sign upadhmaniya - 111C3)\n"
	"	x (newa sign upadhmaniya - 11461)\n"
	"	x (soyombo sign upadhmaniya - 11A85)"},
/* 1CF7 */ { "VEDIC SIGN ATIKRAMA","	= vaidika saamagaana atikrama\n"
	"	* indicates skipping of a svara"},
/* 1CF8 */ { "VEDIC TONE RING ABOVE",NULL},
/* 1CF9 */ { "VEDIC TONE DOUBLE RING ABOVE",NULL},
/* 1CFA */ { "VEDIC SIGN DOUBLE ANUSVARA ANTARGOMUKHA","	* used as a base for a combining nasal sign"},
/* 1CFB */ { NULL,NULL},
/* 1CFC */ { NULL,NULL},
/* 1CFD */ { NULL,NULL},
/* 1CFE */ { NULL,NULL},
/* 1CFF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_00_1D[] = {
/* 1D00 */ { "LATIN LETTER SMALL CAPITAL A",NULL},
/* 1D01 */ { "LATIN LETTER SMALL CAPITAL AE",NULL},
/* 1D02 */ { "LATIN SMALL LETTER TURNED AE","	* glyph can also have sideways orientation"},
/* 1D03 */ { "LATIN LETTER SMALL CAPITAL BARRED B","	x (latin capital letter b with stroke - 0243)"},
/* 1D04 */ { "LATIN LETTER SMALL CAPITAL C",NULL},
/* 1D05 */ { "LATIN LETTER SMALL CAPITAL D",NULL},
/* 1D06 */ { "LATIN LETTER SMALL CAPITAL ETH",NULL},
/* 1D07 */ { "LATIN LETTER SMALL CAPITAL E",NULL},
/* 1D08 */ { "LATIN SMALL LETTER TURNED OPEN E","	x (latin small letter reversed open e - 025C)\n"
	"	x (modifier letter small turned open e - 1D4C)"},
/* 1D09 */ { "LATIN SMALL LETTER TURNED I",NULL},
/* 1D0A */ { "LATIN LETTER SMALL CAPITAL J",NULL},
/* 1D0B */ { "LATIN LETTER SMALL CAPITAL K","	x (latin small letter kra - 0138)\n"
	"	x (cyrillic small letter ka - 043A)"},
/* 1D0C */ { "LATIN LETTER SMALL CAPITAL L WITH STROKE",NULL},
/* 1D0D */ { "LATIN LETTER SMALL CAPITAL M",NULL},
/* 1D0E */ { "LATIN LETTER SMALL CAPITAL REVERSED N","	x (cyrillic small letter i - 0438)\n"
	"	x (modifier letter capital reversed n - 1D3B)"},
/* 1D0F */ { "LATIN LETTER SMALL CAPITAL O",NULL},
/* 1D10 */ { "LATIN LETTER SMALL CAPITAL OPEN O","	x (latin small letter open o - 0254)\n"
	"	x (latin small letter reversed c - 2184)"},
/* 1D11 */ { "LATIN SMALL LETTER SIDEWAYS O",NULL},
/* 1D12 */ { "LATIN SMALL LETTER SIDEWAYS OPEN O",NULL},
/* 1D13 */ { "LATIN SMALL LETTER SIDEWAYS O WITH STROKE",NULL},
/* 1D14 */ { "LATIN SMALL LETTER TURNED OE","	* glyph can also have sideways orientation"},
/* 1D15 */ { "LATIN LETTER SMALL CAPITAL OU",NULL},
/* 1D16 */ { "LATIN SMALL LETTER TOP HALF O",NULL},
/* 1D17 */ { "LATIN SMALL LETTER BOTTOM HALF O",NULL},
/* 1D18 */ { "LATIN LETTER SMALL CAPITAL P","	* represents a semi-voiced [p]\n"
	"	x (greek letter small capital rho - 1D29)"},
/* 1D19 */ { "LATIN LETTER SMALL CAPITAL REVERSED R",NULL},
/* 1D1A */ { "LATIN LETTER SMALL CAPITAL TURNED R",NULL},
/* 1D1B */ { "LATIN LETTER SMALL CAPITAL T","	x (cyrillic small letter te - 0442)"},
/* 1D1C */ { "LATIN LETTER SMALL CAPITAL U",NULL},
/* 1D1D */ { "LATIN SMALL LETTER SIDEWAYS U",NULL},
/* 1D1E */ { "LATIN SMALL LETTER SIDEWAYS DIAERESIZED U","	* glyph can also have turned orientation"},
/* 1D1F */ { "LATIN SMALL LETTER SIDEWAYS TURNED M",NULL},
/* 1D20 */ { "LATIN LETTER SMALL CAPITAL V",NULL},
/* 1D21 */ { "LATIN LETTER SMALL CAPITAL W",NULL},
/* 1D22 */ { "LATIN LETTER SMALL CAPITAL Z",NULL},
/* 1D23 */ { "LATIN LETTER SMALL CAPITAL EZH","	x (cyrillic small letter abkhasian dze - 04E1)"},
/* 1D24 */ { "LATIN LETTER VOICED LARYNGEAL SPIRANT",NULL},
/* 1D25 */ { "LATIN LETTER AIN","	x (arabic letter ain - 0639)\n"
	"	x (latin small letter egyptological ain - A725)"},
/* 1D26 */ { "GREEK LETTER SMALL CAPITAL GAMMA",NULL},
/* 1D27 */ { "GREEK LETTER SMALL CAPITAL LAMDA",NULL},
/* 1D28 */ { "GREEK LETTER SMALL CAPITAL PI",NULL},
/* 1D29 */ { "GREEK LETTER SMALL CAPITAL RHO","	* represents a voiceless uvular trill\n"
	"	x (latin letter small capital p - 1D18)"},
/* 1D2A */ { "GREEK LETTER SMALL CAPITAL PSI",NULL},
/* 1D2B */ { "CYRILLIC LETTER SMALL CAPITAL EL","	* in italic style, the glyph is obliqued, not italicized\n"
	"	x (cyrillic small letter el - 043B)"},
/* 1D2C */ { "MODIFIER LETTER CAPITAL A","	# <super> 0041"},
/* 1D2D */ { "MODIFIER LETTER CAPITAL AE","	# <super> 00C6"},
/* 1D2E */ { "MODIFIER LETTER CAPITAL B","	# <super> 0042"},
/* 1D2F */ { "MODIFIER LETTER CAPITAL BARRED B",NULL},
/* 1D30 */ { "MODIFIER LETTER CAPITAL D","	# <super> 0044"},
/* 1D31 */ { "MODIFIER LETTER CAPITAL E","	# <super> 0045"},
/* 1D32 */ { "MODIFIER LETTER CAPITAL REVERSED E","	# <super> 018E"},
/* 1D33 */ { "MODIFIER LETTER CAPITAL G","	# <super> 0047"},
/* 1D34 */ { "MODIFIER LETTER CAPITAL H","	# <super> 0048\n"
	"		A typographical distinction between a capital form and a small capital form is not distinctive for this character in IPA usage.\n"
	"	* voiceless epiglottalized release (extended IPA)\n"
	"	x (latin letter small capital h - 029C)\n"
	"	x (modifier letter cyrillic en - 1D78)"},
/* 1D35 */ { "MODIFIER LETTER CAPITAL I","	# <super> 0049"},
/* 1D36 */ { "MODIFIER LETTER CAPITAL J","	# <super> 004A"},
/* 1D37 */ { "MODIFIER LETTER CAPITAL K","	# <super> 004B"},
/* 1D38 */ { "MODIFIER LETTER CAPITAL L","	# <super> 004C"},
/* 1D39 */ { "MODIFIER LETTER CAPITAL M","	# <super> 004D"},
/* 1D3A */ { "MODIFIER LETTER CAPITAL N","	# <super> 004E"},
/* 1D3B */ { "MODIFIER LETTER CAPITAL REVERSED N",NULL},
/* 1D3C */ { "MODIFIER LETTER CAPITAL O","	# <super> 004F"},
/* 1D3D */ { "MODIFIER LETTER CAPITAL OU","	# <super> 0222"},
/* 1D3E */ { "MODIFIER LETTER CAPITAL P","	# <super> 0050"},
/* 1D3F */ { "MODIFIER LETTER CAPITAL R","	# <super> 0052"},
/* 1D40 */ { "MODIFIER LETTER CAPITAL T","	# <super> 0054"},
/* 1D41 */ { "MODIFIER LETTER CAPITAL U","	# <super> 0055"},
/* 1D42 */ { "MODIFIER LETTER CAPITAL W","	# <super> 0057"},
/* 1D43 */ { "MODIFIER LETTER SMALL A","	# <super> 0061"},
/* 1D44 */ { "MODIFIER LETTER SMALL TURNED A","	# <super> 0250"},
/* 1D45 */ { "MODIFIER LETTER SMALL ALPHA","	# <super> 0251"},
/* 1D46 */ { "MODIFIER LETTER SMALL TURNED AE","	# <super> 1D02"},
/* 1D47 */ { "MODIFIER LETTER SMALL B","	# <super> 0062"},
/* 1D48 */ { "MODIFIER LETTER SMALL D","	# <super> 0064"},
/* 1D49 */ { "MODIFIER LETTER SMALL E","	# <super> 0065"},
/* 1D4A */ { "MODIFIER LETTER SMALL SCHWA","	# <super> 0259"},
/* 1D4B */ { "MODIFIER LETTER SMALL OPEN E","	# <super> 025B"},
/* 1D4C */ { "MODIFIER LETTER SMALL TURNED OPEN E","	* more appropriate equivalence would be to 1D08\n"
	"	# <super> 025C"},
/* 1D4D */ { "MODIFIER LETTER SMALL G","	# <super> 0067"},
/* 1D4E */ { "MODIFIER LETTER SMALL TURNED I",NULL},
/* 1D4F */ { "MODIFIER LETTER SMALL K","	# <super> 006B"},
/* 1D50 */ { "MODIFIER LETTER SMALL M","	# <super> 006D"},
/* 1D51 */ { "MODIFIER LETTER SMALL ENG","	# <super> 014B"},
/* 1D52 */ { "MODIFIER LETTER SMALL O","	# <super> 006F"},
/* 1D53 */ { "MODIFIER LETTER SMALL OPEN O","	# <super> 0254"},
/* 1D54 */ { "MODIFIER LETTER SMALL TOP HALF O","	# <super> 1D16"},
/* 1D55 */ { "MODIFIER LETTER SMALL BOTTOM HALF O","	# <super> 1D17"},
/* 1D56 */ { "MODIFIER LETTER SMALL P","	# <super> 0070"},
/* 1D57 */ { "MODIFIER LETTER SMALL T","	# <super> 0074"},
/* 1D58 */ { "MODIFIER LETTER SMALL U","	# <super> 0075"},
/* 1D59 */ { "MODIFIER LETTER SMALL SIDEWAYS U","	# <super> 1D1D"},
/* 1D5A */ { "MODIFIER LETTER SMALL TURNED M","	# <super> 026F"},
/* 1D5B */ { "MODIFIER LETTER SMALL V","	# <super> 0076"},
/* 1D5C */ { "MODIFIER LETTER SMALL AIN","	x (latin small letter egyptological ain - A725)\n"
	"	# <super> 1D25"},
/* 1D5D */ { "MODIFIER LETTER SMALL BETA","	# <super> 03B2"},
/* 1D5E */ { "MODIFIER LETTER SMALL GREEK GAMMA","	# <super> 03B3"},
/* 1D5F */ { "MODIFIER LETTER SMALL DELTA","	# <super> 03B4"},
/* 1D60 */ { "MODIFIER LETTER SMALL GREEK PHI","	# <super> 03C6"},
/* 1D61 */ { "MODIFIER LETTER SMALL CHI","	# <super> 03C7"},
/* 1D62 */ { "LATIN SUBSCRIPT SMALL LETTER I","	# <sub> 0069"},
/* 1D63 */ { "LATIN SUBSCRIPT SMALL LETTER R","	# <sub> 0072"},
/* 1D64 */ { "LATIN SUBSCRIPT SMALL LETTER U","	# <sub> 0075"},
/* 1D65 */ { "LATIN SUBSCRIPT SMALL LETTER V","	# <sub> 0076"},
/* 1D66 */ { "GREEK SUBSCRIPT SMALL LETTER BETA","	# <sub> 03B2"},
/* 1D67 */ { "GREEK SUBSCRIPT SMALL LETTER GAMMA","	# <sub> 03B3"},
/* 1D68 */ { "GREEK SUBSCRIPT SMALL LETTER RHO","	# <sub> 03C1"},
/* 1D69 */ { "GREEK SUBSCRIPT SMALL LETTER PHI","	# <sub> 03C6"},
/* 1D6A */ { "GREEK SUBSCRIPT SMALL LETTER CHI","	# <sub> 03C7"},
/* 1D6B */ { "LATIN SMALL LETTER UE",NULL},
/* 1D6C */ { "LATIN SMALL LETTER B WITH MIDDLE TILDE",NULL},
/* 1D6D */ { "LATIN SMALL LETTER D WITH MIDDLE TILDE",NULL},
/* 1D6E */ { "LATIN SMALL LETTER F WITH MIDDLE TILDE",NULL},
/* 1D6F */ { "LATIN SMALL LETTER M WITH MIDDLE TILDE",NULL},
/* 1D70 */ { "LATIN SMALL LETTER N WITH MIDDLE TILDE",NULL},
/* 1D71 */ { "LATIN SMALL LETTER P WITH MIDDLE TILDE",NULL},
/* 1D72 */ { "LATIN SMALL LETTER R WITH MIDDLE TILDE",NULL},
/* 1D73 */ { "LATIN SMALL LETTER R WITH FISHHOOK AND MIDDLE TILDE",NULL},
/* 1D74 */ { "LATIN SMALL LETTER S WITH MIDDLE TILDE",NULL},
/* 1D75 */ { "LATIN SMALL LETTER T WITH MIDDLE TILDE",NULL},
/* 1D76 */ { "LATIN SMALL LETTER Z WITH MIDDLE TILDE",NULL},
/* 1D77 */ { "LATIN SMALL LETTER TURNED G","	* Georgian transcription\n"
	"	x (georgian letter turned gan - 10F9)"},
/* 1D78 */ { "MODIFIER LETTER CYRILLIC EN","	* sometimes substituted for 1D34 in extended IPA\n"
	"	x (modifier letter capital h - 1D34)\n"
	"	# <super> 043D"},
/* 1D79 */ { "LATIN SMALL LETTER INSULAR G","	* older Irish phonetic notation\n"
	"	* uppercase is A77D\n"
	"	x (latin small letter g - 0067)\n"
	"	x (latin small letter yogh - 021D)\n"
	"	x (latin small letter script g - 0261)\n"
	"	x (latin small letter gamma - 0263)\n"
	"	x (latin small letter closed insular g - A7D1)"},
/* 1D7A */ { "LATIN SMALL LETTER TH WITH STRIKETHROUGH","	* American dictionary usage\n"
	"	x (greek small letter theta - 03B8)"},
/* 1D7B */ { "LATIN SMALL CAPITAL LETTER I WITH STROKE","	* used with different meanings by Americanists and Oxford dictionaries\n"
	"	x (latin capital letter i with stroke - 0197)"},
/* 1D7C */ { "LATIN SMALL LETTER IOTA WITH STROKE","	* used by Russianists"},
/* 1D7D */ { "LATIN SMALL LETTER P WITH STROKE","	* used by Americanists\n"
	"	* uppercase is 2C63"},
/* 1D7E */ { "LATIN SMALL CAPITAL LETTER U WITH STROKE","	* used by Americanists\n"
	"	x (latin small letter u bar - 0289)"},
/* 1D7F */ { "LATIN SMALL LETTER UPSILON WITH STROKE","	* used by Americanists and Oxford dictionaries"},
/* 1D80 */ { "LATIN SMALL LETTER B WITH PALATAL HOOK",NULL},
/* 1D81 */ { "LATIN SMALL LETTER D WITH PALATAL HOOK",NULL},
/* 1D82 */ { "LATIN SMALL LETTER F WITH PALATAL HOOK",NULL},
/* 1D83 */ { "LATIN SMALL LETTER G WITH PALATAL HOOK",NULL},
/* 1D84 */ { "LATIN SMALL LETTER K WITH PALATAL HOOK",NULL},
/* 1D85 */ { "LATIN SMALL LETTER L WITH PALATAL HOOK",NULL},
/* 1D86 */ { "LATIN SMALL LETTER M WITH PALATAL HOOK","	x (latin small letter m with hook - 0271)"},
/* 1D87 */ { "LATIN SMALL LETTER N WITH PALATAL HOOK","	x (latin small letter eng - 014B)"},
/* 1D88 */ { "LATIN SMALL LETTER P WITH PALATAL HOOK",NULL},
/* 1D89 */ { "LATIN SMALL LETTER R WITH PALATAL HOOK",NULL},
/* 1D8A */ { "LATIN SMALL LETTER S WITH PALATAL HOOK",NULL},
/* 1D8B */ { "LATIN SMALL LETTER ESH WITH PALATAL HOOK",NULL},
/* 1D8C */ { "LATIN SMALL LETTER V WITH PALATAL HOOK",NULL},
/* 1D8D */ { "LATIN SMALL LETTER X WITH PALATAL HOOK",NULL},
/* 1D8E */ { "LATIN SMALL LETTER Z WITH PALATAL HOOK","	* uppercase is A7C6\n"
	"	x (latin small letter z with hook - 0225)"},
/* 1D8F */ { "LATIN SMALL LETTER A WITH RETROFLEX HOOK",NULL},
/* 1D90 */ { "LATIN SMALL LETTER ALPHA WITH RETROFLEX HOOK",NULL},
/* 1D91 */ { "LATIN SMALL LETTER D WITH HOOK AND TAIL",NULL},
/* 1D92 */ { "LATIN SMALL LETTER E WITH RETROFLEX HOOK",NULL},
/* 1D93 */ { "LATIN SMALL LETTER OPEN E WITH RETROFLEX HOOK",NULL},
/* 1D94 */ { "LATIN SMALL LETTER REVERSED OPEN E WITH RETROFLEX HOOK","	x (latin small letter reversed open e with hook - 025D)"},
/* 1D95 */ { "LATIN SMALL LETTER SCHWA WITH RETROFLEX HOOK","	x (latin small letter schwa with hook - 025A)"},
/* 1D96 */ { "LATIN SMALL LETTER I WITH RETROFLEX HOOK",NULL},
/* 1D97 */ { "LATIN SMALL LETTER OPEN O WITH RETROFLEX HOOK",NULL},
/* 1D98 */ { "LATIN SMALL LETTER ESH WITH RETROFLEX HOOK",NULL},
/* 1D99 */ { "LATIN SMALL LETTER U WITH RETROFLEX HOOK",NULL},
/* 1D9A */ { "LATIN SMALL LETTER EZH WITH RETROFLEX HOOK",NULL},
/* 1D9B */ { "MODIFIER LETTER SMALL TURNED ALPHA","	# <super> 0252"},
/* 1D9C */ { "MODIFIER LETTER SMALL C","	# <super> 0063"},
/* 1D9D */ { "MODIFIER LETTER SMALL C WITH CURL","	# <super> 0255"},
/* 1D9E */ { "MODIFIER LETTER SMALL ETH","	# <super> 00F0"},
/* 1D9F */ { "MODIFIER LETTER SMALL REVERSED OPEN E","	# <super> 025C"},
/* 1DA0 */ { "MODIFIER LETTER SMALL F","	# <super> 0066"},
/* 1DA1 */ { "MODIFIER LETTER SMALL DOTLESS J WITH STROKE","	# <super> 025F"},
/* 1DA2 */ { "MODIFIER LETTER SMALL SCRIPT G","	# <super> 0261"},
/* 1DA3 */ { "MODIFIER LETTER SMALL TURNED H","	# <super> 0265"},
/* 1DA4 */ { "MODIFIER LETTER SMALL I WITH STROKE","	# <super> 0268"},
/* 1DA5 */ { "MODIFIER LETTER SMALL IOTA","	# <super> 0269"},
/* 1DA6 */ { "MODIFIER LETTER SMALL CAPITAL I","	* not for use in UPA\n"
	"	x (modifier letter capital i - 1D35)\n"
	"	# <super> 026A"},
/* 1DA7 */ { "MODIFIER LETTER SMALL CAPITAL I WITH STROKE","	# <super> 1D7B"},
/* 1DA8 */ { "MODIFIER LETTER SMALL J WITH CROSSED-TAIL","	# <super> 029D"},
/* 1DA9 */ { "MODIFIER LETTER SMALL L WITH RETROFLEX HOOK","	# <super> 026D"},
/* 1DAA */ { "MODIFIER LETTER SMALL L WITH PALATAL HOOK","	# <super> 1D85"},
/* 1DAB */ { "MODIFIER LETTER SMALL CAPITAL L","	* not for use in UPA\n"
	"	x (modifier letter capital l - 1D38)\n"
	"	# <super> 029F"},
/* 1DAC */ { "MODIFIER LETTER SMALL M WITH HOOK","	# <super> 0271"},
/* 1DAD */ { "MODIFIER LETTER SMALL TURNED M WITH LONG LEG","	# <super> 0270"},
/* 1DAE */ { "MODIFIER LETTER SMALL N WITH LEFT HOOK","	# <super> 0272"},
/* 1DAF */ { "MODIFIER LETTER SMALL N WITH RETROFLEX HOOK","	# <super> 0273"},
/* 1DB0 */ { "MODIFIER LETTER SMALL CAPITAL N","	* not for use in UPA\n"
	"	x (modifier letter capital n - 1D3A)\n"
	"	# <super> 0274"},
/* 1DB1 */ { "MODIFIER LETTER SMALL BARRED O","	# <super> 0275"},
/* 1DB2 */ { "MODIFIER LETTER SMALL PHI","	# <super> 0278"},
/* 1DB3 */ { "MODIFIER LETTER SMALL S WITH HOOK","	# <super> 0282"},
/* 1DB4 */ { "MODIFIER LETTER SMALL ESH","	# <super> 0283"},
/* 1DB5 */ { "MODIFIER LETTER SMALL T WITH PALATAL HOOK","	# <super> 01AB"},
/* 1DB6 */ { "MODIFIER LETTER SMALL U BAR","	# <super> 0289"},
/* 1DB7 */ { "MODIFIER LETTER SMALL UPSILON","	# <super> 028A"},
/* 1DB8 */ { "MODIFIER LETTER SMALL CAPITAL U","	* not for use in UPA\n"
	"	x (modifier letter capital u - 1D41)\n"
	"	# <super> 1D1C"},
/* 1DB9 */ { "MODIFIER LETTER SMALL V WITH HOOK","	# <super> 028B"},
/* 1DBA */ { "MODIFIER LETTER SMALL TURNED V","	# <super> 028C"},
/* 1DBB */ { "MODIFIER LETTER SMALL Z","	# <super> 007A"},
/* 1DBC */ { "MODIFIER LETTER SMALL Z WITH RETROFLEX HOOK","	# <super> 0290"},
/* 1DBD */ { "MODIFIER LETTER SMALL Z WITH CURL","	# <super> 0291"},
/* 1DBE */ { "MODIFIER LETTER SMALL EZH","	# <super> 0292"},
/* 1DBF */ { "MODIFIER LETTER SMALL THETA","	# <super> 03B8"},
/* 1DC0 */ { "COMBINING DOTTED GRAVE ACCENT","	x (combining grave accent - 0300)\n"
	"	x (greek dialytika and varia - 1FED)"},
/* 1DC1 */ { "COMBINING DOTTED ACUTE ACCENT","	x (combining acute accent - 0301)\n"
	"	x (combining greek dialytika tonos - 0344)\n"
	"	x (greek dialytika and oxia - 1FEE)"},
/* 1DC2 */ { "COMBINING SNAKE BELOW",NULL},
/* 1DC3 */ { "COMBINING SUSPENSION MARK","	* abbreviation mark in Glagolitic\n"
	"	x (combining breve - 0306)"},
/* 1DC4 */ { "COMBINING MACRON-ACUTE","	* also used to represent the Middle Vietnamese \"apex\" diacritic (dấu sóng)\n"
	"	x (combining tilde - 0303)"},
/* 1DC5 */ { "COMBINING GRAVE-MACRON",NULL},
/* 1DC6 */ { "COMBINING MACRON-GRAVE",NULL},
/* 1DC7 */ { "COMBINING ACUTE-MACRON",NULL},
/* 1DC8 */ { "COMBINING GRAVE-ACUTE-GRAVE",NULL},
/* 1DC9 */ { "COMBINING ACUTE-GRAVE-ACUTE",NULL},
/* 1DCA */ { "COMBINING LATIN SMALL LETTER R BELOW",NULL},
/* 1DCB */ { "COMBINING BREVE-MACRON","	* Lithuanian dialectology"},
/* 1DCC */ { "COMBINING MACRON-BREVE","	* Lithuanian dialectology"},
/* 1DCD */ { "COMBINING DOUBLE CIRCUMFLEX ABOVE",NULL},
/* 1DCE */ { "COMBINING OGONEK ABOVE",NULL},
/* 1DCF */ { "COMBINING ZIGZAG BELOW",NULL},
/* 1DD0 */ { "COMBINING IS BELOW",NULL},
/* 1DD1 */ { "COMBINING UR ABOVE",NULL},
/* 1DD2 */ { "COMBINING US ABOVE",NULL},
/* 1DD3 */ { "COMBINING LATIN SMALL LETTER FLATTENED OPEN A ABOVE",NULL},
/* 1DD4 */ { "COMBINING LATIN SMALL LETTER AE",NULL},
/* 1DD5 */ { "COMBINING LATIN SMALL LETTER AO",NULL},
/* 1DD6 */ { "COMBINING LATIN SMALL LETTER AV",NULL},
/* 1DD7 */ { "COMBINING LATIN SMALL LETTER C CEDILLA",NULL},
/* 1DD8 */ { "COMBINING LATIN SMALL LETTER INSULAR D",NULL},
/* 1DD9 */ { "COMBINING LATIN SMALL LETTER ETH",NULL},
/* 1DDA */ { "COMBINING LATIN SMALL LETTER G",NULL},
/* 1DDB */ { "COMBINING LATIN LETTER SMALL CAPITAL G",NULL},
/* 1DDC */ { "COMBINING LATIN SMALL LETTER K",NULL},
/* 1DDD */ { "COMBINING LATIN SMALL LETTER L",NULL},
/* 1DDE */ { "COMBINING LATIN LETTER SMALL CAPITAL L",NULL},
/* 1DDF */ { "COMBINING LATIN LETTER SMALL CAPITAL M",NULL},
/* 1DE0 */ { "COMBINING LATIN SMALL LETTER N",NULL},
/* 1DE1 */ { "COMBINING LATIN LETTER SMALL CAPITAL N",NULL},
/* 1DE2 */ { "COMBINING LATIN LETTER SMALL CAPITAL R",NULL},
/* 1DE3 */ { "COMBINING LATIN SMALL LETTER R ROTUNDA",NULL},
/* 1DE4 */ { "COMBINING LATIN SMALL LETTER S",NULL},
/* 1DE5 */ { "COMBINING LATIN SMALL LETTER LONG S",NULL},
/* 1DE6 */ { "COMBINING LATIN SMALL LETTER Z",NULL},
/* 1DE7 */ { "COMBINING LATIN SMALL LETTER ALPHA",NULL},
/* 1DE8 */ { "COMBINING LATIN SMALL LETTER B",NULL},
/* 1DE9 */ { "COMBINING LATIN SMALL LETTER BETA",NULL},
/* 1DEA */ { "COMBINING LATIN SMALL LETTER SCHWA",NULL},
/* 1DEB */ { "COMBINING LATIN SMALL LETTER F",NULL},
/* 1DEC */ { "COMBINING LATIN SMALL LETTER L WITH DOUBLE MIDDLE TILDE",NULL},
/* 1DED */ { "COMBINING LATIN SMALL LETTER O WITH LIGHT CENTRALIZATION STROKE",NULL},
/* 1DEE */ { "COMBINING LATIN SMALL LETTER P",NULL},
/* 1DEF */ { "COMBINING LATIN SMALL LETTER ESH",NULL},
/* 1DF0 */ { "COMBINING LATIN SMALL LETTER U WITH LIGHT CENTRALIZATION STROKE",NULL},
/* 1DF1 */ { "COMBINING LATIN SMALL LETTER W","	x (combining latin small letter w below - 1ABF)\n"
	"	x (combining inverted double arch above - 1AC7)"},
/* 1DF2 */ { "COMBINING LATIN SMALL LETTER A WITH DIAERESIS",NULL},
/* 1DF3 */ { "COMBINING LATIN SMALL LETTER O WITH DIAERESIS",NULL},
/* 1DF4 */ { "COMBINING LATIN SMALL LETTER U WITH DIAERESIS",NULL},
/* 1DF5 */ { "COMBINING UP TACK ABOVE","	x (combining up tack below - 031D)"},
/* 1DF6 */ { "COMBINING KAVYKA ABOVE RIGHT",NULL},
/* 1DF7 */ { "COMBINING KAVYKA ABOVE LEFT","	x (combining cyrillic kavyka - A67C)"},
/* 1DF8 */ { "COMBINING DOT ABOVE LEFT","	* used in Syriac as a disambiguation dot\n"
	"	* used in Typicon Cyrillic, where the dot may have a square appearance\n"
	"	* used in the Latin-based Americanist phonetic notation of Franz Boas\n"
	"	x (combining dot above right - 0358)\n"
	"	x (syriac feminine dot - 0740)"},
/* 1DF9 */ { "COMBINING WIDE INVERTED BRIDGE BELOW","	* used as a Typicon mark\n"
	"	x (combining inverted bridge below - 033A)"},
/* 1DFA */ { "COMBINING DOT BELOW LEFT","	* used in Syriac as a disambiguation dot"},
/* 1DFB */ { "COMBINING DELETION MARK","	* used for \"mhusaa\" in Newa scribal tradition"},
/* 1DFC */ { "COMBINING DOUBLE INVERTED BREVE BELOW",NULL},
/* 1DFD */ { "COMBINING ALMOST EQUAL TO BELOW","	* diacritic indicating a strident vowel in Khoisan languages"},
/* 1DFE */ { "COMBINING LEFT ARROWHEAD ABOVE","	x (combining left arrowhead below - 0354)"},
/* 1DFF */ { "COMBINING RIGHT ARROWHEAD AND DOWN ARROWHEAD BELOW",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_00_1E[] = {
/* 1E00 */ { "LATIN CAPITAL LETTER A WITH RING BELOW","	: 0041 0325"},
/* 1E01 */ { "LATIN SMALL LETTER A WITH RING BELOW","	: 0061 0325"},
/* 1E02 */ { "LATIN CAPITAL LETTER B WITH DOT ABOVE","	: 0042 0307"},
/* 1E03 */ { "LATIN SMALL LETTER B WITH DOT ABOVE","	* Irish Gaelic (old orthography)\n"
	"	: 0062 0307"},
/* 1E04 */ { "LATIN CAPITAL LETTER B WITH DOT BELOW","	: 0042 0323"},
/* 1E05 */ { "LATIN SMALL LETTER B WITH DOT BELOW","	: 0062 0323"},
/* 1E06 */ { "LATIN CAPITAL LETTER B WITH LINE BELOW","	: 0042 0331"},
/* 1E07 */ { "LATIN SMALL LETTER B WITH LINE BELOW","	: 0062 0331"},
/* 1E08 */ { "LATIN CAPITAL LETTER C WITH CEDILLA AND ACUTE","	: 00C7 0301"},
/* 1E09 */ { "LATIN SMALL LETTER C WITH CEDILLA AND ACUTE","	: 00E7 0301"},
/* 1E0A */ { "LATIN CAPITAL LETTER D WITH DOT ABOVE","	: 0044 0307"},
/* 1E0B */ { "LATIN SMALL LETTER D WITH DOT ABOVE","	* Irish Gaelic (old orthography)\n"
	"	: 0064 0307"},
/* 1E0C */ { "LATIN CAPITAL LETTER D WITH DOT BELOW","	: 0044 0323"},
/* 1E0D */ { "LATIN SMALL LETTER D WITH DOT BELOW","	* Indic transliteration\n"
	"	: 0064 0323"},
/* 1E0E */ { "LATIN CAPITAL LETTER D WITH LINE BELOW","	: 0044 0331"},
/* 1E0F */ { "LATIN SMALL LETTER D WITH LINE BELOW","	: 0064 0331"},
/* 1E10 */ { "LATIN CAPITAL LETTER D WITH CEDILLA","	: 0044 0327"},
/* 1E11 */ { "LATIN SMALL LETTER D WITH CEDILLA","	* Livonian\n"
	"	* despite their names, this pair of characters should normally be displayed with a comma below\n"
	"	: 0064 0327"},
/* 1E12 */ { "LATIN CAPITAL LETTER D WITH CIRCUMFLEX BELOW","	: 0044 032D"},
/* 1E13 */ { "LATIN SMALL LETTER D WITH CIRCUMFLEX BELOW","	: 0064 032D"},
/* 1E14 */ { "LATIN CAPITAL LETTER E WITH MACRON AND GRAVE","	: 0112 0300"},
/* 1E15 */ { "LATIN SMALL LETTER E WITH MACRON AND GRAVE","	: 0113 0300"},
/* 1E16 */ { "LATIN CAPITAL LETTER E WITH MACRON AND ACUTE","	: 0112 0301"},
/* 1E17 */ { "LATIN SMALL LETTER E WITH MACRON AND ACUTE","	: 0113 0301"},
/* 1E18 */ { "LATIN CAPITAL LETTER E WITH CIRCUMFLEX BELOW","	: 0045 032D"},
/* 1E19 */ { "LATIN SMALL LETTER E WITH CIRCUMFLEX BELOW","	: 0065 032D"},
/* 1E1A */ { "LATIN CAPITAL LETTER E WITH TILDE BELOW","	: 0045 0330"},
/* 1E1B */ { "LATIN SMALL LETTER E WITH TILDE BELOW","	: 0065 0330"},
/* 1E1C */ { "LATIN CAPITAL LETTER E WITH CEDILLA AND BREVE","	: 0228 0306"},
/* 1E1D */ { "LATIN SMALL LETTER E WITH CEDILLA AND BREVE","	* Hebrew transliteration\n"
	"	: 0229 0306"},
/* 1E1E */ { "LATIN CAPITAL LETTER F WITH DOT ABOVE","	: 0046 0307"},
/* 1E1F */ { "LATIN SMALL LETTER F WITH DOT ABOVE","	* Irish Gaelic (old orthography)\n"
	"	: 0066 0307"},
/* 1E20 */ { "LATIN CAPITAL LETTER G WITH MACRON","	: 0047 0304"},
/* 1E21 */ { "LATIN SMALL LETTER G WITH MACRON","	: 0067 0304"},
/* 1E22 */ { "LATIN CAPITAL LETTER H WITH DOT ABOVE","	: 0048 0307"},
/* 1E23 */ { "LATIN SMALL LETTER H WITH DOT ABOVE","	: 0068 0307"},
/* 1E24 */ { "LATIN CAPITAL LETTER H WITH DOT BELOW","	: 0048 0323"},
/* 1E25 */ { "LATIN SMALL LETTER H WITH DOT BELOW","	* Indic transliteration\n"
	"	: 0068 0323"},
/* 1E26 */ { "LATIN CAPITAL LETTER H WITH DIAERESIS","	: 0048 0308"},
/* 1E27 */ { "LATIN SMALL LETTER H WITH DIAERESIS","	: 0068 0308"},
/* 1E28 */ { "LATIN CAPITAL LETTER H WITH CEDILLA","	: 0048 0327"},
/* 1E29 */ { "LATIN SMALL LETTER H WITH CEDILLA","	: 0068 0327"},
/* 1E2A */ { "LATIN CAPITAL LETTER H WITH BREVE BELOW","	: 0048 032E"},
/* 1E2B */ { "LATIN SMALL LETTER H WITH BREVE BELOW","	* Semitic transliteration\n"
	"	: 0068 032E"},
/* 1E2C */ { "LATIN CAPITAL LETTER I WITH TILDE BELOW","	: 0049 0330"},
/* 1E2D */ { "LATIN SMALL LETTER I WITH TILDE BELOW","	: 0069 0330"},
/* 1E2E */ { "LATIN CAPITAL LETTER I WITH DIAERESIS AND ACUTE","	: 00CF 0301"},
/* 1E2F */ { "LATIN SMALL LETTER I WITH DIAERESIS AND ACUTE","	: 00EF 0301"},
/* 1E30 */ { "LATIN CAPITAL LETTER K WITH ACUTE","	: 004B 0301"},
/* 1E31 */ { "LATIN SMALL LETTER K WITH ACUTE","	* Macedonian transliteration\n"
	"	: 006B 0301"},
/* 1E32 */ { "LATIN CAPITAL LETTER K WITH DOT BELOW","	: 004B 0323"},
/* 1E33 */ { "LATIN SMALL LETTER K WITH DOT BELOW","	: 006B 0323"},
/* 1E34 */ { "LATIN CAPITAL LETTER K WITH LINE BELOW","	: 004B 0331"},
/* 1E35 */ { "LATIN SMALL LETTER K WITH LINE BELOW","	: 006B 0331"},
/* 1E36 */ { "LATIN CAPITAL LETTER L WITH DOT BELOW","	: 004C 0323"},
/* 1E37 */ { "LATIN SMALL LETTER L WITH DOT BELOW","	* Indic transliteration\n"
	"	* see ISO 15919 on the use of dot below versus ring below in Indic transliteration\n"
	"	x (combining ring below - 0325)\n"
	"	: 006C 0323"},
/* 1E38 */ { "LATIN CAPITAL LETTER L WITH DOT BELOW AND MACRON","	: 1E36 0304"},
/* 1E39 */ { "LATIN SMALL LETTER L WITH DOT BELOW AND MACRON","	* Indic transliteration\n"
	"	: 1E37 0304"},
/* 1E3A */ { "LATIN CAPITAL LETTER L WITH LINE BELOW","	: 004C 0331"},
/* 1E3B */ { "LATIN SMALL LETTER L WITH LINE BELOW","	* Indic transliteration\n"
	"	: 006C 0331"},
/* 1E3C */ { "LATIN CAPITAL LETTER L WITH CIRCUMFLEX BELOW","	: 004C 032D"},
/* 1E3D */ { "LATIN SMALL LETTER L WITH CIRCUMFLEX BELOW","	: 006C 032D"},
/* 1E3E */ { "LATIN CAPITAL LETTER M WITH ACUTE","	: 004D 0301"},
/* 1E3F */ { "LATIN SMALL LETTER M WITH ACUTE","	: 006D 0301"},
/* 1E40 */ { "LATIN CAPITAL LETTER M WITH DOT ABOVE","	: 004D 0307"},
/* 1E41 */ { "LATIN SMALL LETTER M WITH DOT ABOVE","	* Irish Gaelic (old orthography)\n"
	"	: 006D 0307"},
/* 1E42 */ { "LATIN CAPITAL LETTER M WITH DOT BELOW","	: 004D 0323"},
/* 1E43 */ { "LATIN SMALL LETTER M WITH DOT BELOW","	* Indic transliteration\n"
	"	: 006D 0323"},
/* 1E44 */ { "LATIN CAPITAL LETTER N WITH DOT ABOVE","	: 004E 0307"},
/* 1E45 */ { "LATIN SMALL LETTER N WITH DOT ABOVE","	* Indic transliteration\n"
	"	: 006E 0307"},
/* 1E46 */ { "LATIN CAPITAL LETTER N WITH DOT BELOW","	: 004E 0323"},
/* 1E47 */ { "LATIN SMALL LETTER N WITH DOT BELOW","	* Indic transliteration\n"
	"	: 006E 0323"},
/* 1E48 */ { "LATIN CAPITAL LETTER N WITH LINE BELOW","	: 004E 0331"},
/* 1E49 */ { "LATIN SMALL LETTER N WITH LINE BELOW","	* Indic transliteration\n"
	"	: 006E 0331"},
/* 1E4A */ { "LATIN CAPITAL LETTER N WITH CIRCUMFLEX BELOW","	: 004E 032D"},
/* 1E4B */ { "LATIN SMALL LETTER N WITH CIRCUMFLEX BELOW","	: 006E 032D"},
/* 1E4C */ { "LATIN CAPITAL LETTER O WITH TILDE AND ACUTE","	: 00D5 0301"},
/* 1E4D */ { "LATIN SMALL LETTER O WITH TILDE AND ACUTE","	: 00F5 0301"},
/* 1E4E */ { "LATIN CAPITAL LETTER O WITH TILDE AND DIAERESIS","	: 00D5 0308"},
/* 1E4F */ { "LATIN SMALL LETTER O WITH TILDE AND DIAERESIS","	: 00F5 0308"},
/* 1E50 */ { "LATIN CAPITAL LETTER O WITH MACRON AND GRAVE","	: 014C 0300"},
/* 1E51 */ { "LATIN SMALL LETTER O WITH MACRON AND GRAVE","	: 014D 0300"},
/* 1E52 */ { "LATIN CAPITAL LETTER O WITH MACRON AND ACUTE","	: 014C 0301"},
/* 1E53 */ { "LATIN SMALL LETTER O WITH MACRON AND ACUTE","	: 014D 0301"},
/* 1E54 */ { "LATIN CAPITAL LETTER P WITH ACUTE","	: 0050 0301"},
/* 1E55 */ { "LATIN SMALL LETTER P WITH ACUTE","	: 0070 0301"},
/* 1E56 */ { "LATIN CAPITAL LETTER P WITH DOT ABOVE","	: 0050 0307"},
/* 1E57 */ { "LATIN SMALL LETTER P WITH DOT ABOVE","	* Irish Gaelic (old orthography)\n"
	"	: 0070 0307"},
/* 1E58 */ { "LATIN CAPITAL LETTER R WITH DOT ABOVE","	: 0052 0307"},
/* 1E59 */ { "LATIN SMALL LETTER R WITH DOT ABOVE","	: 0072 0307"},
/* 1E5A */ { "LATIN CAPITAL LETTER R WITH DOT BELOW","	: 0052 0323"},
/* 1E5B */ { "LATIN SMALL LETTER R WITH DOT BELOW","	* Indic transliteration\n"
	"	* see ISO 15919 on the use of dot below versus ring below in Indic transliteration\n"
	"	x (combining ring below - 0325)\n"
	"	: 0072 0323"},
/* 1E5C */ { "LATIN CAPITAL LETTER R WITH DOT BELOW AND MACRON","	: 1E5A 0304"},
/* 1E5D */ { "LATIN SMALL LETTER R WITH DOT BELOW AND MACRON","	* Indic transliteration\n"
	"	: 1E5B 0304"},
/* 1E5E */ { "LATIN CAPITAL LETTER R WITH LINE BELOW","	: 0052 0331"},
/* 1E5F */ { "LATIN SMALL LETTER R WITH LINE BELOW","	* Indic transliteration\n"
	"	: 0072 0331"},
/* 1E60 */ { "LATIN CAPITAL LETTER S WITH DOT ABOVE","	: 0053 0307"},
/* 1E61 */ { "LATIN SMALL LETTER S WITH DOT ABOVE","	* Irish Gaelic (old orthography)\n"
	"	: 0073 0307"},
/* 1E62 */ { "LATIN CAPITAL LETTER S WITH DOT BELOW","	: 0053 0323"},
/* 1E63 */ { "LATIN SMALL LETTER S WITH DOT BELOW","	* Indic transliteration\n"
	"	: 0073 0323"},
/* 1E64 */ { "LATIN CAPITAL LETTER S WITH ACUTE AND DOT ABOVE","	: 015A 0307"},
/* 1E65 */ { "LATIN SMALL LETTER S WITH ACUTE AND DOT ABOVE","	: 015B 0307"},
/* 1E66 */ { "LATIN CAPITAL LETTER S WITH CARON AND DOT ABOVE","	: 0160 0307"},
/* 1E67 */ { "LATIN SMALL LETTER S WITH CARON AND DOT ABOVE","	: 0161 0307"},
/* 1E68 */ { "LATIN CAPITAL LETTER S WITH DOT BELOW AND DOT ABOVE","	: 1E62 0307"},
/* 1E69 */ { "LATIN SMALL LETTER S WITH DOT BELOW AND DOT ABOVE","	: 1E63 0307"},
/* 1E6A */ { "LATIN CAPITAL LETTER T WITH DOT ABOVE","	: 0054 0307"},
/* 1E6B */ { "LATIN SMALL LETTER T WITH DOT ABOVE","	* Irish Gaelic (old orthography)\n"
	"	: 0074 0307"},
/* 1E6C */ { "LATIN CAPITAL LETTER T WITH DOT BELOW","	: 0054 0323"},
/* 1E6D */ { "LATIN SMALL LETTER T WITH DOT BELOW","	* Indic transliteration\n"
	"	: 0074 0323"},
/* 1E6E */ { "LATIN CAPITAL LETTER T WITH LINE BELOW","	: 0054 0331"},
/* 1E6F */ { "LATIN SMALL LETTER T WITH LINE BELOW","	* Semitic transliteration\n"
	"	: 0074 0331"},
/* 1E70 */ { "LATIN CAPITAL LETTER T WITH CIRCUMFLEX BELOW","	: 0054 032D"},
/* 1E71 */ { "LATIN SMALL LETTER T WITH CIRCUMFLEX BELOW","	: 0074 032D"},
/* 1E72 */ { "LATIN CAPITAL LETTER U WITH DIAERESIS BELOW","	: 0055 0324"},
/* 1E73 */ { "LATIN SMALL LETTER U WITH DIAERESIS BELOW","	: 0075 0324"},
/* 1E74 */ { "LATIN CAPITAL LETTER U WITH TILDE BELOW","	: 0055 0330"},
/* 1E75 */ { "LATIN SMALL LETTER U WITH TILDE BELOW","	: 0075 0330"},
/* 1E76 */ { "LATIN CAPITAL LETTER U WITH CIRCUMFLEX BELOW","	: 0055 032D"},
/* 1E77 */ { "LATIN SMALL LETTER U WITH CIRCUMFLEX BELOW","	: 0075 032D"},
/* 1E78 */ { "LATIN CAPITAL LETTER U WITH TILDE AND ACUTE","	: 0168 0301"},
/* 1E79 */ { "LATIN SMALL LETTER U WITH TILDE AND ACUTE","	: 0169 0301"},
/* 1E7A */ { "LATIN CAPITAL LETTER U WITH MACRON AND DIAERESIS","	: 016A 0308"},
/* 1E7B */ { "LATIN SMALL LETTER U WITH MACRON AND DIAERESIS","	: 016B 0308"},
/* 1E7C */ { "LATIN CAPITAL LETTER V WITH TILDE","	: 0056 0303"},
/* 1E7D */ { "LATIN SMALL LETTER V WITH TILDE","	: 0076 0303"},
/* 1E7E */ { "LATIN CAPITAL LETTER V WITH DOT BELOW","	: 0056 0323"},
/* 1E7F */ { "LATIN SMALL LETTER V WITH DOT BELOW","	: 0076 0323"},
/* 1E80 */ { "LATIN CAPITAL LETTER W WITH GRAVE","	: 0057 0300"},
/* 1E81 */ { "LATIN SMALL LETTER W WITH GRAVE","	* Welsh\n"
	"	: 0077 0300"},
/* 1E82 */ { "LATIN CAPITAL LETTER W WITH ACUTE","	: 0057 0301"},
/* 1E83 */ { "LATIN SMALL LETTER W WITH ACUTE","	* Welsh\n"
	"	: 0077 0301"},
/* 1E84 */ { "LATIN CAPITAL LETTER W WITH DIAERESIS","	: 0057 0308"},
/* 1E85 */ { "LATIN SMALL LETTER W WITH DIAERESIS","	* Welsh\n"
	"	: 0077 0308"},
/* 1E86 */ { "LATIN CAPITAL LETTER W WITH DOT ABOVE","	: 0057 0307"},
/* 1E87 */ { "LATIN SMALL LETTER W WITH DOT ABOVE","	: 0077 0307"},
/* 1E88 */ { "LATIN CAPITAL LETTER W WITH DOT BELOW","	: 0057 0323"},
/* 1E89 */ { "LATIN SMALL LETTER W WITH DOT BELOW","	: 0077 0323"},
/* 1E8A */ { "LATIN CAPITAL LETTER X WITH DOT ABOVE","	: 0058 0307"},
/* 1E8B */ { "LATIN SMALL LETTER X WITH DOT ABOVE","	: 0078 0307"},
/* 1E8C */ { "LATIN CAPITAL LETTER X WITH DIAERESIS","	: 0058 0308"},
/* 1E8D */ { "LATIN SMALL LETTER X WITH DIAERESIS","	: 0078 0308"},
/* 1E8E */ { "LATIN CAPITAL LETTER Y WITH DOT ABOVE","	: 0059 0307"},
/* 1E8F */ { "LATIN SMALL LETTER Y WITH DOT ABOVE","	: 0079 0307"},
/* 1E90 */ { "LATIN CAPITAL LETTER Z WITH CIRCUMFLEX","	: 005A 0302"},
/* 1E91 */ { "LATIN SMALL LETTER Z WITH CIRCUMFLEX","	: 007A 0302"},
/* 1E92 */ { "LATIN CAPITAL LETTER Z WITH DOT BELOW","	: 005A 0323"},
/* 1E93 */ { "LATIN SMALL LETTER Z WITH DOT BELOW","	* Semitic transliteration\n"
	"	x (arabic letter zah - 0638)\n"
	"	: 007A 0323"},
/* 1E94 */ { "LATIN CAPITAL LETTER Z WITH LINE BELOW","	: 005A 0331"},
/* 1E95 */ { "LATIN SMALL LETTER Z WITH LINE BELOW","	* Semitic transliteration\n"
	"	: 007A 0331"},
/* 1E96 */ { "LATIN SMALL LETTER H WITH LINE BELOW","	* Semitic transliteration\n"
	"	: 0068 0331"},
/* 1E97 */ { "LATIN SMALL LETTER T WITH DIAERESIS","	: 0074 0308"},
/* 1E98 */ { "LATIN SMALL LETTER W WITH RING ABOVE","	: 0077 030A"},
/* 1E99 */ { "LATIN SMALL LETTER Y WITH RING ABOVE","	: 0079 030A"},
/* 1E9A */ { "LATIN SMALL LETTER A WITH RIGHT HALF RING","	# 0061 02BE"},
/* 1E9B */ { "LATIN SMALL LETTER LONG S WITH DOT ABOVE","	* in current use in Gaelic types (as glyph variant of 1E61)\n"
	"	: 017F 0307"},
/* 1E9C */ { "LATIN SMALL LETTER LONG S WITH DIAGONAL STROKE","	* medievalist use for several abbreviations\n"
	"	* used in pre-1921 Latvian orthography\n"
	"	* used in Blackletter types of pre-1950 Lower Sorbian orthography\n"
	"	x (latin small letter s with oblique stroke - A7A9)"},
/* 1E9D */ { "LATIN SMALL LETTER LONG S WITH HIGH STROKE",NULL},
/* 1E9E */ { "LATIN CAPITAL LETTER SHARP S","	* not used in Swiss High German\n"
	"	* lowercase is 00DF\n"
	"	x (latin small letter sharp s - 00DF)\n"
	"	x (latin capital letter middle scots s - A7D6)"},
/* 1E9F */ { "LATIN SMALL LETTER DELTA","	* this is a non-casing letter\n"
	"	x (greek small letter delta - 03B4)"},
/* 1EA0 */ { "LATIN CAPITAL LETTER A WITH DOT BELOW","	: 0041 0323"},
/* 1EA1 */ { "LATIN SMALL LETTER A WITH DOT BELOW","	: 0061 0323"},
/* 1EA2 */ { "LATIN CAPITAL LETTER A WITH HOOK ABOVE","	: 0041 0309"},
/* 1EA3 */ { "LATIN SMALL LETTER A WITH HOOK ABOVE","	: 0061 0309"},
/* 1EA4 */ { "LATIN CAPITAL LETTER A WITH CIRCUMFLEX AND ACUTE","	: 00C2 0301"},
/* 1EA5 */ { "LATIN SMALL LETTER A WITH CIRCUMFLEX AND ACUTE","	: 00E2 0301"},
/* 1EA6 */ { "LATIN CAPITAL LETTER A WITH CIRCUMFLEX AND GRAVE","	: 00C2 0300"},
/* 1EA7 */ { "LATIN SMALL LETTER A WITH CIRCUMFLEX AND GRAVE","	: 00E2 0300"},
/* 1EA8 */ { "LATIN CAPITAL LETTER A WITH CIRCUMFLEX AND HOOK ABOVE","	: 00C2 0309"},
/* 1EA9 */ { "LATIN SMALL LETTER A WITH CIRCUMFLEX AND HOOK ABOVE","	: 00E2 0309"},
/* 1EAA */ { "LATIN CAPITAL LETTER A WITH CIRCUMFLEX AND TILDE","	: 00C2 0303"},
/* 1EAB */ { "LATIN SMALL LETTER A WITH CIRCUMFLEX AND TILDE","	: 00E2 0303"},
/* 1EAC */ { "LATIN CAPITAL LETTER A WITH CIRCUMFLEX AND DOT BELOW","	: 1EA0 0302"},
/* 1EAD */ { "LATIN SMALL LETTER A WITH CIRCUMFLEX AND DOT BELOW","	: 1EA1 0302"},
/* 1EAE */ { "LATIN CAPITAL LETTER A WITH BREVE AND ACUTE","	: 0102 0301"},
/* 1EAF */ { "LATIN SMALL LETTER A WITH BREVE AND ACUTE","	: 0103 0301"},
/* 1EB0 */ { "LATIN CAPITAL LETTER A WITH BREVE AND GRAVE","	: 0102 0300"},
/* 1EB1 */ { "LATIN SMALL LETTER A WITH BREVE AND GRAVE","	: 0103 0300"},
/* 1EB2 */ { "LATIN CAPITAL LETTER A WITH BREVE AND HOOK ABOVE","	: 0102 0309"},
/* 1EB3 */ { "LATIN SMALL LETTER A WITH BREVE AND HOOK ABOVE","	: 0103 0309"},
/* 1EB4 */ { "LATIN CAPITAL LETTER A WITH BREVE AND TILDE","	: 0102 0303"},
/* 1EB5 */ { "LATIN SMALL LETTER A WITH BREVE AND TILDE","	: 0103 0303"},
/* 1EB6 */ { "LATIN CAPITAL LETTER A WITH BREVE AND DOT BELOW","	: 1EA0 0306"},
/* 1EB7 */ { "LATIN SMALL LETTER A WITH BREVE AND DOT BELOW","	: 1EA1 0306"},
/* 1EB8 */ { "LATIN CAPITAL LETTER E WITH DOT BELOW","	: 0045 0323"},
/* 1EB9 */ { "LATIN SMALL LETTER E WITH DOT BELOW","	: 0065 0323"},
/* 1EBA */ { "LATIN CAPITAL LETTER E WITH HOOK ABOVE","	: 0045 0309"},
/* 1EBB */ { "LATIN SMALL LETTER E WITH HOOK ABOVE","	: 0065 0309"},
/* 1EBC */ { "LATIN CAPITAL LETTER E WITH TILDE","	: 0045 0303"},
/* 1EBD */ { "LATIN SMALL LETTER E WITH TILDE","	: 0065 0303"},
/* 1EBE */ { "LATIN CAPITAL LETTER E WITH CIRCUMFLEX AND ACUTE","	: 00CA 0301"},
/* 1EBF */ { "LATIN SMALL LETTER E WITH CIRCUMFLEX AND ACUTE","	: 00EA 0301"},
/* 1EC0 */ { "LATIN CAPITAL LETTER E WITH CIRCUMFLEX AND GRAVE","	: 00CA 0300"},
/* 1EC1 */ { "LATIN SMALL LETTER E WITH CIRCUMFLEX AND GRAVE","	: 00EA 0300"},
/* 1EC2 */ { "LATIN CAPITAL LETTER E WITH CIRCUMFLEX AND HOOK ABOVE","	: 00CA 0309"},
/* 1EC3 */ { "LATIN SMALL LETTER E WITH CIRCUMFLEX AND HOOK ABOVE","	: 00EA 0309"},
/* 1EC4 */ { "LATIN CAPITAL LETTER E WITH CIRCUMFLEX AND TILDE","	: 00CA 0303"},
/* 1EC5 */ { "LATIN SMALL LETTER E WITH CIRCUMFLEX AND TILDE","	: 00EA 0303"},
/* 1EC6 */ { "LATIN CAPITAL LETTER E WITH CIRCUMFLEX AND DOT BELOW","	: 1EB8 0302"},
/* 1EC7 */ { "LATIN SMALL LETTER E WITH CIRCUMFLEX AND DOT BELOW","	: 1EB9 0302"},
/* 1EC8 */ { "LATIN CAPITAL LETTER I WITH HOOK ABOVE","	: 0049 0309"},
/* 1EC9 */ { "LATIN SMALL LETTER I WITH HOOK ABOVE","	: 0069 0309"},
/* 1ECA */ { "LATIN CAPITAL LETTER I WITH DOT BELOW","	: 0049 0323"},
/* 1ECB */ { "LATIN SMALL LETTER I WITH DOT BELOW","	: 0069 0323"},
/* 1ECC */ { "LATIN CAPITAL LETTER O WITH DOT BELOW","	: 004F 0323"},
/* 1ECD */ { "LATIN SMALL LETTER O WITH DOT BELOW","	: 006F 0323"},
/* 1ECE */ { "LATIN CAPITAL LETTER O WITH HOOK ABOVE","	: 004F 0309"},
/* 1ECF */ { "LATIN SMALL LETTER O WITH HOOK ABOVE","	: 006F 0309"},
/* 1ED0 */ { "LATIN CAPITAL LETTER O WITH CIRCUMFLEX AND ACUTE","	: 00D4 0301"},
/* 1ED1 */ { "LATIN SMALL LETTER O WITH CIRCUMFLEX AND ACUTE","	: 00F4 0301"},
/* 1ED2 */ { "LATIN CAPITAL LETTER O WITH CIRCUMFLEX AND GRAVE","	: 00D4 0300"},
/* 1ED3 */ { "LATIN SMALL LETTER O WITH CIRCUMFLEX AND GRAVE","	: 00F4 0300"},
/* 1ED4 */ { "LATIN CAPITAL LETTER O WITH CIRCUMFLEX AND HOOK ABOVE","	: 00D4 0309"},
/* 1ED5 */ { "LATIN SMALL LETTER O WITH CIRCUMFLEX AND HOOK ABOVE","	: 00F4 0309"},
/* 1ED6 */ { "LATIN CAPITAL LETTER O WITH CIRCUMFLEX AND TILDE","	: 00D4 0303"},
/* 1ED7 */ { "LATIN SMALL LETTER O WITH CIRCUMFLEX AND TILDE","	: 00F4 0303"},
/* 1ED8 */ { "LATIN CAPITAL LETTER O WITH CIRCUMFLEX AND DOT BELOW","	: 1ECC 0302"},
/* 1ED9 */ { "LATIN SMALL LETTER O WITH CIRCUMFLEX AND DOT BELOW","	: 1ECD 0302"},
/* 1EDA */ { "LATIN CAPITAL LETTER O WITH HORN AND ACUTE","	: 01A0 0301"},
/* 1EDB */ { "LATIN SMALL LETTER O WITH HORN AND ACUTE","	: 01A1 0301"},
/* 1EDC */ { "LATIN CAPITAL LETTER O WITH HORN AND GRAVE","	: 01A0 0300"},
/* 1EDD */ { "LATIN SMALL LETTER O WITH HORN AND GRAVE","	: 01A1 0300"},
/* 1EDE */ { "LATIN CAPITAL LETTER O WITH HORN AND HOOK ABOVE","	: 01A0 0309"},
/* 1EDF */ { "LATIN SMALL LETTER O WITH HORN AND HOOK ABOVE","	: 01A1 0309"},
/* 1EE0 */ { "LATIN CAPITAL LETTER O WITH HORN AND TILDE","	: 01A0 0303"},
/* 1EE1 */ { "LATIN SMALL LETTER O WITH HORN AND TILDE","	: 01A1 0303"},
/* 1EE2 */ { "LATIN CAPITAL LETTER O WITH HORN AND DOT BELOW","	: 01A0 0323"},
/* 1EE3 */ { "LATIN SMALL LETTER O WITH HORN AND DOT BELOW","	: 01A1 0323"},
/* 1EE4 */ { "LATIN CAPITAL LETTER U WITH DOT BELOW","	: 0055 0323"},
/* 1EE5 */ { "LATIN SMALL LETTER U WITH DOT BELOW","	: 0075 0323"},
/* 1EE6 */ { "LATIN CAPITAL LETTER U WITH HOOK ABOVE","	: 0055 0309"},
/* 1EE7 */ { "LATIN SMALL LETTER U WITH HOOK ABOVE","	: 0075 0309"},
/* 1EE8 */ { "LATIN CAPITAL LETTER U WITH HORN AND ACUTE","	: 01AF 0301"},
/* 1EE9 */ { "LATIN SMALL LETTER U WITH HORN AND ACUTE","	: 01B0 0301"},
/* 1EEA */ { "LATIN CAPITAL LETTER U WITH HORN AND GRAVE","	: 01AF 0300"},
/* 1EEB */ { "LATIN SMALL LETTER U WITH HORN AND GRAVE","	: 01B0 0300"},
/* 1EEC */ { "LATIN CAPITAL LETTER U WITH HORN AND HOOK ABOVE","	: 01AF 0309"},
/* 1EED */ { "LATIN SMALL LETTER U WITH HORN AND HOOK ABOVE","	: 01B0 0309"},
/* 1EEE */ { "LATIN CAPITAL LETTER U WITH HORN AND TILDE","	: 01AF 0303"},
/* 1EEF */ { "LATIN SMALL LETTER U WITH HORN AND TILDE","	: 01B0 0303"},
/* 1EF0 */ { "LATIN CAPITAL LETTER U WITH HORN AND DOT BELOW","	: 01AF 0323"},
/* 1EF1 */ { "LATIN SMALL LETTER U WITH HORN AND DOT BELOW","	: 01B0 0323"},
/* 1EF2 */ { "LATIN CAPITAL LETTER Y WITH GRAVE","	: 0059 0300"},
/* 1EF3 */ { "LATIN SMALL LETTER Y WITH GRAVE","	* Welsh\n"
	"	: 0079 0300"},
/* 1EF4 */ { "LATIN CAPITAL LETTER Y WITH DOT BELOW","	: 0059 0323"},
/* 1EF5 */ { "LATIN SMALL LETTER Y WITH DOT BELOW","	: 0079 0323"},
/* 1EF6 */ { "LATIN CAPITAL LETTER Y WITH HOOK ABOVE","	: 0059 0309"},
/* 1EF7 */ { "LATIN SMALL LETTER Y WITH HOOK ABOVE","	: 0079 0309"},
/* 1EF8 */ { "LATIN CAPITAL LETTER Y WITH TILDE","	: 0059 0303"},
/* 1EF9 */ { "LATIN SMALL LETTER Y WITH TILDE","	: 0079 0303"},
/* 1EFA */ { "LATIN CAPITAL LETTER MIDDLE-WELSH LL",NULL},
/* 1EFB */ { "LATIN SMALL LETTER MIDDLE-WELSH LL",NULL},
/* 1EFC */ { "LATIN CAPITAL LETTER MIDDLE-WELSH V",NULL},
/* 1EFD */ { "LATIN SMALL LETTER MIDDLE-WELSH V",NULL},
/* 1EFE */ { "LATIN CAPITAL LETTER Y WITH LOOP",NULL},
/* 1EFF */ { "LATIN SMALL LETTER Y WITH LOOP",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_00_1F[] = {
/* 1F00 */ { "GREEK SMALL LETTER ALPHA WITH PSILI","	: 03B1 0313"},
/* 1F01 */ { "GREEK SMALL LETTER ALPHA WITH DASIA","	: 03B1 0314"},
/* 1F02 */ { "GREEK SMALL LETTER ALPHA WITH PSILI AND VARIA","	: 1F00 0300"},
/* 1F03 */ { "GREEK SMALL LETTER ALPHA WITH DASIA AND VARIA","	: 1F01 0300"},
/* 1F04 */ { "GREEK SMALL LETTER ALPHA WITH PSILI AND OXIA","	: 1F00 0301"},
/* 1F05 */ { "GREEK SMALL LETTER ALPHA WITH DASIA AND OXIA","	: 1F01 0301"},
/* 1F06 */ { "GREEK SMALL LETTER ALPHA WITH PSILI AND PERISPOMENI","	: 1F00 0342"},
/* 1F07 */ { "GREEK SMALL LETTER ALPHA WITH DASIA AND PERISPOMENI","	: 1F01 0342"},
/* 1F08 */ { "GREEK CAPITAL LETTER ALPHA WITH PSILI","	: 0391 0313"},
/* 1F09 */ { "GREEK CAPITAL LETTER ALPHA WITH DASIA","	: 0391 0314"},
/* 1F0A */ { "GREEK CAPITAL LETTER ALPHA WITH PSILI AND VARIA","	: 1F08 0300"},
/* 1F0B */ { "GREEK CAPITAL LETTER ALPHA WITH DASIA AND VARIA","	: 1F09 0300"},
/* 1F0C */ { "GREEK CAPITAL LETTER ALPHA WITH PSILI AND OXIA","	: 1F08 0301"},
/* 1F0D */ { "GREEK CAPITAL LETTER ALPHA WITH DASIA AND OXIA","	: 1F09 0301"},
/* 1F0E */ { "GREEK CAPITAL LETTER ALPHA WITH PSILI AND PERISPOMENI","	: 1F08 0342"},
/* 1F0F */ { "GREEK CAPITAL LETTER ALPHA WITH DASIA AND PERISPOMENI","	: 1F09 0342"},
/* 1F10 */ { "GREEK SMALL LETTER EPSILON WITH PSILI","	: 03B5 0313"},
/* 1F11 */ { "GREEK SMALL LETTER EPSILON WITH DASIA","	: 03B5 0314"},
/* 1F12 */ { "GREEK SMALL LETTER EPSILON WITH PSILI AND VARIA","	: 1F10 0300"},
/* 1F13 */ { "GREEK SMALL LETTER EPSILON WITH DASIA AND VARIA","	: 1F11 0300"},
/* 1F14 */ { "GREEK SMALL LETTER EPSILON WITH PSILI AND OXIA","	: 1F10 0301"},
/* 1F15 */ { "GREEK SMALL LETTER EPSILON WITH DASIA AND OXIA","	: 1F11 0301"},
/* 1F16 */ { NULL,NULL},
/* 1F17 */ { NULL,NULL},
/* 1F18 */ { "GREEK CAPITAL LETTER EPSILON WITH PSILI","	: 0395 0313"},
/* 1F19 */ { "GREEK CAPITAL LETTER EPSILON WITH DASIA","	: 0395 0314"},
/* 1F1A */ { "GREEK CAPITAL LETTER EPSILON WITH PSILI AND VARIA","	: 1F18 0300"},
/* 1F1B */ { "GREEK CAPITAL LETTER EPSILON WITH DASIA AND VARIA","	: 1F19 0300"},
/* 1F1C */ { "GREEK CAPITAL LETTER EPSILON WITH PSILI AND OXIA","	: 1F18 0301"},
/* 1F1D */ { "GREEK CAPITAL LETTER EPSILON WITH DASIA AND OXIA","	: 1F19 0301"},
/* 1F1E */ { NULL,NULL},
/* 1F1F */ { NULL,NULL},
/* 1F20 */ { "GREEK SMALL LETTER ETA WITH PSILI","	: 03B7 0313"},
/* 1F21 */ { "GREEK SMALL LETTER ETA WITH DASIA","	: 03B7 0314"},
/* 1F22 */ { "GREEK SMALL LETTER ETA WITH PSILI AND VARIA","	: 1F20 0300"},
/* 1F23 */ { "GREEK SMALL LETTER ETA WITH DASIA AND VARIA","	: 1F21 0300"},
/* 1F24 */ { "GREEK SMALL LETTER ETA WITH PSILI AND OXIA","	: 1F20 0301"},
/* 1F25 */ { "GREEK SMALL LETTER ETA WITH DASIA AND OXIA","	: 1F21 0301"},
/* 1F26 */ { "GREEK SMALL LETTER ETA WITH PSILI AND PERISPOMENI","	: 1F20 0342"},
/* 1F27 */ { "GREEK SMALL LETTER ETA WITH DASIA AND PERISPOMENI","	: 1F21 0342"},
/* 1F28 */ { "GREEK CAPITAL LETTER ETA WITH PSILI","	: 0397 0313"},
/* 1F29 */ { "GREEK CAPITAL LETTER ETA WITH DASIA","	: 0397 0314"},
/* 1F2A */ { "GREEK CAPITAL LETTER ETA WITH PSILI AND VARIA","	: 1F28 0300"},
/* 1F2B */ { "GREEK CAPITAL LETTER ETA WITH DASIA AND VARIA","	: 1F29 0300"},
/* 1F2C */ { "GREEK CAPITAL LETTER ETA WITH PSILI AND OXIA","	: 1F28 0301"},
/* 1F2D */ { "GREEK CAPITAL LETTER ETA WITH DASIA AND OXIA","	: 1F29 0301"},
/* 1F2E */ { "GREEK CAPITAL LETTER ETA WITH PSILI AND PERISPOMENI","	: 1F28 0342"},
/* 1F2F */ { "GREEK CAPITAL LETTER ETA WITH DASIA AND PERISPOMENI","	: 1F29 0342"},
/* 1F30 */ { "GREEK SMALL LETTER IOTA WITH PSILI","	: 03B9 0313"},
/* 1F31 */ { "GREEK SMALL LETTER IOTA WITH DASIA","	: 03B9 0314"},
/* 1F32 */ { "GREEK SMALL LETTER IOTA WITH PSILI AND VARIA","	: 1F30 0300"},
/* 1F33 */ { "GREEK SMALL LETTER IOTA WITH DASIA AND VARIA","	: 1F31 0300"},
/* 1F34 */ { "GREEK SMALL LETTER IOTA WITH PSILI AND OXIA","	: 1F30 0301"},
/* 1F35 */ { "GREEK SMALL LETTER IOTA WITH DASIA AND OXIA","	: 1F31 0301"},
/* 1F36 */ { "GREEK SMALL LETTER IOTA WITH PSILI AND PERISPOMENI","	: 1F30 0342"},
/* 1F37 */ { "GREEK SMALL LETTER IOTA WITH DASIA AND PERISPOMENI","	: 1F31 0342"},
/* 1F38 */ { "GREEK CAPITAL LETTER IOTA WITH PSILI","	: 0399 0313"},
/* 1F39 */ { "GREEK CAPITAL LETTER IOTA WITH DASIA","	: 0399 0314"},
/* 1F3A */ { "GREEK CAPITAL LETTER IOTA WITH PSILI AND VARIA","	: 1F38 0300"},
/* 1F3B */ { "GREEK CAPITAL LETTER IOTA WITH DASIA AND VARIA","	: 1F39 0300"},
/* 1F3C */ { "GREEK CAPITAL LETTER IOTA WITH PSILI AND OXIA","	: 1F38 0301"},
/* 1F3D */ { "GREEK CAPITAL LETTER IOTA WITH DASIA AND OXIA","	: 1F39 0301"},
/* 1F3E */ { "GREEK CAPITAL LETTER IOTA WITH PSILI AND PERISPOMENI","	: 1F38 0342"},
/* 1F3F */ { "GREEK CAPITAL LETTER IOTA WITH DASIA AND PERISPOMENI","	: 1F39 0342"},
/* 1F40 */ { "GREEK SMALL LETTER OMICRON WITH PSILI","	: 03BF 0313"},
/* 1F41 */ { "GREEK SMALL LETTER OMICRON WITH DASIA","	: 03BF 0314"},
/* 1F42 */ { "GREEK SMALL LETTER OMICRON WITH PSILI AND VARIA","	: 1F40 0300"},
/* 1F43 */ { "GREEK SMALL LETTER OMICRON WITH DASIA AND VARIA","	: 1F41 0300"},
/* 1F44 */ { "GREEK SMALL LETTER OMICRON WITH PSILI AND OXIA","	: 1F40 0301"},
/* 1F45 */ { "GREEK SMALL LETTER OMICRON WITH DASIA AND OXIA","	: 1F41 0301"},
/* 1F46 */ { NULL,NULL},
/* 1F47 */ { NULL,NULL},
/* 1F48 */ { "GREEK CAPITAL LETTER OMICRON WITH PSILI","	: 039F 0313"},
/* 1F49 */ { "GREEK CAPITAL LETTER OMICRON WITH DASIA","	: 039F 0314"},
/* 1F4A */ { "GREEK CAPITAL LETTER OMICRON WITH PSILI AND VARIA","	: 1F48 0300"},
/* 1F4B */ { "GREEK CAPITAL LETTER OMICRON WITH DASIA AND VARIA","	: 1F49 0300"},
/* 1F4C */ { "GREEK CAPITAL LETTER OMICRON WITH PSILI AND OXIA","	: 1F48 0301"},
/* 1F4D */ { "GREEK CAPITAL LETTER OMICRON WITH DASIA AND OXIA","	: 1F49 0301"},
/* 1F4E */ { NULL,NULL},
/* 1F4F */ { NULL,NULL},
/* 1F50 */ { "GREEK SMALL LETTER UPSILON WITH PSILI","	: 03C5 0313"},
/* 1F51 */ { "GREEK SMALL LETTER UPSILON WITH DASIA","	: 03C5 0314"},
/* 1F52 */ { "GREEK SMALL LETTER UPSILON WITH PSILI AND VARIA","	: 1F50 0300"},
/* 1F53 */ { "GREEK SMALL LETTER UPSILON WITH DASIA AND VARIA","	: 1F51 0300"},
/* 1F54 */ { "GREEK SMALL LETTER UPSILON WITH PSILI AND OXIA","	: 1F50 0301"},
/* 1F55 */ { "GREEK SMALL LETTER UPSILON WITH DASIA AND OXIA","	: 1F51 0301"},
/* 1F56 */ { "GREEK SMALL LETTER UPSILON WITH PSILI AND PERISPOMENI","	: 1F50 0342"},
/* 1F57 */ { "GREEK SMALL LETTER UPSILON WITH DASIA AND PERISPOMENI","	: 1F51 0342"},
/* 1F58 */ { NULL,NULL},
/* 1F59 */ { "GREEK CAPITAL LETTER UPSILON WITH DASIA","	: 03A5 0314"},
/* 1F5A */ { NULL,NULL},
/* 1F5B */ { "GREEK CAPITAL LETTER UPSILON WITH DASIA AND VARIA","	: 1F59 0300"},
/* 1F5C */ { NULL,NULL},
/* 1F5D */ { "GREEK CAPITAL LETTER UPSILON WITH DASIA AND OXIA","	: 1F59 0301"},
/* 1F5E */ { NULL,NULL},
/* 1F5F */ { "GREEK CAPITAL LETTER UPSILON WITH DASIA AND PERISPOMENI","	: 1F59 0342"},
/* 1F60 */ { "GREEK SMALL LETTER OMEGA WITH PSILI","	: 03C9 0313"},
/* 1F61 */ { "GREEK SMALL LETTER OMEGA WITH DASIA","	: 03C9 0314"},
/* 1F62 */ { "GREEK SMALL LETTER OMEGA WITH PSILI AND VARIA","	: 1F60 0300"},
/* 1F63 */ { "GREEK SMALL LETTER OMEGA WITH DASIA AND VARIA","	: 1F61 0300"},
/* 1F64 */ { "GREEK SMALL LETTER OMEGA WITH PSILI AND OXIA","	: 1F60 0301"},
/* 1F65 */ { "GREEK SMALL LETTER OMEGA WITH DASIA AND OXIA","	: 1F61 0301"},
/* 1F66 */ { "GREEK SMALL LETTER OMEGA WITH PSILI AND PERISPOMENI","	: 1F60 0342"},
/* 1F67 */ { "GREEK SMALL LETTER OMEGA WITH DASIA AND PERISPOMENI","	: 1F61 0342"},
/* 1F68 */ { "GREEK CAPITAL LETTER OMEGA WITH PSILI","	: 03A9 0313"},
/* 1F69 */ { "GREEK CAPITAL LETTER OMEGA WITH DASIA","	: 03A9 0314"},
/* 1F6A */ { "GREEK CAPITAL LETTER OMEGA WITH PSILI AND VARIA","	: 1F68 0300"},
/* 1F6B */ { "GREEK CAPITAL LETTER OMEGA WITH DASIA AND VARIA","	: 1F69 0300"},
/* 1F6C */ { "GREEK CAPITAL LETTER OMEGA WITH PSILI AND OXIA","	: 1F68 0301"},
/* 1F6D */ { "GREEK CAPITAL LETTER OMEGA WITH DASIA AND OXIA","	: 1F69 0301"},
/* 1F6E */ { "GREEK CAPITAL LETTER OMEGA WITH PSILI AND PERISPOMENI","	: 1F68 0342"},
/* 1F6F */ { "GREEK CAPITAL LETTER OMEGA WITH DASIA AND PERISPOMENI","	: 1F69 0342"},
/* 1F70 */ { "GREEK SMALL LETTER ALPHA WITH VARIA","	: 03B1 0300"},
/* 1F71 */ { "GREEK SMALL LETTER ALPHA WITH OXIA","	: 03AC greek small letter alpha with tonos"},
/* 1F72 */ { "GREEK SMALL LETTER EPSILON WITH VARIA","	: 03B5 0300"},
/* 1F73 */ { "GREEK SMALL LETTER EPSILON WITH OXIA","	: 03AD greek small letter epsilon with tonos"},
/* 1F74 */ { "GREEK SMALL LETTER ETA WITH VARIA","	: 03B7 0300"},
/* 1F75 */ { "GREEK SMALL LETTER ETA WITH OXIA","	: 03AE greek small letter eta with tonos"},
/* 1F76 */ { "GREEK SMALL LETTER IOTA WITH VARIA","	: 03B9 0300"},
/* 1F77 */ { "GREEK SMALL LETTER IOTA WITH OXIA","	: 03AF greek small letter iota with tonos"},
/* 1F78 */ { "GREEK SMALL LETTER OMICRON WITH VARIA","	: 03BF 0300"},
/* 1F79 */ { "GREEK SMALL LETTER OMICRON WITH OXIA","	: 03CC greek small letter omicron with tonos"},
/* 1F7A */ { "GREEK SMALL LETTER UPSILON WITH VARIA","	: 03C5 0300"},
/* 1F7B */ { "GREEK SMALL LETTER UPSILON WITH OXIA","	: 03CD greek small letter upsilon with tonos"},
/* 1F7C */ { "GREEK SMALL LETTER OMEGA WITH VARIA","	: 03C9 0300"},
/* 1F7D */ { "GREEK SMALL LETTER OMEGA WITH OXIA","	: 03CE greek small letter omega with tonos"},
/* 1F7E */ { NULL,NULL},
/* 1F7F */ { NULL,NULL},
/* 1F80 */ { "GREEK SMALL LETTER ALPHA WITH PSILI AND YPOGEGRAMMENI","	: 1F00 0345"},
/* 1F81 */ { "GREEK SMALL LETTER ALPHA WITH DASIA AND YPOGEGRAMMENI","	: 1F01 0345"},
/* 1F82 */ { "GREEK SMALL LETTER ALPHA WITH PSILI AND VARIA AND YPOGEGRAMMENI","	: 1F02 0345"},
/* 1F83 */ { "GREEK SMALL LETTER ALPHA WITH DASIA AND VARIA AND YPOGEGRAMMENI","	: 1F03 0345"},
/* 1F84 */ { "GREEK SMALL LETTER ALPHA WITH PSILI AND OXIA AND YPOGEGRAMMENI","	: 1F04 0345"},
/* 1F85 */ { "GREEK SMALL LETTER ALPHA WITH DASIA AND OXIA AND YPOGEGRAMMENI","	: 1F05 0345"},
/* 1F86 */ { "GREEK SMALL LETTER ALPHA WITH PSILI AND PERISPOMENI AND YPOGEGRAMMENI","	: 1F06 0345"},
/* 1F87 */ { "GREEK SMALL LETTER ALPHA WITH DASIA AND PERISPOMENI AND YPOGEGRAMMENI","	: 1F07 0345"},
/* 1F88 */ { "GREEK CAPITAL LETTER ALPHA WITH PSILI AND PROSGEGRAMMENI","	: 1F08 0345"},
/* 1F89 */ { "GREEK CAPITAL LETTER ALPHA WITH DASIA AND PROSGEGRAMMENI","	: 1F09 0345"},
/* 1F8A */ { "GREEK CAPITAL LETTER ALPHA WITH PSILI AND VARIA AND PROSGEGRAMMENI","	: 1F0A 0345"},
/* 1F8B */ { "GREEK CAPITAL LETTER ALPHA WITH DASIA AND VARIA AND PROSGEGRAMMENI","	: 1F0B 0345"},
/* 1F8C */ { "GREEK CAPITAL LETTER ALPHA WITH PSILI AND OXIA AND PROSGEGRAMMENI","	: 1F0C 0345"},
/* 1F8D */ { "GREEK CAPITAL LETTER ALPHA WITH DASIA AND OXIA AND PROSGEGRAMMENI","	: 1F0D 0345"},
/* 1F8E */ { "GREEK CAPITAL LETTER ALPHA WITH PSILI AND PERISPOMENI AND PROSGEGRAMMENI","	: 1F0E 0345"},
/* 1F8F */ { "GREEK CAPITAL LETTER ALPHA WITH DASIA AND PERISPOMENI AND PROSGEGRAMMENI","	: 1F0F 0345"},
/* 1F90 */ { "GREEK SMALL LETTER ETA WITH PSILI AND YPOGEGRAMMENI","	: 1F20 0345"},
/* 1F91 */ { "GREEK SMALL LETTER ETA WITH DASIA AND YPOGEGRAMMENI","	: 1F21 0345"},
/* 1F92 */ { "GREEK SMALL LETTER ETA WITH PSILI AND VARIA AND YPOGEGRAMMENI","	: 1F22 0345"},
/* 1F93 */ { "GREEK SMALL LETTER ETA WITH DASIA AND VARIA AND YPOGEGRAMMENI","	: 1F23 0345"},
/* 1F94 */ { "GREEK SMALL LETTER ETA WITH PSILI AND OXIA AND YPOGEGRAMMENI","	: 1F24 0345"},
/* 1F95 */ { "GREEK SMALL LETTER ETA WITH DASIA AND OXIA AND YPOGEGRAMMENI","	: 1F25 0345"},
/* 1F96 */ { "GREEK SMALL LETTER ETA WITH PSILI AND PERISPOMENI AND YPOGEGRAMMENI","	: 1F26 0345"},
/* 1F97 */ { "GREEK SMALL LETTER ETA WITH DASIA AND PERISPOMENI AND YPOGEGRAMMENI","	: 1F27 0345"},
/* 1F98 */ { "GREEK CAPITAL LETTER ETA WITH PSILI AND PROSGEGRAMMENI","	: 1F28 0345"},
/* 1F99 */ { "GREEK CAPITAL LETTER ETA WITH DASIA AND PROSGEGRAMMENI","	: 1F29 0345"},
/* 1F9A */ { "GREEK CAPITAL LETTER ETA WITH PSILI AND VARIA AND PROSGEGRAMMENI","	: 1F2A 0345"},
/* 1F9B */ { "GREEK CAPITAL LETTER ETA WITH DASIA AND VARIA AND PROSGEGRAMMENI","	: 1F2B 0345"},
/* 1F9C */ { "GREEK CAPITAL LETTER ETA WITH PSILI AND OXIA AND PROSGEGRAMMENI","	: 1F2C 0345"},
/* 1F9D */ { "GREEK CAPITAL LETTER ETA WITH DASIA AND OXIA AND PROSGEGRAMMENI","	: 1F2D 0345"},
/* 1F9E */ { "GREEK CAPITAL LETTER ETA WITH PSILI AND PERISPOMENI AND PROSGEGRAMMENI","	: 1F2E 0345"},
/* 1F9F */ { "GREEK CAPITAL LETTER ETA WITH DASIA AND PERISPOMENI AND PROSGEGRAMMENI","	: 1F2F 0345"},
/* 1FA0 */ { "GREEK SMALL LETTER OMEGA WITH PSILI AND YPOGEGRAMMENI","	: 1F60 0345"},
/* 1FA1 */ { "GREEK SMALL LETTER OMEGA WITH DASIA AND YPOGEGRAMMENI","	: 1F61 0345"},
/* 1FA2 */ { "GREEK SMALL LETTER OMEGA WITH PSILI AND VARIA AND YPOGEGRAMMENI","	: 1F62 0345"},
/* 1FA3 */ { "GREEK SMALL LETTER OMEGA WITH DASIA AND VARIA AND YPOGEGRAMMENI","	: 1F63 0345"},
/* 1FA4 */ { "GREEK SMALL LETTER OMEGA WITH PSILI AND OXIA AND YPOGEGRAMMENI","	: 1F64 0345"},
/* 1FA5 */ { "GREEK SMALL LETTER OMEGA WITH DASIA AND OXIA AND YPOGEGRAMMENI","	: 1F65 0345"},
/* 1FA6 */ { "GREEK SMALL LETTER OMEGA WITH PSILI AND PERISPOMENI AND YPOGEGRAMMENI","	: 1F66 0345"},
/* 1FA7 */ { "GREEK SMALL LETTER OMEGA WITH DASIA AND PERISPOMENI AND YPOGEGRAMMENI","	: 1F67 0345"},
/* 1FA8 */ { "GREEK CAPITAL LETTER OMEGA WITH PSILI AND PROSGEGRAMMENI","	: 1F68 0345"},
/* 1FA9 */ { "GREEK CAPITAL LETTER OMEGA WITH DASIA AND PROSGEGRAMMENI","	: 1F69 0345"},
/* 1FAA */ { "GREEK CAPITAL LETTER OMEGA WITH PSILI AND VARIA AND PROSGEGRAMMENI","	: 1F6A 0345"},
/* 1FAB */ { "GREEK CAPITAL LETTER OMEGA WITH DASIA AND VARIA AND PROSGEGRAMMENI","	: 1F6B 0345"},
/* 1FAC */ { "GREEK CAPITAL LETTER OMEGA WITH PSILI AND OXIA AND PROSGEGRAMMENI","	: 1F6C 0345"},
/* 1FAD */ { "GREEK CAPITAL LETTER OMEGA WITH DASIA AND OXIA AND PROSGEGRAMMENI","	: 1F6D 0345"},
/* 1FAE */ { "GREEK CAPITAL LETTER OMEGA WITH PSILI AND PERISPOMENI AND PROSGEGRAMMENI","	: 1F6E 0345"},
/* 1FAF */ { "GREEK CAPITAL LETTER OMEGA WITH DASIA AND PERISPOMENI AND PROSGEGRAMMENI","	: 1F6F 0345"},
/* 1FB0 */ { "GREEK SMALL LETTER ALPHA WITH VRACHY","	: 03B1 0306"},
/* 1FB1 */ { "GREEK SMALL LETTER ALPHA WITH MACRON","	: 03B1 0304"},
/* 1FB2 */ { "GREEK SMALL LETTER ALPHA WITH VARIA AND YPOGEGRAMMENI","	: 1F70 0345"},
/* 1FB3 */ { "GREEK SMALL LETTER ALPHA WITH YPOGEGRAMMENI","	: 03B1 0345"},
/* 1FB4 */ { "GREEK SMALL LETTER ALPHA WITH OXIA AND YPOGEGRAMMENI","	: 03AC 0345"},
/* 1FB5 */ { NULL,NULL},
/* 1FB6 */ { "GREEK SMALL LETTER ALPHA WITH PERISPOMENI","	: 03B1 0342"},
/* 1FB7 */ { "GREEK SMALL LETTER ALPHA WITH PERISPOMENI AND YPOGEGRAMMENI","	: 1FB6 0345"},
/* 1FB8 */ { "GREEK CAPITAL LETTER ALPHA WITH VRACHY","	: 0391 0306"},
/* 1FB9 */ { "GREEK CAPITAL LETTER ALPHA WITH MACRON","	: 0391 0304"},
/* 1FBA */ { "GREEK CAPITAL LETTER ALPHA WITH VARIA","	: 0391 0300"},
/* 1FBB */ { "GREEK CAPITAL LETTER ALPHA WITH OXIA","	: 0386 greek capital letter alpha with tonos"},
/* 1FBC */ { "GREEK CAPITAL LETTER ALPHA WITH PROSGEGRAMMENI","	: 0391 0345"},
/* 1FBD */ { "GREEK KORONIS","	# 0020 0313"},
/* 1FBE */ { "GREEK PROSGEGRAMMENI","	: 03B9 greek small letter iota"},
/* 1FBF */ { "GREEK PSILI","	x (modifier letter apostrophe - 02BC)\n"
	"	# 0020 0313"},
/* 1FC0 */ { "GREEK PERISPOMENI","	# 0020 0342"},
/* 1FC1 */ { "GREEK DIALYTIKA AND PERISPOMENI","	: 00A8 0342"},
/* 1FC2 */ { "GREEK SMALL LETTER ETA WITH VARIA AND YPOGEGRAMMENI","	: 1F74 0345"},
/* 1FC3 */ { "GREEK SMALL LETTER ETA WITH YPOGEGRAMMENI","	: 03B7 0345"},
/* 1FC4 */ { "GREEK SMALL LETTER ETA WITH OXIA AND YPOGEGRAMMENI","	: 03AE 0345"},
/* 1FC5 */ { NULL,NULL},
/* 1FC6 */ { "GREEK SMALL LETTER ETA WITH PERISPOMENI","	: 03B7 0342"},
/* 1FC7 */ { "GREEK SMALL LETTER ETA WITH PERISPOMENI AND YPOGEGRAMMENI","	: 1FC6 0345"},
/* 1FC8 */ { "GREEK CAPITAL LETTER EPSILON WITH VARIA","	: 0395 0300"},
/* 1FC9 */ { "GREEK CAPITAL LETTER EPSILON WITH OXIA","	: 0388 greek capital letter epsilon with tonos"},
/* 1FCA */ { "GREEK CAPITAL LETTER ETA WITH VARIA","	: 0397 0300"},
/* 1FCB */ { "GREEK CAPITAL LETTER ETA WITH OXIA","	: 0389 greek capital letter eta with tonos"},
/* 1FCC */ { "GREEK CAPITAL LETTER ETA WITH PROSGEGRAMMENI","	: 0397 0345"},
/* 1FCD */ { "GREEK PSILI AND VARIA","	: 1FBF 0300"},
/* 1FCE */ { "GREEK PSILI AND OXIA","	: 1FBF 0301"},
/* 1FCF */ { "GREEK PSILI AND PERISPOMENI","	: 1FBF 0342"},
/* 1FD0 */ { "GREEK SMALL LETTER IOTA WITH VRACHY","	: 03B9 0306"},
/* 1FD1 */ { "GREEK SMALL LETTER IOTA WITH MACRON","	: 03B9 0304"},
/* 1FD2 */ { "GREEK SMALL LETTER IOTA WITH DIALYTIKA AND VARIA","	: 03CA 0300"},
/* 1FD3 */ { "GREEK SMALL LETTER IOTA WITH DIALYTIKA AND OXIA","	: 0390 greek small letter iota with dialytika and tonos"},
/* 1FD4 */ { NULL,NULL},
/* 1FD5 */ { NULL,NULL},
/* 1FD6 */ { "GREEK SMALL LETTER IOTA WITH PERISPOMENI","	: 03B9 0342"},
/* 1FD7 */ { "GREEK SMALL LETTER IOTA WITH DIALYTIKA AND PERISPOMENI","	: 03CA 0342"},
/* 1FD8 */ { "GREEK CAPITAL LETTER IOTA WITH VRACHY","	: 0399 0306"},
/* 1FD9 */ { "GREEK CAPITAL LETTER IOTA WITH MACRON","	: 0399 0304"},
/* 1FDA */ { "GREEK CAPITAL LETTER IOTA WITH VARIA","	: 0399 0300"},
/* 1FDB */ { "GREEK CAPITAL LETTER IOTA WITH OXIA","	: 038A greek capital letter iota with tonos"},
/* 1FDC */ { NULL,NULL},
/* 1FDD */ { "GREEK DASIA AND VARIA","	: 1FFE 0300"},
/* 1FDE */ { "GREEK DASIA AND OXIA","	: 1FFE 0301"},
/* 1FDF */ { "GREEK DASIA AND PERISPOMENI","	: 1FFE 0342"},
/* 1FE0 */ { "GREEK SMALL LETTER UPSILON WITH VRACHY","	: 03C5 0306"},
/* 1FE1 */ { "GREEK SMALL LETTER UPSILON WITH MACRON","	: 03C5 0304"},
/* 1FE2 */ { "GREEK SMALL LETTER UPSILON WITH DIALYTIKA AND VARIA","	: 03CB 0300"},
/* 1FE3 */ { "GREEK SMALL LETTER UPSILON WITH DIALYTIKA AND OXIA","	: 03B0 greek small letter upsilon with dialytika and tonos"},
/* 1FE4 */ { "GREEK SMALL LETTER RHO WITH PSILI","	: 03C1 0313"},
/* 1FE5 */ { "GREEK SMALL LETTER RHO WITH DASIA","	: 03C1 0314"},
/* 1FE6 */ { "GREEK SMALL LETTER UPSILON WITH PERISPOMENI","	: 03C5 0342"},
/* 1FE7 */ { "GREEK SMALL LETTER UPSILON WITH DIALYTIKA AND PERISPOMENI","	: 03CB 0342"},
/* 1FE8 */ { "GREEK CAPITAL LETTER UPSILON WITH VRACHY","	: 03A5 0306"},
/* 1FE9 */ { "GREEK CAPITAL LETTER UPSILON WITH MACRON","	: 03A5 0304"},
/* 1FEA */ { "GREEK CAPITAL LETTER UPSILON WITH VARIA","	: 03A5 0300"},
/* 1FEB */ { "GREEK CAPITAL LETTER UPSILON WITH OXIA","	: 038E greek capital letter upsilon with tonos"},
/* 1FEC */ { "GREEK CAPITAL LETTER RHO WITH DASIA","	: 03A1 0314"},
/* 1FED */ { "GREEK DIALYTIKA AND VARIA","	: 00A8 0300"},
/* 1FEE */ { "GREEK DIALYTIKA AND OXIA","	: 0385 greek dialytika tonos"},
/* 1FEF */ { "GREEK VARIA","	: 0060 grave accent"},
/* 1FF0 */ { NULL,NULL},
/* 1FF1 */ { NULL,NULL},
/* 1FF2 */ { "GREEK SMALL LETTER OMEGA WITH VARIA AND YPOGEGRAMMENI","	: 1F7C 0345"},
/* 1FF3 */ { "GREEK SMALL LETTER OMEGA WITH YPOGEGRAMMENI","	: 03C9 0345"},
/* 1FF4 */ { "GREEK SMALL LETTER OMEGA WITH OXIA AND YPOGEGRAMMENI","	: 03CE 0345"},
/* 1FF5 */ { NULL,NULL},
/* 1FF6 */ { "GREEK SMALL LETTER OMEGA WITH PERISPOMENI","	: 03C9 0342"},
/* 1FF7 */ { "GREEK SMALL LETTER OMEGA WITH PERISPOMENI AND YPOGEGRAMMENI","	: 1FF6 0345"},
/* 1FF8 */ { "GREEK CAPITAL LETTER OMICRON WITH VARIA","	: 039F 0300"},
/* 1FF9 */ { "GREEK CAPITAL LETTER OMICRON WITH OXIA","	: 038C greek capital letter omicron with tonos"},
/* 1FFA */ { "GREEK CAPITAL LETTER OMEGA WITH VARIA","	: 03A9 0300"},
/* 1FFB */ { "GREEK CAPITAL LETTER OMEGA WITH OXIA","	: 038F greek capital letter omega with tonos"},
/* 1FFC */ { "GREEK CAPITAL LETTER OMEGA WITH PROSGEGRAMMENI","	: 03A9 0345"},
/* 1FFD */ { "GREEK OXIA","	: 00B4 acute accent"},
/* 1FFE */ { "GREEK DASIA","	x (modifier letter reversed comma - 02BD)\n"
	"	# 0020 0314"},
/* 1FFF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_00_20[] = {
/* 2000 */ { "EN QUAD","	: 2002 en space"},
/* 2001 */ { "EM QUAD","	= mutton quad\n"
	"	: 2003 em space"},
/* 2002 */ { "EN SPACE","	= nut\n"
	"	* half an em\n"
	"	# 0020 space"},
/* 2003 */ { "EM SPACE","	= mutton\n"
	"	* nominally, a space equal to the type size in points\n"
	"	* may scale by the condensation factor of a font\n"
	"	# 0020 space"},
/* 2004 */ { "THREE-PER-EM SPACE","	= thick space\n"
	"	# 0020 space"},
/* 2005 */ { "FOUR-PER-EM SPACE","	= mid space\n"
	"	# 0020 space"},
/* 2006 */ { "SIX-PER-EM SPACE","	* in computer typography sometimes equated to thin space\n"
	"	# 0020 space"},
/* 2007 */ { "FIGURE SPACE","	* space equal to tabular width of a font, typically set to the same width as digit zero 0030\n"
	"	* this is equivalent to the digit width of fonts with fixed-width digits\n"
	"	# <noBreak> 0020"},
/* 2008 */ { "PUNCTUATION SPACE","	* space equal to narrow punctuation of a font, typically set to the same width as full stop 002E\n"
	"	# 0020 space"},
/* 2009 */ { "THIN SPACE","	= narrow space\n"
	"	* this should be much narrower than space 0020; typically set to 1/5 or 1/6 em\n"
	"	x (narrow no-break space - 202F)\n"
	"	# 0020 space"},
/* 200A */ { "HAIR SPACE","	* thinner than a thin space; typically set to 1/10 to 1/16 em\n"
	"	* in traditional typography, the thinnest space available\n"
	"	# 0020 space"},
/* 200B */ { "ZERO WIDTH SPACE","	* commonly abbreviated ZWSP\n"
	"	* this character is intended for invisible word separation and for line break control; it has no width, but its presence between two characters does not prevent increased letter spacing in justification"},
/* 200C */ { "ZERO WIDTH NON-JOINER","	* commonly abbreviated ZWNJ"},
/* 200D */ { "ZERO WIDTH JOINER","	* commonly abbreviated ZWJ"},
/* 200E */ { "LEFT-TO-RIGHT MARK","	* commonly abbreviated LRM"},
/* 200F */ { "RIGHT-TO-LEFT MARK","	* commonly abbreviated RLM\n"
	"	x (arabic letter mark - 061C)"},
/* 2010 */ { "HYPHEN","	x (hyphen-minus - 002D)\n"
	"	x (soft hyphen - 00AD)"},
/* 2011 */ { "NON-BREAKING HYPHEN","	# <noBreak> 2010"},
/* 2012 */ { "FIGURE DASH",NULL},
/* 2013 */ { "EN DASH",NULL},
/* 2014 */ { "EM DASH","	* may be used in pairs to offset parenthetical text\n"
	"	x (two-em dash - 2E3A)\n"
	"	x (katakana-hiragana prolonged sound mark - 30FC)"},
/* 2015 */ { "HORIZONTAL BAR","	= quotation dash\n"
	"	* long dash introducing quoted text"},
/* 2016 */ { "DOUBLE VERTICAL LINE","	* used in pairs to indicate norm of a matrix\n"
	"	x (combining double vertical stroke overlay - 20E6)\n"
	"	x (parallel to - 2225)\n"
	"	x (double vertical bar - 23F8)"},
/* 2017 */ { "DOUBLE LOW LINE","	* this is a spacing character\n"
	"	x (low line - 005F)\n"
	"	x (combining double low line - 0333)\n"
	"	# 0020 0333"},
/* 2018 */ { "LEFT SINGLE QUOTATION MARK","	= single turned comma quotation mark\n"
	"	* this is the preferred character (as opposed to 201B)\n"
	"	x (apostrophe - 0027)\n"
	"	x (modifier letter turned comma - 02BB)\n"
	"	x (heavy single turned comma quotation mark ornament - 275B)\n"
	"	~ 2018 FE00 non-fullwidth form\n"
	"	~ 2018 FE01 right-justified fullwidth form\n"
	"	~ 2018 FE02 Sibe form"},
/* 2019 */ { "RIGHT SINGLE QUOTATION MARK","	= single comma quotation mark\n"
	"	* this is the preferred character to use for apostrophe\n"
	"	x (apostrophe - 0027)\n"
	"	x (modifier letter apostrophe - 02BC)\n"
	"	x (heavy single comma quotation mark ornament - 275C)\n"
	"	~ 2019 FE00 non-fullwidth form\n"
	"	~ 2019 FE01 left-justified fullwidth form\n"
	"	~ 2019 FE02 Sibe form"},
/* 201A */ { "SINGLE LOW-9 QUOTATION MARK","	= low single comma quotation mark\n"
	"	* used as opening single quotation mark in some languages"},
/* 201B */ { "SINGLE HIGH-REVERSED-9 QUOTATION MARK","	= single reversed comma quotation mark\n"
	"	* has same semantic as 2018, but differs in appearance\n"
	"	x (modifier letter reversed comma - 02BD)"},
/* 201C */ { "LEFT DOUBLE QUOTATION MARK","	= double turned comma quotation mark\n"
	"	* this is the preferred character (as opposed to 201F)\n"
	"	x (quotation mark - 0022)\n"
	"	x (heavy double turned comma quotation mark ornament - 275D)\n"
	"	x (reversed double prime quotation mark - 301D)\n"
	"	~ 201C FE00 non-fullwidth form\n"
	"	~ 201C FE01 right-justified fullwidth form\n"
	"	~ 201C FE02 Sibe form"},
/* 201D */ { "RIGHT DOUBLE QUOTATION MARK","	= double comma quotation mark\n"
	"	x (quotation mark - 0022)\n"
	"	x (double prime - 2033)\n"
	"	x (heavy double comma quotation mark ornament - 275E)\n"
	"	x (double prime quotation mark - 301E)\n"
	"	~ 201D FE00 non-fullwidth form\n"
	"	~ 201D FE01 left-justified fullwidth form\n"
	"	~ 201D FE02 Sibe form"},
/* 201E */ { "DOUBLE LOW-9 QUOTATION MARK","	= low double comma quotation mark\n"
	"	* used as opening double quotation mark in some languages\n"
	"	x (double low-reversed-9 quotation mark - 2E42)\n"
	"	x (low double prime quotation mark - 301F)"},
/* 201F */ { "DOUBLE HIGH-REVERSED-9 QUOTATION MARK","	= double reversed comma quotation mark\n"
	"	* has same semantic as 201C, but differs in appearance"},
/* 2020 */ { "DAGGER","	= obelisk, long cross, oblong cross\n"
	"	x (turned dagger - 2E38)"},
/* 2021 */ { "DOUBLE DAGGER","	= diesis, double obelisk\n"
	"	x (triple dagger - 2E4B)"},
/* 2022 */ { "BULLET","	= black small circle\n"
	"	x (middle dot - 00B7)\n"
	"	x (one dot leader - 2024)\n"
	"	x (bullet operator - 2219)\n"
	"	x (inverse bullet - 25D8)\n"
	"	x (white bullet - 25E6)"},
/* 2023 */ { "TRIANGULAR BULLET","	x (end of proof - 220E)\n"
	"	x (black right-pointing small triangle - 25B8)"},
/* 2024 */ { "ONE DOT LEADER","	* also used as an Armenian semicolon (mijaket)\n"
	"	x (middle dot - 00B7)\n"
	"	x (bullet - 2022)\n"
	"	x (bullet operator - 2219)\n"
	"	# 002E full stop"},
/* 2025 */ { "TWO DOT LEADER","	# 002E 002E"},
/* 2026 */ { "HORIZONTAL ELLIPSIS","	= three dot leader\n"
	"	x (vertical ellipsis - 22EE)\n"
	"	x (presentation form for vertical horizontal ellipsis - FE19)\n"
	"	# 002E 002E 002E"},
/* 2027 */ { "HYPHENATION POINT","	* visible symbol used to indicate correct positions for word breaking, as in dic·tion·ar·ies"},
/* 2028 */ { "LINE SEPARATOR","	* may be used to represent this semantic unambiguously"},
/* 2029 */ { "PARAGRAPH SEPARATOR","	* may be used to represent this semantic unambiguously"},
/* 202A */ { "LEFT-TO-RIGHT EMBEDDING","	* commonly abbreviated LRE"},
/* 202B */ { "RIGHT-TO-LEFT EMBEDDING","	* commonly abbreviated RLE"},
/* 202C */ { "POP DIRECTIONAL FORMATTING","	* commonly abbreviated PDF"},
/* 202D */ { "LEFT-TO-RIGHT OVERRIDE","	* commonly abbreviated LRO"},
/* 202E */ { "RIGHT-TO-LEFT OVERRIDE","	* commonly abbreviated RLO"},
/* 202F */ { "NARROW NO-BREAK SPACE","	= no-break thin space\n"
	"	* commonly abbreviated NNBSP\n"
	"	* a narrow form of a no-break space; should be the same width as thin space 2009\n"
	"	x (no-break space - 00A0)\n"
	"	x (four-per-em space - 2005)\n"
	"	x (thin space - 2009)\n"
	"	# <noBreak> 0020"},
/* 2030 */ { "PER MILLE SIGN","	= permille, per thousand\n"
	"	* used, for example, in measures of blood alcohol content, salinity, etc.\n"
	"	x (percent sign - 0025)\n"
	"	x (arabic-indic per mille sign - 0609)"},
/* 2031 */ { "PER TEN THOUSAND SIGN","	= permyriad\n"
	"	* percent of a percent, rarely used\n"
	"	x (percent sign - 0025)\n"
	"	x (arabic-indic per ten thousand sign - 060A)"},
/* 2032 */ { "PRIME","	= minutes, feet\n"
	"	x (apostrophe - 0027)\n"
	"	x (acute accent - 00B4)\n"
	"	x (modifier letter prime - 02B9)"},
/* 2033 */ { "DOUBLE PRIME","	= seconds, inches\n"
	"	x (quotation mark - 0022)\n"
	"	x (modifier letter double prime - 02BA)\n"
	"	x (right double quotation mark - 201D)\n"
	"	x (ditto mark - 3003)\n"
	"	x (double prime quotation mark - 301E)\n"
	"	# 2032 2032"},
/* 2034 */ { "TRIPLE PRIME","	= lines (old measure, 1/12 of an inch)\n"
	"	# 2032 2032 2032"},
/* 2035 */ { "REVERSED PRIME","	x (grave accent - 0060)"},
/* 2036 */ { "REVERSED DOUBLE PRIME","	x (reversed double prime quotation mark - 301D)\n"
	"	# 2035 2035"},
/* 2037 */ { "REVERSED TRIPLE PRIME","	# 2035 2035 2035"},
/* 2038 */ { "CARET","	x (up arrowhead - 2303)\n"
	"	x (modifier letter low circumflex accent - A788)"},
/* 2039 */ { "SINGLE LEFT-POINTING ANGLE QUOTATION MARK","	= left pointing single guillemet\n"
	"	* usually opening, sometimes closing\n"
	"	x (less-than sign - 003C)\n"
	"	x (left-pointing angle bracket - 2329)\n"
	"	x (left angle bracket - 3008)"},
/* 203A */ { "SINGLE RIGHT-POINTING ANGLE QUOTATION MARK","	= right pointing single guillemet\n"
	"	* usually closing, sometimes opening\n"
	"	x (greater-than sign - 003E)\n"
	"	x (right-pointing angle bracket - 232A)\n"
	"	x (right angle bracket - 3009)"},
/* 203B */ { "REFERENCE MARK","	= Japanese kome\n"
	"	= Urdu paragraph separator\n"
	"	x (tibetan ku ru kha bzhi mig can - 0FBF)\n"
	"	x 200AD"},
/* 203C */ { "DOUBLE EXCLAMATION MARK","	x (exclamation mark - 0021)\n"
	"	# 0021 0021"},
/* 203D */ { "INTERROBANG","	x (exclamation mark - 0021)\n"
	"	x (question mark - 003F)\n"
	"	x (inverted interrobang - 2E18)\n"
	"	x (heavy interrobang ornament - 1F679)"},
/* 203E */ { "OVERLINE","	= spacing overscore\n"
	"	# 0020 0305"},
/* 203F */ { "UNDERTIE","	= Greek enotikon\n"
	"	x (smile - 2323)"},
/* 2040 */ { "CHARACTER TIE","	= z notation sequence concatenation\n"
	"	x (frown - 2322)"},
/* 2041 */ { "CARET INSERTION POINT","	* proofreader's mark: insert here\n"
	"	x (right semidirect product - 22CC)"},
/* 2042 */ { "ASTERISM",NULL},
/* 2043 */ { "HYPHEN BULLET","	x (hyphen-minus - 002D)"},
/* 2044 */ { "FRACTION SLASH","	= solidus (in typography)\n"
	"	* for composing arbitrary fractions\n"
	"	x (solidus - 002F)\n"
	"	x (division slash - 2215)"},
/* 2045 */ { "LEFT SQUARE BRACKET WITH QUILL","	x (left vertical bar with quill - 2E20)\n"
	"	x (left square bracket with stroke - 2E55)"},
/* 2046 */ { "RIGHT SQUARE BRACKET WITH QUILL",NULL},
/* 2047 */ { "DOUBLE QUESTION MARK","	# 003F 003F"},
/* 2048 */ { "QUESTION EXCLAMATION MARK","	# 003F 0021"},
/* 2049 */ { "EXCLAMATION QUESTION MARK","	# 0021 003F"},
/* 204A */ { "TIRONIAN SIGN ET","	* Irish Gaelic, Old English, ...\n"
	"	x (ampersand - 0026)\n"
	"	x (tironian sign capital et - 2E52)\n"
	"	x (script ligature et ornament - 1F670)"},
/* 204B */ { "REVERSED PILCROW SIGN","	x (pilcrow sign - 00B6)\n"
	"	x (paragraphus mark - 2E4D)"},
/* 204C */ { "BLACK LEFTWARDS BULLET",NULL},
/* 204D */ { "BLACK RIGHTWARDS BULLET",NULL},
/* 204E */ { "LOW ASTERISK","	x (asterisk - 002A)\n"
	"	x (combining asterisk below - 0359)"},
/* 204F */ { "REVERSED SEMICOLON","	* used occasionally in Sindhi when Sindhi is written in the Arabic script\n"
	"	x (semicolon - 003B)\n"
	"	x (arabic semicolon - 061B)"},
/* 2050 */ { "CLOSE UP","	* editing mark\n"
	"	x (modifier breve with inverted breve - AB5B)"},
/* 2051 */ { "TWO ASTERISKS ALIGNED VERTICALLY",NULL},
/* 2052 */ { "COMMERCIAL MINUS SIGN","	= abzüglich (German), med avdrag av (Swedish), piska (Swedish, \"whip\")\n"
	"	* a common glyph variant and fallback representation looks like ./.\n"
	"	* may also be used as a dingbat to indicate correctness\n"
	"	* used in Finno-Ugric Phonetic Alphabet to indicate a related borrowed form with different sound\n"
	"	x (percent sign - 0025)\n"
	"	x (arabic percent sign - 066A)\n"
	"	x (division sign - 00F7)"},
/* 2053 */ { "SWUNG DASH","	x (tilde - 007E)"},
/* 2054 */ { "INVERTED UNDERTIE",NULL},
/* 2055 */ { "FLOWER PUNCTUATION MARK","	= phul, puspika\n"
	"	* used as a punctuation mark with Syloti Nagri, Bengali and other Indic scripts\n"
	"	x (heavy eight teardrop-spoked propeller asterisk - 274B)"},
/* 2056 */ { "THREE DOT PUNCTUATION","	x (georgian paragraph separator - 10FB)"},
/* 2057 */ { "QUADRUPLE PRIME","	# 2032 2032 2032 2032"},
/* 2058 */ { "FOUR DOT PUNCTUATION",NULL},
/* 2059 */ { "FIVE DOT PUNCTUATION","	= Greek pentonkion\n"
	"	= quincunx\n"
	"	x (die face-5 - 2684)"},
/* 205A */ { "TWO DOT PUNCTUATION","	* historically used to indicate the end of a sentence or change of speaker\n"
	"	* extends from baseline to cap height\n"
	"	x (presentation form for vertical two dot leader - FE30)\n"
	"	x (greek acrophonic epidaurean two - 1015B)"},
/* 205B */ { "FOUR DOT MARK","	* used by scribes in the margin as highlighter mark\n"
	"	* this is centered on the line, but extends beyond top and bottom of the line"},
/* 205C */ { "DOTTED CROSS","	* used by scribes in the margin as highlighter mark"},
/* 205D */ { "TRICOLON","	= Epidaurean acrophonic symbol three\n"
	"	x (vertical ellipsis - 22EE)\n"
	"	x (triple colon operator - 2AF6)\n"
	"	x (presentation form for vertical horizontal ellipsis - FE19)"},
/* 205E */ { "VERTICAL FOUR DOTS","	* used in dictionaries to indicate legal but undesirable word break\n"
	"	* glyph extends the whole height of the line\n"
	"	x (vertical six dots - 2E3D)"},
/* 205F */ { "MEDIUM MATHEMATICAL SPACE","	* abbreviated MMSP\n"
	"	* four-eighteenths of an em\n"
	"	# 0020 space"},
/* 2060 */ { "WORD JOINER","	* commonly abbreviated WJ\n"
	"	* a zero width non-breaking space (only)\n"
	"	* intended for disambiguation of functions for byte order mark\n"
	"	x (zero width no-break space - FEFF)"},
/* 2061 */ { "FUNCTION APPLICATION","	* contiguity operator indicating application of a function"},
/* 2062 */ { "INVISIBLE TIMES","	* contiguity operator indicating multiplication"},
/* 2063 */ { "INVISIBLE SEPARATOR","	= invisible comma\n"
	"	* contiguity operator indicating that adjacent mathematical symbols form a list, e.g. when no visible comma is used between multiple indices"},
/* 2064 */ { "INVISIBLE PLUS","	* contiguity operator indicating addition"},
/* 2065 */ { NULL,NULL},
/* 2066 */ { "LEFT-TO-RIGHT ISOLATE","	* commonly abbreviated LRI"},
/* 2067 */ { "RIGHT-TO-LEFT ISOLATE","	* commonly abbreviated RLI"},
/* 2068 */ { "FIRST STRONG ISOLATE","	* commonly abbreviated FSI"},
/* 2069 */ { "POP DIRECTIONAL ISOLATE","	* commonly abbreviated PDI"},
/* 206A */ { "INHIBIT SYMMETRIC SWAPPING",NULL},
/* 206B */ { "ACTIVATE SYMMETRIC SWAPPING",NULL},
/* 206C */ { "INHIBIT ARABIC FORM SHAPING",NULL},
/* 206D */ { "ACTIVATE ARABIC FORM SHAPING",NULL},
/* 206E */ { "NATIONAL DIGIT SHAPES",NULL},
/* 206F */ { "NOMINAL DIGIT SHAPES",NULL},
/* 2070 */ { "SUPERSCRIPT ZERO","	# <super> 0030"},
/* 2071 */ { "SUPERSCRIPT LATIN SMALL LETTER I","	* functions as a modifier letter\n"
	"	# <super> 0069"},
/* 2072 */ { NULL,"	x (superscript two - 00B2)"},
/* 2073 */ { NULL,"	x (superscript three - 00B3)"},
/* 2074 */ { "SUPERSCRIPT FOUR","	# <super> 0034"},
/* 2075 */ { "SUPERSCRIPT FIVE","	# <super> 0035"},
/* 2076 */ { "SUPERSCRIPT SIX","	# <super> 0036"},
/* 2077 */ { "SUPERSCRIPT SEVEN","	# <super> 0037"},
/* 2078 */ { "SUPERSCRIPT EIGHT","	# <super> 0038"},
/* 2079 */ { "SUPERSCRIPT NINE","	# <super> 0039"},
/* 207A */ { "SUPERSCRIPT PLUS SIGN","	# <super> 002B"},
/* 207B */ { "SUPERSCRIPT MINUS","	# <super> 2212"},
/* 207C */ { "SUPERSCRIPT EQUALS SIGN","	# <super> 003D"},
/* 207D */ { "SUPERSCRIPT LEFT PARENTHESIS","	# <super> 0028"},
/* 207E */ { "SUPERSCRIPT RIGHT PARENTHESIS","	# <super> 0029"},
/* 207F */ { "SUPERSCRIPT LATIN SMALL LETTER N","	* functions as a modifier letter\n"
	"	# <super> 006E"},
/* 2080 */ { "SUBSCRIPT ZERO","	# <sub> 0030"},
/* 2081 */ { "SUBSCRIPT ONE","	# <sub> 0031"},
/* 2082 */ { "SUBSCRIPT TWO","	# <sub> 0032"},
/* 2083 */ { "SUBSCRIPT THREE","	# <sub> 0033"},
/* 2084 */ { "SUBSCRIPT FOUR","	# <sub> 0034"},
/* 2085 */ { "SUBSCRIPT FIVE","	# <sub> 0035"},
/* 2086 */ { "SUBSCRIPT SIX","	# <sub> 0036"},
/* 2087 */ { "SUBSCRIPT SEVEN","	# <sub> 0037"},
/* 2088 */ { "SUBSCRIPT EIGHT","	# <sub> 0038"},
/* 2089 */ { "SUBSCRIPT NINE","	# <sub> 0039"},
/* 208A */ { "SUBSCRIPT PLUS SIGN","	# <sub> 002B"},
/* 208B */ { "SUBSCRIPT MINUS","	# <sub> 2212"},
/* 208C */ { "SUBSCRIPT EQUALS SIGN","	# <sub> 003D"},
/* 208D */ { "SUBSCRIPT LEFT PARENTHESIS","	# <sub> 0028"},
/* 208E */ { "SUBSCRIPT RIGHT PARENTHESIS","	# <sub> 0029"},
/* 208F */ { NULL,NULL},
/* 2090 */ { "LATIN SUBSCRIPT SMALL LETTER A","	# <sub> 0061"},
/* 2091 */ { "LATIN SUBSCRIPT SMALL LETTER E","	# <sub> 0065"},
/* 2092 */ { "LATIN SUBSCRIPT SMALL LETTER O","	# <sub> 006F"},
/* 2093 */ { "LATIN SUBSCRIPT SMALL LETTER X","	# <sub> 0078"},
/* 2094 */ { "LATIN SUBSCRIPT SMALL LETTER SCHWA","	# <sub> 0259"},
/* 2095 */ { "LATIN SUBSCRIPT SMALL LETTER H","	# <sub> 0068"},
/* 2096 */ { "LATIN SUBSCRIPT SMALL LETTER K","	# <sub> 006B"},
/* 2097 */ { "LATIN SUBSCRIPT SMALL LETTER L","	# <sub> 006C"},
/* 2098 */ { "LATIN SUBSCRIPT SMALL LETTER M","	# <sub> 006D"},
/* 2099 */ { "LATIN SUBSCRIPT SMALL LETTER N","	# <sub> 006E"},
/* 209A */ { "LATIN SUBSCRIPT SMALL LETTER P","	# <sub> 0070"},
/* 209B */ { "LATIN SUBSCRIPT SMALL LETTER S","	# <sub> 0073"},
/* 209C */ { "LATIN SUBSCRIPT SMALL LETTER T","	# <sub> 0074"},
/* 209D */ { NULL,NULL},
/* 209E */ { NULL,NULL},
/* 209F */ { NULL,NULL},
/* 20A0 */ { "EURO-CURRENCY SIGN","	* intended for ECU, but not widely used\n"
	"	* historical character; this is NOT the euro!\n"
	"	x (euro sign - 20AC)"},
/* 20A1 */ { "COLON SIGN","	* Costa Rica, El Salvador"},
/* 20A2 */ { "CRUZEIRO SIGN","	* Brazil"},
/* 20A3 */ { "FRENCH FRANC SIGN","	* France\n"
	"	x (latin capital letter f with stroke - A798)"},
/* 20A4 */ { "LIRA SIGN","	* intended for lira, but not widely used\n"
	"	* preferred character for lira is 00A3\n"
	"	x (pound sign - 00A3)\n"
	"	x (turkish lira sign - 20BA)"},
/* 20A5 */ { "MILL SIGN","	* USA (1/10 cent)"},
/* 20A6 */ { "NAIRA SIGN","	* Nigeria"},
/* 20A7 */ { "PESETA SIGN","	* Spain\n"
	"	x (peso sign - 20B1)"},
/* 20A8 */ { "RUPEE SIGN","	* India, unofficial legacy practice\n"
	"	x (indian rupee sign - 20B9)\n"
	"	# 0052 0073"},
/* 20A9 */ { "WON SIGN","	* Korea\n"
	"	* glyph may have one or two crossbars, but the most common form in Korea has only one"},
/* 20AA */ { "NEW SHEQEL SIGN","	= shekel\n"
	"	* Israel"},
/* 20AB */ { "DONG SIGN","	* Vietnam"},
/* 20AC */ { "EURO SIGN","	* currency sign for the European Monetary Union\n"
	"	* euro, not ecu\n"
	"	x (euro-currency sign - 20A0)"},
/* 20AD */ { "KIP SIGN","	* Laos"},
/* 20AE */ { "TUGRIK SIGN","	* Mongolia\n"
	"	* also transliterated as tugrug, tugric, tugrog, togrog, tögrög"},
/* 20AF */ { "DRACHMA SIGN","	* Greece"},
/* 20B0 */ { "GERMAN PENNY SIGN",NULL},
/* 20B1 */ { "PESO SIGN","	= Filipino peso sign\n"
	"	* Philippines\n"
	"	* extant and discontinued Latin-American peso currencies (Mexican, Chilean, Colombian, etc.) use the dollar sign\n"
	"	x (dollar sign - 0024)\n"
	"	x (peseta sign - 20A7)"},
/* 20B2 */ { "GUARANI SIGN","	* Paraguay\n"
	"	* Often represented by G. or Gs."},
/* 20B3 */ { "AUSTRAL SIGN","	* former Argentinian currency"},
/* 20B4 */ { "HRYVNIA SIGN","	* Ukraine"},
/* 20B5 */ { "CEDI SIGN","	* Ghana\n"
	"	* glyph may look like '023B' or like C with a short vertical stroke through the upper arm\n"
	"	x (cent sign - 00A2)\n"
	"	x (latin capital letter c with stroke - 023B)"},
/* 20B6 */ { "LIVRE TOURNOIS SIGN","	* used in France from 13th-18th centuries"},
/* 20B7 */ { "SPESMILO SIGN","	* historical international currency associated with Esperanto"},
/* 20B8 */ { "TENGE SIGN","	* Kazakhstan\n"
	"	x (apl functional symbol up tack overbar - 2351)\n"
	"	x (box drawings down single and horizontal double - 2564)\n"
	"	x (postal mark - 3012)"},
/* 20B9 */ { "INDIAN RUPEE SIGN","	* official rupee currency sign for India\n"
	"	* contrasts with script-specific rupee signs and abbreviations\n"
	"	x (devanagari letter ra - 0930)"},
/* 20BA */ { "TURKISH LIRA SIGN","	* official lira currency sign for Turkey"},
/* 20BB */ { "NORDIC MARK SIGN","	* early representation of the Mark currency used in Denmark and Norway\n"
	"	x (script capital m - 2133)"},
/* 20BC */ { "MANAT SIGN","	* Azerbaijan"},
/* 20BD */ { "RUBLE SIGN","	* Russia"},
/* 20BE */ { "LARI SIGN","	* Georgia"},
/* 20BF */ { "BITCOIN SIGN","	* a cryptocurrency"},
/* 20C0 */ { "SOM SIGN","	* Kyrgyzstan"},
/* 20C1 */ { "SAUDI RIYAL SIGN","	* Saudi Arabia"},
/* 20C2 */ { NULL,NULL},
/* 20C3 */ { NULL,NULL},
/* 20C4 */ { NULL,NULL},
/* 20C5 */ { NULL,NULL},
/* 20C6 */ { NULL,NULL},
/* 20C7 */ { NULL,NULL},
/* 20C8 */ { NULL,NULL},
/* 20C9 */ { NULL,NULL},
/* 20CA */ { NULL,NULL},
/* 20CB */ { NULL,NULL},
/* 20CC */ { NULL,NULL},
/* 20CD */ { NULL,NULL},
/* 20CE */ { NULL,NULL},
/* 20CF */ { NULL,NULL},
/* 20D0 */ { "COMBINING LEFT HARPOON ABOVE",NULL},
/* 20D1 */ { "COMBINING RIGHT HARPOON ABOVE","	* vector"},
/* 20D2 */ { "COMBINING LONG VERTICAL LINE OVERLAY","	* negation"},
/* 20D3 */ { "COMBINING SHORT VERTICAL LINE OVERLAY","	* occasional variant for negation"},
/* 20D4 */ { "COMBINING ANTICLOCKWISE ARROW ABOVE",NULL},
/* 20D5 */ { "COMBINING CLOCKWISE ARROW ABOVE","	* rotation"},
/* 20D6 */ { "COMBINING LEFT ARROW ABOVE",NULL},
/* 20D7 */ { "COMBINING RIGHT ARROW ABOVE","	* vector"},
/* 20D8 */ { "COMBINING RING OVERLAY",NULL},
/* 20D9 */ { "COMBINING CLOCKWISE RING OVERLAY",NULL},
/* 20DA */ { "COMBINING ANTICLOCKWISE RING OVERLAY",NULL},
/* 20DB */ { "COMBINING THREE DOTS ABOVE","	= third derivative"},
/* 20DC */ { "COMBINING FOUR DOTS ABOVE","	= fourth derivative"},
/* 20DD */ { "COMBINING ENCLOSING CIRCLE","	= JIS composition circle\n"
	"	= Cyrillic combining ten thousands sign\n"
	"	x (white circle - 25CB)\n"
	"	x (large circle - 25EF)\n"
	"	x (ideographic number zero - 3007)"},
/* 20DE */ { "COMBINING ENCLOSING SQUARE","	x (white square - 25A1)"},
/* 20DF */ { "COMBINING ENCLOSING DIAMOND","	x (white diamond - 25C7)"},
/* 20E0 */ { "COMBINING ENCLOSING CIRCLE BACKSLASH","	* prohibition\n"
	"	x (prohibited sign - 1F6C7)"},
/* 20E1 */ { "COMBINING LEFT RIGHT ARROW ABOVE","	* tensor\n"
	"	x (combining left right arrow below - 034D)"},
/* 20E2 */ { "COMBINING ENCLOSING SCREEN","	x (clear screen symbol - 239A)\n"
	"	x (screen - 1F5B5)"},
/* 20E3 */ { "COMBINING ENCLOSING KEYCAP",NULL},
/* 20E4 */ { "COMBINING ENCLOSING UPWARD POINTING TRIANGLE","	x (white up-pointing triangle - 25B3)"},
/* 20E5 */ { "COMBINING REVERSE SOLIDUS OVERLAY","	x (reverse solidus - 005C)"},
/* 20E6 */ { "COMBINING DOUBLE VERTICAL STROKE OVERLAY","	= z notation finite function diacritic\n"
	"	x (double vertical line - 2016)\n"
	"	x (rightwards arrow with double vertical stroke - 21FB)\n"
	"	x (rightwards two-headed arrow with double vertical stroke - 2901)\n"
	"	x (rightwards arrow with tail with double vertical stroke - 2915)"},
/* 20E7 */ { "COMBINING ANNUITY SYMBOL","	= actuarial bend\n"
	"	x (right ceiling - 2309)"},
/* 20E8 */ { "COMBINING TRIPLE UNDERDOT",NULL},
/* 20E9 */ { "COMBINING WIDE BRIDGE ABOVE","	= contraction operator\n"
	"	* extends the full width of the base character\n"
	"	x (combining bridge above - 0346)"},
/* 20EA */ { "COMBINING LEFTWARDS ARROW OVERLAY","	x (leftwards arrow - 2190)"},
/* 20EB */ { "COMBINING LONG DOUBLE SOLIDUS OVERLAY","	= long double slash overlay"},
/* 20EC */ { "COMBINING RIGHTWARDS HARPOON WITH BARB DOWNWARDS",NULL},
/* 20ED */ { "COMBINING LEFTWARDS HARPOON WITH BARB DOWNWARDS",NULL},
/* 20EE */ { "COMBINING LEFT ARROW BELOW",NULL},
/* 20EF */ { "COMBINING RIGHT ARROW BELOW",NULL},
/* 20F0 */ { "COMBINING ASTERISK ABOVE",NULL},
/* 20F1 */ { NULL,NULL},
/* 20F2 */ { NULL,NULL},
/* 20F3 */ { NULL,NULL},
/* 20F4 */ { NULL,NULL},
/* 20F5 */ { NULL,NULL},
/* 20F6 */ { NULL,NULL},
/* 20F7 */ { NULL,NULL},
/* 20F8 */ { NULL,NULL},
/* 20F9 */ { NULL,NULL},
/* 20FA */ { NULL,NULL},
/* 20FB */ { NULL,NULL},
/* 20FC */ { NULL,NULL},
/* 20FD */ { NULL,NULL},
/* 20FE */ { NULL,NULL},
/* 20FF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_00_21[] = {
/* 2100 */ { "ACCOUNT OF","	# 0061 002F 0063"},
/* 2101 */ { "ADDRESSED TO THE SUBJECT","	= aux soins (de)\n"
	"	x (aktieselskab - 214D)\n"
	"	# 0061 002F 0073"},
/* 2102 */ { "DOUBLE-STRUCK CAPITAL C","	= the set of complex numbers\n"
	"	# <font> 0043 latin capital letter c"},
/* 2103 */ { "DEGREE CELSIUS","	= degrees centigrade\n"
	"	# 00B0 0043"},
/* 2104 */ { "CENTRE LINE SYMBOL","	= clone"},
/* 2105 */ { "CARE OF","	# 0063 002F 006F"},
/* 2106 */ { "CADA UNA","	* Spanish for \"each one\"\n"
	"	# 0063 002F 0075"},
/* 2107 */ { "EULER CONSTANT","	x (latin capital letter e - 0045)\n"
	"	# 0190 latin capital letter open e"},
/* 2108 */ { "SCRUPLE",NULL},
/* 2109 */ { "DEGREE FAHRENHEIT","	# 00B0 0046"},
/* 210A */ { "SCRIPT SMALL G","	= real number symbol\n"
	"	# <font> 0067 latin small letter g"},
/* 210B */ { "SCRIPT CAPITAL H","	= Hamiltonian operator\n"
	"	~ 210B FE00 chancery style\n"
	"	~ 210B FE01 roundhand style\n"
	"	# <font> 0048 latin capital letter h"},
/* 210C */ { "BLACK-LETTER CAPITAL H","	= Hilbert space\n"
	"	# <font> 0048 latin capital letter h"},
/* 210D */ { "DOUBLE-STRUCK CAPITAL H","	# <font> 0048 latin capital letter h"},
/* 210E */ { "PLANCK CONSTANT","	= height, specific enthalpy, ...\n"
	"	* simply a mathematical italic h; this character's name results from legacy usage\n"
	"	# <font> 0068 latin small letter h"},
/* 210F */ { "PLANCK CONSTANT OVER TWO PI","	= reduced Planck constant, Dirac constant\n"
	"	x (cyrillic small letter tshe - 045B)\n"
	"	# <font> 0127 latin small letter h with stroke"},
/* 2110 */ { "SCRIPT CAPITAL I","	~ 2110 FE00 chancery style\n"
	"	~ 2110 FE01 roundhand style\n"
	"	# <font> 0049 latin capital letter i"},
/* 2111 */ { "BLACK-LETTER CAPITAL I","	= imaginary part\n"
	"	# <font> 0049 latin capital letter i"},
/* 2112 */ { "SCRIPT CAPITAL L","	= Laplace transform\n"
	"	~ 2112 FE00 chancery style\n"
	"	~ 2112 FE01 roundhand style\n"
	"	# <font> 004C latin capital letter l"},
/* 2113 */ { "SCRIPT SMALL L","	= mathematical symbol 'ell'\n"
	"	= liter (traditional symbol)\n"
	"	* despite its character name, this symbol is derived from a special italicized version of the small letter l\n"
	"	* the SI recommended symbol for liter is 006C or 004C\n"
	"	x (mathematical script small l - 1D4C1)\n"
	"	# <font> 006C latin small letter l"},
/* 2114 */ { "L B BAR SYMBOL","	= pounds\n"
	"	x (number sign - 0023)"},
/* 2115 */ { "DOUBLE-STRUCK CAPITAL N","	= natural number\n"
	"	* a glyph variant with doubled vertical strokes exists\n"
	"	# <font> 004E latin capital letter n"},
/* 2116 */ { "NUMERO SIGN","	x (number sign - 0023)\n"
	"	x (masculine ordinal indicator - 00BA)\n"
	"	# 004E 006F"},
/* 2117 */ { "SOUND RECORDING COPYRIGHT","	= published\n"
	"	= phonorecord sign\n"
	"	x (copyright sign - 00A9)\n"
	"	x (circled latin capital letter p - 24C5)"},
/* 2118 */ { "SCRIPT CAPITAL P","	% WEIERSTRASS ELLIPTIC FUNCTION\n"
	"	* actually this has the form of a lowercase calligraphic p, despite its name"},
/* 2119 */ { "DOUBLE-STRUCK CAPITAL P","	# <font> 0050 latin capital letter p"},
/* 211A */ { "DOUBLE-STRUCK CAPITAL Q","	= the set of rational numbers\n"
	"	# <font> 0051 latin capital letter q"},
/* 211B */ { "SCRIPT CAPITAL R","	= Riemann Integral\n"
	"	~ 211B FE00 chancery style\n"
	"	~ 211B FE01 roundhand style\n"
	"	# <font> 0052 latin capital letter r"},
/* 211C */ { "BLACK-LETTER CAPITAL R","	= real part\n"
	"	# <font> 0052 latin capital letter r"},
/* 211D */ { "DOUBLE-STRUCK CAPITAL R","	= the set of real numbers\n"
	"	# <font> 0052 latin capital letter r"},
/* 211E */ { "PRESCRIPTION TAKE","	= recipe\n"
	"	= cross ratio"},
/* 211F */ { "RESPONSE",NULL},
/* 2120 */ { "SERVICE MARK","	# <super> 0053 004D"},
/* 2121 */ { "TELEPHONE SIGN","	* typical forms for this symbol may use lowercase, small caps or superscripted letter shapes\n"
	"	x (black telephone - 260E)\n"
	"	x (telephone location sign - 2706)\n"
	"	x (telephone receiver - 1F4DE)\n"
	"	# 0054 0045 004C"},
/* 2122 */ { "TRADE MARK SIGN","	x (circled wz - 1F12E)\n"
	"	# <super> 0054 004D"},
/* 2123 */ { "VERSICLE",NULL},
/* 2124 */ { "DOUBLE-STRUCK CAPITAL Z","	= the set of integers\n"
	"	# <font> 005A latin capital letter z"},
/* 2125 */ { "OUNCE SIGN","	x (latin small letter ezh - 0292)\n"
	"	x (alchemical symbol for half ounce - 1F773)\n"
	"	x 2CF04"},
/* 2126 */ { "OHM SIGN","	* SI unit of resistance, named after G. S. Ohm, German physicist\n"
	"	* preferred representation is 03A9\n"
	"	x (ascending node - 260A)\n"
	"	: 03A9 greek capital letter omega"},
/* 2127 */ { "INVERTED OHM SIGN","	= mho\n"
	"	* archaic unit of conductance (= the SI unit siemens)\n"
	"	* typographically a turned greek capital letter omega\n"
	"	x (latin capital letter upsilon - 01B1)\n"
	"	x (greek capital letter omega - 03A9)\n"
	"	x (descending node - 260B)"},
/* 2128 */ { "BLACK-LETTER CAPITAL Z","	# <font> 005A latin capital letter z"},
/* 2129 */ { "TURNED GREEK SMALL LETTER IOTA","	* unique element fulfilling a description (logic)\n"
	"	x (greek small letter iota - 03B9)"},
/* 212A */ { "KELVIN SIGN","	: 004B latin capital letter k"},
/* 212B */ { "ANGSTROM SIGN","	* non SI length unit (=0.1 nm) named after A. J. Ångström, Swedish physicist\n"
	"	* preferred representation is 00C5\n"
	"	: 00C5 latin capital letter a with ring above"},
/* 212C */ { "SCRIPT CAPITAL B","	= Bernoulli function\n"
	"	~ 212C FE00 chancery style\n"
	"	~ 212C FE01 roundhand style\n"
	"	# <font> 0042 latin capital letter b"},
/* 212D */ { "BLACK-LETTER CAPITAL C","	# <font> 0043 latin capital letter c"},
/* 212E */ { "ESTIMATED SYMBOL","	* used in European packaging\n"
	"	x (latin small letter e - 0065)"},
/* 212F */ { "SCRIPT SMALL E","	= error\n"
	"	= natural exponent\n"
	"	# <font> 0065 latin small letter e"},
/* 2130 */ { "SCRIPT CAPITAL E","	= emf (electromotive force)\n"
	"	~ 2130 FE00 chancery style\n"
	"	~ 2130 FE01 roundhand style\n"
	"	# <font> 0045 latin capital letter e"},
/* 2131 */ { "SCRIPT CAPITAL F","	= Fourier transform\n"
	"	~ 2131 FE00 chancery style\n"
	"	~ 2131 FE01 roundhand style\n"
	"	# <font> 0046 latin capital letter f"},
/* 2132 */ { "TURNED CAPITAL F","	= Claudian digamma inversum\n"
	"	* lowercase is 214E\n"
	"	x (latin capital letter f - 0046)\n"
	"	x (greek letter digamma - 03DC)"},
/* 2133 */ { "SCRIPT CAPITAL M","	= M-matrix (physics)\n"
	"	= German Mark currency symbol, before WWII\n"
	"	* when used for the Mark symbol, the range of glyph variation is restricted\n"
	"	x (nordic mark sign - 20BB)\n"
	"	~ 2133 FE00 chancery style\n"
	"	~ 2133 FE01 roundhand style\n"
	"	# <font> 004D latin capital letter m"},
/* 2134 */ { "SCRIPT SMALL O","	= order, of inferior order to\n"
	"	# <font> 006F latin small letter o"},
/* 2135 */ { "ALEF SYMBOL","	# 05D0 hebrew letter alef"},
/* 2136 */ { "BET SYMBOL","	# 05D1 hebrew letter bet"},
/* 2137 */ { "GIMEL SYMBOL","	# 05D2 hebrew letter gimel"},
/* 2138 */ { "DALET SYMBOL","	# 05D3 hebrew letter dalet"},
/* 2139 */ { "INFORMATION SOURCE","	* intended for use with 20DD\n"
	"	x (circled information source - 1F6C8)\n"
	"	# <font> 0069 latin small letter i"},
/* 213A */ { "ROTATED CAPITAL Q","	* a binding signature mark"},
/* 213B */ { "FACSIMILE SIGN","	* typical forms for this symbol may use lowercase, small caps or superscripted letter shapes\n"
	"	x (telephone sign - 2121)\n"
	"	x (fax machine - 1F4E0)\n"
	"	# 0046 0041 0058"},
/* 213C */ { "DOUBLE-STRUCK SMALL PI","	# <font> 03C0 greek small letter pi"},
/* 213D */ { "DOUBLE-STRUCK SMALL GAMMA","	# <font> 03B3 greek small letter gamma"},
/* 213E */ { "DOUBLE-STRUCK CAPITAL GAMMA","	# <font> 0393 greek capital letter gamma"},
/* 213F */ { "DOUBLE-STRUCK CAPITAL PI","	# <font> 03A0 greek capital letter pi"},
/* 2140 */ { "DOUBLE-STRUCK N-ARY SUMMATION","	# <font> 2211 n-ary summation"},
/* 2141 */ { "TURNED SANS-SERIF CAPITAL G","	= game\n"
	"	x (lisu letter hha - A4E8)"},
/* 2142 */ { "TURNED SANS-SERIF CAPITAL L","	x (lisu letter uh - A4F6)"},
/* 2143 */ { "REVERSED SANS-SERIF CAPITAL L",NULL},
/* 2144 */ { "TURNED SANS-SERIF CAPITAL Y","	x (lisu letter yha - 11FB0)"},
/* 2145 */ { "DOUBLE-STRUCK ITALIC CAPITAL D","	* sometimes used for the differential\n"
	"	# <font> 0044 latin capital letter d"},
/* 2146 */ { "DOUBLE-STRUCK ITALIC SMALL D","	* sometimes used for the differential\n"
	"	# <font> 0064 latin small letter d"},
/* 2147 */ { "DOUBLE-STRUCK ITALIC SMALL E","	* sometimes used for the natural exponent\n"
	"	# <font> 0065 latin small letter e"},
/* 2148 */ { "DOUBLE-STRUCK ITALIC SMALL I","	* sometimes used for the imaginary unit\n"
	"	# <font> 0069 latin small letter i"},
/* 2149 */ { "DOUBLE-STRUCK ITALIC SMALL J","	* sometimes used for the imaginary unit\n"
	"	# <font> 006A latin small letter j"},
/* 214A */ { "PROPERTY LINE",NULL},
/* 214B */ { "TURNED AMPERSAND","	* used in linear logic\n"
	"	x (ampersand - 0026)"},
/* 214C */ { "PER SIGN","	* abbreviates the word 'per'"},
/* 214D */ { "AKTIESELSKAB","	x (addressed to the subject - 2101)"},
/* 214E */ { "TURNED SMALL F","	* uppercase is 2132\n"
	"	x (greek small letter digamma - 03DD)"},
/* 214F */ { "SYMBOL FOR SAMARITAN SOURCE",NULL},
/* 2150 */ { "VULGAR FRACTION ONE SEVENTH","	# <fraction> 0031 2044 0037"},
/* 2151 */ { "VULGAR FRACTION ONE NINTH","	# <fraction> 0031 2044 0039"},
/* 2152 */ { "VULGAR FRACTION ONE TENTH","	# <fraction> 0031 2044 0031 0030"},
/* 2153 */ { "VULGAR FRACTION ONE THIRD","	# <fraction> 0031 2044 0033"},
/* 2154 */ { "VULGAR FRACTION TWO THIRDS","	# <fraction> 0032 2044 0033"},
/* 2155 */ { "VULGAR FRACTION ONE FIFTH","	# <fraction> 0031 2044 0035"},
/* 2156 */ { "VULGAR FRACTION TWO FIFTHS","	# <fraction> 0032 2044 0035"},
/* 2157 */ { "VULGAR FRACTION THREE FIFTHS","	# <fraction> 0033 2044 0035"},
/* 2158 */ { "VULGAR FRACTION FOUR FIFTHS","	# <fraction> 0034 2044 0035"},
/* 2159 */ { "VULGAR FRACTION ONE SIXTH","	# <fraction> 0031 2044 0036"},
/* 215A */ { "VULGAR FRACTION FIVE SIXTHS","	# <fraction> 0035 2044 0036"},
/* 215B */ { "VULGAR FRACTION ONE EIGHTH","	# <fraction> 0031 2044 0038"},
/* 215C */ { "VULGAR FRACTION THREE EIGHTHS","	# <fraction> 0033 2044 0038"},
/* 215D */ { "VULGAR FRACTION FIVE EIGHTHS","	# <fraction> 0035 2044 0038"},
/* 215E */ { "VULGAR FRACTION SEVEN EIGHTHS","	# <fraction> 0037 2044 0038"},
/* 215F */ { "FRACTION NUMERATOR ONE","	# <fraction> 0031 2044"},
/* 2160 */ { "ROMAN NUMERAL ONE","	# 0049 latin capital letter i"},
/* 2161 */ { "ROMAN NUMERAL TWO","	# 0049 0049"},
/* 2162 */ { "ROMAN NUMERAL THREE","	# 0049 0049 0049"},
/* 2163 */ { "ROMAN NUMERAL FOUR","	# 0049 0056"},
/* 2164 */ { "ROMAN NUMERAL FIVE","	# 0056 latin capital letter v"},
/* 2165 */ { "ROMAN NUMERAL SIX","	# 0056 0049"},
/* 2166 */ { "ROMAN NUMERAL SEVEN","	# 0056 0049 0049"},
/* 2167 */ { "ROMAN NUMERAL EIGHT","	# 0056 0049 0049 0049"},
/* 2168 */ { "ROMAN NUMERAL NINE","	# 0049 0058"},
/* 2169 */ { "ROMAN NUMERAL TEN","	# 0058 latin capital letter x"},
/* 216A */ { "ROMAN NUMERAL ELEVEN","	# 0058 0049"},
/* 216B */ { "ROMAN NUMERAL TWELVE","	# 0058 0049 0049"},
/* 216C */ { "ROMAN NUMERAL FIFTY","	# 004C latin capital letter l"},
/* 216D */ { "ROMAN NUMERAL ONE HUNDRED","	# 0043 latin capital letter c"},
/* 216E */ { "ROMAN NUMERAL FIVE HUNDRED","	# 0044 latin capital letter d"},
/* 216F */ { "ROMAN NUMERAL ONE THOUSAND","	# 004D latin capital letter m"},
/* 2170 */ { "SMALL ROMAN NUMERAL ONE","	# 0069 latin small letter i"},
/* 2171 */ { "SMALL ROMAN NUMERAL TWO","	# 0069 0069"},
/* 2172 */ { "SMALL ROMAN NUMERAL THREE","	# 0069 0069 0069"},
/* 2173 */ { "SMALL ROMAN NUMERAL FOUR","	# 0069 0076"},
/* 2174 */ { "SMALL ROMAN NUMERAL FIVE","	# 0076 latin small letter v"},
/* 2175 */ { "SMALL ROMAN NUMERAL SIX","	# 0076 0069"},
/* 2176 */ { "SMALL ROMAN NUMERAL SEVEN","	# 0076 0069 0069"},
/* 2177 */ { "SMALL ROMAN NUMERAL EIGHT","	# 0076 0069 0069 0069"},
/* 2178 */ { "SMALL ROMAN NUMERAL NINE","	# 0069 0078"},
/* 2179 */ { "SMALL ROMAN NUMERAL TEN","	# 0078 latin small letter x"},
/* 217A */ { "SMALL ROMAN NUMERAL ELEVEN","	# 0078 0069"},
/* 217B */ { "SMALL ROMAN NUMERAL TWELVE","	# 0078 0069 0069"},
/* 217C */ { "SMALL ROMAN NUMERAL FIFTY","	# 006C latin small letter l"},
/* 217D */ { "SMALL ROMAN NUMERAL ONE HUNDRED","	# 0063 latin small letter c"},
/* 217E */ { "SMALL ROMAN NUMERAL FIVE HUNDRED","	# 0064 latin small letter d"},
/* 217F */ { "SMALL ROMAN NUMERAL ONE THOUSAND","	# 006D latin small letter m"},
/* 2180 */ { "ROMAN NUMERAL ONE THOUSAND C D",NULL},
/* 2181 */ { "ROMAN NUMERAL FIVE THOUSAND",NULL},
/* 2182 */ { "ROMAN NUMERAL TEN THOUSAND",NULL},
/* 2183 */ { "ROMAN NUMERAL REVERSED ONE HUNDRED","	= apostrophic C\n"
	"	= Claudian antisigma\n"
	"	* used in combination with C and I to form large numbers\n"
	"	* lowercase is 2184\n"
	"	x (latin capital letter open o - 0186)\n"
	"	x (greek capital reversed lunate sigma symbol - 03FD)"},
/* 2184 */ { "LATIN SMALL LETTER REVERSED C","	x (latin small letter open o - 0254)\n"
	"	x (greek small reversed lunate sigma symbol - 037B)"},
/* 2185 */ { "ROMAN NUMERAL SIX LATE FORM","	x (greek letter stigma - 03DA)"},
/* 2186 */ { "ROMAN NUMERAL FIFTY EARLY FORM","	x (runic letter z - 16CE)\n"
	"	x (downwards arrow - 2193)"},
/* 2187 */ { "ROMAN NUMERAL FIFTY THOUSAND",NULL},
/* 2188 */ { "ROMAN NUMERAL ONE HUNDRED THOUSAND",NULL},
/* 2189 */ { "VULGAR FRACTION ZERO THIRDS","	* used in baseball scoring, from ARIB STD B24\n"
	"	# <fraction> 0030 2044 0033"},
/* 218A */ { "TURNED DIGIT TWO","	* digit for 10 in some duodecimal systems"},
/* 218B */ { "TURNED DIGIT THREE","	* digit for 11 in some duodecimal systems\n"
	"	x (latin capital letter open e - 0190)\n"
	"	x (euler constant - 2107)\n"
	"	x (latin small letter tresillo - A72B)"},
/* 218C */ { NULL,NULL},
/* 218D */ { NULL,NULL},
/* 218E */ { NULL,NULL},
/* 218F */ { NULL,NULL},
/* 2190 */ { "LEFTWARDS ARROW","	x (combining leftwards arrow overlay - 20EA)"},
/* 2191 */ { "UPWARDS ARROW","	* IPA: egressive airflow"},
/* 2192 */ { "RIGHTWARDS ARROW","	= z notation total function"},
/* 2193 */ { "DOWNWARDS ARROW","	* IPA: ingressive airflow\n"
	"	x (leftwards arrow from downwards arrow - 1F8C0)"},
/* 2194 */ { "LEFT RIGHT ARROW","	= z notation relation"},
/* 2195 */ { "UP DOWN ARROW",NULL},
/* 2196 */ { "NORTH WEST ARROW",NULL},
/* 2197 */ { "NORTH EAST ARROW",NULL},
/* 2198 */ { "SOUTH EAST ARROW",NULL},
/* 2199 */ { "SOUTH WEST ARROW",NULL},
/* 219A */ { "LEFTWARDS ARROW WITH STROKE","	* negation of 2190\n"
	"	: 2190 0338"},
/* 219B */ { "RIGHTWARDS ARROW WITH STROKE","	* negation of 2192\n"
	"	: 2192 0338"},
/* 219C */ { "LEFTWARDS WAVE ARROW","	x (wave arrow pointing directly left - 2B3F)"},
/* 219D */ { "RIGHTWARDS WAVE ARROW",NULL},
/* 219E */ { "LEFTWARDS TWO HEADED ARROW","	= fast cursor left\n"
	"	x (leftwards two-headed arrow with triangle arrowheads - 2BEC)"},
/* 219F */ { "UPWARDS TWO HEADED ARROW","	= fast cursor up"},
/* 21A0 */ { "RIGHTWARDS TWO HEADED ARROW","	= z notation total surjection\n"
	"	= fast cursor right"},
/* 21A1 */ { "DOWNWARDS TWO HEADED ARROW","	= form feed\n"
	"	= fast cursor down"},
/* 21A2 */ { "LEFTWARDS ARROW WITH TAIL",NULL},
/* 21A3 */ { "RIGHTWARDS ARROW WITH TAIL","	= z notation total injection"},
/* 21A4 */ { "LEFTWARDS ARROW FROM BAR",NULL},
/* 21A5 */ { "UPWARDS ARROW FROM BAR",NULL},
/* 21A6 */ { "RIGHTWARDS ARROW FROM BAR","	= z notation maplet"},
/* 21A7 */ { "DOWNWARDS ARROW FROM BAR","	= depth symbol"},
/* 21A8 */ { "UP DOWN ARROW WITH BASE",NULL},
/* 21A9 */ { "LEFTWARDS ARROW WITH HOOK",NULL},
/* 21AA */ { "RIGHTWARDS ARROW WITH HOOK",NULL},
/* 21AB */ { "LEFTWARDS ARROW WITH LOOP",NULL},
/* 21AC */ { "RIGHTWARDS ARROW WITH LOOP",NULL},
/* 21AD */ { "LEFT RIGHT WAVE ARROW",NULL},
/* 21AE */ { "LEFT RIGHT ARROW WITH STROKE","	* negation of 2194\n"
	"	: 2194 0338"},
/* 21AF */ { "DOWNWARDS ZIGZAG ARROW","	= electrolysis\n"
	"	x (downwards triangle-headed zigzag arrow - 2B4D)"},
/* 21B0 */ { "UPWARDS ARROW WITH TIP LEFTWARDS",NULL},
/* 21B1 */ { "UPWARDS ARROW WITH TIP RIGHTWARDS",NULL},
/* 21B2 */ { "DOWNWARDS ARROW WITH TIP LEFTWARDS","	x (inverse downwards arrow with tip leftwards - 1FBB4)"},
/* 21B3 */ { "DOWNWARDS ARROW WITH TIP RIGHTWARDS",NULL},
/* 21B4 */ { "RIGHTWARDS ARROW WITH CORNER DOWNWARDS","	= line feed"},
/* 21B5 */ { "DOWNWARDS ARROW WITH CORNER LEFTWARDS","	* may indicate a carriage return or new line\n"
	"	x (return symbol - 23CE)"},
/* 21B6 */ { "ANTICLOCKWISE TOP SEMICIRCLE ARROW",NULL},
/* 21B7 */ { "CLOCKWISE TOP SEMICIRCLE ARROW",NULL},
/* 21B8 */ { "NORTH WEST ARROW TO LONG BAR","	= home"},
/* 21B9 */ { "LEFTWARDS ARROW TO BAR OVER RIGHTWARDS ARROW TO BAR","	= tab with shift tab\n"
	"	x (horizontal tab key - 2B7E)"},
/* 21BA */ { "ANTICLOCKWISE OPEN CIRCLE ARROW",NULL},
/* 21BB */ { "CLOCKWISE OPEN CIRCLE ARROW",NULL},
/* 21BC */ { "LEFTWARDS HARPOON WITH BARB UPWARDS",NULL},
/* 21BD */ { "LEFTWARDS HARPOON WITH BARB DOWNWARDS",NULL},
/* 21BE */ { "UPWARDS HARPOON WITH BARB RIGHTWARDS",NULL},
/* 21BF */ { "UPWARDS HARPOON WITH BARB LEFTWARDS",NULL},
/* 21C0 */ { "RIGHTWARDS HARPOON WITH BARB UPWARDS",NULL},
/* 21C1 */ { "RIGHTWARDS HARPOON WITH BARB DOWNWARDS",NULL},
/* 21C2 */ { "DOWNWARDS HARPOON WITH BARB RIGHTWARDS",NULL},
/* 21C3 */ { "DOWNWARDS HARPOON WITH BARB LEFTWARDS",NULL},
/* 21C4 */ { "RIGHTWARDS ARROW OVER LEFTWARDS ARROW","	x (long rightwards arrow over long leftwards arrow - 1F8D0)"},
/* 21C5 */ { "UPWARDS ARROW LEFTWARDS OF DOWNWARDS ARROW",NULL},
/* 21C6 */ { "LEFTWARDS ARROW OVER RIGHTWARDS ARROW",NULL},
/* 21C7 */ { "LEFTWARDS PAIRED ARROWS",NULL},
/* 21C8 */ { "UPWARDS PAIRED ARROWS",NULL},
/* 21C9 */ { "RIGHTWARDS PAIRED ARROWS",NULL},
/* 21CA */ { "DOWNWARDS PAIRED ARROWS",NULL},
/* 21CB */ { "LEFTWARDS HARPOON OVER RIGHTWARDS HARPOON",NULL},
/* 21CC */ { "RIGHTWARDS HARPOON OVER LEFTWARDS HARPOON","	x (long rightwards harpoon over long leftwards harpoon - 1F8D1)"},
/* 21CD */ { "LEFTWARDS DOUBLE ARROW WITH STROKE","	* negation of 21D0\n"
	"	: 21D0 0338"},
/* 21CE */ { "LEFT RIGHT DOUBLE ARROW WITH STROKE","	* negation of 21D4\n"
	"	: 21D4 0338"},
/* 21CF */ { "RIGHTWARDS DOUBLE ARROW WITH STROKE","	* negation of 21D2\n"
	"	: 21D2 0338"},
/* 21D0 */ { "LEFTWARDS DOUBLE ARROW",NULL},
/* 21D1 */ { "UPWARDS DOUBLE ARROW",NULL},
/* 21D2 */ { "RIGHTWARDS DOUBLE ARROW",NULL},
/* 21D3 */ { "DOWNWARDS DOUBLE ARROW",NULL},
/* 21D4 */ { "LEFT RIGHT DOUBLE ARROW",NULL},
/* 21D5 */ { "UP DOWN DOUBLE ARROW",NULL},
/* 21D6 */ { "NORTH WEST DOUBLE ARROW",NULL},
/* 21D7 */ { "NORTH EAST DOUBLE ARROW",NULL},
/* 21D8 */ { "SOUTH EAST DOUBLE ARROW",NULL},
/* 21D9 */ { "SOUTH WEST DOUBLE ARROW",NULL},
/* 21DA */ { "LEFTWARDS TRIPLE ARROW",NULL},
/* 21DB */ { "RIGHTWARDS TRIPLE ARROW",NULL},
/* 21DC */ { "LEFTWARDS SQUIGGLE ARROW","	x (long leftwards squiggle arrow - 2B33)"},
/* 21DD */ { "RIGHTWARDS SQUIGGLE ARROW",NULL},
/* 21DE */ { "UPWARDS ARROW WITH DOUBLE STROKE","	= page up"},
/* 21DF */ { "DOWNWARDS ARROW WITH DOUBLE STROKE","	= page down"},
/* 21E0 */ { "LEFTWARDS DASHED ARROW",NULL},
/* 21E1 */ { "UPWARDS DASHED ARROW",NULL},
/* 21E2 */ { "RIGHTWARDS DASHED ARROW",NULL},
/* 21E3 */ { "DOWNWARDS DASHED ARROW",NULL},
/* 21E4 */ { "LEFTWARDS ARROW TO BAR","	= leftward tab"},
/* 21E5 */ { "RIGHTWARDS ARROW TO BAR","	= rightward tab"},
/* 21E6 */ { "LEFTWARDS WHITE ARROW","	x (north east white arrow - 2B00)"},
/* 21E7 */ { "UPWARDS WHITE ARROW","	= shift\n"
	"	= level 2 select (ISO 9995-7)"},
/* 21E8 */ { "RIGHTWARDS WHITE ARROW","	= group select (ISO 9995-7)"},
/* 21E9 */ { "DOWNWARDS WHITE ARROW",NULL},
/* 21EA */ { "UPWARDS WHITE ARROW FROM BAR","	= caps lock"},
/* 21EB */ { "UPWARDS WHITE ARROW ON PEDESTAL","	= level 2 lock"},
/* 21EC */ { "UPWARDS WHITE ARROW ON PEDESTAL WITH HORIZONTAL BAR","	= capitals (caps) lock\n"
	"	x (upwards white arrow from bar with horizontal bar - 2BB8)"},
/* 21ED */ { "UPWARDS WHITE ARROW ON PEDESTAL WITH VERTICAL BAR","	= numeric lock"},
/* 21EE */ { "UPWARDS WHITE DOUBLE ARROW","	= level 3 select"},
/* 21EF */ { "UPWARDS WHITE DOUBLE ARROW ON PEDESTAL","	= level 3 lock"},
/* 21F0 */ { "RIGHTWARDS WHITE ARROW FROM WALL","	= group lock"},
/* 21F1 */ { "NORTH WEST ARROW TO CORNER","	= home"},
/* 21F2 */ { "SOUTH EAST ARROW TO CORNER","	= end"},
/* 21F3 */ { "UP DOWN WHITE ARROW","	= scrolling\n"
	"	x (left right white arrow - 2B04)"},
/* 21F4 */ { "RIGHT ARROW WITH SMALL CIRCLE","	x (left arrow with small circle - 2B30)"},
/* 21F5 */ { "DOWNWARDS ARROW LEFTWARDS OF UPWARDS ARROW",NULL},
/* 21F6 */ { "THREE RIGHTWARDS ARROWS","	x (three leftwards arrows - 2B31)"},
/* 21F7 */ { "LEFTWARDS ARROW WITH VERTICAL STROKE",NULL},
/* 21F8 */ { "RIGHTWARDS ARROW WITH VERTICAL STROKE","	= z notation partial function"},
/* 21F9 */ { "LEFT RIGHT ARROW WITH VERTICAL STROKE","	= z notation partial relation"},
/* 21FA */ { "LEFTWARDS ARROW WITH DOUBLE VERTICAL STROKE",NULL},
/* 21FB */ { "RIGHTWARDS ARROW WITH DOUBLE VERTICAL STROKE","	= z notation finite function"},
/* 21FC */ { "LEFT RIGHT ARROW WITH DOUBLE VERTICAL STROKE","	= z notation finite relation"},
/* 21FD */ { "LEFTWARDS OPEN-HEADED ARROW",NULL},
/* 21FE */ { "RIGHTWARDS OPEN-HEADED ARROW",NULL},
/* 21FF */ { "LEFT RIGHT OPEN-HEADED ARROW",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_00_22[] = {
/* 2200 */ { "FOR ALL","	= universal quantifier"},
/* 2201 */ { "COMPLEMENT","	x (latin letter stretched c - 0297)"},
/* 2202 */ { "PARTIAL DIFFERENTIAL",NULL},
/* 2203 */ { "THERE EXISTS","	= existential quantifier"},
/* 2204 */ { "THERE DOES NOT EXIST","	: 2203 0338"},
/* 2205 */ { "EMPTY SET","	= null set\n"
	"	* used in linguistics to indicate a null morpheme or phonological \"zero\"\n"
	"	x (latin capital letter o with stroke - 00D8)\n"
	"	x (diameter sign - 2300)\n"
	"	~ 2205 FE00 zero with long diagonal stroke overlay form"},
/* 2206 */ { "INCREMENT","	= Laplace operator\n"
	"	= forward difference\n"
	"	= symmetric difference (in set theory)\n"
	"	* other symbols may also be used for symmetric difference\n"
	"	x (greek capital letter delta - 0394)\n"
	"	x (white up-pointing triangle - 25B3)"},
/* 2207 */ { "NABLA","	= backward difference\n"
	"	= gradient, del\n"
	"	* used for Laplacian operator (written with superscript 2)\n"
	"	x (white down-pointing triangle - 25BD)"},
/* 2208 */ { "ELEMENT OF",NULL},
/* 2209 */ { "NOT AN ELEMENT OF","	: 2208 0338"},
/* 220A */ { "SMALL ELEMENT OF","	* originates in math pi fonts; not the straight epsilon\n"
	"	x (greek lunate epsilon symbol - 03F5)"},
/* 220B */ { "CONTAINS AS MEMBER","	= such that"},
/* 220C */ { "DOES NOT CONTAIN AS MEMBER","	: 220B 0338"},
/* 220D */ { "SMALL CONTAINS AS MEMBER","	x (greek reversed lunate epsilon symbol - 03F6)"},
/* 220E */ { "END OF PROOF","	= q.e.d.\n"
	"	x (triangular bullet - 2023)\n"
	"	x (black vertical rectangle - 25AE)"},
/* 220F */ { "N-ARY PRODUCT","	= product sign\n"
	"	x (greek capital letter pi - 03A0)"},
/* 2210 */ { "N-ARY COPRODUCT","	= coproduct sign"},
/* 2211 */ { "N-ARY SUMMATION","	= summation sign\n"
	"	x (greek capital letter sigma - 03A3)\n"
	"	x (double-struck n-ary summation - 2140)"},
/* 2212 */ { "MINUS SIGN","	x (hyphen-minus - 002D)\n"
	"	x (heavy minus sign - 2796)"},
/* 2213 */ { "MINUS-OR-PLUS SIGN","	x (plus-minus sign - 00B1)"},
/* 2214 */ { "DOT PLUS",NULL},
/* 2215 */ { "DIVISION SLASH","	* generic division operator\n"
	"	x (solidus - 002F)\n"
	"	x (fraction slash - 2044)\n"
	"	x (mathematical rising diagonal - 27CB)"},
/* 2216 */ { "SET MINUS","	x (reverse solidus - 005C)\n"
	"	x (mathematical falling diagonal - 27CD)\n"
	"	x (reverse solidus operator - 29F5)"},
/* 2217 */ { "ASTERISK OPERATOR","	* may be used to represent the telephony asterisk seen on keypads\n"
	"	x (asterisk - 002A)"},
/* 2218 */ { "RING OPERATOR","	= composite function\n"
	"	= APL jot\n"
	"	x (degree sign - 00B0)\n"
	"	x (devanagari abbreviation sign - 0970)\n"
	"	x (white bullet - 25E6)\n"
	"	x (avestan abbreviation mark - 10B39)"},
/* 2219 */ { "BULLET OPERATOR","	x (middle dot - 00B7)\n"
	"	x (bullet - 2022)\n"
	"	x (one dot leader - 2024)"},
/* 221A */ { "SQUARE ROOT","	= radical sign\n"
	"	x (check mark - 2713)"},
/* 221B */ { "CUBE ROOT","	x (arabic-indic cube root - 0606)"},
/* 221C */ { "FOURTH ROOT","	x (arabic-indic fourth root - 0607)"},
/* 221D */ { "PROPORTIONAL TO","	x (greek small letter alpha - 03B1)"},
/* 221E */ { "INFINITY",NULL},
/* 221F */ { "RIGHT ANGLE","	= with (in chess notation)\n"
	"	x (reversed right angle - 2BFE)"},
/* 2220 */ { "ANGLE","	* used in astrological contexts for aspect semisquare\n"
	"	x (acute angle - 299F)"},
/* 2221 */ { "MEASURED ANGLE",NULL},
/* 2222 */ { "SPHERICAL ANGLE","	= angle arc"},
/* 2223 */ { "DIVIDES","	= such that\n"
	"	= APL stile\n"
	"	x (vertical line - 007C)\n"
	"	x (latin letter dental click - 01C0)"},
/* 2224 */ { "DOES NOT DIVIDE","	: 2223 0338"},
/* 2225 */ { "PARALLEL TO","	x (latin letter lateral click - 01C1)\n"
	"	x (double vertical line - 2016)"},
/* 2226 */ { "NOT PARALLEL TO","	: 2225 0338"},
/* 2227 */ { "LOGICAL AND","	= wedge, conjunction\n"
	"	x (n-ary logical and - 22C0)\n"
	"	x (up arrowhead - 2303)\n"
	"	x (and with dot - 27D1)"},
/* 2228 */ { "LOGICAL OR","	= vee, disjunction\n"
	"	x (n-ary logical or - 22C1)\n"
	"	x (down arrowhead - 2304)\n"
	"	x (or with dot inside - 27C7)"},
/* 2229 */ { "INTERSECTION","	= cap, hat\n"
	"	x (n-ary intersection - 22C2)\n"
	"	~ 2229 FE00 with serifs"},
/* 222A */ { "UNION","	= cup\n"
	"	x (n-ary union - 22C3)\n"
	"	~ 222A FE00 with serifs"},
/* 222B */ { "INTEGRAL","	x (latin small letter esh - 0283)"},
/* 222C */ { "DOUBLE INTEGRAL","	# 222B 222B"},
/* 222D */ { "TRIPLE INTEGRAL","	x (quadruple integral operator - 2A0C)\n"
	"	# 222B 222B 222B"},
/* 222E */ { "CONTOUR INTEGRAL","	x (integral around a point operator - 2A15)"},
/* 222F */ { "SURFACE INTEGRAL","	# 222E 222E"},
/* 2230 */ { "VOLUME INTEGRAL","	# 222E 222E 222E"},
/* 2231 */ { "CLOCKWISE INTEGRAL",NULL},
/* 2232 */ { "CLOCKWISE CONTOUR INTEGRAL",NULL},
/* 2233 */ { "ANTICLOCKWISE CONTOUR INTEGRAL","	* clockwise or anticlockwise arrows do not reverse during layout mirroring"},
/* 2234 */ { "THEREFORE","	x (historic site - 26EC)"},
/* 2235 */ { "BECAUSE",NULL},
/* 2236 */ { "RATIO","	* preferred to 003A for denotation of division or scale in mathematical use\n"
	"	x (colon - 003A)"},
/* 2237 */ { "PROPORTION",NULL},
/* 2238 */ { "DOT MINUS","	= saturating subtraction\n"
	"	* sometimes claimed as notation for symmetric set difference, but 2206 is preferred"},
/* 2239 */ { "EXCESS",NULL},
/* 223A */ { "GEOMETRIC PROPORTION",NULL},
/* 223B */ { "HOMOTHETIC","	x (tilde operator with rising dots - 2A6B)"},
/* 223C */ { "TILDE OPERATOR","	= varies with (proportional to)\n"
	"	= difference between\n"
	"	= similar to\n"
	"	= not\n"
	"	= cycle\n"
	"	= APL tilde\n"
	"	x (tilde - 007E)\n"
	"	x (not sign - 00AC)\n"
	"	x (small tilde - 02DC)"},
/* 223D */ { "REVERSED TILDE","	= lazy S\n"
	"	* reversed tilde and lazy S are glyph variants"},
/* 223E */ { "INVERTED LAZY S","	= most positive"},
/* 223F */ { "SINE WAVE","	= alternating current"},
/* 2240 */ { "WREATH PRODUCT",NULL},
/* 2241 */ { "NOT TILDE","	: 223C 0338"},
/* 2242 */ { "MINUS TILDE",NULL},
/* 2243 */ { "ASYMPTOTICALLY EQUAL TO",NULL},
/* 2244 */ { "NOT ASYMPTOTICALLY EQUAL TO","	: 2243 0338"},
/* 2245 */ { "APPROXIMATELY EQUAL TO","	x (approximately equal or equal to - 2A70)"},
/* 2246 */ { "APPROXIMATELY BUT NOT ACTUALLY EQUAL TO",NULL},
/* 2247 */ { "NEITHER APPROXIMATELY NOR ACTUALLY EQUAL TO","	: 2245 0338"},
/* 2248 */ { "ALMOST EQUAL TO","	= asymptotic to"},
/* 2249 */ { "NOT ALMOST EQUAL TO","	: 2248 0338"},
/* 224A */ { "ALMOST EQUAL OR EQUAL TO",NULL},
/* 224B */ { "TRIPLE TILDE",NULL},
/* 224C */ { "ALL EQUAL TO","	* reversed tilde and lazy S are glyph variants"},
/* 224D */ { "EQUIVALENT TO",NULL},
/* 224E */ { "GEOMETRICALLY EQUIVALENT TO",NULL},
/* 224F */ { "DIFFERENCE BETWEEN",NULL},
/* 2250 */ { "APPROACHES THE LIMIT",NULL},
/* 2251 */ { "GEOMETRICALLY EQUAL TO",NULL},
/* 2252 */ { "APPROXIMATELY EQUAL TO OR THE IMAGE OF","	= nearly equals"},
/* 2253 */ { "IMAGE OF OR APPROXIMATELY EQUAL TO",NULL},
/* 2254 */ { "COLON EQUALS",NULL},
/* 2255 */ { "EQUALS COLON",NULL},
/* 2256 */ { "RING IN EQUAL TO",NULL},
/* 2257 */ { "RING EQUAL TO","	= approximately equal to"},
/* 2258 */ { "CORRESPONDS TO",NULL},
/* 2259 */ { "ESTIMATES","	= corresponds to"},
/* 225A */ { "EQUIANGULAR TO",NULL},
/* 225B */ { "STAR EQUALS",NULL},
/* 225C */ { "DELTA EQUAL TO","	= equiangular\n"
	"	= equal to by definition"},
/* 225D */ { "EQUAL TO BY DEFINITION",NULL},
/* 225E */ { "MEASURED BY",NULL},
/* 225F */ { "QUESTIONED EQUAL TO",NULL},
/* 2260 */ { "NOT EQUAL TO","	x (equals sign - 003D)\n"
	"	x (latin letter alveolar click - 01C2)\n"
	"	: 003D 0338"},
/* 2261 */ { "IDENTICAL TO",NULL},
/* 2262 */ { "NOT IDENTICAL TO","	: 2261 0338"},
/* 2263 */ { "STRICTLY EQUIVALENT TO",NULL},
/* 2264 */ { "LESS-THAN OR EQUAL TO","	x (less-than sign - 003C)"},
/* 2265 */ { "GREATER-THAN OR EQUAL TO","	x (greater-than sign - 003E)"},
/* 2266 */ { "LESS-THAN OVER EQUAL TO",NULL},
/* 2267 */ { "GREATER-THAN OVER EQUAL TO",NULL},
/* 2268 */ { "LESS-THAN BUT NOT EQUAL TO","	x (less-than and single-line not equal to - 2A87)\n"
	"	~ 2268 FE00 with vertical stroke"},
/* 2269 */ { "GREATER-THAN BUT NOT EQUAL TO","	x (greater-than and single-line not equal to - 2A88)\n"
	"	~ 2269 FE00 with vertical stroke"},
/* 226A */ { "MUCH LESS-THAN","	x (left-pointing double angle quotation mark - 00AB)"},
/* 226B */ { "MUCH GREATER-THAN","	x (right-pointing double angle quotation mark - 00BB)"},
/* 226C */ { "BETWEEN","	= plaintiff, quantic"},
/* 226D */ { "NOT EQUIVALENT TO","	: 224D 0338"},
/* 226E */ { "NOT LESS-THAN","	: 003C 0338"},
/* 226F */ { "NOT GREATER-THAN","	: 003E 0338"},
/* 2270 */ { "NEITHER LESS-THAN NOR EQUAL TO","	: 2264 0338"},
/* 2271 */ { "NEITHER GREATER-THAN NOR EQUAL TO","	: 2265 0338"},
/* 2272 */ { "LESS-THAN OR EQUIVALENT TO","	~ 2272 FE00 following the slant of the lower leg"},
/* 2273 */ { "GREATER-THAN OR EQUIVALENT TO","	~ 2273 FE00 following the slant of the lower leg"},
/* 2274 */ { "NEITHER LESS-THAN NOR EQUIVALENT TO","	: 2272 0338"},
/* 2275 */ { "NEITHER GREATER-THAN NOR EQUIVALENT TO","	: 2273 0338"},
/* 2276 */ { "LESS-THAN OR GREATER-THAN",NULL},
/* 2277 */ { "GREATER-THAN OR LESS-THAN",NULL},
/* 2278 */ { "NEITHER LESS-THAN NOR GREATER-THAN","	: 2276 0338"},
/* 2279 */ { "NEITHER GREATER-THAN NOR LESS-THAN","	: 2277 0338"},
/* 227A */ { "PRECEDES","	= lower rank than\n"
	"	x (precedes under relation - 22B0)"},
/* 227B */ { "SUCCEEDS","	= higher rank than\n"
	"	x (succeeds under relation - 22B1)"},
/* 227C */ { "PRECEDES OR EQUAL TO",NULL},
/* 227D */ { "SUCCEEDS OR EQUAL TO",NULL},
/* 227E */ { "PRECEDES OR EQUIVALENT TO",NULL},
/* 227F */ { "SUCCEEDS OR EQUIVALENT TO",NULL},
/* 2280 */ { "DOES NOT PRECEDE","	: 227A 0338"},
/* 2281 */ { "DOES NOT SUCCEED","	: 227B 0338"},
/* 2282 */ { "SUBSET OF","	= included in set\n"
	"	x (left sideways u bracket - 2E26)"},
/* 2283 */ { "SUPERSET OF","	= includes in set\n"
	"	x (right sideways u bracket - 2E27)"},
/* 2284 */ { "NOT A SUBSET OF","	: 2282 0338"},
/* 2285 */ { "NOT A SUPERSET OF","	: 2283 0338"},
/* 2286 */ { "SUBSET OF OR EQUAL TO",NULL},
/* 2287 */ { "SUPERSET OF OR EQUAL TO",NULL},
/* 2288 */ { "NEITHER A SUBSET OF NOR EQUAL TO","	: 2286 0338"},
/* 2289 */ { "NEITHER A SUPERSET OF NOR EQUAL TO","	: 2287 0338"},
/* 228A */ { "SUBSET OF WITH NOT EQUAL TO","	~ 228A FE00 with stroke through bottom members"},
/* 228B */ { "SUPERSET OF WITH NOT EQUAL TO","	~ 228B FE00 with stroke through bottom members"},
/* 228C */ { "MULTISET",NULL},
/* 228D */ { "MULTISET MULTIPLICATION","	x (n-ary union operator with dot - 2A03)\n"
	"	x (intersection with dot - 2A40)"},
/* 228E */ { "MULTISET UNION","	= z notation bag addition\n"
	"	x (n-ary union operator with plus - 2A04)"},
/* 228F */ { "SQUARE IMAGE OF",NULL},
/* 2290 */ { "SQUARE ORIGINAL OF",NULL},
/* 2291 */ { "SQUARE IMAGE OF OR EQUAL TO",NULL},
/* 2292 */ { "SQUARE ORIGINAL OF OR EQUAL TO",NULL},
/* 2293 */ { "SQUARE CAP","	x (n-ary square intersection operator - 2A05)\n"
	"	~ 2293 FE00 with serifs"},
/* 2294 */ { "SQUARE CUP","	x (n-ary square union operator - 2A06)\n"
	"	~ 2294 FE00 with serifs"},
/* 2295 */ { "CIRCLED PLUS","	= direct sum\n"
	"	= vector pointing into page\n"
	"	x (n-ary circled plus operator - 2A01)\n"
	"	x (alchemical symbol for verdigris - 1F728)\n"
	"	~ 2295 FE00 with white rim"},
/* 2296 */ { "CIRCLED MINUS","	= symmetric difference\n"
	"	x (circle with horizontal bar - 29B5)\n"
	"	x (alchemical symbol for salt - 1F714)"},
/* 2297 */ { "CIRCLED TIMES","	= tensor product\n"
	"	= vector pointing into page\n"
	"	x (circled crossing lanes - 26D2)\n"
	"	x (n-ary circled times operator - 2A02)\n"
	"	x (circled x - 2BBE)\n"
	"	x (lot of fortune - 1F774)\n"
	"	~ 2297 FE00 with white rim"},
/* 2298 */ { "CIRCLED DIVISION SLASH",NULL},
/* 2299 */ { "CIRCLED DOT OPERATOR","	= direct product\n"
	"	= vector pointing out of page\n"
	"	x (latin letter bilabial click - 0298)\n"
	"	x (sun - 2609)\n"
	"	x (n-ary circled dot operator - 2A00)"},
/* 229A */ { "CIRCLED RING OPERATOR","	x (apl functional symbol circle jot - 233E)\n"
	"	x (bullseye - 25CE)"},
/* 229B */ { "CIRCLED ASTERISK OPERATOR","	x (apl functional symbol circle star - 235F)"},
/* 229C */ { "CIRCLED EQUALS","	= NoDerivatives (symbol used for Creative Commons licenses)\n"
	"	x (circled cc - 1F16D)\n"
	"	~ 229C FE00 with equal sign touching the circle"},
/* 229D */ { "CIRCLED DASH",NULL},
/* 229E */ { "SQUARED PLUS",NULL},
/* 229F */ { "SQUARED MINUS",NULL},
/* 22A0 */ { "SQUARED TIMES","	x (ballot box with x - 2612)\n"
	"	x (squared saltire - 26DD)\n"
	"	x (alchemical symbol for month - 1F771)"},
/* 22A1 */ { "SQUARED DOT OPERATOR","	x (alchemical symbol for urine - 1F755)\n"
	"	x (right open squared dot - 1FBBC)"},
/* 22A2 */ { "RIGHT TACK","	= turnstile\n"
	"	= proves, implies, yields\n"
	"	= reducible"},
/* 22A3 */ { "LEFT TACK","	= reverse turnstile\n"
	"	= non-theorem, does not yield"},
/* 22A4 */ { "DOWN TACK","	= top\n"
	"	x (raised interpolation marker - 2E06)\n"
	"	x (alchemical symbol for crucible-4 - 1F768)"},
/* 22A5 */ { "UP TACK","	= base, bottom\n"
	"	x (perpendicular - 27C2)"},
/* 22A6 */ { "ASSERTION","	= reduces to"},
/* 22A7 */ { "MODELS",NULL},
/* 22A8 */ { "TRUE","	= statement is true, valid\n"
	"	= is a tautology\n"
	"	= satisfies\n"
	"	= results in"},
/* 22A9 */ { "FORCES",NULL},
/* 22AA */ { "TRIPLE VERTICAL BAR RIGHT TURNSTILE",NULL},
/* 22AB */ { "DOUBLE VERTICAL BAR DOUBLE RIGHT TURNSTILE",NULL},
/* 22AC */ { "DOES NOT PROVE","	: 22A2 0338"},
/* 22AD */ { "NOT TRUE","	: 22A8 0338"},
/* 22AE */ { "DOES NOT FORCE","	: 22A9 0338"},
/* 22AF */ { "NEGATED DOUBLE VERTICAL BAR DOUBLE RIGHT TURNSTILE","	: 22AB 0338"},
/* 22B0 */ { "PRECEDES UNDER RELATION","	x (precedes - 227A)"},
/* 22B1 */ { "SUCCEEDS UNDER RELATION","	x (succeeds - 227B)"},
/* 22B2 */ { "NORMAL SUBGROUP OF","	x (white left-pointing pointer - 25C5)"},
/* 22B3 */ { "CONTAINS AS NORMAL SUBGROUP","	x (white right-pointing pointer - 25BB)"},
/* 22B4 */ { "NORMAL SUBGROUP OF OR EQUAL TO",NULL},
/* 22B5 */ { "CONTAINS AS NORMAL SUBGROUP OR EQUAL TO",NULL},
/* 22B6 */ { "ORIGINAL OF",NULL},
/* 22B7 */ { "IMAGE OF",NULL},
/* 22B8 */ { "MULTIMAP",NULL},
/* 22B9 */ { "HERMITIAN CONJUGATE MATRIX",NULL},
/* 22BA */ { "INTERCALATE",NULL},
/* 22BB */ { "XOR","	x (semisextile - 26BA)"},
/* 22BC */ { "NAND","	x (projective - 2305)\n"
	"	x (quincunx - 26BB)"},
/* 22BD */ { "NOR",NULL},
/* 22BE */ { "RIGHT ANGLE WITH ARC",NULL},
/* 22BF */ { "RIGHT TRIANGLE",NULL},
/* 22C0 */ { "N-ARY LOGICAL AND","	* also used to denote the universal quantifier\n"
	"	x (logical and - 2227)"},
/* 22C1 */ { "N-ARY LOGICAL OR","	* also used to denote the existential quantifier\n"
	"	x (logical or - 2228)"},
/* 22C2 */ { "N-ARY INTERSECTION","	= z notation generalised intersection\n"
	"	x (intersection - 2229)"},
/* 22C3 */ { "N-ARY UNION","	= z notation generalised union\n"
	"	x (union - 222A)"},
/* 22C4 */ { "DIAMOND OPERATOR","	x (white diamond - 25C7)\n"
	"	x (black small diamond - 2B29)"},
/* 22C5 */ { "DOT OPERATOR","	* preferred to 00B7 for denotation of multiplication\n"
	"	x (middle dot - 00B7)"},
/* 22C6 */ { "STAR OPERATOR","	* APL\n"
	"	x (arabic five pointed star - 066D)\n"
	"	x (black star - 2605)\n"
	"	x (white medium star - 2B50)"},
/* 22C7 */ { "DIVISION TIMES","	* ambiguous sign conflating two operators\n"
	"	x (plus-minus sign - 00B1)\n"
	"	x (multiplication sign - 00D7)\n"
	"	x (division sign - 00F7)\n"
	"	x (multiplication x - 2715)"},
/* 22C8 */ { "BOWTIE","	x (ocr bow tie - 2445)"},
/* 22C9 */ { "LEFT NORMAL FACTOR SEMIDIRECT PRODUCT",NULL},
/* 22CA */ { "RIGHT NORMAL FACTOR SEMIDIRECT PRODUCT",NULL},
/* 22CB */ { "LEFT SEMIDIRECT PRODUCT",NULL},
/* 22CC */ { "RIGHT SEMIDIRECT PRODUCT","	x (caret insertion point - 2041)"},
/* 22CD */ { "REVERSED TILDE EQUALS",NULL},
/* 22CE */ { "CURLY LOGICAL OR",NULL},
/* 22CF */ { "CURLY LOGICAL AND",NULL},
/* 22D0 */ { "DOUBLE SUBSET",NULL},
/* 22D1 */ { "DOUBLE SUPERSET",NULL},
/* 22D2 */ { "DOUBLE INTERSECTION",NULL},
/* 22D3 */ { "DOUBLE UNION",NULL},
/* 22D4 */ { "PITCHFORK","	= proper intersection"},
/* 22D5 */ { "EQUAL AND PARALLEL TO","	x (viewdata square - 2317)"},
/* 22D6 */ { "LESS-THAN WITH DOT",NULL},
/* 22D7 */ { "GREATER-THAN WITH DOT",NULL},
/* 22D8 */ { "VERY MUCH LESS-THAN",NULL},
/* 22D9 */ { "VERY MUCH GREATER-THAN",NULL},
/* 22DA */ { "LESS-THAN EQUAL TO OR GREATER-THAN","	~ 22DA FE00 with slanted equal"},
/* 22DB */ { "GREATER-THAN EQUAL TO OR LESS-THAN","	~ 22DB FE00 with slanted equal"},
/* 22DC */ { "EQUAL TO OR LESS-THAN",NULL},
/* 22DD */ { "EQUAL TO OR GREATER-THAN",NULL},
/* 22DE */ { "EQUAL TO OR PRECEDES",NULL},
/* 22DF */ { "EQUAL TO OR SUCCEEDS",NULL},
/* 22E0 */ { "DOES NOT PRECEDE OR EQUAL","	: 227C 0338"},
/* 22E1 */ { "DOES NOT SUCCEED OR EQUAL","	: 227D 0338"},
/* 22E2 */ { "NOT SQUARE IMAGE OF OR EQUAL TO","	: 2291 0338"},
/* 22E3 */ { "NOT SQUARE ORIGINAL OF OR EQUAL TO","	: 2292 0338"},
/* 22E4 */ { "SQUARE IMAGE OF OR NOT EQUAL TO",NULL},
/* 22E5 */ { "SQUARE ORIGINAL OF OR NOT EQUAL TO",NULL},
/* 22E6 */ { "LESS-THAN BUT NOT EQUIVALENT TO",NULL},
/* 22E7 */ { "GREATER-THAN BUT NOT EQUIVALENT TO",NULL},
/* 22E8 */ { "PRECEDES BUT NOT EQUIVALENT TO",NULL},
/* 22E9 */ { "SUCCEEDS BUT NOT EQUIVALENT TO",NULL},
/* 22EA */ { "NOT NORMAL SUBGROUP OF","	: 22B2 0338"},
/* 22EB */ { "DOES NOT CONTAIN AS NORMAL SUBGROUP","	: 22B3 0338"},
/* 22EC */ { "NOT NORMAL SUBGROUP OF OR EQUAL TO","	: 22B4 0338"},
/* 22ED */ { "DOES NOT CONTAIN AS NORMAL SUBGROUP OR EQUAL","	: 22B5 0338"},
/* 22EE */ { "VERTICAL ELLIPSIS","	x (tricolon - 205D)\n"
	"	x (horizontal ellipsis - 2026)\n"
	"	x (presentation form for vertical horizontal ellipsis - FE19)"},
/* 22EF */ { "MIDLINE HORIZONTAL ELLIPSIS",NULL},
/* 22F0 */ { "UP RIGHT DIAGONAL ELLIPSIS",NULL},
/* 22F1 */ { "DOWN RIGHT DIAGONAL ELLIPSIS",NULL},
/* 22F2 */ { "ELEMENT OF WITH LONG HORIZONTAL STROKE",NULL},
/* 22F3 */ { "ELEMENT OF WITH VERTICAL BAR AT END OF HORIZONTAL STROKE",NULL},
/* 22F4 */ { "SMALL ELEMENT OF WITH VERTICAL BAR AT END OF HORIZONTAL STROKE",NULL},
/* 22F5 */ { "ELEMENT OF WITH DOT ABOVE",NULL},
/* 22F6 */ { "ELEMENT OF WITH OVERBAR",NULL},
/* 22F7 */ { "SMALL ELEMENT OF WITH OVERBAR",NULL},
/* 22F8 */ { "ELEMENT OF WITH UNDERBAR",NULL},
/* 22F9 */ { "ELEMENT OF WITH TWO HORIZONTAL STROKES",NULL},
/* 22FA */ { "CONTAINS WITH LONG HORIZONTAL STROKE",NULL},
/* 22FB */ { "CONTAINS WITH VERTICAL BAR AT END OF HORIZONTAL STROKE",NULL},
/* 22FC */ { "SMALL CONTAINS WITH VERTICAL BAR AT END OF HORIZONTAL STROKE",NULL},
/* 22FD */ { "CONTAINS WITH OVERBAR",NULL},
/* 22FE */ { "SMALL CONTAINS WITH OVERBAR",NULL},
/* 22FF */ { "Z NOTATION BAG MEMBERSHIP",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_00_23[] = {
/* 2300 */ { "DIAMETER SIGN","	x (latin small letter o with stroke - 00F8)\n"
	"	x (empty set - 2205)"},
/* 2301 */ { "ELECTRIC ARROW","	* from ISO 2047\n"
	"	* symbol for End of Transmission"},
/* 2302 */ { "HOUSE",NULL},
/* 2303 */ { "UP ARROWHEAD","	x (circumflex accent - 005E)\n"
	"	x (modifier letter up arrowhead - 02C4)\n"
	"	x (caret - 2038)\n"
	"	x (logical and - 2227)"},
/* 2304 */ { "DOWN ARROWHEAD","	x (modifier letter down arrowhead - 02C5)\n"
	"	x (logical or - 2228)\n"
	"	x (countersink - 2335)"},
/* 2305 */ { "PROJECTIVE","	x (nand - 22BC)"},
/* 2306 */ { "PERSPECTIVE",NULL},
/* 2307 */ { "WAVY LINE","	x (wiggly vertical line - 2E3E)\n"
	"	x (wavy dash - 3030)"},
/* 2308 */ { "LEFT CEILING","	= APL upstile\n"
	"	x (top left half bracket - 2E22)\n"
	"	x (left corner bracket - 300C)"},
/* 2309 */ { "RIGHT CEILING","	x (combining annuity symbol - 20E7)\n"
	"	x (top right half bracket - 2E23)"},
/* 230A */ { "LEFT FLOOR","	= APL downstile\n"
	"	x (bottom left half bracket - 2E24)"},
/* 230B */ { "RIGHT FLOOR","	x (right corner bracket - 300D)\n"
	"	x (bottom right half bracket - 2E25)"},
/* 230C */ { "BOTTOM RIGHT CROP","	* set of four \"crop\" corners, arranged facing outward"},
/* 230D */ { "BOTTOM LEFT CROP",NULL},
/* 230E */ { "TOP RIGHT CROP",NULL},
/* 230F */ { "TOP LEFT CROP",NULL},
/* 2310 */ { "REVERSED NOT SIGN","	= beginning of line\n"
	"	x (not sign - 00AC)"},
/* 2311 */ { "SQUARE LOZENGE","	= Kissen (pillow)\n"
	"	* used as a command delimiter in some very old computers\n"
	"	x (rotated white four pointed cusp - 2BCF)"},
/* 2312 */ { "ARC","	= position of any line\n"
	"	x (upper half circle - 25E0)"},
/* 2313 */ { "SEGMENT","	= position of a surface"},
/* 2314 */ { "SECTOR",NULL},
/* 2315 */ { "TELEPHONE RECORDER",NULL},
/* 2316 */ { "POSITION INDICATOR","	= true position\n"
	"	x (square position indicator - 2BD0)"},
/* 2317 */ { "VIEWDATA SQUARE","	x (equal and parallel to - 22D5)"},
/* 2318 */ { "PLACE OF INTEREST SIGN","	= command key (1.0)\n"
	"	= operating system key (ISO 9995-7)"},
/* 2319 */ { "TURNED NOT SIGN","	= line marker"},
/* 231A */ { "WATCH","	x (alarm clock - 23F0)\n"
	"	x (clock face one oclock - 1F550)"},
/* 231B */ { "HOURGLASS","	= alchemical symbol for hour"},
/* 231C */ { "TOP LEFT CORNER","	x (right angle substitution marker - 2E00)\n"
	"	x (top left half bracket - 2E22)"},
/* 231D */ { "TOP RIGHT CORNER",NULL},
/* 231E */ { "BOTTOM LEFT CORNER",NULL},
/* 231F */ { "BOTTOM RIGHT CORNER",NULL},
/* 2320 */ { "TOP HALF INTEGRAL","	x (integral extension - 23AE)"},
/* 2321 */ { "BOTTOM HALF INTEGRAL",NULL},
/* 2322 */ { "FROWN","	x (character tie - 2040)"},
/* 2323 */ { "SMILE","	x (undertie - 203F)"},
/* 2324 */ { "UP ARROWHEAD BETWEEN TWO HORIZONTAL BARS","	= enter key"},
/* 2325 */ { "OPTION KEY",NULL},
/* 2326 */ { "ERASE TO THE RIGHT","	= delete to the right key"},
/* 2327 */ { "X IN A RECTANGLE BOX","	= clear key\n"
	"	x (ballot box with x - 2612)"},
/* 2328 */ { "KEYBOARD","	x (keyboard and mouse - 1F5A6)\n"
	"	x (wired keyboard - 1F5AE)"},
/* 2329 */ { "LEFT-POINTING ANGLE BRACKET","	x (less-than sign - 003C)\n"
	"	x (single left-pointing angle quotation mark - 2039)\n"
	"	x (mathematical left angle bracket - 27E8)\n"
	"	: 3008 left angle bracket"},
/* 232A */ { "RIGHT-POINTING ANGLE BRACKET","	x (greater-than sign - 003E)\n"
	"	x (single right-pointing angle quotation mark - 203A)\n"
	"	x (mathematical right angle bracket - 27E9)\n"
	"	: 3009 right angle bracket"},
/* 232B */ { "ERASE TO THE LEFT","	= delete to the left key"},
/* 232C */ { "BENZENE RING",NULL},
/* 232D */ { "CYLINDRICITY",NULL},
/* 232E */ { "ALL AROUND-PROFILE",NULL},
/* 232F */ { "SYMMETRY",NULL},
/* 2330 */ { "TOTAL RUNOUT",NULL},
/* 2331 */ { "DIMENSION ORIGIN",NULL},
/* 2332 */ { "CONICAL TAPER",NULL},
/* 2333 */ { "SLOPE","	x (lower left triangle - 25FA)"},
/* 2334 */ { "COUNTERBORE","	x (open box - 2423)"},
/* 2335 */ { "COUNTERSINK","	x (down arrowhead - 2304)"},
/* 2336 */ { "APL FUNCTIONAL SYMBOL I-BEAM",NULL},
/* 2337 */ { "APL FUNCTIONAL SYMBOL SQUISH QUAD","	x (apl functional symbol quad - 2395)\n"
	"	x (white vertical rectangle - 25AF)\n"
	"	x (n-ary white vertical bar - 2AFF)"},
/* 2338 */ { "APL FUNCTIONAL SYMBOL QUAD EQUAL",NULL},
/* 2339 */ { "APL FUNCTIONAL SYMBOL QUAD DIVIDE",NULL},
/* 233A */ { "APL FUNCTIONAL SYMBOL QUAD DIAMOND","	x (white diamond in square - 26CB)"},
/* 233B */ { "APL FUNCTIONAL SYMBOL QUAD JOT","	x (squared small circle - 29C7)"},
/* 233C */ { "APL FUNCTIONAL SYMBOL QUAD CIRCLE",NULL},
/* 233D */ { "APL FUNCTIONAL SYMBOL CIRCLE STILE",NULL},
/* 233E */ { "APL FUNCTIONAL SYMBOL CIRCLE JOT","	x (circled ring operator - 229A)\n"
	"	x (circled white bullet - 29BE)"},
/* 233F */ { "APL FUNCTIONAL SYMBOL SLASH BAR","	x (roman as sign - 1019A)"},
/* 2340 */ { "APL FUNCTIONAL SYMBOL BACKSLASH BAR","	x (reverse solidus with horizontal stroke - 29F7)"},
/* 2341 */ { "APL FUNCTIONAL SYMBOL QUAD SLASH","	x (squared rising diagonal slash - 29C4)"},
/* 2342 */ { "APL FUNCTIONAL SYMBOL QUAD BACKSLASH","	x (squared falling diagonal slash - 29C5)"},
/* 2343 */ { "APL FUNCTIONAL SYMBOL QUAD LESS-THAN",NULL},
/* 2344 */ { "APL FUNCTIONAL SYMBOL QUAD GREATER-THAN",NULL},
/* 2345 */ { "APL FUNCTIONAL SYMBOL LEFTWARDS VANE",NULL},
/* 2346 */ { "APL FUNCTIONAL SYMBOL RIGHTWARDS VANE",NULL},
/* 2347 */ { "APL FUNCTIONAL SYMBOL QUAD LEFTWARDS ARROW",NULL},
/* 2348 */ { "APL FUNCTIONAL SYMBOL QUAD RIGHTWARDS ARROW",NULL},
/* 2349 */ { "APL FUNCTIONAL SYMBOL CIRCLE BACKSLASH","	x (reversed empty set - 29B0)"},
/* 234A */ { "APL FUNCTIONAL SYMBOL DOWN TACK UNDERBAR","	= up tack underbar\n"
	"	* preferred naming for APL tack symbols now follows the London Convention in ISO/IEC 13751:2000 (APL Extended)\n"
	"	x (up tack - 22A5)"},
/* 234B */ { "APL FUNCTIONAL SYMBOL DELTA STILE",NULL},
/* 234C */ { "APL FUNCTIONAL SYMBOL QUAD DOWN CARET",NULL},
/* 234D */ { "APL FUNCTIONAL SYMBOL QUAD DELTA",NULL},
/* 234E */ { "APL FUNCTIONAL SYMBOL DOWN TACK JOT","	= up tack jot\n"
	"	x (up tack - 22A5)"},
/* 234F */ { "APL FUNCTIONAL SYMBOL UPWARDS VANE",NULL},
/* 2350 */ { "APL FUNCTIONAL SYMBOL QUAD UPWARDS ARROW",NULL},
/* 2351 */ { "APL FUNCTIONAL SYMBOL UP TACK OVERBAR","	= down tack overbar\n"
	"	x (down tack - 22A4)\n"
	"	x (postal mark - 3012)"},
/* 2352 */ { "APL FUNCTIONAL SYMBOL DEL STILE",NULL},
/* 2353 */ { "APL FUNCTIONAL SYMBOL QUAD UP CARET","	x (up arrowhead in a rectangle box - 2BB9)"},
/* 2354 */ { "APL FUNCTIONAL SYMBOL QUAD DEL",NULL},
/* 2355 */ { "APL FUNCTIONAL SYMBOL UP TACK JOT","	= down tack jot\n"
	"	x (down tack - 22A4)"},
/* 2356 */ { "APL FUNCTIONAL SYMBOL DOWNWARDS VANE",NULL},
/* 2357 */ { "APL FUNCTIONAL SYMBOL QUAD DOWNWARDS ARROW",NULL},
/* 2358 */ { "APL FUNCTIONAL SYMBOL QUOTE UNDERBAR",NULL},
/* 2359 */ { "APL FUNCTIONAL SYMBOL DELTA UNDERBAR",NULL},
/* 235A */ { "APL FUNCTIONAL SYMBOL DIAMOND UNDERBAR",NULL},
/* 235B */ { "APL FUNCTIONAL SYMBOL JOT UNDERBAR",NULL},
/* 235C */ { "APL FUNCTIONAL SYMBOL CIRCLE UNDERBAR",NULL},
/* 235D */ { "APL FUNCTIONAL SYMBOL UP SHOE JOT","	x (intersection with dot - 2A40)"},
/* 235E */ { "APL FUNCTIONAL SYMBOL QUOTE QUAD",NULL},
/* 235F */ { "APL FUNCTIONAL SYMBOL CIRCLE STAR","	x (circled asterisk operator - 229B)"},
/* 2360 */ { "APL FUNCTIONAL SYMBOL QUAD COLON",NULL},
/* 2361 */ { "APL FUNCTIONAL SYMBOL UP TACK DIAERESIS","	= down tack diaeresis\n"
	"	x (down tack - 22A4)"},
/* 2362 */ { "APL FUNCTIONAL SYMBOL DEL DIAERESIS",NULL},
/* 2363 */ { "APL FUNCTIONAL SYMBOL STAR DIAERESIS",NULL},
/* 2364 */ { "APL FUNCTIONAL SYMBOL JOT DIAERESIS","	= hoot"},
/* 2365 */ { "APL FUNCTIONAL SYMBOL CIRCLE DIAERESIS","	= holler"},
/* 2366 */ { "APL FUNCTIONAL SYMBOL DOWN SHOE STILE",NULL},
/* 2367 */ { "APL FUNCTIONAL SYMBOL LEFT SHOE STILE",NULL},
/* 2368 */ { "APL FUNCTIONAL SYMBOL TILDE DIAERESIS","	= smirk"},
/* 2369 */ { "APL FUNCTIONAL SYMBOL GREATER-THAN DIAERESIS",NULL},
/* 236A */ { "APL FUNCTIONAL SYMBOL COMMA BAR",NULL},
/* 236B */ { "APL FUNCTIONAL SYMBOL DEL TILDE",NULL},
/* 236C */ { "APL FUNCTIONAL SYMBOL ZILDE",NULL},
/* 236D */ { "APL FUNCTIONAL SYMBOL STILE TILDE",NULL},
/* 236E */ { "APL FUNCTIONAL SYMBOL SEMICOLON UNDERBAR",NULL},
/* 236F */ { "APL FUNCTIONAL SYMBOL QUAD NOT EQUAL",NULL},
/* 2370 */ { "APL FUNCTIONAL SYMBOL QUAD QUESTION","	x (uncertainty sign - 2BD1)"},
/* 2371 */ { "APL FUNCTIONAL SYMBOL DOWN CARET TILDE",NULL},
/* 2372 */ { "APL FUNCTIONAL SYMBOL UP CARET TILDE",NULL},
/* 2373 */ { "APL FUNCTIONAL SYMBOL IOTA",NULL},
/* 2374 */ { "APL FUNCTIONAL SYMBOL RHO",NULL},
/* 2375 */ { "APL FUNCTIONAL SYMBOL OMEGA",NULL},
/* 2376 */ { "APL FUNCTIONAL SYMBOL ALPHA UNDERBAR",NULL},
/* 2377 */ { "APL FUNCTIONAL SYMBOL EPSILON UNDERBAR",NULL},
/* 2378 */ { "APL FUNCTIONAL SYMBOL IOTA UNDERBAR",NULL},
/* 2379 */ { "APL FUNCTIONAL SYMBOL OMEGA UNDERBAR",NULL},
/* 237A */ { "APL FUNCTIONAL SYMBOL ALPHA",NULL},
/* 237B */ { "NOT CHECK MARK","	* from ISO 2047\n"
	"	* symbol for Negative Acknowledge"},
/* 237C */ { "RIGHT ANGLE WITH DOWNWARDS ZIGZAG ARROW",NULL},
/* 237D */ { "SHOULDERED OPEN BOX","	* from ISO 9995-7\n"
	"	* keyboard symbol for No Break Space\n"
	"	x (open box - 2423)"},
/* 237E */ { "BELL SYMBOL","	* from ISO 2047\n"
	"	x (alarm bell symbol - 1FBFA)"},
/* 237F */ { "VERTICAL LINE WITH MIDDLE DOT","	* from ISO 2047\n"
	"	* symbol for End of Medium"},
/* 2380 */ { "INSERTION SYMBOL",NULL},
/* 2381 */ { "CONTINUOUS UNDERLINE SYMBOL",NULL},
/* 2382 */ { "DISCONTINUOUS UNDERLINE SYMBOL",NULL},
/* 2383 */ { "EMPHASIS SYMBOL",NULL},
/* 2384 */ { "COMPOSITION SYMBOL",NULL},
/* 2385 */ { "WHITE SQUARE WITH CENTRE VERTICAL LINE","	= center"},
/* 2386 */ { "ENTER SYMBOL",NULL},
/* 2387 */ { "ALTERNATIVE KEY SYMBOL",NULL},
/* 2388 */ { "HELM SYMBOL","	= control\n"
	"	x (wheel of dharma - 2638)"},
/* 2389 */ { "CIRCLED HORIZONTAL BAR WITH NOTCH","	= pause"},
/* 238A */ { "CIRCLED TRIANGLE DOWN","	= interrupt, break"},
/* 238B */ { "BROKEN CIRCLE WITH NORTHWEST ARROW","	= escape"},
/* 238C */ { "UNDO SYMBOL",NULL},
/* 238D */ { "MONOSTABLE SYMBOL",NULL},
/* 238E */ { "HYSTERESIS SYMBOL",NULL},
/* 238F */ { "OPEN-CIRCUIT-OUTPUT H-TYPE SYMBOL",NULL},
/* 2390 */ { "OPEN-CIRCUIT-OUTPUT L-TYPE SYMBOL",NULL},
/* 2391 */ { "PASSIVE-PULL-DOWN-OUTPUT SYMBOL",NULL},
/* 2392 */ { "PASSIVE-PULL-UP-OUTPUT SYMBOL",NULL},
/* 2393 */ { "DIRECT CURRENT SYMBOL FORM TWO",NULL},
/* 2394 */ { "SOFTWARE-FUNCTION SYMBOL","	x (white hexagon - 2B21)"},
/* 2395 */ { "APL FUNCTIONAL SYMBOL QUAD","	x (apl functional symbol squish quad - 2337)\n"
	"	x (white vertical rectangle - 25AF)"},
/* 2396 */ { "DECIMAL SEPARATOR KEY SYMBOL",NULL},
/* 2397 */ { "PREVIOUS PAGE","	x (back with leftwards arrow above - 1F519)"},
/* 2398 */ { "NEXT PAGE",NULL},
/* 2399 */ { "PRINT SCREEN SYMBOL",NULL},
/* 239A */ { "CLEAR SCREEN SYMBOL","	x (combining enclosing screen - 20E2)"},
/* 239B */ { "LEFT PARENTHESIS UPPER HOOK",NULL},
/* 239C */ { "LEFT PARENTHESIS EXTENSION",NULL},
/* 239D */ { "LEFT PARENTHESIS LOWER HOOK",NULL},
/* 239E */ { "RIGHT PARENTHESIS UPPER HOOK",NULL},
/* 239F */ { "RIGHT PARENTHESIS EXTENSION",NULL},
/* 23A0 */ { "RIGHT PARENTHESIS LOWER HOOK",NULL},
/* 23A1 */ { "LEFT SQUARE BRACKET UPPER CORNER",NULL},
/* 23A2 */ { "LEFT SQUARE BRACKET EXTENSION",NULL},
/* 23A3 */ { "LEFT SQUARE BRACKET LOWER CORNER",NULL},
/* 23A4 */ { "RIGHT SQUARE BRACKET UPPER CORNER",NULL},
/* 23A5 */ { "RIGHT SQUARE BRACKET EXTENSION",NULL},
/* 23A6 */ { "RIGHT SQUARE BRACKET LOWER CORNER",NULL},
/* 23A7 */ { "LEFT CURLY BRACKET UPPER HOOK",NULL},
/* 23A8 */ { "LEFT CURLY BRACKET MIDDLE PIECE",NULL},
/* 23A9 */ { "LEFT CURLY BRACKET LOWER HOOK",NULL},
/* 23AA */ { "CURLY BRACKET EXTENSION",NULL},
/* 23AB */ { "RIGHT CURLY BRACKET UPPER HOOK",NULL},
/* 23AC */ { "RIGHT CURLY BRACKET MIDDLE PIECE",NULL},
/* 23AD */ { "RIGHT CURLY BRACKET LOWER HOOK",NULL},
/* 23AE */ { "INTEGRAL EXTENSION","	x (top half integral - 2320)\n"
	"	x (bottom half integral - 2321)"},
/* 23AF */ { "HORIZONTAL LINE EXTENSION","	* used for extension of arrows\n"
	"	x (vertical line extension - 23D0)"},
/* 23B0 */ { "UPPER LEFT OR LOWER RIGHT CURLY BRACKET SECTION","	= left moustache"},
/* 23B1 */ { "UPPER RIGHT OR LOWER LEFT CURLY BRACKET SECTION","	= right moustache"},
/* 23B2 */ { "SUMMATION TOP",NULL},
/* 23B3 */ { "SUMMATION BOTTOM","	x (n-ary summation - 2211)"},
/* 23B4 */ { "TOP SQUARE BRACKET","	x (presentation form for vertical left square bracket - FE47)"},
/* 23B5 */ { "BOTTOM SQUARE BRACKET","	x (presentation form for vertical right square bracket - FE48)"},
/* 23B6 */ { "BOTTOM SQUARE BRACKET OVER TOP SQUARE BRACKET","	* only used for terminal emulation"},
/* 23B7 */ { "RADICAL SYMBOL BOTTOM",NULL},
/* 23B8 */ { "LEFT VERTICAL BOX LINE",NULL},
/* 23B9 */ { "RIGHT VERTICAL BOX LINE",NULL},
/* 23BA */ { "HORIZONTAL SCAN LINE-1",NULL},
/* 23BB */ { "HORIZONTAL SCAN LINE-3","	* scan line-5 is unified with the box-drawing graphic character 2500"},
/* 23BC */ { "HORIZONTAL SCAN LINE-7",NULL},
/* 23BD */ { "HORIZONTAL SCAN LINE-9",NULL},
/* 23BE */ { "DENTISTRY SYMBOL LIGHT VERTICAL AND TOP RIGHT","	x (left ceiling - 2308)"},
/* 23BF */ { "DENTISTRY SYMBOL LIGHT VERTICAL AND BOTTOM RIGHT","	x (left floor - 230A)"},
/* 23C0 */ { "DENTISTRY SYMBOL LIGHT VERTICAL WITH CIRCLE",NULL},
/* 23C1 */ { "DENTISTRY SYMBOL LIGHT DOWN AND HORIZONTAL WITH CIRCLE",NULL},
/* 23C2 */ { "DENTISTRY SYMBOL LIGHT UP AND HORIZONTAL WITH CIRCLE",NULL},
/* 23C3 */ { "DENTISTRY SYMBOL LIGHT VERTICAL WITH TRIANGLE",NULL},
/* 23C4 */ { "DENTISTRY SYMBOL LIGHT DOWN AND HORIZONTAL WITH TRIANGLE",NULL},
/* 23C5 */ { "DENTISTRY SYMBOL LIGHT UP AND HORIZONTAL WITH TRIANGLE",NULL},
/* 23C6 */ { "DENTISTRY SYMBOL LIGHT VERTICAL AND WAVE",NULL},
/* 23C7 */ { "DENTISTRY SYMBOL LIGHT DOWN AND HORIZONTAL WITH WAVE",NULL},
/* 23C8 */ { "DENTISTRY SYMBOL LIGHT UP AND HORIZONTAL WITH WAVE",NULL},
/* 23C9 */ { "DENTISTRY SYMBOL LIGHT DOWN AND HORIZONTAL","	x (down tack - 22A4)\n"
	"	x (box drawings light down and horizontal - 252C)"},
/* 23CA */ { "DENTISTRY SYMBOL LIGHT UP AND HORIZONTAL","	x (up tack - 22A5)\n"
	"	x (box drawings light up and horizontal - 2534)"},
/* 23CB */ { "DENTISTRY SYMBOL LIGHT VERTICAL AND TOP LEFT","	x (right ceiling - 2309)"},
/* 23CC */ { "DENTISTRY SYMBOL LIGHT VERTICAL AND BOTTOM LEFT","	x (right floor - 230B)"},
/* 23CD */ { "SQUARE FOOT",NULL},
/* 23CE */ { "RETURN SYMBOL","	* may be shown with either hollow or filled glyph\n"
	"	x (downwards arrow with corner leftwards - 21B5)\n"
	"	x (return left - 2B90)"},
/* 23CF */ { "EJECT SYMBOL","	* UI symbol to eject media"},
/* 23D0 */ { "VERTICAL LINE EXTENSION","	* used for extension of arrows\n"
	"	x (horizontal line extension - 23AF)"},
/* 23D1 */ { "METRICAL BREVE",NULL},
/* 23D2 */ { "METRICAL LONG OVER SHORT",NULL},
/* 23D3 */ { "METRICAL SHORT OVER LONG",NULL},
/* 23D4 */ { "METRICAL LONG OVER TWO SHORTS",NULL},
/* 23D5 */ { "METRICAL TWO SHORTS OVER LONG",NULL},
/* 23D6 */ { "METRICAL TWO SHORTS JOINED",NULL},
/* 23D7 */ { "METRICAL TRISEME","	x (combining greek musical triseme - 1D242)"},
/* 23D8 */ { "METRICAL TETRASEME","	x (combining greek musical tetraseme - 1D243)"},
/* 23D9 */ { "METRICAL PENTASEME","	x (combining greek musical pentaseme - 1D244)"},
/* 23DA */ { "EARTH GROUND",NULL},
/* 23DB */ { "FUSE",NULL},
/* 23DC */ { "TOP PARENTHESIS","	x (presentation form for vertical left parenthesis - FE35)"},
/* 23DD */ { "BOTTOM PARENTHESIS","	x (presentation form for vertical right parenthesis - FE36)"},
/* 23DE */ { "TOP CURLY BRACKET","	x (presentation form for vertical left curly bracket - FE37)"},
/* 23DF */ { "BOTTOM CURLY BRACKET","	x (presentation form for vertical right curly bracket - FE38)"},
/* 23E0 */ { "TOP TORTOISE SHELL BRACKET","	x (presentation form for vertical left tortoise shell bracket - FE39)"},
/* 23E1 */ { "BOTTOM TORTOISE SHELL BRACKET","	x (presentation form for vertical right tortoise shell bracket - FE3A)"},
/* 23E2 */ { "WHITE TRAPEZIUM",NULL},
/* 23E3 */ { "BENZENE RING WITH CIRCLE",NULL},
/* 23E4 */ { "STRAIGHTNESS",NULL},
/* 23E5 */ { "FLATNESS",NULL},
/* 23E6 */ { "AC CURRENT",NULL},
/* 23E7 */ { "ELECTRICAL INTERSECTION",NULL},
/* 23E8 */ { "DECIMAL EXPONENT SYMBOL","	* Algol-60 token for scientific notation literals"},
/* 23E9 */ { "BLACK RIGHT-POINTING DOUBLE TRIANGLE","	= fast forward"},
/* 23EA */ { "BLACK LEFT-POINTING DOUBLE TRIANGLE","	= rewind, fast backwards"},
/* 23EB */ { "BLACK UP-POINTING DOUBLE TRIANGLE",NULL},
/* 23EC */ { "BLACK DOWN-POINTING DOUBLE TRIANGLE",NULL},
/* 23ED */ { "BLACK RIGHT-POINTING DOUBLE TRIANGLE WITH VERTICAL BAR","	= skip to the end or next file/track/chapter"},
/* 23EE */ { "BLACK LEFT-POINTING DOUBLE TRIANGLE WITH VERTICAL BAR","	= skip to the start or previous file/track/chapter"},
/* 23EF */ { "BLACK RIGHT-POINTING TRIANGLE WITH DOUBLE VERTICAL BAR","	= play/pause toggle"},
/* 23F0 */ { "ALARM CLOCK","	x (watch - 231A)\n"
	"	x (clock face one oclock - 1F550)\n"
	"	x (mantelpiece clock - 1F570)"},
/* 23F1 */ { "STOPWATCH",NULL},
/* 23F2 */ { "TIMER CLOCK",NULL},
/* 23F3 */ { "HOURGLASS WITH FLOWING SAND","	x (hourglass - 231B)"},
/* 23F4 */ { "BLACK MEDIUM LEFT-POINTING TRIANGLE","	= reverse, back\n"
	"	* preferred to 25C0 black left-pointing triangle\n"
	"	x (black medium left-pointing triangle centred - 2BC7)\n"
	"	x (black left-pointing isosceles right triangle - 1F780)"},
/* 23F5 */ { "BLACK MEDIUM RIGHT-POINTING TRIANGLE","	= forward\n"
	"	* preferred to 25B6 black right-pointing triangle\n"
	"	x (black medium right-pointing triangle centred - 2BC8)\n"
	"	x (black right-pointing isosceles right triangle - 1F782)"},
/* 23F6 */ { "BLACK MEDIUM UP-POINTING TRIANGLE","	= increase\n"
	"	* preferred to 25B2 black up-pointing triangle\n"
	"	x (black medium up-pointing triangle centred - 2BC5)\n"
	"	x (black up-pointing isosceles right triangle - 1F781)"},
/* 23F7 */ { "BLACK MEDIUM DOWN-POINTING TRIANGLE","	= decrease\n"
	"	* preferred to 25BC black down-pointing triangle\n"
	"	x (black medium down-pointing triangle centred - 2BC6)\n"
	"	x (black down-pointing isosceles right triangle - 1F783)"},
/* 23F8 */ { "DOUBLE VERTICAL BAR","	= pause\n"
	"	x (double vertical line - 2016)"},
/* 23F9 */ { "BLACK SQUARE FOR STOP","	= stop\n"
	"	x (black medium square - 25FC)"},
/* 23FA */ { "BLACK CIRCLE FOR RECORD","	= record\n"
	"	x (medium black circle - 26AB)\n"
	"	x (large red circle - 1F534)"},
/* 23FB */ { "POWER SYMBOL","	* IEC 5009 standby symbol\n"
	"	* IEEE 1621 power symbol"},
/* 23FC */ { "POWER ON-OFF SYMBOL","	* IEC 5010 power on-off symbol"},
/* 23FD */ { "POWER ON SYMBOL","	* use 2B58 for power off symbol\n"
	"	x (heavy circle - 2B58)"},
/* 23FE */ { "POWER SLEEP SYMBOL","	x (last quarter moon - 263E)"},
/* 23FF */ { "OBSERVER EYE SYMBOL",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_00_24[] = {
/* 2400 */ { "SYMBOL FOR NULL",NULL},
/* 2401 */ { "SYMBOL FOR START OF HEADING",NULL},
/* 2402 */ { "SYMBOL FOR START OF TEXT",NULL},
/* 2403 */ { "SYMBOL FOR END OF TEXT",NULL},
/* 2404 */ { "SYMBOL FOR END OF TRANSMISSION",NULL},
/* 2405 */ { "SYMBOL FOR ENQUIRY",NULL},
/* 2406 */ { "SYMBOL FOR ACKNOWLEDGE",NULL},
/* 2407 */ { "SYMBOL FOR BELL",NULL},
/* 2408 */ { "SYMBOL FOR BACKSPACE",NULL},
/* 2409 */ { "SYMBOL FOR HORIZONTAL TABULATION",NULL},
/* 240A */ { "SYMBOL FOR LINE FEED",NULL},
/* 240B */ { "SYMBOL FOR VERTICAL TABULATION",NULL},
/* 240C */ { "SYMBOL FOR FORM FEED",NULL},
/* 240D */ { "SYMBOL FOR CARRIAGE RETURN",NULL},
/* 240E */ { "SYMBOL FOR SHIFT OUT",NULL},
/* 240F */ { "SYMBOL FOR SHIFT IN",NULL},
/* 2410 */ { "SYMBOL FOR DATA LINK ESCAPE",NULL},
/* 2411 */ { "SYMBOL FOR DEVICE CONTROL ONE",NULL},
/* 2412 */ { "SYMBOL FOR DEVICE CONTROL TWO",NULL},
/* 2413 */ { "SYMBOL FOR DEVICE CONTROL THREE",NULL},
/* 2414 */ { "SYMBOL FOR DEVICE CONTROL FOUR",NULL},
/* 2415 */ { "SYMBOL FOR NEGATIVE ACKNOWLEDGE",NULL},
/* 2416 */ { "SYMBOL FOR SYNCHRONOUS IDLE",NULL},
/* 2417 */ { "SYMBOL FOR END OF TRANSMISSION BLOCK",NULL},
/* 2418 */ { "SYMBOL FOR CANCEL",NULL},
/* 2419 */ { "SYMBOL FOR END OF MEDIUM",NULL},
/* 241A */ { "SYMBOL FOR SUBSTITUTE",NULL},
/* 241B */ { "SYMBOL FOR ESCAPE",NULL},
/* 241C */ { "SYMBOL FOR FILE SEPARATOR",NULL},
/* 241D */ { "SYMBOL FOR GROUP SEPARATOR",NULL},
/* 241E */ { "SYMBOL FOR RECORD SEPARATOR",NULL},
/* 241F */ { "SYMBOL FOR UNIT SEPARATOR",NULL},
/* 2420 */ { "SYMBOL FOR SPACE",NULL},
/* 2421 */ { "SYMBOL FOR DELETE",NULL},
/* 2422 */ { "BLANK SYMBOL","	* graphic for space\n"
	"	x (latin small letter b with stroke - 0180)"},
/* 2423 */ { "OPEN BOX","	* graphic for space\n"
	"	x (counterbore - 2334)"},
/* 2424 */ { "SYMBOL FOR NEWLINE",NULL},
/* 2425 */ { "SYMBOL FOR DELETE FORM TWO","	* from ISO 9995-7\n"
	"	* keyboard symbol for undoable delete"},
/* 2426 */ { "SYMBOL FOR SUBSTITUTE FORM TWO","	* from ISO 2047\n"
	"	x (arabic question mark - 061F)"},
/* 2427 */ { "SYMBOL FOR DELETE SQUARE CHECKER BOARD FORM",NULL},
/* 2428 */ { "SYMBOL FOR DELETE RECTANGULAR CHECKER BOARD FORM",NULL},
/* 2429 */ { "SYMBOL FOR DELETE MEDIUM SHADE FORM",NULL},
/* 242A */ { NULL,NULL},
/* 242B */ { NULL,NULL},
/* 242C */ { NULL,NULL},
/* 242D */ { NULL,NULL},
/* 242E */ { NULL,NULL},
/* 242F */ { NULL,NULL},
/* 2430 */ { NULL,NULL},
/* 2431 */ { NULL,NULL},
/* 2432 */ { NULL,NULL},
/* 2433 */ { NULL,NULL},
/* 2434 */ { NULL,NULL},
/* 2435 */ { NULL,NULL},
/* 2436 */ { NULL,NULL},
/* 2437 */ { NULL,NULL},
/* 2438 */ { NULL,NULL},
/* 2439 */ { NULL,NULL},
/* 243A */ { NULL,NULL},
/* 243B */ { NULL,NULL},
/* 243C */ { NULL,NULL},
/* 243D */ { NULL,NULL},
/* 243E */ { NULL,NULL},
/* 243F */ { NULL,NULL},
/* 2440 */ { "OCR HOOK",NULL},
/* 2441 */ { "OCR CHAIR",NULL},
/* 2442 */ { "OCR FORK",NULL},
/* 2443 */ { "OCR INVERTED FORK",NULL},
/* 2444 */ { "OCR BELT BUCKLE",NULL},
/* 2445 */ { "OCR BOW TIE","	= unique asterisk\n"
	"	x (bowtie - 22C8)"},
/* 2446 */ { "OCR BRANCH BANK IDENTIFICATION","	= transit"},
/* 2447 */ { "OCR AMOUNT OF CHECK","	= amount"},
/* 2448 */ { "OCR DASH","	% MICR ON US SYMBOL\n"
	"	= on us"},
/* 2449 */ { "OCR CUSTOMER ACCOUNT NUMBER","	% MICR DASH SYMBOL\n"
	"	= dash"},
/* 244A */ { "OCR DOUBLE BACKSLASH",NULL},
/* 244B */ { NULL,NULL},
/* 244C */ { NULL,NULL},
/* 244D */ { NULL,NULL},
/* 244E */ { NULL,NULL},
/* 244F */ { NULL,NULL},
/* 2450 */ { NULL,NULL},
/* 2451 */ { NULL,NULL},
/* 2452 */ { NULL,NULL},
/* 2453 */ { NULL,NULL},
/* 2454 */ { NULL,NULL},
/* 2455 */ { NULL,NULL},
/* 2456 */ { NULL,NULL},
/* 2457 */ { NULL,NULL},
/* 2458 */ { NULL,NULL},
/* 2459 */ { NULL,NULL},
/* 245A */ { NULL,NULL},
/* 245B */ { NULL,NULL},
/* 245C */ { NULL,NULL},
/* 245D */ { NULL,NULL},
/* 245E */ { NULL,NULL},
/* 245F */ { NULL,NULL},
/* 2460 */ { "CIRCLED DIGIT ONE","	# <circle> 0031"},
/* 2461 */ { "CIRCLED DIGIT TWO","	# <circle> 0032"},
/* 2462 */ { "CIRCLED DIGIT THREE","	# <circle> 0033"},
/* 2463 */ { "CIRCLED DIGIT FOUR","	# <circle> 0034"},
/* 2464 */ { "CIRCLED DIGIT FIVE","	# <circle> 0035"},
/* 2465 */ { "CIRCLED DIGIT SIX","	# <circle> 0036"},
/* 2466 */ { "CIRCLED DIGIT SEVEN","	# <circle> 0037"},
/* 2467 */ { "CIRCLED DIGIT EIGHT","	# <circle> 0038"},
/* 2468 */ { "CIRCLED DIGIT NINE","	# <circle> 0039"},
/* 2469 */ { "CIRCLED NUMBER TEN","	# <circle> 0031 0030"},
/* 246A */ { "CIRCLED NUMBER ELEVEN","	# <circle> 0031 0031"},
/* 246B */ { "CIRCLED NUMBER TWELVE","	# <circle> 0031 0032"},
/* 246C */ { "CIRCLED NUMBER THIRTEEN","	# <circle> 0031 0033"},
/* 246D */ { "CIRCLED NUMBER FOURTEEN","	# <circle> 0031 0034"},
/* 246E */ { "CIRCLED NUMBER FIFTEEN","	# <circle> 0031 0035"},
/* 246F */ { "CIRCLED NUMBER SIXTEEN","	# <circle> 0031 0036"},
/* 2470 */ { "CIRCLED NUMBER SEVENTEEN","	# <circle> 0031 0037"},
/* 2471 */ { "CIRCLED NUMBER EIGHTEEN","	# <circle> 0031 0038"},
/* 2472 */ { "CIRCLED NUMBER NINETEEN","	# <circle> 0031 0039"},
/* 2473 */ { "CIRCLED NUMBER TWENTY","	# <circle> 0032 0030"},
/* 2474 */ { "PARENTHESIZED DIGIT ONE","	# 0028 0031 0029"},
/* 2475 */ { "PARENTHESIZED DIGIT TWO","	# 0028 0032 0029"},
/* 2476 */ { "PARENTHESIZED DIGIT THREE","	# 0028 0033 0029"},
/* 2477 */ { "PARENTHESIZED DIGIT FOUR","	# 0028 0034 0029"},
/* 2478 */ { "PARENTHESIZED DIGIT FIVE","	# 0028 0035 0029"},
/* 2479 */ { "PARENTHESIZED DIGIT SIX","	# 0028 0036 0029"},
/* 247A */ { "PARENTHESIZED DIGIT SEVEN","	# 0028 0037 0029"},
/* 247B */ { "PARENTHESIZED DIGIT EIGHT","	# 0028 0038 0029"},
/* 247C */ { "PARENTHESIZED DIGIT NINE","	# 0028 0039 0029"},
/* 247D */ { "PARENTHESIZED NUMBER TEN","	# 0028 0031 0030 0029"},
/* 247E */ { "PARENTHESIZED NUMBER ELEVEN","	# 0028 0031 0031 0029"},
/* 247F */ { "PARENTHESIZED NUMBER TWELVE","	# 0028 0031 0032 0029"},
/* 2480 */ { "PARENTHESIZED NUMBER THIRTEEN","	# 0028 0031 0033 0029"},
/* 2481 */ { "PARENTHESIZED NUMBER FOURTEEN","	# 0028 0031 0034 0029"},
/* 2482 */ { "PARENTHESIZED NUMBER FIFTEEN","	# 0028 0031 0035 0029"},
/* 2483 */ { "PARENTHESIZED NUMBER SIXTEEN","	# 0028 0031 0036 0029"},
/* 2484 */ { "PARENTHESIZED NUMBER SEVENTEEN","	# 0028 0031 0037 0029"},
/* 2485 */ { "PARENTHESIZED NUMBER EIGHTEEN","	# 0028 0031 0038 0029"},
/* 2486 */ { "PARENTHESIZED NUMBER NINETEEN","	# 0028 0031 0039 0029"},
/* 2487 */ { "PARENTHESIZED NUMBER TWENTY","	# 0028 0032 0030 0029"},
/* 2488 */ { "DIGIT ONE FULL STOP","	# 0031 002E"},
/* 2489 */ { "DIGIT TWO FULL STOP","	# 0032 002E"},
/* 248A */ { "DIGIT THREE FULL STOP","	# 0033 002E"},
/* 248B */ { "DIGIT FOUR FULL STOP","	# 0034 002E"},
/* 248C */ { "DIGIT FIVE FULL STOP","	# 0035 002E"},
/* 248D */ { "DIGIT SIX FULL STOP","	# 0036 002E"},
/* 248E */ { "DIGIT SEVEN FULL STOP","	# 0037 002E"},
/* 248F */ { "DIGIT EIGHT FULL STOP","	# 0038 002E"},
/* 2490 */ { "DIGIT NINE FULL STOP","	# 0039 002E"},
/* 2491 */ { "NUMBER TEN FULL STOP","	# 0031 0030 002E"},
/* 2492 */ { "NUMBER ELEVEN FULL STOP","	# 0031 0031 002E"},
/* 2493 */ { "NUMBER TWELVE FULL STOP","	# 0031 0032 002E"},
/* 2494 */ { "NUMBER THIRTEEN FULL STOP","	# 0031 0033 002E"},
/* 2495 */ { "NUMBER FOURTEEN FULL STOP","	# 0031 0034 002E"},
/* 2496 */ { "NUMBER FIFTEEN FULL STOP","	# 0031 0035 002E"},
/* 2497 */ { "NUMBER SIXTEEN FULL STOP","	# 0031 0036 002E"},
/* 2498 */ { "NUMBER SEVENTEEN FULL STOP","	# 0031 0037 002E"},
/* 2499 */ { "NUMBER EIGHTEEN FULL STOP","	# 0031 0038 002E"},
/* 249A */ { "NUMBER NINETEEN FULL STOP","	# 0031 0039 002E"},
/* 249B */ { "NUMBER TWENTY FULL STOP","	# 0032 0030 002E"},
/* 249C */ { "PARENTHESIZED LATIN SMALL LETTER A","	# 0028 0061 0029"},
/* 249D */ { "PARENTHESIZED LATIN SMALL LETTER B","	# 0028 0062 0029"},
/* 249E */ { "PARENTHESIZED LATIN SMALL LETTER C","	# 0028 0063 0029"},
/* 249F */ { "PARENTHESIZED LATIN SMALL LETTER D","	# 0028 0064 0029"},
/* 24A0 */ { "PARENTHESIZED LATIN SMALL LETTER E","	# 0028 0065 0029"},
/* 24A1 */ { "PARENTHESIZED LATIN SMALL LETTER F","	# 0028 0066 0029"},
/* 24A2 */ { "PARENTHESIZED LATIN SMALL LETTER G","	# 0028 0067 0029"},
/* 24A3 */ { "PARENTHESIZED LATIN SMALL LETTER H","	# 0028 0068 0029"},
/* 24A4 */ { "PARENTHESIZED LATIN SMALL LETTER I","	# 0028 0069 0029"},
/* 24A5 */ { "PARENTHESIZED LATIN SMALL LETTER J","	# 0028 006A 0029"},
/* 24A6 */ { "PARENTHESIZED LATIN SMALL LETTER K","	# 0028 006B 0029"},
/* 24A7 */ { "PARENTHESIZED LATIN SMALL LETTER L","	# 0028 006C 0029"},
/* 24A8 */ { "PARENTHESIZED LATIN SMALL LETTER M","	# 0028 006D 0029"},
/* 24A9 */ { "PARENTHESIZED LATIN SMALL LETTER N","	# 0028 006E 0029"},
/* 24AA */ { "PARENTHESIZED LATIN SMALL LETTER O","	# 0028 006F 0029"},
/* 24AB */ { "PARENTHESIZED LATIN SMALL LETTER P","	# 0028 0070 0029"},
/* 24AC */ { "PARENTHESIZED LATIN SMALL LETTER Q","	# 0028 0071 0029"},
/* 24AD */ { "PARENTHESIZED LATIN SMALL LETTER R","	# 0028 0072 0029"},
/* 24AE */ { "PARENTHESIZED LATIN SMALL LETTER S","	# 0028 0073 0029"},
/* 24AF */ { "PARENTHESIZED LATIN SMALL LETTER T","	# 0028 0074 0029"},
/* 24B0 */ { "PARENTHESIZED LATIN SMALL LETTER U","	# 0028 0075 0029"},
/* 24B1 */ { "PARENTHESIZED LATIN SMALL LETTER V","	# 0028 0076 0029"},
/* 24B2 */ { "PARENTHESIZED LATIN SMALL LETTER W","	# 0028 0077 0029"},
/* 24B3 */ { "PARENTHESIZED LATIN SMALL LETTER X","	# 0028 0078 0029"},
/* 24B4 */ { "PARENTHESIZED LATIN SMALL LETTER Y","	# 0028 0079 0029"},
/* 24B5 */ { "PARENTHESIZED LATIN SMALL LETTER Z","	# 0028 007A 0029"},
/* 24B6 */ { "CIRCLED LATIN CAPITAL LETTER A","	# <circle> 0041"},
/* 24B7 */ { "CIRCLED LATIN CAPITAL LETTER B","	# <circle> 0042"},
/* 24B8 */ { "CIRCLED LATIN CAPITAL LETTER C","	x (copyright sign - 00A9)\n"
	"	# <circle> 0043"},
/* 24B9 */ { "CIRCLED LATIN CAPITAL LETTER D","	# <circle> 0044"},
/* 24BA */ { "CIRCLED LATIN CAPITAL LETTER E","	# <circle> 0045"},
/* 24BB */ { "CIRCLED LATIN CAPITAL LETTER F","	# <circle> 0046"},
/* 24BC */ { "CIRCLED LATIN CAPITAL LETTER G","	# <circle> 0047"},
/* 24BD */ { "CIRCLED LATIN CAPITAL LETTER H","	# <circle> 0048"},
/* 24BE */ { "CIRCLED LATIN CAPITAL LETTER I","	# <circle> 0049"},
/* 24BF */ { "CIRCLED LATIN CAPITAL LETTER J","	# <circle> 004A"},
/* 24C0 */ { "CIRCLED LATIN CAPITAL LETTER K","	# <circle> 004B"},
/* 24C1 */ { "CIRCLED LATIN CAPITAL LETTER L","	# <circle> 004C"},
/* 24C2 */ { "CIRCLED LATIN CAPITAL LETTER M","	x (mask work symbol - 1F1AD)\n"
	"	# <circle> 004D"},
/* 24C3 */ { "CIRCLED LATIN CAPITAL LETTER N","	# <circle> 004E"},
/* 24C4 */ { "CIRCLED LATIN CAPITAL LETTER O","	# <circle> 004F"},
/* 24C5 */ { "CIRCLED LATIN CAPITAL LETTER P","	x (sound recording copyright - 2117)\n"
	"	# <circle> 0050"},
/* 24C6 */ { "CIRCLED LATIN CAPITAL LETTER Q","	# <circle> 0051"},
/* 24C7 */ { "CIRCLED LATIN CAPITAL LETTER R","	x (registered sign - 00AE)\n"
	"	# <circle> 0052"},
/* 24C8 */ { "CIRCLED LATIN CAPITAL LETTER S","	# <circle> 0053"},
/* 24C9 */ { "CIRCLED LATIN CAPITAL LETTER T","	# <circle> 0054"},
/* 24CA */ { "CIRCLED LATIN CAPITAL LETTER U","	# <circle> 0055"},
/* 24CB */ { "CIRCLED LATIN CAPITAL LETTER V","	# <circle> 0056"},
/* 24CC */ { "CIRCLED LATIN CAPITAL LETTER W","	# <circle> 0057"},
/* 24CD */ { "CIRCLED LATIN CAPITAL LETTER X","	# <circle> 0058"},
/* 24CE */ { "CIRCLED LATIN CAPITAL LETTER Y","	# <circle> 0059"},
/* 24CF */ { "CIRCLED LATIN CAPITAL LETTER Z","	# <circle> 005A"},
/* 24D0 */ { "CIRCLED LATIN SMALL LETTER A","	# <circle> 0061"},
/* 24D1 */ { "CIRCLED LATIN SMALL LETTER B","	# <circle> 0062"},
/* 24D2 */ { "CIRCLED LATIN SMALL LETTER C","	# <circle> 0063"},
/* 24D3 */ { "CIRCLED LATIN SMALL LETTER D","	# <circle> 0064"},
/* 24D4 */ { "CIRCLED LATIN SMALL LETTER E","	# <circle> 0065"},
/* 24D5 */ { "CIRCLED LATIN SMALL LETTER F","	# <circle> 0066"},
/* 24D6 */ { "CIRCLED LATIN SMALL LETTER G","	# <circle> 0067"},
/* 24D7 */ { "CIRCLED LATIN SMALL LETTER H","	# <circle> 0068"},
/* 24D8 */ { "CIRCLED LATIN SMALL LETTER I","	# <circle> 0069"},
/* 24D9 */ { "CIRCLED LATIN SMALL LETTER J","	# <circle> 006A"},
/* 24DA */ { "CIRCLED LATIN SMALL LETTER K","	# <circle> 006B"},
/* 24DB */ { "CIRCLED LATIN SMALL LETTER L","	# <circle> 006C"},
/* 24DC */ { "CIRCLED LATIN SMALL LETTER M","	# <circle> 006D"},
/* 24DD */ { "CIRCLED LATIN SMALL LETTER N","	# <circle> 006E"},
/* 24DE */ { "CIRCLED LATIN SMALL LETTER O","	# <circle> 006F"},
/* 24DF */ { "CIRCLED LATIN SMALL LETTER P","	# <circle> 0070"},
/* 24E0 */ { "CIRCLED LATIN SMALL LETTER Q","	# <circle> 0071"},
/* 24E1 */ { "CIRCLED LATIN SMALL LETTER R","	# <circle> 0072"},
/* 24E2 */ { "CIRCLED LATIN SMALL LETTER S","	# <circle> 0073"},
/* 24E3 */ { "CIRCLED LATIN SMALL LETTER T","	# <circle> 0074"},
/* 24E4 */ { "CIRCLED LATIN SMALL LETTER U","	# <circle> 0075"},
/* 24E5 */ { "CIRCLED LATIN SMALL LETTER V","	# <circle> 0076"},
/* 24E6 */ { "CIRCLED LATIN SMALL LETTER W","	# <circle> 0077"},
/* 24E7 */ { "CIRCLED LATIN SMALL LETTER X","	# <circle> 0078"},
/* 24E8 */ { "CIRCLED LATIN SMALL LETTER Y","	# <circle> 0079"},
/* 24E9 */ { "CIRCLED LATIN SMALL LETTER Z","	# <circle> 007A"},
/* 24EA */ { "CIRCLED DIGIT ZERO","	# <circle> 0030"},
/* 24EB */ { "NEGATIVE CIRCLED NUMBER ELEVEN",NULL},
/* 24EC */ { "NEGATIVE CIRCLED NUMBER TWELVE",NULL},
/* 24ED */ { "NEGATIVE CIRCLED NUMBER THIRTEEN",NULL},
/* 24EE */ { "NEGATIVE CIRCLED NUMBER FOURTEEN",NULL},
/* 24EF */ { "NEGATIVE CIRCLED NUMBER FIFTEEN",NULL},
/* 24F0 */ { "NEGATIVE CIRCLED NUMBER SIXTEEN",NULL},
/* 24F1 */ { "NEGATIVE CIRCLED NUMBER SEVENTEEN",NULL},
/* 24F2 */ { "NEGATIVE CIRCLED NUMBER EIGHTEEN",NULL},
/* 24F3 */ { "NEGATIVE CIRCLED NUMBER NINETEEN",NULL},
/* 24F4 */ { "NEGATIVE CIRCLED NUMBER TWENTY",NULL},
/* 24F5 */ { "DOUBLE CIRCLED DIGIT ONE",NULL},
/* 24F6 */ { "DOUBLE CIRCLED DIGIT TWO",NULL},
/* 24F7 */ { "DOUBLE CIRCLED DIGIT THREE",NULL},
/* 24F8 */ { "DOUBLE CIRCLED DIGIT FOUR",NULL},
/* 24F9 */ { "DOUBLE CIRCLED DIGIT FIVE",NULL},
/* 24FA */ { "DOUBLE CIRCLED DIGIT SIX",NULL},
/* 24FB */ { "DOUBLE CIRCLED DIGIT SEVEN",NULL},
/* 24FC */ { "DOUBLE CIRCLED DIGIT EIGHT",NULL},
/* 24FD */ { "DOUBLE CIRCLED DIGIT NINE",NULL},
/* 24FE */ { "DOUBLE CIRCLED NUMBER TEN",NULL},
/* 24FF */ { "NEGATIVE CIRCLED DIGIT ZERO","	x (dingbat negative circled digit one - 2776)"}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_00_25[] = {
/* 2500 */ { "BOX DRAWINGS LIGHT HORIZONTAL","	= Videotex Mosaic DG 15\n"
	"	x (box drawings light horizontal with vertical stroke - 1FBAF)"},
/* 2501 */ { "BOX DRAWINGS HEAVY HORIZONTAL",NULL},
/* 2502 */ { "BOX DRAWINGS LIGHT VERTICAL","	= Videotex Mosaic DG 14"},
/* 2503 */ { "BOX DRAWINGS HEAVY VERTICAL",NULL},
/* 2504 */ { "BOX DRAWINGS LIGHT TRIPLE DASH HORIZONTAL",NULL},
/* 2505 */ { "BOX DRAWINGS HEAVY TRIPLE DASH HORIZONTAL",NULL},
/* 2506 */ { "BOX DRAWINGS LIGHT TRIPLE DASH VERTICAL",NULL},
/* 2507 */ { "BOX DRAWINGS HEAVY TRIPLE DASH VERTICAL",NULL},
/* 2508 */ { "BOX DRAWINGS LIGHT QUADRUPLE DASH HORIZONTAL",NULL},
/* 2509 */ { "BOX DRAWINGS HEAVY QUADRUPLE DASH HORIZONTAL",NULL},
/* 250A */ { "BOX DRAWINGS LIGHT QUADRUPLE DASH VERTICAL",NULL},
/* 250B */ { "BOX DRAWINGS HEAVY QUADRUPLE DASH VERTICAL",NULL},
/* 250C */ { "BOX DRAWINGS LIGHT DOWN AND RIGHT","	= Videotex Mosaic DG 16"},
/* 250D */ { "BOX DRAWINGS DOWN LIGHT AND RIGHT HEAVY",NULL},
/* 250E */ { "BOX DRAWINGS DOWN HEAVY AND RIGHT LIGHT",NULL},
/* 250F */ { "BOX DRAWINGS HEAVY DOWN AND RIGHT",NULL},
/* 2510 */ { "BOX DRAWINGS LIGHT DOWN AND LEFT","	= Videotex Mosaic DG 17"},
/* 2511 */ { "BOX DRAWINGS DOWN LIGHT AND LEFT HEAVY",NULL},
/* 2512 */ { "BOX DRAWINGS DOWN HEAVY AND LEFT LIGHT",NULL},
/* 2513 */ { "BOX DRAWINGS HEAVY DOWN AND LEFT",NULL},
/* 2514 */ { "BOX DRAWINGS LIGHT UP AND RIGHT","	= Videotex Mosaic DG 18"},
/* 2515 */ { "BOX DRAWINGS UP LIGHT AND RIGHT HEAVY",NULL},
/* 2516 */ { "BOX DRAWINGS UP HEAVY AND RIGHT LIGHT",NULL},
/* 2517 */ { "BOX DRAWINGS HEAVY UP AND RIGHT",NULL},
/* 2518 */ { "BOX DRAWINGS LIGHT UP AND LEFT","	= Videotex Mosaic DG 19"},
/* 2519 */ { "BOX DRAWINGS UP LIGHT AND LEFT HEAVY",NULL},
/* 251A */ { "BOX DRAWINGS UP HEAVY AND LEFT LIGHT",NULL},
/* 251B */ { "BOX DRAWINGS HEAVY UP AND LEFT",NULL},
/* 251C */ { "BOX DRAWINGS LIGHT VERTICAL AND RIGHT","	= Videotex Mosaic DG 20"},
/* 251D */ { "BOX DRAWINGS VERTICAL LIGHT AND RIGHT HEAVY","	= Videotex Mosaic DG 03"},
/* 251E */ { "BOX DRAWINGS UP HEAVY AND RIGHT DOWN LIGHT",NULL},
/* 251F */ { "BOX DRAWINGS DOWN HEAVY AND RIGHT UP LIGHT",NULL},
/* 2520 */ { "BOX DRAWINGS VERTICAL HEAVY AND RIGHT LIGHT",NULL},
/* 2521 */ { "BOX DRAWINGS DOWN LIGHT AND RIGHT UP HEAVY",NULL},
/* 2522 */ { "BOX DRAWINGS UP LIGHT AND RIGHT DOWN HEAVY",NULL},
/* 2523 */ { "BOX DRAWINGS HEAVY VERTICAL AND RIGHT",NULL},
/* 2524 */ { "BOX DRAWINGS LIGHT VERTICAL AND LEFT","	= Videotex Mosaic DG 21"},
/* 2525 */ { "BOX DRAWINGS VERTICAL LIGHT AND LEFT HEAVY","	= Videotex Mosaic DG 04"},
/* 2526 */ { "BOX DRAWINGS UP HEAVY AND LEFT DOWN LIGHT",NULL},
/* 2527 */ { "BOX DRAWINGS DOWN HEAVY AND LEFT UP LIGHT",NULL},
/* 2528 */ { "BOX DRAWINGS VERTICAL HEAVY AND LEFT LIGHT",NULL},
/* 2529 */ { "BOX DRAWINGS DOWN LIGHT AND LEFT UP HEAVY",NULL},
/* 252A */ { "BOX DRAWINGS UP LIGHT AND LEFT DOWN HEAVY",NULL},
/* 252B */ { "BOX DRAWINGS HEAVY VERTICAL AND LEFT",NULL},
/* 252C */ { "BOX DRAWINGS LIGHT DOWN AND HORIZONTAL","	= Videotex Mosaic DG 22"},
/* 252D */ { "BOX DRAWINGS LEFT HEAVY AND RIGHT DOWN LIGHT",NULL},
/* 252E */ { "BOX DRAWINGS RIGHT HEAVY AND LEFT DOWN LIGHT",NULL},
/* 252F */ { "BOX DRAWINGS DOWN LIGHT AND HORIZONTAL HEAVY","	= Videotex Mosaic DG 02"},
/* 2530 */ { "BOX DRAWINGS DOWN HEAVY AND HORIZONTAL LIGHT",NULL},
/* 2531 */ { "BOX DRAWINGS RIGHT LIGHT AND LEFT DOWN HEAVY",NULL},
/* 2532 */ { "BOX DRAWINGS LEFT LIGHT AND RIGHT DOWN HEAVY",NULL},
/* 2533 */ { "BOX DRAWINGS HEAVY DOWN AND HORIZONTAL",NULL},
/* 2534 */ { "BOX DRAWINGS LIGHT UP AND HORIZONTAL","	= Videotex Mosaic DG 23"},
/* 2535 */ { "BOX DRAWINGS LEFT HEAVY AND RIGHT UP LIGHT",NULL},
/* 2536 */ { "BOX DRAWINGS RIGHT HEAVY AND LEFT UP LIGHT",NULL},
/* 2537 */ { "BOX DRAWINGS UP LIGHT AND HORIZONTAL HEAVY","	= Videotex Mosaic DG 01"},
/* 2538 */ { "BOX DRAWINGS UP HEAVY AND HORIZONTAL LIGHT",NULL},
/* 2539 */ { "BOX DRAWINGS RIGHT LIGHT AND LEFT UP HEAVY",NULL},
/* 253A */ { "BOX DRAWINGS LEFT LIGHT AND RIGHT UP HEAVY",NULL},
/* 253B */ { "BOX DRAWINGS HEAVY UP AND HORIZONTAL",NULL},
/* 253C */ { "BOX DRAWINGS LIGHT VERTICAL AND HORIZONTAL","	= Videotex Mosaic DG 24"},
/* 253D */ { "BOX DRAWINGS LEFT HEAVY AND RIGHT VERTICAL LIGHT",NULL},
/* 253E */ { "BOX DRAWINGS RIGHT HEAVY AND LEFT VERTICAL LIGHT",NULL},
/* 253F */ { "BOX DRAWINGS VERTICAL LIGHT AND HORIZONTAL HEAVY","	= Videotex Mosaic DG 13"},
/* 2540 */ { "BOX DRAWINGS UP HEAVY AND DOWN HORIZONTAL LIGHT",NULL},
/* 2541 */ { "BOX DRAWINGS DOWN HEAVY AND UP HORIZONTAL LIGHT",NULL},
/* 2542 */ { "BOX DRAWINGS VERTICAL HEAVY AND HORIZONTAL LIGHT",NULL},
/* 2543 */ { "BOX DRAWINGS LEFT UP HEAVY AND RIGHT DOWN LIGHT",NULL},
/* 2544 */ { "BOX DRAWINGS RIGHT UP HEAVY AND LEFT DOWN LIGHT",NULL},
/* 2545 */ { "BOX DRAWINGS LEFT DOWN HEAVY AND RIGHT UP LIGHT",NULL},
/* 2546 */ { "BOX DRAWINGS RIGHT DOWN HEAVY AND LEFT UP LIGHT",NULL},
/* 2547 */ { "BOX DRAWINGS DOWN LIGHT AND UP HORIZONTAL HEAVY",NULL},
/* 2548 */ { "BOX DRAWINGS UP LIGHT AND DOWN HORIZONTAL HEAVY",NULL},
/* 2549 */ { "BOX DRAWINGS RIGHT LIGHT AND LEFT VERTICAL HEAVY",NULL},
/* 254A */ { "BOX DRAWINGS LEFT LIGHT AND RIGHT VERTICAL HEAVY",NULL},
/* 254B */ { "BOX DRAWINGS HEAVY VERTICAL AND HORIZONTAL",NULL},
/* 254C */ { "BOX DRAWINGS LIGHT DOUBLE DASH HORIZONTAL",NULL},
/* 254D */ { "BOX DRAWINGS HEAVY DOUBLE DASH HORIZONTAL",NULL},
/* 254E */ { "BOX DRAWINGS LIGHT DOUBLE DASH VERTICAL",NULL},
/* 254F */ { "BOX DRAWINGS HEAVY DOUBLE DASH VERTICAL",NULL},
/* 2550 */ { "BOX DRAWINGS DOUBLE HORIZONTAL",NULL},
/* 2551 */ { "BOX DRAWINGS DOUBLE VERTICAL",NULL},
/* 2552 */ { "BOX DRAWINGS DOWN SINGLE AND RIGHT DOUBLE",NULL},
/* 2553 */ { "BOX DRAWINGS DOWN DOUBLE AND RIGHT SINGLE",NULL},
/* 2554 */ { "BOX DRAWINGS DOUBLE DOWN AND RIGHT",NULL},
/* 2555 */ { "BOX DRAWINGS DOWN SINGLE AND LEFT DOUBLE",NULL},
/* 2556 */ { "BOX DRAWINGS DOWN DOUBLE AND LEFT SINGLE",NULL},
/* 2557 */ { "BOX DRAWINGS DOUBLE DOWN AND LEFT",NULL},
/* 2558 */ { "BOX DRAWINGS UP SINGLE AND RIGHT DOUBLE",NULL},
/* 2559 */ { "BOX DRAWINGS UP DOUBLE AND RIGHT SINGLE",NULL},
/* 255A */ { "BOX DRAWINGS DOUBLE UP AND RIGHT",NULL},
/* 255B */ { "BOX DRAWINGS UP SINGLE AND LEFT DOUBLE",NULL},
/* 255C */ { "BOX DRAWINGS UP DOUBLE AND LEFT SINGLE",NULL},
/* 255D */ { "BOX DRAWINGS DOUBLE UP AND LEFT",NULL},
/* 255E */ { "BOX DRAWINGS VERTICAL SINGLE AND RIGHT DOUBLE",NULL},
/* 255F */ { "BOX DRAWINGS VERTICAL DOUBLE AND RIGHT SINGLE",NULL},
/* 2560 */ { "BOX DRAWINGS DOUBLE VERTICAL AND RIGHT",NULL},
/* 2561 */ { "BOX DRAWINGS VERTICAL SINGLE AND LEFT DOUBLE",NULL},
/* 2562 */ { "BOX DRAWINGS VERTICAL DOUBLE AND LEFT SINGLE",NULL},
/* 2563 */ { "BOX DRAWINGS DOUBLE VERTICAL AND LEFT",NULL},
/* 2564 */ { "BOX DRAWINGS DOWN SINGLE AND HORIZONTAL DOUBLE",NULL},
/* 2565 */ { "BOX DRAWINGS DOWN DOUBLE AND HORIZONTAL SINGLE",NULL},
/* 2566 */ { "BOX DRAWINGS DOUBLE DOWN AND HORIZONTAL",NULL},
/* 2567 */ { "BOX DRAWINGS UP SINGLE AND HORIZONTAL DOUBLE",NULL},
/* 2568 */ { "BOX DRAWINGS UP DOUBLE AND HORIZONTAL SINGLE",NULL},
/* 2569 */ { "BOX DRAWINGS DOUBLE UP AND HORIZONTAL",NULL},
/* 256A */ { "BOX DRAWINGS VERTICAL SINGLE AND HORIZONTAL DOUBLE",NULL},
/* 256B */ { "BOX DRAWINGS VERTICAL DOUBLE AND HORIZONTAL SINGLE",NULL},
/* 256C */ { "BOX DRAWINGS DOUBLE VERTICAL AND HORIZONTAL",NULL},
/* 256D */ { "BOX DRAWINGS LIGHT ARC DOWN AND RIGHT",NULL},
/* 256E */ { "BOX DRAWINGS LIGHT ARC DOWN AND LEFT",NULL},
/* 256F */ { "BOX DRAWINGS LIGHT ARC UP AND LEFT",NULL},
/* 2570 */ { "BOX DRAWINGS LIGHT ARC UP AND RIGHT",NULL},
/* 2571 */ { "BOX DRAWINGS LIGHT DIAGONAL UPPER RIGHT TO LOWER LEFT","	* not intended for mathematical symbol \\diagup\n"
	"	x (solidus - 002F)\n"
	"	x (fraction slash - 2044)\n"
	"	x (division slash - 2215)"},
/* 2572 */ { "BOX DRAWINGS LIGHT DIAGONAL UPPER LEFT TO LOWER RIGHT","	* not intended for mathematical symbol \\diagdown\n"
	"	x (reverse solidus - 005C)\n"
	"	x (set minus - 2216)\n"
	"	x (reverse solidus operator - 29F5)"},
/* 2573 */ { "BOX DRAWINGS LIGHT DIAGONAL CROSS","	x (saltire - 2613)\n"
	"	x (multiplication x - 2715)"},
/* 2574 */ { "BOX DRAWINGS LIGHT LEFT",NULL},
/* 2575 */ { "BOX DRAWINGS LIGHT UP",NULL},
/* 2576 */ { "BOX DRAWINGS LIGHT RIGHT",NULL},
/* 2577 */ { "BOX DRAWINGS LIGHT DOWN",NULL},
/* 2578 */ { "BOX DRAWINGS HEAVY LEFT",NULL},
/* 2579 */ { "BOX DRAWINGS HEAVY UP",NULL},
/* 257A */ { "BOX DRAWINGS HEAVY RIGHT",NULL},
/* 257B */ { "BOX DRAWINGS HEAVY DOWN",NULL},
/* 257C */ { "BOX DRAWINGS LIGHT LEFT AND HEAVY RIGHT",NULL},
/* 257D */ { "BOX DRAWINGS LIGHT UP AND HEAVY DOWN",NULL},
/* 257E */ { "BOX DRAWINGS HEAVY LEFT AND LIGHT RIGHT",NULL},
/* 257F */ { "BOX DRAWINGS HEAVY UP AND LIGHT DOWN",NULL},
/* 2580 */ { "UPPER HALF BLOCK",NULL},
/* 2581 */ { "LOWER ONE EIGHTH BLOCK",NULL},
/* 2582 */ { "LOWER ONE QUARTER BLOCK",NULL},
/* 2583 */ { "LOWER THREE EIGHTHS BLOCK",NULL},
/* 2584 */ { "LOWER HALF BLOCK",NULL},
/* 2585 */ { "LOWER FIVE EIGHTHS BLOCK",NULL},
/* 2586 */ { "LOWER THREE QUARTERS BLOCK",NULL},
/* 2587 */ { "LOWER SEVEN EIGHTHS BLOCK",NULL},
/* 2588 */ { "FULL BLOCK","	= solid\n"
	"	x (black square - 25A0)"},
/* 2589 */ { "LEFT SEVEN EIGHTHS BLOCK",NULL},
/* 258A */ { "LEFT THREE QUARTERS BLOCK",NULL},
/* 258B */ { "LEFT FIVE EIGHTHS BLOCK",NULL},
/* 258C */ { "LEFT HALF BLOCK",NULL},
/* 258D */ { "LEFT THREE EIGHTHS BLOCK",NULL},
/* 258E */ { "LEFT ONE QUARTER BLOCK",NULL},
/* 258F */ { "LEFT ONE EIGHTH BLOCK",NULL},
/* 2590 */ { "RIGHT HALF BLOCK",NULL},
/* 2591 */ { "LIGHT SHADE","	* 25%"},
/* 2592 */ { "MEDIUM SHADE","	= speckles fill, dotted fill\n"
	"	* 50%\n"
	"	* used in mapping to cp949\n"
	"	x (inverse medium shade - 1FB90)"},
/* 2593 */ { "DARK SHADE","	* 75%"},
/* 2594 */ { "UPPER ONE EIGHTH BLOCK",NULL},
/* 2595 */ { "RIGHT ONE EIGHTH BLOCK",NULL},
/* 2596 */ { "QUADRANT LOWER LEFT",NULL},
/* 2597 */ { "QUADRANT LOWER RIGHT",NULL},
/* 2598 */ { "QUADRANT UPPER LEFT",NULL},
/* 2599 */ { "QUADRANT UPPER LEFT AND LOWER LEFT AND LOWER RIGHT",NULL},
/* 259A */ { "QUADRANT UPPER LEFT AND LOWER RIGHT","	x (reverse checker board - 1F67F)\n"
	"	x (checker board fill - 1FB95)"},
/* 259B */ { "QUADRANT UPPER LEFT AND UPPER RIGHT AND LOWER LEFT",NULL},
/* 259C */ { "QUADRANT UPPER LEFT AND UPPER RIGHT AND LOWER RIGHT",NULL},
/* 259D */ { "QUADRANT UPPER RIGHT",NULL},
/* 259E */ { "QUADRANT UPPER RIGHT AND LOWER LEFT","	x (checker board - 1F67E)\n"
	"	x (inverse checker board fill - 1FB96)"},
/* 259F */ { "QUADRANT UPPER RIGHT AND LOWER LEFT AND LOWER RIGHT",NULL},
/* 25A0 */ { "BLACK SQUARE","	= moding mark (in ideographic text)\n"
	"	x (full block - 2588)\n"
	"	x (black large square - 2B1B)"},
/* 25A1 */ { "WHITE SQUARE","	= quadrature\n"
	"	= alchemical symbol for salt\n"
	"	* used in astrological contexts for aspect square\n"
	"	* may be used to represent a missing ideograph\n"
	"	x (combining enclosing square - 20DE)\n"
	"	x (white medium square - 25FB)\n"
	"	x (ballot box - 2610)\n"
	"	x (white large square - 2B1C)\n"
	"	x (geta mark - 3013)"},
/* 25A2 */ { "WHITE SQUARE WITH ROUNDED CORNERS",NULL},
/* 25A3 */ { "WHITE SQUARE CONTAINING BLACK SMALL SQUARE",NULL},
/* 25A4 */ { "SQUARE WITH HORIZONTAL FILL",NULL},
/* 25A5 */ { "SQUARE WITH VERTICAL FILL",NULL},
/* 25A6 */ { "SQUARE WITH ORTHOGONAL CROSSHATCH FILL",NULL},
/* 25A7 */ { "SQUARE WITH UPPER LEFT TO LOWER RIGHT FILL","	x (upper left to lower right fill - 1FB98)"},
/* 25A8 */ { "SQUARE WITH UPPER RIGHT TO LOWER LEFT FILL","	x (upper right to lower left fill - 1FB99)"},
/* 25A9 */ { "SQUARE WITH DIAGONAL CROSSHATCH FILL",NULL},
/* 25AA */ { "BLACK SMALL SQUARE","	= square bullet\n"
	"	x (black very small square - 2B1D)"},
/* 25AB */ { "WHITE SMALL SQUARE","	x (white very small square - 2B1E)"},
/* 25AC */ { "BLACK RECTANGLE",NULL},
/* 25AD */ { "WHITE RECTANGLE",NULL},
/* 25AE */ { "BLACK VERTICAL RECTANGLE","	= histogram marker\n"
	"	x (end of proof - 220E)"},
/* 25AF */ { "WHITE VERTICAL RECTANGLE","	x (apl functional symbol squish quad - 2337)\n"
	"	x (apl functional symbol quad - 2395)"},
/* 25B0 */ { "BLACK PARALLELOGRAM",NULL},
/* 25B1 */ { "WHITE PARALLELOGRAM",NULL},
/* 25B2 */ { "BLACK UP-POINTING TRIANGLE","	x (black medium up-pointing triangle - 23F6)\n"
	"	x (black medium up-pointing triangle centred - 2BC5)\n"
	"	x (up-pointing red triangle - 1F53A)"},
/* 25B3 */ { "WHITE UP-POINTING TRIANGLE","	= trine\n"
	"	x (combining enclosing upward pointing triangle - 20E4)\n"
	"	x (increment - 2206)\n"
	"	x (triangle with rounded corners - 1F6C6)\n"
	"	x (alchemical symbol for fire - 1F702)"},
/* 25B4 */ { "BLACK UP-POINTING SMALL TRIANGLE","	x (up-pointing small red triangle - 1F53C)"},
/* 25B5 */ { "WHITE UP-POINTING SMALL TRIANGLE",NULL},
/* 25B6 */ { "BLACK RIGHT-POINTING TRIANGLE","	x (black medium right-pointing triangle - 23F5)\n"
	"	x (black medium right-pointing triangle centred - 2BC8)"},
/* 25B7 */ { "WHITE RIGHT-POINTING TRIANGLE","	= z notation range restriction"},
/* 25B8 */ { "BLACK RIGHT-POINTING SMALL TRIANGLE","	x (triangular bullet - 2023)"},
/* 25B9 */ { "WHITE RIGHT-POINTING SMALL TRIANGLE",NULL},
/* 25BA */ { "BLACK RIGHT-POINTING POINTER",NULL},
/* 25BB */ { "WHITE RIGHT-POINTING POINTER","	= forward arrow indicator\n"
	"	x (contains as normal subgroup - 22B3)"},
/* 25BC */ { "BLACK DOWN-POINTING TRIANGLE","	x (black medium down-pointing triangle - 23F7)\n"
	"	x (black medium down-pointing triangle centred - 2BC6)\n"
	"	x (down-pointing red triangle - 1F53B)"},
/* 25BD */ { "WHITE DOWN-POINTING TRIANGLE","	= Hamilton operator\n"
	"	x (nabla - 2207)\n"
	"	x (heavy white down-pointing triangle - 26DB)\n"
	"	x (alchemical symbol for water - 1F704)"},
/* 25BE */ { "BLACK DOWN-POINTING SMALL TRIANGLE","	x (down-pointing small red triangle - 1F53D)"},
/* 25BF */ { "WHITE DOWN-POINTING SMALL TRIANGLE",NULL},
/* 25C0 */ { "BLACK LEFT-POINTING TRIANGLE","	x (black medium left-pointing triangle - 23F4)\n"
	"	x (black medium left-pointing triangle centred - 2BC7)"},
/* 25C1 */ { "WHITE LEFT-POINTING TRIANGLE","	= z notation domain restriction"},
/* 25C2 */ { "BLACK LEFT-POINTING SMALL TRIANGLE",NULL},
/* 25C3 */ { "WHITE LEFT-POINTING SMALL TRIANGLE",NULL},
/* 25C4 */ { "BLACK LEFT-POINTING POINTER",NULL},
/* 25C5 */ { "WHITE LEFT-POINTING POINTER","	= backward arrow indicator\n"
	"	x (normal subgroup of - 22B2)"},
/* 25C6 */ { "BLACK DIAMOND","	x (black diamond suit - 2666)\n"
	"	x (black medium diamond - 2B25)\n"
	"	x (large orange diamond - 1F536)"},
/* 25C7 */ { "WHITE DIAMOND","	x (combining enclosing diamond - 20DF)\n"
	"	x (diamond operator - 22C4)\n"
	"	x (white diamond suit - 2662)\n"
	"	x (white concave-sided diamond - 27E1)\n"
	"	x (white medium diamond - 2B26)\n"
	"	x (alchemical symbol for soap - 1F754)\n"
	"	x (box drawings light diagonal diamond - 1FBAE)"},
/* 25C8 */ { "WHITE DIAMOND CONTAINING BLACK SMALL DIAMOND",NULL},
/* 25C9 */ { "FISHEYE","	= tainome (Japanese, a kind of bullet)"},
/* 25CA */ { "LOZENGE","	x (white diamond suit - 2662)"},
/* 25CB */ { "WHITE CIRCLE","	x (combining enclosing circle - 20DD)\n"
	"	x (large circle - 25EF)\n"
	"	x (heavy circle - 2B58)\n"
	"	x (ideographic number zero - 3007)\n"
	"	x (full moon symbol - 1F315)"},
/* 25CC */ { "DOTTED CIRCLE","	* note that the reference glyph for this character is intentionally larger than the dotted circle glyph used to indicate combining characters in this standard; see, for example, 0300"},
/* 25CD */ { "CIRCLE WITH VERTICAL FILL",NULL},
/* 25CE */ { "BULLSEYE","	x (circled ring operator - 229A)\n"
	"	x (heavy circle with circle inside - 2B57)\n"
	"	x (direct hit - 1F3AF)\n"
	"	x (round target - 1F78B)"},
/* 25CF */ { "BLACK CIRCLE","	x (black large circle - 2B24)\n"
	"	x (new moon symbol - 1F311)\n"
	"	x (large red circle - 1F534)"},
/* 25D0 */ { "CIRCLE WITH LEFT HALF BLACK","	x (first quarter moon symbol - 1F313)"},
/* 25D1 */ { "CIRCLE WITH RIGHT HALF BLACK","	x (last quarter moon symbol - 1F317)"},
/* 25D2 */ { "CIRCLE WITH LOWER HALF BLACK",NULL},
/* 25D3 */ { "CIRCLE WITH UPPER HALF BLACK",NULL},
/* 25D4 */ { "CIRCLE WITH UPPER RIGHT QUADRANT BLACK",NULL},
/* 25D5 */ { "CIRCLE WITH ALL BUT UPPER LEFT QUADRANT BLACK",NULL},
/* 25D6 */ { "LEFT HALF BLACK CIRCLE",NULL},
/* 25D7 */ { "RIGHT HALF BLACK CIRCLE",NULL},
/* 25D8 */ { "INVERSE BULLET","	x (bullet - 2022)\n"
	"	x (white bullet - 25E6)"},
/* 25D9 */ { "INVERSE WHITE CIRCLE",NULL},
/* 25DA */ { "UPPER HALF INVERSE WHITE CIRCLE",NULL},
/* 25DB */ { "LOWER HALF INVERSE WHITE CIRCLE",NULL},
/* 25DC */ { "UPPER LEFT QUADRANT CIRCULAR ARC",NULL},
/* 25DD */ { "UPPER RIGHT QUADRANT CIRCULAR ARC",NULL},
/* 25DE */ { "LOWER RIGHT QUADRANT CIRCULAR ARC",NULL},
/* 25DF */ { "LOWER LEFT QUADRANT CIRCULAR ARC",NULL},
/* 25E0 */ { "UPPER HALF CIRCLE","	x (arc - 2312)"},
/* 25E1 */ { "LOWER HALF CIRCLE",NULL},
/* 25E2 */ { "BLACK LOWER RIGHT TRIANGLE","	x (lower right triangular medium shade - 1FB9E)"},
/* 25E3 */ { "BLACK LOWER LEFT TRIANGLE","	x (lower left triangular medium shade - 1FB9F)"},
/* 25E4 */ { "BLACK UPPER LEFT TRIANGLE","	x (upper left triangular medium shade - 1FB9C)"},
/* 25E5 */ { "BLACK UPPER RIGHT TRIANGLE","	x (upper right triangular medium shade - 1FB9D)"},
/* 25E6 */ { "WHITE BULLET","	x (bullet - 2022)\n"
	"	x (ring operator - 2218)\n"
	"	x (inverse bullet - 25D8)"},
/* 25E7 */ { "SQUARE WITH LEFT HALF BLACK","	x (square with top half black - 2B12)"},
/* 25E8 */ { "SQUARE WITH RIGHT HALF BLACK",NULL},
/* 25E9 */ { "SQUARE WITH UPPER LEFT DIAGONAL HALF BLACK",NULL},
/* 25EA */ { "SQUARE WITH LOWER RIGHT DIAGONAL HALF BLACK",NULL},
/* 25EB */ { "WHITE SQUARE WITH VERTICAL BISECTING LINE",NULL},
/* 25EC */ { "WHITE UP-POINTING TRIANGLE WITH DOT",NULL},
/* 25ED */ { "UP-POINTING TRIANGLE WITH LEFT HALF BLACK",NULL},
/* 25EE */ { "UP-POINTING TRIANGLE WITH RIGHT HALF BLACK",NULL},
/* 25EF */ { "LARGE CIRCLE","	x (combining enclosing circle - 20DD)\n"
	"	x (white circle - 25CB)\n"
	"	x (black large circle - 2B24)\n"
	"	x (heavy large circle - 2B55)\n"
	"	x (ideographic number zero - 3007)"},
/* 25F0 */ { "WHITE SQUARE WITH UPPER LEFT QUADRANT",NULL},
/* 25F1 */ { "WHITE SQUARE WITH LOWER LEFT QUADRANT",NULL},
/* 25F2 */ { "WHITE SQUARE WITH LOWER RIGHT QUADRANT",NULL},
/* 25F3 */ { "WHITE SQUARE WITH UPPER RIGHT QUADRANT",NULL},
/* 25F4 */ { "WHITE CIRCLE WITH UPPER LEFT QUADRANT",NULL},
/* 25F5 */ { "WHITE CIRCLE WITH LOWER LEFT QUADRANT",NULL},
/* 25F6 */ { "WHITE CIRCLE WITH LOWER RIGHT QUADRANT",NULL},
/* 25F7 */ { "WHITE CIRCLE WITH UPPER RIGHT QUADRANT",NULL},
/* 25F8 */ { "UPPER LEFT TRIANGLE",NULL},
/* 25F9 */ { "UPPER RIGHT TRIANGLE",NULL},
/* 25FA */ { "LOWER LEFT TRIANGLE","	x (right triangle - 22BF)"},
/* 25FB */ { "WHITE MEDIUM SQUARE","	= always (modal operator)\n"
	"	x (white square - 25A1)\n"
	"	x (white square with leftwards tick - 27E4)"},
/* 25FC */ { "BLACK MEDIUM SQUARE","	x (black square for stop - 23F9)\n"
	"	x (black square - 25A0)"},
/* 25FD */ { "WHITE MEDIUM SMALL SQUARE","	x (white small square - 25AB)"},
/* 25FE */ { "BLACK MEDIUM SMALL SQUARE","	x (black small square - 25AA)"},
/* 25FF */ { "LOWER RIGHT TRIANGLE","	x (right triangle - 22BF)"}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_00_26[] = {
/* 2600 */ { "BLACK SUN WITH RAYS","	= clear weather\n"
	"	x (sun - 2609)\n"
	"	x (high brightness symbol - 1F506)"},
/* 2601 */ { "CLOUD","	= cloudy weather"},
/* 2602 */ { "UMBRELLA","	= rainy weather\n"
	"	x (closed umbrella - 1F302)\n"
	"	x (cloud with rain - 1F327)"},
/* 2603 */ { "SNOWMAN","	= snowy weather"},
/* 2604 */ { "COMET",NULL},
/* 2605 */ { "BLACK STAR","	x (star operator - 22C6)\n"
	"	x (black small star - 2B51)\n"
	"	x (left half black star - 2BE8)\n"
	"	x (light five pointed black star - 1F7C9)"},
/* 2606 */ { "WHITE STAR","	x (stress outlined white star - 2729)\n"
	"	x (white medium star - 2B50)\n"
	"	x (glowing star - 1F31F)"},
/* 2607 */ { "LIGHTNING",NULL},
/* 2608 */ { "THUNDERSTORM",NULL},
/* 2609 */ { "SUN","	= alchemical symbol for gold\n"
	"	x (circled dot operator - 2299)\n"
	"	x (black sun with rays - 2600)\n"
	"	x (white sun with rays - 263C)\n"
	"	x (sun with face - 1F31E)"},
/* 260A */ { "ASCENDING NODE","	= alchemical symbol for sublimation\n"
	"	x (alchemical symbol for sublimation - 1F75E)"},
/* 260B */ { "DESCENDING NODE","	= alchemical symbol for purify\n"
	"	x (alchemical symbol for purify - 1F763)"},
/* 260C */ { "CONJUNCTION","	= alchemical symbol for day\n"
	"	x (occultation - 1F775)"},
/* 260D */ { "OPPOSITION","	x (lunar eclipse - 1F776)"},
/* 260E */ { "BLACK TELEPHONE","	x (telephone sign - 2121)\n"
	"	x (telephone location sign - 2706)\n"
	"	x (telephone receiver - 1F4DE)\n"
	"	x (black touchtone telephone - 1F57F)"},
/* 260F */ { "WHITE TELEPHONE","	x (white touchtone telephone - 1F57E)"},
/* 2610 */ { "BALLOT BOX","	x (white square - 25A1)"},
/* 2611 */ { "BALLOT BOX WITH CHECK","	x (ballot box with bold check - 1F5F9)"},
/* 2612 */ { "BALLOT BOX WITH X","	x (squared times - 22A0)\n"
	"	x (x in a rectangle box - 2327)\n"
	"	x (ballot box with light x - 2BBD)\n"
	"	x (ballot box with ballot - 1F5F3)\n"
	"	x (ballot box with script x - 1F5F5)"},
/* 2613 */ { "SALTIRE","	= St. Andrew's Cross\n"
	"	x (ballot x - 2717)\n"
	"	x (light saltire - 1F7A9)"},
/* 2614 */ { "UMBRELLA WITH RAIN DROPS","	= showery weather"},
/* 2615 */ { "HOT BEVERAGE","	= tea or coffee, depending on locale\n"
	"	* can be used to indicate a wait\n"
	"	x (watch - 231A)\n"
	"	x (hourglass - 231B)\n"
	"	x (teacup without handle - 1F375)"},
/* 2616 */ { "WHITE SHOGI PIECE",NULL},
/* 2617 */ { "BLACK SHOGI PIECE",NULL},
/* 2618 */ { "SHAMROCK","	x (four leaf clover - 1F340)"},
/* 2619 */ { "REVERSED ROTATED FLORAL HEART BULLET","	* a binding signature mark\n"
	"	x (rotated floral heart bullet - 2767)\n"
	"	x (south west pointing vine leaf - 1F659)"},
/* 261A */ { "BLACK LEFT POINTING INDEX",NULL},
/* 261B */ { "BLACK RIGHT POINTING INDEX",NULL},
/* 261C */ { "WHITE LEFT POINTING INDEX","	x (white left pointing backhand index - 1F448)\n"
	"	x (sideways white left pointing index - 1F598)"},
/* 261D */ { "WHITE UP POINTING INDEX","	x (sideways white up pointing index - 1F59E)"},
/* 261E */ { "WHITE RIGHT POINTING INDEX","	= fist (typographic term)\n"
	"	x (sideways white right pointing index - 1F599)\n"
	"	x (left third white right pointing index - 1FBC1)"},
/* 261F */ { "WHITE DOWN POINTING INDEX","	x (white down pointing left hand index - 1F597)\n"
	"	x (sideways white down pointing index - 1F59F)"},
/* 2620 */ { "SKULL AND CROSSBONES","	= poison\n"
	"	x (black skull and crossbones - 1F571)"},
/* 2621 */ { "CAUTION SIGN",NULL},
/* 2622 */ { "RADIOACTIVE SIGN",NULL},
/* 2623 */ { "BIOHAZARD SIGN",NULL},
/* 2624 */ { "CADUCEUS","	x (staff of aesculapius - 2695)\n"
	"	x (alchemical symbol for caduceus - 1F750)"},
/* 2625 */ { "ANKH",NULL},
/* 2626 */ { "ORTHODOX CROSS",NULL},
/* 2627 */ { "CHI RHO","	= Constantine's cross, Christogram\n"
	"	x (coptic symbol khi ro - 2CE9)"},
/* 2628 */ { "CROSS OF LORRAINE",NULL},
/* 2629 */ { "CROSS OF JERUSALEM","	= simple cross potent\n"
	"	* contrasts with the actual cross of Jerusalem, which adds a small crosslet at each corner\n"
	"	x (alchemical symbol for vinegar - 1F70A)"},
/* 262A */ { "STAR AND CRESCENT",NULL},
/* 262B */ { "FARSI SYMBOL","	= symbol of iran (1.0)"},
/* 262C */ { "ADI SHAKTI","	= khanda\n"
	"	* Sikh religious symbol\n"
	"	x (khanda - 1FAAF)"},
/* 262D */ { "HAMMER AND SICKLE",NULL},
/* 262E */ { "PEACE SYMBOL",NULL},
/* 262F */ { "YIN YANG","	x (tibetan symbol nor bu nyis -khyil - 0FCA)"},
/* 2630 */ { "TRIGRAM FOR HEAVEN","	= qian2"},
/* 2631 */ { "TRIGRAM FOR LAKE","	= dui4"},
/* 2632 */ { "TRIGRAM FOR FIRE","	= li2"},
/* 2633 */ { "TRIGRAM FOR THUNDER","	= zhen4"},
/* 2634 */ { "TRIGRAM FOR WIND","	= xun4"},
/* 2635 */ { "TRIGRAM FOR WATER","	= kan3"},
/* 2636 */ { "TRIGRAM FOR MOUNTAIN","	= gen4"},
/* 2637 */ { "TRIGRAM FOR EARTH","	= kun1"},
/* 2638 */ { "WHEEL OF DHARMA","	x (helm symbol - 2388)"},
/* 2639 */ { "WHITE FROWNING FACE","	x (slightly frowning face - 1F641)"},
/* 263A */ { "WHITE SMILING FACE","	x (slightly smiling face - 1F642)\n"
	"	= have a nice day!"},
/* 263B */ { "BLACK SMILING FACE",NULL},
/* 263C */ { "WHITE SUN WITH RAYS","	= compass\n"
	"	x (sun - 2609)\n"
	"	x (sun with face - 1F31E)\n"
	"	x (white sun - 1F323)\n"
	"	x (high brightness symbol - 1F506)"},
/* 263D */ { "FIRST QUARTER MOON","	= alchemical symbol for silver\n"
	"	x (first quarter moon symbol - 1F313)"},
/* 263E */ { "LAST QUARTER MOON","	= alchemical symbol for silver\n"
	"	x (power sleep symbol - 23FE)\n"
	"	x (last quarter moon symbol - 1F317)\n"
	"	x (crescent moon - 1F319)"},
/* 263F */ { "MERCURY","	= alchemical symbol for quicksilver\n"
	"	= intersexuality"},
/* 2640 */ { "FEMALE SIGN","	= Venus\n"
	"	= alchemical symbol for copper\n"
	"	x (woman - 1F469)\n"
	"	x (womens symbol - 1F6BA)"},
/* 2641 */ { "EARTH","	= alchemical symbol for antimony\n"
	"	x (alchemical symbol for verdigris - 1F728)"},
/* 2642 */ { "MALE SIGN","	= Mars\n"
	"	= alchemical symbol for iron\n"
	"	x (passed symbol - 2BFD)\n"
	"	x (man - 1F468)\n"
	"	x (mens symbol - 1F6B9)"},
/* 2643 */ { "JUPITER","	= alchemical symbol for tin"},
/* 2644 */ { "SATURN","	= alchemical symbol for lead"},
/* 2645 */ { "URANUS","	= alchemical symbol for platinum\n"
	"	x (astronomical symbol for uranus - 26E2)"},
/* 2646 */ { "NEPTUNE","	= alchemical symbol for bismuth/tinglass\n"
	"	x (neptune form two - 2BC9)"},
/* 2647 */ { "PLUTO","	x (pluto form two - 2BD3)"},
/* 2648 */ { "ARIES","	x (ram - 1F40F)"},
/* 2649 */ { "TAURUS",NULL},
/* 264A */ { "GEMINI",NULL},
/* 264B */ { "CANCER","	x (crab - 1F980)"},
/* 264C */ { "LEO","	x (lion face - 1F981)"},
/* 264D */ { "VIRGO","	= minim (alternate glyph)"},
/* 264E */ { "LIBRA","	x (scales - 2696)\n"
	"	x (alchemical symbol for sublimation - 1F75E)"},
/* 264F */ { "SCORPIUS","	= Scorpio\n"
	"	= minim, drop\n"
	"	x (scorpion - 1F982)"},
/* 2650 */ { "SAGITTARIUS","	x (bow and arrow - 1F3F9)"},
/* 2651 */ { "CAPRICORN",NULL},
/* 2652 */ { "AQUARIUS","	x (amphora - 1F3FA)"},
/* 2653 */ { "PISCES",NULL},
/* 2654 */ { "WHITE CHESS KING",NULL},
/* 2655 */ { "WHITE CHESS QUEEN",NULL},
/* 2656 */ { "WHITE CHESS ROOK",NULL},
/* 2657 */ { "WHITE CHESS BISHOP",NULL},
/* 2658 */ { "WHITE CHESS KNIGHT",NULL},
/* 2659 */ { "WHITE CHESS PAWN",NULL},
/* 265A */ { "BLACK CHESS KING",NULL},
/* 265B */ { "BLACK CHESS QUEEN",NULL},
/* 265C */ { "BLACK CHESS ROOK",NULL},
/* 265D */ { "BLACK CHESS BISHOP",NULL},
/* 265E */ { "BLACK CHESS KNIGHT",NULL},
/* 265F */ { "BLACK CHESS PAWN",NULL},
/* 2660 */ { "BLACK SPADE SUIT",NULL},
/* 2661 */ { "WHITE HEART SUIT",NULL},
/* 2662 */ { "WHITE DIAMOND SUIT","	x (white diamond - 25C7)\n"
	"	x (lozenge - 25CA)"},
/* 2663 */ { "BLACK CLUB SUIT","	x (shamrock - 2618)"},
/* 2664 */ { "WHITE SPADE SUIT",NULL},
/* 2665 */ { "BLACK HEART SUIT","	= valentine\n"
	"	x (heavy black heart - 2764)\n"
	"	x (heart with tip on the left - 1F394)\n"
	"	x (blue heart - 1F499)\n"
	"	x (black heart - 1F5A4)"},
/* 2666 */ { "BLACK DIAMOND SUIT","	x (black diamond - 25C6)"},
/* 2667 */ { "WHITE CLUB SUIT",NULL},
/* 2668 */ { "HOT SPRINGS",NULL},
/* 2669 */ { "QUARTER NOTE","	= crotchet\n"
	"	x (musical symbol quarter note - 1D15F)"},
/* 266A */ { "EIGHTH NOTE","	= quaver\n"
	"	x (musical symbol eighth note - 1D160)\n"
	"	x (musical note - 1F3B5)"},
/* 266B */ { "BEAMED EIGHTH NOTES","	= beamed quavers\n"
	"	x (beamed descending musical notes - 1F39D)\n"
	"	x (multiple musical notes - 1F3B6)"},
/* 266C */ { "BEAMED SIXTEENTH NOTES","	= beamed semiquavers"},
/* 266D */ { "MUSIC FLAT SIGN",NULL},
/* 266E */ { "MUSIC NATURAL SIGN",NULL},
/* 266F */ { "MUSIC SHARP SIGN","	= z notation infix bag count\n"
	"	x (number sign - 0023)"},
/* 2670 */ { "WEST SYRIAC CROSS",NULL},
/* 2671 */ { "EAST SYRIAC CROSS",NULL},
/* 2672 */ { "UNIVERSAL RECYCLING SYMBOL","	* used as generic symbol for recycling or to indicate that material is recyclable"},
/* 2673 */ { "RECYCLING SYMBOL FOR TYPE-1 PLASTICS","	* polyethylene terephthalate"},
/* 2674 */ { "RECYCLING SYMBOL FOR TYPE-2 PLASTICS","	* high density polyethylene"},
/* 2675 */ { "RECYCLING SYMBOL FOR TYPE-3 PLASTICS","	* vinyl, polyvinyl chloride"},
/* 2676 */ { "RECYCLING SYMBOL FOR TYPE-4 PLASTICS","	* low density polyethylene"},
/* 2677 */ { "RECYCLING SYMBOL FOR TYPE-5 PLASTICS","	* polypropylene"},
/* 2678 */ { "RECYCLING SYMBOL FOR TYPE-6 PLASTICS","	* polystyrene"},
/* 2679 */ { "RECYCLING SYMBOL FOR TYPE-7 PLASTICS","	* other plastics"},
/* 267A */ { "RECYCLING SYMBOL FOR GENERIC MATERIALS","	* used together with other text and labels to indicate the type of material to be recycled"},
/* 267B */ { "BLACK UNIVERSAL RECYCLING SYMBOL","	x (clockwise rightwards and leftwards open circle arrows - 1F501)"},
/* 267C */ { "RECYCLED PAPER SYMBOL","	* used to indicate 100% recycled paper content"},
/* 267D */ { "PARTIALLY-RECYCLED PAPER SYMBOL","	* percentage of recycled paper content indicated in overlay or next to this symbol"},
/* 267E */ { "PERMANENT PAPER SIGN","	= non-acid paper"},
/* 267F */ { "WHEELCHAIR SYMBOL","	= accessible place"},
/* 2680 */ { "DIE FACE-1","	x (game die - 1F3B2)"},
/* 2681 */ { "DIE FACE-2",NULL},
/* 2682 */ { "DIE FACE-3",NULL},
/* 2683 */ { "DIE FACE-4",NULL},
/* 2684 */ { "DIE FACE-5",NULL},
/* 2685 */ { "DIE FACE-6",NULL},
/* 2686 */ { "WHITE CIRCLE WITH DOT RIGHT",NULL},
/* 2687 */ { "WHITE CIRCLE WITH TWO DOTS","	x (face without mouth - 1F636)"},
/* 2688 */ { "BLACK CIRCLE WITH WHITE DOT RIGHT",NULL},
/* 2689 */ { "BLACK CIRCLE WITH TWO WHITE DOTS",NULL},
/* 268A */ { "MONOGRAM FOR YANG",NULL},
/* 268B */ { "MONOGRAM FOR YIN",NULL},
/* 268C */ { "DIGRAM FOR GREATER YANG",NULL},
/* 268D */ { "DIGRAM FOR LESSER YIN",NULL},
/* 268E */ { "DIGRAM FOR LESSER YANG",NULL},
/* 268F */ { "DIGRAM FOR GREATER YIN",NULL},
/* 2690 */ { "WHITE FLAG","	x (waving white flag - 1F3F3)"},
/* 2691 */ { "BLACK FLAG",NULL},
/* 2692 */ { "HAMMER AND PICK","	= mining, working day (in timetables)\n"
	"	x (pick - 26CF)\n"
	"	x (hammer and wrench - 1F6E0)"},
/* 2693 */ { "ANCHOR","	= nautical term, harbor (on maps)"},
/* 2694 */ { "CROSSED SWORDS","	= military term, battleground (on maps), killed in action\n"
	"	x (fencer - 1F93A)"},
/* 2695 */ { "STAFF OF AESCULAPIUS","	= medical term\n"
	"	* both inclined or upright renderings of this symbol are common\n"
	"	x (caduceus - 2624)\n"
	"	x (bowl of hygieia - 1F54F)"},
/* 2696 */ { "SCALES","	= legal term, jurisprudence\n"
	"	x (libra - 264E)"},
/* 2697 */ { "ALEMBIC","	= chemical term, chemistry\n"
	"	x (alchemical symbol for retort - 1F76D)"},
/* 2698 */ { "FLOWER","	= botanical term\n"
	"	x (flower punctuation mark - 2055)\n"
	"	x (white florette - 2740)\n"
	"	x (tulip - 1F337)"},
/* 2699 */ { "GEAR","	= technology, tools"},
/* 269A */ { "STAFF OF HERMES","	* signifies a commercial term or commerce\n"
	"	* glyph shows a heraldic staff with a winged wheel"},
/* 269B */ { "ATOM SYMBOL","	= nuclear installation (on maps)"},
/* 269C */ { "FLEUR-DE-LIS",NULL},
/* 269D */ { "OUTLINED WHITE STAR","	* alternative form of the interlaced pentagram (a symbol of Morocco)\n"
	"	x (right-handed interlaced pentagram - 26E5)"},
/* 269E */ { "THREE LINES CONVERGING RIGHT","	= someone speaking\n"
	"	x (three rays left - 1F5E6)"},
/* 269F */ { "THREE LINES CONVERGING LEFT","	= background speaking\n"
	"	x (three rays right - 1F5E7)"},
/* 26A0 */ { "WARNING SIGN","	x (octagonal sign - 1F6D1)"},
/* 26A1 */ { "HIGH VOLTAGE SIGN","	= thunder\n"
	"	= lightning symbol\n"
	"	x (lightning mood - 1F5F2)"},
/* 26A2 */ { "DOUBLED FEMALE SIGN","	= female homosexuality\n"
	"	x (two women holding hands - 1F46D)"},
/* 26A3 */ { "DOUBLED MALE SIGN","	* a glyph variant has the two circles on the same line\n"
	"	= male homosexuality\n"
	"	x (two men holding hands - 1F46C)"},
/* 26A4 */ { "INTERLOCKED FEMALE AND MALE SIGN","	* a glyph variant has the two circles on the same line\n"
	"	= heterosexuality"},
/* 26A5 */ { "MALE AND FEMALE SIGN","	= intersex, androgynous\n"
	"	= hermaphroditic (in botany)"},
/* 26A6 */ { "MALE WITH STROKE SIGN","	= transgender\n"
	"	= alchemical symbol for iron or crocus of iron"},
/* 26A7 */ { "MALE WITH STROKE AND MALE AND FEMALE SIGN","	= transgender"},
/* 26A8 */ { "VERTICAL MALE WITH STROKE SIGN","	= alchemical symbol for iron"},
/* 26A9 */ { "HORIZONTAL MALE WITH STROKE SIGN","	= alchemical symbol for iron"},
/* 26AA */ { "MEDIUM WHITE CIRCLE","	= asexuality, sexless, genderless\n"
	"	= engaged, betrothed\n"
	"	* base for male or female sign\n"
	"	x (medium bold white circle - 1F785)"},
/* 26AB */ { "MEDIUM BLACK CIRCLE","	* UI symbol for record function\n"
	"	x (black circle for record - 23FA)"},
/* 26AC */ { "MEDIUM SMALL WHITE CIRCLE","	= engaged, betrothed (genealogy)\n"
	"	* can represent wedding ring"},
/* 26AD */ { "MARRIAGE SYMBOL","	x (infinity - 221E)\n"
	"	x (wedding - 1F492)"},
/* 26AE */ { "DIVORCE SYMBOL","	x (infinity negated with vertical bar - 29DE)\n"
	"	x (united symbol - 2BFA)"},
/* 26AF */ { "UNMARRIED PARTNERSHIP SYMBOL","	x (double-ended multimap - 29DF)\n"
	"	x (separated symbol - 2BFB)"},
/* 26B0 */ { "COFFIN","	= buried (genealogy)\n"
	"	x (white rectangle - 25AD)"},
/* 26B1 */ { "FUNERAL URN","	= cremated (genealogy)"},
/* 26B2 */ { "NEUTER",NULL},
/* 26B3 */ { "CERES",NULL},
/* 26B4 */ { "PALLAS",NULL},
/* 26B5 */ { "JUNO",NULL},
/* 26B6 */ { "VESTA","	x (vesta form two - 1F777)"},
/* 26B7 */ { "CHIRON",NULL},
/* 26B8 */ { "BLACK MOON LILITH",NULL},
/* 26B9 */ { "SEXTILE","	* an aspect of 60 degrees\n"
	"	x (asterisk - 002A)\n"
	"	x (six pointed black star - 2736)\n"
	"	x (alchemical symbol for sal-ammoniac - 1F739)"},
/* 26BA */ { "SEMISEXTILE","	* an aspect of 30 degrees\n"
	"	x (xor - 22BB)"},
/* 26BB */ { "QUINCUNX","	* an aspect of 150 degrees\n"
	"	x (nand - 22BC)"},
/* 26BC */ { "SESQUIQUADRATE","	* an aspect of 135 degrees"},
/* 26BD */ { "SOCCER BALL",NULL},
/* 26BE */ { "BASEBALL",NULL},
/* 26BF */ { "SQUARED KEY","	= parental lock\n"
	"	x (key - 1F511)"},
/* 26C0 */ { "WHITE DRAUGHTS MAN",NULL},
/* 26C1 */ { "WHITE DRAUGHTS KING",NULL},
/* 26C2 */ { "BLACK DRAUGHTS MAN",NULL},
/* 26C3 */ { "BLACK DRAUGHTS KING",NULL},
/* 26C4 */ { "SNOWMAN WITHOUT SNOW","	= light snow"},
/* 26C5 */ { "SUN BEHIND CLOUD","	= partly cloudy\n"
	"	x (white sun with small cloud - 1F324)"},
/* 26C6 */ { "RAIN","	= rainy weather"},
/* 26C7 */ { "BLACK SNOWMAN","	= heavy snow"},
/* 26C8 */ { "THUNDER CLOUD AND RAIN","	= thunderstorm\n"
	"	x (cloud with lightning - 1F329)"},
/* 26C9 */ { "TURNED WHITE SHOGI PIECE",NULL},
/* 26CA */ { "TURNED BLACK SHOGI PIECE",NULL},
/* 26CB */ { "WHITE DIAMOND IN SQUARE","	x (apl functional symbol quad diamond - 233A)"},
/* 26CC */ { "CROSSING LANES","	= accident\n"
	"	x (falling diagonal crossing rising diagonal - 292C)"},
/* 26CD */ { "DISABLED CAR",NULL},
/* 26CE */ { "OPHIUCHUS",NULL},
/* 26CF */ { "PICK","	= under construction\n"
	"	x (hammer and pick - 2692)\n"
	"	x (construction sign - 1F6A7)"},
/* 26D0 */ { "CAR SLIDING","	= icy road"},
/* 26D1 */ { "HELMET WITH WHITE CROSS","	= maintenance\n"
	"	x (construction worker - 1F477)"},
/* 26D2 */ { "CIRCLED CROSSING LANES","	= road closed\n"
	"	x (circled times - 2297)"},
/* 26D3 */ { "CHAINS","	= tyre chains required"},
/* 26D4 */ { "NO ENTRY","	x (no entry sign - 1F6AB)"},
/* 26D5 */ { "ALTERNATE ONE-WAY LEFT WAY TRAFFIC","	* left side traffic"},
/* 26D6 */ { "BLACK TWO-WAY LEFT WAY TRAFFIC","	* left side traffic"},
/* 26D7 */ { "WHITE TWO-WAY LEFT WAY TRAFFIC","	* left side traffic"},
/* 26D8 */ { "BLACK LEFT LANE MERGE","	* left side traffic"},
/* 26D9 */ { "WHITE LEFT LANE MERGE","	* left side traffic"},
/* 26DA */ { "DRIVE SLOW SIGN",NULL},
/* 26DB */ { "HEAVY WHITE DOWN-POINTING TRIANGLE","	= drive slow\n"
	"	x (white down-pointing triangle - 25BD)"},
/* 26DC */ { "LEFT CLOSED ENTRY",NULL},
/* 26DD */ { "SQUARED SALTIRE","	= closed entry\n"
	"	x (squared times - 22A0)"},
/* 26DE */ { "FALLING DIAGONAL IN WHITE CIRCLE IN BLACK SQUARE","	= closed to large vehicles"},
/* 26DF */ { "BLACK TRUCK","	= black lorry\n"
	"	= closed to large vehicles, alternate\n"
	"	x (delivery truck - 1F69A)"},
/* 26E0 */ { "RESTRICTED LEFT ENTRY-1",NULL},
/* 26E1 */ { "RESTRICTED LEFT ENTRY-2",NULL},
/* 26E2 */ { "ASTRONOMICAL SYMBOL FOR URANUS","	x (uranus - 2645)"},
/* 26E3 */ { "HEAVY CIRCLE WITH STROKE AND TWO DOTS ABOVE","	= public office"},
/* 26E4 */ { "PENTAGRAM","	= pentalpha, pentangle\n"
	"	* symbol of various uses, including symbol on Moroccan flag\n"
	"	x (white star - 2606)"},
/* 26E5 */ { "RIGHT-HANDED INTERLACED PENTAGRAM","	* symbol of various countries, including Morocco\n"
	"	x (outlined white star - 269D)"},
/* 26E6 */ { "LEFT-HANDED INTERLACED PENTAGRAM","	* symbol of various countries, including Ethiopia"},
/* 26E7 */ { "INVERTED PENTAGRAM",NULL},
/* 26E8 */ { "BLACK CROSS ON SHIELD","	= hospital\n"
	"	x (hospital - 1F3E5)"},
/* 26E9 */ { "SHINTO SHRINE","	= torii"},
/* 26EA */ { "CHURCH",NULL},
/* 26EB */ { "CASTLE","	x (european castle - 1F3F0)"},
/* 26EC */ { "HISTORIC SITE","	x (therefore - 2234)"},
/* 26ED */ { "GEAR WITHOUT HUB","	= factory\n"
	"	x (gear - 2699)\n"
	"	x (factory - 1F3ED)"},
/* 26EE */ { "GEAR WITH HANDLES","	= power plant, power substation"},
/* 26EF */ { "MAP SYMBOL FOR LIGHTHOUSE",NULL},
/* 26F0 */ { "MOUNTAIN","	x (snow capped mountain - 1F3D4)"},
/* 26F1 */ { "UMBRELLA ON GROUND","	= bathing beach\n"
	"	x (umbrella - 2602)\n"
	"	x (beach with umbrella - 1F3D6)"},
/* 26F2 */ { "FOUNTAIN","	= park"},
/* 26F3 */ { "FLAG IN HOLE","	= golf course\n"
	"	x (triangular flag on post - 1F6A9)"},
/* 26F4 */ { "FERRY","	= ferry boat terminal\n"
	"	x (ship - 1F6A2)"},
/* 26F5 */ { "SAILBOAT","	= marina or yacht harbour\n"
	"	x (rowboat - 1F6A3)"},
/* 26F6 */ { "SQUARE FOUR CORNERS","	= intersection"},
/* 26F7 */ { "SKIER","	= ski resort\n"
	"	x (ski and ski boot - 1F3BF)"},
/* 26F8 */ { "ICE SKATE","	= ice skating rink"},
/* 26F9 */ { "PERSON WITH BALL","	= track and field, gymnasium"},
/* 26FA */ { "TENT","	= camping site\n"
	"	x (camping - 1F3D5)"},
/* 26FB */ { "JAPANESE BANK SYMBOL","	x (bank - 1F3E6)"},
/* 26FC */ { "HEADSTONE GRAVEYARD SYMBOL","	= graveyard, memorial park, cemetery"},
/* 26FD */ { "FUEL PUMP","	= petrol station, gas station"},
/* 26FE */ { "CUP ON BLACK SQUARE","	= drive-in restaurant\n"
	"	x (hot beverage - 2615)\n"
	"	x (teacup without handle - 1F375)"},
/* 26FF */ { "WHITE FLAG WITH HORIZONTAL MIDDLE BLACK STRIPE","	= Japanese self-defence force site"}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_00_27[] = {
/* 2700 */ { "BLACK SAFETY SCISSORS","	* forms a pair with 2704 white scissors"},
/* 2701 */ { "UPPER BLADE SCISSORS",NULL},
/* 2702 */ { "BLACK SCISSORS",NULL},
/* 2703 */ { "LOWER BLADE SCISSORS",NULL},
/* 2704 */ { "WHITE SCISSORS",NULL},
/* 2705 */ { "WHITE HEAVY CHECK MARK","	x (heavy check mark - 2714)"},
/* 2706 */ { "TELEPHONE LOCATION SIGN","	x (telephone sign - 2121)\n"
	"	x (telephone receiver - 1F4DE)"},
/* 2707 */ { "TAPE DRIVE",NULL},
/* 2708 */ { "AIRPLANE","	x (up-pointing airplane - 1F6E7)"},
/* 2709 */ { "ENVELOPE","	= sealed envelope\n"
	"	x (incoming envelope - 1F4E8)\n"
	"	x (back of envelope - 1F582)"},
/* 270A */ { "RAISED FIST","	= rock in Rock, Paper, Scissors game\n"
	"	x (fisted hand sign - 1F44A)"},
/* 270B */ { "RAISED HAND","	= paper in Rock, Paper, Scissors game\n"
	"	x (waving hand sign - 1F44B)\n"
	"	x (raised hand with fingers splayed - 1F590)"},
/* 270C */ { "VICTORY HAND","	= scissors in Rock, Paper, Scissors game\n"
	"	x (reversed victory hand - 1F594)"},
/* 270D */ { "WRITING HAND","	x (left writing hand - 1F58E)"},
/* 270E */ { "LOWER RIGHT PENCIL","	x (lower left pencil - 1F589)"},
/* 270F */ { "PENCIL",NULL},
/* 2710 */ { "UPPER RIGHT PENCIL",NULL},
/* 2711 */ { "WHITE NIB","	x (lower left fountain pen - 1F58B)"},
/* 2712 */ { "BLACK NIB",NULL},
/* 2713 */ { "CHECK MARK","	x (square root - 221A)\n"
	"	x (light check mark - 1F5F8)\n"
	"	x (inverse check mark - 1FBB1)"},
/* 2714 */ { "HEAVY CHECK MARK",NULL},
/* 2715 */ { "MULTIPLICATION X","	x (multiplication sign - 00D7)\n"
	"	x (box drawings light diagonal cross - 2573)\n"
	"	x (thin saltire - 1F7A8)"},
/* 2716 */ { "HEAVY MULTIPLICATION X","	x (extremely heavy saltire - 1F7AE)"},
/* 2717 */ { "BALLOT X","	x (saltire - 2613)\n"
	"	x (ballot script x - 1F5F4)"},
/* 2718 */ { "HEAVY BALLOT X","	x (ballot bold script x - 1F5F6)"},
/* 2719 */ { "OUTLINED GREEK CROSS",NULL},
/* 271A */ { "HEAVY GREEK CROSS","	x (very bold greek cross - 1F7A5)\n"
	"	x (voided greek cross - 1FBBB)"},
/* 271B */ { "OPEN CENTRE CROSS",NULL},
/* 271C */ { "HEAVY OPEN CENTRE CROSS",NULL},
/* 271D */ { "LATIN CROSS",NULL},
/* 271E */ { "SHADOWED WHITE LATIN CROSS","	x (white latin cross - 1F546)"},
/* 271F */ { "OUTLINED LATIN CROSS",NULL},
/* 2720 */ { "MALTESE CROSS","	* historically, the Maltese cross took many forms; the shape shown in the Zapf Dingbats is similar to one known as the Cross Formée\n"
	"	x (cross patty with right crossbar - 2E50)\n"
	"	x (circled cross formee - 1F902)"},
/* 2721 */ { "STAR OF DAVID","	x (six pointed star with middle dot - 1F52F)"},
/* 2722 */ { "FOUR TEARDROP-SPOKED ASTERISK",NULL},
/* 2723 */ { "FOUR BALLOON-SPOKED ASTERISK",NULL},
/* 2724 */ { "HEAVY FOUR BALLOON-SPOKED ASTERISK",NULL},
/* 2725 */ { "FOUR CLUB-SPOKED ASTERISK",NULL},
/* 2726 */ { "BLACK FOUR POINTED STAR","	x (light four pointed black cusp - 2BCC)\n"
	"	x (four pointed black star - 1F7C6)"},
/* 2727 */ { "WHITE FOUR POINTED STAR","	x (white four pointed cusp - 2BCE)"},
/* 2728 */ { "SPARKLES",NULL},
/* 2729 */ { "STRESS OUTLINED WHITE STAR","	x (white star - 2606)"},
/* 272A */ { "CIRCLED WHITE STAR",NULL},
/* 272B */ { "OPEN CENTRE BLACK STAR",NULL},
/* 272C */ { "BLACK CENTRE WHITE STAR",NULL},
/* 272D */ { "OUTLINED BLACK STAR",NULL},
/* 272E */ { "HEAVY OUTLINED BLACK STAR",NULL},
/* 272F */ { "PINWHEEL STAR",NULL},
/* 2730 */ { "SHADOWED WHITE STAR",NULL},
/* 2731 */ { "HEAVY ASTERISK","	x (asterisk - 002A)\n"
	"	x (heavy six spoked asterisk - 1F7B8)"},
/* 2732 */ { "OPEN CENTRE ASTERISK",NULL},
/* 2733 */ { "EIGHT SPOKED ASTERISK","	x (light eight spoked asterisk - 1F7BB)"},
/* 2734 */ { "EIGHT POINTED BLACK STAR",NULL},
/* 2735 */ { "EIGHT POINTED PINWHEEL STAR","	x (heavy eight pointed pinwheel star - 1F7D1)"},
/* 2736 */ { "SIX POINTED BLACK STAR","	x (sextile - 26B9)"},
/* 2737 */ { "EIGHT POINTED RECTILINEAR BLACK STAR","	x (medium eight pointed black star - 1F7CE)"},
/* 2738 */ { "HEAVY EIGHT POINTED RECTILINEAR BLACK STAR","	x (heavy eight pointed black star - 1F7CF)"},
/* 2739 */ { "TWELVE POINTED BLACK STAR",NULL},
/* 273A */ { "SIXTEEN POINTED ASTERISK","	= starburst"},
/* 273B */ { "TEARDROP-SPOKED ASTERISK",NULL},
/* 273C */ { "OPEN CENTRE TEARDROP-SPOKED ASTERISK",NULL},
/* 273D */ { "HEAVY TEARDROP-SPOKED ASTERISK",NULL},
/* 273E */ { "SIX PETALLED BLACK AND WHITE FLORETTE",NULL},
/* 273F */ { "BLACK FLORETTE",NULL},
/* 2740 */ { "WHITE FLORETTE","	x (rosette - 1F3F5)\n"
	"	x (white flower - 1F4AE)"},
/* 2741 */ { "EIGHT PETALLED OUTLINED BLACK FLORETTE","	x (black rosette - 1F3F6)"},
/* 2742 */ { "CIRCLED OPEN CENTRE EIGHT POINTED STAR",NULL},
/* 2743 */ { "HEAVY TEARDROP-SPOKED PINWHEEL ASTERISK",NULL},
/* 2744 */ { "SNOWFLAKE",NULL},
/* 2745 */ { "TIGHT TRIFOLIATE SNOWFLAKE",NULL},
/* 2746 */ { "HEAVY CHEVRON SNOWFLAKE",NULL},
/* 2747 */ { "SPARKLE",NULL},
/* 2748 */ { "HEAVY SPARKLE",NULL},
/* 2749 */ { "BALLOON-SPOKED ASTERISK","	= jack"},
/* 274A */ { "EIGHT TEARDROP-SPOKED PROPELLER ASTERISK",NULL},
/* 274B */ { "HEAVY EIGHT TEARDROP-SPOKED PROPELLER ASTERISK","	= turbofan"},
/* 274C */ { "CROSS MARK","	* forms a game tally pair with 2B55\n"
	"	x (multiplication sign - 00D7)\n"
	"	x (cancellation x - 1F5D9)\n"
	"	x (heavy saltire - 1F7AC)\n"
	"	x (white heavy saltire with rounded corners - 1FBC0)"},
/* 274D */ { "SHADOWED WHITE CIRCLE","	x (lower right shadowed white circle - 1F53E)"},
/* 274E */ { "NEGATIVE SQUARED CROSS MARK","	x (negative diagonal cross - 1FBBD)"},
/* 274F */ { "LOWER RIGHT DROP-SHADOWED WHITE SQUARE",NULL},
/* 2750 */ { "UPPER RIGHT DROP-SHADOWED WHITE SQUARE",NULL},
/* 2751 */ { "LOWER RIGHT SHADOWED WHITE SQUARE",NULL},
/* 2752 */ { "UPPER RIGHT SHADOWED WHITE SQUARE",NULL},
/* 2753 */ { "BLACK QUESTION MARK ORNAMENT",NULL},
/* 2754 */ { "WHITE QUESTION MARK ORNAMENT",NULL},
/* 2755 */ { "WHITE EXCLAMATION MARK ORNAMENT",NULL},
/* 2756 */ { "BLACK DIAMOND MINUS WHITE X",NULL},
/* 2757 */ { "HEAVY EXCLAMATION MARK SYMBOL","	= obstacles on the road, ARIB STD B24"},
/* 2758 */ { "LIGHT VERTICAL BAR","	x (vertical line - 007C)"},
/* 2759 */ { "MEDIUM VERTICAL BAR",NULL},
/* 275A */ { "HEAVY VERTICAL BAR",NULL},
/* 275B */ { "HEAVY SINGLE TURNED COMMA QUOTATION MARK ORNAMENT","	x (left single quotation mark - 2018)"},
/* 275C */ { "HEAVY SINGLE COMMA QUOTATION MARK ORNAMENT","	x (right single quotation mark - 2019)"},
/* 275D */ { "HEAVY DOUBLE TURNED COMMA QUOTATION MARK ORNAMENT","	x (left double quotation mark - 201C)\n"
	"	x (sans-serif heavy double turned comma quotation mark ornament - 1F676)"},
/* 275E */ { "HEAVY DOUBLE COMMA QUOTATION MARK ORNAMENT","	x (right double quotation mark - 201D)\n"
	"	x (sans-serif heavy double comma quotation mark ornament - 1F677)"},
/* 275F */ { "HEAVY LOW SINGLE COMMA QUOTATION MARK ORNAMENT","	x (single low-9 quotation mark - 201A)"},
/* 2760 */ { "HEAVY LOW DOUBLE COMMA QUOTATION MARK ORNAMENT","	x (double low-9 quotation mark - 201E)\n"
	"	x (sans-serif heavy low double comma quotation mark ornament - 1F678)"},
/* 2761 */ { "CURVED STEM PARAGRAPH SIGN ORNAMENT","	x (pilcrow sign - 00B6)"},
/* 2762 */ { "HEAVY EXCLAMATION MARK ORNAMENT","	x (exclamation mark - 0021)"},
/* 2763 */ { "HEAVY HEART EXCLAMATION MARK ORNAMENT",NULL},
/* 2764 */ { "HEAVY BLACK HEART","	* displayed with a red color when used in emoji style\n"
	"	x (black heart suit - 2665)\n"
	"	x (black heart - 1F5A4)\n"
	"	x (white heart - 1F90D)"},
/* 2765 */ { "ROTATED HEAVY BLACK HEART BULLET",NULL},
/* 2766 */ { "FLORAL HEART","	= Aldus leaf"},
/* 2767 */ { "ROTATED FLORAL HEART BULLET","	= hedera, ivy leaf\n"
	"	x (reversed rotated floral heart bullet - 2619)\n"
	"	x (south east pointing vine leaf - 1F65B)"},
/* 2768 */ { "MEDIUM LEFT PARENTHESIS ORNAMENT","	x (left parenthesis - 0028)"},
/* 2769 */ { "MEDIUM RIGHT PARENTHESIS ORNAMENT","	x (right parenthesis - 0029)"},
/* 276A */ { "MEDIUM FLATTENED LEFT PARENTHESIS ORNAMENT",NULL},
/* 276B */ { "MEDIUM FLATTENED RIGHT PARENTHESIS ORNAMENT",NULL},
/* 276C */ { "MEDIUM LEFT-POINTING ANGLE BRACKET ORNAMENT","	x (left-pointing angle bracket - 2329)"},
/* 276D */ { "MEDIUM RIGHT-POINTING ANGLE BRACKET ORNAMENT","	x (right-pointing angle bracket - 232A)"},
/* 276E */ { "HEAVY LEFT-POINTING ANGLE QUOTATION MARK ORNAMENT","	x (single left-pointing angle quotation mark - 2039)"},
/* 276F */ { "HEAVY RIGHT-POINTING ANGLE QUOTATION MARK ORNAMENT","	x (single right-pointing angle quotation mark - 203A)"},
/* 2770 */ { "HEAVY LEFT-POINTING ANGLE BRACKET ORNAMENT",NULL},
/* 2771 */ { "HEAVY RIGHT-POINTING ANGLE BRACKET ORNAMENT",NULL},
/* 2772 */ { "LIGHT LEFT TORTOISE SHELL BRACKET ORNAMENT","	x (left tortoise shell bracket - 3014)"},
/* 2773 */ { "LIGHT RIGHT TORTOISE SHELL BRACKET ORNAMENT","	x (right tortoise shell bracket - 3015)"},
/* 2774 */ { "MEDIUM LEFT CURLY BRACKET ORNAMENT","	x (left curly bracket - 007B)"},
/* 2775 */ { "MEDIUM RIGHT CURLY BRACKET ORNAMENT","	x (right curly bracket - 007D)"},
/* 2776 */ { "DINGBAT NEGATIVE CIRCLED DIGIT ONE",NULL},
/* 2777 */ { "DINGBAT NEGATIVE CIRCLED DIGIT TWO",NULL},
/* 2778 */ { "DINGBAT NEGATIVE CIRCLED DIGIT THREE",NULL},
/* 2779 */ { "DINGBAT NEGATIVE CIRCLED DIGIT FOUR",NULL},
/* 277A */ { "DINGBAT NEGATIVE CIRCLED DIGIT FIVE",NULL},
/* 277B */ { "DINGBAT NEGATIVE CIRCLED DIGIT SIX",NULL},
/* 277C */ { "DINGBAT NEGATIVE CIRCLED DIGIT SEVEN",NULL},
/* 277D */ { "DINGBAT NEGATIVE CIRCLED DIGIT EIGHT",NULL},
/* 277E */ { "DINGBAT NEGATIVE CIRCLED DIGIT NINE",NULL},
/* 277F */ { "DINGBAT NEGATIVE CIRCLED NUMBER TEN",NULL},
/* 2780 */ { "DINGBAT CIRCLED SANS-SERIF DIGIT ONE",NULL},
/* 2781 */ { "DINGBAT CIRCLED SANS-SERIF DIGIT TWO",NULL},
/* 2782 */ { "DINGBAT CIRCLED SANS-SERIF DIGIT THREE",NULL},
/* 2783 */ { "DINGBAT CIRCLED SANS-SERIF DIGIT FOUR",NULL},
/* 2784 */ { "DINGBAT CIRCLED SANS-SERIF DIGIT FIVE",NULL},
/* 2785 */ { "DINGBAT CIRCLED SANS-SERIF DIGIT SIX",NULL},
/* 2786 */ { "DINGBAT CIRCLED SANS-SERIF DIGIT SEVEN",NULL},
/* 2787 */ { "DINGBAT CIRCLED SANS-SERIF DIGIT EIGHT",NULL},
/* 2788 */ { "DINGBAT CIRCLED SANS-SERIF DIGIT NINE",NULL},
/* 2789 */ { "DINGBAT CIRCLED SANS-SERIF NUMBER TEN",NULL},
/* 278A */ { "DINGBAT NEGATIVE CIRCLED SANS-SERIF DIGIT ONE",NULL},
/* 278B */ { "DINGBAT NEGATIVE CIRCLED SANS-SERIF DIGIT TWO",NULL},
/* 278C */ { "DINGBAT NEGATIVE CIRCLED SANS-SERIF DIGIT THREE",NULL},
/* 278D */ { "DINGBAT NEGATIVE CIRCLED SANS-SERIF DIGIT FOUR",NULL},
/* 278E */ { "DINGBAT NEGATIVE CIRCLED SANS-SERIF DIGIT FIVE",NULL},
/* 278F */ { "DINGBAT NEGATIVE CIRCLED SANS-SERIF DIGIT SIX",NULL},
/* 2790 */ { "DINGBAT NEGATIVE CIRCLED SANS-SERIF DIGIT SEVEN",NULL},
/* 2791 */ { "DINGBAT NEGATIVE CIRCLED SANS-SERIF DIGIT EIGHT",NULL},
/* 2792 */ { "DINGBAT NEGATIVE CIRCLED SANS-SERIF DIGIT NINE",NULL},
/* 2793 */ { "DINGBAT NEGATIVE CIRCLED SANS-SERIF NUMBER TEN",NULL},
/* 2794 */ { "HEAVY WIDE-HEADED RIGHTWARDS ARROW","	x (wide-headed rightwards medium barb arrow - 1F872)"},
/* 2795 */ { "HEAVY PLUS SIGN","	x (plus sign - 002B)"},
/* 2796 */ { "HEAVY MINUS SIGN","	x (minus sign - 2212)"},
/* 2797 */ { "HEAVY DIVISION SIGN","	x (division sign - 00F7)"},
/* 2798 */ { "HEAVY SOUTH EAST ARROW",NULL},
/* 2799 */ { "HEAVY RIGHTWARDS ARROW",NULL},
/* 279A */ { "HEAVY NORTH EAST ARROW",NULL},
/* 279B */ { "DRAFTING POINT RIGHTWARDS ARROW",NULL},
/* 279C */ { "HEAVY ROUND-TIPPED RIGHTWARDS ARROW",NULL},
/* 279D */ { "TRIANGLE-HEADED RIGHTWARDS ARROW",NULL},
/* 279E */ { "HEAVY TRIANGLE-HEADED RIGHTWARDS ARROW",NULL},
/* 279F */ { "DASHED TRIANGLE-HEADED RIGHTWARDS ARROW",NULL},
/* 27A0 */ { "HEAVY DASHED TRIANGLE-HEADED RIGHTWARDS ARROW",NULL},
/* 27A1 */ { "BLACK RIGHTWARDS ARROW","	* fonts may harmonize this glyph with the style for other black arrows\n"
	"	x (leftwards black arrow - 2B05)\n"
	"	x (rightwards black arrow - 2B95)"},
/* 27A2 */ { "THREE-D TOP-LIGHTED RIGHTWARDS ARROWHEAD","	x (three-d top-lighted rightwards equilateral arrowhead - 2B9A)"},
/* 27A3 */ { "THREE-D BOTTOM-LIGHTED RIGHTWARDS ARROWHEAD",NULL},
/* 27A4 */ { "BLACK RIGHTWARDS ARROWHEAD","	x (black rightwards equilateral arrowhead - 2B9E)\n"
	"	x (arrowhead-shaped pointer - 1FBB0)"},
/* 27A5 */ { "HEAVY BLACK CURVED DOWNWARDS AND RIGHTWARDS ARROW","	x (black curved downwards and rightwards arrow - 2BA9)"},
/* 27A6 */ { "HEAVY BLACK CURVED UPWARDS AND RIGHTWARDS ARROW","	x (black curved upwards and rightwards arrow - 2BAB)"},
/* 27A7 */ { "SQUAT BLACK RIGHTWARDS ARROW","	x (rightwards heavy compressed arrow - 1F842)"},
/* 27A8 */ { "HEAVY CONCAVE-POINTED BLACK RIGHTWARDS ARROW",NULL},
/* 27A9 */ { "RIGHT-SHADED WHITE RIGHTWARDS ARROW","	x (rightwards right-shaded white arrow - 1F8A5)"},
/* 27AA */ { "LEFT-SHADED WHITE RIGHTWARDS ARROW","	x (rightwards left-shaded white arrow - 1F8A7)"},
/* 27AB */ { "BACK-TILTED SHADOWED WHITE RIGHTWARDS ARROW","	x (rightwards back-tilted shadowed white arrow - 1F8A9)"},
/* 27AC */ { "FRONT-TILTED SHADOWED WHITE RIGHTWARDS ARROW","	x (rightwards front-tilted shadowed white arrow - 1F8AB)"},
/* 27AD */ { "HEAVY LOWER RIGHT-SHADOWED WHITE RIGHTWARDS ARROW",NULL},
/* 27AE */ { "HEAVY UPPER RIGHT-SHADOWED WHITE RIGHTWARDS ARROW",NULL},
/* 27AF */ { "NOTCHED LOWER RIGHT-SHADOWED WHITE RIGHTWARDS ARROW","	x (rightwards arrow with notched tail - 1F89A)"},
/* 27B0 */ { "CURLY LOOP","	= kururi"},
/* 27B1 */ { "NOTCHED UPPER RIGHT-SHADOWED WHITE RIGHTWARDS ARROW",NULL},
/* 27B2 */ { "CIRCLED HEAVY WHITE RIGHTWARDS ARROW",NULL},
/* 27B3 */ { "WHITE-FEATHERED RIGHTWARDS ARROW",NULL},
/* 27B4 */ { "BLACK-FEATHERED SOUTH EAST ARROW",NULL},
/* 27B5 */ { "BLACK-FEATHERED RIGHTWARDS ARROW",NULL},
/* 27B6 */ { "BLACK-FEATHERED NORTH EAST ARROW",NULL},
/* 27B7 */ { "HEAVY BLACK-FEATHERED SOUTH EAST ARROW",NULL},
/* 27B8 */ { "HEAVY BLACK-FEATHERED RIGHTWARDS ARROW",NULL},
/* 27B9 */ { "HEAVY BLACK-FEATHERED NORTH EAST ARROW",NULL},
/* 27BA */ { "TEARDROP-BARBED RIGHTWARDS ARROW",NULL},
/* 27BB */ { "HEAVY TEARDROP-SHANKED RIGHTWARDS ARROW",NULL},
/* 27BC */ { "WEDGE-TAILED RIGHTWARDS ARROW",NULL},
/* 27BD */ { "HEAVY WEDGE-TAILED RIGHTWARDS ARROW",NULL},
/* 27BE */ { "OPEN-OUTLINED RIGHTWARDS ARROW",NULL},
/* 27BF */ { "DOUBLE CURLY LOOP",NULL},
/* 27C0 */ { "THREE DIMENSIONAL ANGLE","	* used by Euclid"},
/* 27C1 */ { "WHITE TRIANGLE CONTAINING SMALL WHITE TRIANGLE","	* used by Euclid"},
/* 27C2 */ { "PERPENDICULAR","	= orthogonal to\n"
	"	* relation, typeset with additional spacing\n"
	"	x (up tack - 22A5)"},
/* 27C3 */ { "OPEN SUBSET",NULL},
/* 27C4 */ { "OPEN SUPERSET",NULL},
/* 27C5 */ { "LEFT S-SHAPED BAG DELIMITER",NULL},
/* 27C6 */ { "RIGHT S-SHAPED BAG DELIMITER",NULL},
/* 27C7 */ { "OR WITH DOT INSIDE","	x (logical or - 2228)\n"
	"	x (multiset multiplication - 228D)\n"
	"	x (and with dot - 27D1)"},
/* 27C8 */ { "REVERSE SOLIDUS PRECEDING SUBSET",NULL},
/* 27C9 */ { "SUPERSET PRECEDING SOLIDUS",NULL},
/* 27CA */ { "VERTICAL BAR WITH HORIZONTAL STROKE","	x (parallel with horizontal stroke - 2AF2)\n"
	"	x (triple vertical bar with horizontal stroke - 2AF5)"},
/* 27CB */ { "MATHEMATICAL RISING DIAGONAL","	= \\diagup\n"
	"	x (division slash - 2215)"},
/* 27CC */ { "LONG DIVISION","	* graphically extends over the dividend\n"
	"	x (division sign - 00F7)\n"
	"	x (division slash - 2215)\n"
	"	x (square root - 221A)"},
/* 27CD */ { "MATHEMATICAL FALLING DIAGONAL","	= \\diagdown\n"
	"	x (set minus - 2216)\n"
	"	x (reverse solidus operator - 29F5)"},
/* 27CE */ { "SQUARED LOGICAL AND","	= box min\n"
	"	* morphological min product operator\n"
	"	* morphological erosion operator\n"
	"	* additive minimum operator"},
/* 27CF */ { "SQUARED LOGICAL OR","	= box max\n"
	"	* morphological max product operator\n"
	"	* morphological dilation operator\n"
	"	* additive maximum operator"},
/* 27D0 */ { "WHITE DIAMOND WITH CENTRED DOT","	x (diamond shape with a dot inside - 1F4A0)"},
/* 27D1 */ { "AND WITH DOT","	x (logical and - 2227)\n"
	"	x (or with dot inside - 27C7)\n"
	"	x (intersection with dot - 2A40)"},
/* 27D2 */ { "ELEMENT OF OPENING UPWARDS","	x (element of opening downwards - 2AD9)"},
/* 27D3 */ { "LOWER RIGHT CORNER WITH DOT","	= pullback\n"
	"	x (right floor - 230B)"},
/* 27D4 */ { "UPPER LEFT CORNER WITH DOT","	= pushout\n"
	"	x (left ceiling - 2308)"},
/* 27D5 */ { "LEFT OUTER JOIN",NULL},
/* 27D6 */ { "RIGHT OUTER JOIN",NULL},
/* 27D7 */ { "FULL OUTER JOIN","	x (join - 2A1D)"},
/* 27D8 */ { "LARGE UP TACK","	x (up tack - 22A5)"},
/* 27D9 */ { "LARGE DOWN TACK","	x (down tack - 22A4)"},
/* 27DA */ { "LEFT AND RIGHT DOUBLE TURNSTILE","	x (true - 22A8)\n"
	"	x (vertical bar double left turnstile - 2AE4)"},
/* 27DB */ { "LEFT AND RIGHT TACK","	x (right tack - 22A2)"},
/* 27DC */ { "LEFT MULTIMAP","	x (multimap - 22B8)"},
/* 27DD */ { "LONG RIGHT TACK","	x (right tack - 22A2)"},
/* 27DE */ { "LONG LEFT TACK","	x (left tack - 22A3)"},
/* 27DF */ { "UP TACK WITH CIRCLE ABOVE","	= radial component\n"
	"	x (down tack with circle below - 2AF1)"},
/* 27E0 */ { "LOZENGE DIVIDED BY HORIZONTAL RULE","	* used as form of possibility in modal logic\n"
	"	x (lozenge - 25CA)"},
/* 27E1 */ { "WHITE CONCAVE-SIDED DIAMOND","	= never (modal operator)\n"
	"	x (white diamond - 25C7)"},
/* 27E2 */ { "WHITE CONCAVE-SIDED DIAMOND WITH LEFTWARDS TICK","	= was never (modal operator)"},
/* 27E3 */ { "WHITE CONCAVE-SIDED DIAMOND WITH RIGHTWARDS TICK","	= will never be (modal operator)"},
/* 27E4 */ { "WHITE SQUARE WITH LEFTWARDS TICK","	= was always (modal operator)\n"
	"	x (white square - 25A1)\n"
	"	x (white medium square - 25FB)"},
/* 27E5 */ { "WHITE SQUARE WITH RIGHTWARDS TICK","	= will always be (modal operator)"},
/* 27E6 */ { "MATHEMATICAL LEFT WHITE SQUARE BRACKET","	= z notation left bag bracket\n"
	"	x (left white square bracket - 301A)"},
/* 27E7 */ { "MATHEMATICAL RIGHT WHITE SQUARE BRACKET","	= z notation right bag bracket\n"
	"	x (right white square bracket - 301B)"},
/* 27E8 */ { "MATHEMATICAL LEFT ANGLE BRACKET","	= bra\n"
	"	= z notation left sequence bracket\n"
	"	x (left-pointing angle bracket - 2329)\n"
	"	x (left angle bracket - 3008)"},
/* 27E9 */ { "MATHEMATICAL RIGHT ANGLE BRACKET","	= ket\n"
	"	= z notation right sequence bracket\n"
	"	x (right-pointing angle bracket - 232A)\n"
	"	x (right angle bracket - 3009)"},
/* 27EA */ { "MATHEMATICAL LEFT DOUBLE ANGLE BRACKET","	= z notation left chevron bracket\n"
	"	x (left double angle bracket - 300A)"},
/* 27EB */ { "MATHEMATICAL RIGHT DOUBLE ANGLE BRACKET","	= z notation right chevron bracket\n"
	"	x (right double angle bracket - 300B)"},
/* 27EC */ { "MATHEMATICAL LEFT WHITE TORTOISE SHELL BRACKET","	x (left black tortoise shell bracket - 2997)\n"
	"	x (left white tortoise shell bracket - 3018)"},
/* 27ED */ { "MATHEMATICAL RIGHT WHITE TORTOISE SHELL BRACKET","	x (right black tortoise shell bracket - 2998)\n"
	"	x (right white tortoise shell bracket - 3019)"},
/* 27EE */ { "MATHEMATICAL LEFT FLATTENED PARENTHESIS","	= lgroup"},
/* 27EF */ { "MATHEMATICAL RIGHT FLATTENED PARENTHESIS","	= rgroup"},
/* 27F0 */ { "UPWARDS QUADRUPLE ARROW","	x (upwards triple arrow - 290A)\n"
	"	x (leftwards quadruple arrow - 2B45)"},
/* 27F1 */ { "DOWNWARDS QUADRUPLE ARROW","	x (downwards triple arrow - 290B)"},
/* 27F2 */ { "ANTICLOCKWISE GAPPED CIRCLE ARROW","	x (anticlockwise open circle arrow - 21BA)\n"
	"	x (anticlockwise closed circle arrow - 2940)"},
/* 27F3 */ { "CLOCKWISE GAPPED CIRCLE ARROW","	x (clockwise open circle arrow - 21BB)\n"
	"	x (clockwise closed circle arrow - 2941)"},
/* 27F4 */ { "RIGHT ARROW WITH CIRCLED PLUS","	x (left arrow with circled plus - 2B32)"},
/* 27F5 */ { "LONG LEFTWARDS ARROW","	x (leftwards arrow - 2190)"},
/* 27F6 */ { "LONG RIGHTWARDS ARROW","	x (rightwards arrow - 2192)"},
/* 27F7 */ { "LONG LEFT RIGHT ARROW","	x (left right arrow - 2194)"},
/* 27F8 */ { "LONG LEFTWARDS DOUBLE ARROW","	x (leftwards double arrow - 21D0)"},
/* 27F9 */ { "LONG RIGHTWARDS DOUBLE ARROW","	x (rightwards double arrow - 21D2)"},
/* 27FA */ { "LONG LEFT RIGHT DOUBLE ARROW","	x (left right double arrow - 21D4)"},
/* 27FB */ { "LONG LEFTWARDS ARROW FROM BAR","	= maps from\n"
	"	x (leftwards arrow from bar - 21A4)"},
/* 27FC */ { "LONG RIGHTWARDS ARROW FROM BAR","	= maps to\n"
	"	x (rightwards arrow from bar - 21A6)"},
/* 27FD */ { "LONG LEFTWARDS DOUBLE ARROW FROM BAR","	x (leftwards double arrow from bar - 2906)"},
/* 27FE */ { "LONG RIGHTWARDS DOUBLE ARROW FROM BAR","	x (rightwards double arrow from bar - 2907)"},
/* 27FF */ { "LONG RIGHTWARDS SQUIGGLE ARROW","	x (rightwards squiggle arrow - 21DD)\n"
	"	x (long leftwards squiggle arrow - 2B33)"}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_00_28[] = {
/* 2800 */ { "BRAILLE PATTERN BLANK","	* while this character is imaged as a fixed-width blank in many fonts, it does not act as a space"},
/* 2801 */ { "BRAILLE PATTERN DOTS-1",NULL},
/* 2802 */ { "BRAILLE PATTERN DOTS-2",NULL},
/* 2803 */ { "BRAILLE PATTERN DOTS-12",NULL},
/* 2804 */ { "BRAILLE PATTERN DOTS-3",NULL},
/* 2805 */ { "BRAILLE PATTERN DOTS-13",NULL},
/* 2806 */ { "BRAILLE PATTERN DOTS-23",NULL},
/* 2807 */ { "BRAILLE PATTERN DOTS-123",NULL},
/* 2808 */ { "BRAILLE PATTERN DOTS-4",NULL},
/* 2809 */ { "BRAILLE PATTERN DOTS-14",NULL},
/* 280A */ { "BRAILLE PATTERN DOTS-24",NULL},
/* 280B */ { "BRAILLE PATTERN DOTS-124",NULL},
/* 280C */ { "BRAILLE PATTERN DOTS-34",NULL},
/* 280D */ { "BRAILLE PATTERN DOTS-134",NULL},
/* 280E */ { "BRAILLE PATTERN DOTS-234",NULL},
/* 280F */ { "BRAILLE PATTERN DOTS-1234",NULL},
/* 2810 */ { "BRAILLE PATTERN DOTS-5",NULL},
/* 2811 */ { "BRAILLE PATTERN DOTS-15",NULL},
/* 2812 */ { "BRAILLE PATTERN DOTS-25",NULL},
/* 2813 */ { "BRAILLE PATTERN DOTS-125",NULL},
/* 2814 */ { "BRAILLE PATTERN DOTS-35",NULL},
/* 2815 */ { "BRAILLE PATTERN DOTS-135",NULL},
/* 2816 */ { "BRAILLE PATTERN DOTS-235",NULL},
/* 2817 */ { "BRAILLE PATTERN DOTS-1235",NULL},
/* 2818 */ { "BRAILLE PATTERN DOTS-45",NULL},
/* 2819 */ { "BRAILLE PATTERN DOTS-145",NULL},
/* 281A */ { "BRAILLE PATTERN DOTS-245",NULL},
/* 281B */ { "BRAILLE PATTERN DOTS-1245",NULL},
/* 281C */ { "BRAILLE PATTERN DOTS-345",NULL},
/* 281D */ { "BRAILLE PATTERN DOTS-1345",NULL},
/* 281E */ { "BRAILLE PATTERN DOTS-2345",NULL},
/* 281F */ { "BRAILLE PATTERN DOTS-12345",NULL},
/* 2820 */ { "BRAILLE PATTERN DOTS-6",NULL},
/* 2821 */ { "BRAILLE PATTERN DOTS-16",NULL},
/* 2822 */ { "BRAILLE PATTERN DOTS-26",NULL},
/* 2823 */ { "BRAILLE PATTERN DOTS-126",NULL},
/* 2824 */ { "BRAILLE PATTERN DOTS-36",NULL},
/* 2825 */ { "BRAILLE PATTERN DOTS-136",NULL},
/* 2826 */ { "BRAILLE PATTERN DOTS-236",NULL},
/* 2827 */ { "BRAILLE PATTERN DOTS-1236",NULL},
/* 2828 */ { "BRAILLE PATTERN DOTS-46",NULL},
/* 2829 */ { "BRAILLE PATTERN DOTS-146",NULL},
/* 282A */ { "BRAILLE PATTERN DOTS-246",NULL},
/* 282B */ { "BRAILLE PATTERN DOTS-1246",NULL},
/* 282C */ { "BRAILLE PATTERN DOTS-346",NULL},
/* 282D */ { "BRAILLE PATTERN DOTS-1346",NULL},
/* 282E */ { "BRAILLE PATTERN DOTS-2346",NULL},
/* 282F */ { "BRAILLE PATTERN DOTS-12346",NULL},
/* 2830 */ { "BRAILLE PATTERN DOTS-56",NULL},
/* 2831 */ { "BRAILLE PATTERN DOTS-156",NULL},
/* 2832 */ { "BRAILLE PATTERN DOTS-256",NULL},
/* 2833 */ { "BRAILLE PATTERN DOTS-1256",NULL},
/* 2834 */ { "BRAILLE PATTERN DOTS-356",NULL},
/* 2835 */ { "BRAILLE PATTERN DOTS-1356",NULL},
/* 2836 */ { "BRAILLE PATTERN DOTS-2356",NULL},
/* 2837 */ { "BRAILLE PATTERN DOTS-12356",NULL},
/* 2838 */ { "BRAILLE PATTERN DOTS-456",NULL},
/* 2839 */ { "BRAILLE PATTERN DOTS-1456",NULL},
/* 283A */ { "BRAILLE PATTERN DOTS-2456",NULL},
/* 283B */ { "BRAILLE PATTERN DOTS-12456",NULL},
/* 283C */ { "BRAILLE PATTERN DOTS-3456",NULL},
/* 283D */ { "BRAILLE PATTERN DOTS-13456",NULL},
/* 283E */ { "BRAILLE PATTERN DOTS-23456",NULL},
/* 283F */ { "BRAILLE PATTERN DOTS-123456",NULL},
/* 2840 */ { "BRAILLE PATTERN DOTS-7",NULL},
/* 2841 */ { "BRAILLE PATTERN DOTS-17",NULL},
/* 2842 */ { "BRAILLE PATTERN DOTS-27",NULL},
/* 2843 */ { "BRAILLE PATTERN DOTS-127",NULL},
/* 2844 */ { "BRAILLE PATTERN DOTS-37",NULL},
/* 2845 */ { "BRAILLE PATTERN DOTS-137",NULL},
/* 2846 */ { "BRAILLE PATTERN DOTS-237",NULL},
/* 2847 */ { "BRAILLE PATTERN DOTS-1237",NULL},
/* 2848 */ { "BRAILLE PATTERN DOTS-47",NULL},
/* 2849 */ { "BRAILLE PATTERN DOTS-147",NULL},
/* 284A */ { "BRAILLE PATTERN DOTS-247",NULL},
/* 284B */ { "BRAILLE PATTERN DOTS-1247",NULL},
/* 284C */ { "BRAILLE PATTERN DOTS-347",NULL},
/* 284D */ { "BRAILLE PATTERN DOTS-1347",NULL},
/* 284E */ { "BRAILLE PATTERN DOTS-2347",NULL},
/* 284F */ { "BRAILLE PATTERN DOTS-12347",NULL},
/* 2850 */ { "BRAILLE PATTERN DOTS-57",NULL},
/* 2851 */ { "BRAILLE PATTERN DOTS-157",NULL},
/* 2852 */ { "BRAILLE PATTERN DOTS-257",NULL},
/* 2853 */ { "BRAILLE PATTERN DOTS-1257",NULL},
/* 2854 */ { "BRAILLE PATTERN DOTS-357",NULL},
/* 2855 */ { "BRAILLE PATTERN DOTS-1357",NULL},
/* 2856 */ { "BRAILLE PATTERN DOTS-2357",NULL},
/* 2857 */ { "BRAILLE PATTERN DOTS-12357",NULL},
/* 2858 */ { "BRAILLE PATTERN DOTS-457",NULL},
/* 2859 */ { "BRAILLE PATTERN DOTS-1457",NULL},
/* 285A */ { "BRAILLE PATTERN DOTS-2457",NULL},
/* 285B */ { "BRAILLE PATTERN DOTS-12457",NULL},
/* 285C */ { "BRAILLE PATTERN DOTS-3457",NULL},
/* 285D */ { "BRAILLE PATTERN DOTS-13457",NULL},
/* 285E */ { "BRAILLE PATTERN DOTS-23457",NULL},
/* 285F */ { "BRAILLE PATTERN DOTS-123457",NULL},
/* 2860 */ { "BRAILLE PATTERN DOTS-67",NULL},
/* 2861 */ { "BRAILLE PATTERN DOTS-167",NULL},
/* 2862 */ { "BRAILLE PATTERN DOTS-267",NULL},
/* 2863 */ { "BRAILLE PATTERN DOTS-1267",NULL},
/* 2864 */ { "BRAILLE PATTERN DOTS-367",NULL},
/* 2865 */ { "BRAILLE PATTERN DOTS-1367",NULL},
/* 2866 */ { "BRAILLE PATTERN DOTS-2367",NULL},
/* 2867 */ { "BRAILLE PATTERN DOTS-12367",NULL},
/* 2868 */ { "BRAILLE PATTERN DOTS-467",NULL},
/* 2869 */ { "BRAILLE PATTERN DOTS-1467",NULL},
/* 286A */ { "BRAILLE PATTERN DOTS-2467",NULL},
/* 286B */ { "BRAILLE PATTERN DOTS-12467",NULL},
/* 286C */ { "BRAILLE PATTERN DOTS-3467",NULL},
/* 286D */ { "BRAILLE PATTERN DOTS-13467",NULL},
/* 286E */ { "BRAILLE PATTERN DOTS-23467",NULL},
/* 286F */ { "BRAILLE PATTERN DOTS-123467",NULL},
/* 2870 */ { "BRAILLE PATTERN DOTS-567",NULL},
/* 2871 */ { "BRAILLE PATTERN DOTS-1567",NULL},
/* 2872 */ { "BRAILLE PATTERN DOTS-2567",NULL},
/* 2873 */ { "BRAILLE PATTERN DOTS-12567",NULL},
/* 2874 */ { "BRAILLE PATTERN DOTS-3567",NULL},
/* 2875 */ { "BRAILLE PATTERN DOTS-13567",NULL},
/* 2876 */ { "BRAILLE PATTERN DOTS-23567",NULL},
/* 2877 */ { "BRAILLE PATTERN DOTS-123567",NULL},
/* 2878 */ { "BRAILLE PATTERN DOTS-4567",NULL},
/* 2879 */ { "BRAILLE PATTERN DOTS-14567",NULL},
/* 287A */ { "BRAILLE PATTERN DOTS-24567",NULL},
/* 287B */ { "BRAILLE PATTERN DOTS-124567",NULL},
/* 287C */ { "BRAILLE PATTERN DOTS-34567",NULL},
/* 287D */ { "BRAILLE PATTERN DOTS-134567",NULL},
/* 287E */ { "BRAILLE PATTERN DOTS-234567",NULL},
/* 287F */ { "BRAILLE PATTERN DOTS-1234567",NULL},
/* 2880 */ { "BRAILLE PATTERN DOTS-8",NULL},
/* 2881 */ { "BRAILLE PATTERN DOTS-18",NULL},
/* 2882 */ { "BRAILLE PATTERN DOTS-28",NULL},
/* 2883 */ { "BRAILLE PATTERN DOTS-128",NULL},
/* 2884 */ { "BRAILLE PATTERN DOTS-38",NULL},
/* 2885 */ { "BRAILLE PATTERN DOTS-138",NULL},
/* 2886 */ { "BRAILLE PATTERN DOTS-238",NULL},
/* 2887 */ { "BRAILLE PATTERN DOTS-1238",NULL},
/* 2888 */ { "BRAILLE PATTERN DOTS-48",NULL},
/* 2889 */ { "BRAILLE PATTERN DOTS-148",NULL},
/* 288A */ { "BRAILLE PATTERN DOTS-248",NULL},
/* 288B */ { "BRAILLE PATTERN DOTS-1248",NULL},
/* 288C */ { "BRAILLE PATTERN DOTS-348",NULL},
/* 288D */ { "BRAILLE PATTERN DOTS-1348",NULL},
/* 288E */ { "BRAILLE PATTERN DOTS-2348",NULL},
/* 288F */ { "BRAILLE PATTERN DOTS-12348",NULL},
/* 2890 */ { "BRAILLE PATTERN DOTS-58",NULL},
/* 2891 */ { "BRAILLE PATTERN DOTS-158",NULL},
/* 2892 */ { "BRAILLE PATTERN DOTS-258",NULL},
/* 2893 */ { "BRAILLE PATTERN DOTS-1258",NULL},
/* 2894 */ { "BRAILLE PATTERN DOTS-358",NULL},
/* 2895 */ { "BRAILLE PATTERN DOTS-1358",NULL},
/* 2896 */ { "BRAILLE PATTERN DOTS-2358",NULL},
/* 2897 */ { "BRAILLE PATTERN DOTS-12358",NULL},
/* 2898 */ { "BRAILLE PATTERN DOTS-458",NULL},
/* 2899 */ { "BRAILLE PATTERN DOTS-1458",NULL},
/* 289A */ { "BRAILLE PATTERN DOTS-2458",NULL},
/* 289B */ { "BRAILLE PATTERN DOTS-12458",NULL},
/* 289C */ { "BRAILLE PATTERN DOTS-3458",NULL},
/* 289D */ { "BRAILLE PATTERN DOTS-13458",NULL},
/* 289E */ { "BRAILLE PATTERN DOTS-23458",NULL},
/* 289F */ { "BRAILLE PATTERN DOTS-123458",NULL},
/* 28A0 */ { "BRAILLE PATTERN DOTS-68",NULL},
/* 28A1 */ { "BRAILLE PATTERN DOTS-168",NULL},
/* 28A2 */ { "BRAILLE PATTERN DOTS-268",NULL},
/* 28A3 */ { "BRAILLE PATTERN DOTS-1268",NULL},
/* 28A4 */ { "BRAILLE PATTERN DOTS-368",NULL},
/* 28A5 */ { "BRAILLE PATTERN DOTS-1368",NULL},
/* 28A6 */ { "BRAILLE PATTERN DOTS-2368",NULL},
/* 28A7 */ { "BRAILLE PATTERN DOTS-12368",NULL},
/* 28A8 */ { "BRAILLE PATTERN DOTS-468",NULL},
/* 28A9 */ { "BRAILLE PATTERN DOTS-1468",NULL},
/* 28AA */ { "BRAILLE PATTERN DOTS-2468",NULL},
/* 28AB */ { "BRAILLE PATTERN DOTS-12468",NULL},
/* 28AC */ { "BRAILLE PATTERN DOTS-3468",NULL},
/* 28AD */ { "BRAILLE PATTERN DOTS-13468",NULL},
/* 28AE */ { "BRAILLE PATTERN DOTS-23468",NULL},
/* 28AF */ { "BRAILLE PATTERN DOTS-123468",NULL},
/* 28B0 */ { "BRAILLE PATTERN DOTS-568",NULL},
/* 28B1 */ { "BRAILLE PATTERN DOTS-1568",NULL},
/* 28B2 */ { "BRAILLE PATTERN DOTS-2568",NULL},
/* 28B3 */ { "BRAILLE PATTERN DOTS-12568",NULL},
/* 28B4 */ { "BRAILLE PATTERN DOTS-3568",NULL},
/* 28B5 */ { "BRAILLE PATTERN DOTS-13568",NULL},
/* 28B6 */ { "BRAILLE PATTERN DOTS-23568",NULL},
/* 28B7 */ { "BRAILLE PATTERN DOTS-123568",NULL},
/* 28B8 */ { "BRAILLE PATTERN DOTS-4568",NULL},
/* 28B9 */ { "BRAILLE PATTERN DOTS-14568",NULL},
/* 28BA */ { "BRAILLE PATTERN DOTS-24568",NULL},
/* 28BB */ { "BRAILLE PATTERN DOTS-124568",NULL},
/* 28BC */ { "BRAILLE PATTERN DOTS-34568",NULL},
/* 28BD */ { "BRAILLE PATTERN DOTS-134568",NULL},
/* 28BE */ { "BRAILLE PATTERN DOTS-234568",NULL},
/* 28BF */ { "BRAILLE PATTERN DOTS-1234568",NULL},
/* 28C0 */ { "BRAILLE PATTERN DOTS-78",NULL},
/* 28C1 */ { "BRAILLE PATTERN DOTS-178",NULL},
/* 28C2 */ { "BRAILLE PATTERN DOTS-278",NULL},
/* 28C3 */ { "BRAILLE PATTERN DOTS-1278",NULL},
/* 28C4 */ { "BRAILLE PATTERN DOTS-378",NULL},
/* 28C5 */ { "BRAILLE PATTERN DOTS-1378",NULL},
/* 28C6 */ { "BRAILLE PATTERN DOTS-2378",NULL},
/* 28C7 */ { "BRAILLE PATTERN DOTS-12378",NULL},
/* 28C8 */ { "BRAILLE PATTERN DOTS-478",NULL},
/* 28C9 */ { "BRAILLE PATTERN DOTS-1478",NULL},
/* 28CA */ { "BRAILLE PATTERN DOTS-2478",NULL},
/* 28CB */ { "BRAILLE PATTERN DOTS-12478",NULL},
/* 28CC */ { "BRAILLE PATTERN DOTS-3478",NULL},
/* 28CD */ { "BRAILLE PATTERN DOTS-13478",NULL},
/* 28CE */ { "BRAILLE PATTERN DOTS-23478",NULL},
/* 28CF */ { "BRAILLE PATTERN DOTS-123478",NULL},
/* 28D0 */ { "BRAILLE PATTERN DOTS-578",NULL},
/* 28D1 */ { "BRAILLE PATTERN DOTS-1578",NULL},
/* 28D2 */ { "BRAILLE PATTERN DOTS-2578",NULL},
/* 28D3 */ { "BRAILLE PATTERN DOTS-12578",NULL},
/* 28D4 */ { "BRAILLE PATTERN DOTS-3578",NULL},
/* 28D5 */ { "BRAILLE PATTERN DOTS-13578",NULL},
/* 28D6 */ { "BRAILLE PATTERN DOTS-23578",NULL},
/* 28D7 */ { "BRAILLE PATTERN DOTS-123578",NULL},
/* 28D8 */ { "BRAILLE PATTERN DOTS-4578",NULL},
/* 28D9 */ { "BRAILLE PATTERN DOTS-14578",NULL},
/* 28DA */ { "BRAILLE PATTERN DOTS-24578",NULL},
/* 28DB */ { "BRAILLE PATTERN DOTS-124578",NULL},
/* 28DC */ { "BRAILLE PATTERN DOTS-34578",NULL},
/* 28DD */ { "BRAILLE PATTERN DOTS-134578",NULL},
/* 28DE */ { "BRAILLE PATTERN DOTS-234578",NULL},
/* 28DF */ { "BRAILLE PATTERN DOTS-1234578",NULL},
/* 28E0 */ { "BRAILLE PATTERN DOTS-678",NULL},
/* 28E1 */ { "BRAILLE PATTERN DOTS-1678",NULL},
/* 28E2 */ { "BRAILLE PATTERN DOTS-2678",NULL},
/* 28E3 */ { "BRAILLE PATTERN DOTS-12678",NULL},
/* 28E4 */ { "BRAILLE PATTERN DOTS-3678",NULL},
/* 28E5 */ { "BRAILLE PATTERN DOTS-13678",NULL},
/* 28E6 */ { "BRAILLE PATTERN DOTS-23678",NULL},
/* 28E7 */ { "BRAILLE PATTERN DOTS-123678",NULL},
/* 28E8 */ { "BRAILLE PATTERN DOTS-4678",NULL},
/* 28E9 */ { "BRAILLE PATTERN DOTS-14678",NULL},
/* 28EA */ { "BRAILLE PATTERN DOTS-24678",NULL},
/* 28EB */ { "BRAILLE PATTERN DOTS-124678",NULL},
/* 28EC */ { "BRAILLE PATTERN DOTS-34678",NULL},
/* 28ED */ { "BRAILLE PATTERN DOTS-134678",NULL},
/* 28EE */ { "BRAILLE PATTERN DOTS-234678",NULL},
/* 28EF */ { "BRAILLE PATTERN DOTS-1234678",NULL},
/* 28F0 */ { "BRAILLE PATTERN DOTS-5678",NULL},
/* 28F1 */ { "BRAILLE PATTERN DOTS-15678",NULL},
/* 28F2 */ { "BRAILLE PATTERN DOTS-25678",NULL},
/* 28F3 */ { "BRAILLE PATTERN DOTS-125678",NULL},
/* 28F4 */ { "BRAILLE PATTERN DOTS-35678",NULL},
/* 28F5 */ { "BRAILLE PATTERN DOTS-135678",NULL},
/* 28F6 */ { "BRAILLE PATTERN DOTS-235678",NULL},
/* 28F7 */ { "BRAILLE PATTERN DOTS-1235678",NULL},
/* 28F8 */ { "BRAILLE PATTERN DOTS-45678",NULL},
/* 28F9 */ { "BRAILLE PATTERN DOTS-145678",NULL},
/* 28FA */ { "BRAILLE PATTERN DOTS-245678",NULL},
/* 28FB */ { "BRAILLE PATTERN DOTS-1245678",NULL},
/* 28FC */ { "BRAILLE PATTERN DOTS-345678",NULL},
/* 28FD */ { "BRAILLE PATTERN DOTS-1345678",NULL},
/* 28FE */ { "BRAILLE PATTERN DOTS-2345678",NULL},
/* 28FF */ { "BRAILLE PATTERN DOTS-12345678",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_00_29[] = {
/* 2900 */ { "RIGHTWARDS TWO-HEADED ARROW WITH VERTICAL STROKE","	= z notation partial surjection\n"
	"	x (leftwards two-headed arrow with vertical stroke - 2B34)"},
/* 2901 */ { "RIGHTWARDS TWO-HEADED ARROW WITH DOUBLE VERTICAL STROKE","	= z notation finite surjection\n"
	"	x (leftwards two-headed arrow with double vertical stroke - 2B35)"},
/* 2902 */ { "LEFTWARDS DOUBLE ARROW WITH VERTICAL STROKE",NULL},
/* 2903 */ { "RIGHTWARDS DOUBLE ARROW WITH VERTICAL STROKE",NULL},
/* 2904 */ { "LEFT RIGHT DOUBLE ARROW WITH VERTICAL STROKE",NULL},
/* 2905 */ { "RIGHTWARDS TWO-HEADED ARROW FROM BAR","	= maps to\n"
	"	x (leftwards two-headed arrow from bar - 2B36)"},
/* 2906 */ { "LEFTWARDS DOUBLE ARROW FROM BAR","	= maps from\n"
	"	x (long leftwards arrow from bar - 27FB)"},
/* 2907 */ { "RIGHTWARDS DOUBLE ARROW FROM BAR","	= maps to\n"
	"	x (long rightwards arrow from bar - 27FC)"},
/* 2908 */ { "DOWNWARDS ARROW WITH HORIZONTAL STROKE",NULL},
/* 2909 */ { "UPWARDS ARROW WITH HORIZONTAL STROKE",NULL},
/* 290A */ { "UPWARDS TRIPLE ARROW","	x (upwards double arrow - 21D1)\n"
	"	x (upwards quadruple arrow - 27F0)"},
/* 290B */ { "DOWNWARDS TRIPLE ARROW","	x (downwards double arrow - 21D3)\n"
	"	x (downwards quadruple arrow - 27F1)"},
/* 290C */ { "LEFTWARDS DOUBLE DASH ARROW",NULL},
/* 290D */ { "RIGHTWARDS DOUBLE DASH ARROW",NULL},
/* 290E */ { "LEFTWARDS TRIPLE DASH ARROW",NULL},
/* 290F */ { "RIGHTWARDS TRIPLE DASH ARROW",NULL},
/* 2910 */ { "RIGHTWARDS TWO-HEADED TRIPLE DASH ARROW","	x (leftwards two-headed triple dash arrow - 2B37)"},
/* 2911 */ { "RIGHTWARDS ARROW WITH DOTTED STEM","	x (leftwards arrow with dotted stem - 2B38)"},
/* 2912 */ { "UPWARDS ARROW TO BAR",NULL},
/* 2913 */ { "DOWNWARDS ARROW TO BAR",NULL},
/* 2914 */ { "RIGHTWARDS ARROW WITH TAIL WITH VERTICAL STROKE","	= z notation partial injection\n"
	"	x (leftwards arrow with tail with vertical stroke - 2B39)"},
/* 2915 */ { "RIGHTWARDS ARROW WITH TAIL WITH DOUBLE VERTICAL STROKE","	= z notation finite injection\n"
	"	x (leftwards arrow with tail with double vertical stroke - 2B3A)"},
/* 2916 */ { "RIGHTWARDS TWO-HEADED ARROW WITH TAIL","	= bijective mapping\n"
	"	= z notation bijection\n"
	"	x (leftwards two-headed arrow with tail - 2B3B)"},
/* 2917 */ { "RIGHTWARDS TWO-HEADED ARROW WITH TAIL WITH VERTICAL STROKE","	= z notation surjective injection\n"
	"	x (leftwards two-headed arrow with tail with vertical stroke - 2B3C)"},
/* 2918 */ { "RIGHTWARDS TWO-HEADED ARROW WITH TAIL WITH DOUBLE VERTICAL STROKE","	= z notation finite surjective injection\n"
	"	x (leftwards two-headed arrow with tail with double vertical stroke - 2B3D)"},
/* 2919 */ { "LEFTWARDS ARROW-TAIL",NULL},
/* 291A */ { "RIGHTWARDS ARROW-TAIL",NULL},
/* 291B */ { "LEFTWARDS DOUBLE ARROW-TAIL",NULL},
/* 291C */ { "RIGHTWARDS DOUBLE ARROW-TAIL",NULL},
/* 291D */ { "LEFTWARDS ARROW TO BLACK DIAMOND",NULL},
/* 291E */ { "RIGHTWARDS ARROW TO BLACK DIAMOND",NULL},
/* 291F */ { "LEFTWARDS ARROW FROM BAR TO BLACK DIAMOND",NULL},
/* 2920 */ { "RIGHTWARDS ARROW FROM BAR TO BLACK DIAMOND",NULL},
/* 2921 */ { "NORTH WEST AND SOUTH EAST ARROW",NULL},
/* 2922 */ { "NORTH EAST AND SOUTH WEST ARROW",NULL},
/* 2923 */ { "NORTH WEST ARROW WITH HOOK",NULL},
/* 2924 */ { "NORTH EAST ARROW WITH HOOK",NULL},
/* 2925 */ { "SOUTH EAST ARROW WITH HOOK",NULL},
/* 2926 */ { "SOUTH WEST ARROW WITH HOOK",NULL},
/* 2927 */ { "NORTH WEST ARROW AND NORTH EAST ARROW",NULL},
/* 2928 */ { "NORTH EAST ARROW AND SOUTH EAST ARROW",NULL},
/* 2929 */ { "SOUTH EAST ARROW AND SOUTH WEST ARROW",NULL},
/* 292A */ { "SOUTH WEST ARROW AND NORTH WEST ARROW",NULL},
/* 292B */ { "RISING DIAGONAL CROSSING FALLING DIAGONAL",NULL},
/* 292C */ { "FALLING DIAGONAL CROSSING RISING DIAGONAL","	x (crossing lanes - 26CC)"},
/* 292D */ { "SOUTH EAST ARROW CROSSING NORTH EAST ARROW",NULL},
/* 292E */ { "NORTH EAST ARROW CROSSING SOUTH EAST ARROW",NULL},
/* 292F */ { "FALLING DIAGONAL CROSSING NORTH EAST ARROW",NULL},
/* 2930 */ { "RISING DIAGONAL CROSSING SOUTH EAST ARROW",NULL},
/* 2931 */ { "NORTH EAST ARROW CROSSING NORTH WEST ARROW",NULL},
/* 2932 */ { "NORTH WEST ARROW CROSSING NORTH EAST ARROW",NULL},
/* 2933 */ { "WAVE ARROW POINTING DIRECTLY RIGHT","	x (rightwards wave arrow - 219D)\n"
	"	x (wave arrow pointing directly left - 2B3F)"},
/* 2934 */ { "ARROW POINTING RIGHTWARDS THEN CURVING UPWARDS",NULL},
/* 2935 */ { "ARROW POINTING RIGHTWARDS THEN CURVING DOWNWARDS",NULL},
/* 2936 */ { "ARROW POINTING DOWNWARDS THEN CURVING LEFTWARDS",NULL},
/* 2937 */ { "ARROW POINTING DOWNWARDS THEN CURVING RIGHTWARDS",NULL},
/* 2938 */ { "RIGHT-SIDE ARC CLOCKWISE ARROW",NULL},
/* 2939 */ { "LEFT-SIDE ARC ANTICLOCKWISE ARROW",NULL},
/* 293A */ { "TOP ARC ANTICLOCKWISE ARROW",NULL},
/* 293B */ { "BOTTOM ARC ANTICLOCKWISE ARROW",NULL},
/* 293C */ { "TOP ARC CLOCKWISE ARROW WITH MINUS",NULL},
/* 293D */ { "TOP ARC ANTICLOCKWISE ARROW WITH PLUS",NULL},
/* 293E */ { "LOWER RIGHT SEMICIRCULAR CLOCKWISE ARROW",NULL},
/* 293F */ { "LOWER LEFT SEMICIRCULAR ANTICLOCKWISE ARROW",NULL},
/* 2940 */ { "ANTICLOCKWISE CLOSED CIRCLE ARROW","	x (combining anticlockwise ring overlay - 20DA)"},
/* 2941 */ { "CLOCKWISE CLOSED CIRCLE ARROW","	x (combining clockwise ring overlay - 20D9)"},
/* 2942 */ { "RIGHTWARDS ARROW ABOVE SHORT LEFTWARDS ARROW",NULL},
/* 2943 */ { "LEFTWARDS ARROW ABOVE SHORT RIGHTWARDS ARROW",NULL},
/* 2944 */ { "SHORT RIGHTWARDS ARROW ABOVE LEFTWARDS ARROW",NULL},
/* 2945 */ { "RIGHTWARDS ARROW WITH PLUS BELOW",NULL},
/* 2946 */ { "LEFTWARDS ARROW WITH PLUS BELOW",NULL},
/* 2947 */ { "RIGHTWARDS ARROW THROUGH X","	x (leftwards arrow through x - 2B3E)"},
/* 2948 */ { "LEFT RIGHT ARROW THROUGH SMALL CIRCLE",NULL},
/* 2949 */ { "UPWARDS TWO-HEADED ARROW FROM SMALL CIRCLE",NULL},
/* 294A */ { "LEFT BARB UP RIGHT BARB DOWN HARPOON",NULL},
/* 294B */ { "LEFT BARB DOWN RIGHT BARB UP HARPOON",NULL},
/* 294C */ { "UP BARB RIGHT DOWN BARB LEFT HARPOON",NULL},
/* 294D */ { "UP BARB LEFT DOWN BARB RIGHT HARPOON",NULL},
/* 294E */ { "LEFT BARB UP RIGHT BARB UP HARPOON",NULL},
/* 294F */ { "UP BARB RIGHT DOWN BARB RIGHT HARPOON",NULL},
/* 2950 */ { "LEFT BARB DOWN RIGHT BARB DOWN HARPOON",NULL},
/* 2951 */ { "UP BARB LEFT DOWN BARB LEFT HARPOON",NULL},
/* 2952 */ { "LEFTWARDS HARPOON WITH BARB UP TO BAR",NULL},
/* 2953 */ { "RIGHTWARDS HARPOON WITH BARB UP TO BAR",NULL},
/* 2954 */ { "UPWARDS HARPOON WITH BARB RIGHT TO BAR",NULL},
/* 2955 */ { "DOWNWARDS HARPOON WITH BARB RIGHT TO BAR",NULL},
/* 2956 */ { "LEFTWARDS HARPOON WITH BARB DOWN TO BAR",NULL},
/* 2957 */ { "RIGHTWARDS HARPOON WITH BARB DOWN TO BAR",NULL},
/* 2958 */ { "UPWARDS HARPOON WITH BARB LEFT TO BAR",NULL},
/* 2959 */ { "DOWNWARDS HARPOON WITH BARB LEFT TO BAR",NULL},
/* 295A */ { "LEFTWARDS HARPOON WITH BARB UP FROM BAR",NULL},
/* 295B */ { "RIGHTWARDS HARPOON WITH BARB UP FROM BAR",NULL},
/* 295C */ { "UPWARDS HARPOON WITH BARB RIGHT FROM BAR",NULL},
/* 295D */ { "DOWNWARDS HARPOON WITH BARB RIGHT FROM BAR",NULL},
/* 295E */ { "LEFTWARDS HARPOON WITH BARB DOWN FROM BAR",NULL},
/* 295F */ { "RIGHTWARDS HARPOON WITH BARB DOWN FROM BAR",NULL},
/* 2960 */ { "UPWARDS HARPOON WITH BARB LEFT FROM BAR",NULL},
/* 2961 */ { "DOWNWARDS HARPOON WITH BARB LEFT FROM BAR",NULL},
/* 2962 */ { "LEFTWARDS HARPOON WITH BARB UP ABOVE LEFTWARDS HARPOON WITH BARB DOWN",NULL},
/* 2963 */ { "UPWARDS HARPOON WITH BARB LEFT BESIDE UPWARDS HARPOON WITH BARB RIGHT",NULL},
/* 2964 */ { "RIGHTWARDS HARPOON WITH BARB UP ABOVE RIGHTWARDS HARPOON WITH BARB DOWN",NULL},
/* 2965 */ { "DOWNWARDS HARPOON WITH BARB LEFT BESIDE DOWNWARDS HARPOON WITH BARB RIGHT",NULL},
/* 2966 */ { "LEFTWARDS HARPOON WITH BARB UP ABOVE RIGHTWARDS HARPOON WITH BARB UP",NULL},
/* 2967 */ { "LEFTWARDS HARPOON WITH BARB DOWN ABOVE RIGHTWARDS HARPOON WITH BARB DOWN",NULL},
/* 2968 */ { "RIGHTWARDS HARPOON WITH BARB UP ABOVE LEFTWARDS HARPOON WITH BARB UP",NULL},
/* 2969 */ { "RIGHTWARDS HARPOON WITH BARB DOWN ABOVE LEFTWARDS HARPOON WITH BARB DOWN",NULL},
/* 296A */ { "LEFTWARDS HARPOON WITH BARB UP ABOVE LONG DASH",NULL},
/* 296B */ { "LEFTWARDS HARPOON WITH BARB DOWN BELOW LONG DASH",NULL},
/* 296C */ { "RIGHTWARDS HARPOON WITH BARB UP ABOVE LONG DASH",NULL},
/* 296D */ { "RIGHTWARDS HARPOON WITH BARB DOWN BELOW LONG DASH",NULL},
/* 296E */ { "UPWARDS HARPOON WITH BARB LEFT BESIDE DOWNWARDS HARPOON WITH BARB RIGHT",NULL},
/* 296F */ { "DOWNWARDS HARPOON WITH BARB LEFT BESIDE UPWARDS HARPOON WITH BARB RIGHT",NULL},
/* 2970 */ { "RIGHT DOUBLE ARROW WITH ROUNDED HEAD","	x (superset of - 2283)"},
/* 2971 */ { "EQUALS SIGN ABOVE RIGHTWARDS ARROW","	x (equals sign above leftwards arrow - 2B40)"},
/* 2972 */ { "TILDE OPERATOR ABOVE RIGHTWARDS ARROW","	x (reverse tilde operator above leftwards arrow - 2B41)"},
/* 2973 */ { "LEFTWARDS ARROW ABOVE TILDE OPERATOR","	x (rightwards arrow above reverse tilde operator - 2B4C)"},
/* 2974 */ { "RIGHTWARDS ARROW ABOVE TILDE OPERATOR","	x (leftwards arrow above reverse tilde operator - 2B4B)"},
/* 2975 */ { "RIGHTWARDS ARROW ABOVE ALMOST EQUAL TO","	x (leftwards arrow above reverse almost equal to - 2B42)"},
/* 2976 */ { "LESS-THAN ABOVE LEFTWARDS ARROW",NULL},
/* 2977 */ { "LEFTWARDS ARROW THROUGH LESS-THAN","	x (rightwards arrow through greater-than - 2B43)"},
/* 2978 */ { "GREATER-THAN ABOVE RIGHTWARDS ARROW",NULL},
/* 2979 */ { "SUBSET ABOVE RIGHTWARDS ARROW",NULL},
/* 297A */ { "LEFTWARDS ARROW THROUGH SUBSET","	x (rightwards arrow through superset - 2B44)"},
/* 297B */ { "SUPERSET ABOVE LEFTWARDS ARROW",NULL},
/* 297C */ { "LEFT FISH TAIL",NULL},
/* 297D */ { "RIGHT FISH TAIL",NULL},
/* 297E */ { "UP FISH TAIL",NULL},
/* 297F */ { "DOWN FISH TAIL",NULL},
/* 2980 */ { "TRIPLE VERTICAL BAR DELIMITER","	x (triple vertical bar binary relation - 2AF4)\n"
	"	x (large triple vertical bar operator - 2AFC)"},
/* 2981 */ { "Z NOTATION SPOT","	* medium-small-sized black circle\n"
	"	x (bullet operator - 2219)\n"
	"	x (black circle - 25CF)"},
/* 2982 */ { "Z NOTATION TYPE COLON","	x (tibetan sign rnam bcad - 0F7F)"},
/* 2983 */ { "LEFT WHITE CURLY BRACKET",NULL},
/* 2984 */ { "RIGHT WHITE CURLY BRACKET",NULL},
/* 2985 */ { "LEFT WHITE PARENTHESIS","	x (left double parenthesis - 2E28)\n"
	"	x (fullwidth left white parenthesis - FF5F)"},
/* 2986 */ { "RIGHT WHITE PARENTHESIS","	* used for Bourbakist intervals\n"
	"	x (right double parenthesis - 2E29)\n"
	"	x (fullwidth right white parenthesis - FF60)"},
/* 2987 */ { "Z NOTATION LEFT IMAGE BRACKET",NULL},
/* 2988 */ { "Z NOTATION RIGHT IMAGE BRACKET",NULL},
/* 2989 */ { "Z NOTATION LEFT BINDING BRACKET",NULL},
/* 298A */ { "Z NOTATION RIGHT BINDING BRACKET",NULL},
/* 298B */ { "LEFT SQUARE BRACKET WITH UNDERBAR",NULL},
/* 298C */ { "RIGHT SQUARE BRACKET WITH UNDERBAR",NULL},
/* 298D */ { "LEFT SQUARE BRACKET WITH TICK IN TOP CORNER",NULL},
/* 298E */ { "RIGHT SQUARE BRACKET WITH TICK IN BOTTOM CORNER",NULL},
/* 298F */ { "LEFT SQUARE BRACKET WITH TICK IN BOTTOM CORNER",NULL},
/* 2990 */ { "RIGHT SQUARE BRACKET WITH TICK IN TOP CORNER",NULL},
/* 2991 */ { "LEFT ANGLE BRACKET WITH DOT",NULL},
/* 2992 */ { "RIGHT ANGLE BRACKET WITH DOT",NULL},
/* 2993 */ { "LEFT ARC LESS-THAN BRACKET",NULL},
/* 2994 */ { "RIGHT ARC GREATER-THAN BRACKET",NULL},
/* 2995 */ { "DOUBLE LEFT ARC GREATER-THAN BRACKET",NULL},
/* 2996 */ { "DOUBLE RIGHT ARC LESS-THAN BRACKET",NULL},
/* 2997 */ { "LEFT BLACK TORTOISE SHELL BRACKET","	x (mathematical left white tortoise shell bracket - 27EC)\n"
	"	x (left tortoise shell bracket - 3014)\n"
	"	x (left white tortoise shell bracket - 3018)"},
/* 2998 */ { "RIGHT BLACK TORTOISE SHELL BRACKET",NULL},
/* 2999 */ { "DOTTED FENCE","	* four close dots vertical"},
/* 299A */ { "VERTICAL ZIGZAG LINE","	x (wavy line - 2307)"},
/* 299B */ { "MEASURED ANGLE OPENING LEFT","	x (measured angle - 2221)"},
/* 299C */ { "RIGHT ANGLE VARIANT WITH SQUARE","	x (right angle - 221F)"},
/* 299D */ { "MEASURED RIGHT ANGLE WITH DOT",NULL},
/* 299E */ { "ANGLE WITH S INSIDE",NULL},
/* 299F */ { "ACUTE ANGLE","	x (angle - 2220)"},
/* 29A0 */ { "SPHERICAL ANGLE OPENING LEFT","	x (spherical angle - 2222)"},
/* 29A1 */ { "SPHERICAL ANGLE OPENING UP",NULL},
/* 29A2 */ { "TURNED ANGLE","	x (angle - 2220)"},
/* 29A3 */ { "REVERSED ANGLE",NULL},
/* 29A4 */ { "ANGLE WITH UNDERBAR",NULL},
/* 29A5 */ { "REVERSED ANGLE WITH UNDERBAR",NULL},
/* 29A6 */ { "OBLIQUE ANGLE OPENING UP",NULL},
/* 29A7 */ { "OBLIQUE ANGLE OPENING DOWN",NULL},
/* 29A8 */ { "MEASURED ANGLE WITH OPEN ARM ENDING IN ARROW POINTING UP AND RIGHT",NULL},
/* 29A9 */ { "MEASURED ANGLE WITH OPEN ARM ENDING IN ARROW POINTING UP AND LEFT",NULL},
/* 29AA */ { "MEASURED ANGLE WITH OPEN ARM ENDING IN ARROW POINTING DOWN AND RIGHT",NULL},
/* 29AB */ { "MEASURED ANGLE WITH OPEN ARM ENDING IN ARROW POINTING DOWN AND LEFT",NULL},
/* 29AC */ { "MEASURED ANGLE WITH OPEN ARM ENDING IN ARROW POINTING RIGHT AND UP",NULL},
/* 29AD */ { "MEASURED ANGLE WITH OPEN ARM ENDING IN ARROW POINTING LEFT AND UP",NULL},
/* 29AE */ { "MEASURED ANGLE WITH OPEN ARM ENDING IN ARROW POINTING RIGHT AND DOWN",NULL},
/* 29AF */ { "MEASURED ANGLE WITH OPEN ARM ENDING IN ARROW POINTING LEFT AND DOWN",NULL},
/* 29B0 */ { "REVERSED EMPTY SET","	x (empty set - 2205)\n"
	"	x (apl functional symbol circle backslash - 2349)"},
/* 29B1 */ { "EMPTY SET WITH OVERBAR",NULL},
/* 29B2 */ { "EMPTY SET WITH SMALL CIRCLE ABOVE",NULL},
/* 29B3 */ { "EMPTY SET WITH RIGHT ARROW ABOVE",NULL},
/* 29B4 */ { "EMPTY SET WITH LEFT ARROW ABOVE",NULL},
/* 29B5 */ { "CIRCLE WITH HORIZONTAL BAR","	x (circled minus - 2296)\n"
	"	x (medium small white circle with horizontal bar - 1CEF0)"},
/* 29B6 */ { "CIRCLED VERTICAL BAR","	x (alchemical symbol for nitre - 1F715)"},
/* 29B7 */ { "CIRCLED PARALLEL","	~ 29B7 FE00 with parallel lines touching the circle"},
/* 29B8 */ { "CIRCLED REVERSE SOLIDUS",NULL},
/* 29B9 */ { "CIRCLED PERPENDICULAR",NULL},
/* 29BA */ { "CIRCLE DIVIDED BY HORIZONTAL BAR AND TOP HALF DIVIDED BY VERTICAL BAR",NULL},
/* 29BB */ { "CIRCLE WITH SUPERIMPOSED X","	x (circled times - 2297)"},
/* 29BC */ { "CIRCLED ANTICLOCKWISE-ROTATED DIVISION SIGN",NULL},
/* 29BD */ { "UP ARROW THROUGH CIRCLE",NULL},
/* 29BE */ { "CIRCLED WHITE BULLET","	x (circled ring operator - 229A)\n"
	"	x (apl functional symbol circle jot - 233E)\n"
	"	x (bullseye - 25CE)"},
/* 29BF */ { "CIRCLED BULLET","	* forms part of a graduated set of circles with enclosed black circle of different sizes\n"
	"	x (circled dot operator - 2299)\n"
	"	x (fisheye - 25C9)\n"
	"	x (n-ary circled dot operator - 2A00)"},
/* 29C0 */ { "CIRCLED LESS-THAN",NULL},
/* 29C1 */ { "CIRCLED GREATER-THAN",NULL},
/* 29C2 */ { "CIRCLE WITH SMALL CIRCLE TO THE RIGHT",NULL},
/* 29C3 */ { "CIRCLE WITH TWO HORIZONTAL STROKES TO THE RIGHT",NULL},
/* 29C4 */ { "SQUARED RISING DIAGONAL SLASH","	x (apl functional symbol quad slash - 2341)\n"
	"	x (masu mark - 303C)"},
/* 29C5 */ { "SQUARED FALLING DIAGONAL SLASH","	x (apl functional symbol quad backslash - 2342)"},
/* 29C6 */ { "SQUARED ASTERISK",NULL},
/* 29C7 */ { "SQUARED SMALL CIRCLE","	x (apl functional symbol quad jot - 233B)"},
/* 29C8 */ { "SQUARED SQUARE",NULL},
/* 29C9 */ { "TWO JOINED SQUARES","	x (overlapping white squares - 2BBA)"},
/* 29CA */ { "TRIANGLE WITH DOT ABOVE",NULL},
/* 29CB */ { "TRIANGLE WITH UNDERBAR",NULL},
/* 29CC */ { "S IN TRIANGLE",NULL},
/* 29CD */ { "TRIANGLE WITH SERIFS AT BOTTOM","	x (white up-pointing triangle - 25B3)"},
/* 29CE */ { "RIGHT TRIANGLE ABOVE LEFT TRIANGLE",NULL},
/* 29CF */ { "LEFT TRIANGLE BESIDE VERTICAL BAR",NULL},
/* 29D0 */ { "VERTICAL BAR BESIDE RIGHT TRIANGLE",NULL},
/* 29D1 */ { "BOWTIE WITH LEFT HALF BLACK","	x (bowtie - 22C8)"},
/* 29D2 */ { "BOWTIE WITH RIGHT HALF BLACK",NULL},
/* 29D3 */ { "BLACK BOWTIE","	x (left and right triangular half block - 1FB9B)"},
/* 29D4 */ { "TIMES WITH LEFT HALF BLACK","	x (left normal factor semidirect product - 22C9)"},
/* 29D5 */ { "TIMES WITH RIGHT HALF BLACK","	x (right normal factor semidirect product - 22CA)"},
/* 29D6 */ { "WHITE HOURGLASS","	= vertical bowtie\n"
	"	= white framus\n"
	"	x (hourglass - 231B)\n"
	"	x (alchemical symbol for hour - 1F76E)"},
/* 29D7 */ { "BLACK HOURGLASS","	x (upper and lower triangular half block - 1FB9A)"},
/* 29D8 */ { "LEFT WIGGLY FENCE","	x (presentation form for vertical wavy low line - FE34)"},
/* 29D9 */ { "RIGHT WIGGLY FENCE",NULL},
/* 29DA */ { "LEFT DOUBLE WIGGLY FENCE",NULL},
/* 29DB */ { "RIGHT DOUBLE WIGGLY FENCE",NULL},
/* 29DC */ { "INCOMPLETE INFINITY","	= ISOtech entity &iinfin;\n"
	"	x (infinity - 221E)"},
/* 29DD */ { "TIE OVER INFINITY",NULL},
/* 29DE */ { "INFINITY NEGATED WITH VERTICAL BAR",NULL},
/* 29DF */ { "DOUBLE-ENDED MULTIMAP","	x (multimap - 22B8)\n"
	"	x (alchemical symbol for arsenic - 1F73A)"},
/* 29E0 */ { "SQUARE WITH CONTOURED OUTLINE","	= D'Alembertian\n"
	"	x (lower right drop-shadowed white square - 274F)"},
/* 29E1 */ { "INCREASES AS","	x (normal subgroup of or equal to - 22B4)"},
/* 29E2 */ { "SHUFFLE PRODUCT","	x (z notation bag membership - 22FF)"},
/* 29E3 */ { "EQUALS SIGN AND SLANTED PARALLEL","	x (number sign - 0023)\n"
	"	x (equal and parallel to - 22D5)"},
/* 29E4 */ { "EQUALS SIGN AND SLANTED PARALLEL WITH TILDE ABOVE",NULL},
/* 29E5 */ { "IDENTICAL TO AND SLANTED PARALLEL","	x (triple horizontal bar with double vertical stroke - 2A68)"},
/* 29E6 */ { "GLEICH STARK","	= tautological equivalent"},
/* 29E7 */ { "THERMODYNAMIC","	= record mark\n"
	"	* vertical bar crossed by two horizontals\n"
	"	x (not equal to - 2260)\n"
	"	x (group mark - 2BD2)"},
/* 29E8 */ { "DOWN-POINTING TRIANGLE WITH LEFT HALF BLACK","	x (up-pointing triangle with left half black - 25ED)"},
/* 29E9 */ { "DOWN-POINTING TRIANGLE WITH RIGHT HALF BLACK","	x (up-pointing triangle with right half black - 25EE)"},
/* 29EA */ { "BLACK DIAMOND WITH DOWN ARROW",NULL},
/* 29EB */ { "BLACK LOZENGE","	x (lozenge - 25CA)"},
/* 29EC */ { "WHITE CIRCLE WITH DOWN ARROW",NULL},
/* 29ED */ { "BLACK CIRCLE WITH DOWN ARROW",NULL},
/* 29EE */ { "ERROR-BARRED WHITE SQUARE",NULL},
/* 29EF */ { "ERROR-BARRED BLACK SQUARE",NULL},
/* 29F0 */ { "ERROR-BARRED WHITE DIAMOND",NULL},
/* 29F1 */ { "ERROR-BARRED BLACK DIAMOND",NULL},
/* 29F2 */ { "ERROR-BARRED WHITE CIRCLE",NULL},
/* 29F3 */ { "ERROR-BARRED BLACK CIRCLE",NULL},
/* 29F4 */ { "RULE-DELAYED","	= colon right arrow"},
/* 29F5 */ { "REVERSE SOLIDUS OPERATOR","	x (reverse solidus - 005C)\n"
	"	x (set minus - 2216)\n"
	"	x (mathematical falling diagonal - 27CD)"},
/* 29F6 */ { "SOLIDUS WITH OVERBAR",NULL},
/* 29F7 */ { "REVERSE SOLIDUS WITH HORIZONTAL STROKE","	x (apl functional symbol backslash bar - 2340)"},
/* 29F8 */ { "BIG SOLIDUS","	x (division slash - 2215)"},
/* 29F9 */ { "BIG REVERSE SOLIDUS","	= z notation schema hiding\n"
	"	x (set minus - 2216)"},
/* 29FA */ { "DOUBLE PLUS",NULL},
/* 29FB */ { "TRIPLE PLUS",NULL},
/* 29FC */ { "LEFT-POINTING CURVED ANGLE BRACKET","	x (precedes - 227A)\n"
	"	x (left-pointing angle bracket - 2329)"},
/* 29FD */ { "RIGHT-POINTING CURVED ANGLE BRACKET","	x (succeeds - 227B)\n"
	"	x (right-pointing angle bracket - 232A)"},
/* 29FE */ { "TINY","	x (plus sign - 002B)"},
/* 29FF */ { "MINY","	x (minus sign - 2212)"}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_00_2A[] = {
/* 2A00 */ { "N-ARY CIRCLED DOT OPERATOR","	x (circled dot operator - 2299)\n"
	"	x (fisheye - 25C9)"},
/* 2A01 */ { "N-ARY CIRCLED PLUS OPERATOR","	x (circled plus - 2295)"},
/* 2A02 */ { "N-ARY CIRCLED TIMES OPERATOR","	x (circled times - 2297)\n"
	"	x (heavy circled saltire - 2B59)"},
/* 2A03 */ { "N-ARY UNION OPERATOR WITH DOT","	x (multiset multiplication - 228D)"},
/* 2A04 */ { "N-ARY UNION OPERATOR WITH PLUS","	x (multiset union - 228E)"},
/* 2A05 */ { "N-ARY SQUARE INTERSECTION OPERATOR","	x (square cap - 2293)"},
/* 2A06 */ { "N-ARY SQUARE UNION OPERATOR","	x (square cup - 2294)"},
/* 2A07 */ { "TWO LOGICAL AND OPERATOR","	= merge\n"
	"	x (two intersecting logical and - 2A55)"},
/* 2A08 */ { "TWO LOGICAL OR OPERATOR","	x (two intersecting logical or - 2A56)"},
/* 2A09 */ { "N-ARY TIMES OPERATOR","	x (multiplication sign - 00D7)"},
/* 2A0A */ { "MODULO TWO SUM","	x (n-ary summation - 2211)"},
/* 2A0B */ { "SUMMATION WITH INTEGRAL",NULL},
/* 2A0C */ { "QUADRUPLE INTEGRAL OPERATOR","	x (triple integral - 222D)\n"
	"	# 222B 222B 222B 222B"},
/* 2A0D */ { "FINITE PART INTEGRAL",NULL},
/* 2A0E */ { "INTEGRAL WITH DOUBLE STROKE",NULL},
/* 2A0F */ { "INTEGRAL AVERAGE WITH SLASH",NULL},
/* 2A10 */ { "CIRCULATION FUNCTION",NULL},
/* 2A11 */ { "ANTICLOCKWISE INTEGRATION",NULL},
/* 2A12 */ { "LINE INTEGRATION WITH RECTANGULAR PATH AROUND POLE",NULL},
/* 2A13 */ { "LINE INTEGRATION WITH SEMICIRCULAR PATH AROUND POLE",NULL},
/* 2A14 */ { "LINE INTEGRATION NOT INCLUDING THE POLE",NULL},
/* 2A15 */ { "INTEGRAL AROUND A POINT OPERATOR","	x (contour integral - 222E)"},
/* 2A16 */ { "QUATERNION INTEGRAL OPERATOR",NULL},
/* 2A17 */ { "INTEGRAL WITH LEFTWARDS ARROW WITH HOOK",NULL},
/* 2A18 */ { "INTEGRAL WITH TIMES SIGN",NULL},
/* 2A19 */ { "INTEGRAL WITH INTERSECTION",NULL},
/* 2A1A */ { "INTEGRAL WITH UNION",NULL},
/* 2A1B */ { "INTEGRAL WITH OVERBAR","	= upper integral"},
/* 2A1C */ { "INTEGRAL WITH UNDERBAR","	= lower integral"},
/* 2A1D */ { "JOIN","	= large bowtie\n"
	"	* relational database theory\n"
	"	x (bowtie - 22C8)\n"
	"	x (full outer join - 27D7)"},
/* 2A1E */ { "LARGE LEFT TRIANGLE OPERATOR","	* relational database theory\n"
	"	x (white left-pointing triangle - 25C1)"},
/* 2A1F */ { "Z NOTATION SCHEMA COMPOSITION","	x (z notation relational composition - 2A3E)"},
/* 2A20 */ { "Z NOTATION SCHEMA PIPING","	x (much greater-than - 226B)"},
/* 2A21 */ { "Z NOTATION SCHEMA PROJECTION","	x (upwards harpoon with barb rightwards - 21BE)"},
/* 2A22 */ { "PLUS SIGN WITH SMALL CIRCLE ABOVE",NULL},
/* 2A23 */ { "PLUS SIGN WITH CIRCUMFLEX ACCENT ABOVE",NULL},
/* 2A24 */ { "PLUS SIGN WITH TILDE ABOVE","	= positive difference or sum"},
/* 2A25 */ { "PLUS SIGN WITH DOT BELOW","	x (dot plus - 2214)"},
/* 2A26 */ { "PLUS SIGN WITH TILDE BELOW","	= sum or positive difference"},
/* 2A27 */ { "PLUS SIGN WITH SUBSCRIPT TWO","	= nim-addition"},
/* 2A28 */ { "PLUS SIGN WITH BLACK TRIANGLE",NULL},
/* 2A29 */ { "MINUS SIGN WITH COMMA ABOVE",NULL},
/* 2A2A */ { "MINUS SIGN WITH DOT BELOW","	x (dot minus - 2238)"},
/* 2A2B */ { "MINUS SIGN WITH FALLING DOTS",NULL},
/* 2A2C */ { "MINUS SIGN WITH RISING DOTS",NULL},
/* 2A2D */ { "PLUS SIGN IN LEFT HALF CIRCLE",NULL},
/* 2A2E */ { "PLUS SIGN IN RIGHT HALF CIRCLE",NULL},
/* 2A2F */ { "VECTOR OR CROSS PRODUCT","	x (multiplication sign - 00D7)"},
/* 2A30 */ { "MULTIPLICATION SIGN WITH DOT ABOVE",NULL},
/* 2A31 */ { "MULTIPLICATION SIGN WITH UNDERBAR",NULL},
/* 2A32 */ { "SEMIDIRECT PRODUCT WITH BOTTOM CLOSED",NULL},
/* 2A33 */ { "SMASH PRODUCT",NULL},
/* 2A34 */ { "MULTIPLICATION SIGN IN LEFT HALF CIRCLE",NULL},
/* 2A35 */ { "MULTIPLICATION SIGN IN RIGHT HALF CIRCLE",NULL},
/* 2A36 */ { "CIRCLED MULTIPLICATION SIGN WITH CIRCUMFLEX ACCENT",NULL},
/* 2A37 */ { "MULTIPLICATION SIGN IN DOUBLE CIRCLE",NULL},
/* 2A38 */ { "CIRCLED DIVISION SIGN",NULL},
/* 2A39 */ { "PLUS SIGN IN TRIANGLE",NULL},
/* 2A3A */ { "MINUS SIGN IN TRIANGLE",NULL},
/* 2A3B */ { "MULTIPLICATION SIGN IN TRIANGLE",NULL},
/* 2A3C */ { "INTERIOR PRODUCT","	x (right floor - 230B)\n"
	"	~ 2A3C FE00 tall variant with narrow foot"},
/* 2A3D */ { "RIGHTHAND INTERIOR PRODUCT","	x (left floor - 230A)\n"
	"	x (turned not sign - 2319)\n"
	"	~ 2A3D FE00 tall variant with narrow foot"},
/* 2A3E */ { "Z NOTATION RELATIONAL COMPOSITION","	x (z notation schema composition - 2A1F)"},
/* 2A3F */ { "AMALGAMATION OR COPRODUCT","	x (n-ary coproduct - 2210)"},
/* 2A40 */ { "INTERSECTION WITH DOT","	x (logical and - 2227)\n"
	"	x (and with dot - 27D1)"},
/* 2A41 */ { "UNION WITH MINUS SIGN","	= z notation bag subtraction\n"
	"	x (multiset union - 228E)"},
/* 2A42 */ { "UNION WITH OVERBAR",NULL},
/* 2A43 */ { "INTERSECTION WITH OVERBAR",NULL},
/* 2A44 */ { "INTERSECTION WITH LOGICAL AND",NULL},
/* 2A45 */ { "UNION WITH LOGICAL OR",NULL},
/* 2A46 */ { "UNION ABOVE INTERSECTION",NULL},
/* 2A47 */ { "INTERSECTION ABOVE UNION",NULL},
/* 2A48 */ { "UNION ABOVE BAR ABOVE INTERSECTION",NULL},
/* 2A49 */ { "INTERSECTION ABOVE BAR ABOVE UNION",NULL},
/* 2A4A */ { "UNION BESIDE AND JOINED WITH UNION",NULL},
/* 2A4B */ { "INTERSECTION BESIDE AND JOINED WITH INTERSECTION",NULL},
/* 2A4C */ { "CLOSED UNION WITH SERIFS","	x (union - 222A)"},
/* 2A4D */ { "CLOSED INTERSECTION WITH SERIFS","	x (intersection - 2229)"},
/* 2A4E */ { "DOUBLE SQUARE INTERSECTION",NULL},
/* 2A4F */ { "DOUBLE SQUARE UNION",NULL},
/* 2A50 */ { "CLOSED UNION WITH SERIFS AND SMASH PRODUCT",NULL},
/* 2A51 */ { "LOGICAL AND WITH DOT ABOVE",NULL},
/* 2A52 */ { "LOGICAL OR WITH DOT ABOVE",NULL},
/* 2A53 */ { "DOUBLE LOGICAL AND",NULL},
/* 2A54 */ { "DOUBLE LOGICAL OR",NULL},
/* 2A55 */ { "TWO INTERSECTING LOGICAL AND","	x (two logical and operator - 2A07)"},
/* 2A56 */ { "TWO INTERSECTING LOGICAL OR","	x (two logical or operator - 2A08)"},
/* 2A57 */ { "SLOPING LARGE OR",NULL},
/* 2A58 */ { "SLOPING LARGE AND",NULL},
/* 2A59 */ { "LOGICAL OR OVERLAPPING LOGICAL AND",NULL},
/* 2A5A */ { "LOGICAL AND WITH MIDDLE STEM",NULL},
/* 2A5B */ { "LOGICAL OR WITH MIDDLE STEM",NULL},
/* 2A5C */ { "LOGICAL AND WITH HORIZONTAL DASH",NULL},
/* 2A5D */ { "LOGICAL OR WITH HORIZONTAL DASH",NULL},
/* 2A5E */ { "LOGICAL AND WITH DOUBLE OVERBAR","	x (perspective - 2306)"},
/* 2A5F */ { "LOGICAL AND WITH UNDERBAR",NULL},
/* 2A60 */ { "LOGICAL AND WITH DOUBLE UNDERBAR","	x (estimates - 2259)"},
/* 2A61 */ { "SMALL VEE WITH UNDERBAR","	x (equiangular to - 225A)"},
/* 2A62 */ { "LOGICAL OR WITH DOUBLE OVERBAR",NULL},
/* 2A63 */ { "LOGICAL OR WITH DOUBLE UNDERBAR","	x (equiangular to - 225A)"},
/* 2A64 */ { "Z NOTATION DOMAIN ANTIRESTRICTION",NULL},
/* 2A65 */ { "Z NOTATION RANGE ANTIRESTRICTION","	x (conical taper - 2332)"},
/* 2A66 */ { "EQUALS SIGN WITH DOT BELOW","	x (approaches the limit - 2250)"},
/* 2A67 */ { "IDENTICAL WITH DOT ABOVE",NULL},
/* 2A68 */ { "TRIPLE HORIZONTAL BAR WITH DOUBLE VERTICAL STROKE","	= identical and parallel to\n"
	"	x (equal and parallel to - 22D5)\n"
	"	x (identical to and slanted parallel - 29E5)"},
/* 2A69 */ { "TRIPLE HORIZONTAL BAR WITH TRIPLE VERTICAL STROKE",NULL},
/* 2A6A */ { "TILDE OPERATOR WITH DOT ABOVE",NULL},
/* 2A6B */ { "TILDE OPERATOR WITH RISING DOTS","	x (homothetic - 223B)"},
/* 2A6C */ { "SIMILAR MINUS SIMILAR",NULL},
/* 2A6D */ { "CONGRUENT WITH DOT ABOVE","	x (approximately equal to - 2245)"},
/* 2A6E */ { "EQUALS WITH ASTERISK","	x (star equals - 225B)"},
/* 2A6F */ { "ALMOST EQUAL TO WITH CIRCUMFLEX ACCENT",NULL},
/* 2A70 */ { "APPROXIMATELY EQUAL OR EQUAL TO","	x (approximately equal to - 2245)"},
/* 2A71 */ { "EQUALS SIGN ABOVE PLUS SIGN","	* black stands slightly better (chess notation)"},
/* 2A72 */ { "PLUS SIGN ABOVE EQUALS SIGN","	* white stands slightly better (chess notation)"},
/* 2A73 */ { "EQUALS SIGN ABOVE TILDE OPERATOR",NULL},
/* 2A74 */ { "DOUBLE COLON EQUAL","	# 003A 003A 003D"},
/* 2A75 */ { "TWO CONSECUTIVE EQUALS SIGNS","	# 003D 003D"},
/* 2A76 */ { "THREE CONSECUTIVE EQUALS SIGNS","	# 003D 003D 003D"},
/* 2A77 */ { "EQUALS SIGN WITH TWO DOTS ABOVE AND TWO DOTS BELOW",NULL},
/* 2A78 */ { "EQUIVALENT WITH FOUR DOTS ABOVE",NULL},
/* 2A79 */ { "LESS-THAN WITH CIRCLE INSIDE",NULL},
/* 2A7A */ { "GREATER-THAN WITH CIRCLE INSIDE",NULL},
/* 2A7B */ { "LESS-THAN WITH QUESTION MARK ABOVE",NULL},
/* 2A7C */ { "GREATER-THAN WITH QUESTION MARK ABOVE",NULL},
/* 2A7D */ { "LESS-THAN OR SLANTED EQUAL TO","	x (less-than or equal to - 2264)"},
/* 2A7E */ { "GREATER-THAN OR SLANTED EQUAL TO","	x (greater-than or equal to - 2265)"},
/* 2A7F */ { "LESS-THAN OR SLANTED EQUAL TO WITH DOT INSIDE",NULL},
/* 2A80 */ { "GREATER-THAN OR SLANTED EQUAL TO WITH DOT INSIDE",NULL},
/* 2A81 */ { "LESS-THAN OR SLANTED EQUAL TO WITH DOT ABOVE",NULL},
/* 2A82 */ { "GREATER-THAN OR SLANTED EQUAL TO WITH DOT ABOVE",NULL},
/* 2A83 */ { "LESS-THAN OR SLANTED EQUAL TO WITH DOT ABOVE RIGHT",NULL},
/* 2A84 */ { "GREATER-THAN OR SLANTED EQUAL TO WITH DOT ABOVE LEFT",NULL},
/* 2A85 */ { "LESS-THAN OR APPROXIMATE",NULL},
/* 2A86 */ { "GREATER-THAN OR APPROXIMATE",NULL},
/* 2A87 */ { "LESS-THAN AND SINGLE-LINE NOT EQUAL TO","	x (less-than but not equal to - 2268)"},
/* 2A88 */ { "GREATER-THAN AND SINGLE-LINE NOT EQUAL TO","	x (greater-than but not equal to - 2269)"},
/* 2A89 */ { "LESS-THAN AND NOT APPROXIMATE",NULL},
/* 2A8A */ { "GREATER-THAN AND NOT APPROXIMATE",NULL},
/* 2A8B */ { "LESS-THAN ABOVE DOUBLE-LINE EQUAL ABOVE GREATER-THAN","	x (less-than equal to or greater-than - 22DA)"},
/* 2A8C */ { "GREATER-THAN ABOVE DOUBLE-LINE EQUAL ABOVE LESS-THAN","	x (greater-than equal to or less-than - 22DB)"},
/* 2A8D */ { "LESS-THAN ABOVE SIMILAR OR EQUAL",NULL},
/* 2A8E */ { "GREATER-THAN ABOVE SIMILAR OR EQUAL",NULL},
/* 2A8F */ { "LESS-THAN ABOVE SIMILAR ABOVE GREATER-THAN",NULL},
/* 2A90 */ { "GREATER-THAN ABOVE SIMILAR ABOVE LESS-THAN",NULL},
/* 2A91 */ { "LESS-THAN ABOVE GREATER-THAN ABOVE DOUBLE-LINE EQUAL",NULL},
/* 2A92 */ { "GREATER-THAN ABOVE LESS-THAN ABOVE DOUBLE-LINE EQUAL",NULL},
/* 2A93 */ { "LESS-THAN ABOVE SLANTED EQUAL ABOVE GREATER-THAN ABOVE SLANTED EQUAL",NULL},
/* 2A94 */ { "GREATER-THAN ABOVE SLANTED EQUAL ABOVE LESS-THAN ABOVE SLANTED EQUAL",NULL},
/* 2A95 */ { "SLANTED EQUAL TO OR LESS-THAN","	x (equal to or less-than - 22DC)"},
/* 2A96 */ { "SLANTED EQUAL TO OR GREATER-THAN","	x (equal to or greater-than - 22DD)"},
/* 2A97 */ { "SLANTED EQUAL TO OR LESS-THAN WITH DOT INSIDE",NULL},
/* 2A98 */ { "SLANTED EQUAL TO OR GREATER-THAN WITH DOT INSIDE",NULL},
/* 2A99 */ { "DOUBLE-LINE EQUAL TO OR LESS-THAN","	x (equal to or less-than - 22DC)"},
/* 2A9A */ { "DOUBLE-LINE EQUAL TO OR GREATER-THAN","	x (equal to or greater-than - 22DD)"},
/* 2A9B */ { "DOUBLE-LINE SLANTED EQUAL TO OR LESS-THAN",NULL},
/* 2A9C */ { "DOUBLE-LINE SLANTED EQUAL TO OR GREATER-THAN",NULL},
/* 2A9D */ { "SIMILAR OR LESS-THAN","	~ 2A9D FE00 with similar following the slant of the upper leg"},
/* 2A9E */ { "SIMILAR OR GREATER-THAN","	~ 2A9E FE00 with similar following the slant of the upper leg"},
/* 2A9F */ { "SIMILAR ABOVE LESS-THAN ABOVE EQUALS SIGN",NULL},
/* 2AA0 */ { "SIMILAR ABOVE GREATER-THAN ABOVE EQUALS SIGN",NULL},
/* 2AA1 */ { "DOUBLE NESTED LESS-THAN","	= absolute continuity\n"
	"	x (much less-than - 226A)"},
/* 2AA2 */ { "DOUBLE NESTED GREATER-THAN","	x (much greater-than - 226B)"},
/* 2AA3 */ { "DOUBLE NESTED LESS-THAN WITH UNDERBAR",NULL},
/* 2AA4 */ { "GREATER-THAN OVERLAPPING LESS-THAN",NULL},
/* 2AA5 */ { "GREATER-THAN BESIDE LESS-THAN",NULL},
/* 2AA6 */ { "LESS-THAN CLOSED BY CURVE",NULL},
/* 2AA7 */ { "GREATER-THAN CLOSED BY CURVE",NULL},
/* 2AA8 */ { "LESS-THAN CLOSED BY CURVE ABOVE SLANTED EQUAL",NULL},
/* 2AA9 */ { "GREATER-THAN CLOSED BY CURVE ABOVE SLANTED EQUAL",NULL},
/* 2AAA */ { "SMALLER THAN",NULL},
/* 2AAB */ { "LARGER THAN",NULL},
/* 2AAC */ { "SMALLER THAN OR EQUAL TO","	~ 2AAC FE00 with slanted equal"},
/* 2AAD */ { "LARGER THAN OR EQUAL TO","	~ 2AAD FE00 with slanted equal"},
/* 2AAE */ { "EQUALS SIGN WITH BUMPY ABOVE","	x (difference between - 224F)"},
/* 2AAF */ { "PRECEDES ABOVE SINGLE-LINE EQUALS SIGN","	x (precedes or equal to - 227C)"},
/* 2AB0 */ { "SUCCEEDS ABOVE SINGLE-LINE EQUALS SIGN","	x (succeeds or equal to - 227D)"},
/* 2AB1 */ { "PRECEDES ABOVE SINGLE-LINE NOT EQUAL TO",NULL},
/* 2AB2 */ { "SUCCEEDS ABOVE SINGLE-LINE NOT EQUAL TO",NULL},
/* 2AB3 */ { "PRECEDES ABOVE EQUALS SIGN",NULL},
/* 2AB4 */ { "SUCCEEDS ABOVE EQUALS SIGN",NULL},
/* 2AB5 */ { "PRECEDES ABOVE NOT EQUAL TO",NULL},
/* 2AB6 */ { "SUCCEEDS ABOVE NOT EQUAL TO",NULL},
/* 2AB7 */ { "PRECEDES ABOVE ALMOST EQUAL TO",NULL},
/* 2AB8 */ { "SUCCEEDS ABOVE ALMOST EQUAL TO",NULL},
/* 2AB9 */ { "PRECEDES ABOVE NOT ALMOST EQUAL TO",NULL},
/* 2ABA */ { "SUCCEEDS ABOVE NOT ALMOST EQUAL TO",NULL},
/* 2ABB */ { "DOUBLE PRECEDES",NULL},
/* 2ABC */ { "DOUBLE SUCCEEDS",NULL},
/* 2ABD */ { "SUBSET WITH DOT",NULL},
/* 2ABE */ { "SUPERSET WITH DOT",NULL},
/* 2ABF */ { "SUBSET WITH PLUS SIGN BELOW",NULL},
/* 2AC0 */ { "SUPERSET WITH PLUS SIGN BELOW",NULL},
/* 2AC1 */ { "SUBSET WITH MULTIPLICATION SIGN BELOW",NULL},
/* 2AC2 */ { "SUPERSET WITH MULTIPLICATION SIGN BELOW",NULL},
/* 2AC3 */ { "SUBSET OF OR EQUAL TO WITH DOT ABOVE",NULL},
/* 2AC4 */ { "SUPERSET OF OR EQUAL TO WITH DOT ABOVE",NULL},
/* 2AC5 */ { "SUBSET OF ABOVE EQUALS SIGN",NULL},
/* 2AC6 */ { "SUPERSET OF ABOVE EQUALS SIGN",NULL},
/* 2AC7 */ { "SUBSET OF ABOVE TILDE OPERATOR",NULL},
/* 2AC8 */ { "SUPERSET OF ABOVE TILDE OPERATOR",NULL},
/* 2AC9 */ { "SUBSET OF ABOVE ALMOST EQUAL TO",NULL},
/* 2ACA */ { "SUPERSET OF ABOVE ALMOST EQUAL TO",NULL},
/* 2ACB */ { "SUBSET OF ABOVE NOT EQUAL TO","	~ 2ACB FE00 with stroke through bottom members"},
/* 2ACC */ { "SUPERSET OF ABOVE NOT EQUAL TO","	~ 2ACC FE00 with stroke through bottom members"},
/* 2ACD */ { "SQUARE LEFT OPEN BOX OPERATOR",NULL},
/* 2ACE */ { "SQUARE RIGHT OPEN BOX OPERATOR",NULL},
/* 2ACF */ { "CLOSED SUBSET","	x (subset of - 2282)"},
/* 2AD0 */ { "CLOSED SUPERSET","	x (superset of - 2283)"},
/* 2AD1 */ { "CLOSED SUBSET OR EQUAL TO",NULL},
/* 2AD2 */ { "CLOSED SUPERSET OR EQUAL TO",NULL},
/* 2AD3 */ { "SUBSET ABOVE SUPERSET",NULL},
/* 2AD4 */ { "SUPERSET ABOVE SUBSET",NULL},
/* 2AD5 */ { "SUBSET ABOVE SUBSET",NULL},
/* 2AD6 */ { "SUPERSET ABOVE SUPERSET",NULL},
/* 2AD7 */ { "SUPERSET BESIDE SUBSET",NULL},
/* 2AD8 */ { "SUPERSET BESIDE AND JOINED BY DASH WITH SUBSET",NULL},
/* 2AD9 */ { "ELEMENT OF OPENING DOWNWARDS","	x (element of - 2208)\n"
	"	x (element of opening upwards - 27D2)"},
/* 2ADA */ { "PITCHFORK WITH TEE TOP","	x (pitchfork - 22D4)"},
/* 2ADB */ { "TRANSVERSAL INTERSECTION","	x (pitchfork - 22D4)"},
/* 2ADC */ { "FORKING","	= not independent\n"
	"	* an equational logic symbol, not a computing science symbol\n"
	"	* non-independence (original concept) is related to forking\n"
	"	: 2ADD 0338"},
/* 2ADD */ { "NONFORKING","	= independent\n"
	"	* an equational logic symbol, not a computing science symbol\n"
	"	* independence (original concept) is related to non-forking"},
/* 2ADE */ { "SHORT LEFT TACK","	x (left tack - 22A3)"},
/* 2ADF */ { "SHORT DOWN TACK","	x (down tack - 22A4)"},
/* 2AE0 */ { "SHORT UP TACK","	x (up tack - 22A5)"},
/* 2AE1 */ { "PERPENDICULAR WITH S",NULL},
/* 2AE2 */ { "VERTICAL BAR TRIPLE RIGHT TURNSTILE","	= ordinarily satisfies"},
/* 2AE3 */ { "DOUBLE VERTICAL BAR LEFT TURNSTILE","	x (forces - 22A9)"},
/* 2AE4 */ { "VERTICAL BAR DOUBLE LEFT TURNSTILE","	x (true - 22A8)"},
/* 2AE5 */ { "DOUBLE VERTICAL BAR DOUBLE LEFT TURNSTILE",NULL},
/* 2AE6 */ { "LONG DASH FROM LEFT MEMBER OF DOUBLE VERTICAL","	x (forces - 22A9)"},
/* 2AE7 */ { "SHORT DOWN TACK WITH OVERBAR","	x (down tack - 22A4)\n"
	"	x (apl functional symbol up tack overbar - 2351)\n"
	"	x (postal mark - 3012)"},
/* 2AE8 */ { "SHORT UP TACK WITH UNDERBAR","	x (up tack - 22A5)\n"
	"	x (apl functional symbol down tack underbar - 234A)"},
/* 2AE9 */ { "SHORT UP TACK ABOVE SHORT DOWN TACK",NULL},
/* 2AEA */ { "DOUBLE DOWN TACK",NULL},
/* 2AEB */ { "DOUBLE UP TACK","	= independence\n"
	"	* probability theory"},
/* 2AEC */ { "DOUBLE STROKE NOT SIGN","	x (not sign - 00AC)"},
/* 2AED */ { "REVERSED DOUBLE STROKE NOT SIGN","	x (reversed not sign - 2310)"},
/* 2AEE */ { "DOES NOT DIVIDE WITH REVERSED NEGATION SLASH","	x (does not divide - 2224)"},
/* 2AEF */ { "VERTICAL LINE WITH CIRCLE ABOVE",NULL},
/* 2AF0 */ { "VERTICAL LINE WITH CIRCLE BELOW",NULL},
/* 2AF1 */ { "DOWN TACK WITH CIRCLE BELOW","	= necessarily satisfies\n"
	"	x (up tack with circle above - 27DF)"},
/* 2AF2 */ { "PARALLEL WITH HORIZONTAL STROKE","	x (not parallel to - 2226)\n"
	"	x (vertical bar with horizontal stroke - 27CA)"},
/* 2AF3 */ { "PARALLEL WITH TILDE OPERATOR",NULL},
/* 2AF4 */ { "TRIPLE VERTICAL BAR BINARY RELATION","	= interleave\n"
	"	x (triple vertical bar delimiter - 2980)"},
/* 2AF5 */ { "TRIPLE VERTICAL BAR WITH HORIZONTAL STROKE","	x (vertical bar with horizontal stroke - 27CA)"},
/* 2AF6 */ { "TRIPLE COLON OPERATOR","	* logic\n"
	"	x (tricolon - 205D)\n"
	"	x (vertical ellipsis - 22EE)"},
/* 2AF7 */ { "TRIPLE NESTED LESS-THAN","	x (very much less-than - 22D8)"},
/* 2AF8 */ { "TRIPLE NESTED GREATER-THAN","	x (very much greater-than - 22D9)"},
/* 2AF9 */ { "DOUBLE-LINE SLANTED LESS-THAN OR EQUAL TO","	x (less-than over equal to - 2266)"},
/* 2AFA */ { "DOUBLE-LINE SLANTED GREATER-THAN OR EQUAL TO","	x (greater-than over equal to - 2267)"},
/* 2AFB */ { "TRIPLE SOLIDUS BINARY RELATION","	x (triple vertical bar binary relation - 2AF4)"},
/* 2AFC */ { "LARGE TRIPLE VERTICAL BAR OPERATOR","	* often n-ary\n"
	"	x (triple vertical bar binary relation - 2AF4)\n"
	"	x (triple vertical bar delimiter - 2980)"},
/* 2AFD */ { "DOUBLE SOLIDUS OPERATOR","	x (parallel to - 2225)"},
/* 2AFE */ { "WHITE VERTICAL BAR","	= Dijkstra choice"},
/* 2AFF */ { "N-ARY WHITE VERTICAL BAR","	= n-ary Dijkstra choice"}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_00_2B[] = {
/* 2B00 */ { "NORTH EAST WHITE ARROW",NULL},
/* 2B01 */ { "NORTH WEST WHITE ARROW",NULL},
/* 2B02 */ { "SOUTH EAST WHITE ARROW",NULL},
/* 2B03 */ { "SOUTH WEST WHITE ARROW",NULL},
/* 2B04 */ { "LEFT RIGHT WHITE ARROW","	x (leftwards white arrow - 21E6)\n"
	"	x (up down white arrow - 21F3)"},
/* 2B05 */ { "LEFTWARDS BLACK ARROW","	x (black rightwards arrow - 27A1)\n"
	"	x (rightwards black arrow - 2B95)"},
/* 2B06 */ { "UPWARDS BLACK ARROW",NULL},
/* 2B07 */ { "DOWNWARDS BLACK ARROW",NULL},
/* 2B08 */ { "NORTH EAST BLACK ARROW",NULL},
/* 2B09 */ { "NORTH WEST BLACK ARROW",NULL},
/* 2B0A */ { "SOUTH EAST BLACK ARROW",NULL},
/* 2B0B */ { "SOUTH WEST BLACK ARROW",NULL},
/* 2B0C */ { "LEFT RIGHT BLACK ARROW",NULL},
/* 2B0D */ { "UP DOWN BLACK ARROW",NULL},
/* 2B0E */ { "RIGHTWARDS ARROW WITH TIP DOWNWARDS",NULL},
/* 2B0F */ { "RIGHTWARDS ARROW WITH TIP UPWARDS",NULL},
/* 2B10 */ { "LEFTWARDS ARROW WITH TIP DOWNWARDS",NULL},
/* 2B11 */ { "LEFTWARDS ARROW WITH TIP UPWARDS",NULL},
/* 2B12 */ { "SQUARE WITH TOP HALF BLACK","	x (square with left half black - 25E7)"},
/* 2B13 */ { "SQUARE WITH BOTTOM HALF BLACK",NULL},
/* 2B14 */ { "SQUARE WITH UPPER RIGHT DIAGONAL HALF BLACK",NULL},
/* 2B15 */ { "SQUARE WITH LOWER LEFT DIAGONAL HALF BLACK",NULL},
/* 2B16 */ { "DIAMOND WITH LEFT HALF BLACK",NULL},
/* 2B17 */ { "DIAMOND WITH RIGHT HALF BLACK",NULL},
/* 2B18 */ { "DIAMOND WITH TOP HALF BLACK",NULL},
/* 2B19 */ { "DIAMOND WITH BOTTOM HALF BLACK",NULL},
/* 2B1A */ { "DOTTED SQUARE",NULL},
/* 2B1B */ { "BLACK LARGE SQUARE","	x (black square - 25A0)"},
/* 2B1C */ { "WHITE LARGE SQUARE","	x (white square - 25A1)"},
/* 2B1D */ { "BLACK VERY SMALL SQUARE","	x (black small square - 25AA)"},
/* 2B1E */ { "WHITE VERY SMALL SQUARE","	x (white small square - 25AB)"},
/* 2B1F */ { "BLACK PENTAGON",NULL},
/* 2B20 */ { "WHITE PENTAGON",NULL},
/* 2B21 */ { "WHITE HEXAGON","	x (software-function symbol - 2394)"},
/* 2B22 */ { "BLACK HEXAGON",NULL},
/* 2B23 */ { "HORIZONTAL BLACK HEXAGON",NULL},
/* 2B24 */ { "BLACK LARGE CIRCLE","	x (black circle - 25CF)\n"
	"	x (large circle - 25EF)\n"
	"	x (large red circle - 1F534)"},
/* 2B25 */ { "BLACK MEDIUM DIAMOND","	x (black diamond - 25C6)"},
/* 2B26 */ { "WHITE MEDIUM DIAMOND","	x (white diamond - 25C7)\n"
	"	x (alchemical symbol for soap - 1F754)"},
/* 2B27 */ { "BLACK MEDIUM LOZENGE",NULL},
/* 2B28 */ { "WHITE MEDIUM LOZENGE","	x (lozenge - 25CA)"},
/* 2B29 */ { "BLACK SMALL DIAMOND","	x (diamond operator - 22C4)\n"
	"	x (small orange diamond - 1F538)"},
/* 2B2A */ { "BLACK SMALL LOZENGE",NULL},
/* 2B2B */ { "WHITE SMALL LOZENGE",NULL},
/* 2B2C */ { "BLACK HORIZONTAL ELLIPSE",NULL},
/* 2B2D */ { "WHITE HORIZONTAL ELLIPSE",NULL},
/* 2B2E */ { "BLACK VERTICAL ELLIPSE",NULL},
/* 2B2F */ { "WHITE VERTICAL ELLIPSE",NULL},
/* 2B30 */ { "LEFT ARROW WITH SMALL CIRCLE","	x (right arrow with small circle - 21F4)"},
/* 2B31 */ { "THREE LEFTWARDS ARROWS","	x (three rightwards arrows - 21F6)"},
/* 2B32 */ { "LEFT ARROW WITH CIRCLED PLUS","	x (right arrow with circled plus - 27F4)"},
/* 2B33 */ { "LONG LEFTWARDS SQUIGGLE ARROW","	x (long rightwards squiggle arrow - 27FF)\n"
	"	x (leftwards squiggle arrow - 21DC)"},
/* 2B34 */ { "LEFTWARDS TWO-HEADED ARROW WITH VERTICAL STROKE","	x (rightwards two-headed arrow with vertical stroke - 2900)"},
/* 2B35 */ { "LEFTWARDS TWO-HEADED ARROW WITH DOUBLE VERTICAL STROKE","	x (rightwards two-headed arrow with double vertical stroke - 2901)"},
/* 2B36 */ { "LEFTWARDS TWO-HEADED ARROW FROM BAR","	x (rightwards two-headed arrow from bar - 2905)"},
/* 2B37 */ { "LEFTWARDS TWO-HEADED TRIPLE DASH ARROW","	x (rightwards two-headed triple dash arrow - 2910)"},
/* 2B38 */ { "LEFTWARDS ARROW WITH DOTTED STEM","	x (rightwards arrow with dotted stem - 2911)"},
/* 2B39 */ { "LEFTWARDS ARROW WITH TAIL WITH VERTICAL STROKE","	x (rightwards arrow with tail with vertical stroke - 2914)"},
/* 2B3A */ { "LEFTWARDS ARROW WITH TAIL WITH DOUBLE VERTICAL STROKE","	x (rightwards arrow with tail with double vertical stroke - 2915)"},
/* 2B3B */ { "LEFTWARDS TWO-HEADED ARROW WITH TAIL","	x (rightwards two-headed arrow with tail - 2916)"},
/* 2B3C */ { "LEFTWARDS TWO-HEADED ARROW WITH TAIL WITH VERTICAL STROKE","	x (rightwards two-headed arrow with tail with vertical stroke - 2917)"},
/* 2B3D */ { "LEFTWARDS TWO-HEADED ARROW WITH TAIL WITH DOUBLE VERTICAL STROKE","	x (rightwards two-headed arrow with tail with double vertical stroke - 2918)"},
/* 2B3E */ { "LEFTWARDS ARROW THROUGH X","	x (rightwards arrow through x - 2947)"},
/* 2B3F */ { "WAVE ARROW POINTING DIRECTLY LEFT","	x (wave arrow pointing directly right - 2933)\n"
	"	x (leftwards wave arrow - 219C)"},
/* 2B40 */ { "EQUALS SIGN ABOVE LEFTWARDS ARROW","	x (equals sign above rightwards arrow - 2971)"},
/* 2B41 */ { "REVERSE TILDE OPERATOR ABOVE LEFTWARDS ARROW","	* mirror image of \"2972\"\n"
	"	x (tilde operator above rightwards arrow - 2972)"},
/* 2B42 */ { "LEFTWARDS ARROW ABOVE REVERSE ALMOST EQUAL TO","	* mirror image of \"2975\"\n"
	"	x (rightwards arrow above almost equal to - 2975)"},
/* 2B43 */ { "RIGHTWARDS ARROW THROUGH GREATER-THAN","	* mirror image of \"2977\"\n"
	"	x (leftwards arrow through less-than - 2977)"},
/* 2B44 */ { "RIGHTWARDS ARROW THROUGH SUPERSET","	* mirror image of \"297A\"\n"
	"	x (leftwards arrow through subset - 297A)"},
/* 2B45 */ { "LEFTWARDS QUADRUPLE ARROW","	x (upwards quadruple arrow - 27F0)"},
/* 2B46 */ { "RIGHTWARDS QUADRUPLE ARROW",NULL},
/* 2B47 */ { "REVERSE TILDE OPERATOR ABOVE RIGHTWARDS ARROW",NULL},
/* 2B48 */ { "RIGHTWARDS ARROW ABOVE REVERSE ALMOST EQUAL TO",NULL},
/* 2B49 */ { "TILDE OPERATOR ABOVE LEFTWARDS ARROW",NULL},
/* 2B4A */ { "LEFTWARDS ARROW ABOVE ALMOST EQUAL TO",NULL},
/* 2B4B */ { "LEFTWARDS ARROW ABOVE REVERSE TILDE OPERATOR","	* mirror image of \"2974\"\n"
	"	x (rightwards arrow above tilde operator - 2974)"},
/* 2B4C */ { "RIGHTWARDS ARROW ABOVE REVERSE TILDE OPERATOR","	* mirror image of \"2973\"\n"
	"	x (leftwards arrow above tilde operator - 2973)"},
/* 2B4D */ { "DOWNWARDS TRIANGLE-HEADED ZIGZAG ARROW","	x (downwards zigzag arrow - 21AF)"},
/* 2B4E */ { "SHORT SLANTED NORTH ARROW","	* slight rise in tone"},
/* 2B4F */ { "SHORT BACKSLANTED SOUTH ARROW","	* slight fall or overall fall in tone when at the end of a word or at the beginning of a phrase, respectively"},
/* 2B50 */ { "WHITE MEDIUM STAR","	x (white star - 2606)"},
/* 2B51 */ { "BLACK SMALL STAR","	x (arabic five pointed star - 066D)\n"
	"	x (star operator - 22C6)\n"
	"	x (black star - 2605)"},
/* 2B52 */ { "WHITE SMALL STAR",NULL},
/* 2B53 */ { "BLACK RIGHT-POINTING PENTAGON",NULL},
/* 2B54 */ { "WHITE RIGHT-POINTING PENTAGON",NULL},
/* 2B55 */ { "HEAVY LARGE CIRCLE","	= basic symbol for speed limit\n"
	"	* forms a game tally pair with 274C\n"
	"	x (large circle - 25EF)"},
/* 2B56 */ { "HEAVY OVAL WITH OVAL INSIDE","	= prefectural office"},
/* 2B57 */ { "HEAVY CIRCLE WITH CIRCLE INSIDE","	= municipal office\n"
	"	x (bullseye - 25CE)"},
/* 2B58 */ { "HEAVY CIRCLE","	= town or village office\n"
	"	= power off symbol\n"
	"	x (power on symbol - 23FD)\n"
	"	x (white circle - 25CB)"},
/* 2B59 */ { "HEAVY CIRCLED SALTIRE","	= police station\n"
	"	x (n-ary circled times operator - 2A02)"},
/* 2B5A */ { "SLANTED NORTH ARROW WITH HOOKED HEAD","	* increasing tone with falling trend at the end"},
/* 2B5B */ { "BACKSLANTED SOUTH ARROW WITH HOOKED TAIL","	* sharp rise and fall in tone"},
/* 2B5C */ { "SLANTED NORTH ARROW WITH HORIZONTAL TAIL","	* continued rise in tone"},
/* 2B5D */ { "BACKSLANTED SOUTH ARROW WITH HORIZONTAL TAIL","	* continued fall in tone"},
/* 2B5E */ { "BENT ARROW POINTING DOWNWARDS THEN NORTH EAST","	* sharp fall in tone with rising trend at the end"},
/* 2B5F */ { "SHORT BENT ARROW POINTING DOWNWARDS THEN NORTH EAST","	* slight fall in tone with rising trend at the end"},
/* 2B60 */ { "LEFTWARDS TRIANGLE-HEADED ARROW","	x (leftwards arrow - 2190)"},
/* 2B61 */ { "UPWARDS TRIANGLE-HEADED ARROW","	x (upwards arrow - 2191)"},
/* 2B62 */ { "RIGHTWARDS TRIANGLE-HEADED ARROW","	x (rightwards arrow - 2192)\n"
	"	x (triangle-headed rightwards arrow - 279D)"},
/* 2B63 */ { "DOWNWARDS TRIANGLE-HEADED ARROW","	x (downwards arrow - 2193)"},
/* 2B64 */ { "LEFT RIGHT TRIANGLE-HEADED ARROW","	x (left right arrow - 2194)"},
/* 2B65 */ { "UP DOWN TRIANGLE-HEADED ARROW","	x (up down arrow - 2195)"},
/* 2B66 */ { "NORTH WEST TRIANGLE-HEADED ARROW","	x (north west arrow - 2196)"},
/* 2B67 */ { "NORTH EAST TRIANGLE-HEADED ARROW","	x (north east arrow - 2197)"},
/* 2B68 */ { "SOUTH EAST TRIANGLE-HEADED ARROW","	x (south east arrow - 2198)"},
/* 2B69 */ { "SOUTH WEST TRIANGLE-HEADED ARROW","	x (south west arrow - 2199)"},
/* 2B6A */ { "LEFTWARDS TRIANGLE-HEADED DASHED ARROW","	x (leftwards dashed arrow - 21E0)"},
/* 2B6B */ { "UPWARDS TRIANGLE-HEADED DASHED ARROW","	x (upwards dashed arrow - 21E1)"},
/* 2B6C */ { "RIGHTWARDS TRIANGLE-HEADED DASHED ARROW","	x (rightwards dashed arrow - 21E2)"},
/* 2B6D */ { "DOWNWARDS TRIANGLE-HEADED DASHED ARROW","	x (downwards dashed arrow - 21E3)"},
/* 2B6E */ { "CLOCKWISE TRIANGLE-HEADED OPEN CIRCLE ARROW","	x (clockwise open circle arrow - 21BB)"},
/* 2B6F */ { "ANTICLOCKWISE TRIANGLE-HEADED OPEN CIRCLE ARROW","	x (anticlockwise open circle arrow - 21BA)"},
/* 2B70 */ { "LEFTWARDS TRIANGLE-HEADED ARROW TO BAR","	= left tab\n"
	"	x (leftwards arrow to bar - 21E4)"},
/* 2B71 */ { "UPWARDS TRIANGLE-HEADED ARROW TO BAR","	= up tab\n"
	"	x (upwards arrow to bar - 2912)"},
/* 2B72 */ { "RIGHTWARDS TRIANGLE-HEADED ARROW TO BAR","	= right tab\n"
	"	x (rightwards arrow to bar - 21E5)"},
/* 2B73 */ { "DOWNWARDS TRIANGLE-HEADED ARROW TO BAR","	= down tab\n"
	"	x (downwards arrow to bar - 2913)"},
/* 2B74 */ { NULL,NULL},
/* 2B75 */ { NULL,NULL},
/* 2B76 */ { "NORTH WEST TRIANGLE-HEADED ARROW TO BAR","	= home"},
/* 2B77 */ { "NORTH EAST TRIANGLE-HEADED ARROW TO BAR",NULL},
/* 2B78 */ { "SOUTH EAST TRIANGLE-HEADED ARROW TO BAR","	= end"},
/* 2B79 */ { "SOUTH WEST TRIANGLE-HEADED ARROW TO BAR",NULL},
/* 2B7A */ { "LEFTWARDS TRIANGLE-HEADED ARROW WITH DOUBLE HORIZONTAL STROKE","	% LEFTWARDS TRIANGLE-HEADED ARROW WITH DOUBLE VERTICAL STROKE"},
/* 2B7B */ { "UPWARDS TRIANGLE-HEADED ARROW WITH DOUBLE HORIZONTAL STROKE","	= page up"},
/* 2B7C */ { "RIGHTWARDS TRIANGLE-HEADED ARROW WITH DOUBLE HORIZONTAL STROKE","	% RIGHTWARDS TRIANGLE-HEADED ARROW WITH DOUBLE VERTICAL STROKE"},
/* 2B7D */ { "DOWNWARDS TRIANGLE-HEADED ARROW WITH DOUBLE HORIZONTAL STROKE","	= page down"},
/* 2B7E */ { "HORIZONTAL TAB KEY","	x (leftwards arrow to bar over rightwards arrow to bar - 21B9)"},
/* 2B7F */ { "VERTICAL TAB KEY",NULL},
/* 2B80 */ { "LEFTWARDS TRIANGLE-HEADED ARROW OVER RIGHTWARDS TRIANGLE-HEADED ARROW","	x (leftwards arrow over rightwards arrow - 21C6)"},
/* 2B81 */ { "UPWARDS TRIANGLE-HEADED ARROW LEFTWARDS OF DOWNWARDS TRIANGLE-HEADED ARROW",NULL},
/* 2B82 */ { "RIGHTWARDS TRIANGLE-HEADED ARROW OVER LEFTWARDS TRIANGLE-HEADED ARROW",NULL},
/* 2B83 */ { "DOWNWARDS TRIANGLE-HEADED ARROW LEFTWARDS OF UPWARDS TRIANGLE-HEADED ARROW","	x (downwards arrow leftwards of upwards arrow - 21F5)"},
/* 2B84 */ { "LEFTWARDS TRIANGLE-HEADED PAIRED ARROWS","	x (leftwards paired arrows - 21C7)"},
/* 2B85 */ { "UPWARDS TRIANGLE-HEADED PAIRED ARROWS","	x (upwards paired arrows - 21C8)"},
/* 2B86 */ { "RIGHTWARDS TRIANGLE-HEADED PAIRED ARROWS","	x (rightwards paired arrows - 21C9)"},
/* 2B87 */ { "DOWNWARDS TRIANGLE-HEADED PAIRED ARROWS","	x (downwards paired arrows - 21CA)"},
/* 2B88 */ { "LEFTWARDS BLACK CIRCLED WHITE ARROW",NULL},
/* 2B89 */ { "UPWARDS BLACK CIRCLED WHITE ARROW",NULL},
/* 2B8A */ { "RIGHTWARDS BLACK CIRCLED WHITE ARROW","	x (circled heavy white rightwards arrow - 27B2)"},
/* 2B8B */ { "DOWNWARDS BLACK CIRCLED WHITE ARROW",NULL},
/* 2B8C */ { "ANTICLOCKWISE TRIANGLE-HEADED RIGHT U-SHAPED ARROW",NULL},
/* 2B8D */ { "ANTICLOCKWISE TRIANGLE-HEADED BOTTOM U-SHAPED ARROW",NULL},
/* 2B8E */ { "ANTICLOCKWISE TRIANGLE-HEADED LEFT U-SHAPED ARROW",NULL},
/* 2B8F */ { "ANTICLOCKWISE TRIANGLE-HEADED TOP U-SHAPED ARROW","	x (anticlockwise top semicircle arrow - 21B6)"},
/* 2B90 */ { "RETURN LEFT","	x (return symbol - 23CE)"},
/* 2B91 */ { "RETURN RIGHT",NULL},
/* 2B92 */ { "NEWLINE LEFT",NULL},
/* 2B93 */ { "NEWLINE RIGHT",NULL},
/* 2B94 */ { "FOUR CORNER ARROWS CIRCLING ANTICLOCKWISE","	= loop"},
/* 2B95 */ { "RIGHTWARDS BLACK ARROW","	x (black rightwards arrow - 27A1)\n"
	"	x (leftwards black arrow - 2B05)"},
/* 2B96 */ { "EQUALS SIGN WITH INFINITY ABOVE","	= with compensation for the material"},
/* 2B97 */ { "SYMBOL FOR TYPE A ELECTRONICS","	* for type B electronics use 3036\n"
	"	x (circled postal mark - 3036)"},
/* 2B98 */ { "THREE-D TOP-LIGHTED LEFTWARDS EQUILATERAL ARROWHEAD",NULL},
/* 2B99 */ { "THREE-D RIGHT-LIGHTED UPWARDS EQUILATERAL ARROWHEAD",NULL},
/* 2B9A */ { "THREE-D TOP-LIGHTED RIGHTWARDS EQUILATERAL ARROWHEAD","	x (three-d top-lighted rightwards arrowhead - 27A2)"},
/* 2B9B */ { "THREE-D LEFT-LIGHTED DOWNWARDS EQUILATERAL ARROWHEAD",NULL},
/* 2B9C */ { "BLACK LEFTWARDS EQUILATERAL ARROWHEAD",NULL},
/* 2B9D */ { "BLACK UPWARDS EQUILATERAL ARROWHEAD",NULL},
/* 2B9E */ { "BLACK RIGHTWARDS EQUILATERAL ARROWHEAD","	x (black rightwards arrowhead - 27A4)"},
/* 2B9F */ { "BLACK DOWNWARDS EQUILATERAL ARROWHEAD",NULL},
/* 2BA0 */ { "DOWNWARDS TRIANGLE-HEADED ARROW WITH LONG TIP LEFTWARDS","	x (downwards arrow with tip leftwards - 21B2)"},
/* 2BA1 */ { "DOWNWARDS TRIANGLE-HEADED ARROW WITH LONG TIP RIGHTWARDS","	x (downwards arrow with tip rightwards - 21B3)"},
/* 2BA2 */ { "UPWARDS TRIANGLE-HEADED ARROW WITH LONG TIP LEFTWARDS","	x (upwards arrow with tip leftwards - 21B0)"},
/* 2BA3 */ { "UPWARDS TRIANGLE-HEADED ARROW WITH LONG TIP RIGHTWARDS","	x (upwards arrow with tip rightwards - 21B1)"},
/* 2BA4 */ { "LEFTWARDS TRIANGLE-HEADED ARROW WITH LONG TIP UPWARDS","	x (leftwards arrow with tip upwards - 2B11)"},
/* 2BA5 */ { "RIGHTWARDS TRIANGLE-HEADED ARROW WITH LONG TIP UPWARDS","	x (rightwards arrow with tip upwards - 2B0F)"},
/* 2BA6 */ { "LEFTWARDS TRIANGLE-HEADED ARROW WITH LONG TIP DOWNWARDS","	x (leftwards arrow with tip downwards - 2B10)"},
/* 2BA7 */ { "RIGHTWARDS TRIANGLE-HEADED ARROW WITH LONG TIP DOWNWARDS","	x (rightwards arrow with tip downwards - 2B0E)"},
/* 2BA8 */ { "BLACK CURVED DOWNWARDS AND LEFTWARDS ARROW",NULL},
/* 2BA9 */ { "BLACK CURVED DOWNWARDS AND RIGHTWARDS ARROW","	x (heavy black curved downwards and rightwards arrow - 27A5)"},
/* 2BAA */ { "BLACK CURVED UPWARDS AND LEFTWARDS ARROW",NULL},
/* 2BAB */ { "BLACK CURVED UPWARDS AND RIGHTWARDS ARROW","	x (heavy black curved upwards and rightwards arrow - 27A6)"},
/* 2BAC */ { "BLACK CURVED LEFTWARDS AND UPWARDS ARROW",NULL},
/* 2BAD */ { "BLACK CURVED RIGHTWARDS AND UPWARDS ARROW",NULL},
/* 2BAE */ { "BLACK CURVED LEFTWARDS AND DOWNWARDS ARROW",NULL},
/* 2BAF */ { "BLACK CURVED RIGHTWARDS AND DOWNWARDS ARROW",NULL},
/* 2BB0 */ { "RIBBON ARROW DOWN LEFT",NULL},
/* 2BB1 */ { "RIBBON ARROW DOWN RIGHT",NULL},
/* 2BB2 */ { "RIBBON ARROW UP LEFT",NULL},
/* 2BB3 */ { "RIBBON ARROW UP RIGHT",NULL},
/* 2BB4 */ { "RIBBON ARROW LEFT UP",NULL},
/* 2BB5 */ { "RIBBON ARROW RIGHT UP",NULL},
/* 2BB6 */ { "RIBBON ARROW LEFT DOWN",NULL},
/* 2BB7 */ { "RIBBON ARROW RIGHT DOWN",NULL},
/* 2BB8 */ { "UPWARDS WHITE ARROW FROM BAR WITH HORIZONTAL BAR","	= caps lock\n"
	"	x (upwards white arrow on pedestal with horizontal bar - 21EC)"},
/* 2BB9 */ { "UP ARROWHEAD IN A RECTANGLE BOX","	= escape\n"
	"	x (apl functional symbol quad up caret - 2353)"},
/* 2BBA */ { "OVERLAPPING WHITE SQUARES","	= pair of bishops\n"
	"	x (two joined squares - 29C9)"},
/* 2BBB */ { "OVERLAPPING WHITE AND BLACK SQUARES","	= bishops of opposite colour"},
/* 2BBC */ { "OVERLAPPING BLACK SQUARES","	= bishops of the same colour"},
/* 2BBD */ { "BALLOT BOX WITH LIGHT X","	x (ballot box with x - 2612)"},
/* 2BBE */ { "CIRCLED X","	x (circled times - 2297)"},
/* 2BBF */ { "CIRCLED BOLD X",NULL},
/* 2BC0 */ { "BLACK SQUARE CENTRED",NULL},
/* 2BC1 */ { "BLACK DIAMOND CENTRED",NULL},
/* 2BC2 */ { "TURNED BLACK PENTAGON",NULL},
/* 2BC3 */ { "HORIZONTAL BLACK OCTAGON","	x (octagonal sign - 1F6D1)"},
/* 2BC4 */ { "BLACK OCTAGON",NULL},
/* 2BC5 */ { "BLACK MEDIUM UP-POINTING TRIANGLE CENTRED","	x (black up-pointing triangle - 25B2)"},
/* 2BC6 */ { "BLACK MEDIUM DOWN-POINTING TRIANGLE CENTRED","	x (black down-pointing triangle - 25BC)"},
/* 2BC7 */ { "BLACK MEDIUM LEFT-POINTING TRIANGLE CENTRED","	x (black left-pointing triangle - 25C0)"},
/* 2BC8 */ { "BLACK MEDIUM RIGHT-POINTING TRIANGLE CENTRED","	x (black right-pointing triangle - 25B6)"},
/* 2BC9 */ { "NEPTUNE FORM TWO","	x (neptune - 2646)"},
/* 2BCA */ { "TOP HALF BLACK CIRCLE",NULL},
/* 2BCB */ { "BOTTOM HALF BLACK CIRCLE",NULL},
/* 2BCC */ { "LIGHT FOUR POINTED BLACK CUSP","	x (black four pointed star - 2726)"},
/* 2BCD */ { "ROTATED LIGHT FOUR POINTED BLACK CUSP",NULL},
/* 2BCE */ { "WHITE FOUR POINTED CUSP","	x (white four pointed star - 2727)"},
/* 2BCF */ { "ROTATED WHITE FOUR POINTED CUSP","	x (square lozenge - 2311)"},
/* 2BD0 */ { "SQUARE POSITION INDICATOR","	x (position indicator - 2316)"},
/* 2BD1 */ { "UNCERTAINTY SIGN","	= query\n"
	"	x (apl functional symbol quad question - 2370)\n"
	"	x (replacement character - FFFD)"},
/* 2BD2 */ { "GROUP MARK","	* formerly used as a separator character for I/O operations\n"
	"	x (double dagger - 2021)\n"
	"	x (thermodynamic - 29E7)\n"
	"	x (triple dagger - 2E4B)"},
/* 2BD3 */ { "PLUTO FORM TWO","	x (pluto - 2647)"},
/* 2BD4 */ { "PLUTO FORM THREE",NULL},
/* 2BD5 */ { "PLUTO FORM FOUR",NULL},
/* 2BD6 */ { "PLUTO FORM FIVE",NULL},
/* 2BD7 */ { "TRANSPLUTO",NULL},
/* 2BD8 */ { "PROSERPINA","	x (astronomical symbol for asteroid proserpina - 1CECD)"},
/* 2BD9 */ { "ASTRAEA","	x (astraea form two - 1F778)"},
/* 2BDA */ { "HYGIEA","	x (hygiea form two - 1F779)"},
/* 2BDB */ { "PHOLUS",NULL},
/* 2BDC */ { "NESSUS",NULL},
/* 2BDD */ { "WHITE MOON SELENA",NULL},
/* 2BDE */ { "BLACK DIAMOND ON CROSS","	= true black moon Lilith"},
/* 2BDF */ { "TRUE LIGHT MOON ARTA",NULL},
/* 2BE0 */ { "CUPIDO",NULL},
/* 2BE1 */ { "HADES",NULL},
/* 2BE2 */ { "ZEUS",NULL},
/* 2BE3 */ { "KRONOS",NULL},
/* 2BE4 */ { "APOLLON",NULL},
/* 2BE5 */ { "ADMETOS",NULL},
/* 2BE6 */ { "VULCANUS",NULL},
/* 2BE7 */ { "POSEIDON",NULL},
/* 2BE8 */ { "LEFT HALF BLACK STAR","	x (black star - 2605)"},
/* 2BE9 */ { "RIGHT HALF BLACK STAR",NULL},
/* 2BEA */ { "STAR WITH LEFT HALF BLACK",NULL},
/* 2BEB */ { "STAR WITH RIGHT HALF BLACK",NULL},
/* 2BEC */ { "LEFTWARDS TWO-HEADED ARROW WITH TRIANGLE ARROWHEADS","	= fast cursor left\n"
	"	x (leftwards two headed arrow - 219E)"},
/* 2BED */ { "UPWARDS TWO-HEADED ARROW WITH TRIANGLE ARROWHEADS","	= fast cursor up"},
/* 2BEE */ { "RIGHTWARDS TWO-HEADED ARROW WITH TRIANGLE ARROWHEADS","	= fast cursor right"},
/* 2BEF */ { "DOWNWARDS TWO-HEADED ARROW WITH TRIANGLE ARROWHEADS","	= fast cursor down"},
/* 2BF0 */ { "ERIS FORM ONE",NULL},
/* 2BF1 */ { "ERIS FORM TWO",NULL},
/* 2BF2 */ { "SEDNA",NULL},
/* 2BF3 */ { "RUSSIAN ASTROLOGICAL SYMBOL VIGINTILE","	* the vigintile aspect is usually represented by the letter V"},
/* 2BF4 */ { "RUSSIAN ASTROLOGICAL SYMBOL NOVILE","	* the novile aspect is usually represented by the letter N"},
/* 2BF5 */ { "RUSSIAN ASTROLOGICAL SYMBOL QUINTILE","	* the quintile aspect is usually represented by the letter Q"},
/* 2BF6 */ { "RUSSIAN ASTROLOGICAL SYMBOL BINOVILE","	* the binovile aspect is usually represented by the term N²"},
/* 2BF7 */ { "RUSSIAN ASTROLOGICAL SYMBOL SENTAGON","	* represents a 100-degree aspect"},
/* 2BF8 */ { "RUSSIAN ASTROLOGICAL SYMBOL TREDECILE","	* the tredecile aspect is usually represented by the term D³"},
/* 2BF9 */ { "EQUALS SIGN WITH INFINITY BELOW","	= with compensation for the material\n"
	"	x (equals sign with infinity above - 2B96)"},
/* 2BFA */ { "UNITED SYMBOL","	= united pawns\n"
	"	x (divorce symbol - 26AE)\n"
	"	x (two rings aligned horizontally - 1CC88)"},
/* 2BFB */ { "SEPARATED SYMBOL","	= separated pawns\n"
	"	x (unmarried partnership symbol - 26AF)\n"
	"	x (double-ended multimap - 29DF)\n"
	"	x (alchemical symbol for arsenic - 1F73A)"},
/* 2BFC */ { "DOUBLED SYMBOL","	= doubled pawns"},
/* 2BFD */ { "PASSED SYMBOL","	= passed pawn\n"
	"	x (male sign - 2642)"},
/* 2BFE */ { "REVERSED RIGHT ANGLE","	= without\n"
	"	x (right angle - 221F)"},
/* 2BFF */ { "HELLSCHREIBER PAUSE SYMBOL",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_00_2C[] = {
/* 2C00 */ { "GLAGOLITIC CAPITAL LETTER AZU",NULL},
/* 2C01 */ { "GLAGOLITIC CAPITAL LETTER BUKY",NULL},
/* 2C02 */ { "GLAGOLITIC CAPITAL LETTER VEDE",NULL},
/* 2C03 */ { "GLAGOLITIC CAPITAL LETTER GLAGOLI",NULL},
/* 2C04 */ { "GLAGOLITIC CAPITAL LETTER DOBRO",NULL},
/* 2C05 */ { "GLAGOLITIC CAPITAL LETTER YESTU",NULL},
/* 2C06 */ { "GLAGOLITIC CAPITAL LETTER ZHIVETE",NULL},
/* 2C07 */ { "GLAGOLITIC CAPITAL LETTER DZELO",NULL},
/* 2C08 */ { "GLAGOLITIC CAPITAL LETTER ZEMLJA",NULL},
/* 2C09 */ { "GLAGOLITIC CAPITAL LETTER IZHE",NULL},
/* 2C0A */ { "GLAGOLITIC CAPITAL LETTER INITIAL IZHE",NULL},
/* 2C0B */ { "GLAGOLITIC CAPITAL LETTER I",NULL},
/* 2C0C */ { "GLAGOLITIC CAPITAL LETTER DJERVI",NULL},
/* 2C0D */ { "GLAGOLITIC CAPITAL LETTER KAKO",NULL},
/* 2C0E */ { "GLAGOLITIC CAPITAL LETTER LJUDIJE",NULL},
/* 2C0F */ { "GLAGOLITIC CAPITAL LETTER MYSLITE",NULL},
/* 2C10 */ { "GLAGOLITIC CAPITAL LETTER NASHI",NULL},
/* 2C11 */ { "GLAGOLITIC CAPITAL LETTER ONU",NULL},
/* 2C12 */ { "GLAGOLITIC CAPITAL LETTER POKOJI",NULL},
/* 2C13 */ { "GLAGOLITIC CAPITAL LETTER RITSI",NULL},
/* 2C14 */ { "GLAGOLITIC CAPITAL LETTER SLOVO",NULL},
/* 2C15 */ { "GLAGOLITIC CAPITAL LETTER TVRIDO",NULL},
/* 2C16 */ { "GLAGOLITIC CAPITAL LETTER UKU",NULL},
/* 2C17 */ { "GLAGOLITIC CAPITAL LETTER FRITU",NULL},
/* 2C18 */ { "GLAGOLITIC CAPITAL LETTER HERU",NULL},
/* 2C19 */ { "GLAGOLITIC CAPITAL LETTER OTU",NULL},
/* 2C1A */ { "GLAGOLITIC CAPITAL LETTER PE",NULL},
/* 2C1B */ { "GLAGOLITIC CAPITAL LETTER SHTA",NULL},
/* 2C1C */ { "GLAGOLITIC CAPITAL LETTER TSI",NULL},
/* 2C1D */ { "GLAGOLITIC CAPITAL LETTER CHRIVI",NULL},
/* 2C1E */ { "GLAGOLITIC CAPITAL LETTER SHA",NULL},
/* 2C1F */ { "GLAGOLITIC CAPITAL LETTER YERU",NULL},
/* 2C20 */ { "GLAGOLITIC CAPITAL LETTER YERI",NULL},
/* 2C21 */ { "GLAGOLITIC CAPITAL LETTER YATI",NULL},
/* 2C22 */ { "GLAGOLITIC CAPITAL LETTER SPIDERY HA",NULL},
/* 2C23 */ { "GLAGOLITIC CAPITAL LETTER YU",NULL},
/* 2C24 */ { "GLAGOLITIC CAPITAL LETTER SMALL YUS",NULL},
/* 2C25 */ { "GLAGOLITIC CAPITAL LETTER SMALL YUS WITH TAIL",NULL},
/* 2C26 */ { "GLAGOLITIC CAPITAL LETTER YO",NULL},
/* 2C27 */ { "GLAGOLITIC CAPITAL LETTER IOTATED SMALL YUS",NULL},
/* 2C28 */ { "GLAGOLITIC CAPITAL LETTER BIG YUS",NULL},
/* 2C29 */ { "GLAGOLITIC CAPITAL LETTER IOTATED BIG YUS",NULL},
/* 2C2A */ { "GLAGOLITIC CAPITAL LETTER FITA",NULL},
/* 2C2B */ { "GLAGOLITIC CAPITAL LETTER IZHITSA",NULL},
/* 2C2C */ { "GLAGOLITIC CAPITAL LETTER SHTAPIC",NULL},
/* 2C2D */ { "GLAGOLITIC CAPITAL LETTER TROKUTASTI A",NULL},
/* 2C2E */ { "GLAGOLITIC CAPITAL LETTER LATINATE MYSLITE",NULL},
/* 2C2F */ { "GLAGOLITIC CAPITAL LETTER CAUDATE CHRIVI","		This is used as an alternative to Glagolitic letter chrivi, combined with 0303 combining tilde or with 0483 combining Cyrillic titlo as an et cetera sign."},
/* 2C30 */ { "GLAGOLITIC SMALL LETTER AZU",NULL},
/* 2C31 */ { "GLAGOLITIC SMALL LETTER BUKY",NULL},
/* 2C32 */ { "GLAGOLITIC SMALL LETTER VEDE",NULL},
/* 2C33 */ { "GLAGOLITIC SMALL LETTER GLAGOLI",NULL},
/* 2C34 */ { "GLAGOLITIC SMALL LETTER DOBRO",NULL},
/* 2C35 */ { "GLAGOLITIC SMALL LETTER YESTU",NULL},
/* 2C36 */ { "GLAGOLITIC SMALL LETTER ZHIVETE",NULL},
/* 2C37 */ { "GLAGOLITIC SMALL LETTER DZELO",NULL},
/* 2C38 */ { "GLAGOLITIC SMALL LETTER ZEMLJA",NULL},
/* 2C39 */ { "GLAGOLITIC SMALL LETTER IZHE",NULL},
/* 2C3A */ { "GLAGOLITIC SMALL LETTER INITIAL IZHE","	x (cyrillic small letter iota - A647)"},
/* 2C3B */ { "GLAGOLITIC SMALL LETTER I",NULL},
/* 2C3C */ { "GLAGOLITIC SMALL LETTER DJERVI",NULL},
/* 2C3D */ { "GLAGOLITIC SMALL LETTER KAKO",NULL},
/* 2C3E */ { "GLAGOLITIC SMALL LETTER LJUDIJE",NULL},
/* 2C3F */ { "GLAGOLITIC SMALL LETTER MYSLITE",NULL},
/* 2C40 */ { "GLAGOLITIC SMALL LETTER NASHI",NULL},
/* 2C41 */ { "GLAGOLITIC SMALL LETTER ONU",NULL},
/* 2C42 */ { "GLAGOLITIC SMALL LETTER POKOJI",NULL},
/* 2C43 */ { "GLAGOLITIC SMALL LETTER RITSI",NULL},
/* 2C44 */ { "GLAGOLITIC SMALL LETTER SLOVO",NULL},
/* 2C45 */ { "GLAGOLITIC SMALL LETTER TVRIDO",NULL},
/* 2C46 */ { "GLAGOLITIC SMALL LETTER UKU",NULL},
/* 2C47 */ { "GLAGOLITIC SMALL LETTER FRITU",NULL},
/* 2C48 */ { "GLAGOLITIC SMALL LETTER HERU",NULL},
/* 2C49 */ { "GLAGOLITIC SMALL LETTER OTU",NULL},
/* 2C4A */ { "GLAGOLITIC SMALL LETTER PE",NULL},
/* 2C4B */ { "GLAGOLITIC SMALL LETTER SHTA",NULL},
/* 2C4C */ { "GLAGOLITIC SMALL LETTER TSI",NULL},
/* 2C4D */ { "GLAGOLITIC SMALL LETTER CHRIVI",NULL},
/* 2C4E */ { "GLAGOLITIC SMALL LETTER SHA",NULL},
/* 2C4F */ { "GLAGOLITIC SMALL LETTER YERU",NULL},
/* 2C50 */ { "GLAGOLITIC SMALL LETTER YERI",NULL},
/* 2C51 */ { "GLAGOLITIC SMALL LETTER YATI",NULL},
/* 2C52 */ { "GLAGOLITIC SMALL LETTER SPIDERY HA",NULL},
/* 2C53 */ { "GLAGOLITIC SMALL LETTER YU",NULL},
/* 2C54 */ { "GLAGOLITIC SMALL LETTER SMALL YUS",NULL},
/* 2C55 */ { "GLAGOLITIC SMALL LETTER SMALL YUS WITH TAIL",NULL},
/* 2C56 */ { "GLAGOLITIC SMALL LETTER YO",NULL},
/* 2C57 */ { "GLAGOLITIC SMALL LETTER IOTATED SMALL YUS",NULL},
/* 2C58 */ { "GLAGOLITIC SMALL LETTER BIG YUS",NULL},
/* 2C59 */ { "GLAGOLITIC SMALL LETTER IOTATED BIG YUS",NULL},
/* 2C5A */ { "GLAGOLITIC SMALL LETTER FITA",NULL},
/* 2C5B */ { "GLAGOLITIC SMALL LETTER IZHITSA",NULL},
/* 2C5C */ { "GLAGOLITIC SMALL LETTER SHTAPIC",NULL},
/* 2C5D */ { "GLAGOLITIC SMALL LETTER TROKUTASTI A",NULL},
/* 2C5E */ { "GLAGOLITIC SMALL LETTER LATINATE MYSLITE",NULL},
/* 2C5F */ { "GLAGOLITIC SMALL LETTER CAUDATE CHRIVI",NULL},
/* 2C60 */ { "LATIN CAPITAL LETTER L WITH DOUBLE BAR","	x (latin capital letter l with bar - 023D)"},
/* 2C61 */ { "LATIN SMALL LETTER L WITH DOUBLE BAR","	x (latin small letter l with bar - 019A)\n"
	"	x (latin small letter l with double middle tilde - AB38)"},
/* 2C62 */ { "LATIN CAPITAL LETTER L WITH MIDDLE TILDE","	* lowercase is 026B\n"
	"	x (latin capital letter l with stroke - 0141)"},
/* 2C63 */ { "LATIN CAPITAL LETTER P WITH STROKE","	* lowercase is 1D7D"},
/* 2C64 */ { "LATIN CAPITAL LETTER R WITH TAIL","	* lowercase is 027D"},
/* 2C65 */ { "LATIN SMALL LETTER A WITH STROKE","	* uppercase is 023A"},
/* 2C66 */ { "LATIN SMALL LETTER T WITH DIAGONAL STROKE","	* uppercase is 023E"},
/* 2C67 */ { "LATIN CAPITAL LETTER H WITH DESCENDER","	x (cyrillic capital letter en with descender - 04A2)"},
/* 2C68 */ { "LATIN SMALL LETTER H WITH DESCENDER",NULL},
/* 2C69 */ { "LATIN CAPITAL LETTER K WITH DESCENDER","	x (cyrillic capital letter ka with descender - 049A)"},
/* 2C6A */ { "LATIN SMALL LETTER K WITH DESCENDER",NULL},
/* 2C6B */ { "LATIN CAPITAL LETTER Z WITH DESCENDER","	x (latin capital letter z with hook - 0224)"},
/* 2C6C */ { "LATIN SMALL LETTER Z WITH DESCENDER",NULL},
/* 2C6D */ { "LATIN CAPITAL LETTER ALPHA","	= capital script a\n"
	"	* lowercase is 0251"},
/* 2C6E */ { "LATIN CAPITAL LETTER M WITH HOOK","	* lowercase is 0271"},
/* 2C6F */ { "LATIN CAPITAL LETTER TURNED A","	* lowercase is 0250\n"
	"	x (for all - 2200)"},
/* 2C70 */ { "LATIN CAPITAL LETTER TURNED ALPHA","	* lowercase is 0252"},
/* 2C71 */ { "LATIN SMALL LETTER V WITH RIGHT HOOK","	* IPA: voiced labiodental flap"},
/* 2C72 */ { "LATIN CAPITAL LETTER W WITH HOOK",NULL},
/* 2C73 */ { "LATIN SMALL LETTER W WITH HOOK",NULL},
/* 2C74 */ { "LATIN SMALL LETTER V WITH CURL",NULL},
/* 2C75 */ { "LATIN CAPITAL LETTER HALF H","	x (greek capital letter heta - 0370)\n"
	"	x (turned capital f - 2132)\n"
	"	x (roman numeral reversed one hundred - 2183)\n"
	"	x (latin capital letter reversed half h - A7F5)"},
/* 2C76 */ { "LATIN SMALL LETTER HALF H","	x (greek small letter heta - 0371)\n"
	"	x (latin small letter reversed half h - A7F6)"},
/* 2C77 */ { "LATIN SMALL LETTER TAILLESS PHI","	* medium rounded o\n"
	"	x (greek small letter phi - 03C6)"},
/* 2C78 */ { "LATIN SMALL LETTER E WITH NOTCH",NULL},
/* 2C79 */ { "LATIN SMALL LETTER TURNED R WITH TAIL",NULL},
/* 2C7A */ { "LATIN SMALL LETTER O WITH LOW RING INSIDE",NULL},
/* 2C7B */ { "LATIN LETTER SMALL CAPITAL TURNED E","	x (latin capital letter reversed e - 018E)"},
/* 2C7C */ { "LATIN SUBSCRIPT SMALL LETTER J","	# <sub> 006A"},
/* 2C7D */ { "MODIFIER LETTER CAPITAL V","	# <super> 0056"},
/* 2C7E */ { "LATIN CAPITAL LETTER S WITH SWASH TAIL","	* lowercase is 023F\n"
	"	x (latin capital letter s with hook - A7C5)"},
/* 2C7F */ { "LATIN CAPITAL LETTER Z WITH SWASH TAIL","	* lowercase is 0240"},
/* 2C80 */ { "COPTIC CAPITAL LETTER ALFA",NULL},
/* 2C81 */ { "COPTIC SMALL LETTER ALFA",NULL},
/* 2C82 */ { "COPTIC CAPITAL LETTER VIDA",NULL},
/* 2C83 */ { "COPTIC SMALL LETTER VIDA",NULL},
/* 2C84 */ { "COPTIC CAPITAL LETTER GAMMA",NULL},
/* 2C85 */ { "COPTIC SMALL LETTER GAMMA",NULL},
/* 2C86 */ { "COPTIC CAPITAL LETTER DALDA",NULL},
/* 2C87 */ { "COPTIC SMALL LETTER DALDA",NULL},
/* 2C88 */ { "COPTIC CAPITAL LETTER EIE",NULL},
/* 2C89 */ { "COPTIC SMALL LETTER EIE",NULL},
/* 2C8A */ { "COPTIC CAPITAL LETTER SOU",NULL},
/* 2C8B */ { "COPTIC SMALL LETTER SOU",NULL},
/* 2C8C */ { "COPTIC CAPITAL LETTER ZATA",NULL},
/* 2C8D */ { "COPTIC SMALL LETTER ZATA",NULL},
/* 2C8E */ { "COPTIC CAPITAL LETTER HATE",NULL},
/* 2C8F */ { "COPTIC SMALL LETTER HATE",NULL},
/* 2C90 */ { "COPTIC CAPITAL LETTER THETHE",NULL},
/* 2C91 */ { "COPTIC SMALL LETTER THETHE",NULL},
/* 2C92 */ { "COPTIC CAPITAL LETTER IAUDA",NULL},
/* 2C93 */ { "COPTIC SMALL LETTER IAUDA",NULL},
/* 2C94 */ { "COPTIC CAPITAL LETTER KAPA",NULL},
/* 2C95 */ { "COPTIC SMALL LETTER KAPA",NULL},
/* 2C96 */ { "COPTIC CAPITAL LETTER LAULA",NULL},
/* 2C97 */ { "COPTIC SMALL LETTER LAULA",NULL},
/* 2C98 */ { "COPTIC CAPITAL LETTER MI",NULL},
/* 2C99 */ { "COPTIC SMALL LETTER MI",NULL},
/* 2C9A */ { "COPTIC CAPITAL LETTER NI",NULL},
/* 2C9B */ { "COPTIC SMALL LETTER NI",NULL},
/* 2C9C */ { "COPTIC CAPITAL LETTER KSI",NULL},
/* 2C9D */ { "COPTIC SMALL LETTER KSI",NULL},
/* 2C9E */ { "COPTIC CAPITAL LETTER O",NULL},
/* 2C9F */ { "COPTIC SMALL LETTER O",NULL},
/* 2CA0 */ { "COPTIC CAPITAL LETTER PI",NULL},
/* 2CA1 */ { "COPTIC SMALL LETTER PI",NULL},
/* 2CA2 */ { "COPTIC CAPITAL LETTER RO",NULL},
/* 2CA3 */ { "COPTIC SMALL LETTER RO",NULL},
/* 2CA4 */ { "COPTIC CAPITAL LETTER SIMA",NULL},
/* 2CA5 */ { "COPTIC SMALL LETTER SIMA",NULL},
/* 2CA6 */ { "COPTIC CAPITAL LETTER TAU",NULL},
/* 2CA7 */ { "COPTIC SMALL LETTER TAU",NULL},
/* 2CA8 */ { "COPTIC CAPITAL LETTER UA",NULL},
/* 2CA9 */ { "COPTIC SMALL LETTER UA",NULL},
/* 2CAA */ { "COPTIC CAPITAL LETTER FI",NULL},
/* 2CAB */ { "COPTIC SMALL LETTER FI",NULL},
/* 2CAC */ { "COPTIC CAPITAL LETTER KHI",NULL},
/* 2CAD */ { "COPTIC SMALL LETTER KHI",NULL},
/* 2CAE */ { "COPTIC CAPITAL LETTER PSI",NULL},
/* 2CAF */ { "COPTIC SMALL LETTER PSI",NULL},
/* 2CB0 */ { "COPTIC CAPITAL LETTER OOU",NULL},
/* 2CB1 */ { "COPTIC SMALL LETTER OOU",NULL},
/* 2CB2 */ { "COPTIC CAPITAL LETTER DIALECT-P ALEF",NULL},
/* 2CB3 */ { "COPTIC SMALL LETTER DIALECT-P ALEF",NULL},
/* 2CB4 */ { "COPTIC CAPITAL LETTER OLD COPTIC AIN",NULL},
/* 2CB5 */ { "COPTIC SMALL LETTER OLD COPTIC AIN",NULL},
/* 2CB6 */ { "COPTIC CAPITAL LETTER CRYPTOGRAMMIC EIE",NULL},
/* 2CB7 */ { "COPTIC SMALL LETTER CRYPTOGRAMMIC EIE",NULL},
/* 2CB8 */ { "COPTIC CAPITAL LETTER DIALECT-P KAPA",NULL},
/* 2CB9 */ { "COPTIC SMALL LETTER DIALECT-P KAPA",NULL},
/* 2CBA */ { "COPTIC CAPITAL LETTER DIALECT-P NI",NULL},
/* 2CBB */ { "COPTIC SMALL LETTER DIALECT-P NI",NULL},
/* 2CBC */ { "COPTIC CAPITAL LETTER CRYPTOGRAMMIC NI",NULL},
/* 2CBD */ { "COPTIC SMALL LETTER CRYPTOGRAMMIC NI",NULL},
/* 2CBE */ { "COPTIC CAPITAL LETTER OLD COPTIC OOU",NULL},
/* 2CBF */ { "COPTIC SMALL LETTER OLD COPTIC OOU",NULL},
/* 2CC0 */ { "COPTIC CAPITAL LETTER SAMPI",NULL},
/* 2CC1 */ { "COPTIC SMALL LETTER SAMPI",NULL},
/* 2CC2 */ { "COPTIC CAPITAL LETTER CROSSED SHEI",NULL},
/* 2CC3 */ { "COPTIC SMALL LETTER CROSSED SHEI",NULL},
/* 2CC4 */ { "COPTIC CAPITAL LETTER OLD COPTIC SHEI",NULL},
/* 2CC5 */ { "COPTIC SMALL LETTER OLD COPTIC SHEI",NULL},
/* 2CC6 */ { "COPTIC CAPITAL LETTER OLD COPTIC ESH",NULL},
/* 2CC7 */ { "COPTIC SMALL LETTER OLD COPTIC ESH",NULL},
/* 2CC8 */ { "COPTIC CAPITAL LETTER AKHMIMIC KHEI",NULL},
/* 2CC9 */ { "COPTIC SMALL LETTER AKHMIMIC KHEI",NULL},
/* 2CCA */ { "COPTIC CAPITAL LETTER DIALECT-P HORI",NULL},
/* 2CCB */ { "COPTIC SMALL LETTER DIALECT-P HORI",NULL},
/* 2CCC */ { "COPTIC CAPITAL LETTER OLD COPTIC HORI",NULL},
/* 2CCD */ { "COPTIC SMALL LETTER OLD COPTIC HORI",NULL},
/* 2CCE */ { "COPTIC CAPITAL LETTER OLD COPTIC HA",NULL},
/* 2CCF */ { "COPTIC SMALL LETTER OLD COPTIC HA",NULL},
/* 2CD0 */ { "COPTIC CAPITAL LETTER L-SHAPED HA",NULL},
/* 2CD1 */ { "COPTIC SMALL LETTER L-SHAPED HA",NULL},
/* 2CD2 */ { "COPTIC CAPITAL LETTER OLD COPTIC HEI",NULL},
/* 2CD3 */ { "COPTIC SMALL LETTER OLD COPTIC HEI",NULL},
/* 2CD4 */ { "COPTIC CAPITAL LETTER OLD COPTIC HAT",NULL},
/* 2CD5 */ { "COPTIC SMALL LETTER OLD COPTIC HAT",NULL},
/* 2CD6 */ { "COPTIC CAPITAL LETTER OLD COPTIC GANGIA",NULL},
/* 2CD7 */ { "COPTIC SMALL LETTER OLD COPTIC GANGIA",NULL},
/* 2CD8 */ { "COPTIC CAPITAL LETTER OLD COPTIC DJA",NULL},
/* 2CD9 */ { "COPTIC SMALL LETTER OLD COPTIC DJA",NULL},
/* 2CDA */ { "COPTIC CAPITAL LETTER OLD COPTIC SHIMA",NULL},
/* 2CDB */ { "COPTIC SMALL LETTER OLD COPTIC SHIMA",NULL},
/* 2CDC */ { "COPTIC CAPITAL LETTER OLD NUBIAN SHIMA",NULL},
/* 2CDD */ { "COPTIC SMALL LETTER OLD NUBIAN SHIMA",NULL},
/* 2CDE */ { "COPTIC CAPITAL LETTER OLD NUBIAN NGI",NULL},
/* 2CDF */ { "COPTIC SMALL LETTER OLD NUBIAN NGI",NULL},
/* 2CE0 */ { "COPTIC CAPITAL LETTER OLD NUBIAN NYI",NULL},
/* 2CE1 */ { "COPTIC SMALL LETTER OLD NUBIAN NYI",NULL},
/* 2CE2 */ { "COPTIC CAPITAL LETTER OLD NUBIAN WAU",NULL},
/* 2CE3 */ { "COPTIC SMALL LETTER OLD NUBIAN WAU",NULL},
/* 2CE4 */ { "COPTIC SYMBOL KAI","	x (greek kai symbol - 03D7)"},
/* 2CE5 */ { "COPTIC SYMBOL MI RO",NULL},
/* 2CE6 */ { "COPTIC SYMBOL PI RO",NULL},
/* 2CE7 */ { "COPTIC SYMBOL STAUROS",NULL},
/* 2CE8 */ { "COPTIC SYMBOL TAU RO","	x (greek symbol tau rho - 101A0)"},
/* 2CE9 */ { "COPTIC SYMBOL KHI RO","	x (chi rho - 2627)"},
/* 2CEA */ { "COPTIC SYMBOL SHIMA SIMA",NULL},
/* 2CEB */ { "COPTIC CAPITAL LETTER CRYPTOGRAMMIC SHEI",NULL},
/* 2CEC */ { "COPTIC SMALL LETTER CRYPTOGRAMMIC SHEI",NULL},
/* 2CED */ { "COPTIC CAPITAL LETTER CRYPTOGRAMMIC GANGIA",NULL},
/* 2CEE */ { "COPTIC SMALL LETTER CRYPTOGRAMMIC GANGIA",NULL},
/* 2CEF */ { "COPTIC COMBINING NI ABOVE","	* this mark is used in final position and extends above the following character (usually a space)"},
/* 2CF0 */ { "COPTIC COMBINING SPIRITUS ASPER","	x (combining reversed comma above - 0314)\n"
	"	x (combining cyrillic dasia pneumata - 0485)"},
/* 2CF1 */ { "COPTIC COMBINING SPIRITUS LENIS","	x (combining comma above - 0313)\n"
	"	x (combining cyrillic psili pneumata - 0486)"},
/* 2CF2 */ { "COPTIC CAPITAL LETTER BOHAIRIC KHEI","	x (coptic capital letter khei - 03E6)"},
/* 2CF3 */ { "COPTIC SMALL LETTER BOHAIRIC KHEI","	x (coptic small letter khei - 03E7)"},
/* 2CF4 */ { NULL,NULL},
/* 2CF5 */ { NULL,NULL},
/* 2CF6 */ { NULL,NULL},
/* 2CF7 */ { NULL,NULL},
/* 2CF8 */ { NULL,NULL},
/* 2CF9 */ { "COPTIC OLD NUBIAN FULL STOP",NULL},
/* 2CFA */ { "COPTIC OLD NUBIAN DIRECT QUESTION MARK",NULL},
/* 2CFB */ { "COPTIC OLD NUBIAN INDIRECT QUESTION MARK",NULL},
/* 2CFC */ { "COPTIC OLD NUBIAN VERSE DIVIDER",NULL},
/* 2CFD */ { "COPTIC FRACTION ONE HALF",NULL},
/* 2CFE */ { "COPTIC FULL STOP",NULL},
/* 2CFF */ { "COPTIC MORPHOLOGICAL DIVIDER",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_00_2D[] = {
/* 2D00 */ { "GEORGIAN SMALL LETTER AN","	x (georgian capital letter an - 10A0)"},
/* 2D01 */ { "GEORGIAN SMALL LETTER BAN",NULL},
/* 2D02 */ { "GEORGIAN SMALL LETTER GAN",NULL},
/* 2D03 */ { "GEORGIAN SMALL LETTER DON",NULL},
/* 2D04 */ { "GEORGIAN SMALL LETTER EN",NULL},
/* 2D05 */ { "GEORGIAN SMALL LETTER VIN",NULL},
/* 2D06 */ { "GEORGIAN SMALL LETTER ZEN",NULL},
/* 2D07 */ { "GEORGIAN SMALL LETTER TAN",NULL},
/* 2D08 */ { "GEORGIAN SMALL LETTER IN",NULL},
/* 2D09 */ { "GEORGIAN SMALL LETTER KAN",NULL},
/* 2D0A */ { "GEORGIAN SMALL LETTER LAS",NULL},
/* 2D0B */ { "GEORGIAN SMALL LETTER MAN",NULL},
/* 2D0C */ { "GEORGIAN SMALL LETTER NAR",NULL},
/* 2D0D */ { "GEORGIAN SMALL LETTER ON",NULL},
/* 2D0E */ { "GEORGIAN SMALL LETTER PAR",NULL},
/* 2D0F */ { "GEORGIAN SMALL LETTER ZHAR",NULL},
/* 2D10 */ { "GEORGIAN SMALL LETTER RAE",NULL},
/* 2D11 */ { "GEORGIAN SMALL LETTER SAN",NULL},
/* 2D12 */ { "GEORGIAN SMALL LETTER TAR",NULL},
/* 2D13 */ { "GEORGIAN SMALL LETTER UN",NULL},
/* 2D14 */ { "GEORGIAN SMALL LETTER PHAR",NULL},
/* 2D15 */ { "GEORGIAN SMALL LETTER KHAR",NULL},
/* 2D16 */ { "GEORGIAN SMALL LETTER GHAN",NULL},
/* 2D17 */ { "GEORGIAN SMALL LETTER QAR",NULL},
/* 2D18 */ { "GEORGIAN SMALL LETTER SHIN",NULL},
/* 2D19 */ { "GEORGIAN SMALL LETTER CHIN",NULL},
/* 2D1A */ { "GEORGIAN SMALL LETTER CAN",NULL},
/* 2D1B */ { "GEORGIAN SMALL LETTER JIL",NULL},
/* 2D1C */ { "GEORGIAN SMALL LETTER CIL",NULL},
/* 2D1D */ { "GEORGIAN SMALL LETTER CHAR",NULL},
/* 2D1E */ { "GEORGIAN SMALL LETTER XAN",NULL},
/* 2D1F */ { "GEORGIAN SMALL LETTER JHAN",NULL},
/* 2D20 */ { "GEORGIAN SMALL LETTER HAE",NULL},
/* 2D21 */ { "GEORGIAN SMALL LETTER HE",NULL},
/* 2D22 */ { "GEORGIAN SMALL LETTER HIE",NULL},
/* 2D23 */ { "GEORGIAN SMALL LETTER WE",NULL},
/* 2D24 */ { "GEORGIAN SMALL LETTER HAR",NULL},
/* 2D25 */ { "GEORGIAN SMALL LETTER HOE",NULL},
/* 2D26 */ { NULL,NULL},
/* 2D27 */ { "GEORGIAN SMALL LETTER YN",NULL},
/* 2D28 */ { NULL,NULL},
/* 2D29 */ { NULL,NULL},
/* 2D2A */ { NULL,NULL},
/* 2D2B */ { NULL,NULL},
/* 2D2C */ { NULL,NULL},
/* 2D2D */ { "GEORGIAN SMALL LETTER AEN",NULL},
/* 2D2E */ { NULL,NULL},
/* 2D2F */ { NULL,NULL},
/* 2D30 */ { "TIFINAGH LETTER YA",NULL},
/* 2D31 */ { "TIFINAGH LETTER YAB",NULL},
/* 2D32 */ { "TIFINAGH LETTER YABH",NULL},
/* 2D33 */ { "TIFINAGH LETTER YAG",NULL},
/* 2D34 */ { "TIFINAGH LETTER YAGHH",NULL},
/* 2D35 */ { "TIFINAGH LETTER BERBER ACADEMY YAJ",NULL},
/* 2D36 */ { "TIFINAGH LETTER YAJ",NULL},
/* 2D37 */ { "TIFINAGH LETTER YAD",NULL},
/* 2D38 */ { "TIFINAGH LETTER YADH",NULL},
/* 2D39 */ { "TIFINAGH LETTER YADD",NULL},
/* 2D3A */ { "TIFINAGH LETTER YADDH",NULL},
/* 2D3B */ { "TIFINAGH LETTER YEY",NULL},
/* 2D3C */ { "TIFINAGH LETTER YAF",NULL},
/* 2D3D */ { "TIFINAGH LETTER YAK",NULL},
/* 2D3E */ { "TIFINAGH LETTER TUAREG YAK",NULL},
/* 2D3F */ { "TIFINAGH LETTER YAKHH",NULL},
/* 2D40 */ { "TIFINAGH LETTER YAH","	= Tuareg yab"},
/* 2D41 */ { "TIFINAGH LETTER BERBER ACADEMY YAH",NULL},
/* 2D42 */ { "TIFINAGH LETTER TUAREG YAH",NULL},
/* 2D43 */ { "TIFINAGH LETTER YAHH",NULL},
/* 2D44 */ { "TIFINAGH LETTER YAA",NULL},
/* 2D45 */ { "TIFINAGH LETTER YAKH",NULL},
/* 2D46 */ { "TIFINAGH LETTER TUAREG YAKH",NULL},
/* 2D47 */ { "TIFINAGH LETTER YAQ",NULL},
/* 2D48 */ { "TIFINAGH LETTER TUAREG YAQ",NULL},
/* 2D49 */ { "TIFINAGH LETTER YI",NULL},
/* 2D4A */ { "TIFINAGH LETTER YAZH",NULL},
/* 2D4B */ { "TIFINAGH LETTER AHAGGAR YAZH",NULL},
/* 2D4C */ { "TIFINAGH LETTER TUAREG YAZH",NULL},
/* 2D4D */ { "TIFINAGH LETTER YAL",NULL},
/* 2D4E */ { "TIFINAGH LETTER YAM",NULL},
/* 2D4F */ { "TIFINAGH LETTER YAN",NULL},
/* 2D50 */ { "TIFINAGH LETTER TUAREG YAGN",NULL},
/* 2D51 */ { "TIFINAGH LETTER TUAREG YANG",NULL},
/* 2D52 */ { "TIFINAGH LETTER YAP",NULL},
/* 2D53 */ { "TIFINAGH LETTER YU","	= Tuareg yaw"},
/* 2D54 */ { "TIFINAGH LETTER YAR",NULL},
/* 2D55 */ { "TIFINAGH LETTER YARR",NULL},
/* 2D56 */ { "TIFINAGH LETTER YAGH",NULL},
/* 2D57 */ { "TIFINAGH LETTER TUAREG YAGH",NULL},
/* 2D58 */ { "TIFINAGH LETTER AYER YAGH","	= Adrar yaj"},
/* 2D59 */ { "TIFINAGH LETTER YAS",NULL},
/* 2D5A */ { "TIFINAGH LETTER YASS",NULL},
/* 2D5B */ { "TIFINAGH LETTER YASH",NULL},
/* 2D5C */ { "TIFINAGH LETTER YAT",NULL},
/* 2D5D */ { "TIFINAGH LETTER YATH",NULL},
/* 2D5E */ { "TIFINAGH LETTER YACH",NULL},
/* 2D5F */ { "TIFINAGH LETTER YATT",NULL},
/* 2D60 */ { "TIFINAGH LETTER YAV",NULL},
/* 2D61 */ { "TIFINAGH LETTER YAW",NULL},
/* 2D62 */ { "TIFINAGH LETTER YAY",NULL},
/* 2D63 */ { "TIFINAGH LETTER YAZ",NULL},
/* 2D64 */ { "TIFINAGH LETTER TAWELLEMET YAZ","	= harpoon yaz"},
/* 2D65 */ { "TIFINAGH LETTER YAZZ",NULL},
/* 2D66 */ { "TIFINAGH LETTER YE",NULL},
/* 2D67 */ { "TIFINAGH LETTER YO",NULL},
/* 2D68 */ { NULL,NULL},
/* 2D69 */ { NULL,NULL},
/* 2D6A */ { NULL,NULL},
/* 2D6B */ { NULL,NULL},
/* 2D6C */ { NULL,NULL},
/* 2D6D */ { NULL,NULL},
/* 2D6E */ { NULL,NULL},
/* 2D6F */ { "TIFINAGH MODIFIER LETTER LABIALIZATION MARK","	= tamatart\n"
	"	# <super> 2D61"},
/* 2D70 */ { "TIFINAGH SEPARATOR MARK","	= tazarast"},
/* 2D71 */ { NULL,NULL},
/* 2D72 */ { NULL,NULL},
/* 2D73 */ { NULL,NULL},
/* 2D74 */ { NULL,NULL},
/* 2D75 */ { NULL,NULL},
/* 2D76 */ { NULL,NULL},
/* 2D77 */ { NULL,NULL},
/* 2D78 */ { NULL,NULL},
/* 2D79 */ { NULL,NULL},
/* 2D7A */ { NULL,NULL},
/* 2D7B */ { NULL,NULL},
/* 2D7C */ { NULL,NULL},
/* 2D7D */ { NULL,NULL},
/* 2D7E */ { NULL,NULL},
/* 2D7F */ { "TIFINAGH CONSONANT JOINER","	* suppresses an inherent vowel\n"
	"	* functions to indicate that previous and following character are part of a bi-consonant cluster\n"
	"	* shape shown is arbitrary and is not visibly rendered"},
/* 2D80 */ { "ETHIOPIC SYLLABLE LOA",NULL},
/* 2D81 */ { "ETHIOPIC SYLLABLE MOA",NULL},
/* 2D82 */ { "ETHIOPIC SYLLABLE ROA",NULL},
/* 2D83 */ { "ETHIOPIC SYLLABLE SOA",NULL},
/* 2D84 */ { "ETHIOPIC SYLLABLE SHOA",NULL},
/* 2D85 */ { "ETHIOPIC SYLLABLE BOA",NULL},
/* 2D86 */ { "ETHIOPIC SYLLABLE TOA",NULL},
/* 2D87 */ { "ETHIOPIC SYLLABLE COA",NULL},
/* 2D88 */ { "ETHIOPIC SYLLABLE NOA",NULL},
/* 2D89 */ { "ETHIOPIC SYLLABLE NYOA",NULL},
/* 2D8A */ { "ETHIOPIC SYLLABLE GLOTTAL OA",NULL},
/* 2D8B */ { "ETHIOPIC SYLLABLE ZOA",NULL},
/* 2D8C */ { "ETHIOPIC SYLLABLE DOA",NULL},
/* 2D8D */ { "ETHIOPIC SYLLABLE DDOA",NULL},
/* 2D8E */ { "ETHIOPIC SYLLABLE JOA",NULL},
/* 2D8F */ { "ETHIOPIC SYLLABLE THOA",NULL},
/* 2D90 */ { "ETHIOPIC SYLLABLE CHOA",NULL},
/* 2D91 */ { "ETHIOPIC SYLLABLE PHOA",NULL},
/* 2D92 */ { "ETHIOPIC SYLLABLE POA",NULL},
/* 2D93 */ { "ETHIOPIC SYLLABLE GGWA",NULL},
/* 2D94 */ { "ETHIOPIC SYLLABLE GGWI",NULL},
/* 2D95 */ { "ETHIOPIC SYLLABLE GGWEE",NULL},
/* 2D96 */ { "ETHIOPIC SYLLABLE GGWE",NULL},
/* 2D97 */ { NULL,NULL},
/* 2D98 */ { NULL,NULL},
/* 2D99 */ { NULL,NULL},
/* 2D9A */ { NULL,NULL},
/* 2D9B */ { NULL,NULL},
/* 2D9C */ { NULL,NULL},
/* 2D9D */ { NULL,NULL},
/* 2D9E */ { NULL,NULL},
/* 2D9F */ { NULL,NULL},
/* 2DA0 */ { "ETHIOPIC SYLLABLE SSA",NULL},
/* 2DA1 */ { "ETHIOPIC SYLLABLE SSU",NULL},
/* 2DA2 */ { "ETHIOPIC SYLLABLE SSI",NULL},
/* 2DA3 */ { "ETHIOPIC SYLLABLE SSAA",NULL},
/* 2DA4 */ { "ETHIOPIC SYLLABLE SSEE",NULL},
/* 2DA5 */ { "ETHIOPIC SYLLABLE SSE",NULL},
/* 2DA6 */ { "ETHIOPIC SYLLABLE SSO",NULL},
/* 2DA7 */ { NULL,NULL},
/* 2DA8 */ { "ETHIOPIC SYLLABLE CCA",NULL},
/* 2DA9 */ { "ETHIOPIC SYLLABLE CCU",NULL},
/* 2DAA */ { "ETHIOPIC SYLLABLE CCI",NULL},
/* 2DAB */ { "ETHIOPIC SYLLABLE CCAA",NULL},
/* 2DAC */ { "ETHIOPIC SYLLABLE CCEE",NULL},
/* 2DAD */ { "ETHIOPIC SYLLABLE CCE",NULL},
/* 2DAE */ { "ETHIOPIC SYLLABLE CCO",NULL},
/* 2DAF */ { NULL,NULL},
/* 2DB0 */ { "ETHIOPIC SYLLABLE ZZA",NULL},
/* 2DB1 */ { "ETHIOPIC SYLLABLE ZZU",NULL},
/* 2DB2 */ { "ETHIOPIC SYLLABLE ZZI",NULL},
/* 2DB3 */ { "ETHIOPIC SYLLABLE ZZAA",NULL},
/* 2DB4 */ { "ETHIOPIC SYLLABLE ZZEE",NULL},
/* 2DB5 */ { "ETHIOPIC SYLLABLE ZZE",NULL},
/* 2DB6 */ { "ETHIOPIC SYLLABLE ZZO",NULL},
/* 2DB7 */ { NULL,NULL},
/* 2DB8 */ { "ETHIOPIC SYLLABLE CCHA",NULL},
/* 2DB9 */ { "ETHIOPIC SYLLABLE CCHU",NULL},
/* 2DBA */ { "ETHIOPIC SYLLABLE CCHI",NULL},
/* 2DBB */ { "ETHIOPIC SYLLABLE CCHAA",NULL},
/* 2DBC */ { "ETHIOPIC SYLLABLE CCHEE",NULL},
/* 2DBD */ { "ETHIOPIC SYLLABLE CCHE",NULL},
/* 2DBE */ { "ETHIOPIC SYLLABLE CCHO",NULL},
/* 2DBF */ { NULL,NULL},
/* 2DC0 */ { "ETHIOPIC SYLLABLE QYA",NULL},
/* 2DC1 */ { "ETHIOPIC SYLLABLE QYU",NULL},
/* 2DC2 */ { "ETHIOPIC SYLLABLE QYI",NULL},
/* 2DC3 */ { "ETHIOPIC SYLLABLE QYAA",NULL},
/* 2DC4 */ { "ETHIOPIC SYLLABLE QYEE",NULL},
/* 2DC5 */ { "ETHIOPIC SYLLABLE QYE",NULL},
/* 2DC6 */ { "ETHIOPIC SYLLABLE QYO",NULL},
/* 2DC7 */ { NULL,NULL},
/* 2DC8 */ { "ETHIOPIC SYLLABLE KYA",NULL},
/* 2DC9 */ { "ETHIOPIC SYLLABLE KYU",NULL},
/* 2DCA */ { "ETHIOPIC SYLLABLE KYI",NULL},
/* 2DCB */ { "ETHIOPIC SYLLABLE KYAA",NULL},
/* 2DCC */ { "ETHIOPIC SYLLABLE KYEE",NULL},
/* 2DCD */ { "ETHIOPIC SYLLABLE KYE",NULL},
/* 2DCE */ { "ETHIOPIC SYLLABLE KYO",NULL},
/* 2DCF */ { NULL,NULL},
/* 2DD0 */ { "ETHIOPIC SYLLABLE XYA","	x (ethiopic syllable hhya - 1E7E0)"},
/* 2DD1 */ { "ETHIOPIC SYLLABLE XYU","	x (ethiopic syllable hhyu - 1E7E1)"},
/* 2DD2 */ { "ETHIOPIC SYLLABLE XYI","	x (ethiopic syllable hhyi - 1E7E2)"},
/* 2DD3 */ { "ETHIOPIC SYLLABLE XYAA","	x (ethiopic syllable hhyaa - 1E7E3)"},
/* 2DD4 */ { "ETHIOPIC SYLLABLE XYEE","	x (ethiopic syllable hhyee - 1E7E4)"},
/* 2DD5 */ { "ETHIOPIC SYLLABLE XYE","	x (ethiopic syllable hhye - 1E7E5)"},
/* 2DD6 */ { "ETHIOPIC SYLLABLE XYO","	x (ethiopic syllable hhyo - 1E7E6)"},
/* 2DD7 */ { NULL,NULL},
/* 2DD8 */ { "ETHIOPIC SYLLABLE GYA",NULL},
/* 2DD9 */ { "ETHIOPIC SYLLABLE GYU",NULL},
/* 2DDA */ { "ETHIOPIC SYLLABLE GYI",NULL},
/* 2DDB */ { "ETHIOPIC SYLLABLE GYAA",NULL},
/* 2DDC */ { "ETHIOPIC SYLLABLE GYEE",NULL},
/* 2DDD */ { "ETHIOPIC SYLLABLE GYE",NULL},
/* 2DDE */ { "ETHIOPIC SYLLABLE GYO",NULL},
/* 2DDF */ { NULL,NULL},
/* 2DE0 */ { "COMBINING CYRILLIC LETTER BE",NULL},
/* 2DE1 */ { "COMBINING CYRILLIC LETTER VE",NULL},
/* 2DE2 */ { "COMBINING CYRILLIC LETTER GHE",NULL},
/* 2DE3 */ { "COMBINING CYRILLIC LETTER DE",NULL},
/* 2DE4 */ { "COMBINING CYRILLIC LETTER ZHE",NULL},
/* 2DE5 */ { "COMBINING CYRILLIC LETTER ZE",NULL},
/* 2DE6 */ { "COMBINING CYRILLIC LETTER KA",NULL},
/* 2DE7 */ { "COMBINING CYRILLIC LETTER EL",NULL},
/* 2DE8 */ { "COMBINING CYRILLIC LETTER EM","	x (combining latin letter small capital m - 1DDF)"},
/* 2DE9 */ { "COMBINING CYRILLIC LETTER EN",NULL},
/* 2DEA */ { "COMBINING CYRILLIC LETTER O","	x (combining latin small letter o - 0366)"},
/* 2DEB */ { "COMBINING CYRILLIC LETTER PE",NULL},
/* 2DEC */ { "COMBINING CYRILLIC LETTER ER",NULL},
/* 2DED */ { "COMBINING CYRILLIC LETTER ES","	x (combining latin small letter c - 0368)"},
/* 2DEE */ { "COMBINING CYRILLIC LETTER TE",NULL},
/* 2DEF */ { "COMBINING CYRILLIC LETTER HA","	x (combining latin small letter x - 036F)"},
/* 2DF0 */ { "COMBINING CYRILLIC LETTER TSE",NULL},
/* 2DF1 */ { "COMBINING CYRILLIC LETTER CHE",NULL},
/* 2DF2 */ { "COMBINING CYRILLIC LETTER SHA",NULL},
/* 2DF3 */ { "COMBINING CYRILLIC LETTER SHCHA",NULL},
/* 2DF4 */ { "COMBINING CYRILLIC LETTER FITA",NULL},
/* 2DF5 */ { "COMBINING CYRILLIC LETTER ES-TE","	* preferred representation is the sequence: 2DED 2DEE"},
/* 2DF6 */ { "COMBINING CYRILLIC LETTER A","	x (combining latin small letter a - 0363)"},
/* 2DF7 */ { "COMBINING CYRILLIC LETTER IE","	x (combining latin small letter e - 0364)"},
/* 2DF8 */ { "COMBINING CYRILLIC LETTER DJERV",NULL},
/* 2DF9 */ { "COMBINING CYRILLIC LETTER MONOGRAPH UK",NULL},
/* 2DFA */ { "COMBINING CYRILLIC LETTER YAT",NULL},
/* 2DFB */ { "COMBINING CYRILLIC LETTER YU",NULL},
/* 2DFC */ { "COMBINING CYRILLIC LETTER IOTIFIED A",NULL},
/* 2DFD */ { "COMBINING CYRILLIC LETTER LITTLE YUS",NULL},
/* 2DFE */ { "COMBINING CYRILLIC LETTER BIG YUS",NULL},
/* 2DFF */ { "COMBINING CYRILLIC LETTER IOTIFIED BIG YUS",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_00_2E[] = {
/* 2E00 */ { "RIGHT ANGLE SUBSTITUTION MARKER","	x (top left corner - 231C)"},
/* 2E01 */ { "RIGHT ANGLE DOTTED SUBSTITUTION MARKER",NULL},
/* 2E02 */ { "LEFT SUBSTITUTION BRACKET",NULL},
/* 2E03 */ { "RIGHT SUBSTITUTION BRACKET",NULL},
/* 2E04 */ { "LEFT DOTTED SUBSTITUTION BRACKET",NULL},
/* 2E05 */ { "RIGHT DOTTED SUBSTITUTION BRACKET",NULL},
/* 2E06 */ { "RAISED INTERPOLATION MARKER","	x (down tack - 22A4)"},
/* 2E07 */ { "RAISED DOTTED INTERPOLATION MARKER",NULL},
/* 2E08 */ { "DOTTED TRANSPOSITION MARKER",NULL},
/* 2E09 */ { "LEFT TRANSPOSITION BRACKET",NULL},
/* 2E0A */ { "RIGHT TRANSPOSITION BRACKET",NULL},
/* 2E0B */ { "RAISED SQUARE","	* used as an opening raised omission bracket"},
/* 2E0C */ { "LEFT RAISED OMISSION BRACKET","	* used as an opening or closing raised omission bracket"},
/* 2E0D */ { "RIGHT RAISED OMISSION BRACKET","	* used as a closing or opening raised omission bracket"},
/* 2E0E */ { "EDITORIAL CORONIS","	x (greek koronis - 1FBD)"},
/* 2E0F */ { "PARAGRAPHOS",NULL},
/* 2E10 */ { "FORKED PARAGRAPHOS",NULL},
/* 2E11 */ { "REVERSED FORKED PARAGRAPHOS",NULL},
/* 2E12 */ { "HYPODIASTOLE","	= ypodiastoli"},
/* 2E13 */ { "DOTTED OBELOS","	* glyph variants may look like '00F7' or '2238'\n"
	"	x (commercial minus sign - 2052)"},
/* 2E14 */ { "DOWNWARDS ANCORA","	* contrary to its formal name this symbol points upwards"},
/* 2E15 */ { "UPWARDS ANCORA","	* contrary to its formal name this symbol points downwards"},
/* 2E16 */ { "DOTTED RIGHT-POINTING ANGLE","	= diple periestigmene"},
/* 2E17 */ { "DOUBLE OBLIQUE HYPHEN","	* used in ancient Near-Eastern linguistics\n"
	"	* hyphen in Fraktur text uses 002D or 2010, but with a '2E17' glyph in Fraktur fonts\n"
	"	x (hyphen-minus - 002D)\n"
	"	x (equals sign - 003D)\n"
	"	x (hyphen - 2010)\n"
	"	x (double hyphen - 2E40)\n"
	"	x (oblique hyphen - 2E5D)"},
/* 2E18 */ { "INVERTED INTERROBANG","	= gnaborretni\n"
	"	x (interrobang - 203D)"},
/* 2E19 */ { "PALM BRANCH","	* used as a separator"},
/* 2E1A */ { "HYPHEN WITH DIAERESIS","	* indicates umlaut of the stem vowel of a plural form"},
/* 2E1B */ { "TILDE WITH RING ABOVE","	* indicates change in case for derived form"},
/* 2E1C */ { "LEFT LOW PARAPHRASE BRACKET",NULL},
/* 2E1D */ { "RIGHT LOW PARAPHRASE BRACKET","	* used in N'Ko"},
/* 2E1E */ { "TILDE WITH DOT ABOVE","	* indicates derived form changes to uppercase"},
/* 2E1F */ { "TILDE WITH DOT BELOW","	* indicates derived form changes to lowercase"},
/* 2E20 */ { "LEFT VERTICAL BAR WITH QUILL","	x (left square bracket with quill - 2045)"},
/* 2E21 */ { "RIGHT VERTICAL BAR WITH QUILL",NULL},
/* 2E22 */ { "TOP LEFT HALF BRACKET","	x (left ceiling - 2308)\n"
	"	x (top left corner - 231C)\n"
	"	x (left corner bracket - 300C)"},
/* 2E23 */ { "TOP RIGHT HALF BRACKET",NULL},
/* 2E24 */ { "BOTTOM LEFT HALF BRACKET",NULL},
/* 2E25 */ { "BOTTOM RIGHT HALF BRACKET",NULL},
/* 2E26 */ { "LEFT SIDEWAYS U BRACKET","	x (subset of - 2282)"},
/* 2E27 */ { "RIGHT SIDEWAYS U BRACKET","	x (superset of - 2283)"},
/* 2E28 */ { "LEFT DOUBLE PARENTHESIS","	x (left white parenthesis - 2985)\n"
	"	x (fullwidth left white parenthesis - FF5F)"},
/* 2E29 */ { "RIGHT DOUBLE PARENTHESIS",NULL},
/* 2E2A */ { "TWO DOTS OVER ONE DOT PUNCTUATION",NULL},
/* 2E2B */ { "ONE DOT OVER TWO DOTS PUNCTUATION",NULL},
/* 2E2C */ { "SQUARED FOUR DOT PUNCTUATION",NULL},
/* 2E2D */ { "FIVE DOT MARK",NULL},
/* 2E2E */ { "REVERSED QUESTION MARK","	= punctus percontativus\n"
	"	x (question mark - 003F)\n"
	"	x (inverted question mark - 00BF)\n"
	"	x (arabic question mark - 061F)"},
/* 2E2F */ { "VERTICAL TILDE","	* used for Cyrillic yerik\n"
	"	x (combining vertical tilde - 033E)\n"
	"	x (cyrillic payerok - A67F)"},
/* 2E30 */ { "RING POINT","	* used in Avestan\n"
	"	x (ring operator - 2218)\n"
	"	x (white bullet - 25E6)"},
/* 2E31 */ { "WORD SEPARATOR MIDDLE DOT","	* used in Avestan, Samaritan, ...\n"
	"	x (middle dot - 00B7)"},
/* 2E32 */ { "TURNED COMMA","	* indicates nasalization\n"
	"	x (arabic comma - 060C)"},
/* 2E33 */ { "RAISED DOT","	* glyph position intermediate between 002E and 00B7\n"
	"	x (full stop - 002E)\n"
	"	x (middle dot - 00B7)"},
/* 2E34 */ { "RAISED COMMA","	x (comma - 002C)"},
/* 2E35 */ { "TURNED SEMICOLON","	* indicates sudden glottal closure\n"
	"	x (arabic semicolon - 061B)"},
/* 2E36 */ { "DAGGER WITH LEFT GUARD","	* indicates retracted pronunciation"},
/* 2E37 */ { "DAGGER WITH RIGHT GUARD","	* indicates advanced pronunciation"},
/* 2E38 */ { "TURNED DAGGER","	* indicates retroflex pronunciation\n"
	"	x (dagger - 2020)"},
/* 2E39 */ { "TOP HALF SECTION SIGN","	* indicates pronunciation on one side of the mouth only\n"
	"	x (section sign - 00A7)"},
/* 2E3A */ { "TWO-EM DASH","	= omission dash\n"
	"	* may be used in Chinese for abrupt change of thought, inserting new content, or continuation of tone or sound\n"
	"	x (em dash - 2014)"},
/* 2E3B */ { "THREE-EM DASH",NULL},
/* 2E3C */ { "STENOGRAPHIC FULL STOP","	* used in shorthands and stenographies\n"
	"	x (full stop - 002E)\n"
	"	x (canadian syllabics full stop - 166E)"},
/* 2E3D */ { "VERTICAL SIX DOTS","	x (vertical four dots - 205E)\n"
	"	x (dotted fence - 2999)"},
/* 2E3E */ { "WIGGLY VERTICAL LINE","	x (wavy line - 2307)\n"
	"	x (vertical zigzag line - 299A)"},
/* 2E3F */ { "CAPITULUM","	* ancestor of the pilcrow sign\n"
	"	x (pilcrow sign - 00B6)"},
/* 2E40 */ { "DOUBLE HYPHEN","	x (equals sign - 003D)\n"
	"	x (hyphen - 2010)\n"
	"	x (double oblique hyphen - 2E17)\n"
	"	x (katakana-hiragana double hyphen - 30A0)\n"
	"	x (modifier letter short equals sign - A78A)"},
/* 2E41 */ { "REVERSED COMMA","	* Old Hungarian\n"
	"	* used occasionally in Sindhi when Sindhi is written in the Arabic script\n"
	"	x (comma - 002C)\n"
	"	x (arabic comma - 060C)"},
/* 2E42 */ { "DOUBLE LOW-REVERSED-9 QUOTATION MARK","	x (double low-9 quotation mark - 201E)"},
/* 2E43 */ { "DASH WITH LEFT UPTURN","	* functions as a paragraphos in some Slavonic texts\n"
	"	x (paragraphos - 2E0F)"},
/* 2E44 */ { "DOUBLE SUSPENSION MARK","	* indicates omission of letters in a word on some Byzantine Greek seals and coins\n"
	"	x (greek numeral sign - 0374)"},
/* 2E45 */ { "INVERTED LOW KAVYKA",NULL},
/* 2E46 */ { "INVERTED LOW KAVYKA WITH KAVYKA ABOVE","	x (union above intersection - 2A46)\n"
	"	x (modifier breve with inverted breve - AB5B)"},
/* 2E47 */ { "LOW KAVYKA","	x (cyrillic kavyka - A67E)"},
/* 2E48 */ { "LOW KAVYKA WITH DOT",NULL},
/* 2E49 */ { "DOUBLE STACKED COMMA",NULL},
/* 2E4A */ { "DOTTED SOLIDUS","	= virgula suspensiva\n"
	"	* indicates a medial disjunction more than solidus but less than punctus elevatus"},
/* 2E4B */ { "TRIPLE DAGGER","	x (dagger - 2020)\n"
	"	x (double dagger - 2021)"},
/* 2E4C */ { "MEDIEVAL COMMA","	* indicates a minor medial pause or disjunction of sense"},
/* 2E4D */ { "PARAGRAPHUS MARK","	* indicates the beginning of a paragraph, section, stanza, or proposition\n"
	"	x (pilcrow sign - 00B6)\n"
	"	x (reversed pilcrow sign - 204B)\n"
	"	x (paragraphos - 2E0F)\n"
	"	x (capitulum - 2E3F)"},
/* 2E4E */ { "PUNCTUS ELEVATUS MARK","		* This mark indicates a major intermediate pause where the sensus is complete but the sentence is not; this is similar in some regards to the modern use of a semicolon."},
/* 2E4F */ { "CORNISH VERSE DIVIDER",NULL},
/* 2E50 */ { "CROSS PATTY WITH RIGHT CROSSBAR","	x (maltese cross - 2720)\n"
	"	x (latin capital letter half h - 2C75)"},
/* 2E51 */ { "CROSS PATTY WITH LEFT CROSSBAR","	x (latin capital letter reversed half h - A7F5)"},
/* 2E52 */ { "TIRONIAN SIGN CAPITAL ET","	x (tironian sign et - 204A)"},
/* 2E53 */ { "MEDIEVAL EXCLAMATION MARK",NULL},
/* 2E54 */ { "MEDIEVAL QUESTION MARK",NULL},
/* 2E55 */ { "LEFT SQUARE BRACKET WITH STROKE","	* optional ellipsis\n"
	"	x (left square bracket with quill - 2045)"},
/* 2E56 */ { "RIGHT SQUARE BRACKET WITH STROKE",NULL},
/* 2E57 */ { "LEFT SQUARE BRACKET WITH DOUBLE STROKE","	* obligatory ellipsis"},
/* 2E58 */ { "RIGHT SQUARE BRACKET WITH DOUBLE STROKE",NULL},
/* 2E59 */ { "TOP HALF LEFT PARENTHESIS",NULL},
/* 2E5A */ { "TOP HALF RIGHT PARENTHESIS",NULL},
/* 2E5B */ { "BOTTOM HALF LEFT PARENTHESIS",NULL},
/* 2E5C */ { "BOTTOM HALF RIGHT PARENTHESIS",NULL},
/* 2E5D */ { "OBLIQUE HYPHEN","	x (hyphen - 2010)\n"
	"	x (double oblique hyphen - 2E17)"},
/* 2E5E */ { NULL,NULL},
/* 2E5F */ { NULL,NULL},
/* 2E60 */ { NULL,NULL},
/* 2E61 */ { NULL,NULL},
/* 2E62 */ { NULL,NULL},
/* 2E63 */ { NULL,NULL},
/* 2E64 */ { NULL,NULL},
/* 2E65 */ { NULL,NULL},
/* 2E66 */ { NULL,NULL},
/* 2E67 */ { NULL,NULL},
/* 2E68 */ { NULL,NULL},
/* 2E69 */ { NULL,NULL},
/* 2E6A */ { NULL,NULL},
/* 2E6B */ { NULL,NULL},
/* 2E6C */ { NULL,NULL},
/* 2E6D */ { NULL,NULL},
/* 2E6E */ { NULL,NULL},
/* 2E6F */ { NULL,NULL},
/* 2E70 */ { NULL,NULL},
/* 2E71 */ { NULL,NULL},
/* 2E72 */ { NULL,NULL},
/* 2E73 */ { NULL,NULL},
/* 2E74 */ { NULL,NULL},
/* 2E75 */ { NULL,NULL},
/* 2E76 */ { NULL,NULL},
/* 2E77 */ { NULL,NULL},
/* 2E78 */ { NULL,NULL},
/* 2E79 */ { NULL,NULL},
/* 2E7A */ { NULL,NULL},
/* 2E7B */ { NULL,NULL},
/* 2E7C */ { NULL,NULL},
/* 2E7D */ { NULL,NULL},
/* 2E7E */ { NULL,NULL},
/* 2E7F */ { NULL,NULL},
/* 2E80 */ { "CJK RADICAL REPEAT","	* variant of Kangxi Radical 3"},
/* 2E81 */ { "CJK RADICAL CLIFF","	* variant of Kangxi Radical 27\n"
	"	x 5382\n"
	"	x 20086"},
/* 2E82 */ { "CJK RADICAL SECOND ONE","	* variant of Kangxi Radical 5\n"
	"	x 4E5B"},
/* 2E83 */ { "CJK RADICAL SECOND TWO","	* variant of Kangxi Radical 5\n"
	"	x 4E5A"},
/* 2E84 */ { "CJK RADICAL SECOND THREE","	* variant of Kangxi Radical 5\n"
	"	x 4E59"},
/* 2E85 */ { "CJK RADICAL PERSON","	* variant of Kangxi Radical 9\n"
	"	* form used on left side\n"
	"	x 4EBB"},
/* 2E86 */ { "CJK RADICAL BOX","	* variant of Kangxi Radical 13\n"
	"	x 5182"},
/* 2E87 */ { "CJK RADICAL TABLE","	* variant of Kangxi Radical 16\n"
	"	x 51E0\n"
	"	x 20628"},
/* 2E88 */ { "CJK RADICAL KNIFE ONE","	* variant of Kangxi Radical 18\n"
	"	* form used at top\n"
	"	x 5200\n"
	"	x 2008A"},
/* 2E89 */ { "CJK RADICAL KNIFE TWO","	* variant of Kangxi Radical 18\n"
	"	* form used on right side\n"
	"	x 5202"},
/* 2E8A */ { "CJK RADICAL DIVINATION","	* variant of Kangxi Radical 25\n"
	"	* form used at top\n"
	"	x 535C"},
/* 2E8B */ { "CJK RADICAL SEAL","	* variant of Kangxi Radical 26\n"
	"	* form used at bottom\n"
	"	x 353E"},
/* 2E8C */ { "CJK RADICAL SMALL ONE","	* variant of Kangxi Radical 42\n"
	"	* form used at top\n"
	"	x 5C0F"},
/* 2E8D */ { "CJK RADICAL SMALL TWO","	* variant of Kangxi Radical 42\n"
	"	* form used at top\n"
	"	x 5C0F\n"
	"	x 2D544"},
/* 2E8E */ { "CJK RADICAL LAME ONE","	* variant of Kangxi Radical 43\n"
	"	x 5C22\n"
	"	x 5140"},
/* 2E8F */ { "CJK RADICAL LAME TWO","	* variant of Kangxi Radical 43\n"
	"	x 5C23"},
/* 2E90 */ { "CJK RADICAL LAME THREE","	* variant of Kangxi Radical 43\n"
	"	x 5C22"},
/* 2E91 */ { "CJK RADICAL LAME FOUR","	* variant of Kangxi Radical 43\n"
	"	x 5C23\n"
	"	x 21BC2"},
/* 2E92 */ { "CJK RADICAL SNAKE","	* variant of Kangxi Radical 49\n"
	"	x 5DF3"},
/* 2E93 */ { "CJK RADICAL THREAD","	* variant of Kangxi Radical 52\n"
	"	x 5E7A"},
/* 2E94 */ { "CJK RADICAL SNOUT ONE","	* variant of Kangxi Radical 58\n"
	"	x 5F51"},
/* 2E95 */ { "CJK RADICAL SNOUT TWO","	* variant of Kangxi Radical 58\n"
	"	* actually a form of the radical for hand, despite its resemblance in shape to the radical for snout\n"
	"	x 5F50\n"
	"	x 2B739"},
/* 2E96 */ { "CJK RADICAL HEART ONE","	* variant of Kangxi Radical 61\n"
	"	* form used on left side\n"
	"	x 5FC4"},
/* 2E97 */ { "CJK RADICAL HEART TWO","	* variant of Kangxi Radical 61\n"
	"	* form used at bottom\n"
	"	x 38FA\n"
	"	x 5FC3"},
/* 2E98 */ { "CJK RADICAL HAND","	* variant of Kangxi Radical 64\n"
	"	* form used on left side\n"
	"	x 624C"},
/* 2E99 */ { "CJK RADICAL RAP","	* variant of Kangxi Radical 66\n"
	"	* form used on right side\n"
	"	x 6535"},
/* 2E9A */ { NULL,"	x (kangxi radical not - 2F46)"},
/* 2E9B */ { "CJK RADICAL CHOKE","	* variant of Kangxi Radical 71\n"
	"	x 65E1"},
/* 2E9C */ { "CJK RADICAL SUN","	* variant of Kangxi Radical 72\n"
	"	* actually a form of the radical for hat, despite its resemblance in shape to the radical for sun\n"
	"	x 5183\n"
	"	x 65E5"},
/* 2E9D */ { "CJK RADICAL MOON","	* variant of Kangxi Radical 74\n"
	"	x 6708"},
/* 2E9E */ { "CJK RADICAL DEATH","	* variant of Kangxi Radical 78\n"
	"	x 6B7A"},
/* 2E9F */ { "CJK RADICAL MOTHER","	* variant of Kangxi Radical 80\n"
	"	# 6BCD"},
/* 2EA0 */ { "CJK RADICAL CIVILIAN","	* variant of Kangxi Radical 83\n"
	"	x 6C11"},
/* 2EA1 */ { "CJK RADICAL WATER ONE","	* variant of Kangxi Radical 85\n"
	"	* form used on left side\n"
	"	x 6C35"},
/* 2EA2 */ { "CJK RADICAL WATER TWO","	* variant of Kangxi Radical 85\n"
	"	* form used (rarely) at bottom\n"
	"	x 6C3A"},
/* 2EA3 */ { "CJK RADICAL FIRE","	* variant of Kangxi Radical 86\n"
	"	* form used at bottom\n"
	"	x 706C"},
/* 2EA4 */ { "CJK RADICAL PAW ONE","	* variant of Kangxi Radical 87\n"
	"	* form used at top\n"
	"	x 722B"},
/* 2EA5 */ { "CJK RADICAL PAW TWO","	* variant of Kangxi Radical 87\n"
	"	* form used at top\n"
	"	x 722B"},
/* 2EA6 */ { "CJK RADICAL SIMPLIFIED HALF TREE TRUNK","	* simplified variant of Kangxi Radical 90\n"
	"	x 4E2C"},
/* 2EA7 */ { "CJK RADICAL COW","	* variant of Kangxi Radical 93\n"
	"	x 725B\n"
	"	x 20092"},
/* 2EA8 */ { "CJK RADICAL DOG","	* variant of Kangxi Radical 94\n"
	"	* form used on left side\n"
	"	x 72AD"},
/* 2EA9 */ { "CJK RADICAL JADE","	* variant of Kangxi Radical 96\n"
	"	* form used on left side\n"
	"	x 738B\n"
	"	x 248E9"},
/* 2EAA */ { "CJK RADICAL BOLT OF CLOTH","	* variant of Kangxi Radical 103\n"
	"	* form used on left side\n"
	"	x 758B\n"
	"	x 24D14"},
/* 2EAB */ { "CJK RADICAL EYE","	* variant of Kangxi Radical 109\n"
	"	* variant of Kangxi Radical 122\n"
	"	* form used at top\n"
	"	x (cjk radical net two - 2EB2)\n"
	"	x 76EE\n"
	"	x 7F52"},
/* 2EAC */ { "CJK RADICAL SPIRIT ONE","	* variant of Kangxi Radical 113\n"
	"	x 793A"},
/* 2EAD */ { "CJK RADICAL SPIRIT TWO","	* variant of Kangxi Radical 113\n"
	"	x 793B"},
/* 2EAE */ { "CJK RADICAL BAMBOO","	* variant of Kangxi Radical 118\n"
	"	x 7AF9\n"
	"	x 25AD7"},
/* 2EAF */ { "CJK RADICAL SILK","	* variant of Kangxi Radical 120\n"
	"	* form used on left side\n"
	"	x 7CF9"},
/* 2EB0 */ { "CJK RADICAL C-SIMPLIFIED SILK","	* simplified Chinese variant of Kangxi Radical 120\n"
	"	* form used on left side\n"
	"	x 7E9F"},
/* 2EB1 */ { "CJK RADICAL NET ONE","	* variant of Kangxi Radical 122\n"
	"	x 7F53"},
/* 2EB2 */ { "CJK RADICAL NET TWO","	* variant of Kangxi Radical 109\n"
	"	* variant of Kangxi Radical 122\n"
	"	x (cjk radical eye - 2EAB)\n"
	"	x 7F52\n"
	"	x 26270"},
/* 2EB3 */ { "CJK RADICAL NET THREE","	* variant of Kangxi Radical 122\n"
	"	x 34C1\n"
	"	x 7F51"},
/* 2EB4 */ { "CJK RADICAL NET FOUR","	* variant of Kangxi Radical 122\n"
	"	x 34C1\n"
	"	x 7F51"},
/* 2EB5 */ { "CJK RADICAL MESH","	* variant of Kangxi Radical 122\n"
	"	x 2626B"},
/* 2EB6 */ { "CJK RADICAL SHEEP","	* variant of Kangxi Radical 123\n"
	"	* form used on left side\n"
	"	x 7F8A"},
/* 2EB7 */ { "CJK RADICAL RAM","	* variant of Kangxi Radical 123\n"
	"	* form used at top\n"
	"	x 7F8A\n"
	"	x 2634C"},
/* 2EB8 */ { "CJK RADICAL EWE","	* variant of Kangxi Radical 123\n"
	"	x 7F8B\n"
	"	x 2634B"},
/* 2EB9 */ { "CJK RADICAL OLD","	* variant of Kangxi Radical 125\n"
	"	x 8002"},
/* 2EBA */ { "CJK RADICAL BRUSH ONE","	* variant of Kangxi Radical 129\n"
	"	x 8080"},
/* 2EBB */ { "CJK RADICAL BRUSH TWO","	* variant of Kangxi Radical 129\n"
	"	x 807F"},
/* 2EBC */ { "CJK RADICAL MEAT","	* variant of Kangxi Radical 130\n"
	"	x 8089"},
/* 2EBD */ { "CJK RADICAL MORTAR","	* variant of Kangxi Radical 134\n"
	"	x 81FC\n"
	"	x 26951"},
/* 2EBE */ { "CJK RADICAL GRASS ONE","	* simplified variant of Kangxi Radical 140\n"
	"	x 8279"},
/* 2EBF */ { "CJK RADICAL GRASS TWO","	* variant of Kangxi Radical 140\n"
	"	x 8279"},
/* 2EC0 */ { "CJK RADICAL GRASS THREE","	* variant of Kangxi Radical 140\n"
	"	x 8279"},
/* 2EC1 */ { "CJK RADICAL TIGER","	* variant of Kangxi Radical 141\n"
	"	x 864E"},
/* 2EC2 */ { "CJK RADICAL CLOTHES","	* variant of Kangxi Radical 145\n"
	"	* form used on left side\n"
	"	x 8864"},
/* 2EC3 */ { "CJK RADICAL WEST ONE","	* variant of Kangxi Radical 146\n"
	"	* form used at top\n"
	"	x 8980"},
/* 2EC4 */ { "CJK RADICAL WEST TWO","	* variant of Kangxi Radical 146\n"
	"	* form used on left side\n"
	"	x 897F"},
/* 2EC5 */ { "CJK RADICAL C-SIMPLIFIED SEE","	* simplified Chinese variant of Kangxi Radical 147\n"
	"	x 89C1"},
/* 2EC6 */ { "CJK RADICAL SIMPLIFIED HORN","	* simplified Chinese variant of Kangxi Radical 148\n"
	"	x 89D2"},
/* 2EC7 */ { "CJK RADICAL HORN","	* variant of Kangxi Radical 148\n"
	"	x 278B2"},
/* 2EC8 */ { "CJK RADICAL C-SIMPLIFIED SPEECH","	* simplified Chinese variant of Kangxi Radical 149\n"
	"	x 8BA0"},
/* 2EC9 */ { "CJK RADICAL C-SIMPLIFIED SHELL","	* simplified Chinese variant of Kangxi Radical 154\n"
	"	x 8D1D"},
/* 2ECA */ { "CJK RADICAL FOOT","	* variant of Kangxi Radical 157\n"
	"	* form used on left side\n"
	"	x 8DB3\n"
	"	x 27FB7"},
/* 2ECB */ { "CJK RADICAL C-SIMPLIFIED CART","	* simplified Chinese variant of Kangxi Radical 159\n"
	"	x 8F66"},
/* 2ECC */ { "CJK RADICAL SIMPLIFIED WALK","	* simplified variant of Kangxi Radical 162\n"
	"	x 8FB6"},
/* 2ECD */ { "CJK RADICAL WALK ONE","	* variant of Kangxi Radical 162\n"
	"	x 8FB6"},
/* 2ECE */ { "CJK RADICAL WALK TWO","	* variant of Kangxi Radical 162\n"
	"	x 8FB6"},
/* 2ECF */ { "CJK RADICAL CITY","	* variant of Kangxi Radical 163\n"
	"	* form used on right side\n"
	"	x 9091"},
/* 2ED0 */ { "CJK RADICAL C-SIMPLIFIED GOLD","	* simplified Chinese variant of Kangxi Radical 167\n"
	"	x 9485"},
/* 2ED1 */ { "CJK RADICAL LONG ONE","	* variant of Kangxi Radical 168\n"
	"	x 9577"},
/* 2ED2 */ { "CJK RADICAL LONG TWO","	* variant of Kangxi Radical 168\n"
	"	* form used on left side\n"
	"	x 9578"},
/* 2ED3 */ { "CJK RADICAL C-SIMPLIFIED LONG","	* simplified Chinese variant of Kangxi Radical 168\n"
	"	x 957F"},
/* 2ED4 */ { "CJK RADICAL C-SIMPLIFIED GATE","	* simplified Chinese variant of Kangxi Radical 169\n"
	"	x 95E8"},
/* 2ED5 */ { "CJK RADICAL MOUND ONE","	* variant of Kangxi Radical 170\n"
	"	x 961C\n"
	"	x 28E0F"},
/* 2ED6 */ { "CJK RADICAL MOUND TWO","	* variant of Kangxi Radical 170\n"
	"	* form used on left side\n"
	"	x 961D"},
/* 2ED7 */ { "CJK RADICAL RAIN","	* variant of Kangxi Radical 173\n"
	"	x 96E8"},
/* 2ED8 */ { "CJK RADICAL BLUE","	* variant of Kangxi Radical 174\n"
	"	x 9752"},
/* 2ED9 */ { "CJK RADICAL C-SIMPLIFIED TANNED LEATHER","	* simplified Chinese variant of Kangxi Radical 178\n"
	"	x 97E6"},
/* 2EDA */ { "CJK RADICAL C-SIMPLIFIED LEAF","	* simplified Chinese variant of Kangxi Radical 181\n"
	"	x 9875"},
/* 2EDB */ { "CJK RADICAL C-SIMPLIFIED WIND","	* simplified Chinese variant of Kangxi Radical 182\n"
	"	x 98CE"},
/* 2EDC */ { "CJK RADICAL C-SIMPLIFIED FLY","	* simplified Chinese variant of Kangxi Radical 183\n"
	"	x 98DE"},
/* 2EDD */ { "CJK RADICAL EAT ONE","	* variant of Kangxi Radical 184\n"
	"	* form used at bottom\n"
	"	x 98DF"},
/* 2EDE */ { "CJK RADICAL EAT TWO","	* variant of Kangxi Radical 184\n"
	"	* form used on left side\n"
	"	x 2967F"},
/* 2EDF */ { "CJK RADICAL EAT THREE","	* variant of Kangxi Radical 184\n"
	"	* form used on left side\n"
	"	x 98E0"},
/* 2EE0 */ { "CJK RADICAL C-SIMPLIFIED EAT","	* simplified Chinese variant of Kangxi Radical 184\n"
	"	* form used on left side\n"
	"	x 9963"},
/* 2EE1 */ { "CJK RADICAL HEAD","	* variant of Kangxi Radical 185\n"
	"	x 29810"},
/* 2EE2 */ { "CJK RADICAL C-SIMPLIFIED HORSE","	* simplified Chinese variant of Kangxi Radical 187\n"
	"	x 9A6C"},
/* 2EE3 */ { "CJK RADICAL BONE","	* simplified Chinese variant of Kangxi Radical 188\n"
	"	x 9AA8"},
/* 2EE4 */ { "CJK RADICAL GHOST","	* variant of Kangxi Radical 194\n"
	"	x 9B3C"},
/* 2EE5 */ { "CJK RADICAL C-SIMPLIFIED FISH","	* simplified Chinese variant of Kangxi Radical 195\n"
	"	x 9C7C"},
/* 2EE6 */ { "CJK RADICAL C-SIMPLIFIED BIRD","	* simplified Chinese variant of Kangxi Radical 196\n"
	"	x 9E1F"},
/* 2EE7 */ { "CJK RADICAL C-SIMPLIFIED SALT","	* simplified Chinese variant of Kangxi Radical 197\n"
	"	x 5364"},
/* 2EE8 */ { "CJK RADICAL SIMPLIFIED WHEAT","	* simplified variant of Kangxi Radical 199\n"
	"	x 9EA6"},
/* 2EE9 */ { "CJK RADICAL SIMPLIFIED YELLOW","	* simplified variant of Kangxi Radical 201\n"
	"	x 9EC4"},
/* 2EEA */ { "CJK RADICAL C-SIMPLIFIED FROG","	* simplified Chinese variant of Kangxi Radical 205\n"
	"	x 9EFE"},
/* 2EEB */ { "CJK RADICAL J-SIMPLIFIED EVEN","	* simplified Japanese variant of Kangxi Radical 210\n"
	"	x 6589"},
/* 2EEC */ { "CJK RADICAL C-SIMPLIFIED EVEN","	* simplified Chinese variant of Kangxi Radical 210\n"
	"	x 9F50"},
/* 2EED */ { "CJK RADICAL J-SIMPLIFIED TOOTH","	* simplified Japanese variant of Kangxi Radical 211\n"
	"	x 6B6F"},
/* 2EEE */ { "CJK RADICAL C-SIMPLIFIED TOOTH","	* simplified Chinese variant of Kangxi Radical 211\n"
	"	x 9F7F"},
/* 2EEF */ { "CJK RADICAL J-SIMPLIFIED DRAGON","	* simplified Japanese variant of Kangxi Radical 212\n"
	"	x 7ADC\n"
	"	x 9F8D"},
/* 2EF0 */ { "CJK RADICAL C-SIMPLIFIED DRAGON","	* simplified Chinese variant of Kangxi Radical 212\n"
	"	x 9F99"},
/* 2EF1 */ { "CJK RADICAL TURTLE","	* variant of Kangxi Radical 213\n"
	"	x 9F9C"},
/* 2EF2 */ { "CJK RADICAL J-SIMPLIFIED TURTLE","	* simplified Japanese variant of Kangxi Radical 213\n"
	"	x 4E80"},
/* 2EF3 */ { "CJK RADICAL C-SIMPLIFIED TURTLE","	* simplified Chinese variant of Kangxi Radical 213\n"
	"	# 9F9F"},
/* 2EF4 */ { NULL,NULL},
/* 2EF5 */ { NULL,NULL},
/* 2EF6 */ { NULL,NULL},
/* 2EF7 */ { NULL,NULL},
/* 2EF8 */ { NULL,NULL},
/* 2EF9 */ { NULL,NULL},
/* 2EFA */ { NULL,NULL},
/* 2EFB */ { NULL,NULL},
/* 2EFC */ { NULL,NULL},
/* 2EFD */ { NULL,NULL},
/* 2EFE */ { NULL,NULL},
/* 2EFF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_00_2F[] = {
/* 2F00 */ { "KANGXI RADICAL ONE","	* Kangxi Radical 1\n"
	"	# 4E00"},
/* 2F01 */ { "KANGXI RADICAL LINE","	* Kangxi Radical 2\n"
	"	# 4E28"},
/* 2F02 */ { "KANGXI RADICAL DOT","	* Kangxi Radical 3\n"
	"	# 4E36"},
/* 2F03 */ { "KANGXI RADICAL SLASH","	* Kangxi Radical 4\n"
	"	# 4E3F"},
/* 2F04 */ { "KANGXI RADICAL SECOND","	* Kangxi Radical 5\n"
	"	# 4E59"},
/* 2F05 */ { "KANGXI RADICAL HOOK","	* Kangxi Radical 6\n"
	"	# 4E85"},
/* 2F06 */ { "KANGXI RADICAL TWO","	* Kangxi Radical 7\n"
	"	# 4E8C"},
/* 2F07 */ { "KANGXI RADICAL LID","	* Kangxi Radical 8\n"
	"	# 4EA0"},
/* 2F08 */ { "KANGXI RADICAL MAN","	* Kangxi Radical 9\n"
	"	# 4EBA"},
/* 2F09 */ { "KANGXI RADICAL LEGS","	* Kangxi Radical 10\n"
	"	# 513F"},
/* 2F0A */ { "KANGXI RADICAL ENTER","	* Kangxi Radical 11\n"
	"	# 5165"},
/* 2F0B */ { "KANGXI RADICAL EIGHT","	* Kangxi Radical 12\n"
	"	# 516B"},
/* 2F0C */ { "KANGXI RADICAL DOWN BOX","	* Kangxi Radical 13\n"
	"	# 5182"},
/* 2F0D */ { "KANGXI RADICAL COVER","	* Kangxi Radical 14\n"
	"	# 5196"},
/* 2F0E */ { "KANGXI RADICAL ICE","	* Kangxi Radical 15\n"
	"	# 51AB"},
/* 2F0F */ { "KANGXI RADICAL TABLE","	* Kangxi Radical 16\n"
	"	# 51E0"},
/* 2F10 */ { "KANGXI RADICAL OPEN BOX","	* Kangxi Radical 17\n"
	"	# 51F5"},
/* 2F11 */ { "KANGXI RADICAL KNIFE","	* Kangxi Radical 18\n"
	"	# 5200"},
/* 2F12 */ { "KANGXI RADICAL POWER","	* Kangxi Radical 19\n"
	"	# 529B"},
/* 2F13 */ { "KANGXI RADICAL WRAP","	* Kangxi Radical 20\n"
	"	# 52F9"},
/* 2F14 */ { "KANGXI RADICAL SPOON","	* Kangxi Radical 21\n"
	"	# 5315"},
/* 2F15 */ { "KANGXI RADICAL RIGHT OPEN BOX","	* Kangxi Radical 22\n"
	"	# 531A"},
/* 2F16 */ { "KANGXI RADICAL HIDING ENCLOSURE","	* Kangxi Radical 23\n"
	"	# 5338"},
/* 2F17 */ { "KANGXI RADICAL TEN","	* Kangxi Radical 24\n"
	"	# 5341"},
/* 2F18 */ { "KANGXI RADICAL DIVINATION","	* Kangxi Radical 25\n"
	"	# 535C"},
/* 2F19 */ { "KANGXI RADICAL SEAL","	* Kangxi Radical 26\n"
	"	# 5369"},
/* 2F1A */ { "KANGXI RADICAL CLIFF","	* Kangxi Radical 27\n"
	"	# 5382"},
/* 2F1B */ { "KANGXI RADICAL PRIVATE","	* Kangxi Radical 28\n"
	"	# 53B6"},
/* 2F1C */ { "KANGXI RADICAL AGAIN","	* Kangxi Radical 29\n"
	"	# 53C8"},
/* 2F1D */ { "KANGXI RADICAL MOUTH","	* Kangxi Radical 30\n"
	"	# 53E3"},
/* 2F1E */ { "KANGXI RADICAL ENCLOSURE","	* Kangxi Radical 31\n"
	"	# 56D7"},
/* 2F1F */ { "KANGXI RADICAL EARTH","	* Kangxi Radical 32\n"
	"	# 571F"},
/* 2F20 */ { "KANGXI RADICAL SCHOLAR","	* Kangxi Radical 33\n"
	"	# 58EB"},
/* 2F21 */ { "KANGXI RADICAL GO","	* Kangxi Radical 34\n"
	"	# 5902"},
/* 2F22 */ { "KANGXI RADICAL GO SLOWLY","	* Kangxi Radical 35\n"
	"	# 590A"},
/* 2F23 */ { "KANGXI RADICAL EVENING","	* Kangxi Radical 36\n"
	"	# 5915"},
/* 2F24 */ { "KANGXI RADICAL BIG","	* Kangxi Radical 37\n"
	"	# 5927"},
/* 2F25 */ { "KANGXI RADICAL WOMAN","	* Kangxi Radical 38\n"
	"	# 5973"},
/* 2F26 */ { "KANGXI RADICAL CHILD","	* Kangxi Radical 39\n"
	"	# 5B50"},
/* 2F27 */ { "KANGXI RADICAL ROOF","	* Kangxi Radical 40\n"
	"	# 5B80"},
/* 2F28 */ { "KANGXI RADICAL INCH","	* Kangxi Radical 41\n"
	"	# 5BF8"},
/* 2F29 */ { "KANGXI RADICAL SMALL","	* Kangxi Radical 42\n"
	"	# 5C0F"},
/* 2F2A */ { "KANGXI RADICAL LAME","	* Kangxi Radical 43\n"
	"	x 21BC1\n"
	"	# 5C22"},
/* 2F2B */ { "KANGXI RADICAL CORPSE","	* Kangxi Radical 44\n"
	"	# 5C38"},
/* 2F2C */ { "KANGXI RADICAL SPROUT","	* Kangxi Radical 45\n"
	"	# 5C6E"},
/* 2F2D */ { "KANGXI RADICAL MOUNTAIN","	* Kangxi Radical 46\n"
	"	# 5C71"},
/* 2F2E */ { "KANGXI RADICAL RIVER","	* Kangxi Radical 47\n"
	"	# 5DDB"},
/* 2F2F */ { "KANGXI RADICAL WORK","	* Kangxi Radical 48\n"
	"	# 5DE5"},
/* 2F30 */ { "KANGXI RADICAL ONESELF","	* Kangxi Radical 49\n"
	"	# 5DF1"},
/* 2F31 */ { "KANGXI RADICAL TURBAN","	* Kangxi Radical 50\n"
	"	# 5DFE"},
/* 2F32 */ { "KANGXI RADICAL DRY","	* Kangxi Radical 51\n"
	"	# 5E72"},
/* 2F33 */ { "KANGXI RADICAL SHORT THREAD","	* Kangxi Radical 52\n"
	"	# 5E7A"},
/* 2F34 */ { "KANGXI RADICAL DOTTED CLIFF","	* Kangxi Radical 53\n"
	"	# 5E7F"},
/* 2F35 */ { "KANGXI RADICAL LONG STRIDE","	* Kangxi Radical 54\n"
	"	# 5EF4"},
/* 2F36 */ { "KANGXI RADICAL TWO HANDS","	* Kangxi Radical 55\n"
	"	# 5EFE"},
/* 2F37 */ { "KANGXI RADICAL SHOOT","	* Kangxi Radical 56\n"
	"	# 5F0B"},
/* 2F38 */ { "KANGXI RADICAL BOW","	* Kangxi Radical 57\n"
	"	# 5F13"},
/* 2F39 */ { "KANGXI RADICAL SNOUT","	* Kangxi Radical 58\n"
	"	# 5F50"},
/* 2F3A */ { "KANGXI RADICAL BRISTLE","	* Kangxi Radical 59\n"
	"	# 5F61"},
/* 2F3B */ { "KANGXI RADICAL STEP","	* Kangxi Radical 60\n"
	"	# 5F73"},
/* 2F3C */ { "KANGXI RADICAL HEART","	* Kangxi Radical 61\n"
	"	# 5FC3"},
/* 2F3D */ { "KANGXI RADICAL HALBERD","	* Kangxi Radical 62\n"
	"	# 6208"},
/* 2F3E */ { "KANGXI RADICAL DOOR","	* Kangxi Radical 63\n"
	"	# 6236"},
/* 2F3F */ { "KANGXI RADICAL HAND","	* Kangxi Radical 64\n"
	"	# 624B"},
/* 2F40 */ { "KANGXI RADICAL BRANCH","	* Kangxi Radical 65\n"
	"	# 652F"},
/* 2F41 */ { "KANGXI RADICAL RAP","	* Kangxi Radical 66\n"
	"	# 6534"},
/* 2F42 */ { "KANGXI RADICAL SCRIPT","	* Kangxi Radical 67\n"
	"	# 6587"},
/* 2F43 */ { "KANGXI RADICAL DIPPER","	* Kangxi Radical 68\n"
	"	# 6597"},
/* 2F44 */ { "KANGXI RADICAL AXE","	* Kangxi Radical 69\n"
	"	# 65A4"},
/* 2F45 */ { "KANGXI RADICAL SQUARE","	* Kangxi Radical 70\n"
	"	# 65B9"},
/* 2F46 */ { "KANGXI RADICAL NOT","	* Kangxi Radical 71\n"
	"	# 65E0"},
/* 2F47 */ { "KANGXI RADICAL SUN","	* Kangxi Radical 72\n"
	"	# 65E5"},
/* 2F48 */ { "KANGXI RADICAL SAY","	* Kangxi Radical 73\n"
	"	# 66F0"},
/* 2F49 */ { "KANGXI RADICAL MOON","	* Kangxi Radical 74\n"
	"	# 6708"},
/* 2F4A */ { "KANGXI RADICAL TREE","	* Kangxi Radical 75\n"
	"	# 6728"},
/* 2F4B */ { "KANGXI RADICAL LACK","	* Kangxi Radical 76\n"
	"	# 6B20"},
/* 2F4C */ { "KANGXI RADICAL STOP","	* Kangxi Radical 77\n"
	"	# 6B62"},
/* 2F4D */ { "KANGXI RADICAL DEATH","	* Kangxi Radical 78\n"
	"	# 6B79"},
/* 2F4E */ { "KANGXI RADICAL WEAPON","	* Kangxi Radical 79\n"
	"	# 6BB3"},
/* 2F4F */ { "KANGXI RADICAL DO NOT","	* Kangxi Radical 80\n"
	"	# 6BCB"},
/* 2F50 */ { "KANGXI RADICAL COMPARE","	* Kangxi Radical 81\n"
	"	# 6BD4"},
/* 2F51 */ { "KANGXI RADICAL FUR","	* Kangxi Radical 82\n"
	"	# 6BDB"},
/* 2F52 */ { "KANGXI RADICAL CLAN","	* Kangxi Radical 83\n"
	"	# 6C0F"},
/* 2F53 */ { "KANGXI RADICAL STEAM","	* Kangxi Radical 84\n"
	"	# 6C14"},
/* 2F54 */ { "KANGXI RADICAL WATER","	* Kangxi Radical 85\n"
	"	# 6C34"},
/* 2F55 */ { "KANGXI RADICAL FIRE","	* Kangxi Radical 86\n"
	"	# 706B"},
/* 2F56 */ { "KANGXI RADICAL CLAW","	* Kangxi Radical 87\n"
	"	# 722A"},
/* 2F57 */ { "KANGXI RADICAL FATHER","	* Kangxi Radical 88\n"
	"	# 7236"},
/* 2F58 */ { "KANGXI RADICAL DOUBLE X","	* Kangxi Radical 89\n"
	"	# 723B"},
/* 2F59 */ { "KANGXI RADICAL HALF TREE TRUNK","	* Kangxi Radical 90\n"
	"	# 723F"},
/* 2F5A */ { "KANGXI RADICAL SLICE","	* Kangxi Radical 91\n"
	"	# 7247"},
/* 2F5B */ { "KANGXI RADICAL FANG","	* Kangxi Radical 92\n"
	"	# 7259"},
/* 2F5C */ { "KANGXI RADICAL COW","	* Kangxi Radical 93\n"
	"	# 725B"},
/* 2F5D */ { "KANGXI RADICAL DOG","	* Kangxi Radical 94\n"
	"	# 72AC"},
/* 2F5E */ { "KANGXI RADICAL PROFOUND","	* Kangxi Radical 95\n"
	"	# 7384"},
/* 2F5F */ { "KANGXI RADICAL JADE","	* Kangxi Radical 96\n"
	"	# 7389"},
/* 2F60 */ { "KANGXI RADICAL MELON","	* Kangxi Radical 97\n"
	"	# 74DC"},
/* 2F61 */ { "KANGXI RADICAL TILE","	* Kangxi Radical 98\n"
	"	# 74E6"},
/* 2F62 */ { "KANGXI RADICAL SWEET","	* Kangxi Radical 99\n"
	"	# 7518"},
/* 2F63 */ { "KANGXI RADICAL LIFE","	* Kangxi Radical 100\n"
	"	# 751F"},
/* 2F64 */ { "KANGXI RADICAL USE","	* Kangxi Radical 101\n"
	"	# 7528"},
/* 2F65 */ { "KANGXI RADICAL FIELD","	* Kangxi Radical 102\n"
	"	# 7530"},
/* 2F66 */ { "KANGXI RADICAL BOLT OF CLOTH","	* Kangxi Radical 103\n"
	"	# 758B"},
/* 2F67 */ { "KANGXI RADICAL SICKNESS","	* Kangxi Radical 104\n"
	"	# 7592"},
/* 2F68 */ { "KANGXI RADICAL DOTTED TENT","	* Kangxi Radical 105\n"
	"	# 7676"},
/* 2F69 */ { "KANGXI RADICAL WHITE","	* Kangxi Radical 106\n"
	"	# 767D"},
/* 2F6A */ { "KANGXI RADICAL SKIN","	* Kangxi Radical 107\n"
	"	# 76AE"},
/* 2F6B */ { "KANGXI RADICAL DISH","	* Kangxi Radical 108\n"
	"	# 76BF"},
/* 2F6C */ { "KANGXI RADICAL EYE","	* Kangxi Radical 109\n"
	"	# 76EE"},
/* 2F6D */ { "KANGXI RADICAL SPEAR","	* Kangxi Radical 110\n"
	"	# 77DB"},
/* 2F6E */ { "KANGXI RADICAL ARROW","	* Kangxi Radical 111\n"
	"	# 77E2"},
/* 2F6F */ { "KANGXI RADICAL STONE","	* Kangxi Radical 112\n"
	"	# 77F3"},
/* 2F70 */ { "KANGXI RADICAL SPIRIT","	* Kangxi Radical 113\n"
	"	# 793A"},
/* 2F71 */ { "KANGXI RADICAL TRACK","	* Kangxi Radical 114\n"
	"	# 79B8"},
/* 2F72 */ { "KANGXI RADICAL GRAIN","	* Kangxi Radical 115\n"
	"	# 79BE"},
/* 2F73 */ { "KANGXI RADICAL CAVE","	* Kangxi Radical 116\n"
	"	# 7A74"},
/* 2F74 */ { "KANGXI RADICAL STAND","	* Kangxi Radical 117\n"
	"	# 7ACB"},
/* 2F75 */ { "KANGXI RADICAL BAMBOO","	* Kangxi Radical 118\n"
	"	# 7AF9"},
/* 2F76 */ { "KANGXI RADICAL RICE","	* Kangxi Radical 119\n"
	"	# 7C73"},
/* 2F77 */ { "KANGXI RADICAL SILK","	* Kangxi Radical 120\n"
	"	# 7CF8"},
/* 2F78 */ { "KANGXI RADICAL JAR","	* Kangxi Radical 121\n"
	"	# 7F36"},
/* 2F79 */ { "KANGXI RADICAL NET","	* Kangxi Radical 122\n"
	"	# 7F51"},
/* 2F7A */ { "KANGXI RADICAL SHEEP","	* Kangxi Radical 123\n"
	"	# 7F8A"},
/* 2F7B */ { "KANGXI RADICAL FEATHER","	* Kangxi Radical 124\n"
	"	# 7FBD"},
/* 2F7C */ { "KANGXI RADICAL OLD","	* Kangxi Radical 125\n"
	"	# 8001"},
/* 2F7D */ { "KANGXI RADICAL AND","	* Kangxi Radical 126\n"
	"	# 800C"},
/* 2F7E */ { "KANGXI RADICAL PLOW","	* Kangxi Radical 127\n"
	"	# 8012"},
/* 2F7F */ { "KANGXI RADICAL EAR","	* Kangxi Radical 128\n"
	"	# 8033"},
/* 2F80 */ { "KANGXI RADICAL BRUSH","	* Kangxi Radical 129\n"
	"	# 807F"},
/* 2F81 */ { "KANGXI RADICAL MEAT","	* Kangxi Radical 130\n"
	"	# 8089"},
/* 2F82 */ { "KANGXI RADICAL MINISTER","	* Kangxi Radical 131\n"
	"	# 81E3"},
/* 2F83 */ { "KANGXI RADICAL SELF","	* Kangxi Radical 132\n"
	"	# 81EA"},
/* 2F84 */ { "KANGXI RADICAL ARRIVE","	* Kangxi Radical 133\n"
	"	# 81F3"},
/* 2F85 */ { "KANGXI RADICAL MORTAR","	* Kangxi Radical 134\n"
	"	# 81FC"},
/* 2F86 */ { "KANGXI RADICAL TONGUE","	* Kangxi Radical 135\n"
	"	# 820C"},
/* 2F87 */ { "KANGXI RADICAL OPPOSE","	* Kangxi Radical 136\n"
	"	# 821B"},
/* 2F88 */ { "KANGXI RADICAL BOAT","	* Kangxi Radical 137\n"
	"	# 821F"},
/* 2F89 */ { "KANGXI RADICAL STOPPING","	* Kangxi Radical 138\n"
	"	# 826E"},
/* 2F8A */ { "KANGXI RADICAL COLOR","	* Kangxi Radical 139\n"
	"	# 8272"},
/* 2F8B */ { "KANGXI RADICAL GRASS","	* Kangxi Radical 140\n"
	"	# 8278"},
/* 2F8C */ { "KANGXI RADICAL TIGER","	* Kangxi Radical 141\n"
	"	# 864D"},
/* 2F8D */ { "KANGXI RADICAL INSECT","	* Kangxi Radical 142\n"
	"	# 866B"},
/* 2F8E */ { "KANGXI RADICAL BLOOD","	* Kangxi Radical 143\n"
	"	# 8840"},
/* 2F8F */ { "KANGXI RADICAL WALK ENCLOSURE","	* Kangxi Radical 144\n"
	"	# 884C"},
/* 2F90 */ { "KANGXI RADICAL CLOTHES","	* Kangxi Radical 145\n"
	"	# 8863"},
/* 2F91 */ { "KANGXI RADICAL WEST","	* Kangxi Radical 146\n"
	"	# 897E"},
/* 2F92 */ { "KANGXI RADICAL SEE","	* Kangxi Radical 147\n"
	"	# 898B"},
/* 2F93 */ { "KANGXI RADICAL HORN","	* Kangxi Radical 148\n"
	"	# 89D2"},
/* 2F94 */ { "KANGXI RADICAL SPEECH","	* Kangxi Radical 149\n"
	"	# 8A00"},
/* 2F95 */ { "KANGXI RADICAL VALLEY","	* Kangxi Radical 150\n"
	"	# 8C37"},
/* 2F96 */ { "KANGXI RADICAL BEAN","	* Kangxi Radical 151\n"
	"	# 8C46"},
/* 2F97 */ { "KANGXI RADICAL PIG","	* Kangxi Radical 152\n"
	"	# 8C55"},
/* 2F98 */ { "KANGXI RADICAL BADGER","	* Kangxi Radical 153\n"
	"	# 8C78"},
/* 2F99 */ { "KANGXI RADICAL SHELL","	* Kangxi Radical 154\n"
	"	# 8C9D"},
/* 2F9A */ { "KANGXI RADICAL RED","	* Kangxi Radical 155\n"
	"	# 8D64"},
/* 2F9B */ { "KANGXI RADICAL RUN","	* Kangxi Radical 156\n"
	"	# 8D70"},
/* 2F9C */ { "KANGXI RADICAL FOOT","	* Kangxi Radical 157\n"
	"	# 8DB3"},
/* 2F9D */ { "KANGXI RADICAL BODY","	* Kangxi Radical 158\n"
	"	# 8EAB"},
/* 2F9E */ { "KANGXI RADICAL CART","	* Kangxi Radical 159\n"
	"	# 8ECA"},
/* 2F9F */ { "KANGXI RADICAL BITTER","	* Kangxi Radical 160\n"
	"	# 8F9B"},
/* 2FA0 */ { "KANGXI RADICAL MORNING","	* Kangxi Radical 161\n"
	"	# 8FB0"},
/* 2FA1 */ { "KANGXI RADICAL WALK","	* Kangxi Radical 162\n"
	"	# 8FB5"},
/* 2FA2 */ { "KANGXI RADICAL CITY","	* Kangxi Radical 163\n"
	"	# 9091"},
/* 2FA3 */ { "KANGXI RADICAL WINE","	* Kangxi Radical 164\n"
	"	# 9149"},
/* 2FA4 */ { "KANGXI RADICAL DISTINGUISH","	* Kangxi Radical 165\n"
	"	# 91C6"},
/* 2FA5 */ { "KANGXI RADICAL VILLAGE","	* Kangxi Radical 166\n"
	"	# 91CC"},
/* 2FA6 */ { "KANGXI RADICAL GOLD","	* Kangxi Radical 167\n"
	"	# 91D1"},
/* 2FA7 */ { "KANGXI RADICAL LONG","	* Kangxi Radical 168\n"
	"	# 9577"},
/* 2FA8 */ { "KANGXI RADICAL GATE","	* Kangxi Radical 169\n"
	"	# 9580"},
/* 2FA9 */ { "KANGXI RADICAL MOUND","	* Kangxi Radical 170\n"
	"	# 961C"},
/* 2FAA */ { "KANGXI RADICAL SLAVE","	* Kangxi Radical 171\n"
	"	# 96B6"},
/* 2FAB */ { "KANGXI RADICAL SHORT TAILED BIRD","	* Kangxi Radical 172\n"
	"	# 96B9"},
/* 2FAC */ { "KANGXI RADICAL RAIN","	* Kangxi Radical 173\n"
	"	# 96E8"},
/* 2FAD */ { "KANGXI RADICAL BLUE","	* Kangxi Radical 174\n"
	"	# 9751"},
/* 2FAE */ { "KANGXI RADICAL WRONG","	* Kangxi Radical 175\n"
	"	# 975E"},
/* 2FAF */ { "KANGXI RADICAL FACE","	* Kangxi Radical 176\n"
	"	# 9762"},
/* 2FB0 */ { "KANGXI RADICAL LEATHER","	* Kangxi Radical 177\n"
	"	# 9769"},
/* 2FB1 */ { "KANGXI RADICAL TANNED LEATHER","	* Kangxi Radical 178\n"
	"	# 97CB"},
/* 2FB2 */ { "KANGXI RADICAL LEEK","	* Kangxi Radical 179\n"
	"	# 97ED"},
/* 2FB3 */ { "KANGXI RADICAL SOUND","	* Kangxi Radical 180\n"
	"	# 97F3"},
/* 2FB4 */ { "KANGXI RADICAL LEAF","	* Kangxi Radical 181\n"
	"	# 9801"},
/* 2FB5 */ { "KANGXI RADICAL WIND","	* Kangxi Radical 182\n"
	"	# 98A8"},
/* 2FB6 */ { "KANGXI RADICAL FLY","	* Kangxi Radical 183\n"
	"	# 98DB"},
/* 2FB7 */ { "KANGXI RADICAL EAT","	* Kangxi Radical 184\n"
	"	# 98DF"},
/* 2FB8 */ { "KANGXI RADICAL HEAD","	* Kangxi Radical 185\n"
	"	# 9996"},
/* 2FB9 */ { "KANGXI RADICAL FRAGRANT","	* Kangxi Radical 186\n"
	"	# 9999"},
/* 2FBA */ { "KANGXI RADICAL HORSE","	* Kangxi Radical 187\n"
	"	# 99AC"},
/* 2FBB */ { "KANGXI RADICAL BONE","	* Kangxi Radical 188\n"
	"	# 9AA8"},
/* 2FBC */ { "KANGXI RADICAL TALL","	* Kangxi Radical 189\n"
	"	# 9AD8"},
/* 2FBD */ { "KANGXI RADICAL HAIR","	* Kangxi Radical 190\n"
	"	# 9ADF"},
/* 2FBE */ { "KANGXI RADICAL FIGHT","	* Kangxi Radical 191\n"
	"	# 9B25"},
/* 2FBF */ { "KANGXI RADICAL SACRIFICIAL WINE","	* Kangxi Radical 192\n"
	"	# 9B2F"},
/* 2FC0 */ { "KANGXI RADICAL CAULDRON","	* Kangxi Radical 193\n"
	"	# 9B32"},
/* 2FC1 */ { "KANGXI RADICAL GHOST","	* Kangxi Radical 194\n"
	"	# 9B3C"},
/* 2FC2 */ { "KANGXI RADICAL FISH","	* Kangxi Radical 195\n"
	"	# 9B5A"},
/* 2FC3 */ { "KANGXI RADICAL BIRD","	* Kangxi Radical 196\n"
	"	# 9CE5"},
/* 2FC4 */ { "KANGXI RADICAL SALT","	* Kangxi Radical 197\n"
	"	# 9E75"},
/* 2FC5 */ { "KANGXI RADICAL DEER","	* Kangxi Radical 198\n"
	"	# 9E7F"},
/* 2FC6 */ { "KANGXI RADICAL WHEAT","	* Kangxi Radical 199\n"
	"	# 9EA5"},
/* 2FC7 */ { "KANGXI RADICAL HEMP","	* Kangxi Radical 200\n"
	"	# 9EBB"},
/* 2FC8 */ { "KANGXI RADICAL YELLOW","	* Kangxi Radical 201\n"
	"	# 9EC3"},
/* 2FC9 */ { "KANGXI RADICAL MILLET","	* Kangxi Radical 202\n"
	"	# 9ECD"},
/* 2FCA */ { "KANGXI RADICAL BLACK","	* Kangxi Radical 203\n"
	"	# 9ED1"},
/* 2FCB */ { "KANGXI RADICAL EMBROIDERY","	* Kangxi Radical 204\n"
	"	# 9EF9"},
/* 2FCC */ { "KANGXI RADICAL FROG","	* Kangxi Radical 205\n"
	"	# 9EFD"},
/* 2FCD */ { "KANGXI RADICAL TRIPOD","	* Kangxi Radical 206\n"
	"	# 9F0E"},
/* 2FCE */ { "KANGXI RADICAL DRUM","	* Kangxi Radical 207\n"
	"	# 9F13"},
/* 2FCF */ { "KANGXI RADICAL RAT","	* Kangxi Radical 208\n"
	"	# 9F20"},
/* 2FD0 */ { "KANGXI RADICAL NOSE","	* Kangxi Radical 209\n"
	"	# 9F3B"},
/* 2FD1 */ { "KANGXI RADICAL EVEN","	* Kangxi Radical 210\n"
	"	# 9F4A"},
/* 2FD2 */ { "KANGXI RADICAL TOOTH","	* Kangxi Radical 211\n"
	"	# 9F52"},
/* 2FD3 */ { "KANGXI RADICAL DRAGON","	* Kangxi Radical 212\n"
	"	# 9F8D"},
/* 2FD4 */ { "KANGXI RADICAL TURTLE","	* Kangxi Radical 213\n"
	"	# 9F9C"},
/* 2FD5 */ { "KANGXI RADICAL FLUTE","	* Kangxi Radical 214\n"
	"	# 9FA0"},
/* 2FD6 */ { NULL,NULL},
/* 2FD7 */ { NULL,NULL},
/* 2FD8 */ { NULL,NULL},
/* 2FD9 */ { NULL,NULL},
/* 2FDA */ { NULL,NULL},
/* 2FDB */ { NULL,NULL},
/* 2FDC */ { NULL,NULL},
/* 2FDD */ { NULL,NULL},
/* 2FDE */ { NULL,NULL},
/* 2FDF */ { NULL,NULL},
/* 2FE0 */ { NULL,NULL},
/* 2FE1 */ { NULL,NULL},
/* 2FE2 */ { NULL,NULL},
/* 2FE3 */ { NULL,NULL},
/* 2FE4 */ { NULL,NULL},
/* 2FE5 */ { NULL,NULL},
/* 2FE6 */ { NULL,NULL},
/* 2FE7 */ { NULL,NULL},
/* 2FE8 */ { NULL,NULL},
/* 2FE9 */ { NULL,NULL},
/* 2FEA */ { NULL,NULL},
/* 2FEB */ { NULL,NULL},
/* 2FEC */ { NULL,NULL},
/* 2FED */ { NULL,NULL},
/* 2FEE */ { NULL,NULL},
/* 2FEF */ { NULL,NULL},
/* 2FF0 */ { "IDEOGRAPHIC DESCRIPTION CHARACTER LEFT TO RIGHT",NULL},
/* 2FF1 */ { "IDEOGRAPHIC DESCRIPTION CHARACTER ABOVE TO BELOW",NULL},
/* 2FF2 */ { "IDEOGRAPHIC DESCRIPTION CHARACTER LEFT TO MIDDLE AND RIGHT",NULL},
/* 2FF3 */ { "IDEOGRAPHIC DESCRIPTION CHARACTER ABOVE TO MIDDLE AND BELOW",NULL},
/* 2FF4 */ { "IDEOGRAPHIC DESCRIPTION CHARACTER FULL SURROUND",NULL},
/* 2FF5 */ { "IDEOGRAPHIC DESCRIPTION CHARACTER SURROUND FROM ABOVE",NULL},
/* 2FF6 */ { "IDEOGRAPHIC DESCRIPTION CHARACTER SURROUND FROM BELOW",NULL},
/* 2FF7 */ { "IDEOGRAPHIC DESCRIPTION CHARACTER SURROUND FROM LEFT",NULL},
/* 2FF8 */ { "IDEOGRAPHIC DESCRIPTION CHARACTER SURROUND FROM UPPER LEFT",NULL},
/* 2FF9 */ { "IDEOGRAPHIC DESCRIPTION CHARACTER SURROUND FROM UPPER RIGHT",NULL},
/* 2FFA */ { "IDEOGRAPHIC DESCRIPTION CHARACTER SURROUND FROM LOWER LEFT",NULL},
/* 2FFB */ { "IDEOGRAPHIC DESCRIPTION CHARACTER OVERLAID",NULL},
/* 2FFC */ { "IDEOGRAPHIC DESCRIPTION CHARACTER SURROUND FROM RIGHT",NULL},
/* 2FFD */ { "IDEOGRAPHIC DESCRIPTION CHARACTER SURROUND FROM LOWER RIGHT",NULL},
/* 2FFE */ { "IDEOGRAPHIC DESCRIPTION CHARACTER HORIZONTAL REFLECTION",NULL},
/* 2FFF */ { "IDEOGRAPHIC DESCRIPTION CHARACTER ROTATION",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_00_30[] = {
/* 3000 */ { "IDEOGRAPHIC SPACE","	x (space - 0020)\n"
	"	# <wide> 0020"},
/* 3001 */ { "IDEOGRAPHIC COMMA","	* in Chinese, delimits items in a list or series\n"
	"	x (comma - 002C)\n"
	"	x (fullwidth comma - FF0C)\n"
	"	x (halfwidth ideographic comma - FF64)\n"
	"	~ 3001 FE00 corner-justified form\n"
	"	~ 3001 FE01 centered form"},
/* 3002 */ { "IDEOGRAPHIC FULL STOP","	x (full stop - 002E)\n"
	"	x (fullwidth full stop - FF0E)\n"
	"	x (halfwidth ideographic full stop - FF61)\n"
	"	~ 3002 FE00 corner-justified form\n"
	"	~ 3002 FE01 centered form"},
/* 3003 */ { "DITTO MARK","	x (double prime - 2033)"},
/* 3004 */ { "JAPANESE INDUSTRIAL STANDARD SYMBOL",NULL},
/* 3005 */ { "IDEOGRAPHIC ITERATION MARK","	x 206A4\n"
	"	x (tangut iteration mark - 16FE0)"},
/* 3006 */ { "IDEOGRAPHIC CLOSING MARK","	x 4E44"},
/* 3007 */ { "IDEOGRAPHIC NUMBER ZERO","	x (combining enclosing circle - 20DD)\n"
	"	x (white circle - 25CB)\n"
	"	x (large circle - 25EF)"},
/* 3008 */ { "LEFT ANGLE BRACKET","	x (less-than sign - 003C)\n"
	"	x (single left-pointing angle quotation mark - 2039)\n"
	"	x (left-pointing angle bracket - 2329)\n"
	"	x (mathematical left angle bracket - 27E8)"},
/* 3009 */ { "RIGHT ANGLE BRACKET","	x (greater-than sign - 003E)\n"
	"	x (single right-pointing angle quotation mark - 203A)\n"
	"	x (right-pointing angle bracket - 232A)\n"
	"	x (mathematical right angle bracket - 27E9)"},
/* 300A */ { "LEFT DOUBLE ANGLE BRACKET","	x (left-pointing double angle quotation mark - 00AB)\n"
	"	x (mathematical left double angle bracket - 27EA)"},
/* 300B */ { "RIGHT DOUBLE ANGLE BRACKET","	x (right-pointing double angle quotation mark - 00BB)\n"
	"	x (mathematical right double angle bracket - 27EB)"},
/* 300C */ { "LEFT CORNER BRACKET","	x (left ceiling - 2308)"},
/* 300D */ { "RIGHT CORNER BRACKET","	x (right floor - 230B)"},
/* 300E */ { "LEFT WHITE CORNER BRACKET",NULL},
/* 300F */ { "RIGHT WHITE CORNER BRACKET",NULL},
/* 3010 */ { "LEFT BLACK LENTICULAR BRACKET",NULL},
/* 3011 */ { "RIGHT BLACK LENTICULAR BRACKET",NULL},
/* 3012 */ { "POSTAL MARK","	x (tenge sign - 20B8)\n"
	"	x (short down tack with overbar - 2AE7)\n"
	"	x (japanese post office - 1F3E3)"},
/* 3013 */ { "GETA MARK","	* substitute for ideograph not in font\n"
	"	* editorial convention to represent ideographic lacuna\n"
	"	x (white square - 25A1)\n"
	"	x (heavy equals sign - 1F7F0)"},
/* 3014 */ { "LEFT TORTOISE SHELL BRACKET",NULL},
/* 3015 */ { "RIGHT TORTOISE SHELL BRACKET",NULL},
/* 3016 */ { "LEFT WHITE LENTICULAR BRACKET",NULL},
/* 3017 */ { "RIGHT WHITE LENTICULAR BRACKET",NULL},
/* 3018 */ { "LEFT WHITE TORTOISE SHELL BRACKET","	x (mathematical left white tortoise shell bracket - 27EC)"},
/* 3019 */ { "RIGHT WHITE TORTOISE SHELL BRACKET","	x (mathematical right white tortoise shell bracket - 27ED)"},
/* 301A */ { "LEFT WHITE SQUARE BRACKET","	= left abstract syntax bracket\n"
	"	x (mathematical left white square bracket - 27E6)"},
/* 301B */ { "RIGHT WHITE SQUARE BRACKET","	= right abstract syntax bracket\n"
	"	x (mathematical right white square bracket - 27E7)"},
/* 301C */ { "WAVE DASH","		This character was encoded to match JIS C 6226-1978 1-33 \"wave dash\".\n"
	"	x (swung dash - 2053)\n"
	"	x (wavy dash - 3030)\n"
	"	x (fullwidth tilde - FF5E)"},
/* 301D */ { "REVERSED DOUBLE PRIME QUOTATION MARK","	* sometimes depicted as double prime quotation mark\n"
	"	x (left double quotation mark - 201C)\n"
	"	x (reversed double prime - 2036)"},
/* 301E */ { "DOUBLE PRIME QUOTATION MARK","	* this is a mistaken analogue to 201D; 301F is preferred\n"
	"	x (right double quotation mark - 201D)\n"
	"	x (double prime - 2033)"},
/* 301F */ { "LOW DOUBLE PRIME QUOTATION MARK","	* may be depicted as low inverse double prime quotation mark"},
/* 3020 */ { "POSTAL MARK FACE",NULL},
/* 3021 */ { "HANGZHOU NUMERAL ONE",NULL},
/* 3022 */ { "HANGZHOU NUMERAL TWO",NULL},
/* 3023 */ { "HANGZHOU NUMERAL THREE",NULL},
/* 3024 */ { "HANGZHOU NUMERAL FOUR",NULL},
/* 3025 */ { "HANGZHOU NUMERAL FIVE",NULL},
/* 3026 */ { "HANGZHOU NUMERAL SIX","	= yangqin sign slow one half beat\n"
	"	* represents one half beat in the yangqin tempo marking system\n"
	"	x (yangqin sign slow one beat - 16FF4)"},
/* 3027 */ { "HANGZHOU NUMERAL SEVEN",NULL},
/* 3028 */ { "HANGZHOU NUMERAL EIGHT",NULL},
/* 3029 */ { "HANGZHOU NUMERAL NINE",NULL},
/* 302A */ { "IDEOGRAPHIC LEVEL TONE MARK",NULL},
/* 302B */ { "IDEOGRAPHIC RISING TONE MARK",NULL},
/* 302C */ { "IDEOGRAPHIC DEPARTING TONE MARK",NULL},
/* 302D */ { "IDEOGRAPHIC ENTERING TONE MARK",NULL},
/* 302E */ { "HANGUL SINGLE DOT TONE MARK","	= single dot Bangjeom"},
/* 302F */ { "HANGUL DOUBLE DOT TONE MARK","	= double dot Bangjeom"},
/* 3030 */ { "WAVY DASH","	x (wavy line - 2307)\n"
	"	x (wave dash - 301C)"},
/* 3031 */ { "VERTICAL KANA REPEAT MARK",NULL},
/* 3032 */ { "VERTICAL KANA REPEAT WITH VOICED SOUND MARK","	* implemented as glyphs that are two-em tall"},
/* 3033 */ { "VERTICAL KANA REPEAT MARK UPPER HALF",NULL},
/* 3034 */ { "VERTICAL KANA REPEAT WITH VOICED SOUND MARK UPPER HALF","	* implemented as glyphs that are one-em tall and that combine with the following character to form ligated two-em glyphs for the complete repeat marks"},
/* 3035 */ { "VERTICAL KANA REPEAT MARK LOWER HALF",NULL},
/* 3036 */ { "CIRCLED POSTAL MARK","	= symbol for type B electronics\n"
	"	* not used as a postal mark\n"
	"	x (symbol for type a electronics - 2B97)\n"
	"	# 3012 postal mark"},
/* 3037 */ { "IDEOGRAPHIC TELEGRAPH LINE FEED SEPARATOR SYMBOL",NULL},
/* 3038 */ { "HANGZHOU NUMERAL TEN","	# 5341"},
/* 3039 */ { "HANGZHOU NUMERAL TWENTY","	# 5344"},
/* 303A */ { "HANGZHOU NUMERAL THIRTY","	# 5345"},
/* 303B */ { "VERTICAL IDEOGRAPHIC ITERATION MARK",NULL},
/* 303C */ { "MASU MARK","	* informal abbreviation for Japanese -masu ending\n"
	"	x (squared rising diagonal slash - 29C4)"},
/* 303D */ { "PART ALTERNATION MARK","	* marks the start of a song part in Japanese"},
/* 303E */ { "IDEOGRAPHIC VARIATION INDICATOR","	* visual indicator that the following ideograph is to be taken as a variant of the intended character"},
/* 303F */ { "IDEOGRAPHIC HALF FILL SPACE","	* visual indicator of a screen space for half of an ideograph"},
/* 3040 */ { NULL,NULL},
/* 3041 */ { "HIRAGANA LETTER SMALL A",NULL},
/* 3042 */ { "HIRAGANA LETTER A",NULL},
/* 3043 */ { "HIRAGANA LETTER SMALL I",NULL},
/* 3044 */ { "HIRAGANA LETTER I",NULL},
/* 3045 */ { "HIRAGANA LETTER SMALL U",NULL},
/* 3046 */ { "HIRAGANA LETTER U",NULL},
/* 3047 */ { "HIRAGANA LETTER SMALL E",NULL},
/* 3048 */ { "HIRAGANA LETTER E",NULL},
/* 3049 */ { "HIRAGANA LETTER SMALL O",NULL},
/* 304A */ { "HIRAGANA LETTER O",NULL},
/* 304B */ { "HIRAGANA LETTER KA",NULL},
/* 304C */ { "HIRAGANA LETTER GA","	: 304B 3099"},
/* 304D */ { "HIRAGANA LETTER KI",NULL},
/* 304E */ { "HIRAGANA LETTER GI","	: 304D 3099"},
/* 304F */ { "HIRAGANA LETTER KU",NULL},
/* 3050 */ { "HIRAGANA LETTER GU","	: 304F 3099"},
/* 3051 */ { "HIRAGANA LETTER KE",NULL},
/* 3052 */ { "HIRAGANA LETTER GE","	: 3051 3099"},
/* 3053 */ { "HIRAGANA LETTER KO",NULL},
/* 3054 */ { "HIRAGANA LETTER GO","	: 3053 3099"},
/* 3055 */ { "HIRAGANA LETTER SA",NULL},
/* 3056 */ { "HIRAGANA LETTER ZA","	: 3055 3099"},
/* 3057 */ { "HIRAGANA LETTER SI","	= SHI"},
/* 3058 */ { "HIRAGANA LETTER ZI","	= JI (not unique)\n"
	"	: 3057 3099"},
/* 3059 */ { "HIRAGANA LETTER SU",NULL},
/* 305A */ { "HIRAGANA LETTER ZU","	: 3059 3099"},
/* 305B */ { "HIRAGANA LETTER SE",NULL},
/* 305C */ { "HIRAGANA LETTER ZE","	: 305B 3099"},
/* 305D */ { "HIRAGANA LETTER SO",NULL},
/* 305E */ { "HIRAGANA LETTER ZO","	: 305D 3099"},
/* 305F */ { "HIRAGANA LETTER TA",NULL},
/* 3060 */ { "HIRAGANA LETTER DA","	: 305F 3099"},
/* 3061 */ { "HIRAGANA LETTER TI","	= CHI"},
/* 3062 */ { "HIRAGANA LETTER DI","	= JI (not unique)\n"
	"	: 3061 3099"},
/* 3063 */ { "HIRAGANA LETTER SMALL TU","	= SMALL TSU"},
/* 3064 */ { "HIRAGANA LETTER TU","	= TSU"},
/* 3065 */ { "HIRAGANA LETTER DU","	= ZU (not unique)\n"
	"	: 3064 3099"},
/* 3066 */ { "HIRAGANA LETTER TE",NULL},
/* 3067 */ { "HIRAGANA LETTER DE","	: 3066 3099"},
/* 3068 */ { "HIRAGANA LETTER TO",NULL},
/* 3069 */ { "HIRAGANA LETTER DO","	: 3068 3099"},
/* 306A */ { "HIRAGANA LETTER NA",NULL},
/* 306B */ { "HIRAGANA LETTER NI",NULL},
/* 306C */ { "HIRAGANA LETTER NU",NULL},
/* 306D */ { "HIRAGANA LETTER NE",NULL},
/* 306E */ { "HIRAGANA LETTER NO",NULL},
/* 306F */ { "HIRAGANA LETTER HA",NULL},
/* 3070 */ { "HIRAGANA LETTER BA","	: 306F 3099"},
/* 3071 */ { "HIRAGANA LETTER PA","	: 306F 309A"},
/* 3072 */ { "HIRAGANA LETTER HI",NULL},
/* 3073 */ { "HIRAGANA LETTER BI","	: 3072 3099"},
/* 3074 */ { "HIRAGANA LETTER PI","	: 3072 309A"},
/* 3075 */ { "HIRAGANA LETTER HU","	= FU"},
/* 3076 */ { "HIRAGANA LETTER BU","	: 3075 3099"},
/* 3077 */ { "HIRAGANA LETTER PU","	: 3075 309A"},
/* 3078 */ { "HIRAGANA LETTER HE",NULL},
/* 3079 */ { "HIRAGANA LETTER BE","	: 3078 3099"},
/* 307A */ { "HIRAGANA LETTER PE","	: 3078 309A"},
/* 307B */ { "HIRAGANA LETTER HO",NULL},
/* 307C */ { "HIRAGANA LETTER BO","	: 307B 3099"},
/* 307D */ { "HIRAGANA LETTER PO","	: 307B 309A"},
/* 307E */ { "HIRAGANA LETTER MA",NULL},
/* 307F */ { "HIRAGANA LETTER MI",NULL},
/* 3080 */ { "HIRAGANA LETTER MU",NULL},
/* 3081 */ { "HIRAGANA LETTER ME",NULL},
/* 3082 */ { "HIRAGANA LETTER MO",NULL},
/* 3083 */ { "HIRAGANA LETTER SMALL YA",NULL},
/* 3084 */ { "HIRAGANA LETTER YA",NULL},
/* 3085 */ { "HIRAGANA LETTER SMALL YU",NULL},
/* 3086 */ { "HIRAGANA LETTER YU",NULL},
/* 3087 */ { "HIRAGANA LETTER SMALL YO",NULL},
/* 3088 */ { "HIRAGANA LETTER YO",NULL},
/* 3089 */ { "HIRAGANA LETTER RA",NULL},
/* 308A */ { "HIRAGANA LETTER RI",NULL},
/* 308B */ { "HIRAGANA LETTER RU",NULL},
/* 308C */ { "HIRAGANA LETTER RE",NULL},
/* 308D */ { "HIRAGANA LETTER RO",NULL},
/* 308E */ { "HIRAGANA LETTER SMALL WA",NULL},
/* 308F */ { "HIRAGANA LETTER WA",NULL},
/* 3090 */ { "HIRAGANA LETTER WI",NULL},
/* 3091 */ { "HIRAGANA LETTER WE",NULL},
/* 3092 */ { "HIRAGANA LETTER WO",NULL},
/* 3093 */ { "HIRAGANA LETTER N",NULL},
/* 3094 */ { "HIRAGANA LETTER VU","	: 3046 3099"},
/* 3095 */ { "HIRAGANA LETTER SMALL KA",NULL},
/* 3096 */ { "HIRAGANA LETTER SMALL KE",NULL},
/* 3097 */ { NULL,NULL},
/* 3098 */ { NULL,NULL},
/* 3099 */ { "COMBINING KATAKANA-HIRAGANA VOICED SOUND MARK",NULL},
/* 309A */ { "COMBINING KATAKANA-HIRAGANA SEMI-VOICED SOUND MARK",NULL},
/* 309B */ { "KATAKANA-HIRAGANA VOICED SOUND MARK","	# 0020 3099"},
/* 309C */ { "KATAKANA-HIRAGANA SEMI-VOICED SOUND MARK","	# 0020 309A"},
/* 309D */ { "HIRAGANA ITERATION MARK",NULL},
/* 309E */ { "HIRAGANA VOICED ITERATION MARK","	: 309D 3099"},
/* 309F */ { "HIRAGANA DIGRAPH YORI","	* represents the Japanese word \"yori\" (from or than)\n"
	"	* historically used in vertical contexts, but now found also in horizontal layout\n"
	"	# <vertical> 3088 308A"},
/* 30A0 */ { "KATAKANA-HIRAGANA DOUBLE HYPHEN","	x (equals sign - 003D)\n"
	"	x (double hyphen - 2E40)"},
/* 30A1 */ { "KATAKANA LETTER SMALL A",NULL},
/* 30A2 */ { "KATAKANA LETTER A",NULL},
/* 30A3 */ { "KATAKANA LETTER SMALL I",NULL},
/* 30A4 */ { "KATAKANA LETTER I",NULL},
/* 30A5 */ { "KATAKANA LETTER SMALL U",NULL},
/* 30A6 */ { "KATAKANA LETTER U",NULL},
/* 30A7 */ { "KATAKANA LETTER SMALL E",NULL},
/* 30A8 */ { "KATAKANA LETTER E",NULL},
/* 30A9 */ { "KATAKANA LETTER SMALL O",NULL},
/* 30AA */ { "KATAKANA LETTER O",NULL},
/* 30AB */ { "KATAKANA LETTER KA",NULL},
/* 30AC */ { "KATAKANA LETTER GA","	: 30AB 3099"},
/* 30AD */ { "KATAKANA LETTER KI",NULL},
/* 30AE */ { "KATAKANA LETTER GI","	: 30AD 3099"},
/* 30AF */ { "KATAKANA LETTER KU",NULL},
/* 30B0 */ { "KATAKANA LETTER GU","	: 30AF 3099"},
/* 30B1 */ { "KATAKANA LETTER KE",NULL},
/* 30B2 */ { "KATAKANA LETTER GE","	: 30B1 3099"},
/* 30B3 */ { "KATAKANA LETTER KO",NULL},
/* 30B4 */ { "KATAKANA LETTER GO","	: 30B3 3099"},
/* 30B5 */ { "KATAKANA LETTER SA",NULL},
/* 30B6 */ { "KATAKANA LETTER ZA","	: 30B5 3099"},
/* 30B7 */ { "KATAKANA LETTER SI","	= SHI"},
/* 30B8 */ { "KATAKANA LETTER ZI","	= JI (not unique)\n"
	"	: 30B7 3099"},
/* 30B9 */ { "KATAKANA LETTER SU",NULL},
/* 30BA */ { "KATAKANA LETTER ZU","	: 30B9 3099"},
/* 30BB */ { "KATAKANA LETTER SE",NULL},
/* 30BC */ { "KATAKANA LETTER ZE","	: 30BB 3099"},
/* 30BD */ { "KATAKANA LETTER SO",NULL},
/* 30BE */ { "KATAKANA LETTER ZO","	: 30BD 3099"},
/* 30BF */ { "KATAKANA LETTER TA",NULL},
/* 30C0 */ { "KATAKANA LETTER DA","	: 30BF 3099"},
/* 30C1 */ { "KATAKANA LETTER TI","	= CHI"},
/* 30C2 */ { "KATAKANA LETTER DI","	= JI (not unique)\n"
	"	: 30C1 3099"},
/* 30C3 */ { "KATAKANA LETTER SMALL TU","	= SMALL TSU"},
/* 30C4 */ { "KATAKANA LETTER TU","	= TSU"},
/* 30C5 */ { "KATAKANA LETTER DU","	= ZU (not unique)\n"
	"	: 30C4 3099"},
/* 30C6 */ { "KATAKANA LETTER TE",NULL},
/* 30C7 */ { "KATAKANA LETTER DE","	: 30C6 3099"},
/* 30C8 */ { "KATAKANA LETTER TO",NULL},
/* 30C9 */ { "KATAKANA LETTER DO","	: 30C8 3099"},
/* 30CA */ { "KATAKANA LETTER NA",NULL},
/* 30CB */ { "KATAKANA LETTER NI",NULL},
/* 30CC */ { "KATAKANA LETTER NU",NULL},
/* 30CD */ { "KATAKANA LETTER NE",NULL},
/* 30CE */ { "KATAKANA LETTER NO",NULL},
/* 30CF */ { "KATAKANA LETTER HA",NULL},
/* 30D0 */ { "KATAKANA LETTER BA","	: 30CF 3099"},
/* 30D1 */ { "KATAKANA LETTER PA","	: 30CF 309A"},
/* 30D2 */ { "KATAKANA LETTER HI",NULL},
/* 30D3 */ { "KATAKANA LETTER BI","	: 30D2 3099"},
/* 30D4 */ { "KATAKANA LETTER PI","	: 30D2 309A"},
/* 30D5 */ { "KATAKANA LETTER HU","	= FU"},
/* 30D6 */ { "KATAKANA LETTER BU","	: 30D5 3099"},
/* 30D7 */ { "KATAKANA LETTER PU","	: 30D5 309A"},
/* 30D8 */ { "KATAKANA LETTER HE",NULL},
/* 30D9 */ { "KATAKANA LETTER BE","	: 30D8 3099"},
/* 30DA */ { "KATAKANA LETTER PE","	: 30D8 309A"},
/* 30DB */ { "KATAKANA LETTER HO",NULL},
/* 30DC */ { "KATAKANA LETTER BO","	: 30DB 3099"},
/* 30DD */ { "KATAKANA LETTER PO","	: 30DB 309A"},
/* 30DE */ { "KATAKANA LETTER MA",NULL},
/* 30DF */ { "KATAKANA LETTER MI",NULL},
/* 30E0 */ { "KATAKANA LETTER MU",NULL},
/* 30E1 */ { "KATAKANA LETTER ME",NULL},
/* 30E2 */ { "KATAKANA LETTER MO",NULL},
/* 30E3 */ { "KATAKANA LETTER SMALL YA",NULL},
/* 30E4 */ { "KATAKANA LETTER YA",NULL},
/* 30E5 */ { "KATAKANA LETTER SMALL YU",NULL},
/* 30E6 */ { "KATAKANA LETTER YU",NULL},
/* 30E7 */ { "KATAKANA LETTER SMALL YO",NULL},
/* 30E8 */ { "KATAKANA LETTER YO",NULL},
/* 30E9 */ { "KATAKANA LETTER RA",NULL},
/* 30EA */ { "KATAKANA LETTER RI",NULL},
/* 30EB */ { "KATAKANA LETTER RU",NULL},
/* 30EC */ { "KATAKANA LETTER RE",NULL},
/* 30ED */ { "KATAKANA LETTER RO",NULL},
/* 30EE */ { "KATAKANA LETTER SMALL WA",NULL},
/* 30EF */ { "KATAKANA LETTER WA",NULL},
/* 30F0 */ { "KATAKANA LETTER WI",NULL},
/* 30F1 */ { "KATAKANA LETTER WE",NULL},
/* 30F2 */ { "KATAKANA LETTER WO",NULL},
/* 30F3 */ { "KATAKANA LETTER N",NULL},
/* 30F4 */ { "KATAKANA LETTER VU","	: 30A6 3099"},
/* 30F5 */ { "KATAKANA LETTER SMALL KA",NULL},
/* 30F6 */ { "KATAKANA LETTER SMALL KE",NULL},
/* 30F7 */ { "KATAKANA LETTER VA","	: 30EF 3099"},
/* 30F8 */ { "KATAKANA LETTER VI","	: 30F0 3099"},
/* 30F9 */ { "KATAKANA LETTER VE","	: 30F1 3099"},
/* 30FA */ { "KATAKANA LETTER VO","	: 30F2 3099"},
/* 30FB */ { "KATAKANA MIDDLE DOT","	x (middle dot - 00B7)"},
/* 30FC */ { "KATAKANA-HIRAGANA PROLONGED SOUND MARK","	x (em dash - 2014)"},
/* 30FD */ { "KATAKANA ITERATION MARK",NULL},
/* 30FE */ { "KATAKANA VOICED ITERATION MARK","	: 30FD 3099"},
/* 30FF */ { "KATAKANA DIGRAPH KOTO","	* represents the Japanese word \"koto\" (thing)\n"
	"	* historically used in vertical contexts, but now found also in horizontal layout\n"
	"	# <vertical> 30B3 30C8"}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_00_31[] = {
/* 3100 */ { NULL,NULL},
/* 3101 */ { NULL,NULL},
/* 3102 */ { NULL,NULL},
/* 3103 */ { NULL,NULL},
/* 3104 */ { NULL,NULL},
/* 3105 */ { "BOPOMOFO LETTER B",NULL},
/* 3106 */ { "BOPOMOFO LETTER P",NULL},
/* 3107 */ { "BOPOMOFO LETTER M",NULL},
/* 3108 */ { "BOPOMOFO LETTER F",NULL},
/* 3109 */ { "BOPOMOFO LETTER D",NULL},
/* 310A */ { "BOPOMOFO LETTER T",NULL},
/* 310B */ { "BOPOMOFO LETTER N",NULL},
/* 310C */ { "BOPOMOFO LETTER L",NULL},
/* 310D */ { "BOPOMOFO LETTER G",NULL},
/* 310E */ { "BOPOMOFO LETTER K",NULL},
/* 310F */ { "BOPOMOFO LETTER H",NULL},
/* 3110 */ { "BOPOMOFO LETTER J",NULL},
/* 3111 */ { "BOPOMOFO LETTER Q",NULL},
/* 3112 */ { "BOPOMOFO LETTER X",NULL},
/* 3113 */ { "BOPOMOFO LETTER ZH",NULL},
/* 3114 */ { "BOPOMOFO LETTER CH",NULL},
/* 3115 */ { "BOPOMOFO LETTER SH",NULL},
/* 3116 */ { "BOPOMOFO LETTER R",NULL},
/* 3117 */ { "BOPOMOFO LETTER Z",NULL},
/* 3118 */ { "BOPOMOFO LETTER C",NULL},
/* 3119 */ { "BOPOMOFO LETTER S",NULL},
/* 311A */ { "BOPOMOFO LETTER A",NULL},
/* 311B */ { "BOPOMOFO LETTER O",NULL},
/* 311C */ { "BOPOMOFO LETTER E",NULL},
/* 311D */ { "BOPOMOFO LETTER EH",NULL},
/* 311E */ { "BOPOMOFO LETTER AI",NULL},
/* 311F */ { "BOPOMOFO LETTER EI",NULL},
/* 3120 */ { "BOPOMOFO LETTER AU",NULL},
/* 3121 */ { "BOPOMOFO LETTER OU",NULL},
/* 3122 */ { "BOPOMOFO LETTER AN",NULL},
/* 3123 */ { "BOPOMOFO LETTER EN",NULL},
/* 3124 */ { "BOPOMOFO LETTER ANG",NULL},
/* 3125 */ { "BOPOMOFO LETTER ENG",NULL},
/* 3126 */ { "BOPOMOFO LETTER ER",NULL},
/* 3127 */ { "BOPOMOFO LETTER I","	* the vertical stroke form is considered a rendering variant"},
/* 3128 */ { "BOPOMOFO LETTER U",NULL},
/* 3129 */ { "BOPOMOFO LETTER IU",NULL},
/* 312A */ { "BOPOMOFO LETTER V",NULL},
/* 312B */ { "BOPOMOFO LETTER NG",NULL},
/* 312C */ { "BOPOMOFO LETTER GN",NULL},
/* 312D */ { "BOPOMOFO LETTER IH","	* for analytic representation of apical vowel"},
/* 312E */ { "BOPOMOFO LETTER O WITH DOT ABOVE","	* early form of letter e"},
/* 312F */ { "BOPOMOFO LETTER NN","	* syllabic nasal"},
/* 3130 */ { NULL,NULL},
/* 3131 */ { "HANGUL LETTER KIYEOK","	# 1100 hangul choseong kiyeok"},
/* 3132 */ { "HANGUL LETTER SSANGKIYEOK","	# 1101 hangul choseong ssangkiyeok"},
/* 3133 */ { "HANGUL LETTER KIYEOK-SIOS","	# 11AA hangul jongseong kiyeok-sios"},
/* 3134 */ { "HANGUL LETTER NIEUN","	# 1102 hangul choseong nieun"},
/* 3135 */ { "HANGUL LETTER NIEUN-CIEUC","	# 11AC hangul jongseong nieun-cieuc"},
/* 3136 */ { "HANGUL LETTER NIEUN-HIEUH","	# 11AD hangul jongseong nieun-hieuh"},
/* 3137 */ { "HANGUL LETTER TIKEUT","	# 1103 hangul choseong tikeut"},
/* 3138 */ { "HANGUL LETTER SSANGTIKEUT","	# 1104 hangul choseong ssangtikeut"},
/* 3139 */ { "HANGUL LETTER RIEUL","	# 1105 hangul choseong rieul"},
/* 313A */ { "HANGUL LETTER RIEUL-KIYEOK","	# 11B0 hangul jongseong rieul-kiyeok"},
/* 313B */ { "HANGUL LETTER RIEUL-MIEUM","	# 11B1 hangul jongseong rieul-mieum"},
/* 313C */ { "HANGUL LETTER RIEUL-PIEUP","	# 11B2 hangul jongseong rieul-pieup"},
/* 313D */ { "HANGUL LETTER RIEUL-SIOS","	# 11B3 hangul jongseong rieul-sios"},
/* 313E */ { "HANGUL LETTER RIEUL-THIEUTH","	# 11B4 hangul jongseong rieul-thieuth"},
/* 313F */ { "HANGUL LETTER RIEUL-PHIEUPH","	# 11B5 hangul jongseong rieul-phieuph"},
/* 3140 */ { "HANGUL LETTER RIEUL-HIEUH","	# 111A hangul choseong rieul-hieuh"},
/* 3141 */ { "HANGUL LETTER MIEUM","	# 1106 hangul choseong mieum"},
/* 3142 */ { "HANGUL LETTER PIEUP","	# 1107 hangul choseong pieup"},
/* 3143 */ { "HANGUL LETTER SSANGPIEUP","	# 1108 hangul choseong ssangpieup"},
/* 3144 */ { "HANGUL LETTER PIEUP-SIOS","	# 1121 hangul choseong pieup-sios"},
/* 3145 */ { "HANGUL LETTER SIOS","	# 1109 hangul choseong sios"},
/* 3146 */ { "HANGUL LETTER SSANGSIOS","	# 110A hangul choseong ssangsios"},
/* 3147 */ { "HANGUL LETTER IEUNG","	* zero sound as initial or velar nasal consonant as final\n"
	"	# 110B hangul choseong ieung"},
/* 3148 */ { "HANGUL LETTER CIEUC","	# 110C hangul choseong cieuc"},
/* 3149 */ { "HANGUL LETTER SSANGCIEUC","	# 110D hangul choseong ssangcieuc"},
/* 314A */ { "HANGUL LETTER CHIEUCH","	# 110E hangul choseong chieuch"},
/* 314B */ { "HANGUL LETTER KHIEUKH","	# 110F hangul choseong khieukh"},
/* 314C */ { "HANGUL LETTER THIEUTH","	# 1110 hangul choseong thieuth"},
/* 314D */ { "HANGUL LETTER PHIEUPH","	# 1111 hangul choseong phieuph"},
/* 314E */ { "HANGUL LETTER HIEUH","	* voiceless glottal fricative\n"
	"	# 1112 hangul choseong hieuh"},
/* 314F */ { "HANGUL LETTER A","	# 1161 hangul jungseong a"},
/* 3150 */ { "HANGUL LETTER AE","	# 1162 hangul jungseong ae"},
/* 3151 */ { "HANGUL LETTER YA","	# 1163 hangul jungseong ya"},
/* 3152 */ { "HANGUL LETTER YAE","	# 1164 hangul jungseong yae"},
/* 3153 */ { "HANGUL LETTER EO","	# 1165 hangul jungseong eo"},
/* 3154 */ { "HANGUL LETTER E","	# 1166 hangul jungseong e"},
/* 3155 */ { "HANGUL LETTER YEO","	# 1167 hangul jungseong yeo"},
/* 3156 */ { "HANGUL LETTER YE","	# 1168 hangul jungseong ye"},
/* 3157 */ { "HANGUL LETTER O","	# 1169 hangul jungseong o"},
/* 3158 */ { "HANGUL LETTER WA","	# 116A hangul jungseong wa"},
/* 3159 */ { "HANGUL LETTER WAE","	# 116B hangul jungseong wae"},
/* 315A */ { "HANGUL LETTER OE","	# 116C hangul jungseong oe"},
/* 315B */ { "HANGUL LETTER YO","	# 116D hangul jungseong yo"},
/* 315C */ { "HANGUL LETTER U","	# 116E hangul jungseong u"},
/* 315D */ { "HANGUL LETTER WEO","	# 116F hangul jungseong weo"},
/* 315E */ { "HANGUL LETTER WE","	# 1170 hangul jungseong we"},
/* 315F */ { "HANGUL LETTER WI","	# 1171 hangul jungseong wi"},
/* 3160 */ { "HANGUL LETTER YU","	# 1172 hangul jungseong yu"},
/* 3161 */ { "HANGUL LETTER EU","	# 1173 hangul jungseong eu"},
/* 3162 */ { "HANGUL LETTER YI","	# 1174 hangul jungseong yi"},
/* 3163 */ { "HANGUL LETTER I","	# 1175 hangul jungseong i"},
/* 3164 */ { "HANGUL FILLER","	= chaeum\n"
	"	# 1160 hangul jungseong filler"},
/* 3165 */ { "HANGUL LETTER SSANGNIEUN","	# 1114 hangul choseong ssangnieun"},
/* 3166 */ { "HANGUL LETTER NIEUN-TIKEUT","	# 1115 hangul choseong nieun-tikeut"},
/* 3167 */ { "HANGUL LETTER NIEUN-SIOS","	# 11C7 hangul jongseong nieun-sios"},
/* 3168 */ { "HANGUL LETTER NIEUN-PANSIOS","	# 11C8 hangul jongseong nieun-pansios"},
/* 3169 */ { "HANGUL LETTER RIEUL-KIYEOK-SIOS","	# 11CC hangul jongseong rieul-kiyeok-sios"},
/* 316A */ { "HANGUL LETTER RIEUL-TIKEUT","	# 11CE hangul jongseong rieul-tikeut"},
/* 316B */ { "HANGUL LETTER RIEUL-PIEUP-SIOS","	# 11D3 hangul jongseong rieul-pieup-sios"},
/* 316C */ { "HANGUL LETTER RIEUL-PANSIOS","	# 11D7 hangul jongseong rieul-pansios"},
/* 316D */ { "HANGUL LETTER RIEUL-YEORINHIEUH","	# 11D9 hangul jongseong rieul-yeorinhieuh"},
/* 316E */ { "HANGUL LETTER MIEUM-PIEUP","	# 111C hangul choseong mieum-pieup"},
/* 316F */ { "HANGUL LETTER MIEUM-SIOS","	# 11DD hangul jongseong mieum-sios"},
/* 3170 */ { "HANGUL LETTER MIEUM-PANSIOS","	# 11DF hangul jongseong mieum-pansios"},
/* 3171 */ { "HANGUL LETTER KAPYEOUNMIEUM","	# 111D hangul choseong kapyeounmieum"},
/* 3172 */ { "HANGUL LETTER PIEUP-KIYEOK","	# 111E hangul choseong pieup-kiyeok"},
/* 3173 */ { "HANGUL LETTER PIEUP-TIKEUT","	# 1120 hangul choseong pieup-tikeut"},
/* 3174 */ { "HANGUL LETTER PIEUP-SIOS-KIYEOK","	# 1122 hangul choseong pieup-sios-kiyeok"},
/* 3175 */ { "HANGUL LETTER PIEUP-SIOS-TIKEUT","	# 1123 hangul choseong pieup-sios-tikeut"},
/* 3176 */ { "HANGUL LETTER PIEUP-CIEUC","	# 1127 hangul choseong pieup-cieuc"},
/* 3177 */ { "HANGUL LETTER PIEUP-THIEUTH","	# 1129 hangul choseong pieup-thieuth"},
/* 3178 */ { "HANGUL LETTER KAPYEOUNPIEUP","	# 112B hangul choseong kapyeounpieup"},
/* 3179 */ { "HANGUL LETTER KAPYEOUNSSANGPIEUP","	# 112C hangul choseong kapyeounssangpieup"},
/* 317A */ { "HANGUL LETTER SIOS-KIYEOK","	# 112D hangul choseong sios-kiyeok"},
/* 317B */ { "HANGUL LETTER SIOS-NIEUN","	# 112E hangul choseong sios-nieun"},
/* 317C */ { "HANGUL LETTER SIOS-TIKEUT","	# 112F hangul choseong sios-tikeut"},
/* 317D */ { "HANGUL LETTER SIOS-PIEUP","	# 1132 hangul choseong sios-pieup"},
/* 317E */ { "HANGUL LETTER SIOS-CIEUC","	# 1136 hangul choseong sios-cieuc"},
/* 317F */ { "HANGUL LETTER PANSIOS","	* voiced alveolar fricative\n"
	"	# 1140 hangul choseong pansios"},
/* 3180 */ { "HANGUL LETTER SSANGIEUNG","	= ssangyesieung\n"
	"	# 1147 hangul choseong ssangieung"},
/* 3181 */ { "HANGUL LETTER YESIEUNG","	* velar nasal consonant\n"
	"	# 114C hangul choseong yesieung"},
/* 3182 */ { "HANGUL LETTER YESIEUNG-SIOS","	# 11F1 hangul jongseong yesieung-sios"},
/* 3183 */ { "HANGUL LETTER YESIEUNG-PANSIOS","	# 11F2 hangul jongseong yesieung-pansios"},
/* 3184 */ { "HANGUL LETTER KAPYEOUNPHIEUPH","	# 1157 hangul choseong kapyeounphieuph"},
/* 3185 */ { "HANGUL LETTER SSANGHIEUH","	# 1158 hangul choseong ssanghieuh"},
/* 3186 */ { "HANGUL LETTER YEORINHIEUH","	* glottal stop\n"
	"	# 1159 hangul choseong yeorinhieuh"},
/* 3187 */ { "HANGUL LETTER YO-YA","	# 1184 hangul jungseong yo-ya"},
/* 3188 */ { "HANGUL LETTER YO-YAE","	# 1185 hangul jungseong yo-yae"},
/* 3189 */ { "HANGUL LETTER YO-I","	# 1188 hangul jungseong yo-i"},
/* 318A */ { "HANGUL LETTER YU-YEO","	# 1191 hangul jungseong yu-yeo"},
/* 318B */ { "HANGUL LETTER YU-YE","	# 1192 hangul jungseong yu-ye"},
/* 318C */ { "HANGUL LETTER YU-I","	# 1194 hangul jungseong yu-i"},
/* 318D */ { "HANGUL LETTER ARAEA","	* rounded open-mid back vowel\n"
	"	# 119E hangul jungseong araea"},
/* 318E */ { "HANGUL LETTER ARAEAE","	# 11A1 hangul jungseong araea-i"},
/* 318F */ { NULL,NULL},
/* 3190 */ { "IDEOGRAPHIC ANNOTATION LINKING MARK","	= tateten"},
/* 3191 */ { "IDEOGRAPHIC ANNOTATION REVERSE MARK","	= kaeriten re"},
/* 3192 */ { "IDEOGRAPHIC ANNOTATION ONE MARK","	# <super> 4E00"},
/* 3193 */ { "IDEOGRAPHIC ANNOTATION TWO MARK","	# <super> 4E8C"},
/* 3194 */ { "IDEOGRAPHIC ANNOTATION THREE MARK","	# <super> 4E09"},
/* 3195 */ { "IDEOGRAPHIC ANNOTATION FOUR MARK","	# <super> 56DB"},
/* 3196 */ { "IDEOGRAPHIC ANNOTATION TOP MARK","	# <super> 4E0A"},
/* 3197 */ { "IDEOGRAPHIC ANNOTATION MIDDLE MARK","	# <super> 4E2D"},
/* 3198 */ { "IDEOGRAPHIC ANNOTATION BOTTOM MARK","	# <super> 4E0B"},
/* 3199 */ { "IDEOGRAPHIC ANNOTATION FIRST MARK","	# <super> 7532"},
/* 319A */ { "IDEOGRAPHIC ANNOTATION SECOND MARK","	# <super> 4E59"},
/* 319B */ { "IDEOGRAPHIC ANNOTATION THIRD MARK","	# <super> 4E19"},
/* 319C */ { "IDEOGRAPHIC ANNOTATION FOURTH MARK","	# <super> 4E01"},
/* 319D */ { "IDEOGRAPHIC ANNOTATION HEAVEN MARK","	# <super> 5929"},
/* 319E */ { "IDEOGRAPHIC ANNOTATION EARTH MARK","	# <super> 5730"},
/* 319F */ { "IDEOGRAPHIC ANNOTATION MAN MARK","	# <super> 4EBA"},
/* 31A0 */ { "BOPOMOFO LETTER BU",NULL},
/* 31A1 */ { "BOPOMOFO LETTER ZI",NULL},
/* 31A2 */ { "BOPOMOFO LETTER JI",NULL},
/* 31A3 */ { "BOPOMOFO LETTER GU",NULL},
/* 31A4 */ { "BOPOMOFO LETTER EE",NULL},
/* 31A5 */ { "BOPOMOFO LETTER ENN",NULL},
/* 31A6 */ { "BOPOMOFO LETTER OO",NULL},
/* 31A7 */ { "BOPOMOFO LETTER ONN",NULL},
/* 31A8 */ { "BOPOMOFO LETTER IR",NULL},
/* 31A9 */ { "BOPOMOFO LETTER ANN",NULL},
/* 31AA */ { "BOPOMOFO LETTER INN",NULL},
/* 31AB */ { "BOPOMOFO LETTER UNN",NULL},
/* 31AC */ { "BOPOMOFO LETTER IM",NULL},
/* 31AD */ { "BOPOMOFO LETTER NGG",NULL},
/* 31AE */ { "BOPOMOFO LETTER AINN",NULL},
/* 31AF */ { "BOPOMOFO LETTER AUNN",NULL},
/* 31B0 */ { "BOPOMOFO LETTER AM",NULL},
/* 31B1 */ { "BOPOMOFO LETTER OM",NULL},
/* 31B2 */ { "BOPOMOFO LETTER ONG",NULL},
/* 31B3 */ { "BOPOMOFO LETTER INNN",NULL},
/* 31B4 */ { "BOPOMOFO FINAL LETTER P",NULL},
/* 31B5 */ { "BOPOMOFO FINAL LETTER T",NULL},
/* 31B6 */ { "BOPOMOFO FINAL LETTER K","	* use of 31BB is preferred"},
/* 31B7 */ { "BOPOMOFO FINAL LETTER H",NULL},
/* 31B8 */ { "BOPOMOFO LETTER GH",NULL},
/* 31B9 */ { "BOPOMOFO LETTER LH",NULL},
/* 31BA */ { "BOPOMOFO LETTER ZY",NULL},
/* 31BB */ { "BOPOMOFO FINAL LETTER G",NULL},
/* 31BC */ { "BOPOMOFO LETTER GW",NULL},
/* 31BD */ { "BOPOMOFO LETTER KW",NULL},
/* 31BE */ { "BOPOMOFO LETTER OE",NULL},
/* 31BF */ { "BOPOMOFO LETTER AH",NULL},
/* 31C0 */ { "CJK STROKE T","	* 2nd stroke of 51B0"},
/* 31C1 */ { "CJK STROKE WG","	* 2nd stroke of 72D0"},
/* 31C2 */ { "CJK STROKE XG","	* 5th stroke of 6211"},
/* 31C3 */ { "CJK STROKE BXG","	* occurs only in Kaiti typefaces\n"
	"	* equivalent to SWG stroke in Songti typefaces\n"
	"	* 2nd stroke of 5FC3"},
/* 31C4 */ { "CJK STROKE SW","	* 3rd stroke of 4EA1\n"
	"	* 4th stroke of 56DB"},
/* 31C5 */ { "CJK STROKE HZZ","	* 1st stroke of 534D"},
/* 31C6 */ { "CJK STROKE HZG","	* 1st stroke of 7FBD\n"
	"	* 1st stroke of 4E5F"},
/* 31C7 */ { "CJK STROKE HP","	* 1st stroke of 53C8\n"
	"	* 4th stroke of 4ECA"},
/* 31C8 */ { "CJK STROKE HZWG","	* 2nd stroke of 4E5D"},
/* 31C9 */ { "CJK STROKE SZWG","	* 3rd stroke of 5F13\n"
	"	* 2nd stroke of 9A6C"},
/* 31CA */ { "CJK STROKE HZT","	* 2nd stroke of 8BA1\n"
	"	* 2nd stroke of 9CE9"},
/* 31CB */ { "CJK STROKE HZZP","	* 1st stroke of 53CA"},
/* 31CC */ { "CJK STROKE HPWG","	* 1st stroke of 961D\n"
	"	* 6th stroke of 90AE"},
/* 31CD */ { "CJK STROKE HZW","	* 5th stroke of 6295"},
/* 31CE */ { "CJK STROKE HZZZ","	* 1st stroke of 51F8"},
/* 31CF */ { "CJK STROKE N","	* 3rd stroke of 5927"},
/* 31D0 */ { "CJK STROKE H","	* 1st stroke of 5927\n"
	"	* 1st stroke of 4E03"},
/* 31D1 */ { "CJK STROKE S","	* 4th stroke of 4E2D"},
/* 31D2 */ { "CJK STROKE P","	* 1st stroke of 4E4F"},
/* 31D3 */ { "CJK STROKE SP","	* 1st stroke of 6708"},
/* 31D4 */ { "CJK STROKE D","	* 3rd stroke of 4E38"},
/* 31D5 */ { "CJK STROKE HZ","	* 2nd stroke of 56DB"},
/* 31D6 */ { "CJK STROKE HG","	* 1st stroke of 758B\n"
	"	* 1st stroke of 5B50"},
/* 31D7 */ { "CJK STROKE SZ","	* 2nd stroke of 5C71\n"
	"	* 2nd stroke of 4E1C"},
/* 31D8 */ { "CJK STROKE SWZ","	* 6th stroke of 8085"},
/* 31D9 */ { "CJK STROKE ST","	* 3rd stroke of 6C11"},
/* 31DA */ { "CJK STROKE SG","	* 1st stroke of 6C34"},
/* 31DB */ { "CJK STROKE PD","	* 1st stroke of 5DE1\n"
	"	* 1st stroke of 5973"},
/* 31DC */ { "CJK STROKE PZ","	* 3rd stroke of 516C\n"
	"	* 4th stroke of 5F18"},
/* 31DD */ { "CJK STROKE TN","	* 8th stroke of 5EFB"},
/* 31DE */ { "CJK STROKE SZZ","	* 1st stroke of 5350\n"
	"	* 4th stroke of 4E9E"},
/* 31DF */ { "CJK STROKE SWG","	* 7th stroke of 4E71\n"
	"	* 3rd stroke of 5DF1"},
/* 31E0 */ { "CJK STROKE HXWG","	* 1st stroke of 4E59"},
/* 31E1 */ { "CJK STROKE HZZZG","	* 1st stroke of 4E43"},
/* 31E2 */ { "CJK STROKE PG","	* 1st stroke of 4E44"},
/* 31E3 */ { "CJK STROKE Q","	* 6th stroke of 3514"},
/* 31E4 */ { "CJK STROKE HXG","	* 1st stroke of 98DE"},
/* 31E5 */ { "CJK STROKE SZP","	* 8th stroke of 594A"},
/* 31E6 */ { NULL,NULL},
/* 31E7 */ { NULL,NULL},
/* 31E8 */ { NULL,NULL},
/* 31E9 */ { NULL,NULL},
/* 31EA */ { NULL,NULL},
/* 31EB */ { NULL,NULL},
/* 31EC */ { NULL,NULL},
/* 31ED */ { NULL,NULL},
/* 31EE */ { NULL,NULL},
/* 31EF */ { "IDEOGRAPHIC DESCRIPTION CHARACTER SUBTRACTION","	* used to describe a character or a component with a stroke (or other component) removed"},
/* 31F0 */ { "KATAKANA LETTER SMALL KU",NULL},
/* 31F1 */ { "KATAKANA LETTER SMALL SI",NULL},
/* 31F2 */ { "KATAKANA LETTER SMALL SU",NULL},
/* 31F3 */ { "KATAKANA LETTER SMALL TO",NULL},
/* 31F4 */ { "KATAKANA LETTER SMALL NU",NULL},
/* 31F5 */ { "KATAKANA LETTER SMALL HA",NULL},
/* 31F6 */ { "KATAKANA LETTER SMALL HI",NULL},
/* 31F7 */ { "KATAKANA LETTER SMALL HU",NULL},
/* 31F8 */ { "KATAKANA LETTER SMALL HE",NULL},
/* 31F9 */ { "KATAKANA LETTER SMALL HO",NULL},
/* 31FA */ { "KATAKANA LETTER SMALL MU",NULL},
/* 31FB */ { "KATAKANA LETTER SMALL RA",NULL},
/* 31FC */ { "KATAKANA LETTER SMALL RI",NULL},
/* 31FD */ { "KATAKANA LETTER SMALL RU",NULL},
/* 31FE */ { "KATAKANA LETTER SMALL RE",NULL},
/* 31FF */ { "KATAKANA LETTER SMALL RO",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_00_32[] = {
/* 3200 */ { "PARENTHESIZED HANGUL KIYEOK","	# 0028 1100 0029"},
/* 3201 */ { "PARENTHESIZED HANGUL NIEUN","	# 0028 1102 0029"},
/* 3202 */ { "PARENTHESIZED HANGUL TIKEUT","	# 0028 1103 0029"},
/* 3203 */ { "PARENTHESIZED HANGUL RIEUL","	# 0028 1105 0029"},
/* 3204 */ { "PARENTHESIZED HANGUL MIEUM","	# 0028 1106 0029"},
/* 3205 */ { "PARENTHESIZED HANGUL PIEUP","	# 0028 1107 0029"},
/* 3206 */ { "PARENTHESIZED HANGUL SIOS","	# 0028 1109 0029"},
/* 3207 */ { "PARENTHESIZED HANGUL IEUNG","	# 0028 110B 0029"},
/* 3208 */ { "PARENTHESIZED HANGUL CIEUC","	# 0028 110C 0029"},
/* 3209 */ { "PARENTHESIZED HANGUL CHIEUCH","	# 0028 110E 0029"},
/* 320A */ { "PARENTHESIZED HANGUL KHIEUKH","	# 0028 110F 0029"},
/* 320B */ { "PARENTHESIZED HANGUL THIEUTH","	# 0028 1110 0029"},
/* 320C */ { "PARENTHESIZED HANGUL PHIEUPH","	# 0028 1111 0029"},
/* 320D */ { "PARENTHESIZED HANGUL HIEUH","	# 0028 1112 0029"},
/* 320E */ { "PARENTHESIZED HANGUL KIYEOK A","	# 0028 1100 1161 0029"},
/* 320F */ { "PARENTHESIZED HANGUL NIEUN A","	# 0028 1102 1161 0029"},
/* 3210 */ { "PARENTHESIZED HANGUL TIKEUT A","	# 0028 1103 1161 0029"},
/* 3211 */ { "PARENTHESIZED HANGUL RIEUL A","	# 0028 1105 1161 0029"},
/* 3212 */ { "PARENTHESIZED HANGUL MIEUM A","	# 0028 1106 1161 0029"},
/* 3213 */ { "PARENTHESIZED HANGUL PIEUP A","	# 0028 1107 1161 0029"},
/* 3214 */ { "PARENTHESIZED HANGUL SIOS A","	# 0028 1109 1161 0029"},
/* 3215 */ { "PARENTHESIZED HANGUL IEUNG A","	# 0028 110B 1161 0029"},
/* 3216 */ { "PARENTHESIZED HANGUL CIEUC A","	# 0028 110C 1161 0029"},
/* 3217 */ { "PARENTHESIZED HANGUL CHIEUCH A","	# 0028 110E 1161 0029"},
/* 3218 */ { "PARENTHESIZED HANGUL KHIEUKH A","	# 0028 110F 1161 0029"},
/* 3219 */ { "PARENTHESIZED HANGUL THIEUTH A","	# 0028 1110 1161 0029"},
/* 321A */ { "PARENTHESIZED HANGUL PHIEUPH A","	# 0028 1111 1161 0029"},
/* 321B */ { "PARENTHESIZED HANGUL HIEUH A","	# 0028 1112 1161 0029"},
/* 321C */ { "PARENTHESIZED HANGUL CIEUC U","	# 0028 110C 116E 0029"},
/* 321D */ { "PARENTHESIZED KOREAN CHARACTER OJEON","	# 0028 110B 1169 110C 1165 11AB 0029"},
/* 321E */ { "PARENTHESIZED KOREAN CHARACTER O HU","	* preferred spelling for the name is ohu\n"
	"	# 0028 110B 1169 1112 116E 0029"},
/* 321F */ { NULL,NULL},
/* 3220 */ { "PARENTHESIZED IDEOGRAPH ONE","	# 0028 4E00 0029"},
/* 3221 */ { "PARENTHESIZED IDEOGRAPH TWO","	# 0028 4E8C 0029"},
/* 3222 */ { "PARENTHESIZED IDEOGRAPH THREE","	# 0028 4E09 0029"},
/* 3223 */ { "PARENTHESIZED IDEOGRAPH FOUR","	# 0028 56DB 0029"},
/* 3224 */ { "PARENTHESIZED IDEOGRAPH FIVE","	# 0028 4E94 0029"},
/* 3225 */ { "PARENTHESIZED IDEOGRAPH SIX","	# 0028 516D 0029"},
/* 3226 */ { "PARENTHESIZED IDEOGRAPH SEVEN","	# 0028 4E03 0029"},
/* 3227 */ { "PARENTHESIZED IDEOGRAPH EIGHT","	# 0028 516B 0029"},
/* 3228 */ { "PARENTHESIZED IDEOGRAPH NINE","	# 0028 4E5D 0029"},
/* 3229 */ { "PARENTHESIZED IDEOGRAPH TEN","	# 0028 5341 0029"},
/* 322A */ { "PARENTHESIZED IDEOGRAPH MOON","	* Monday\n"
	"	# 0028 6708 0029"},
/* 322B */ { "PARENTHESIZED IDEOGRAPH FIRE","	* Tuesday\n"
	"	# 0028 706B 0029"},
/* 322C */ { "PARENTHESIZED IDEOGRAPH WATER","	* Wednesday\n"
	"	# 0028 6C34 0029"},
/* 322D */ { "PARENTHESIZED IDEOGRAPH WOOD","	* Thursday\n"
	"	# 0028 6728 0029"},
/* 322E */ { "PARENTHESIZED IDEOGRAPH METAL","	* Friday\n"
	"	# 0028 91D1 0029"},
/* 322F */ { "PARENTHESIZED IDEOGRAPH EARTH","	* Saturday\n"
	"	# 0028 571F 0029"},
/* 3230 */ { "PARENTHESIZED IDEOGRAPH SUN","	* Sunday\n"
	"	# 0028 65E5 0029"},
/* 3231 */ { "PARENTHESIZED IDEOGRAPH STOCK","	* incorporated\n"
	"	# 0028 682A 0029"},
/* 3232 */ { "PARENTHESIZED IDEOGRAPH HAVE","	* limited\n"
	"	# 0028 6709 0029"},
/* 3233 */ { "PARENTHESIZED IDEOGRAPH SOCIETY","	* company\n"
	"	# 0028 793E 0029"},
/* 3234 */ { "PARENTHESIZED IDEOGRAPH NAME","	# 0028 540D 0029"},
/* 3235 */ { "PARENTHESIZED IDEOGRAPH SPECIAL","	# 0028 7279 0029"},
/* 3236 */ { "PARENTHESIZED IDEOGRAPH FINANCIAL","	# 0028 8CA1 0029"},
/* 3237 */ { "PARENTHESIZED IDEOGRAPH CONGRATULATION","	# 0028 795D 0029"},
/* 3238 */ { "PARENTHESIZED IDEOGRAPH LABOR","	# 0028 52B4 0029"},
/* 3239 */ { "PARENTHESIZED IDEOGRAPH REPRESENT","	# 0028 4EE3 0029"},
/* 323A */ { "PARENTHESIZED IDEOGRAPH CALL","	# 0028 547C 0029"},
/* 323B */ { "PARENTHESIZED IDEOGRAPH STUDY","	# 0028 5B66 0029"},
/* 323C */ { "PARENTHESIZED IDEOGRAPH SUPERVISE","	# 0028 76E3 0029"},
/* 323D */ { "PARENTHESIZED IDEOGRAPH ENTERPRISE","	# 0028 4F01 0029"},
/* 323E */ { "PARENTHESIZED IDEOGRAPH RESOURCE","	# 0028 8CC7 0029"},
/* 323F */ { "PARENTHESIZED IDEOGRAPH ALLIANCE","	# 0028 5354 0029"},
/* 3240 */ { "PARENTHESIZED IDEOGRAPH FESTIVAL","	# 0028 796D 0029"},
/* 3241 */ { "PARENTHESIZED IDEOGRAPH REST","	# 0028 4F11 0029"},
/* 3242 */ { "PARENTHESIZED IDEOGRAPH SELF","	* from\n"
	"	# 0028 81EA 0029"},
/* 3243 */ { "PARENTHESIZED IDEOGRAPH REACH","	* to\n"
	"	# 0028 81F3 0029"},
/* 3244 */ { "CIRCLED IDEOGRAPH QUESTION","	# <circle> 554F"},
/* 3245 */ { "CIRCLED IDEOGRAPH KINDERGARTEN","	# <circle> 5E7C"},
/* 3246 */ { "CIRCLED IDEOGRAPH SCHOOL","	# <circle> 6587"},
/* 3247 */ { "CIRCLED IDEOGRAPH KOTO","	# <circle> 7B8F"},
/* 3248 */ { "CIRCLED NUMBER TEN ON BLACK SQUARE","	= speed limit 10 km/h"},
/* 3249 */ { "CIRCLED NUMBER TWENTY ON BLACK SQUARE","	= speed limit 20 km/h"},
/* 324A */ { "CIRCLED NUMBER THIRTY ON BLACK SQUARE","	= speed limit 30 km/h"},
/* 324B */ { "CIRCLED NUMBER FORTY ON BLACK SQUARE","	= speed limit 40 km/h"},
/* 324C */ { "CIRCLED NUMBER FIFTY ON BLACK SQUARE","	= speed limit 50 km/h"},
/* 324D */ { "CIRCLED NUMBER SIXTY ON BLACK SQUARE","	= speed limit 60 km/h"},
/* 324E */ { "CIRCLED NUMBER SEVENTY ON BLACK SQUARE","	= speed limit 70 km/h"},
/* 324F */ { "CIRCLED NUMBER EIGHTY ON BLACK SQUARE","	= speed limit 80 km/h"},
/* 3250 */ { "PARTNERSHIP SIGN","	# <square> 0050 0054 0045"},
/* 3251 */ { "CIRCLED NUMBER TWENTY ONE","	# <circle> 0032 0031"},
/* 3252 */ { "CIRCLED NUMBER TWENTY TWO","	# <circle> 0032 0032"},
/* 3253 */ { "CIRCLED NUMBER TWENTY THREE","	# <circle> 0032 0033"},
/* 3254 */ { "CIRCLED NUMBER TWENTY FOUR","	# <circle> 0032 0034"},
/* 3255 */ { "CIRCLED NUMBER TWENTY FIVE","	# <circle> 0032 0035"},
/* 3256 */ { "CIRCLED NUMBER TWENTY SIX","	# <circle> 0032 0036"},
/* 3257 */ { "CIRCLED NUMBER TWENTY SEVEN","	# <circle> 0032 0037"},
/* 3258 */ { "CIRCLED NUMBER TWENTY EIGHT","	# <circle> 0032 0038"},
/* 3259 */ { "CIRCLED NUMBER TWENTY NINE","	# <circle> 0032 0039"},
/* 325A */ { "CIRCLED NUMBER THIRTY","	# <circle> 0033 0030"},
/* 325B */ { "CIRCLED NUMBER THIRTY ONE","	# <circle> 0033 0031"},
/* 325C */ { "CIRCLED NUMBER THIRTY TWO","	# <circle> 0033 0032"},
/* 325D */ { "CIRCLED NUMBER THIRTY THREE","	# <circle> 0033 0033"},
/* 325E */ { "CIRCLED NUMBER THIRTY FOUR","	# <circle> 0033 0034"},
/* 325F */ { "CIRCLED NUMBER THIRTY FIVE","	# <circle> 0033 0035"},
/* 3260 */ { "CIRCLED HANGUL KIYEOK","	# <circle> 1100"},
/* 3261 */ { "CIRCLED HANGUL NIEUN","	# <circle> 1102"},
/* 3262 */ { "CIRCLED HANGUL TIKEUT","	# <circle> 1103"},
/* 3263 */ { "CIRCLED HANGUL RIEUL","	# <circle> 1105"},
/* 3264 */ { "CIRCLED HANGUL MIEUM","	# <circle> 1106"},
/* 3265 */ { "CIRCLED HANGUL PIEUP","	# <circle> 1107"},
/* 3266 */ { "CIRCLED HANGUL SIOS","	# <circle> 1109"},
/* 3267 */ { "CIRCLED HANGUL IEUNG","	# <circle> 110B"},
/* 3268 */ { "CIRCLED HANGUL CIEUC","	# <circle> 110C"},
/* 3269 */ { "CIRCLED HANGUL CHIEUCH","	# <circle> 110E"},
/* 326A */ { "CIRCLED HANGUL KHIEUKH","	# <circle> 110F"},
/* 326B */ { "CIRCLED HANGUL THIEUTH","	# <circle> 1110"},
/* 326C */ { "CIRCLED HANGUL PHIEUPH","	# <circle> 1111"},
/* 326D */ { "CIRCLED HANGUL HIEUH","	# <circle> 1112"},
/* 326E */ { "CIRCLED HANGUL KIYEOK A","	# <circle> 1100 1161"},
/* 326F */ { "CIRCLED HANGUL NIEUN A","	# <circle> 1102 1161"},
/* 3270 */ { "CIRCLED HANGUL TIKEUT A","	# <circle> 1103 1161"},
/* 3271 */ { "CIRCLED HANGUL RIEUL A","	# <circle> 1105 1161"},
/* 3272 */ { "CIRCLED HANGUL MIEUM A","	# <circle> 1106 1161"},
/* 3273 */ { "CIRCLED HANGUL PIEUP A","	# <circle> 1107 1161"},
/* 3274 */ { "CIRCLED HANGUL SIOS A","	# <circle> 1109 1161"},
/* 3275 */ { "CIRCLED HANGUL IEUNG A","	# <circle> 110B 1161"},
/* 3276 */ { "CIRCLED HANGUL CIEUC A","	# <circle> 110C 1161"},
/* 3277 */ { "CIRCLED HANGUL CHIEUCH A","	# <circle> 110E 1161"},
/* 3278 */ { "CIRCLED HANGUL KHIEUKH A","	# <circle> 110F 1161"},
/* 3279 */ { "CIRCLED HANGUL THIEUTH A","	# <circle> 1110 1161"},
/* 327A */ { "CIRCLED HANGUL PHIEUPH A","	# <circle> 1111 1161"},
/* 327B */ { "CIRCLED HANGUL HIEUH A","	# <circle> 1112 1161"},
/* 327C */ { "CIRCLED KOREAN CHARACTER CHAMKO","	# <circle> 110E 1161 11B7 1100 1169"},
/* 327D */ { "CIRCLED KOREAN CHARACTER JUEUI","	# <circle> 110C 116E 110B 1174"},
/* 327E */ { "CIRCLED HANGUL IEUNG U","	* postal code mark\n"
	"	# <circle> 110B 116E"},
/* 327F */ { "KOREAN STANDARD SYMBOL",NULL},
/* 3280 */ { "CIRCLED IDEOGRAPH ONE","	= maru-iti, symbol of unification\n"
	"	# <circle> 4E00"},
/* 3281 */ { "CIRCLED IDEOGRAPH TWO","	# <circle> 4E8C"},
/* 3282 */ { "CIRCLED IDEOGRAPH THREE","	# <circle> 4E09"},
/* 3283 */ { "CIRCLED IDEOGRAPH FOUR","	# <circle> 56DB"},
/* 3284 */ { "CIRCLED IDEOGRAPH FIVE","	# <circle> 4E94"},
/* 3285 */ { "CIRCLED IDEOGRAPH SIX","	# <circle> 516D"},
/* 3286 */ { "CIRCLED IDEOGRAPH SEVEN","	# <circle> 4E03"},
/* 3287 */ { "CIRCLED IDEOGRAPH EIGHT","	# <circle> 516B"},
/* 3288 */ { "CIRCLED IDEOGRAPH NINE","	# <circle> 4E5D"},
/* 3289 */ { "CIRCLED IDEOGRAPH TEN","	# <circle> 5341"},
/* 328A */ { "CIRCLED IDEOGRAPH MOON","	* Monday\n"
	"	# <circle> 6708"},
/* 328B */ { "CIRCLED IDEOGRAPH FIRE","	* Tuesday\n"
	"	# <circle> 706B"},
/* 328C */ { "CIRCLED IDEOGRAPH WATER","	* Wednesday\n"
	"	# <circle> 6C34"},
/* 328D */ { "CIRCLED IDEOGRAPH WOOD","	* Thursday\n"
	"	# <circle> 6728"},
/* 328E */ { "CIRCLED IDEOGRAPH METAL","	* Friday\n"
	"	# <circle> 91D1"},
/* 328F */ { "CIRCLED IDEOGRAPH EARTH","	* Saturday\n"
	"	# <circle> 571F"},
/* 3290 */ { "CIRCLED IDEOGRAPH SUN","	* Sunday\n"
	"	# <circle> 65E5"},
/* 3291 */ { "CIRCLED IDEOGRAPH STOCK","	* incorporated\n"
	"	# <circle> 682A"},
/* 3292 */ { "CIRCLED IDEOGRAPH HAVE","	* limited\n"
	"	# <circle> 6709"},
/* 3293 */ { "CIRCLED IDEOGRAPH SOCIETY","	* company\n"
	"	# <circle> 793E"},
/* 3294 */ { "CIRCLED IDEOGRAPH NAME","	# <circle> 540D"},
/* 3295 */ { "CIRCLED IDEOGRAPH SPECIAL","	# <circle> 7279"},
/* 3296 */ { "CIRCLED IDEOGRAPH FINANCIAL","	# <circle> 8CA1"},
/* 3297 */ { "CIRCLED IDEOGRAPH CONGRATULATION","	# <circle> 795D"},
/* 3298 */ { "CIRCLED IDEOGRAPH LABOR","	# <circle> 52B4"},
/* 3299 */ { "CIRCLED IDEOGRAPH SECRET","	# <circle> 79D8"},
/* 329A */ { "CIRCLED IDEOGRAPH MALE","	# <circle> 7537"},
/* 329B */ { "CIRCLED IDEOGRAPH FEMALE","	# <circle> 5973"},
/* 329C */ { "CIRCLED IDEOGRAPH SUITABLE","	# <circle> 9069"},
/* 329D */ { "CIRCLED IDEOGRAPH EXCELLENT","	# <circle> 512A"},
/* 329E */ { "CIRCLED IDEOGRAPH PRINT","	* name seal\n"
	"	# <circle> 5370"},
/* 329F */ { "CIRCLED IDEOGRAPH ATTENTION","	# <circle> 6CE8"},
/* 32A0 */ { "CIRCLED IDEOGRAPH ITEM","	# <circle> 9805"},
/* 32A1 */ { "CIRCLED IDEOGRAPH REST","	* holiday\n"
	"	# <circle> 4F11"},
/* 32A2 */ { "CIRCLED IDEOGRAPH COPY","	# <circle> 5199"},
/* 32A3 */ { "CIRCLED IDEOGRAPH CORRECT","	# <circle> 6B63"},
/* 32A4 */ { "CIRCLED IDEOGRAPH HIGH","	# <circle> 4E0A"},
/* 32A5 */ { "CIRCLED IDEOGRAPH CENTRE","	# <circle> 4E2D"},
/* 32A6 */ { "CIRCLED IDEOGRAPH LOW","	# <circle> 4E0B"},
/* 32A7 */ { "CIRCLED IDEOGRAPH LEFT","	# <circle> 5DE6"},
/* 32A8 */ { "CIRCLED IDEOGRAPH RIGHT","	# <circle> 53F3"},
/* 32A9 */ { "CIRCLED IDEOGRAPH MEDICINE","	# <circle> 533B"},
/* 32AA */ { "CIRCLED IDEOGRAPH RELIGION","	# <circle> 5B97"},
/* 32AB */ { "CIRCLED IDEOGRAPH STUDY","	# <circle> 5B66"},
/* 32AC */ { "CIRCLED IDEOGRAPH SUPERVISE","	# <circle> 76E3"},
/* 32AD */ { "CIRCLED IDEOGRAPH ENTERPRISE","	# <circle> 4F01"},
/* 32AE */ { "CIRCLED IDEOGRAPH RESOURCE","	# <circle> 8CC7"},
/* 32AF */ { "CIRCLED IDEOGRAPH ALLIANCE","	# <circle> 5354"},
/* 32B0 */ { "CIRCLED IDEOGRAPH NIGHT","	# <circle> 591C"},
/* 32B1 */ { "CIRCLED NUMBER THIRTY SIX","	# <circle> 0033 0036"},
/* 32B2 */ { "CIRCLED NUMBER THIRTY SEVEN","	# <circle> 0033 0037"},
/* 32B3 */ { "CIRCLED NUMBER THIRTY EIGHT","	# <circle> 0033 0038"},
/* 32B4 */ { "CIRCLED NUMBER THIRTY NINE","	# <circle> 0033 0039"},
/* 32B5 */ { "CIRCLED NUMBER FORTY","	# <circle> 0034 0030"},
/* 32B6 */ { "CIRCLED NUMBER FORTY ONE","	# <circle> 0034 0031"},
/* 32B7 */ { "CIRCLED NUMBER FORTY TWO","	# <circle> 0034 0032"},
/* 32B8 */ { "CIRCLED NUMBER FORTY THREE","	# <circle> 0034 0033"},
/* 32B9 */ { "CIRCLED NUMBER FORTY FOUR","	# <circle> 0034 0034"},
/* 32BA */ { "CIRCLED NUMBER FORTY FIVE","	# <circle> 0034 0035"},
/* 32BB */ { "CIRCLED NUMBER FORTY SIX","	# <circle> 0034 0036"},
/* 32BC */ { "CIRCLED NUMBER FORTY SEVEN","	# <circle> 0034 0037"},
/* 32BD */ { "CIRCLED NUMBER FORTY EIGHT","	# <circle> 0034 0038"},
/* 32BE */ { "CIRCLED NUMBER FORTY NINE","	# <circle> 0034 0039"},
/* 32BF */ { "CIRCLED NUMBER FIFTY","	# <circle> 0035 0030"},
/* 32C0 */ { "IDEOGRAPHIC TELEGRAPH SYMBOL FOR JANUARY","	# 0031 6708"},
/* 32C1 */ { "IDEOGRAPHIC TELEGRAPH SYMBOL FOR FEBRUARY","	# 0032 6708"},
/* 32C2 */ { "IDEOGRAPHIC TELEGRAPH SYMBOL FOR MARCH","	# 0033 6708"},
/* 32C3 */ { "IDEOGRAPHIC TELEGRAPH SYMBOL FOR APRIL","	# 0034 6708"},
/* 32C4 */ { "IDEOGRAPHIC TELEGRAPH SYMBOL FOR MAY","	# 0035 6708"},
/* 32C5 */ { "IDEOGRAPHIC TELEGRAPH SYMBOL FOR JUNE","	# 0036 6708"},
/* 32C6 */ { "IDEOGRAPHIC TELEGRAPH SYMBOL FOR JULY","	# 0037 6708"},
/* 32C7 */ { "IDEOGRAPHIC TELEGRAPH SYMBOL FOR AUGUST","	# 0038 6708"},
/* 32C8 */ { "IDEOGRAPHIC TELEGRAPH SYMBOL FOR SEPTEMBER","	# 0039 6708"},
/* 32C9 */ { "IDEOGRAPHIC TELEGRAPH SYMBOL FOR OCTOBER","	# 0031 0030 6708"},
/* 32CA */ { "IDEOGRAPHIC TELEGRAPH SYMBOL FOR NOVEMBER","	# 0031 0031 6708"},
/* 32CB */ { "IDEOGRAPHIC TELEGRAPH SYMBOL FOR DECEMBER","	# 0031 0032 6708"},
/* 32CC */ { "SQUARE HG","	# <square> 0048 0067"},
/* 32CD */ { "SQUARE ERG","	# <square> 0065 0072 0067"},
/* 32CE */ { "SQUARE EV","	# <square> 0065 0056"},
/* 32CF */ { "LIMITED LIABILITY SIGN","	# <square> 004C 0054 0044"},
/* 32D0 */ { "CIRCLED KATAKANA A","	# <circle> 30A2"},
/* 32D1 */ { "CIRCLED KATAKANA I","	# <circle> 30A4"},
/* 32D2 */ { "CIRCLED KATAKANA U","	# <circle> 30A6"},
/* 32D3 */ { "CIRCLED KATAKANA E","	# <circle> 30A8"},
/* 32D4 */ { "CIRCLED KATAKANA O","	# <circle> 30AA"},
/* 32D5 */ { "CIRCLED KATAKANA KA","	# <circle> 30AB"},
/* 32D6 */ { "CIRCLED KATAKANA KI","	# <circle> 30AD"},
/* 32D7 */ { "CIRCLED KATAKANA KU","	# <circle> 30AF"},
/* 32D8 */ { "CIRCLED KATAKANA KE","	# <circle> 30B1"},
/* 32D9 */ { "CIRCLED KATAKANA KO","	# <circle> 30B3"},
/* 32DA */ { "CIRCLED KATAKANA SA","	# <circle> 30B5"},
/* 32DB */ { "CIRCLED KATAKANA SI","	# <circle> 30B7"},
/* 32DC */ { "CIRCLED KATAKANA SU","	# <circle> 30B9"},
/* 32DD */ { "CIRCLED KATAKANA SE","	# <circle> 30BB"},
/* 32DE */ { "CIRCLED KATAKANA SO","	# <circle> 30BD"},
/* 32DF */ { "CIRCLED KATAKANA TA","	# <circle> 30BF"},
/* 32E0 */ { "CIRCLED KATAKANA TI","	# <circle> 30C1"},
/* 32E1 */ { "CIRCLED KATAKANA TU","	# <circle> 30C4"},
/* 32E2 */ { "CIRCLED KATAKANA TE","	# <circle> 30C6"},
/* 32E3 */ { "CIRCLED KATAKANA TO","	# <circle> 30C8"},
/* 32E4 */ { "CIRCLED KATAKANA NA","	# <circle> 30CA"},
/* 32E5 */ { "CIRCLED KATAKANA NI","	# <circle> 30CB"},
/* 32E6 */ { "CIRCLED KATAKANA NU","	# <circle> 30CC"},
/* 32E7 */ { "CIRCLED KATAKANA NE","	# <circle> 30CD"},
/* 32E8 */ { "CIRCLED KATAKANA NO","	# <circle> 30CE"},
/* 32E9 */ { "CIRCLED KATAKANA HA","	# <circle> 30CF"},
/* 32EA */ { "CIRCLED KATAKANA HI","	# <circle> 30D2"},
/* 32EB */ { "CIRCLED KATAKANA HU","	# <circle> 30D5"},
/* 32EC */ { "CIRCLED KATAKANA HE","	# <circle> 30D8"},
/* 32ED */ { "CIRCLED KATAKANA HO","	# <circle> 30DB"},
/* 32EE */ { "CIRCLED KATAKANA MA","	# <circle> 30DE"},
/* 32EF */ { "CIRCLED KATAKANA MI","	# <circle> 30DF"},
/* 32F0 */ { "CIRCLED KATAKANA MU","	# <circle> 30E0"},
/* 32F1 */ { "CIRCLED KATAKANA ME","	# <circle> 30E1"},
/* 32F2 */ { "CIRCLED KATAKANA MO","	# <circle> 30E2"},
/* 32F3 */ { "CIRCLED KATAKANA YA","	# <circle> 30E4"},
/* 32F4 */ { "CIRCLED KATAKANA YU","	# <circle> 30E6"},
/* 32F5 */ { "CIRCLED KATAKANA YO","	# <circle> 30E8"},
/* 32F6 */ { "CIRCLED KATAKANA RA","	# <circle> 30E9"},
/* 32F7 */ { "CIRCLED KATAKANA RI","	# <circle> 30EA"},
/* 32F8 */ { "CIRCLED KATAKANA RU","	# <circle> 30EB"},
/* 32F9 */ { "CIRCLED KATAKANA RE","	# <circle> 30EC"},
/* 32FA */ { "CIRCLED KATAKANA RO","	# <circle> 30ED"},
/* 32FB */ { "CIRCLED KATAKANA WA","	# <circle> 30EF"},
/* 32FC */ { "CIRCLED KATAKANA WI","	# <circle> 30F0"},
/* 32FD */ { "CIRCLED KATAKANA WE","	# <circle> 30F1"},
/* 32FE */ { "CIRCLED KATAKANA WO","	# <circle> 30F2"},
/* 32FF */ { "SQUARE ERA NAME REIWA","	# <square> 4EE4 548C"}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_00_33[] = {
/* 3300 */ { "SQUARE APAATO","	* apartment\n"
	"	# <square> 30A2 30D1 30FC 30C8"},
/* 3301 */ { "SQUARE ARUHUA","	* alpha\n"
	"	# <square> 30A2 30EB 30D5 30A1"},
/* 3302 */ { "SQUARE ANPEA","	* ampere\n"
	"	# <square> 30A2 30F3 30DA 30A2"},
/* 3303 */ { "SQUARE AARU","	* are (unit of area)\n"
	"	# <square> 30A2 30FC 30EB"},
/* 3304 */ { "SQUARE ININGU","	* inning\n"
	"	# <square> 30A4 30CB 30F3 30B0"},
/* 3305 */ { "SQUARE INTI","	* inch\n"
	"	# <square> 30A4 30F3 30C1"},
/* 3306 */ { "SQUARE UON","	* won (Korean currency)\n"
	"	# <square> 30A6 30A9 30F3"},
/* 3307 */ { "SQUARE ESUKUUDO","	* escudo (Portuguese currency)\n"
	"	# <square> 30A8 30B9 30AF 30FC 30C9"},
/* 3308 */ { "SQUARE EEKAA","	* acre\n"
	"	# <square> 30A8 30FC 30AB 30FC"},
/* 3309 */ { "SQUARE ONSU","	* ounce\n"
	"	# <square> 30AA 30F3 30B9"},
/* 330A */ { "SQUARE OOMU","	* ohm\n"
	"	# <square> 30AA 30FC 30E0"},
/* 330B */ { "SQUARE KAIRI","	* kai-ri: nautical mile\n"
	"	# <square> 30AB 30A4 30EA"},
/* 330C */ { "SQUARE KARATTO","	* carat\n"
	"	# <square> 30AB 30E9 30C3 30C8"},
/* 330D */ { "SQUARE KARORII","	* calorie\n"
	"	# <square> 30AB 30ED 30EA 30FC"},
/* 330E */ { "SQUARE GARON","	* gallon\n"
	"	# <square> 30AC 30ED 30F3"},
/* 330F */ { "SQUARE GANMA","	* gamma\n"
	"	# <square> 30AC 30F3 30DE"},
/* 3310 */ { "SQUARE GIGA","	* giga-\n"
	"	# <square> 30AE 30AC"},
/* 3311 */ { "SQUARE GINII","	* guinea\n"
	"	# <square> 30AE 30CB 30FC"},
/* 3312 */ { "SQUARE KYURII","	* curie\n"
	"	# <square> 30AD 30E5 30EA 30FC"},
/* 3313 */ { "SQUARE GIRUDAA","	* guilder\n"
	"	# <square> 30AE 30EB 30C0 30FC"},
/* 3314 */ { "SQUARE KIRO","	* kilo-\n"
	"	# <square> 30AD 30ED"},
/* 3315 */ { "SQUARE KIROGURAMU","	* kilogram\n"
	"	# <square> 30AD 30ED 30B0 30E9 30E0"},
/* 3316 */ { "SQUARE KIROMEETORU","	* kilometer\n"
	"	# <square> 30AD 30ED 30E1 30FC 30C8 30EB"},
/* 3317 */ { "SQUARE KIROWATTO","	* kilowatt\n"
	"	# <square> 30AD 30ED 30EF 30C3 30C8"},
/* 3318 */ { "SQUARE GURAMU","	* gram\n"
	"	# <square> 30B0 30E9 30E0"},
/* 3319 */ { "SQUARE GURAMUTON","	* gram ton\n"
	"	# <square> 30B0 30E9 30E0 30C8 30F3"},
/* 331A */ { "SQUARE KURUZEIRO","	* cruzeiro (Brazilian currency)\n"
	"	# <square> 30AF 30EB 30BC 30A4 30ED"},
/* 331B */ { "SQUARE KUROONE","	* krone\n"
	"	# <square> 30AF 30ED 30FC 30CD"},
/* 331C */ { "SQUARE KEESU","	* case\n"
	"	# <square> 30B1 30FC 30B9"},
/* 331D */ { "SQUARE KORUNA","	* koruna (Czech currency)\n"
	"	# <square> 30B3 30EB 30CA"},
/* 331E */ { "SQUARE KOOPO","	* co-op\n"
	"	# <square> 30B3 30FC 30DD"},
/* 331F */ { "SQUARE SAIKURU","	* cycle\n"
	"	# <square> 30B5 30A4 30AF 30EB"},
/* 3320 */ { "SQUARE SANTIIMU","	* centime\n"
	"	# <square> 30B5 30F3 30C1 30FC 30E0"},
/* 3321 */ { "SQUARE SIRINGU","	* shilling\n"
	"	# <square> 30B7 30EA 30F3 30B0"},
/* 3322 */ { "SQUARE SENTI","	* centi-\n"
	"	# <square> 30BB 30F3 30C1"},
/* 3323 */ { "SQUARE SENTO","	* cent\n"
	"	# <square> 30BB 30F3 30C8"},
/* 3324 */ { "SQUARE DAASU","	* dozen\n"
	"	# <square> 30C0 30FC 30B9"},
/* 3325 */ { "SQUARE DESI","	* deci-\n"
	"	# <square> 30C7 30B7"},
/* 3326 */ { "SQUARE DORU","	* dollar\n"
	"	# <square> 30C9 30EB"},
/* 3327 */ { "SQUARE TON","	* ton\n"
	"	# <square> 30C8 30F3"},
/* 3328 */ { "SQUARE NANO","	* nano-\n"
	"	# <square> 30CA 30CE"},
/* 3329 */ { "SQUARE NOTTO","	* knot, nautical mile\n"
	"	# <square> 30CE 30C3 30C8"},
/* 332A */ { "SQUARE HAITU","	* heights\n"
	"	# <square> 30CF 30A4 30C4"},
/* 332B */ { "SQUARE PAASENTO","	* percent\n"
	"	# <square> 30D1 30FC 30BB 30F3 30C8"},
/* 332C */ { "SQUARE PAATU","	* a mistaken, unused representation originally intended for the Thai baht currency sign\n"
	"	x (thai currency symbol baht - 0E3F)\n"
	"	# <square> 30D1 30FC 30C4"},
/* 332D */ { "SQUARE BAARERU","	* barrel\n"
	"	# <square> 30D0 30FC 30EC 30EB"},
/* 332E */ { "SQUARE PIASUTORU","	* piaster\n"
	"	# <square> 30D4 30A2 30B9 30C8 30EB"},
/* 332F */ { "SQUARE PIKURU","	* picul (unit of weight)\n"
	"	# <square> 30D4 30AF 30EB"},
/* 3330 */ { "SQUARE PIKO","	* pico-\n"
	"	# <square> 30D4 30B3"},
/* 3331 */ { "SQUARE BIRU","	* building\n"
	"	# <square> 30D3 30EB"},
/* 3332 */ { "SQUARE HUARADDO","	* farad\n"
	"	# <square> 30D5 30A1 30E9 30C3 30C9"},
/* 3333 */ { "SQUARE HUIITO","	* feet\n"
	"	# <square> 30D5 30A3 30FC 30C8"},
/* 3334 */ { "SQUARE BUSSYERU","	* bushel\n"
	"	# <square> 30D6 30C3 30B7 30A7 30EB"},
/* 3335 */ { "SQUARE HURAN","	* franc\n"
	"	# <square> 30D5 30E9 30F3"},
/* 3336 */ { "SQUARE HEKUTAARU","	* hectare\n"
	"	# <square> 30D8 30AF 30BF 30FC 30EB"},
/* 3337 */ { "SQUARE PESO","	* peso\n"
	"	# <square> 30DA 30BD"},
/* 3338 */ { "SQUARE PENIHI","	* pfennig\n"
	"	# <square> 30DA 30CB 30D2"},
/* 3339 */ { "SQUARE HERUTU","	* hertz\n"
	"	# <square> 30D8 30EB 30C4"},
/* 333A */ { "SQUARE PENSU","	* pence\n"
	"	# <square> 30DA 30F3 30B9"},
/* 333B */ { "SQUARE PEEZI","	* page\n"
	"	# <square> 30DA 30FC 30B8"},
/* 333C */ { "SQUARE BEETA","	* beta\n"
	"	# <square> 30D9 30FC 30BF"},
/* 333D */ { "SQUARE POINTO","	* point\n"
	"	# <square> 30DD 30A4 30F3 30C8"},
/* 333E */ { "SQUARE BORUTO","	* volt, bolt\n"
	"	# <square> 30DC 30EB 30C8"},
/* 333F */ { "SQUARE HON","	* hon: volume\n"
	"	# <square> 30DB 30F3"},
/* 3340 */ { "SQUARE PONDO","	* pound\n"
	"	# <square> 30DD 30F3 30C9"},
/* 3341 */ { "SQUARE HOORU","	* hall\n"
	"	# <square> 30DB 30FC 30EB"},
/* 3342 */ { "SQUARE HOON","	* horn\n"
	"	# <square> 30DB 30FC 30F3"},
/* 3343 */ { "SQUARE MAIKURO","	* micro-\n"
	"	# <square> 30DE 30A4 30AF 30ED"},
/* 3344 */ { "SQUARE MAIRU","	* mile\n"
	"	# <square> 30DE 30A4 30EB"},
/* 3345 */ { "SQUARE MAHHA","	* mach\n"
	"	# <square> 30DE 30C3 30CF"},
/* 3346 */ { "SQUARE MARUKU","	* mark\n"
	"	# <square> 30DE 30EB 30AF"},
/* 3347 */ { "SQUARE MANSYON","	* mansion (i.e. better quality apartment)\n"
	"	# <square> 30DE 30F3 30B7 30E7 30F3"},
/* 3348 */ { "SQUARE MIKURON","	* micron\n"
	"	# <square> 30DF 30AF 30ED 30F3"},
/* 3349 */ { "SQUARE MIRI","	* milli-\n"
	"	# <square> 30DF 30EA"},
/* 334A */ { "SQUARE MIRIBAARU","	* millibar\n"
	"	# <square> 30DF 30EA 30D0 30FC 30EB"},
/* 334B */ { "SQUARE MEGA","	* mega-\n"
	"	# <square> 30E1 30AC"},
/* 334C */ { "SQUARE MEGATON","	* megaton\n"
	"	# <square> 30E1 30AC 30C8 30F3"},
/* 334D */ { "SQUARE MEETORU","	* meter\n"
	"	# <square> 30E1 30FC 30C8 30EB"},
/* 334E */ { "SQUARE YAADO","	* yard\n"
	"	# <square> 30E4 30FC 30C9"},
/* 334F */ { "SQUARE YAARU","	* yard\n"
	"	# <square> 30E4 30FC 30EB"},
/* 3350 */ { "SQUARE YUAN","	* yuan (Chinese currency)\n"
	"	# <square> 30E6 30A2 30F3"},
/* 3351 */ { "SQUARE RITTORU","	* liter\n"
	"	# <square> 30EA 30C3 30C8 30EB"},
/* 3352 */ { "SQUARE RIRA","	* lira\n"
	"	# <square> 30EA 30E9"},
/* 3353 */ { "SQUARE RUPII","	* rupee\n"
	"	# <square> 30EB 30D4 30FC"},
/* 3354 */ { "SQUARE RUUBURU","	* ruble\n"
	"	# <square> 30EB 30FC 30D6 30EB"},
/* 3355 */ { "SQUARE REMU","	* rem (unit of radiation)\n"
	"	# <square> 30EC 30E0"},
/* 3356 */ { "SQUARE RENTOGEN","	* roentgen\n"
	"	# <square> 30EC 30F3 30C8 30B2 30F3"},
/* 3357 */ { "SQUARE WATTO","	* watt\n"
	"	# <square> 30EF 30C3 30C8"},
/* 3358 */ { "IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR ZERO","	# 0030 70B9"},
/* 3359 */ { "IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR ONE","	# 0031 70B9"},
/* 335A */ { "IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR TWO","	# 0032 70B9"},
/* 335B */ { "IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR THREE","	# 0033 70B9"},
/* 335C */ { "IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR FOUR","	# 0034 70B9"},
/* 335D */ { "IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR FIVE","	# 0035 70B9"},
/* 335E */ { "IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR SIX","	# 0036 70B9"},
/* 335F */ { "IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR SEVEN","	# 0037 70B9"},
/* 3360 */ { "IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR EIGHT","	# 0038 70B9"},
/* 3361 */ { "IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR NINE","	# 0039 70B9"},
/* 3362 */ { "IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR TEN","	# 0031 0030 70B9"},
/* 3363 */ { "IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR ELEVEN","	# 0031 0031 70B9"},
/* 3364 */ { "IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR TWELVE","	# 0031 0032 70B9"},
/* 3365 */ { "IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR THIRTEEN","	# 0031 0033 70B9"},
/* 3366 */ { "IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR FOURTEEN","	# 0031 0034 70B9"},
/* 3367 */ { "IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR FIFTEEN","	# 0031 0035 70B9"},
/* 3368 */ { "IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR SIXTEEN","	# 0031 0036 70B9"},
/* 3369 */ { "IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR SEVENTEEN","	# 0031 0037 70B9"},
/* 336A */ { "IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR EIGHTEEN","	# 0031 0038 70B9"},
/* 336B */ { "IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR NINETEEN","	# 0031 0039 70B9"},
/* 336C */ { "IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR TWENTY","	# 0032 0030 70B9"},
/* 336D */ { "IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR TWENTY-ONE","	# 0032 0031 70B9"},
/* 336E */ { "IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR TWENTY-TWO","	# 0032 0032 70B9"},
/* 336F */ { "IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR TWENTY-THREE","	# 0032 0033 70B9"},
/* 3370 */ { "IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR TWENTY-FOUR","	# 0032 0034 70B9"},
/* 3371 */ { "SQUARE HPA","	# <square> 0068 0050 0061"},
/* 3372 */ { "SQUARE DA","	# <square> 0064 0061"},
/* 3373 */ { "SQUARE AU","	# <square> 0041 0055"},
/* 3374 */ { "SQUARE BAR","	# <square> 0062 0061 0072"},
/* 3375 */ { "SQUARE OV","	# <square> 006F 0056"},
/* 3376 */ { "SQUARE PC","	# <square> 0070 0063"},
/* 3377 */ { "SQUARE DM","	# <square> 0064 006D"},
/* 3378 */ { "SQUARE DM SQUARED","	# <square> 0064 006D 00B2"},
/* 3379 */ { "SQUARE DM CUBED","	# <square> 0064 006D 00B3"},
/* 337A */ { "SQUARE IU","	# <square> 0049 0055"},
/* 337B */ { "SQUARE ERA NAME HEISEI","	# <square> 5E73 6210"},
/* 337C */ { "SQUARE ERA NAME SYOUWA","	# <square> 662D 548C"},
/* 337D */ { "SQUARE ERA NAME TAISYOU","	# <square> 5927 6B63"},
/* 337E */ { "SQUARE ERA NAME MEIZI","	# <square> 660E 6CBB"},
/* 337F */ { "SQUARE CORPORATION","	= kabusiki-gaisya\n"
	"	* incorporated\n"
	"	# <square> 682A 5F0F 4F1A 793E"},
/* 3380 */ { "SQUARE PA AMPS","	# <square> 0070 0041"},
/* 3381 */ { "SQUARE NA","	# <square> 006E 0041"},
/* 3382 */ { "SQUARE MU A","	# <square> 03BC 0041"},
/* 3383 */ { "SQUARE MA","	# <square> 006D 0041"},
/* 3384 */ { "SQUARE KA","	# <square> 006B 0041"},
/* 3385 */ { "SQUARE KB","	# <square> 004B 0042"},
/* 3386 */ { "SQUARE MB","	# <square> 004D 0042"},
/* 3387 */ { "SQUARE GB","	# <square> 0047 0042"},
/* 3388 */ { "SQUARE CAL","	# <square> 0063 0061 006C"},
/* 3389 */ { "SQUARE KCAL","	# <square> 006B 0063 0061 006C"},
/* 338A */ { "SQUARE PF","	# <square> 0070 0046"},
/* 338B */ { "SQUARE NF","	# <square> 006E 0046"},
/* 338C */ { "SQUARE MU F","	# <square> 03BC 0046"},
/* 338D */ { "SQUARE MU G","	# <square> 03BC 0067"},
/* 338E */ { "SQUARE MG","	# <square> 006D 0067"},
/* 338F */ { "SQUARE KG","	# <square> 006B 0067"},
/* 3390 */ { "SQUARE HZ","	# <square> 0048 007A"},
/* 3391 */ { "SQUARE KHZ","	# <square> 006B 0048 007A"},
/* 3392 */ { "SQUARE MHZ","	# <square> 004D 0048 007A"},
/* 3393 */ { "SQUARE GHZ","	# <square> 0047 0048 007A"},
/* 3394 */ { "SQUARE THZ","	# <square> 0054 0048 007A"},
/* 3395 */ { "SQUARE MU L","	# <square> 03BC 2113"},
/* 3396 */ { "SQUARE ML","	# <square> 006D 2113"},
/* 3397 */ { "SQUARE DL","	# <square> 0064 2113"},
/* 3398 */ { "SQUARE KL","	# <square> 006B 2113"},
/* 3399 */ { "SQUARE FM","	# <square> 0066 006D"},
/* 339A */ { "SQUARE NM","	# <square> 006E 006D"},
/* 339B */ { "SQUARE MU M","	# <square> 03BC 006D"},
/* 339C */ { "SQUARE MM","	# <square> 006D 006D"},
/* 339D */ { "SQUARE CM","	# <square> 0063 006D"},
/* 339E */ { "SQUARE KM","	# <square> 006B 006D"},
/* 339F */ { "SQUARE MM SQUARED","	# <square> 006D 006D 00B2"},
/* 33A0 */ { "SQUARE CM SQUARED","	# <square> 0063 006D 00B2"},
/* 33A1 */ { "SQUARE M SQUARED","	# <square> 006D 00B2"},
/* 33A2 */ { "SQUARE KM SQUARED","	# <square> 006B 006D 00B2"},
/* 33A3 */ { "SQUARE MM CUBED","	# <square> 006D 006D 00B3"},
/* 33A4 */ { "SQUARE CM CUBED","	# <square> 0063 006D 00B3"},
/* 33A5 */ { "SQUARE M CUBED","	# <square> 006D 00B3"},
/* 33A6 */ { "SQUARE KM CUBED","	# <square> 006B 006D 00B3"},
/* 33A7 */ { "SQUARE M OVER S","	# <square> 006D 2215 0073"},
/* 33A8 */ { "SQUARE M OVER S SQUARED","	# <square> 006D 2215 0073 00B2"},
/* 33A9 */ { "SQUARE PA","	# <square> 0050 0061"},
/* 33AA */ { "SQUARE KPA","	# <square> 006B 0050 0061"},
/* 33AB */ { "SQUARE MPA","	# <square> 004D 0050 0061"},
/* 33AC */ { "SQUARE GPA","	# <square> 0047 0050 0061"},
/* 33AD */ { "SQUARE RAD","	# <square> 0072 0061 0064"},
/* 33AE */ { "SQUARE RAD OVER S","	# <square> 0072 0061 0064 2215 0073"},
/* 33AF */ { "SQUARE RAD OVER S SQUARED","	# <square> 0072 0061 0064 2215 0073 00B2"},
/* 33B0 */ { "SQUARE PS","	# <square> 0070 0073"},
/* 33B1 */ { "SQUARE NS","	# <square> 006E 0073"},
/* 33B2 */ { "SQUARE MU S","	# <square> 03BC 0073"},
/* 33B3 */ { "SQUARE MS","	# <square> 006D 0073"},
/* 33B4 */ { "SQUARE PV","	# <square> 0070 0056"},
/* 33B5 */ { "SQUARE NV","	# <square> 006E 0056"},
/* 33B6 */ { "SQUARE MU V","	# <square> 03BC 0056"},
/* 33B7 */ { "SQUARE MV","	# <square> 006D 0056"},
/* 33B8 */ { "SQUARE KV","	# <square> 006B 0056"},
/* 33B9 */ { "SQUARE MV MEGA","	# <square> 004D 0056"},
/* 33BA */ { "SQUARE PW","	# <square> 0070 0057"},
/* 33BB */ { "SQUARE NW","	# <square> 006E 0057"},
/* 33BC */ { "SQUARE MU W","	# <square> 03BC 0057"},
/* 33BD */ { "SQUARE MW","	# <square> 006D 0057"},
/* 33BE */ { "SQUARE KW","	# <square> 006B 0057"},
/* 33BF */ { "SQUARE MW MEGA","	# <square> 004D 0057"},
/* 33C0 */ { "SQUARE K OHM","	# <square> 006B 03A9"},
/* 33C1 */ { "SQUARE M OHM","	# <square> 004D 03A9"},
/* 33C2 */ { "SQUARE AM","	# <square> 0061 002E 006D 002E"},
/* 33C3 */ { "SQUARE BQ","	# <square> 0042 0071"},
/* 33C4 */ { "SQUARE CC","	# <square> 0063 0063"},
/* 33C5 */ { "SQUARE CD","	x (circled cd - 1F12D)\n"
	"	# <square> 0063 0064"},
/* 33C6 */ { "SQUARE C OVER KG","	# <square> 0043 2215 006B 0067"},
/* 33C7 */ { "SQUARE CO","	# <square> 0043 006F 002E"},
/* 33C8 */ { "SQUARE DB","	# <square> 0064 0042"},
/* 33C9 */ { "SQUARE GY","	# <square> 0047 0079"},
/* 33CA */ { "SQUARE HA","	# <square> 0068 0061"},
/* 33CB */ { "SQUARE HP","	# <square> 0048 0050"},
/* 33CC */ { "SQUARE IN","	# <square> 0069 006E"},
/* 33CD */ { "SQUARE KK","	# <square> 004B 004B"},
/* 33CE */ { "SQUARE KM CAPITAL","	# <square> 004B 004D"},
/* 33CF */ { "SQUARE KT","	# <square> 006B 0074"},
/* 33D0 */ { "SQUARE LM","	# <square> 006C 006D"},
/* 33D1 */ { "SQUARE LN","	# <square> 006C 006E"},
/* 33D2 */ { "SQUARE LOG","	# <square> 006C 006F 0067"},
/* 33D3 */ { "SQUARE LX","	# <square> 006C 0078"},
/* 33D4 */ { "SQUARE MB SMALL","	# <square> 006D 0062"},
/* 33D5 */ { "SQUARE MIL","	# <square> 006D 0069 006C"},
/* 33D6 */ { "SQUARE MOL","	# <square> 006D 006F 006C"},
/* 33D7 */ { "SQUARE PH","	* casing inconsistency in the compatibility decomposition is a known anomaly dating from glyph presentations in very early versions of the standard\n"
	"	# <square> 0050 0048"},
/* 33D8 */ { "SQUARE PM","	# <square> 0070 002E 006D 002E"},
/* 33D9 */ { "SQUARE PPM","	# <square> 0050 0050 004D"},
/* 33DA */ { "SQUARE PR","	# <square> 0050 0052"},
/* 33DB */ { "SQUARE SR","	# <square> 0073 0072"},
/* 33DC */ { "SQUARE SV","	# <square> 0053 0076"},
/* 33DD */ { "SQUARE WB","	# <square> 0057 0062"},
/* 33DE */ { "SQUARE V OVER M","	# <square> 0056 2215 006D"},
/* 33DF */ { "SQUARE A OVER M","	# <square> 0041 2215 006D"},
/* 33E0 */ { "IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY ONE","	# 0031 65E5"},
/* 33E1 */ { "IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY TWO","	# 0032 65E5"},
/* 33E2 */ { "IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY THREE","	# 0033 65E5"},
/* 33E3 */ { "IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY FOUR","	# 0034 65E5"},
/* 33E4 */ { "IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY FIVE","	# 0035 65E5"},
/* 33E5 */ { "IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY SIX","	# 0036 65E5"},
/* 33E6 */ { "IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY SEVEN","	# 0037 65E5"},
/* 33E7 */ { "IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY EIGHT","	# 0038 65E5"},
/* 33E8 */ { "IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY NINE","	# 0039 65E5"},
/* 33E9 */ { "IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY TEN","	# 0031 0030 65E5"},
/* 33EA */ { "IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY ELEVEN","	# 0031 0031 65E5"},
/* 33EB */ { "IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY TWELVE","	# 0031 0032 65E5"},
/* 33EC */ { "IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY THIRTEEN","	# 0031 0033 65E5"},
/* 33ED */ { "IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY FOURTEEN","	# 0031 0034 65E5"},
/* 33EE */ { "IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY FIFTEEN","	# 0031 0035 65E5"},
/* 33EF */ { "IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY SIXTEEN","	# 0031 0036 65E5"},
/* 33F0 */ { "IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY SEVENTEEN","	# 0031 0037 65E5"},
/* 33F1 */ { "IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY EIGHTEEN","	# 0031 0038 65E5"},
/* 33F2 */ { "IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY NINETEEN","	# 0031 0039 65E5"},
/* 33F3 */ { "IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY TWENTY","	# 0032 0030 65E5"},
/* 33F4 */ { "IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY TWENTY-ONE","	# 0032 0031 65E5"},
/* 33F5 */ { "IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY TWENTY-TWO","	# 0032 0032 65E5"},
/* 33F6 */ { "IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY TWENTY-THREE","	# 0032 0033 65E5"},
/* 33F7 */ { "IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY TWENTY-FOUR","	# 0032 0034 65E5"},
/* 33F8 */ { "IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY TWENTY-FIVE","	# 0032 0035 65E5"},
/* 33F9 */ { "IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY TWENTY-SIX","	# 0032 0036 65E5"},
/* 33FA */ { "IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY TWENTY-SEVEN","	# 0032 0037 65E5"},
/* 33FB */ { "IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY TWENTY-EIGHT","	# 0032 0038 65E5"},
/* 33FC */ { "IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY TWENTY-NINE","	# 0032 0039 65E5"},
/* 33FD */ { "IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY THIRTY","	# 0033 0030 65E5"},
/* 33FE */ { "IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY THIRTY-ONE","	# 0033 0031 65E5"},
/* 33FF */ { "SQUARE GAL","	# <square> 0067 0061 006C"}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_00_4D[] = {
/* 4D00 */ { NULL,NULL},
/* 4D01 */ { NULL,NULL},
/* 4D02 */ { NULL,NULL},
/* 4D03 */ { NULL,NULL},
/* 4D04 */ { NULL,NULL},
/* 4D05 */ { NULL,NULL},
/* 4D06 */ { NULL,NULL},
/* 4D07 */ { NULL,NULL},
/* 4D08 */ { NULL,NULL},
/* 4D09 */ { NULL,NULL},
/* 4D0A */ { NULL,NULL},
/* 4D0B */ { NULL,NULL},
/* 4D0C */ { NULL,NULL},
/* 4D0D */ { NULL,NULL},
/* 4D0E */ { NULL,NULL},
/* 4D0F */ { NULL,NULL},
/* 4D10 */ { NULL,NULL},
/* 4D11 */ { NULL,NULL},
/* 4D12 */ { NULL,NULL},
/* 4D13 */ { NULL,NULL},
/* 4D14 */ { NULL,NULL},
/* 4D15 */ { NULL,NULL},
/* 4D16 */ { NULL,NULL},
/* 4D17 */ { NULL,NULL},
/* 4D18 */ { NULL,NULL},
/* 4D19 */ { NULL,NULL},
/* 4D1A */ { NULL,NULL},
/* 4D1B */ { NULL,NULL},
/* 4D1C */ { NULL,NULL},
/* 4D1D */ { NULL,NULL},
/* 4D1E */ { NULL,NULL},
/* 4D1F */ { NULL,NULL},
/* 4D20 */ { NULL,NULL},
/* 4D21 */ { NULL,NULL},
/* 4D22 */ { NULL,NULL},
/* 4D23 */ { NULL,NULL},
/* 4D24 */ { NULL,NULL},
/* 4D25 */ { NULL,NULL},
/* 4D26 */ { NULL,NULL},
/* 4D27 */ { NULL,NULL},
/* 4D28 */ { NULL,NULL},
/* 4D29 */ { NULL,NULL},
/* 4D2A */ { NULL,NULL},
/* 4D2B */ { NULL,NULL},
/* 4D2C */ { NULL,NULL},
/* 4D2D */ { NULL,NULL},
/* 4D2E */ { NULL,NULL},
/* 4D2F */ { NULL,NULL},
/* 4D30 */ { NULL,NULL},
/* 4D31 */ { NULL,NULL},
/* 4D32 */ { NULL,NULL},
/* 4D33 */ { NULL,NULL},
/* 4D34 */ { NULL,NULL},
/* 4D35 */ { NULL,NULL},
/* 4D36 */ { NULL,NULL},
/* 4D37 */ { NULL,NULL},
/* 4D38 */ { NULL,NULL},
/* 4D39 */ { NULL,NULL},
/* 4D3A */ { NULL,NULL},
/* 4D3B */ { NULL,NULL},
/* 4D3C */ { NULL,NULL},
/* 4D3D */ { NULL,NULL},
/* 4D3E */ { NULL,NULL},
/* 4D3F */ { NULL,NULL},
/* 4D40 */ { NULL,NULL},
/* 4D41 */ { NULL,NULL},
/* 4D42 */ { NULL,NULL},
/* 4D43 */ { NULL,NULL},
/* 4D44 */ { NULL,NULL},
/* 4D45 */ { NULL,NULL},
/* 4D46 */ { NULL,NULL},
/* 4D47 */ { NULL,NULL},
/* 4D48 */ { NULL,NULL},
/* 4D49 */ { NULL,NULL},
/* 4D4A */ { NULL,NULL},
/* 4D4B */ { NULL,NULL},
/* 4D4C */ { NULL,NULL},
/* 4D4D */ { NULL,NULL},
/* 4D4E */ { NULL,NULL},
/* 4D4F */ { NULL,NULL},
/* 4D50 */ { NULL,NULL},
/* 4D51 */ { NULL,NULL},
/* 4D52 */ { NULL,NULL},
/* 4D53 */ { NULL,NULL},
/* 4D54 */ { NULL,NULL},
/* 4D55 */ { NULL,NULL},
/* 4D56 */ { NULL,NULL},
/* 4D57 */ { NULL,NULL},
/* 4D58 */ { NULL,NULL},
/* 4D59 */ { NULL,NULL},
/* 4D5A */ { NULL,NULL},
/* 4D5B */ { NULL,NULL},
/* 4D5C */ { NULL,NULL},
/* 4D5D */ { NULL,NULL},
/* 4D5E */ { NULL,NULL},
/* 4D5F */ { NULL,NULL},
/* 4D60 */ { NULL,NULL},
/* 4D61 */ { NULL,NULL},
/* 4D62 */ { NULL,NULL},
/* 4D63 */ { NULL,NULL},
/* 4D64 */ { NULL,NULL},
/* 4D65 */ { NULL,NULL},
/* 4D66 */ { NULL,NULL},
/* 4D67 */ { NULL,NULL},
/* 4D68 */ { NULL,NULL},
/* 4D69 */ { NULL,NULL},
/* 4D6A */ { NULL,NULL},
/* 4D6B */ { NULL,NULL},
/* 4D6C */ { NULL,NULL},
/* 4D6D */ { NULL,NULL},
/* 4D6E */ { NULL,NULL},
/* 4D6F */ { NULL,NULL},
/* 4D70 */ { NULL,NULL},
/* 4D71 */ { NULL,NULL},
/* 4D72 */ { NULL,NULL},
/* 4D73 */ { NULL,NULL},
/* 4D74 */ { NULL,NULL},
/* 4D75 */ { NULL,NULL},
/* 4D76 */ { NULL,NULL},
/* 4D77 */ { NULL,NULL},
/* 4D78 */ { NULL,NULL},
/* 4D79 */ { NULL,NULL},
/* 4D7A */ { NULL,NULL},
/* 4D7B */ { NULL,NULL},
/* 4D7C */ { NULL,NULL},
/* 4D7D */ { NULL,NULL},
/* 4D7E */ { NULL,NULL},
/* 4D7F */ { NULL,NULL},
/* 4D80 */ { NULL,NULL},
/* 4D81 */ { NULL,NULL},
/* 4D82 */ { NULL,NULL},
/* 4D83 */ { NULL,NULL},
/* 4D84 */ { NULL,NULL},
/* 4D85 */ { NULL,NULL},
/* 4D86 */ { NULL,NULL},
/* 4D87 */ { NULL,NULL},
/* 4D88 */ { NULL,NULL},
/* 4D89 */ { NULL,NULL},
/* 4D8A */ { NULL,NULL},
/* 4D8B */ { NULL,NULL},
/* 4D8C */ { NULL,NULL},
/* 4D8D */ { NULL,NULL},
/* 4D8E */ { NULL,NULL},
/* 4D8F */ { NULL,NULL},
/* 4D90 */ { NULL,NULL},
/* 4D91 */ { NULL,NULL},
/* 4D92 */ { NULL,NULL},
/* 4D93 */ { NULL,NULL},
/* 4D94 */ { NULL,NULL},
/* 4D95 */ { NULL,NULL},
/* 4D96 */ { NULL,NULL},
/* 4D97 */ { NULL,NULL},
/* 4D98 */ { NULL,NULL},
/* 4D99 */ { NULL,NULL},
/* 4D9A */ { NULL,NULL},
/* 4D9B */ { NULL,NULL},
/* 4D9C */ { NULL,NULL},
/* 4D9D */ { NULL,NULL},
/* 4D9E */ { NULL,NULL},
/* 4D9F */ { NULL,NULL},
/* 4DA0 */ { NULL,NULL},
/* 4DA1 */ { NULL,NULL},
/* 4DA2 */ { NULL,NULL},
/* 4DA3 */ { NULL,NULL},
/* 4DA4 */ { NULL,NULL},
/* 4DA5 */ { NULL,NULL},
/* 4DA6 */ { NULL,NULL},
/* 4DA7 */ { NULL,NULL},
/* 4DA8 */ { NULL,NULL},
/* 4DA9 */ { NULL,NULL},
/* 4DAA */ { NULL,NULL},
/* 4DAB */ { NULL,NULL},
/* 4DAC */ { NULL,NULL},
/* 4DAD */ { NULL,NULL},
/* 4DAE */ { NULL,NULL},
/* 4DAF */ { NULL,NULL},
/* 4DB0 */ { NULL,NULL},
/* 4DB1 */ { NULL,NULL},
/* 4DB2 */ { NULL,NULL},
/* 4DB3 */ { NULL,NULL},
/* 4DB4 */ { NULL,NULL},
/* 4DB5 */ { NULL,NULL},
/* 4DB6 */ { NULL,NULL},
/* 4DB7 */ { NULL,NULL},
/* 4DB8 */ { NULL,NULL},
/* 4DB9 */ { NULL,NULL},
/* 4DBA */ { NULL,NULL},
/* 4DBB */ { NULL,NULL},
/* 4DBC */ { NULL,NULL},
/* 4DBD */ { NULL,NULL},
/* 4DBE */ { NULL,NULL},
/* 4DBF */ { NULL,NULL},
/* 4DC0 */ { "HEXAGRAM FOR THE CREATIVE HEAVEN",NULL},
/* 4DC1 */ { "HEXAGRAM FOR THE RECEPTIVE EARTH",NULL},
/* 4DC2 */ { "HEXAGRAM FOR DIFFICULTY AT THE BEGINNING",NULL},
/* 4DC3 */ { "HEXAGRAM FOR YOUTHFUL FOLLY",NULL},
/* 4DC4 */ { "HEXAGRAM FOR WAITING",NULL},
/* 4DC5 */ { "HEXAGRAM FOR CONFLICT",NULL},
/* 4DC6 */ { "HEXAGRAM FOR THE ARMY",NULL},
/* 4DC7 */ { "HEXAGRAM FOR HOLDING TOGETHER",NULL},
/* 4DC8 */ { "HEXAGRAM FOR SMALL TAMING",NULL},
/* 4DC9 */ { "HEXAGRAM FOR TREADING",NULL},
/* 4DCA */ { "HEXAGRAM FOR PEACE",NULL},
/* 4DCB */ { "HEXAGRAM FOR STANDSTILL",NULL},
/* 4DCC */ { "HEXAGRAM FOR FELLOWSHIP",NULL},
/* 4DCD */ { "HEXAGRAM FOR GREAT POSSESSION",NULL},
/* 4DCE */ { "HEXAGRAM FOR MODESTY",NULL},
/* 4DCF */ { "HEXAGRAM FOR ENTHUSIASM",NULL},
/* 4DD0 */ { "HEXAGRAM FOR FOLLOWING",NULL},
/* 4DD1 */ { "HEXAGRAM FOR WORK ON THE DECAYED",NULL},
/* 4DD2 */ { "HEXAGRAM FOR APPROACH",NULL},
/* 4DD3 */ { "HEXAGRAM FOR CONTEMPLATION",NULL},
/* 4DD4 */ { "HEXAGRAM FOR BITING THROUGH",NULL},
/* 4DD5 */ { "HEXAGRAM FOR GRACE",NULL},
/* 4DD6 */ { "HEXAGRAM FOR SPLITTING APART",NULL},
/* 4DD7 */ { "HEXAGRAM FOR RETURN",NULL},
/* 4DD8 */ { "HEXAGRAM FOR INNOCENCE",NULL},
/* 4DD9 */ { "HEXAGRAM FOR GREAT TAMING",NULL},
/* 4DDA */ { "HEXAGRAM FOR MOUTH CORNERS",NULL},
/* 4DDB */ { "HEXAGRAM FOR GREAT PREPONDERANCE",NULL},
/* 4DDC */ { "HEXAGRAM FOR THE ABYSMAL WATER",NULL},
/* 4DDD */ { "HEXAGRAM FOR THE CLINGING FIRE",NULL},
/* 4DDE */ { "HEXAGRAM FOR INFLUENCE",NULL},
/* 4DDF */ { "HEXAGRAM FOR DURATION",NULL},
/* 4DE0 */ { "HEXAGRAM FOR RETREAT",NULL},
/* 4DE1 */ { "HEXAGRAM FOR GREAT POWER",NULL},
/* 4DE2 */ { "HEXAGRAM FOR PROGRESS",NULL},
/* 4DE3 */ { "HEXAGRAM FOR DARKENING OF THE LIGHT",NULL},
/* 4DE4 */ { "HEXAGRAM FOR THE FAMILY",NULL},
/* 4DE5 */ { "HEXAGRAM FOR OPPOSITION",NULL},
/* 4DE6 */ { "HEXAGRAM FOR OBSTRUCTION",NULL},
/* 4DE7 */ { "HEXAGRAM FOR DELIVERANCE",NULL},
/* 4DE8 */ { "HEXAGRAM FOR DECREASE",NULL},
/* 4DE9 */ { "HEXAGRAM FOR INCREASE",NULL},
/* 4DEA */ { "HEXAGRAM FOR BREAKTHROUGH",NULL},
/* 4DEB */ { "HEXAGRAM FOR COMING TO MEET",NULL},
/* 4DEC */ { "HEXAGRAM FOR GATHERING TOGETHER",NULL},
/* 4DED */ { "HEXAGRAM FOR PUSHING UPWARD",NULL},
/* 4DEE */ { "HEXAGRAM FOR OPPRESSION",NULL},
/* 4DEF */ { "HEXAGRAM FOR THE WELL",NULL},
/* 4DF0 */ { "HEXAGRAM FOR REVOLUTION",NULL},
/* 4DF1 */ { "HEXAGRAM FOR THE CAULDRON",NULL},
/* 4DF2 */ { "HEXAGRAM FOR THE AROUSING THUNDER",NULL},
/* 4DF3 */ { "HEXAGRAM FOR THE KEEPING STILL MOUNTAIN",NULL},
/* 4DF4 */ { "HEXAGRAM FOR DEVELOPMENT",NULL},
/* 4DF5 */ { "HEXAGRAM FOR THE MARRYING MAIDEN",NULL},
/* 4DF6 */ { "HEXAGRAM FOR ABUNDANCE",NULL},
/* 4DF7 */ { "HEXAGRAM FOR THE WANDERER",NULL},
/* 4DF8 */ { "HEXAGRAM FOR THE GENTLE WIND",NULL},
/* 4DF9 */ { "HEXAGRAM FOR THE JOYOUS LAKE",NULL},
/* 4DFA */ { "HEXAGRAM FOR DISPERSION",NULL},
/* 4DFB */ { "HEXAGRAM FOR LIMITATION",NULL},
/* 4DFC */ { "HEXAGRAM FOR INNER TRUTH",NULL},
/* 4DFD */ { "HEXAGRAM FOR SMALL PREPONDERANCE",NULL},
/* 4DFE */ { "HEXAGRAM FOR AFTER COMPLETION",NULL},
/* 4DFF */ { "HEXAGRAM FOR BEFORE COMPLETION",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_00_A0[] = {
/* A000 */ { "YI SYLLABLE IT",NULL},
/* A001 */ { "YI SYLLABLE IX",NULL},
/* A002 */ { "YI SYLLABLE I",NULL},
/* A003 */ { "YI SYLLABLE IP",NULL},
/* A004 */ { "YI SYLLABLE IET",NULL},
/* A005 */ { "YI SYLLABLE IEX",NULL},
/* A006 */ { "YI SYLLABLE IE",NULL},
/* A007 */ { "YI SYLLABLE IEP",NULL},
/* A008 */ { "YI SYLLABLE AT",NULL},
/* A009 */ { "YI SYLLABLE AX",NULL},
/* A00A */ { "YI SYLLABLE A",NULL},
/* A00B */ { "YI SYLLABLE AP",NULL},
/* A00C */ { "YI SYLLABLE UOX",NULL},
/* A00D */ { "YI SYLLABLE UO",NULL},
/* A00E */ { "YI SYLLABLE UOP",NULL},
/* A00F */ { "YI SYLLABLE OT",NULL},
/* A010 */ { "YI SYLLABLE OX",NULL},
/* A011 */ { "YI SYLLABLE O",NULL},
/* A012 */ { "YI SYLLABLE OP",NULL},
/* A013 */ { "YI SYLLABLE EX",NULL},
/* A014 */ { "YI SYLLABLE E",NULL},
/* A015 */ { "YI SYLLABLE WU","	% YI SYLLABLE ITERATION MARK\n"
	"	* name is a misnomer"},
/* A016 */ { "YI SYLLABLE BIT",NULL},
/* A017 */ { "YI SYLLABLE BIX",NULL},
/* A018 */ { "YI SYLLABLE BI",NULL},
/* A019 */ { "YI SYLLABLE BIP",NULL},
/* A01A */ { "YI SYLLABLE BIET",NULL},
/* A01B */ { "YI SYLLABLE BIEX",NULL},
/* A01C */ { "YI SYLLABLE BIE",NULL},
/* A01D */ { "YI SYLLABLE BIEP",NULL},
/* A01E */ { "YI SYLLABLE BAT",NULL},
/* A01F */ { "YI SYLLABLE BAX",NULL},
/* A020 */ { "YI SYLLABLE BA",NULL},
/* A021 */ { "YI SYLLABLE BAP",NULL},
/* A022 */ { "YI SYLLABLE BUOX",NULL},
/* A023 */ { "YI SYLLABLE BUO",NULL},
/* A024 */ { "YI SYLLABLE BUOP",NULL},
/* A025 */ { "YI SYLLABLE BOT",NULL},
/* A026 */ { "YI SYLLABLE BOX",NULL},
/* A027 */ { "YI SYLLABLE BO",NULL},
/* A028 */ { "YI SYLLABLE BOP",NULL},
/* A029 */ { "YI SYLLABLE BEX",NULL},
/* A02A */ { "YI SYLLABLE BE",NULL},
/* A02B */ { "YI SYLLABLE BEP",NULL},
/* A02C */ { "YI SYLLABLE BUT",NULL},
/* A02D */ { "YI SYLLABLE BUX",NULL},
/* A02E */ { "YI SYLLABLE BU",NULL},
/* A02F */ { "YI SYLLABLE BUP",NULL},
/* A030 */ { "YI SYLLABLE BURX",NULL},
/* A031 */ { "YI SYLLABLE BUR",NULL},
/* A032 */ { "YI SYLLABLE BYT",NULL},
/* A033 */ { "YI SYLLABLE BYX",NULL},
/* A034 */ { "YI SYLLABLE BY",NULL},
/* A035 */ { "YI SYLLABLE BYP",NULL},
/* A036 */ { "YI SYLLABLE BYRX",NULL},
/* A037 */ { "YI SYLLABLE BYR",NULL},
/* A038 */ { "YI SYLLABLE PIT",NULL},
/* A039 */ { "YI SYLLABLE PIX",NULL},
/* A03A */ { "YI SYLLABLE PI",NULL},
/* A03B */ { "YI SYLLABLE PIP",NULL},
/* A03C */ { "YI SYLLABLE PIEX",NULL},
/* A03D */ { "YI SYLLABLE PIE",NULL},
/* A03E */ { "YI SYLLABLE PIEP",NULL},
/* A03F */ { "YI SYLLABLE PAT",NULL},
/* A040 */ { "YI SYLLABLE PAX",NULL},
/* A041 */ { "YI SYLLABLE PA",NULL},
/* A042 */ { "YI SYLLABLE PAP",NULL},
/* A043 */ { "YI SYLLABLE PUOX",NULL},
/* A044 */ { "YI SYLLABLE PUO",NULL},
/* A045 */ { "YI SYLLABLE PUOP",NULL},
/* A046 */ { "YI SYLLABLE POT",NULL},
/* A047 */ { "YI SYLLABLE POX",NULL},
/* A048 */ { "YI SYLLABLE PO",NULL},
/* A049 */ { "YI SYLLABLE POP",NULL},
/* A04A */ { "YI SYLLABLE PUT",NULL},
/* A04B */ { "YI SYLLABLE PUX",NULL},
/* A04C */ { "YI SYLLABLE PU",NULL},
/* A04D */ { "YI SYLLABLE PUP",NULL},
/* A04E */ { "YI SYLLABLE PURX",NULL},
/* A04F */ { "YI SYLLABLE PUR",NULL},
/* A050 */ { "YI SYLLABLE PYT",NULL},
/* A051 */ { "YI SYLLABLE PYX",NULL},
/* A052 */ { "YI SYLLABLE PY",NULL},
/* A053 */ { "YI SYLLABLE PYP",NULL},
/* A054 */ { "YI SYLLABLE PYRX",NULL},
/* A055 */ { "YI SYLLABLE PYR",NULL},
/* A056 */ { "YI SYLLABLE BBIT",NULL},
/* A057 */ { "YI SYLLABLE BBIX",NULL},
/* A058 */ { "YI SYLLABLE BBI",NULL},
/* A059 */ { "YI SYLLABLE BBIP",NULL},
/* A05A */ { "YI SYLLABLE BBIET",NULL},
/* A05B */ { "YI SYLLABLE BBIEX",NULL},
/* A05C */ { "YI SYLLABLE BBIE",NULL},
/* A05D */ { "YI SYLLABLE BBIEP",NULL},
/* A05E */ { "YI SYLLABLE BBAT",NULL},
/* A05F */ { "YI SYLLABLE BBAX",NULL},
/* A060 */ { "YI SYLLABLE BBA",NULL},
/* A061 */ { "YI SYLLABLE BBAP",NULL},
/* A062 */ { "YI SYLLABLE BBUOX",NULL},
/* A063 */ { "YI SYLLABLE BBUO",NULL},
/* A064 */ { "YI SYLLABLE BBUOP",NULL},
/* A065 */ { "YI SYLLABLE BBOT",NULL},
/* A066 */ { "YI SYLLABLE BBOX",NULL},
/* A067 */ { "YI SYLLABLE BBO",NULL},
/* A068 */ { "YI SYLLABLE BBOP",NULL},
/* A069 */ { "YI SYLLABLE BBEX",NULL},
/* A06A */ { "YI SYLLABLE BBE",NULL},
/* A06B */ { "YI SYLLABLE BBEP",NULL},
/* A06C */ { "YI SYLLABLE BBUT",NULL},
/* A06D */ { "YI SYLLABLE BBUX",NULL},
/* A06E */ { "YI SYLLABLE BBU",NULL},
/* A06F */ { "YI SYLLABLE BBUP",NULL},
/* A070 */ { "YI SYLLABLE BBURX",NULL},
/* A071 */ { "YI SYLLABLE BBUR",NULL},
/* A072 */ { "YI SYLLABLE BBYT",NULL},
/* A073 */ { "YI SYLLABLE BBYX",NULL},
/* A074 */ { "YI SYLLABLE BBY",NULL},
/* A075 */ { "YI SYLLABLE BBYP",NULL},
/* A076 */ { "YI SYLLABLE NBIT",NULL},
/* A077 */ { "YI SYLLABLE NBIX",NULL},
/* A078 */ { "YI SYLLABLE NBI",NULL},
/* A079 */ { "YI SYLLABLE NBIP",NULL},
/* A07A */ { "YI SYLLABLE NBIEX",NULL},
/* A07B */ { "YI SYLLABLE NBIE",NULL},
/* A07C */ { "YI SYLLABLE NBIEP",NULL},
/* A07D */ { "YI SYLLABLE NBAT",NULL},
/* A07E */ { "YI SYLLABLE NBAX",NULL},
/* A07F */ { "YI SYLLABLE NBA",NULL},
/* A080 */ { "YI SYLLABLE NBAP",NULL},
/* A081 */ { "YI SYLLABLE NBOT",NULL},
/* A082 */ { "YI SYLLABLE NBOX",NULL},
/* A083 */ { "YI SYLLABLE NBO",NULL},
/* A084 */ { "YI SYLLABLE NBOP",NULL},
/* A085 */ { "YI SYLLABLE NBUT",NULL},
/* A086 */ { "YI SYLLABLE NBUX",NULL},
/* A087 */ { "YI SYLLABLE NBU",NULL},
/* A088 */ { "YI SYLLABLE NBUP",NULL},
/* A089 */ { "YI SYLLABLE NBURX",NULL},
/* A08A */ { "YI SYLLABLE NBUR",NULL},
/* A08B */ { "YI SYLLABLE NBYT",NULL},
/* A08C */ { "YI SYLLABLE NBYX",NULL},
/* A08D */ { "YI SYLLABLE NBY",NULL},
/* A08E */ { "YI SYLLABLE NBYP",NULL},
/* A08F */ { "YI SYLLABLE NBYRX",NULL},
/* A090 */ { "YI SYLLABLE NBYR",NULL},
/* A091 */ { "YI SYLLABLE HMIT",NULL},
/* A092 */ { "YI SYLLABLE HMIX",NULL},
/* A093 */ { "YI SYLLABLE HMI",NULL},
/* A094 */ { "YI SYLLABLE HMIP",NULL},
/* A095 */ { "YI SYLLABLE HMIEX",NULL},
/* A096 */ { "YI SYLLABLE HMIE",NULL},
/* A097 */ { "YI SYLLABLE HMIEP",NULL},
/* A098 */ { "YI SYLLABLE HMAT",NULL},
/* A099 */ { "YI SYLLABLE HMAX",NULL},
/* A09A */ { "YI SYLLABLE HMA",NULL},
/* A09B */ { "YI SYLLABLE HMAP",NULL},
/* A09C */ { "YI SYLLABLE HMUOX",NULL},
/* A09D */ { "YI SYLLABLE HMUO",NULL},
/* A09E */ { "YI SYLLABLE HMUOP",NULL},
/* A09F */ { "YI SYLLABLE HMOT",NULL},
/* A0A0 */ { "YI SYLLABLE HMOX",NULL},
/* A0A1 */ { "YI SYLLABLE HMO",NULL},
/* A0A2 */ { "YI SYLLABLE HMOP",NULL},
/* A0A3 */ { "YI SYLLABLE HMUT",NULL},
/* A0A4 */ { "YI SYLLABLE HMUX",NULL},
/* A0A5 */ { "YI SYLLABLE HMU",NULL},
/* A0A6 */ { "YI SYLLABLE HMUP",NULL},
/* A0A7 */ { "YI SYLLABLE HMURX",NULL},
/* A0A8 */ { "YI SYLLABLE HMUR",NULL},
/* A0A9 */ { "YI SYLLABLE HMYX",NULL},
/* A0AA */ { "YI SYLLABLE HMY",NULL},
/* A0AB */ { "YI SYLLABLE HMYP",NULL},
/* A0AC */ { "YI SYLLABLE HMYRX",NULL},
/* A0AD */ { "YI SYLLABLE HMYR",NULL},
/* A0AE */ { "YI SYLLABLE MIT",NULL},
/* A0AF */ { "YI SYLLABLE MIX",NULL},
/* A0B0 */ { "YI SYLLABLE MI",NULL},
/* A0B1 */ { "YI SYLLABLE MIP",NULL},
/* A0B2 */ { "YI SYLLABLE MIEX",NULL},
/* A0B3 */ { "YI SYLLABLE MIE",NULL},
/* A0B4 */ { "YI SYLLABLE MIEP",NULL},
/* A0B5 */ { "YI SYLLABLE MAT",NULL},
/* A0B6 */ { "YI SYLLABLE MAX",NULL},
/* A0B7 */ { "YI SYLLABLE MA",NULL},
/* A0B8 */ { "YI SYLLABLE MAP",NULL},
/* A0B9 */ { "YI SYLLABLE MUOT",NULL},
/* A0BA */ { "YI SYLLABLE MUOX",NULL},
/* A0BB */ { "YI SYLLABLE MUO",NULL},
/* A0BC */ { "YI SYLLABLE MUOP",NULL},
/* A0BD */ { "YI SYLLABLE MOT",NULL},
/* A0BE */ { "YI SYLLABLE MOX",NULL},
/* A0BF */ { "YI SYLLABLE MO",NULL},
/* A0C0 */ { "YI SYLLABLE MOP",NULL},
/* A0C1 */ { "YI SYLLABLE MEX",NULL},
/* A0C2 */ { "YI SYLLABLE ME",NULL},
/* A0C3 */ { "YI SYLLABLE MUT",NULL},
/* A0C4 */ { "YI SYLLABLE MUX",NULL},
/* A0C5 */ { "YI SYLLABLE MU",NULL},
/* A0C6 */ { "YI SYLLABLE MUP",NULL},
/* A0C7 */ { "YI SYLLABLE MURX",NULL},
/* A0C8 */ { "YI SYLLABLE MUR",NULL},
/* A0C9 */ { "YI SYLLABLE MYT",NULL},
/* A0CA */ { "YI SYLLABLE MYX",NULL},
/* A0CB */ { "YI SYLLABLE MY",NULL},
/* A0CC */ { "YI SYLLABLE MYP",NULL},
/* A0CD */ { "YI SYLLABLE FIT",NULL},
/* A0CE */ { "YI SYLLABLE FIX",NULL},
/* A0CF */ { "YI SYLLABLE FI",NULL},
/* A0D0 */ { "YI SYLLABLE FIP",NULL},
/* A0D1 */ { "YI SYLLABLE FAT",NULL},
/* A0D2 */ { "YI SYLLABLE FAX",NULL},
/* A0D3 */ { "YI SYLLABLE FA",NULL},
/* A0D4 */ { "YI SYLLABLE FAP",NULL},
/* A0D5 */ { "YI SYLLABLE FOX",NULL},
/* A0D6 */ { "YI SYLLABLE FO",NULL},
/* A0D7 */ { "YI SYLLABLE FOP",NULL},
/* A0D8 */ { "YI SYLLABLE FUT",NULL},
/* A0D9 */ { "YI SYLLABLE FUX",NULL},
/* A0DA */ { "YI SYLLABLE FU",NULL},
/* A0DB */ { "YI SYLLABLE FUP",NULL},
/* A0DC */ { "YI SYLLABLE FURX",NULL},
/* A0DD */ { "YI SYLLABLE FUR",NULL},
/* A0DE */ { "YI SYLLABLE FYT",NULL},
/* A0DF */ { "YI SYLLABLE FYX",NULL},
/* A0E0 */ { "YI SYLLABLE FY",NULL},
/* A0E1 */ { "YI SYLLABLE FYP",NULL},
/* A0E2 */ { "YI SYLLABLE VIT",NULL},
/* A0E3 */ { "YI SYLLABLE VIX",NULL},
/* A0E4 */ { "YI SYLLABLE VI",NULL},
/* A0E5 */ { "YI SYLLABLE VIP",NULL},
/* A0E6 */ { "YI SYLLABLE VIET",NULL},
/* A0E7 */ { "YI SYLLABLE VIEX",NULL},
/* A0E8 */ { "YI SYLLABLE VIE",NULL},
/* A0E9 */ { "YI SYLLABLE VIEP",NULL},
/* A0EA */ { "YI SYLLABLE VAT",NULL},
/* A0EB */ { "YI SYLLABLE VAX",NULL},
/* A0EC */ { "YI SYLLABLE VA",NULL},
/* A0ED */ { "YI SYLLABLE VAP",NULL},
/* A0EE */ { "YI SYLLABLE VOT",NULL},
/* A0EF */ { "YI SYLLABLE VOX",NULL},
/* A0F0 */ { "YI SYLLABLE VO",NULL},
/* A0F1 */ { "YI SYLLABLE VOP",NULL},
/* A0F2 */ { "YI SYLLABLE VEX",NULL},
/* A0F3 */ { "YI SYLLABLE VEP",NULL},
/* A0F4 */ { "YI SYLLABLE VUT",NULL},
/* A0F5 */ { "YI SYLLABLE VUX",NULL},
/* A0F6 */ { "YI SYLLABLE VU",NULL},
/* A0F7 */ { "YI SYLLABLE VUP",NULL},
/* A0F8 */ { "YI SYLLABLE VURX",NULL},
/* A0F9 */ { "YI SYLLABLE VUR",NULL},
/* A0FA */ { "YI SYLLABLE VYT",NULL},
/* A0FB */ { "YI SYLLABLE VYX",NULL},
/* A0FC */ { "YI SYLLABLE VY",NULL},
/* A0FD */ { "YI SYLLABLE VYP",NULL},
/* A0FE */ { "YI SYLLABLE VYRX",NULL},
/* A0FF */ { "YI SYLLABLE VYR",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_00_A1[] = {
/* A100 */ { "YI SYLLABLE DIT",NULL},
/* A101 */ { "YI SYLLABLE DIX",NULL},
/* A102 */ { "YI SYLLABLE DI",NULL},
/* A103 */ { "YI SYLLABLE DIP",NULL},
/* A104 */ { "YI SYLLABLE DIEX",NULL},
/* A105 */ { "YI SYLLABLE DIE",NULL},
/* A106 */ { "YI SYLLABLE DIEP",NULL},
/* A107 */ { "YI SYLLABLE DAT",NULL},
/* A108 */ { "YI SYLLABLE DAX",NULL},
/* A109 */ { "YI SYLLABLE DA",NULL},
/* A10A */ { "YI SYLLABLE DAP",NULL},
/* A10B */ { "YI SYLLABLE DUOX",NULL},
/* A10C */ { "YI SYLLABLE DUO",NULL},
/* A10D */ { "YI SYLLABLE DOT",NULL},
/* A10E */ { "YI SYLLABLE DOX",NULL},
/* A10F */ { "YI SYLLABLE DO",NULL},
/* A110 */ { "YI SYLLABLE DOP",NULL},
/* A111 */ { "YI SYLLABLE DEX",NULL},
/* A112 */ { "YI SYLLABLE DE",NULL},
/* A113 */ { "YI SYLLABLE DEP",NULL},
/* A114 */ { "YI SYLLABLE DUT",NULL},
/* A115 */ { "YI SYLLABLE DUX",NULL},
/* A116 */ { "YI SYLLABLE DU",NULL},
/* A117 */ { "YI SYLLABLE DUP",NULL},
/* A118 */ { "YI SYLLABLE DURX",NULL},
/* A119 */ { "YI SYLLABLE DUR",NULL},
/* A11A */ { "YI SYLLABLE TIT",NULL},
/* A11B */ { "YI SYLLABLE TIX",NULL},
/* A11C */ { "YI SYLLABLE TI",NULL},
/* A11D */ { "YI SYLLABLE TIP",NULL},
/* A11E */ { "YI SYLLABLE TIEX",NULL},
/* A11F */ { "YI SYLLABLE TIE",NULL},
/* A120 */ { "YI SYLLABLE TIEP",NULL},
/* A121 */ { "YI SYLLABLE TAT",NULL},
/* A122 */ { "YI SYLLABLE TAX",NULL},
/* A123 */ { "YI SYLLABLE TA",NULL},
/* A124 */ { "YI SYLLABLE TAP",NULL},
/* A125 */ { "YI SYLLABLE TUOT",NULL},
/* A126 */ { "YI SYLLABLE TUOX",NULL},
/* A127 */ { "YI SYLLABLE TUO",NULL},
/* A128 */ { "YI SYLLABLE TUOP",NULL},
/* A129 */ { "YI SYLLABLE TOT",NULL},
/* A12A */ { "YI SYLLABLE TOX",NULL},
/* A12B */ { "YI SYLLABLE TO",NULL},
/* A12C */ { "YI SYLLABLE TOP",NULL},
/* A12D */ { "YI SYLLABLE TEX",NULL},
/* A12E */ { "YI SYLLABLE TE",NULL},
/* A12F */ { "YI SYLLABLE TEP",NULL},
/* A130 */ { "YI SYLLABLE TUT",NULL},
/* A131 */ { "YI SYLLABLE TUX",NULL},
/* A132 */ { "YI SYLLABLE TU",NULL},
/* A133 */ { "YI SYLLABLE TUP",NULL},
/* A134 */ { "YI SYLLABLE TURX",NULL},
/* A135 */ { "YI SYLLABLE TUR",NULL},
/* A136 */ { "YI SYLLABLE DDIT",NULL},
/* A137 */ { "YI SYLLABLE DDIX",NULL},
/* A138 */ { "YI SYLLABLE DDI",NULL},
/* A139 */ { "YI SYLLABLE DDIP",NULL},
/* A13A */ { "YI SYLLABLE DDIEX",NULL},
/* A13B */ { "YI SYLLABLE DDIE",NULL},
/* A13C */ { "YI SYLLABLE DDIEP",NULL},
/* A13D */ { "YI SYLLABLE DDAT",NULL},
/* A13E */ { "YI SYLLABLE DDAX",NULL},
/* A13F */ { "YI SYLLABLE DDA",NULL},
/* A140 */ { "YI SYLLABLE DDAP",NULL},
/* A141 */ { "YI SYLLABLE DDUOX",NULL},
/* A142 */ { "YI SYLLABLE DDUO",NULL},
/* A143 */ { "YI SYLLABLE DDUOP",NULL},
/* A144 */ { "YI SYLLABLE DDOT",NULL},
/* A145 */ { "YI SYLLABLE DDOX",NULL},
/* A146 */ { "YI SYLLABLE DDO",NULL},
/* A147 */ { "YI SYLLABLE DDOP",NULL},
/* A148 */ { "YI SYLLABLE DDEX",NULL},
/* A149 */ { "YI SYLLABLE DDE",NULL},
/* A14A */ { "YI SYLLABLE DDEP",NULL},
/* A14B */ { "YI SYLLABLE DDUT",NULL},
/* A14C */ { "YI SYLLABLE DDUX",NULL},
/* A14D */ { "YI SYLLABLE DDU",NULL},
/* A14E */ { "YI SYLLABLE DDUP",NULL},
/* A14F */ { "YI SYLLABLE DDURX",NULL},
/* A150 */ { "YI SYLLABLE DDUR",NULL},
/* A151 */ { "YI SYLLABLE NDIT",NULL},
/* A152 */ { "YI SYLLABLE NDIX",NULL},
/* A153 */ { "YI SYLLABLE NDI",NULL},
/* A154 */ { "YI SYLLABLE NDIP",NULL},
/* A155 */ { "YI SYLLABLE NDIEX",NULL},
/* A156 */ { "YI SYLLABLE NDIE",NULL},
/* A157 */ { "YI SYLLABLE NDAT",NULL},
/* A158 */ { "YI SYLLABLE NDAX",NULL},
/* A159 */ { "YI SYLLABLE NDA",NULL},
/* A15A */ { "YI SYLLABLE NDAP",NULL},
/* A15B */ { "YI SYLLABLE NDOT",NULL},
/* A15C */ { "YI SYLLABLE NDOX",NULL},
/* A15D */ { "YI SYLLABLE NDO",NULL},
/* A15E */ { "YI SYLLABLE NDOP",NULL},
/* A15F */ { "YI SYLLABLE NDEX",NULL},
/* A160 */ { "YI SYLLABLE NDE",NULL},
/* A161 */ { "YI SYLLABLE NDEP",NULL},
/* A162 */ { "YI SYLLABLE NDUT",NULL},
/* A163 */ { "YI SYLLABLE NDUX",NULL},
/* A164 */ { "YI SYLLABLE NDU",NULL},
/* A165 */ { "YI SYLLABLE NDUP",NULL},
/* A166 */ { "YI SYLLABLE NDURX",NULL},
/* A167 */ { "YI SYLLABLE NDUR",NULL},
/* A168 */ { "YI SYLLABLE HNIT",NULL},
/* A169 */ { "YI SYLLABLE HNIX",NULL},
/* A16A */ { "YI SYLLABLE HNI",NULL},
/* A16B */ { "YI SYLLABLE HNIP",NULL},
/* A16C */ { "YI SYLLABLE HNIET",NULL},
/* A16D */ { "YI SYLLABLE HNIEX",NULL},
/* A16E */ { "YI SYLLABLE HNIE",NULL},
/* A16F */ { "YI SYLLABLE HNIEP",NULL},
/* A170 */ { "YI SYLLABLE HNAT",NULL},
/* A171 */ { "YI SYLLABLE HNAX",NULL},
/* A172 */ { "YI SYLLABLE HNA",NULL},
/* A173 */ { "YI SYLLABLE HNAP",NULL},
/* A174 */ { "YI SYLLABLE HNUOX",NULL},
/* A175 */ { "YI SYLLABLE HNUO",NULL},
/* A176 */ { "YI SYLLABLE HNOT",NULL},
/* A177 */ { "YI SYLLABLE HNOX",NULL},
/* A178 */ { "YI SYLLABLE HNOP",NULL},
/* A179 */ { "YI SYLLABLE HNEX",NULL},
/* A17A */ { "YI SYLLABLE HNE",NULL},
/* A17B */ { "YI SYLLABLE HNEP",NULL},
/* A17C */ { "YI SYLLABLE HNUT",NULL},
/* A17D */ { "YI SYLLABLE NIT",NULL},
/* A17E */ { "YI SYLLABLE NIX",NULL},
/* A17F */ { "YI SYLLABLE NI",NULL},
/* A180 */ { "YI SYLLABLE NIP",NULL},
/* A181 */ { "YI SYLLABLE NIEX",NULL},
/* A182 */ { "YI SYLLABLE NIE",NULL},
/* A183 */ { "YI SYLLABLE NIEP",NULL},
/* A184 */ { "YI SYLLABLE NAX",NULL},
/* A185 */ { "YI SYLLABLE NA",NULL},
/* A186 */ { "YI SYLLABLE NAP",NULL},
/* A187 */ { "YI SYLLABLE NUOX",NULL},
/* A188 */ { "YI SYLLABLE NUO",NULL},
/* A189 */ { "YI SYLLABLE NUOP",NULL},
/* A18A */ { "YI SYLLABLE NOT",NULL},
/* A18B */ { "YI SYLLABLE NOX",NULL},
/* A18C */ { "YI SYLLABLE NO",NULL},
/* A18D */ { "YI SYLLABLE NOP",NULL},
/* A18E */ { "YI SYLLABLE NEX",NULL},
/* A18F */ { "YI SYLLABLE NE",NULL},
/* A190 */ { "YI SYLLABLE NEP",NULL},
/* A191 */ { "YI SYLLABLE NUT",NULL},
/* A192 */ { "YI SYLLABLE NUX",NULL},
/* A193 */ { "YI SYLLABLE NU",NULL},
/* A194 */ { "YI SYLLABLE NUP",NULL},
/* A195 */ { "YI SYLLABLE NURX",NULL},
/* A196 */ { "YI SYLLABLE NUR",NULL},
/* A197 */ { "YI SYLLABLE HLIT",NULL},
/* A198 */ { "YI SYLLABLE HLIX",NULL},
/* A199 */ { "YI SYLLABLE HLI",NULL},
/* A19A */ { "YI SYLLABLE HLIP",NULL},
/* A19B */ { "YI SYLLABLE HLIEX",NULL},
/* A19C */ { "YI SYLLABLE HLIE",NULL},
/* A19D */ { "YI SYLLABLE HLIEP",NULL},
/* A19E */ { "YI SYLLABLE HLAT",NULL},
/* A19F */ { "YI SYLLABLE HLAX",NULL},
/* A1A0 */ { "YI SYLLABLE HLA",NULL},
/* A1A1 */ { "YI SYLLABLE HLAP",NULL},
/* A1A2 */ { "YI SYLLABLE HLUOX",NULL},
/* A1A3 */ { "YI SYLLABLE HLUO",NULL},
/* A1A4 */ { "YI SYLLABLE HLUOP",NULL},
/* A1A5 */ { "YI SYLLABLE HLOX",NULL},
/* A1A6 */ { "YI SYLLABLE HLO",NULL},
/* A1A7 */ { "YI SYLLABLE HLOP",NULL},
/* A1A8 */ { "YI SYLLABLE HLEX",NULL},
/* A1A9 */ { "YI SYLLABLE HLE",NULL},
/* A1AA */ { "YI SYLLABLE HLEP",NULL},
/* A1AB */ { "YI SYLLABLE HLUT",NULL},
/* A1AC */ { "YI SYLLABLE HLUX",NULL},
/* A1AD */ { "YI SYLLABLE HLU",NULL},
/* A1AE */ { "YI SYLLABLE HLUP",NULL},
/* A1AF */ { "YI SYLLABLE HLURX",NULL},
/* A1B0 */ { "YI SYLLABLE HLUR",NULL},
/* A1B1 */ { "YI SYLLABLE HLYT",NULL},
/* A1B2 */ { "YI SYLLABLE HLYX",NULL},
/* A1B3 */ { "YI SYLLABLE HLY",NULL},
/* A1B4 */ { "YI SYLLABLE HLYP",NULL},
/* A1B5 */ { "YI SYLLABLE HLYRX",NULL},
/* A1B6 */ { "YI SYLLABLE HLYR",NULL},
/* A1B7 */ { "YI SYLLABLE LIT",NULL},
/* A1B8 */ { "YI SYLLABLE LIX",NULL},
/* A1B9 */ { "YI SYLLABLE LI",NULL},
/* A1BA */ { "YI SYLLABLE LIP",NULL},
/* A1BB */ { "YI SYLLABLE LIET",NULL},
/* A1BC */ { "YI SYLLABLE LIEX",NULL},
/* A1BD */ { "YI SYLLABLE LIE",NULL},
/* A1BE */ { "YI SYLLABLE LIEP",NULL},
/* A1BF */ { "YI SYLLABLE LAT",NULL},
/* A1C0 */ { "YI SYLLABLE LAX",NULL},
/* A1C1 */ { "YI SYLLABLE LA",NULL},
/* A1C2 */ { "YI SYLLABLE LAP",NULL},
/* A1C3 */ { "YI SYLLABLE LUOT",NULL},
/* A1C4 */ { "YI SYLLABLE LUOX",NULL},
/* A1C5 */ { "YI SYLLABLE LUO",NULL},
/* A1C6 */ { "YI SYLLABLE LUOP",NULL},
/* A1C7 */ { "YI SYLLABLE LOT",NULL},
/* A1C8 */ { "YI SYLLABLE LOX",NULL},
/* A1C9 */ { "YI SYLLABLE LO",NULL},
/* A1CA */ { "YI SYLLABLE LOP",NULL},
/* A1CB */ { "YI SYLLABLE LEX",NULL},
/* A1CC */ { "YI SYLLABLE LE",NULL},
/* A1CD */ { "YI SYLLABLE LEP",NULL},
/* A1CE */ { "YI SYLLABLE LUT",NULL},
/* A1CF */ { "YI SYLLABLE LUX",NULL},
/* A1D0 */ { "YI SYLLABLE LU",NULL},
/* A1D1 */ { "YI SYLLABLE LUP",NULL},
/* A1D2 */ { "YI SYLLABLE LURX",NULL},
/* A1D3 */ { "YI SYLLABLE LUR",NULL},
/* A1D4 */ { "YI SYLLABLE LYT",NULL},
/* A1D5 */ { "YI SYLLABLE LYX",NULL},
/* A1D6 */ { "YI SYLLABLE LY",NULL},
/* A1D7 */ { "YI SYLLABLE LYP",NULL},
/* A1D8 */ { "YI SYLLABLE LYRX",NULL},
/* A1D9 */ { "YI SYLLABLE LYR",NULL},
/* A1DA */ { "YI SYLLABLE GIT",NULL},
/* A1DB */ { "YI SYLLABLE GIX",NULL},
/* A1DC */ { "YI SYLLABLE GI",NULL},
/* A1DD */ { "YI SYLLABLE GIP",NULL},
/* A1DE */ { "YI SYLLABLE GIET",NULL},
/* A1DF */ { "YI SYLLABLE GIEX",NULL},
/* A1E0 */ { "YI SYLLABLE GIE",NULL},
/* A1E1 */ { "YI SYLLABLE GIEP",NULL},
/* A1E2 */ { "YI SYLLABLE GAT",NULL},
/* A1E3 */ { "YI SYLLABLE GAX",NULL},
/* A1E4 */ { "YI SYLLABLE GA",NULL},
/* A1E5 */ { "YI SYLLABLE GAP",NULL},
/* A1E6 */ { "YI SYLLABLE GUOT",NULL},
/* A1E7 */ { "YI SYLLABLE GUOX",NULL},
/* A1E8 */ { "YI SYLLABLE GUO",NULL},
/* A1E9 */ { "YI SYLLABLE GUOP",NULL},
/* A1EA */ { "YI SYLLABLE GOT",NULL},
/* A1EB */ { "YI SYLLABLE GOX",NULL},
/* A1EC */ { "YI SYLLABLE GO",NULL},
/* A1ED */ { "YI SYLLABLE GOP",NULL},
/* A1EE */ { "YI SYLLABLE GET",NULL},
/* A1EF */ { "YI SYLLABLE GEX",NULL},
/* A1F0 */ { "YI SYLLABLE GE",NULL},
/* A1F1 */ { "YI SYLLABLE GEP",NULL},
/* A1F2 */ { "YI SYLLABLE GUT",NULL},
/* A1F3 */ { "YI SYLLABLE GUX",NULL},
/* A1F4 */ { "YI SYLLABLE GU",NULL},
/* A1F5 */ { "YI SYLLABLE GUP",NULL},
/* A1F6 */ { "YI SYLLABLE GURX",NULL},
/* A1F7 */ { "YI SYLLABLE GUR",NULL},
/* A1F8 */ { "YI SYLLABLE KIT",NULL},
/* A1F9 */ { "YI SYLLABLE KIX",NULL},
/* A1FA */ { "YI SYLLABLE KI",NULL},
/* A1FB */ { "YI SYLLABLE KIP",NULL},
/* A1FC */ { "YI SYLLABLE KIEX",NULL},
/* A1FD */ { "YI SYLLABLE KIE",NULL},
/* A1FE */ { "YI SYLLABLE KIEP",NULL},
/* A1FF */ { "YI SYLLABLE KAT",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_00_A2[] = {
/* A200 */ { "YI SYLLABLE KAX",NULL},
/* A201 */ { "YI SYLLABLE KA",NULL},
/* A202 */ { "YI SYLLABLE KAP",NULL},
/* A203 */ { "YI SYLLABLE KUOX",NULL},
/* A204 */ { "YI SYLLABLE KUO",NULL},
/* A205 */ { "YI SYLLABLE KUOP",NULL},
/* A206 */ { "YI SYLLABLE KOT",NULL},
/* A207 */ { "YI SYLLABLE KOX",NULL},
/* A208 */ { "YI SYLLABLE KO",NULL},
/* A209 */ { "YI SYLLABLE KOP",NULL},
/* A20A */ { "YI SYLLABLE KET",NULL},
/* A20B */ { "YI SYLLABLE KEX",NULL},
/* A20C */ { "YI SYLLABLE KE",NULL},
/* A20D */ { "YI SYLLABLE KEP",NULL},
/* A20E */ { "YI SYLLABLE KUT",NULL},
/* A20F */ { "YI SYLLABLE KUX",NULL},
/* A210 */ { "YI SYLLABLE KU",NULL},
/* A211 */ { "YI SYLLABLE KUP",NULL},
/* A212 */ { "YI SYLLABLE KURX",NULL},
/* A213 */ { "YI SYLLABLE KUR",NULL},
/* A214 */ { "YI SYLLABLE GGIT",NULL},
/* A215 */ { "YI SYLLABLE GGIX",NULL},
/* A216 */ { "YI SYLLABLE GGI",NULL},
/* A217 */ { "YI SYLLABLE GGIEX",NULL},
/* A218 */ { "YI SYLLABLE GGIE",NULL},
/* A219 */ { "YI SYLLABLE GGIEP",NULL},
/* A21A */ { "YI SYLLABLE GGAT",NULL},
/* A21B */ { "YI SYLLABLE GGAX",NULL},
/* A21C */ { "YI SYLLABLE GGA",NULL},
/* A21D */ { "YI SYLLABLE GGAP",NULL},
/* A21E */ { "YI SYLLABLE GGUOT",NULL},
/* A21F */ { "YI SYLLABLE GGUOX",NULL},
/* A220 */ { "YI SYLLABLE GGUO",NULL},
/* A221 */ { "YI SYLLABLE GGUOP",NULL},
/* A222 */ { "YI SYLLABLE GGOT",NULL},
/* A223 */ { "YI SYLLABLE GGOX",NULL},
/* A224 */ { "YI SYLLABLE GGO",NULL},
/* A225 */ { "YI SYLLABLE GGOP",NULL},
/* A226 */ { "YI SYLLABLE GGET",NULL},
/* A227 */ { "YI SYLLABLE GGEX",NULL},
/* A228 */ { "YI SYLLABLE GGE",NULL},
/* A229 */ { "YI SYLLABLE GGEP",NULL},
/* A22A */ { "YI SYLLABLE GGUT",NULL},
/* A22B */ { "YI SYLLABLE GGUX",NULL},
/* A22C */ { "YI SYLLABLE GGU",NULL},
/* A22D */ { "YI SYLLABLE GGUP",NULL},
/* A22E */ { "YI SYLLABLE GGURX",NULL},
/* A22F */ { "YI SYLLABLE GGUR",NULL},
/* A230 */ { "YI SYLLABLE MGIEX",NULL},
/* A231 */ { "YI SYLLABLE MGIE",NULL},
/* A232 */ { "YI SYLLABLE MGAT",NULL},
/* A233 */ { "YI SYLLABLE MGAX",NULL},
/* A234 */ { "YI SYLLABLE MGA",NULL},
/* A235 */ { "YI SYLLABLE MGAP",NULL},
/* A236 */ { "YI SYLLABLE MGUOX",NULL},
/* A237 */ { "YI SYLLABLE MGUO",NULL},
/* A238 */ { "YI SYLLABLE MGUOP",NULL},
/* A239 */ { "YI SYLLABLE MGOT",NULL},
/* A23A */ { "YI SYLLABLE MGOX",NULL},
/* A23B */ { "YI SYLLABLE MGO",NULL},
/* A23C */ { "YI SYLLABLE MGOP",NULL},
/* A23D */ { "YI SYLLABLE MGEX",NULL},
/* A23E */ { "YI SYLLABLE MGE",NULL},
/* A23F */ { "YI SYLLABLE MGEP",NULL},
/* A240 */ { "YI SYLLABLE MGUT",NULL},
/* A241 */ { "YI SYLLABLE MGUX",NULL},
/* A242 */ { "YI SYLLABLE MGU",NULL},
/* A243 */ { "YI SYLLABLE MGUP",NULL},
/* A244 */ { "YI SYLLABLE MGURX",NULL},
/* A245 */ { "YI SYLLABLE MGUR",NULL},
/* A246 */ { "YI SYLLABLE HXIT",NULL},
/* A247 */ { "YI SYLLABLE HXIX",NULL},
/* A248 */ { "YI SYLLABLE HXI",NULL},
/* A249 */ { "YI SYLLABLE HXIP",NULL},
/* A24A */ { "YI SYLLABLE HXIET",NULL},
/* A24B */ { "YI SYLLABLE HXIEX",NULL},
/* A24C */ { "YI SYLLABLE HXIE",NULL},
/* A24D */ { "YI SYLLABLE HXIEP",NULL},
/* A24E */ { "YI SYLLABLE HXAT",NULL},
/* A24F */ { "YI SYLLABLE HXAX",NULL},
/* A250 */ { "YI SYLLABLE HXA",NULL},
/* A251 */ { "YI SYLLABLE HXAP",NULL},
/* A252 */ { "YI SYLLABLE HXUOT",NULL},
/* A253 */ { "YI SYLLABLE HXUOX",NULL},
/* A254 */ { "YI SYLLABLE HXUO",NULL},
/* A255 */ { "YI SYLLABLE HXUOP",NULL},
/* A256 */ { "YI SYLLABLE HXOT",NULL},
/* A257 */ { "YI SYLLABLE HXOX",NULL},
/* A258 */ { "YI SYLLABLE HXO",NULL},
/* A259 */ { "YI SYLLABLE HXOP",NULL},
/* A25A */ { "YI SYLLABLE HXEX",NULL},
/* A25B */ { "YI SYLLABLE HXE",NULL},
/* A25C */ { "YI SYLLABLE HXEP",NULL},
/* A25D */ { "YI SYLLABLE NGIEX",NULL},
/* A25E */ { "YI SYLLABLE NGIE",NULL},
/* A25F */ { "YI SYLLABLE NGIEP",NULL},
/* A260 */ { "YI SYLLABLE NGAT",NULL},
/* A261 */ { "YI SYLLABLE NGAX",NULL},
/* A262 */ { "YI SYLLABLE NGA",NULL},
/* A263 */ { "YI SYLLABLE NGAP",NULL},
/* A264 */ { "YI SYLLABLE NGUOT",NULL},
/* A265 */ { "YI SYLLABLE NGUOX",NULL},
/* A266 */ { "YI SYLLABLE NGUO",NULL},
/* A267 */ { "YI SYLLABLE NGOT",NULL},
/* A268 */ { "YI SYLLABLE NGOX",NULL},
/* A269 */ { "YI SYLLABLE NGO",NULL},
/* A26A */ { "YI SYLLABLE NGOP",NULL},
/* A26B */ { "YI SYLLABLE NGEX",NULL},
/* A26C */ { "YI SYLLABLE NGE",NULL},
/* A26D */ { "YI SYLLABLE NGEP",NULL},
/* A26E */ { "YI SYLLABLE HIT",NULL},
/* A26F */ { "YI SYLLABLE HIEX",NULL},
/* A270 */ { "YI SYLLABLE HIE",NULL},
/* A271 */ { "YI SYLLABLE HAT",NULL},
/* A272 */ { "YI SYLLABLE HAX",NULL},
/* A273 */ { "YI SYLLABLE HA",NULL},
/* A274 */ { "YI SYLLABLE HAP",NULL},
/* A275 */ { "YI SYLLABLE HUOT",NULL},
/* A276 */ { "YI SYLLABLE HUOX",NULL},
/* A277 */ { "YI SYLLABLE HUO",NULL},
/* A278 */ { "YI SYLLABLE HUOP",NULL},
/* A279 */ { "YI SYLLABLE HOT",NULL},
/* A27A */ { "YI SYLLABLE HOX",NULL},
/* A27B */ { "YI SYLLABLE HO",NULL},
/* A27C */ { "YI SYLLABLE HOP",NULL},
/* A27D */ { "YI SYLLABLE HEX",NULL},
/* A27E */ { "YI SYLLABLE HE",NULL},
/* A27F */ { "YI SYLLABLE HEP",NULL},
/* A280 */ { "YI SYLLABLE WAT",NULL},
/* A281 */ { "YI SYLLABLE WAX",NULL},
/* A282 */ { "YI SYLLABLE WA",NULL},
/* A283 */ { "YI SYLLABLE WAP",NULL},
/* A284 */ { "YI SYLLABLE WUOX",NULL},
/* A285 */ { "YI SYLLABLE WUO",NULL},
/* A286 */ { "YI SYLLABLE WUOP",NULL},
/* A287 */ { "YI SYLLABLE WOX",NULL},
/* A288 */ { "YI SYLLABLE WO",NULL},
/* A289 */ { "YI SYLLABLE WOP",NULL},
/* A28A */ { "YI SYLLABLE WEX",NULL},
/* A28B */ { "YI SYLLABLE WE",NULL},
/* A28C */ { "YI SYLLABLE WEP",NULL},
/* A28D */ { "YI SYLLABLE ZIT",NULL},
/* A28E */ { "YI SYLLABLE ZIX",NULL},
/* A28F */ { "YI SYLLABLE ZI",NULL},
/* A290 */ { "YI SYLLABLE ZIP",NULL},
/* A291 */ { "YI SYLLABLE ZIEX",NULL},
/* A292 */ { "YI SYLLABLE ZIE",NULL},
/* A293 */ { "YI SYLLABLE ZIEP",NULL},
/* A294 */ { "YI SYLLABLE ZAT",NULL},
/* A295 */ { "YI SYLLABLE ZAX",NULL},
/* A296 */ { "YI SYLLABLE ZA",NULL},
/* A297 */ { "YI SYLLABLE ZAP",NULL},
/* A298 */ { "YI SYLLABLE ZUOX",NULL},
/* A299 */ { "YI SYLLABLE ZUO",NULL},
/* A29A */ { "YI SYLLABLE ZUOP",NULL},
/* A29B */ { "YI SYLLABLE ZOT",NULL},
/* A29C */ { "YI SYLLABLE ZOX",NULL},
/* A29D */ { "YI SYLLABLE ZO",NULL},
/* A29E */ { "YI SYLLABLE ZOP",NULL},
/* A29F */ { "YI SYLLABLE ZEX",NULL},
/* A2A0 */ { "YI SYLLABLE ZE",NULL},
/* A2A1 */ { "YI SYLLABLE ZEP",NULL},
/* A2A2 */ { "YI SYLLABLE ZUT",NULL},
/* A2A3 */ { "YI SYLLABLE ZUX",NULL},
/* A2A4 */ { "YI SYLLABLE ZU",NULL},
/* A2A5 */ { "YI SYLLABLE ZUP",NULL},
/* A2A6 */ { "YI SYLLABLE ZURX",NULL},
/* A2A7 */ { "YI SYLLABLE ZUR",NULL},
/* A2A8 */ { "YI SYLLABLE ZYT",NULL},
/* A2A9 */ { "YI SYLLABLE ZYX",NULL},
/* A2AA */ { "YI SYLLABLE ZY",NULL},
/* A2AB */ { "YI SYLLABLE ZYP",NULL},
/* A2AC */ { "YI SYLLABLE ZYRX",NULL},
/* A2AD */ { "YI SYLLABLE ZYR",NULL},
/* A2AE */ { "YI SYLLABLE CIT",NULL},
/* A2AF */ { "YI SYLLABLE CIX",NULL},
/* A2B0 */ { "YI SYLLABLE CI",NULL},
/* A2B1 */ { "YI SYLLABLE CIP",NULL},
/* A2B2 */ { "YI SYLLABLE CIET",NULL},
/* A2B3 */ { "YI SYLLABLE CIEX",NULL},
/* A2B4 */ { "YI SYLLABLE CIE",NULL},
/* A2B5 */ { "YI SYLLABLE CIEP",NULL},
/* A2B6 */ { "YI SYLLABLE CAT",NULL},
/* A2B7 */ { "YI SYLLABLE CAX",NULL},
/* A2B8 */ { "YI SYLLABLE CA",NULL},
/* A2B9 */ { "YI SYLLABLE CAP",NULL},
/* A2BA */ { "YI SYLLABLE CUOX",NULL},
/* A2BB */ { "YI SYLLABLE CUO",NULL},
/* A2BC */ { "YI SYLLABLE CUOP",NULL},
/* A2BD */ { "YI SYLLABLE COT",NULL},
/* A2BE */ { "YI SYLLABLE COX",NULL},
/* A2BF */ { "YI SYLLABLE CO",NULL},
/* A2C0 */ { "YI SYLLABLE COP",NULL},
/* A2C1 */ { "YI SYLLABLE CEX",NULL},
/* A2C2 */ { "YI SYLLABLE CE",NULL},
/* A2C3 */ { "YI SYLLABLE CEP",NULL},
/* A2C4 */ { "YI SYLLABLE CUT",NULL},
/* A2C5 */ { "YI SYLLABLE CUX",NULL},
/* A2C6 */ { "YI SYLLABLE CU",NULL},
/* A2C7 */ { "YI SYLLABLE CUP",NULL},
/* A2C8 */ { "YI SYLLABLE CURX",NULL},
/* A2C9 */ { "YI SYLLABLE CUR",NULL},
/* A2CA */ { "YI SYLLABLE CYT",NULL},
/* A2CB */ { "YI SYLLABLE CYX",NULL},
/* A2CC */ { "YI SYLLABLE CY",NULL},
/* A2CD */ { "YI SYLLABLE CYP",NULL},
/* A2CE */ { "YI SYLLABLE CYRX",NULL},
/* A2CF */ { "YI SYLLABLE CYR",NULL},
/* A2D0 */ { "YI SYLLABLE ZZIT",NULL},
/* A2D1 */ { "YI SYLLABLE ZZIX",NULL},
/* A2D2 */ { "YI SYLLABLE ZZI",NULL},
/* A2D3 */ { "YI SYLLABLE ZZIP",NULL},
/* A2D4 */ { "YI SYLLABLE ZZIET",NULL},
/* A2D5 */ { "YI SYLLABLE ZZIEX",NULL},
/* A2D6 */ { "YI SYLLABLE ZZIE",NULL},
/* A2D7 */ { "YI SYLLABLE ZZIEP",NULL},
/* A2D8 */ { "YI SYLLABLE ZZAT",NULL},
/* A2D9 */ { "YI SYLLABLE ZZAX",NULL},
/* A2DA */ { "YI SYLLABLE ZZA",NULL},
/* A2DB */ { "YI SYLLABLE ZZAP",NULL},
/* A2DC */ { "YI SYLLABLE ZZOX",NULL},
/* A2DD */ { "YI SYLLABLE ZZO",NULL},
/* A2DE */ { "YI SYLLABLE ZZOP",NULL},
/* A2DF */ { "YI SYLLABLE ZZEX",NULL},
/* A2E0 */ { "YI SYLLABLE ZZE",NULL},
/* A2E1 */ { "YI SYLLABLE ZZEP",NULL},
/* A2E2 */ { "YI SYLLABLE ZZUX",NULL},
/* A2E3 */ { "YI SYLLABLE ZZU",NULL},
/* A2E4 */ { "YI SYLLABLE ZZUP",NULL},
/* A2E5 */ { "YI SYLLABLE ZZURX",NULL},
/* A2E6 */ { "YI SYLLABLE ZZUR",NULL},
/* A2E7 */ { "YI SYLLABLE ZZYT",NULL},
/* A2E8 */ { "YI SYLLABLE ZZYX",NULL},
/* A2E9 */ { "YI SYLLABLE ZZY",NULL},
/* A2EA */ { "YI SYLLABLE ZZYP",NULL},
/* A2EB */ { "YI SYLLABLE ZZYRX",NULL},
/* A2EC */ { "YI SYLLABLE ZZYR",NULL},
/* A2ED */ { "YI SYLLABLE NZIT",NULL},
/* A2EE */ { "YI SYLLABLE NZIX",NULL},
/* A2EF */ { "YI SYLLABLE NZI",NULL},
/* A2F0 */ { "YI SYLLABLE NZIP",NULL},
/* A2F1 */ { "YI SYLLABLE NZIEX",NULL},
/* A2F2 */ { "YI SYLLABLE NZIE",NULL},
/* A2F3 */ { "YI SYLLABLE NZIEP",NULL},
/* A2F4 */ { "YI SYLLABLE NZAT",NULL},
/* A2F5 */ { "YI SYLLABLE NZAX",NULL},
/* A2F6 */ { "YI SYLLABLE NZA",NULL},
/* A2F7 */ { "YI SYLLABLE NZAP",NULL},
/* A2F8 */ { "YI SYLLABLE NZUOX",NULL},
/* A2F9 */ { "YI SYLLABLE NZUO",NULL},
/* A2FA */ { "YI SYLLABLE NZOX",NULL},
/* A2FB */ { "YI SYLLABLE NZOP",NULL},
/* A2FC */ { "YI SYLLABLE NZEX",NULL},
/* A2FD */ { "YI SYLLABLE NZE",NULL},
/* A2FE */ { "YI SYLLABLE NZUX",NULL},
/* A2FF */ { "YI SYLLABLE NZU",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_00_A3[] = {
/* A300 */ { "YI SYLLABLE NZUP",NULL},
/* A301 */ { "YI SYLLABLE NZURX",NULL},
/* A302 */ { "YI SYLLABLE NZUR",NULL},
/* A303 */ { "YI SYLLABLE NZYT",NULL},
/* A304 */ { "YI SYLLABLE NZYX",NULL},
/* A305 */ { "YI SYLLABLE NZY",NULL},
/* A306 */ { "YI SYLLABLE NZYP",NULL},
/* A307 */ { "YI SYLLABLE NZYRX",NULL},
/* A308 */ { "YI SYLLABLE NZYR",NULL},
/* A309 */ { "YI SYLLABLE SIT",NULL},
/* A30A */ { "YI SYLLABLE SIX",NULL},
/* A30B */ { "YI SYLLABLE SI",NULL},
/* A30C */ { "YI SYLLABLE SIP",NULL},
/* A30D */ { "YI SYLLABLE SIEX",NULL},
/* A30E */ { "YI SYLLABLE SIE",NULL},
/* A30F */ { "YI SYLLABLE SIEP",NULL},
/* A310 */ { "YI SYLLABLE SAT",NULL},
/* A311 */ { "YI SYLLABLE SAX",NULL},
/* A312 */ { "YI SYLLABLE SA",NULL},
/* A313 */ { "YI SYLLABLE SAP",NULL},
/* A314 */ { "YI SYLLABLE SUOX",NULL},
/* A315 */ { "YI SYLLABLE SUO",NULL},
/* A316 */ { "YI SYLLABLE SUOP",NULL},
/* A317 */ { "YI SYLLABLE SOT",NULL},
/* A318 */ { "YI SYLLABLE SOX",NULL},
/* A319 */ { "YI SYLLABLE SO",NULL},
/* A31A */ { "YI SYLLABLE SOP",NULL},
/* A31B */ { "YI SYLLABLE SEX",NULL},
/* A31C */ { "YI SYLLABLE SE",NULL},
/* A31D */ { "YI SYLLABLE SEP",NULL},
/* A31E */ { "YI SYLLABLE SUT",NULL},
/* A31F */ { "YI SYLLABLE SUX",NULL},
/* A320 */ { "YI SYLLABLE SU",NULL},
/* A321 */ { "YI SYLLABLE SUP",NULL},
/* A322 */ { "YI SYLLABLE SURX",NULL},
/* A323 */ { "YI SYLLABLE SUR",NULL},
/* A324 */ { "YI SYLLABLE SYT",NULL},
/* A325 */ { "YI SYLLABLE SYX",NULL},
/* A326 */ { "YI SYLLABLE SY",NULL},
/* A327 */ { "YI SYLLABLE SYP",NULL},
/* A328 */ { "YI SYLLABLE SYRX",NULL},
/* A329 */ { "YI SYLLABLE SYR",NULL},
/* A32A */ { "YI SYLLABLE SSIT",NULL},
/* A32B */ { "YI SYLLABLE SSIX",NULL},
/* A32C */ { "YI SYLLABLE SSI",NULL},
/* A32D */ { "YI SYLLABLE SSIP",NULL},
/* A32E */ { "YI SYLLABLE SSIEX",NULL},
/* A32F */ { "YI SYLLABLE SSIE",NULL},
/* A330 */ { "YI SYLLABLE SSIEP",NULL},
/* A331 */ { "YI SYLLABLE SSAT",NULL},
/* A332 */ { "YI SYLLABLE SSAX",NULL},
/* A333 */ { "YI SYLLABLE SSA",NULL},
/* A334 */ { "YI SYLLABLE SSAP",NULL},
/* A335 */ { "YI SYLLABLE SSOT",NULL},
/* A336 */ { "YI SYLLABLE SSOX",NULL},
/* A337 */ { "YI SYLLABLE SSO",NULL},
/* A338 */ { "YI SYLLABLE SSOP",NULL},
/* A339 */ { "YI SYLLABLE SSEX",NULL},
/* A33A */ { "YI SYLLABLE SSE",NULL},
/* A33B */ { "YI SYLLABLE SSEP",NULL},
/* A33C */ { "YI SYLLABLE SSUT",NULL},
/* A33D */ { "YI SYLLABLE SSUX",NULL},
/* A33E */ { "YI SYLLABLE SSU",NULL},
/* A33F */ { "YI SYLLABLE SSUP",NULL},
/* A340 */ { "YI SYLLABLE SSYT",NULL},
/* A341 */ { "YI SYLLABLE SSYX",NULL},
/* A342 */ { "YI SYLLABLE SSY",NULL},
/* A343 */ { "YI SYLLABLE SSYP",NULL},
/* A344 */ { "YI SYLLABLE SSYRX",NULL},
/* A345 */ { "YI SYLLABLE SSYR",NULL},
/* A346 */ { "YI SYLLABLE ZHAT",NULL},
/* A347 */ { "YI SYLLABLE ZHAX",NULL},
/* A348 */ { "YI SYLLABLE ZHA",NULL},
/* A349 */ { "YI SYLLABLE ZHAP",NULL},
/* A34A */ { "YI SYLLABLE ZHUOX",NULL},
/* A34B */ { "YI SYLLABLE ZHUO",NULL},
/* A34C */ { "YI SYLLABLE ZHUOP",NULL},
/* A34D */ { "YI SYLLABLE ZHOT",NULL},
/* A34E */ { "YI SYLLABLE ZHOX",NULL},
/* A34F */ { "YI SYLLABLE ZHO",NULL},
/* A350 */ { "YI SYLLABLE ZHOP",NULL},
/* A351 */ { "YI SYLLABLE ZHET",NULL},
/* A352 */ { "YI SYLLABLE ZHEX",NULL},
/* A353 */ { "YI SYLLABLE ZHE",NULL},
/* A354 */ { "YI SYLLABLE ZHEP",NULL},
/* A355 */ { "YI SYLLABLE ZHUT",NULL},
/* A356 */ { "YI SYLLABLE ZHUX",NULL},
/* A357 */ { "YI SYLLABLE ZHU",NULL},
/* A358 */ { "YI SYLLABLE ZHUP",NULL},
/* A359 */ { "YI SYLLABLE ZHURX",NULL},
/* A35A */ { "YI SYLLABLE ZHUR",NULL},
/* A35B */ { "YI SYLLABLE ZHYT",NULL},
/* A35C */ { "YI SYLLABLE ZHYX",NULL},
/* A35D */ { "YI SYLLABLE ZHY",NULL},
/* A35E */ { "YI SYLLABLE ZHYP",NULL},
/* A35F */ { "YI SYLLABLE ZHYRX",NULL},
/* A360 */ { "YI SYLLABLE ZHYR",NULL},
/* A361 */ { "YI SYLLABLE CHAT",NULL},
/* A362 */ { "YI SYLLABLE CHAX",NULL},
/* A363 */ { "YI SYLLABLE CHA",NULL},
/* A364 */ { "YI SYLLABLE CHAP",NULL},
/* A365 */ { "YI SYLLABLE CHUOT",NULL},
/* A366 */ { "YI SYLLABLE CHUOX",NULL},
/* A367 */ { "YI SYLLABLE CHUO",NULL},
/* A368 */ { "YI SYLLABLE CHUOP",NULL},
/* A369 */ { "YI SYLLABLE CHOT",NULL},
/* A36A */ { "YI SYLLABLE CHOX",NULL},
/* A36B */ { "YI SYLLABLE CHO",NULL},
/* A36C */ { "YI SYLLABLE CHOP",NULL},
/* A36D */ { "YI SYLLABLE CHET",NULL},
/* A36E */ { "YI SYLLABLE CHEX",NULL},
/* A36F */ { "YI SYLLABLE CHE",NULL},
/* A370 */ { "YI SYLLABLE CHEP",NULL},
/* A371 */ { "YI SYLLABLE CHUX",NULL},
/* A372 */ { "YI SYLLABLE CHU",NULL},
/* A373 */ { "YI SYLLABLE CHUP",NULL},
/* A374 */ { "YI SYLLABLE CHURX",NULL},
/* A375 */ { "YI SYLLABLE CHUR",NULL},
/* A376 */ { "YI SYLLABLE CHYT",NULL},
/* A377 */ { "YI SYLLABLE CHYX",NULL},
/* A378 */ { "YI SYLLABLE CHY",NULL},
/* A379 */ { "YI SYLLABLE CHYP",NULL},
/* A37A */ { "YI SYLLABLE CHYRX",NULL},
/* A37B */ { "YI SYLLABLE CHYR",NULL},
/* A37C */ { "YI SYLLABLE RRAX",NULL},
/* A37D */ { "YI SYLLABLE RRA",NULL},
/* A37E */ { "YI SYLLABLE RRUOX",NULL},
/* A37F */ { "YI SYLLABLE RRUO",NULL},
/* A380 */ { "YI SYLLABLE RROT",NULL},
/* A381 */ { "YI SYLLABLE RROX",NULL},
/* A382 */ { "YI SYLLABLE RRO",NULL},
/* A383 */ { "YI SYLLABLE RROP",NULL},
/* A384 */ { "YI SYLLABLE RRET",NULL},
/* A385 */ { "YI SYLLABLE RREX",NULL},
/* A386 */ { "YI SYLLABLE RRE",NULL},
/* A387 */ { "YI SYLLABLE RREP",NULL},
/* A388 */ { "YI SYLLABLE RRUT",NULL},
/* A389 */ { "YI SYLLABLE RRUX",NULL},
/* A38A */ { "YI SYLLABLE RRU",NULL},
/* A38B */ { "YI SYLLABLE RRUP",NULL},
/* A38C */ { "YI SYLLABLE RRURX",NULL},
/* A38D */ { "YI SYLLABLE RRUR",NULL},
/* A38E */ { "YI SYLLABLE RRYT",NULL},
/* A38F */ { "YI SYLLABLE RRYX",NULL},
/* A390 */ { "YI SYLLABLE RRY",NULL},
/* A391 */ { "YI SYLLABLE RRYP",NULL},
/* A392 */ { "YI SYLLABLE RRYRX",NULL},
/* A393 */ { "YI SYLLABLE RRYR",NULL},
/* A394 */ { "YI SYLLABLE NRAT",NULL},
/* A395 */ { "YI SYLLABLE NRAX",NULL},
/* A396 */ { "YI SYLLABLE NRA",NULL},
/* A397 */ { "YI SYLLABLE NRAP",NULL},
/* A398 */ { "YI SYLLABLE NROX",NULL},
/* A399 */ { "YI SYLLABLE NRO",NULL},
/* A39A */ { "YI SYLLABLE NROP",NULL},
/* A39B */ { "YI SYLLABLE NRET",NULL},
/* A39C */ { "YI SYLLABLE NREX",NULL},
/* A39D */ { "YI SYLLABLE NRE",NULL},
/* A39E */ { "YI SYLLABLE NREP",NULL},
/* A39F */ { "YI SYLLABLE NRUT",NULL},
/* A3A0 */ { "YI SYLLABLE NRUX",NULL},
/* A3A1 */ { "YI SYLLABLE NRU",NULL},
/* A3A2 */ { "YI SYLLABLE NRUP",NULL},
/* A3A3 */ { "YI SYLLABLE NRURX",NULL},
/* A3A4 */ { "YI SYLLABLE NRUR",NULL},
/* A3A5 */ { "YI SYLLABLE NRYT",NULL},
/* A3A6 */ { "YI SYLLABLE NRYX",NULL},
/* A3A7 */ { "YI SYLLABLE NRY",NULL},
/* A3A8 */ { "YI SYLLABLE NRYP",NULL},
/* A3A9 */ { "YI SYLLABLE NRYRX",NULL},
/* A3AA */ { "YI SYLLABLE NRYR",NULL},
/* A3AB */ { "YI SYLLABLE SHAT",NULL},
/* A3AC */ { "YI SYLLABLE SHAX",NULL},
/* A3AD */ { "YI SYLLABLE SHA",NULL},
/* A3AE */ { "YI SYLLABLE SHAP",NULL},
/* A3AF */ { "YI SYLLABLE SHUOX",NULL},
/* A3B0 */ { "YI SYLLABLE SHUO",NULL},
/* A3B1 */ { "YI SYLLABLE SHUOP",NULL},
/* A3B2 */ { "YI SYLLABLE SHOT",NULL},
/* A3B3 */ { "YI SYLLABLE SHOX",NULL},
/* A3B4 */ { "YI SYLLABLE SHO",NULL},
/* A3B5 */ { "YI SYLLABLE SHOP",NULL},
/* A3B6 */ { "YI SYLLABLE SHET",NULL},
/* A3B7 */ { "YI SYLLABLE SHEX",NULL},
/* A3B8 */ { "YI SYLLABLE SHE",NULL},
/* A3B9 */ { "YI SYLLABLE SHEP",NULL},
/* A3BA */ { "YI SYLLABLE SHUT",NULL},
/* A3BB */ { "YI SYLLABLE SHUX",NULL},
/* A3BC */ { "YI SYLLABLE SHU",NULL},
/* A3BD */ { "YI SYLLABLE SHUP",NULL},
/* A3BE */ { "YI SYLLABLE SHURX",NULL},
/* A3BF */ { "YI SYLLABLE SHUR",NULL},
/* A3C0 */ { "YI SYLLABLE SHYT",NULL},
/* A3C1 */ { "YI SYLLABLE SHYX",NULL},
/* A3C2 */ { "YI SYLLABLE SHY",NULL},
/* A3C3 */ { "YI SYLLABLE SHYP",NULL},
/* A3C4 */ { "YI SYLLABLE SHYRX",NULL},
/* A3C5 */ { "YI SYLLABLE SHYR",NULL},
/* A3C6 */ { "YI SYLLABLE RAT",NULL},
/* A3C7 */ { "YI SYLLABLE RAX",NULL},
/* A3C8 */ { "YI SYLLABLE RA",NULL},
/* A3C9 */ { "YI SYLLABLE RAP",NULL},
/* A3CA */ { "YI SYLLABLE RUOX",NULL},
/* A3CB */ { "YI SYLLABLE RUO",NULL},
/* A3CC */ { "YI SYLLABLE RUOP",NULL},
/* A3CD */ { "YI SYLLABLE ROT",NULL},
/* A3CE */ { "YI SYLLABLE ROX",NULL},
/* A3CF */ { "YI SYLLABLE RO",NULL},
/* A3D0 */ { "YI SYLLABLE ROP",NULL},
/* A3D1 */ { "YI SYLLABLE REX",NULL},
/* A3D2 */ { "YI SYLLABLE RE",NULL},
/* A3D3 */ { "YI SYLLABLE REP",NULL},
/* A3D4 */ { "YI SYLLABLE RUT",NULL},
/* A3D5 */ { "YI SYLLABLE RUX",NULL},
/* A3D6 */ { "YI SYLLABLE RU",NULL},
/* A3D7 */ { "YI SYLLABLE RUP",NULL},
/* A3D8 */ { "YI SYLLABLE RURX",NULL},
/* A3D9 */ { "YI SYLLABLE RUR",NULL},
/* A3DA */ { "YI SYLLABLE RYT",NULL},
/* A3DB */ { "YI SYLLABLE RYX",NULL},
/* A3DC */ { "YI SYLLABLE RY",NULL},
/* A3DD */ { "YI SYLLABLE RYP",NULL},
/* A3DE */ { "YI SYLLABLE RYRX",NULL},
/* A3DF */ { "YI SYLLABLE RYR",NULL},
/* A3E0 */ { "YI SYLLABLE JIT",NULL},
/* A3E1 */ { "YI SYLLABLE JIX",NULL},
/* A3E2 */ { "YI SYLLABLE JI",NULL},
/* A3E3 */ { "YI SYLLABLE JIP",NULL},
/* A3E4 */ { "YI SYLLABLE JIET",NULL},
/* A3E5 */ { "YI SYLLABLE JIEX",NULL},
/* A3E6 */ { "YI SYLLABLE JIE",NULL},
/* A3E7 */ { "YI SYLLABLE JIEP",NULL},
/* A3E8 */ { "YI SYLLABLE JUOT",NULL},
/* A3E9 */ { "YI SYLLABLE JUOX",NULL},
/* A3EA */ { "YI SYLLABLE JUO",NULL},
/* A3EB */ { "YI SYLLABLE JUOP",NULL},
/* A3EC */ { "YI SYLLABLE JOT",NULL},
/* A3ED */ { "YI SYLLABLE JOX",NULL},
/* A3EE */ { "YI SYLLABLE JO",NULL},
/* A3EF */ { "YI SYLLABLE JOP",NULL},
/* A3F0 */ { "YI SYLLABLE JUT",NULL},
/* A3F1 */ { "YI SYLLABLE JUX",NULL},
/* A3F2 */ { "YI SYLLABLE JU",NULL},
/* A3F3 */ { "YI SYLLABLE JUP",NULL},
/* A3F4 */ { "YI SYLLABLE JURX",NULL},
/* A3F5 */ { "YI SYLLABLE JUR",NULL},
/* A3F6 */ { "YI SYLLABLE JYT",NULL},
/* A3F7 */ { "YI SYLLABLE JYX",NULL},
/* A3F8 */ { "YI SYLLABLE JY",NULL},
/* A3F9 */ { "YI SYLLABLE JYP",NULL},
/* A3FA */ { "YI SYLLABLE JYRX",NULL},
/* A3FB */ { "YI SYLLABLE JYR",NULL},
/* A3FC */ { "YI SYLLABLE QIT",NULL},
/* A3FD */ { "YI SYLLABLE QIX",NULL},
/* A3FE */ { "YI SYLLABLE QI",NULL},
/* A3FF */ { "YI SYLLABLE QIP",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_00_A4[] = {
/* A400 */ { "YI SYLLABLE QIET",NULL},
/* A401 */ { "YI SYLLABLE QIEX",NULL},
/* A402 */ { "YI SYLLABLE QIE",NULL},
/* A403 */ { "YI SYLLABLE QIEP",NULL},
/* A404 */ { "YI SYLLABLE QUOT",NULL},
/* A405 */ { "YI SYLLABLE QUOX",NULL},
/* A406 */ { "YI SYLLABLE QUO",NULL},
/* A407 */ { "YI SYLLABLE QUOP",NULL},
/* A408 */ { "YI SYLLABLE QOT",NULL},
/* A409 */ { "YI SYLLABLE QOX",NULL},
/* A40A */ { "YI SYLLABLE QO",NULL},
/* A40B */ { "YI SYLLABLE QOP",NULL},
/* A40C */ { "YI SYLLABLE QUT",NULL},
/* A40D */ { "YI SYLLABLE QUX",NULL},
/* A40E */ { "YI SYLLABLE QU",NULL},
/* A40F */ { "YI SYLLABLE QUP",NULL},
/* A410 */ { "YI SYLLABLE QURX",NULL},
/* A411 */ { "YI SYLLABLE QUR",NULL},
/* A412 */ { "YI SYLLABLE QYT",NULL},
/* A413 */ { "YI SYLLABLE QYX",NULL},
/* A414 */ { "YI SYLLABLE QY",NULL},
/* A415 */ { "YI SYLLABLE QYP",NULL},
/* A416 */ { "YI SYLLABLE QYRX",NULL},
/* A417 */ { "YI SYLLABLE QYR",NULL},
/* A418 */ { "YI SYLLABLE JJIT",NULL},
/* A419 */ { "YI SYLLABLE JJIX",NULL},
/* A41A */ { "YI SYLLABLE JJI",NULL},
/* A41B */ { "YI SYLLABLE JJIP",NULL},
/* A41C */ { "YI SYLLABLE JJIET",NULL},
/* A41D */ { "YI SYLLABLE JJIEX",NULL},
/* A41E */ { "YI SYLLABLE JJIE",NULL},
/* A41F */ { "YI SYLLABLE JJIEP",NULL},
/* A420 */ { "YI SYLLABLE JJUOX",NULL},
/* A421 */ { "YI SYLLABLE JJUO",NULL},
/* A422 */ { "YI SYLLABLE JJUOP",NULL},
/* A423 */ { "YI SYLLABLE JJOT",NULL},
/* A424 */ { "YI SYLLABLE JJOX",NULL},
/* A425 */ { "YI SYLLABLE JJO",NULL},
/* A426 */ { "YI SYLLABLE JJOP",NULL},
/* A427 */ { "YI SYLLABLE JJUT",NULL},
/* A428 */ { "YI SYLLABLE JJUX",NULL},
/* A429 */ { "YI SYLLABLE JJU",NULL},
/* A42A */ { "YI SYLLABLE JJUP",NULL},
/* A42B */ { "YI SYLLABLE JJURX",NULL},
/* A42C */ { "YI SYLLABLE JJUR",NULL},
/* A42D */ { "YI SYLLABLE JJYT",NULL},
/* A42E */ { "YI SYLLABLE JJYX",NULL},
/* A42F */ { "YI SYLLABLE JJY",NULL},
/* A430 */ { "YI SYLLABLE JJYP",NULL},
/* A431 */ { "YI SYLLABLE NJIT",NULL},
/* A432 */ { "YI SYLLABLE NJIX",NULL},
/* A433 */ { "YI SYLLABLE NJI",NULL},
/* A434 */ { "YI SYLLABLE NJIP",NULL},
/* A435 */ { "YI SYLLABLE NJIET",NULL},
/* A436 */ { "YI SYLLABLE NJIEX",NULL},
/* A437 */ { "YI SYLLABLE NJIE",NULL},
/* A438 */ { "YI SYLLABLE NJIEP",NULL},
/* A439 */ { "YI SYLLABLE NJUOX",NULL},
/* A43A */ { "YI SYLLABLE NJUO",NULL},
/* A43B */ { "YI SYLLABLE NJOT",NULL},
/* A43C */ { "YI SYLLABLE NJOX",NULL},
/* A43D */ { "YI SYLLABLE NJO",NULL},
/* A43E */ { "YI SYLLABLE NJOP",NULL},
/* A43F */ { "YI SYLLABLE NJUX",NULL},
/* A440 */ { "YI SYLLABLE NJU",NULL},
/* A441 */ { "YI SYLLABLE NJUP",NULL},
/* A442 */ { "YI SYLLABLE NJURX",NULL},
/* A443 */ { "YI SYLLABLE NJUR",NULL},
/* A444 */ { "YI SYLLABLE NJYT",NULL},
/* A445 */ { "YI SYLLABLE NJYX",NULL},
/* A446 */ { "YI SYLLABLE NJY",NULL},
/* A447 */ { "YI SYLLABLE NJYP",NULL},
/* A448 */ { "YI SYLLABLE NJYRX",NULL},
/* A449 */ { "YI SYLLABLE NJYR",NULL},
/* A44A */ { "YI SYLLABLE NYIT",NULL},
/* A44B */ { "YI SYLLABLE NYIX",NULL},
/* A44C */ { "YI SYLLABLE NYI",NULL},
/* A44D */ { "YI SYLLABLE NYIP",NULL},
/* A44E */ { "YI SYLLABLE NYIET",NULL},
/* A44F */ { "YI SYLLABLE NYIEX",NULL},
/* A450 */ { "YI SYLLABLE NYIE",NULL},
/* A451 */ { "YI SYLLABLE NYIEP",NULL},
/* A452 */ { "YI SYLLABLE NYUOX",NULL},
/* A453 */ { "YI SYLLABLE NYUO",NULL},
/* A454 */ { "YI SYLLABLE NYUOP",NULL},
/* A455 */ { "YI SYLLABLE NYOT",NULL},
/* A456 */ { "YI SYLLABLE NYOX",NULL},
/* A457 */ { "YI SYLLABLE NYO",NULL},
/* A458 */ { "YI SYLLABLE NYOP",NULL},
/* A459 */ { "YI SYLLABLE NYUT",NULL},
/* A45A */ { "YI SYLLABLE NYUX",NULL},
/* A45B */ { "YI SYLLABLE NYU",NULL},
/* A45C */ { "YI SYLLABLE NYUP",NULL},
/* A45D */ { "YI SYLLABLE XIT",NULL},
/* A45E */ { "YI SYLLABLE XIX",NULL},
/* A45F */ { "YI SYLLABLE XI",NULL},
/* A460 */ { "YI SYLLABLE XIP",NULL},
/* A461 */ { "YI SYLLABLE XIET",NULL},
/* A462 */ { "YI SYLLABLE XIEX",NULL},
/* A463 */ { "YI SYLLABLE XIE",NULL},
/* A464 */ { "YI SYLLABLE XIEP",NULL},
/* A465 */ { "YI SYLLABLE XUOX",NULL},
/* A466 */ { "YI SYLLABLE XUO",NULL},
/* A467 */ { "YI SYLLABLE XOT",NULL},
/* A468 */ { "YI SYLLABLE XOX",NULL},
/* A469 */ { "YI SYLLABLE XO",NULL},
/* A46A */ { "YI SYLLABLE XOP",NULL},
/* A46B */ { "YI SYLLABLE XYT",NULL},
/* A46C */ { "YI SYLLABLE XYX",NULL},
/* A46D */ { "YI SYLLABLE XY",NULL},
/* A46E */ { "YI SYLLABLE XYP",NULL},
/* A46F */ { "YI SYLLABLE XYRX",NULL},
/* A470 */ { "YI SYLLABLE XYR",NULL},
/* A471 */ { "YI SYLLABLE YIT",NULL},
/* A472 */ { "YI SYLLABLE YIX",NULL},
/* A473 */ { "YI SYLLABLE YI",NULL},
/* A474 */ { "YI SYLLABLE YIP",NULL},
/* A475 */ { "YI SYLLABLE YIET",NULL},
/* A476 */ { "YI SYLLABLE YIEX",NULL},
/* A477 */ { "YI SYLLABLE YIE",NULL},
/* A478 */ { "YI SYLLABLE YIEP",NULL},
/* A479 */ { "YI SYLLABLE YUOT",NULL},
/* A47A */ { "YI SYLLABLE YUOX",NULL},
/* A47B */ { "YI SYLLABLE YUO",NULL},
/* A47C */ { "YI SYLLABLE YUOP",NULL},
/* A47D */ { "YI SYLLABLE YOT",NULL},
/* A47E */ { "YI SYLLABLE YOX",NULL},
/* A47F */ { "YI SYLLABLE YO",NULL},
/* A480 */ { "YI SYLLABLE YOP",NULL},
/* A481 */ { "YI SYLLABLE YUT",NULL},
/* A482 */ { "YI SYLLABLE YUX",NULL},
/* A483 */ { "YI SYLLABLE YU",NULL},
/* A484 */ { "YI SYLLABLE YUP",NULL},
/* A485 */ { "YI SYLLABLE YURX",NULL},
/* A486 */ { "YI SYLLABLE YUR",NULL},
/* A487 */ { "YI SYLLABLE YYT",NULL},
/* A488 */ { "YI SYLLABLE YYX",NULL},
/* A489 */ { "YI SYLLABLE YY",NULL},
/* A48A */ { "YI SYLLABLE YYP",NULL},
/* A48B */ { "YI SYLLABLE YYRX",NULL},
/* A48C */ { "YI SYLLABLE YYR",NULL},
/* A48D */ { NULL,NULL},
/* A48E */ { NULL,NULL},
/* A48F */ { NULL,NULL},
/* A490 */ { "YI RADICAL QOT","	x (yi syllable qot - A408)"},
/* A491 */ { "YI RADICAL LI","	x (yi syllable li - A1B9)"},
/* A492 */ { "YI RADICAL KIT",NULL},
/* A493 */ { "YI RADICAL NYIP",NULL},
/* A494 */ { "YI RADICAL CYP",NULL},
/* A495 */ { "YI RADICAL SSI",NULL},
/* A496 */ { "YI RADICAL GGOP",NULL},
/* A497 */ { "YI RADICAL GEP",NULL},
/* A498 */ { "YI RADICAL MI",NULL},
/* A499 */ { "YI RADICAL HXIT",NULL},
/* A49A */ { "YI RADICAL LYR",NULL},
/* A49B */ { "YI RADICAL BBUT",NULL},
/* A49C */ { "YI RADICAL MOP",NULL},
/* A49D */ { "YI RADICAL YO",NULL},
/* A49E */ { "YI RADICAL PUT",NULL},
/* A49F */ { "YI RADICAL HXUO",NULL},
/* A4A0 */ { "YI RADICAL TAT",NULL},
/* A4A1 */ { "YI RADICAL GA",NULL},
/* A4A2 */ { "YI RADICAL ZUP",NULL},
/* A4A3 */ { "YI RADICAL CYT",NULL},
/* A4A4 */ { "YI RADICAL DDUR",NULL},
/* A4A5 */ { "YI RADICAL BUR",NULL},
/* A4A6 */ { "YI RADICAL GGUO",NULL},
/* A4A7 */ { "YI RADICAL NYOP",NULL},
/* A4A8 */ { "YI RADICAL TU",NULL},
/* A4A9 */ { "YI RADICAL OP",NULL},
/* A4AA */ { "YI RADICAL JJUT",NULL},
/* A4AB */ { "YI RADICAL ZOT",NULL},
/* A4AC */ { "YI RADICAL PYT",NULL},
/* A4AD */ { "YI RADICAL HMO",NULL},
/* A4AE */ { "YI RADICAL YIT",NULL},
/* A4AF */ { "YI RADICAL VUR",NULL},
/* A4B0 */ { "YI RADICAL SHY",NULL},
/* A4B1 */ { "YI RADICAL VEP",NULL},
/* A4B2 */ { "YI RADICAL ZA",NULL},
/* A4B3 */ { "YI RADICAL JO",NULL},
/* A4B4 */ { "YI RADICAL NZUP",NULL},
/* A4B5 */ { "YI RADICAL JJY",NULL},
/* A4B6 */ { "YI RADICAL GOT",NULL},
/* A4B7 */ { "YI RADICAL JJIE",NULL},
/* A4B8 */ { "YI RADICAL WO",NULL},
/* A4B9 */ { "YI RADICAL DU",NULL},
/* A4BA */ { "YI RADICAL SHUR",NULL},
/* A4BB */ { "YI RADICAL LIE",NULL},
/* A4BC */ { "YI RADICAL CY",NULL},
/* A4BD */ { "YI RADICAL CUOP",NULL},
/* A4BE */ { "YI RADICAL CIP",NULL},
/* A4BF */ { "YI RADICAL HXOP",NULL},
/* A4C0 */ { "YI RADICAL SHAT",NULL},
/* A4C1 */ { "YI RADICAL ZUR",NULL},
/* A4C2 */ { "YI RADICAL SHOP",NULL},
/* A4C3 */ { "YI RADICAL CHE",NULL},
/* A4C4 */ { "YI RADICAL ZZIET",NULL},
/* A4C5 */ { "YI RADICAL NBIE",NULL},
/* A4C6 */ { "YI RADICAL KE",NULL},
/* A4C7 */ { NULL,NULL},
/* A4C8 */ { NULL,NULL},
/* A4C9 */ { NULL,NULL},
/* A4CA */ { NULL,NULL},
/* A4CB */ { NULL,NULL},
/* A4CC */ { NULL,NULL},
/* A4CD */ { NULL,NULL},
/* A4CE */ { NULL,NULL},
/* A4CF */ { NULL,NULL},
/* A4D0 */ { "LISU LETTER BA",NULL},
/* A4D1 */ { "LISU LETTER PA",NULL},
/* A4D2 */ { "LISU LETTER PHA",NULL},
/* A4D3 */ { "LISU LETTER DA",NULL},
/* A4D4 */ { "LISU LETTER TA",NULL},
/* A4D5 */ { "LISU LETTER THA",NULL},
/* A4D6 */ { "LISU LETTER GA",NULL},
/* A4D7 */ { "LISU LETTER KA",NULL},
/* A4D8 */ { "LISU LETTER KHA",NULL},
/* A4D9 */ { "LISU LETTER JA",NULL},
/* A4DA */ { "LISU LETTER CA",NULL},
/* A4DB */ { "LISU LETTER CHA",NULL},
/* A4DC */ { "LISU LETTER DZA",NULL},
/* A4DD */ { "LISU LETTER TSA",NULL},
/* A4DE */ { "LISU LETTER TSHA",NULL},
/* A4DF */ { "LISU LETTER MA",NULL},
/* A4E0 */ { "LISU LETTER NA",NULL},
/* A4E1 */ { "LISU LETTER LA",NULL},
/* A4E2 */ { "LISU LETTER SA",NULL},
/* A4E3 */ { "LISU LETTER ZHA",NULL},
/* A4E4 */ { "LISU LETTER ZA",NULL},
/* A4E5 */ { "LISU LETTER NGA",NULL},
/* A4E6 */ { "LISU LETTER HA",NULL},
/* A4E7 */ { "LISU LETTER XA",NULL},
/* A4E8 */ { "LISU LETTER HHA",NULL},
/* A4E9 */ { "LISU LETTER FA",NULL},
/* A4EA */ { "LISU LETTER WA",NULL},
/* A4EB */ { "LISU LETTER SHA",NULL},
/* A4EC */ { "LISU LETTER YA",NULL},
/* A4ED */ { "LISU LETTER GHA",NULL},
/* A4EE */ { "LISU LETTER A",NULL},
/* A4EF */ { "LISU LETTER AE",NULL},
/* A4F0 */ { "LISU LETTER E",NULL},
/* A4F1 */ { "LISU LETTER EU",NULL},
/* A4F2 */ { "LISU LETTER I",NULL},
/* A4F3 */ { "LISU LETTER O",NULL},
/* A4F4 */ { "LISU LETTER U",NULL},
/* A4F5 */ { "LISU LETTER UE",NULL},
/* A4F6 */ { "LISU LETTER UH",NULL},
/* A4F7 */ { "LISU LETTER OE",NULL},
/* A4F8 */ { "LISU LETTER TONE MYA TI",NULL},
/* A4F9 */ { "LISU LETTER TONE NA PO",NULL},
/* A4FA */ { "LISU LETTER TONE MYA CYA",NULL},
/* A4FB */ { "LISU LETTER TONE MYA BO",NULL},
/* A4FC */ { "LISU LETTER TONE MYA NA",NULL},
/* A4FD */ { "LISU LETTER TONE MYA JEU",NULL},
/* A4FE */ { "LISU PUNCTUATION COMMA",NULL},
/* A4FF */ { "LISU PUNCTUATION FULL STOP",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_00_A5[] = {
/* A500 */ { "VAI SYLLABLE EE",NULL},
/* A501 */ { "VAI SYLLABLE EEN",NULL},
/* A502 */ { "VAI SYLLABLE HEE",NULL},
/* A503 */ { "VAI SYLLABLE WEE",NULL},
/* A504 */ { "VAI SYLLABLE WEEN",NULL},
/* A505 */ { "VAI SYLLABLE PEE",NULL},
/* A506 */ { "VAI SYLLABLE BHEE",NULL},
/* A507 */ { "VAI SYLLABLE BEE",NULL},
/* A508 */ { "VAI SYLLABLE MBEE",NULL},
/* A509 */ { "VAI SYLLABLE KPEE",NULL},
/* A50A */ { "VAI SYLLABLE MGBEE",NULL},
/* A50B */ { "VAI SYLLABLE GBEE",NULL},
/* A50C */ { "VAI SYLLABLE FEE",NULL},
/* A50D */ { "VAI SYLLABLE VEE",NULL},
/* A50E */ { "VAI SYLLABLE TEE",NULL},
/* A50F */ { "VAI SYLLABLE THEE",NULL},
/* A510 */ { "VAI SYLLABLE DHEE",NULL},
/* A511 */ { "VAI SYLLABLE DHHEE",NULL},
/* A512 */ { "VAI SYLLABLE LEE",NULL},
/* A513 */ { "VAI SYLLABLE REE",NULL},
/* A514 */ { "VAI SYLLABLE DEE","	* read as logogram deeng \"child, small\" in the Book of Ndole"},
/* A515 */ { "VAI SYLLABLE NDEE",NULL},
/* A516 */ { "VAI SYLLABLE SEE",NULL},
/* A517 */ { "VAI SYLLABLE SHEE",NULL},
/* A518 */ { "VAI SYLLABLE ZEE",NULL},
/* A519 */ { "VAI SYLLABLE ZHEE",NULL},
/* A51A */ { "VAI SYLLABLE CEE",NULL},
/* A51B */ { "VAI SYLLABLE JEE",NULL},
/* A51C */ { "VAI SYLLABLE NJEE",NULL},
/* A51D */ { "VAI SYLLABLE YEE",NULL},
/* A51E */ { "VAI SYLLABLE KEE",NULL},
/* A51F */ { "VAI SYLLABLE NGGEE",NULL},
/* A520 */ { "VAI SYLLABLE GEE",NULL},
/* A521 */ { "VAI SYLLABLE MEE",NULL},
/* A522 */ { "VAI SYLLABLE NEE",NULL},
/* A523 */ { "VAI SYLLABLE NYEE",NULL},
/* A524 */ { "VAI SYLLABLE I",NULL},
/* A525 */ { "VAI SYLLABLE IN",NULL},
/* A526 */ { "VAI SYLLABLE HI",NULL},
/* A527 */ { "VAI SYLLABLE HIN",NULL},
/* A528 */ { "VAI SYLLABLE WI",NULL},
/* A529 */ { "VAI SYLLABLE WIN",NULL},
/* A52A */ { "VAI SYLLABLE PI",NULL},
/* A52B */ { "VAI SYLLABLE BHI",NULL},
/* A52C */ { "VAI SYLLABLE BI",NULL},
/* A52D */ { "VAI SYLLABLE MBI",NULL},
/* A52E */ { "VAI SYLLABLE KPI",NULL},
/* A52F */ { "VAI SYLLABLE MGBI",NULL},
/* A530 */ { "VAI SYLLABLE GBI",NULL},
/* A531 */ { "VAI SYLLABLE FI",NULL},
/* A532 */ { "VAI SYLLABLE VI",NULL},
/* A533 */ { "VAI SYLLABLE TI",NULL},
/* A534 */ { "VAI SYLLABLE THI",NULL},
/* A535 */ { "VAI SYLLABLE DHI",NULL},
/* A536 */ { "VAI SYLLABLE DHHI",NULL},
/* A537 */ { "VAI SYLLABLE LI",NULL},
/* A538 */ { "VAI SYLLABLE RI",NULL},
/* A539 */ { "VAI SYLLABLE DI",NULL},
/* A53A */ { "VAI SYLLABLE NDI",NULL},
/* A53B */ { "VAI SYLLABLE SI",NULL},
/* A53C */ { "VAI SYLLABLE SHI",NULL},
/* A53D */ { "VAI SYLLABLE ZI",NULL},
/* A53E */ { "VAI SYLLABLE ZHI",NULL},
/* A53F */ { "VAI SYLLABLE CI",NULL},
/* A540 */ { "VAI SYLLABLE JI",NULL},
/* A541 */ { "VAI SYLLABLE NJI",NULL},
/* A542 */ { "VAI SYLLABLE YI",NULL},
/* A543 */ { "VAI SYLLABLE KI",NULL},
/* A544 */ { "VAI SYLLABLE NGGI",NULL},
/* A545 */ { "VAI SYLLABLE GI",NULL},
/* A546 */ { "VAI SYLLABLE MI",NULL},
/* A547 */ { "VAI SYLLABLE NI",NULL},
/* A548 */ { "VAI SYLLABLE NYI",NULL},
/* A549 */ { "VAI SYLLABLE A",NULL},
/* A54A */ { "VAI SYLLABLE AN",NULL},
/* A54B */ { "VAI SYLLABLE NGAN",NULL},
/* A54C */ { "VAI SYLLABLE HA",NULL},
/* A54D */ { "VAI SYLLABLE HAN",NULL},
/* A54E */ { "VAI SYLLABLE WA",NULL},
/* A54F */ { "VAI SYLLABLE WAN",NULL},
/* A550 */ { "VAI SYLLABLE PA",NULL},
/* A551 */ { "VAI SYLLABLE BHA",NULL},
/* A552 */ { "VAI SYLLABLE BA",NULL},
/* A553 */ { "VAI SYLLABLE MBA",NULL},
/* A554 */ { "VAI SYLLABLE KPA",NULL},
/* A555 */ { "VAI SYLLABLE KPAN",NULL},
/* A556 */ { "VAI SYLLABLE MGBA",NULL},
/* A557 */ { "VAI SYLLABLE GBA",NULL},
/* A558 */ { "VAI SYLLABLE FA","	x (vai syllable ndole fa - A610)"},
/* A559 */ { "VAI SYLLABLE VA",NULL},
/* A55A */ { "VAI SYLLABLE TA",NULL},
/* A55B */ { "VAI SYLLABLE THA",NULL},
/* A55C */ { "VAI SYLLABLE DHA",NULL},
/* A55D */ { "VAI SYLLABLE DHHA",NULL},
/* A55E */ { "VAI SYLLABLE LA",NULL},
/* A55F */ { "VAI SYLLABLE RA",NULL},
/* A560 */ { "VAI SYLLABLE DA",NULL},
/* A561 */ { "VAI SYLLABLE NDA",NULL},
/* A562 */ { "VAI SYLLABLE SA",NULL},
/* A563 */ { "VAI SYLLABLE SHA",NULL},
/* A564 */ { "VAI SYLLABLE ZA",NULL},
/* A565 */ { "VAI SYLLABLE ZHA",NULL},
/* A566 */ { "VAI SYLLABLE CA",NULL},
/* A567 */ { "VAI SYLLABLE JA",NULL},
/* A568 */ { "VAI SYLLABLE NJA",NULL},
/* A569 */ { "VAI SYLLABLE YA",NULL},
/* A56A */ { "VAI SYLLABLE KA","	* read as logogram kai \"man\" in the Book of Ndole\n"
	"	x (vai syllable ndole ka - A611)"},
/* A56B */ { "VAI SYLLABLE KAN",NULL},
/* A56C */ { "VAI SYLLABLE NGGA",NULL},
/* A56D */ { "VAI SYLLABLE GA",NULL},
/* A56E */ { "VAI SYLLABLE MA","	x (vai syllable ndole ma - A62A)"},
/* A56F */ { "VAI SYLLABLE NA",NULL},
/* A570 */ { "VAI SYLLABLE NYA",NULL},
/* A571 */ { "VAI SYLLABLE OO",NULL},
/* A572 */ { "VAI SYLLABLE OON",NULL},
/* A573 */ { "VAI SYLLABLE HOO",NULL},
/* A574 */ { "VAI SYLLABLE WOO",NULL},
/* A575 */ { "VAI SYLLABLE WOON",NULL},
/* A576 */ { "VAI SYLLABLE POO",NULL},
/* A577 */ { "VAI SYLLABLE BHOO",NULL},
/* A578 */ { "VAI SYLLABLE BOO",NULL},
/* A579 */ { "VAI SYLLABLE MBOO",NULL},
/* A57A */ { "VAI SYLLABLE KPOO",NULL},
/* A57B */ { "VAI SYLLABLE MGBOO",NULL},
/* A57C */ { "VAI SYLLABLE GBOO",NULL},
/* A57D */ { "VAI SYLLABLE FOO",NULL},
/* A57E */ { "VAI SYLLABLE VOO",NULL},
/* A57F */ { "VAI SYLLABLE TOO",NULL},
/* A580 */ { "VAI SYLLABLE THOO",NULL},
/* A581 */ { "VAI SYLLABLE DHOO",NULL},
/* A582 */ { "VAI SYLLABLE DHHOO",NULL},
/* A583 */ { "VAI SYLLABLE LOO",NULL},
/* A584 */ { "VAI SYLLABLE ROO",NULL},
/* A585 */ { "VAI SYLLABLE DOO",NULL},
/* A586 */ { "VAI SYLLABLE NDOO",NULL},
/* A587 */ { "VAI SYLLABLE SOO","	x (vai syllable ndole soo - A612)"},
/* A588 */ { "VAI SYLLABLE SHOO",NULL},
/* A589 */ { "VAI SYLLABLE ZOO",NULL},
/* A58A */ { "VAI SYLLABLE ZHOO",NULL},
/* A58B */ { "VAI SYLLABLE COO",NULL},
/* A58C */ { "VAI SYLLABLE JOO",NULL},
/* A58D */ { "VAI SYLLABLE NJOO",NULL},
/* A58E */ { "VAI SYLLABLE YOO",NULL},
/* A58F */ { "VAI SYLLABLE KOO",NULL},
/* A590 */ { "VAI SYLLABLE NGGOO",NULL},
/* A591 */ { "VAI SYLLABLE GOO",NULL},
/* A592 */ { "VAI SYLLABLE MOO",NULL},
/* A593 */ { "VAI SYLLABLE NOO",NULL},
/* A594 */ { "VAI SYLLABLE NYOO",NULL},
/* A595 */ { "VAI SYLLABLE U",NULL},
/* A596 */ { "VAI SYLLABLE UN",NULL},
/* A597 */ { "VAI SYLLABLE HU",NULL},
/* A598 */ { "VAI SYLLABLE HUN",NULL},
/* A599 */ { "VAI SYLLABLE WU",NULL},
/* A59A */ { "VAI SYLLABLE WUN",NULL},
/* A59B */ { "VAI SYLLABLE PU",NULL},
/* A59C */ { "VAI SYLLABLE BHU",NULL},
/* A59D */ { "VAI SYLLABLE BU",NULL},
/* A59E */ { "VAI SYLLABLE MBU",NULL},
/* A59F */ { "VAI SYLLABLE KPU",NULL},
/* A5A0 */ { "VAI SYLLABLE MGBU",NULL},
/* A5A1 */ { "VAI SYLLABLE GBU",NULL},
/* A5A2 */ { "VAI SYLLABLE FU",NULL},
/* A5A3 */ { "VAI SYLLABLE VU",NULL},
/* A5A4 */ { "VAI SYLLABLE TU",NULL},
/* A5A5 */ { "VAI SYLLABLE THU",NULL},
/* A5A6 */ { "VAI SYLLABLE DHU",NULL},
/* A5A7 */ { "VAI SYLLABLE DHHU",NULL},
/* A5A8 */ { "VAI SYLLABLE LU",NULL},
/* A5A9 */ { "VAI SYLLABLE RU",NULL},
/* A5AA */ { "VAI SYLLABLE DU",NULL},
/* A5AB */ { "VAI SYLLABLE NDU",NULL},
/* A5AC */ { "VAI SYLLABLE SU",NULL},
/* A5AD */ { "VAI SYLLABLE SHU",NULL},
/* A5AE */ { "VAI SYLLABLE ZU",NULL},
/* A5AF */ { "VAI SYLLABLE ZHU",NULL},
/* A5B0 */ { "VAI SYLLABLE CU",NULL},
/* A5B1 */ { "VAI SYLLABLE JU",NULL},
/* A5B2 */ { "VAI SYLLABLE NJU",NULL},
/* A5B3 */ { "VAI SYLLABLE YU",NULL},
/* A5B4 */ { "VAI SYLLABLE KU",NULL},
/* A5B5 */ { "VAI SYLLABLE NGGU",NULL},
/* A5B6 */ { "VAI SYLLABLE GU",NULL},
/* A5B7 */ { "VAI SYLLABLE MU",NULL},
/* A5B8 */ { "VAI SYLLABLE NU",NULL},
/* A5B9 */ { "VAI SYLLABLE NYU",NULL},
/* A5BA */ { "VAI SYLLABLE O",NULL},
/* A5BB */ { "VAI SYLLABLE ON",NULL},
/* A5BC */ { "VAI SYLLABLE NGON",NULL},
/* A5BD */ { "VAI SYLLABLE HO",NULL},
/* A5BE */ { "VAI SYLLABLE HON",NULL},
/* A5BF */ { "VAI SYLLABLE WO",NULL},
/* A5C0 */ { "VAI SYLLABLE WON",NULL},
/* A5C1 */ { "VAI SYLLABLE PO",NULL},
/* A5C2 */ { "VAI SYLLABLE BHO",NULL},
/* A5C3 */ { "VAI SYLLABLE BO",NULL},
/* A5C4 */ { "VAI SYLLABLE MBO",NULL},
/* A5C5 */ { "VAI SYLLABLE KPO",NULL},
/* A5C6 */ { "VAI SYLLABLE MGBO",NULL},
/* A5C7 */ { "VAI SYLLABLE GBO",NULL},
/* A5C8 */ { "VAI SYLLABLE GBON",NULL},
/* A5C9 */ { "VAI SYLLABLE FO",NULL},
/* A5CA */ { "VAI SYLLABLE VO",NULL},
/* A5CB */ { "VAI SYLLABLE TO",NULL},
/* A5CC */ { "VAI SYLLABLE THO",NULL},
/* A5CD */ { "VAI SYLLABLE DHO",NULL},
/* A5CE */ { "VAI SYLLABLE DHHO",NULL},
/* A5CF */ { "VAI SYLLABLE LO",NULL},
/* A5D0 */ { "VAI SYLLABLE RO",NULL},
/* A5D1 */ { "VAI SYLLABLE DO","	* read as logogram lo \"in\" in the Book of Ndole\n"
	"	x (vai syllable ndole do - A62B)"},
/* A5D2 */ { "VAI SYLLABLE NDO",NULL},
/* A5D3 */ { "VAI SYLLABLE SO",NULL},
/* A5D4 */ { "VAI SYLLABLE SHO",NULL},
/* A5D5 */ { "VAI SYLLABLE ZO",NULL},
/* A5D6 */ { "VAI SYLLABLE ZHO",NULL},
/* A5D7 */ { "VAI SYLLABLE CO",NULL},
/* A5D8 */ { "VAI SYLLABLE JO",NULL},
/* A5D9 */ { "VAI SYLLABLE NJO",NULL},
/* A5DA */ { "VAI SYLLABLE YO",NULL},
/* A5DB */ { "VAI SYLLABLE KO",NULL},
/* A5DC */ { "VAI SYLLABLE NGGO",NULL},
/* A5DD */ { "VAI SYLLABLE GO",NULL},
/* A5DE */ { "VAI SYLLABLE MO",NULL},
/* A5DF */ { "VAI SYLLABLE NO",NULL},
/* A5E0 */ { "VAI SYLLABLE NYO",NULL},
/* A5E1 */ { "VAI SYLLABLE E",NULL},
/* A5E2 */ { "VAI SYLLABLE EN",NULL},
/* A5E3 */ { "VAI SYLLABLE NGEN",NULL},
/* A5E4 */ { "VAI SYLLABLE HE",NULL},
/* A5E5 */ { "VAI SYLLABLE HEN",NULL},
/* A5E6 */ { "VAI SYLLABLE WE",NULL},
/* A5E7 */ { "VAI SYLLABLE WEN",NULL},
/* A5E8 */ { "VAI SYLLABLE PE",NULL},
/* A5E9 */ { "VAI SYLLABLE BHE",NULL},
/* A5EA */ { "VAI SYLLABLE BE",NULL},
/* A5EB */ { "VAI SYLLABLE MBE",NULL},
/* A5EC */ { "VAI SYLLABLE KPE",NULL},
/* A5ED */ { "VAI SYLLABLE KPEN",NULL},
/* A5EE */ { "VAI SYLLABLE MGBE",NULL},
/* A5EF */ { "VAI SYLLABLE GBE",NULL},
/* A5F0 */ { "VAI SYLLABLE GBEN",NULL},
/* A5F1 */ { "VAI SYLLABLE FE",NULL},
/* A5F2 */ { "VAI SYLLABLE VE",NULL},
/* A5F3 */ { "VAI SYLLABLE TE",NULL},
/* A5F4 */ { "VAI SYLLABLE THE",NULL},
/* A5F5 */ { "VAI SYLLABLE DHE",NULL},
/* A5F6 */ { "VAI SYLLABLE DHHE",NULL},
/* A5F7 */ { "VAI SYLLABLE LE",NULL},
/* A5F8 */ { "VAI SYLLABLE RE",NULL},
/* A5F9 */ { "VAI SYLLABLE DE",NULL},
/* A5FA */ { "VAI SYLLABLE NDE",NULL},
/* A5FB */ { "VAI SYLLABLE SE",NULL},
/* A5FC */ { "VAI SYLLABLE SHE",NULL},
/* A5FD */ { "VAI SYLLABLE ZE",NULL},
/* A5FE */ { "VAI SYLLABLE ZHE",NULL},
/* A5FF */ { "VAI SYLLABLE CE",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_00_A6[] = {
/* A600 */ { "VAI SYLLABLE JE",NULL},
/* A601 */ { "VAI SYLLABLE NJE",NULL},
/* A602 */ { "VAI SYLLABLE YE",NULL},
/* A603 */ { "VAI SYLLABLE KE",NULL},
/* A604 */ { "VAI SYLLABLE NGGE",NULL},
/* A605 */ { "VAI SYLLABLE NGGEN",NULL},
/* A606 */ { "VAI SYLLABLE GE",NULL},
/* A607 */ { "VAI SYLLABLE GEN",NULL},
/* A608 */ { "VAI SYLLABLE ME",NULL},
/* A609 */ { "VAI SYLLABLE NE",NULL},
/* A60A */ { "VAI SYLLABLE NYE",NULL},
/* A60B */ { "VAI SYLLABLE NG",NULL},
/* A60C */ { "VAI SYLLABLE LENGTHENER",NULL},
/* A60D */ { "VAI COMMA",NULL},
/* A60E */ { "VAI FULL STOP",NULL},
/* A60F */ { "VAI QUESTION MARK",NULL},
/* A610 */ { "VAI SYLLABLE NDOLE FA","	x (vai syllable fa - A558)"},
/* A611 */ { "VAI SYLLABLE NDOLE KA","	x (vai syllable ka - A56A)"},
/* A612 */ { "VAI SYLLABLE NDOLE SOO","	x (vai syllable soo - A587)"},
/* A613 */ { "VAI SYMBOL FEENG","	* logogram for \"thing\""},
/* A614 */ { "VAI SYMBOL KEENG","	* logogram for \"foot\""},
/* A615 */ { "VAI SYMBOL TING","	* logogram for \"island\""},
/* A616 */ { "VAI SYMBOL NII","	* logogram for \"cow\"\n"
	"	* also logogram for kpe kowu \"case of gin\""},
/* A617 */ { "VAI SYMBOL BANG","	* logogram for \"finished\""},
/* A618 */ { "VAI SYMBOL FAA","	* logogram for \"die, kill\""},
/* A619 */ { "VAI SYMBOL TAA","	* logogram for \"go, carry, journey\""},
/* A61A */ { "VAI SYMBOL DANG","	* logogram for \"hear, understand\""},
/* A61B */ { "VAI SYMBOL DOONG","	* logogram for \"enter\""},
/* A61C */ { "VAI SYMBOL KUNG","	* logogram for \"head, be able\""},
/* A61D */ { "VAI SYMBOL TONG","	* logogram for \"be named\""},
/* A61E */ { "VAI SYMBOL DO-O","	* logogram for \"be small\""},
/* A61F */ { "VAI SYMBOL JONG","	* logogram for \"slave\""},
/* A620 */ { "VAI DIGIT ZERO",NULL},
/* A621 */ { "VAI DIGIT ONE",NULL},
/* A622 */ { "VAI DIGIT TWO",NULL},
/* A623 */ { "VAI DIGIT THREE",NULL},
/* A624 */ { "VAI DIGIT FOUR",NULL},
/* A625 */ { "VAI DIGIT FIVE",NULL},
/* A626 */ { "VAI DIGIT SIX",NULL},
/* A627 */ { "VAI DIGIT SEVEN",NULL},
/* A628 */ { "VAI DIGIT EIGHT",NULL},
/* A629 */ { "VAI DIGIT NINE",NULL},
/* A62A */ { "VAI SYLLABLE NDOLE MA","	x (vai syllable ma - A56E)"},
/* A62B */ { "VAI SYLLABLE NDOLE DO","	x (vai syllable do - A5D1)"},
/* A62C */ { NULL,NULL},
/* A62D */ { NULL,NULL},
/* A62E */ { NULL,NULL},
/* A62F */ { NULL,NULL},
/* A630 */ { NULL,NULL},
/* A631 */ { NULL,NULL},
/* A632 */ { NULL,NULL},
/* A633 */ { NULL,NULL},
/* A634 */ { NULL,NULL},
/* A635 */ { NULL,NULL},
/* A636 */ { NULL,NULL},
/* A637 */ { NULL,NULL},
/* A638 */ { NULL,NULL},
/* A639 */ { NULL,NULL},
/* A63A */ { NULL,NULL},
/* A63B */ { NULL,NULL},
/* A63C */ { NULL,NULL},
/* A63D */ { NULL,NULL},
/* A63E */ { NULL,NULL},
/* A63F */ { NULL,NULL},
/* A640 */ { "CYRILLIC CAPITAL LETTER ZEMLYA",NULL},
/* A641 */ { "CYRILLIC SMALL LETTER ZEMLYA","	x (cyrillic small letter ze - 0437)"},
/* A642 */ { "CYRILLIC CAPITAL LETTER DZELO",NULL},
/* A643 */ { "CYRILLIC SMALL LETTER DZELO","	x (cyrillic small letter dze - 0455)"},
/* A644 */ { "CYRILLIC CAPITAL LETTER REVERSED DZE","	x (roman sextula sign - 10193)"},
/* A645 */ { "CYRILLIC SMALL LETTER REVERSED DZE",NULL},
/* A646 */ { "CYRILLIC CAPITAL LETTER IOTA",NULL},
/* A647 */ { "CYRILLIC SMALL LETTER IOTA","	x (glagolitic small letter initial izhe - 2C3A)"},
/* A648 */ { "CYRILLIC CAPITAL LETTER DJERV",NULL},
/* A649 */ { "CYRILLIC SMALL LETTER DJERV","	x (cyrillic small letter dje - 0452)\n"
	"	x (cyrillic small letter tshe - 045B)"},
/* A64A */ { "CYRILLIC CAPITAL LETTER MONOGRAPH UK",NULL},
/* A64B */ { "CYRILLIC SMALL LETTER MONOGRAPH UK","	x (cyrillic small letter u - 0443)"},
/* A64C */ { "CYRILLIC CAPITAL LETTER BROAD OMEGA",NULL},
/* A64D */ { "CYRILLIC SMALL LETTER BROAD OMEGA","	x (cyrillic small letter omega - 0461)"},
/* A64E */ { "CYRILLIC CAPITAL LETTER NEUTRAL YER",NULL},
/* A64F */ { "CYRILLIC SMALL LETTER NEUTRAL YER","	x (cyrillic small letter hard sign - 044A)\n"
	"	x (cyrillic small letter soft sign - 044C)"},
/* A650 */ { "CYRILLIC CAPITAL LETTER YERU WITH BACK YER",NULL},
/* A651 */ { "CYRILLIC SMALL LETTER YERU WITH BACK YER","	x (cyrillic small letter yeru - 044B)"},
/* A652 */ { "CYRILLIC CAPITAL LETTER IOTIFIED YAT",NULL},
/* A653 */ { "CYRILLIC SMALL LETTER IOTIFIED YAT","	x (cyrillic small letter yat - 0463)"},
/* A654 */ { "CYRILLIC CAPITAL LETTER REVERSED YU",NULL},
/* A655 */ { "CYRILLIC SMALL LETTER REVERSED YU","	x (cyrillic small letter yu - 044E)"},
/* A656 */ { "CYRILLIC CAPITAL LETTER IOTIFIED A",NULL},
/* A657 */ { "CYRILLIC SMALL LETTER IOTIFIED A",NULL},
/* A658 */ { "CYRILLIC CAPITAL LETTER CLOSED LITTLE YUS",NULL},
/* A659 */ { "CYRILLIC SMALL LETTER CLOSED LITTLE YUS","	x (cyrillic small letter little yus - 0467)"},
/* A65A */ { "CYRILLIC CAPITAL LETTER BLENDED YUS",NULL},
/* A65B */ { "CYRILLIC SMALL LETTER BLENDED YUS","	x (cyrillic small letter little yus - 0467)\n"
	"	x (cyrillic small letter big yus - 046B)"},
/* A65C */ { "CYRILLIC CAPITAL LETTER IOTIFIED CLOSED LITTLE YUS",NULL},
/* A65D */ { "CYRILLIC SMALL LETTER IOTIFIED CLOSED LITTLE YUS","	x (cyrillic small letter iotified little yus - 0469)"},
/* A65E */ { "CYRILLIC CAPITAL LETTER YN",NULL},
/* A65F */ { "CYRILLIC SMALL LETTER YN","	* Romanian Cyrillic"},
/* A660 */ { "CYRILLIC CAPITAL LETTER REVERSED TSE",NULL},
/* A661 */ { "CYRILLIC SMALL LETTER REVERSED TSE",NULL},
/* A662 */ { "CYRILLIC CAPITAL LETTER SOFT DE",NULL},
/* A663 */ { "CYRILLIC SMALL LETTER SOFT DE",NULL},
/* A664 */ { "CYRILLIC CAPITAL LETTER SOFT EL",NULL},
/* A665 */ { "CYRILLIC SMALL LETTER SOFT EL",NULL},
/* A666 */ { "CYRILLIC CAPITAL LETTER SOFT EM",NULL},
/* A667 */ { "CYRILLIC SMALL LETTER SOFT EM",NULL},
/* A668 */ { "CYRILLIC CAPITAL LETTER MONOCULAR O",NULL},
/* A669 */ { "CYRILLIC SMALL LETTER MONOCULAR O","	* used in words based on the root for 'eye'"},
/* A66A */ { "CYRILLIC CAPITAL LETTER BINOCULAR O",NULL},
/* A66B */ { "CYRILLIC SMALL LETTER BINOCULAR O","	* used in the dual of words based on the root for 'eye'"},
/* A66C */ { "CYRILLIC CAPITAL LETTER DOUBLE MONOCULAR O",NULL},
/* A66D */ { "CYRILLIC SMALL LETTER DOUBLE MONOCULAR O","	* used in the dual of words based on the root for 'eye'"},
/* A66E */ { "CYRILLIC LETTER MULTIOCULAR O","	* used in the epithet 'many-eyed'"},
/* A66F */ { "COMBINING CYRILLIC VZMET","	* used with Cyrillic and Glagolitic letters to indicate abbreviation\n"
	"	x (combining cyrillic titlo - 0483)\n"
	"	x (combining cyrillic pokrytie - 0487)"},
/* A670 */ { "COMBINING CYRILLIC TEN MILLIONS SIGN","	x (combining cyrillic millions sign - 0489)"},
/* A671 */ { "COMBINING CYRILLIC HUNDRED MILLIONS SIGN",NULL},
/* A672 */ { "COMBINING CYRILLIC THOUSAND MILLIONS SIGN",NULL},
/* A673 */ { "SLAVONIC ASTERISK",NULL},
/* A674 */ { "COMBINING CYRILLIC LETTER UKRAINIAN IE",NULL},
/* A675 */ { "COMBINING CYRILLIC LETTER I",NULL},
/* A676 */ { "COMBINING CYRILLIC LETTER YI",NULL},
/* A677 */ { "COMBINING CYRILLIC LETTER U",NULL},
/* A678 */ { "COMBINING CYRILLIC LETTER HARD SIGN",NULL},
/* A679 */ { "COMBINING CYRILLIC LETTER YERU",NULL},
/* A67A */ { "COMBINING CYRILLIC LETTER SOFT SIGN",NULL},
/* A67B */ { "COMBINING CYRILLIC LETTER OMEGA",NULL},
/* A67C */ { "COMBINING CYRILLIC KAVYKA","	* indicates an alternative reading to part of a word\n"
	"	x (combining breve - 0306)\n"
	"	x (combining kavyka above right - 1DF6)\n"
	"	x (combining kavyka above left - 1DF7)"},
/* A67D */ { "COMBINING CYRILLIC PAYEROK","	* may indicate an omitted yer\n"
	"	x (combining vertical tilde - 033E)"},
/* A67E */ { "CYRILLIC KAVYKA","	* used to mark off word that has alternative reading\n"
	"	x (low kavyka - 2E47)"},
/* A67F */ { "CYRILLIC PAYEROK","	* may indicate an omitted yer\n"
	"	x (vertical tilde - 2E2F)"},
/* A680 */ { "CYRILLIC CAPITAL LETTER DWE",NULL},
/* A681 */ { "CYRILLIC SMALL LETTER DWE",NULL},
/* A682 */ { "CYRILLIC CAPITAL LETTER DZWE",NULL},
/* A683 */ { "CYRILLIC SMALL LETTER DZWE",NULL},
/* A684 */ { "CYRILLIC CAPITAL LETTER ZHWE",NULL},
/* A685 */ { "CYRILLIC SMALL LETTER ZHWE",NULL},
/* A686 */ { "CYRILLIC CAPITAL LETTER CCHE",NULL},
/* A687 */ { "CYRILLIC SMALL LETTER CCHE",NULL},
/* A688 */ { "CYRILLIC CAPITAL LETTER DZZE",NULL},
/* A689 */ { "CYRILLIC SMALL LETTER DZZE",NULL},
/* A68A */ { "CYRILLIC CAPITAL LETTER TE WITH MIDDLE HOOK",NULL},
/* A68B */ { "CYRILLIC SMALL LETTER TE WITH MIDDLE HOOK",NULL},
/* A68C */ { "CYRILLIC CAPITAL LETTER TWE",NULL},
/* A68D */ { "CYRILLIC SMALL LETTER TWE",NULL},
/* A68E */ { "CYRILLIC CAPITAL LETTER TSWE",NULL},
/* A68F */ { "CYRILLIC SMALL LETTER TSWE",NULL},
/* A690 */ { "CYRILLIC CAPITAL LETTER TSSE",NULL},
/* A691 */ { "CYRILLIC SMALL LETTER TSSE",NULL},
/* A692 */ { "CYRILLIC CAPITAL LETTER TCHE",NULL},
/* A693 */ { "CYRILLIC SMALL LETTER TCHE",NULL},
/* A694 */ { "CYRILLIC CAPITAL LETTER HWE",NULL},
/* A695 */ { "CYRILLIC SMALL LETTER HWE",NULL},
/* A696 */ { "CYRILLIC CAPITAL LETTER SHWE",NULL},
/* A697 */ { "CYRILLIC SMALL LETTER SHWE",NULL},
/* A698 */ { "CYRILLIC CAPITAL LETTER DOUBLE O",NULL},
/* A699 */ { "CYRILLIC SMALL LETTER DOUBLE O",NULL},
/* A69A */ { "CYRILLIC CAPITAL LETTER CROSSED O",NULL},
/* A69B */ { "CYRILLIC SMALL LETTER CROSSED O",NULL},
/* A69C */ { "MODIFIER LETTER CYRILLIC HARD SIGN","	# <super> 044A"},
/* A69D */ { "MODIFIER LETTER CYRILLIC SOFT SIGN","	# <super> 044C"},
/* A69E */ { "COMBINING CYRILLIC LETTER EF",NULL},
/* A69F */ { "COMBINING CYRILLIC LETTER IOTIFIED E",NULL},
/* A6A0 */ { "BAMUM LETTER A",NULL},
/* A6A1 */ { "BAMUM LETTER KA",NULL},
/* A6A2 */ { "BAMUM LETTER U",NULL},
/* A6A3 */ { "BAMUM LETTER KU",NULL},
/* A6A4 */ { "BAMUM LETTER EE",NULL},
/* A6A5 */ { "BAMUM LETTER REE",NULL},
/* A6A6 */ { "BAMUM LETTER TAE",NULL},
/* A6A7 */ { "BAMUM LETTER O",NULL},
/* A6A8 */ { "BAMUM LETTER NYI",NULL},
/* A6A9 */ { "BAMUM LETTER I",NULL},
/* A6AA */ { "BAMUM LETTER LA",NULL},
/* A6AB */ { "BAMUM LETTER PA",NULL},
/* A6AC */ { "BAMUM LETTER RII",NULL},
/* A6AD */ { "BAMUM LETTER RIEE",NULL},
/* A6AE */ { "BAMUM LETTER LEEEE",NULL},
/* A6AF */ { "BAMUM LETTER MEEEE",NULL},
/* A6B0 */ { "BAMUM LETTER TAA",NULL},
/* A6B1 */ { "BAMUM LETTER NDAA",NULL},
/* A6B2 */ { "BAMUM LETTER NJAEM",NULL},
/* A6B3 */ { "BAMUM LETTER M",NULL},
/* A6B4 */ { "BAMUM LETTER SUU",NULL},
/* A6B5 */ { "BAMUM LETTER MU",NULL},
/* A6B6 */ { "BAMUM LETTER SHII",NULL},
/* A6B7 */ { "BAMUM LETTER SI",NULL},
/* A6B8 */ { "BAMUM LETTER SHEUX",NULL},
/* A6B9 */ { "BAMUM LETTER SEUX",NULL},
/* A6BA */ { "BAMUM LETTER KYEE",NULL},
/* A6BB */ { "BAMUM LETTER KET",NULL},
/* A6BC */ { "BAMUM LETTER NUAE",NULL},
/* A6BD */ { "BAMUM LETTER NU",NULL},
/* A6BE */ { "BAMUM LETTER NJUAE",NULL},
/* A6BF */ { "BAMUM LETTER YOQ",NULL},
/* A6C0 */ { "BAMUM LETTER SHU",NULL},
/* A6C1 */ { "BAMUM LETTER YUQ",NULL},
/* A6C2 */ { "BAMUM LETTER YA",NULL},
/* A6C3 */ { "BAMUM LETTER NSHA",NULL},
/* A6C4 */ { "BAMUM LETTER KEUX",NULL},
/* A6C5 */ { "BAMUM LETTER PEUX",NULL},
/* A6C6 */ { "BAMUM LETTER NJEE",NULL},
/* A6C7 */ { "BAMUM LETTER NTEE",NULL},
/* A6C8 */ { "BAMUM LETTER PUE",NULL},
/* A6C9 */ { "BAMUM LETTER WUE",NULL},
/* A6CA */ { "BAMUM LETTER PEE",NULL},
/* A6CB */ { "BAMUM LETTER FEE",NULL},
/* A6CC */ { "BAMUM LETTER RU",NULL},
/* A6CD */ { "BAMUM LETTER LU",NULL},
/* A6CE */ { "BAMUM LETTER MI",NULL},
/* A6CF */ { "BAMUM LETTER NI",NULL},
/* A6D0 */ { "BAMUM LETTER REUX",NULL},
/* A6D1 */ { "BAMUM LETTER RAE",NULL},
/* A6D2 */ { "BAMUM LETTER KEN",NULL},
/* A6D3 */ { "BAMUM LETTER NGKWAEN",NULL},
/* A6D4 */ { "BAMUM LETTER NGGA",NULL},
/* A6D5 */ { "BAMUM LETTER NGA",NULL},
/* A6D6 */ { "BAMUM LETTER SHO",NULL},
/* A6D7 */ { "BAMUM LETTER PUAE",NULL},
/* A6D8 */ { "BAMUM LETTER FU",NULL},
/* A6D9 */ { "BAMUM LETTER FOM",NULL},
/* A6DA */ { "BAMUM LETTER WA",NULL},
/* A6DB */ { "BAMUM LETTER NA",NULL},
/* A6DC */ { "BAMUM LETTER LI",NULL},
/* A6DD */ { "BAMUM LETTER PI",NULL},
/* A6DE */ { "BAMUM LETTER LOQ",NULL},
/* A6DF */ { "BAMUM LETTER KO",NULL},
/* A6E0 */ { "BAMUM LETTER MBEN",NULL},
/* A6E1 */ { "BAMUM LETTER REN",NULL},
/* A6E2 */ { "BAMUM LETTER MEN",NULL},
/* A6E3 */ { "BAMUM LETTER MA",NULL},
/* A6E4 */ { "BAMUM LETTER TI",NULL},
/* A6E5 */ { "BAMUM LETTER KI",NULL},
/* A6E6 */ { "BAMUM LETTER MO","	* also used for digit one"},
/* A6E7 */ { "BAMUM LETTER MBAA","	* also used for digit two"},
/* A6E8 */ { "BAMUM LETTER TET","	* tèt\n"
	"	* also used for digit three"},
/* A6E9 */ { "BAMUM LETTER KPA","	* also used for digit four"},
/* A6EA */ { "BAMUM LETTER TEN","	* tèn\n"
	"	* also used for digit five"},
/* A6EB */ { "BAMUM LETTER NTUU","	* also used for digit six"},
/* A6EC */ { "BAMUM LETTER SAMBA","	* also used for digit seven"},
/* A6ED */ { "BAMUM LETTER FAAMAE","	* also used for digit eight"},
/* A6EE */ { "BAMUM LETTER KOVUU","	* also used for digit nine"},
/* A6EF */ { "BAMUM LETTER KOGHOM","	* also used for digit zero\n"
	"	* formerly used for number ten"},
/* A6F0 */ { "BAMUM COMBINING MARK KOQNDON",NULL},
/* A6F1 */ { "BAMUM COMBINING MARK TUKWENTIS",NULL},
/* A6F2 */ { "BAMUM NJAEMLI",NULL},
/* A6F3 */ { "BAMUM FULL STOP",NULL},
/* A6F4 */ { "BAMUM COLON",NULL},
/* A6F5 */ { "BAMUM COMMA",NULL},
/* A6F6 */ { "BAMUM SEMICOLON",NULL},
/* A6F7 */ { "BAMUM QUESTION MARK",NULL},
/* A6F8 */ { NULL,NULL},
/* A6F9 */ { NULL,NULL},
/* A6FA */ { NULL,NULL},
/* A6FB */ { NULL,NULL},
/* A6FC */ { NULL,NULL},
/* A6FD */ { NULL,NULL},
/* A6FE */ { NULL,NULL},
/* A6FF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_00_A7[] = {
/* A700 */ { "MODIFIER LETTER CHINESE TONE YIN PING",NULL},
/* A701 */ { "MODIFIER LETTER CHINESE TONE YANG PING",NULL},
/* A702 */ { "MODIFIER LETTER CHINESE TONE YIN SHANG",NULL},
/* A703 */ { "MODIFIER LETTER CHINESE TONE YANG SHANG",NULL},
/* A704 */ { "MODIFIER LETTER CHINESE TONE YIN QU",NULL},
/* A705 */ { "MODIFIER LETTER CHINESE TONE YANG QU",NULL},
/* A706 */ { "MODIFIER LETTER CHINESE TONE YIN RU",NULL},
/* A707 */ { "MODIFIER LETTER CHINESE TONE YANG RU",NULL},
/* A708 */ { "MODIFIER LETTER EXTRA-HIGH DOTTED TONE BAR",NULL},
/* A709 */ { "MODIFIER LETTER HIGH DOTTED TONE BAR",NULL},
/* A70A */ { "MODIFIER LETTER MID DOTTED TONE BAR",NULL},
/* A70B */ { "MODIFIER LETTER LOW DOTTED TONE BAR",NULL},
/* A70C */ { "MODIFIER LETTER EXTRA-LOW DOTTED TONE BAR",NULL},
/* A70D */ { "MODIFIER LETTER EXTRA-HIGH DOTTED LEFT-STEM TONE BAR",NULL},
/* A70E */ { "MODIFIER LETTER HIGH DOTTED LEFT-STEM TONE BAR",NULL},
/* A70F */ { "MODIFIER LETTER MID DOTTED LEFT-STEM TONE BAR",NULL},
/* A710 */ { "MODIFIER LETTER LOW DOTTED LEFT-STEM TONE BAR",NULL},
/* A711 */ { "MODIFIER LETTER EXTRA-LOW DOTTED LEFT-STEM TONE BAR",NULL},
/* A712 */ { "MODIFIER LETTER EXTRA-HIGH LEFT-STEM TONE BAR",NULL},
/* A713 */ { "MODIFIER LETTER HIGH LEFT-STEM TONE BAR",NULL},
/* A714 */ { "MODIFIER LETTER MID LEFT-STEM TONE BAR",NULL},
/* A715 */ { "MODIFIER LETTER LOW LEFT-STEM TONE BAR",NULL},
/* A716 */ { "MODIFIER LETTER EXTRA-LOW LEFT-STEM TONE BAR",NULL},
/* A717 */ { "MODIFIER LETTER DOT VERTICAL BAR",NULL},
/* A718 */ { "MODIFIER LETTER DOT SLASH",NULL},
/* A719 */ { "MODIFIER LETTER DOT HORIZONTAL BAR",NULL},
/* A71A */ { "MODIFIER LETTER LOWER RIGHT CORNER ANGLE",NULL},
/* A71B */ { "MODIFIER LETTER RAISED UP ARROW",NULL},
/* A71C */ { "MODIFIER LETTER RAISED DOWN ARROW",NULL},
/* A71D */ { "MODIFIER LETTER RAISED EXCLAMATION MARK","	x (latin letter retroflex click - 01C3)\n"
	"	x (modifier letter retroflex click with retroflex hook - 107B9)"},
/* A71E */ { "MODIFIER LETTER RAISED INVERTED EXCLAMATION MARK",NULL},
/* A71F */ { "MODIFIER LETTER LOW INVERTED EXCLAMATION MARK",NULL},
/* A720 */ { "MODIFIER LETTER STRESS AND HIGH TONE",NULL},
/* A721 */ { "MODIFIER LETTER STRESS AND LOW TONE",NULL},
/* A722 */ { "LATIN CAPITAL LETTER EGYPTOLOGICAL ALEF",NULL},
/* A723 */ { "LATIN SMALL LETTER EGYPTOLOGICAL ALEF","	x (hebrew letter alef - 05D0)\n"
	"	x (arabic letter alef with hamza above - 0623)"},
/* A724 */ { "LATIN CAPITAL LETTER EGYPTOLOGICAL AIN",NULL},
/* A725 */ { "LATIN SMALL LETTER EGYPTOLOGICAL AIN","	x (modifier letter left half ring - 02BF)\n"
	"	x (hebrew letter ayin - 05E2)\n"
	"	x (arabic letter ain - 0639)\n"
	"	x (latin letter ain - 1D25)\n"
	"	x (modifier letter small ain - 1D5C)\n"
	"	x (latin small letter glottal i - A7BD)"},
/* A726 */ { "LATIN CAPITAL LETTER HENG","	x (cyrillic capital letter en with hook - 04C7)\n"
	"	x (latin capital letter h with descender - 2C67)"},
/* A727 */ { "LATIN SMALL LETTER HENG","	* uvular fricative, see 0281\n"
	"	* also used in Bantu linguistics for the voiced alveolar lateral fricative, see 026E\n"
	"	x (latin small letter heng with hook - 0267)\n"
	"	x (latin small letter h with palatal hook - A795)\n"
	"	x (modifier letter small heng - AB5C)"},
/* A728 */ { "LATIN CAPITAL LETTER TZ",NULL},
/* A729 */ { "LATIN SMALL LETTER TZ","	= tezh digraph\n"
	"	* palatoalveolar affricate [ts]\n"
	"	x (latin small letter ts digraph - 02A6)\n"
	"	x (latin small letter tesh digraph - 02A7)"},
/* A72A */ { "LATIN CAPITAL LETTER TRESILLO",NULL},
/* A72B */ { "LATIN SMALL LETTER TRESILLO","	* uvular ejective stop [qʼ]\n"
	"	x (turned digit three - 218B)"},
/* A72C */ { "LATIN CAPITAL LETTER CUATRILLO",NULL},
/* A72D */ { "LATIN SMALL LETTER CUATRILLO","	* velar ejective stop [kʼ]\n"
	"	x (digit four - 0034)"},
/* A72E */ { "LATIN CAPITAL LETTER CUATRILLO WITH COMMA",NULL},
/* A72F */ { "LATIN SMALL LETTER CUATRILLO WITH COMMA","	* alveolar ejective affricate [tsʼ]"},
/* A730 */ { "LATIN LETTER SMALL CAPITAL F",NULL},
/* A731 */ { "LATIN LETTER SMALL CAPITAL S",NULL},
/* A732 */ { "LATIN CAPITAL LETTER AA","	x (modifier letter small capital aa - 10780)"},
/* A733 */ { "LATIN SMALL LETTER AA",NULL},
/* A734 */ { "LATIN CAPITAL LETTER AO",NULL},
/* A735 */ { "LATIN SMALL LETTER AO",NULL},
/* A736 */ { "LATIN CAPITAL LETTER AU",NULL},
/* A737 */ { "LATIN SMALL LETTER AU",NULL},
/* A738 */ { "LATIN CAPITAL LETTER AV",NULL},
/* A739 */ { "LATIN SMALL LETTER AV",NULL},
/* A73A */ { "LATIN CAPITAL LETTER AV WITH HORIZONTAL BAR",NULL},
/* A73B */ { "LATIN SMALL LETTER AV WITH HORIZONTAL BAR",NULL},
/* A73C */ { "LATIN CAPITAL LETTER AY",NULL},
/* A73D */ { "LATIN SMALL LETTER AY",NULL},
/* A73E */ { "LATIN CAPITAL LETTER REVERSED C WITH DOT","	x (greek capital reversed dotted lunate sigma symbol - 03FF)"},
/* A73F */ { "LATIN SMALL LETTER REVERSED C WITH DOT","	x (greek small reversed dotted lunate sigma symbol - 037D)"},
/* A740 */ { "LATIN CAPITAL LETTER K WITH STROKE",NULL},
/* A741 */ { "LATIN SMALL LETTER K WITH STROKE",NULL},
/* A742 */ { "LATIN CAPITAL LETTER K WITH DIAGONAL STROKE",NULL},
/* A743 */ { "LATIN SMALL LETTER K WITH DIAGONAL STROKE",NULL},
/* A744 */ { "LATIN CAPITAL LETTER K WITH STROKE AND DIAGONAL STROKE",NULL},
/* A745 */ { "LATIN SMALL LETTER K WITH STROKE AND DIAGONAL STROKE",NULL},
/* A746 */ { "LATIN CAPITAL LETTER BROKEN L",NULL},
/* A747 */ { "LATIN SMALL LETTER BROKEN L",NULL},
/* A748 */ { "LATIN CAPITAL LETTER L WITH HIGH STROKE","	x (latin capital letter l with bar - 023D)"},
/* A749 */ { "LATIN SMALL LETTER L WITH HIGH STROKE","	x (latin small letter l with bar - 019A)"},
/* A74A */ { "LATIN CAPITAL LETTER O WITH LONG STROKE OVERLAY","	x (latin capital letter o with middle tilde - 019F)"},
/* A74B */ { "LATIN SMALL LETTER O WITH LONG STROKE OVERLAY","	x (latin small letter o with stroke - 00F8)\n"
	"	x (latin small letter barred o - 0275)"},
/* A74C */ { "LATIN CAPITAL LETTER O WITH LOOP",NULL},
/* A74D */ { "LATIN SMALL LETTER O WITH LOOP",NULL},
/* A74E */ { "LATIN CAPITAL LETTER OO",NULL},
/* A74F */ { "LATIN SMALL LETTER OO","	x (cyrillic small letter double o - A699)"},
/* A750 */ { "LATIN CAPITAL LETTER P WITH STROKE THROUGH DESCENDER","	x (ruble sign - 20BD)"},
/* A751 */ { "LATIN SMALL LETTER P WITH STROKE THROUGH DESCENDER","	x (greek rho with stroke symbol - 03FC)\n"
	"	x (latin small letter p with middle tilde - 1D71)"},
/* A752 */ { "LATIN CAPITAL LETTER P WITH FLOURISH",NULL},
/* A753 */ { "LATIN SMALL LETTER P WITH FLOURISH",NULL},
/* A754 */ { "LATIN CAPITAL LETTER P WITH SQUIRREL TAIL",NULL},
/* A755 */ { "LATIN SMALL LETTER P WITH SQUIRREL TAIL",NULL},
/* A756 */ { "LATIN CAPITAL LETTER Q WITH STROKE THROUGH DESCENDER",NULL},
/* A757 */ { "LATIN SMALL LETTER Q WITH STROKE THROUGH DESCENDER",NULL},
/* A758 */ { "LATIN CAPITAL LETTER Q WITH DIAGONAL STROKE",NULL},
/* A759 */ { "LATIN SMALL LETTER Q WITH DIAGONAL STROKE",NULL},
/* A75A */ { "LATIN CAPITAL LETTER R ROTUNDA",NULL},
/* A75B */ { "LATIN SMALL LETTER R ROTUNDA",NULL},
/* A75C */ { "LATIN CAPITAL LETTER RUM ROTUNDA",NULL},
/* A75D */ { "LATIN SMALL LETTER RUM ROTUNDA",NULL},
/* A75E */ { "LATIN CAPITAL LETTER V WITH DIAGONAL STROKE",NULL},
/* A75F */ { "LATIN SMALL LETTER V WITH DIAGONAL STROKE",NULL},
/* A760 */ { "LATIN CAPITAL LETTER VY",NULL},
/* A761 */ { "LATIN SMALL LETTER VY",NULL},
/* A762 */ { "LATIN CAPITAL LETTER VISIGOTHIC Z",NULL},
/* A763 */ { "LATIN SMALL LETTER VISIGOTHIC Z","	x (latin small letter c with cedilla - 00E7)"},
/* A764 */ { "LATIN CAPITAL LETTER THORN WITH STROKE",NULL},
/* A765 */ { "LATIN SMALL LETTER THORN WITH STROKE","	* Old English, Old Norse\n"
	"	* representative glyph is preferred in Old English text\n"
	"	* Old Norse fonts show a more horizontal stroke"},
/* A766 */ { "LATIN CAPITAL LETTER THORN WITH STROKE THROUGH DESCENDER",NULL},
/* A767 */ { "LATIN SMALL LETTER THORN WITH STROKE THROUGH DESCENDER",NULL},
/* A768 */ { "LATIN CAPITAL LETTER VEND",NULL},
/* A769 */ { "LATIN SMALL LETTER VEND",NULL},
/* A76A */ { "LATIN CAPITAL LETTER ET","	x (latin capital letter reversed open e - A7AB)"},
/* A76B */ { "LATIN SMALL LETTER ET","	x (latin small letter yogh - 021D)"},
/* A76C */ { "LATIN CAPITAL LETTER IS",NULL},
/* A76D */ { "LATIN SMALL LETTER IS",NULL},
/* A76E */ { "LATIN CAPITAL LETTER CON","	x (digit nine - 0039)"},
/* A76F */ { "LATIN SMALL LETTER CON",NULL},
/* A770 */ { "MODIFIER LETTER US","	x (superscript nine - 2079)\n"
	"	# <super> A76F"},
/* A771 */ { "LATIN SMALL LETTER DUM",NULL},
/* A772 */ { "LATIN SMALL LETTER LUM",NULL},
/* A773 */ { "LATIN SMALL LETTER MUM",NULL},
/* A774 */ { "LATIN SMALL LETTER NUM",NULL},
/* A775 */ { "LATIN SMALL LETTER RUM",NULL},
/* A776 */ { "LATIN LETTER SMALL CAPITAL RUM",NULL},
/* A777 */ { "LATIN SMALL LETTER TUM",NULL},
/* A778 */ { "LATIN SMALL LETTER UM",NULL},
/* A779 */ { "LATIN CAPITAL LETTER INSULAR D",NULL},
/* A77A */ { "LATIN SMALL LETTER INSULAR D","	* dental fricative [ð]\n"
	"	x (latin small letter eth - 00F0)\n"
	"	x (latin small letter delta - 1E9F)"},
/* A77B */ { "LATIN CAPITAL LETTER INSULAR F",NULL},
/* A77C */ { "LATIN SMALL LETTER INSULAR F",NULL},
/* A77D */ { "LATIN CAPITAL LETTER INSULAR G","	* lowercase is 1D79\n"
	"	x (latin capital letter closed insular g - A7D0)"},
/* A77E */ { "LATIN CAPITAL LETTER TURNED INSULAR G",NULL},
/* A77F */ { "LATIN SMALL LETTER TURNED INSULAR G","	* velar nasal [ŋ]\n"
	"	x (latin small letter turned g - 1D77)"},
/* A780 */ { "LATIN CAPITAL LETTER TURNED L",NULL},
/* A781 */ { "LATIN SMALL LETTER TURNED L","	* voiceless alveolar lateral fricative [ɬ]"},
/* A782 */ { "LATIN CAPITAL LETTER INSULAR R",NULL},
/* A783 */ { "LATIN SMALL LETTER INSULAR R","	x (latin small letter r with long leg - 027C)"},
/* A784 */ { "LATIN CAPITAL LETTER INSULAR S",NULL},
/* A785 */ { "LATIN SMALL LETTER INSULAR S","	x (latin small letter long s - 017F)"},
/* A786 */ { "LATIN CAPITAL LETTER INSULAR T",NULL},
/* A787 */ { "LATIN SMALL LETTER INSULAR T","	* voiceless dental fricative [θ]"},
/* A788 */ { "MODIFIER LETTER LOW CIRCUMFLEX ACCENT","	* used as a tone letter for Lahu and Akha\n"
	"	x (modifier letter circumflex accent - 02C6)\n"
	"	x (modifier letter low up arrowhead - 02F0)\n"
	"	x (caret - 2038)"},
/* A789 */ { "MODIFIER LETTER COLON","	* used as a tone letter in some orthographies\n"
	"	* Budu (Congo), Sabaot (Kenya), Grebo (Liberia), and several Papua New Guinea languages\n"
	"	x (colon - 003A)\n"
	"	x (modifier letter triangular colon - 02D0)\n"
	"	x (modifier letter raised colon - 02F8)\n"
	"	x (lisu letter tone mya jeu - A4FD)"},
/* A78A */ { "MODIFIER LETTER SHORT EQUALS SIGN","	* used as a tone letter for Budu\n"
	"	x (equals sign - 003D)\n"
	"	x (modifier letter unaspirated - 02ED)\n"
	"	x (double hyphen - 2E40)\n"
	"	x (small equals sign - FE66)"},
/* A78B */ { "LATIN CAPITAL LETTER SALTILLO","	* Me'phaa (Mexico)"},
/* A78C */ { "LATIN SMALL LETTER SALTILLO","	* saltillos are used as a casing pair for glottal stop in some orthographies\n"
	"	* the lowercase is widely used in many languages in Mexico and other regions, including Izere in Nigeria\n"
	"	x (apostrophe - 0027)\n"
	"	x (latin small letter glottal stop - 0242)\n"
	"	x (latin letter glottal stop - 0294)\n"
	"	x (modifier letter apostrophe - 02BC)\n"
	"	x (modifier letter glottal stop - 02C0)"},
/* A78D */ { "LATIN CAPITAL LETTER TURNED H","	* used in the Dan/Gio orthography in Liberia\n"
	"	* also historically used in Latin-based orthographies for Abaza and Abkhaz\n"
	"	* lowercase is 0265\n"
	"	x (cyrillic capital letter che - 0427)"},
/* A78E */ { "LATIN SMALL LETTER L WITH RETROFLEX HOOK AND BELT","	* voiceless lateral retroflex fricative\n"
	"	* used to transcribe Toda\n"
	"	x (latin small letter l with belt - 026C)"},
/* A78F */ { "LATIN LETTER SINOLOGICAL DOT","	* used in transliteration of Phags-Pa and in phonetic transcription of Tangut\n"
	"	x (middle dot - 00B7)\n"
	"	x (bullet - 2022)"},
/* A790 */ { "LATIN CAPITAL LETTER N WITH DESCENDER",NULL},
/* A791 */ { "LATIN SMALL LETTER N WITH DESCENDER","	* velar nasal [ŋ]\n"
	"	* Yañalif\n"
	"	x (latin small letter eng - 014B)\n"
	"	x (latin small letter n with long right leg - 019E)\n"
	"	x (cyrillic small letter en with descender - 04A3)"},
/* A792 */ { "LATIN CAPITAL LETTER C WITH BAR","	= Cambrian symbol\n"
	"	x (euro sign - 20AC)"},
/* A793 */ { "LATIN SMALL LETTER C WITH BAR","	* voiceless postalveolar affricate [tʃ]\n"
	"	* Nanai, ...\n"
	"	x (cyrillic small letter ukrainian ie - 0454)"},
/* A794 */ { "LATIN SMALL LETTER C WITH PALATAL HOOK","	* uppercase is A7C4"},
/* A795 */ { "LATIN SMALL LETTER H WITH PALATAL HOOK","	x (latin small letter heng - A727)"},
/* A796 */ { "LATIN CAPITAL LETTER B WITH FLOURISH",NULL},
/* A797 */ { "LATIN SMALL LETTER B WITH FLOURISH",NULL},
/* A798 */ { "LATIN CAPITAL LETTER F WITH STROKE","	x (latin capital letter f with hook - 0191)\n"
	"	x (french franc sign - 20A3)"},
/* A799 */ { "LATIN SMALL LETTER F WITH STROKE","	* old Ewe orthography\n"
	"	* also used in the Anthropos phonetic alphabet"},
/* A79A */ { "LATIN CAPITAL LETTER VOLAPUK AE",NULL},
/* A79B */ { "LATIN SMALL LETTER VOLAPUK AE",NULL},
/* A79C */ { "LATIN CAPITAL LETTER VOLAPUK OE",NULL},
/* A79D */ { "LATIN SMALL LETTER VOLAPUK OE",NULL},
/* A79E */ { "LATIN CAPITAL LETTER VOLAPUK UE",NULL},
/* A79F */ { "LATIN SMALL LETTER VOLAPUK UE",NULL},
/* A7A0 */ { "LATIN CAPITAL LETTER G WITH OBLIQUE STROKE",NULL},
/* A7A1 */ { "LATIN SMALL LETTER G WITH OBLIQUE STROKE",NULL},
/* A7A2 */ { "LATIN CAPITAL LETTER K WITH OBLIQUE STROKE",NULL},
/* A7A3 */ { "LATIN SMALL LETTER K WITH OBLIQUE STROKE",NULL},
/* A7A4 */ { "LATIN CAPITAL LETTER N WITH OBLIQUE STROKE",NULL},
/* A7A5 */ { "LATIN SMALL LETTER N WITH OBLIQUE STROKE",NULL},
/* A7A6 */ { "LATIN CAPITAL LETTER R WITH OBLIQUE STROKE",NULL},
/* A7A7 */ { "LATIN SMALL LETTER R WITH OBLIQUE STROKE",NULL},
/* A7A8 */ { "LATIN CAPITAL LETTER S WITH OBLIQUE STROKE",NULL},
/* A7A9 */ { "LATIN SMALL LETTER S WITH OBLIQUE STROKE","	* also used in pre-1950 Lower Sorbian orthography\n"
	"	x (latin small letter long s with diagonal stroke - 1E9C)\n"
	"	x (latin small letter s with short stroke overlay - A7CA)"},
/* A7AA */ { "LATIN CAPITAL LETTER H WITH HOOK","	* lowercase is 0266\n"
	"	* used in Chad"},
/* A7AB */ { "LATIN CAPITAL LETTER REVERSED OPEN E","	* lowercase is 025C\n"
	"	x (latin capital letter ezh - 01B7)\n"
	"	x (latin capital letter yogh - 021C)\n"
	"	x (cyrillic capital letter ze - 0417)"},
/* A7AC */ { "LATIN CAPITAL LETTER SCRIPT G","	* lowercase is 0261"},
/* A7AD */ { "LATIN CAPITAL LETTER L WITH BELT","	* lowercase is 026C\n"
	"	x (latin capital letter l with bar - 023D)\n"
	"	x (latin letter small capital l with belt - 1DF04)"},
/* A7AE */ { "LATIN CAPITAL LETTER SMALL CAPITAL I","	* lowercase is 026A\n"
	"	* also used in Unifon\n"
	"	x (latin capital letter i - 0049)\n"
	"	x (latin letter small capital i - 026A)"},
/* A7AF */ { "LATIN LETTER SMALL CAPITAL Q","	* used to represent gemination\n"
	"	x (modifier letter capital q - A7F4)"},
/* A7B0 */ { "LATIN CAPITAL LETTER TURNED K","	* lowercase is 029E"},
/* A7B1 */ { "LATIN CAPITAL LETTER TURNED T","	* lowercase is 0287\n"
	"	* also used in Unifon"},
/* A7B2 */ { "LATIN CAPITAL LETTER J WITH CROSSED-TAIL","	* lowercase is 029D"},
/* A7B3 */ { "LATIN CAPITAL LETTER CHI","	* lowercase is AB53\n"
	"	x (greek capital letter chi - 03A7)"},
/* A7B4 */ { "LATIN CAPITAL LETTER BETA",NULL},
/* A7B5 */ { "LATIN SMALL LETTER BETA","	x (latin small letter sharp s - 00DF)\n"
	"	x (greek small letter beta - 03B2)"},
/* A7B6 */ { "LATIN CAPITAL LETTER OMEGA",NULL},
/* A7B7 */ { "LATIN SMALL LETTER OMEGA","	x (latin small letter closed omega - 0277)\n"
	"	x (greek small letter omega - 03C9)\n"
	"	x (cyrillic small letter omega - 0461)\n"
	"	x (cyrillic small letter broad omega - A64D)"},
/* A7B8 */ { "LATIN CAPITAL LETTER U WITH STROKE",NULL},
/* A7B9 */ { "LATIN SMALL LETTER U WITH STROKE",NULL},
/* A7BA */ { "LATIN CAPITAL LETTER GLOTTAL A",NULL},
/* A7BB */ { "LATIN SMALL LETTER GLOTTAL A",NULL},
/* A7BC */ { "LATIN CAPITAL LETTER GLOTTAL I",NULL},
/* A7BD */ { "LATIN SMALL LETTER GLOTTAL I","	= egyptological yod\n"
	"	x (latin small letter egyptological alef - A723)\n"
	"	x (latin small letter egyptological ain - A725)"},
/* A7BE */ { "LATIN CAPITAL LETTER GLOTTAL U",NULL},
/* A7BF */ { "LATIN SMALL LETTER GLOTTAL U",NULL},
/* A7C0 */ { "LATIN CAPITAL LETTER OLD POLISH O",NULL},
/* A7C1 */ { "LATIN SMALL LETTER OLD POLISH O","	* used in Old Polish as a nasal vowel\n"
	"	x (latin small letter o with stroke - 00F8)"},
/* A7C2 */ { "LATIN CAPITAL LETTER ANGLICANA W",NULL},
/* A7C3 */ { "LATIN SMALL LETTER ANGLICANA W","	* used in medieval English and Cornish"},
/* A7C4 */ { "LATIN CAPITAL LETTER C WITH PALATAL HOOK","	* lowercase is A794"},
/* A7C5 */ { "LATIN CAPITAL LETTER S WITH HOOK","	* lowercase is 0282"},
/* A7C6 */ { "LATIN CAPITAL LETTER Z WITH PALATAL HOOK","	* lowercase is 1D8E"},
/* A7C7 */ { "LATIN CAPITAL LETTER D WITH SHORT STROKE OVERLAY","	x (latin capital letter eth - 00D0)\n"
	"	x (latin capital letter d with stroke - 0110)"},
/* A7C8 */ { "LATIN SMALL LETTER D WITH SHORT STROKE OVERLAY","	= tau gallicum\n"
	"	* indicates a dental affricate\n"
	"	x (latin small letter d with stroke - 0111)"},
/* A7C9 */ { "LATIN CAPITAL LETTER S WITH SHORT STROKE OVERLAY",NULL},
/* A7CA */ { "LATIN SMALL LETTER S WITH SHORT STROKE OVERLAY","	* attested in handwritten documents used in pairs as an alternate tau gallicum"},
/* A7CB */ { "LATIN CAPITAL LETTER RAMS HORN","	* lowercase is 0264"},
/* A7CC */ { "LATIN CAPITAL LETTER S WITH DIAGONAL STROKE",NULL},
/* A7CD */ { "LATIN SMALL LETTER S WITH DIAGONAL STROKE",NULL},
/* A7CE */ { "LATIN CAPITAL LETTER PHARYNGEAL VOICED FRICATIVE",NULL},
/* A7CF */ { "LATIN SMALL LETTER PHARYNGEAL VOICED FRICATIVE","	x (latin letter pharyngeal voiced fricative - 0295)"},
/* A7D0 */ { "LATIN CAPITAL LETTER CLOSED INSULAR G",NULL},
/* A7D1 */ { "LATIN SMALL LETTER CLOSED INSULAR G","	x (latin small letter insular g - 1D79)"},
/* A7D2 */ { "LATIN CAPITAL LETTER DOUBLE THORN",NULL},
/* A7D3 */ { "LATIN SMALL LETTER DOUBLE THORN","	x (latin small letter thorn - 00FE)"},
/* A7D4 */ { "LATIN CAPITAL LETTER DOUBLE WYNN",NULL},
/* A7D5 */ { "LATIN SMALL LETTER DOUBLE WYNN","	x (latin letter wynn - 01BF)"},
/* A7D6 */ { "LATIN CAPITAL LETTER MIDDLE SCOTS S",NULL},
/* A7D7 */ { "LATIN SMALL LETTER MIDDLE SCOTS S","	* used in Middle Scots for s, ss, ser, sir, is, sis, etc.\n"
	"	x (latin small letter sharp s - 00DF)"},
/* A7D8 */ { "LATIN CAPITAL LETTER SIGMOID S",NULL},
/* A7D9 */ { "LATIN SMALL LETTER SIGMOID S","	* used in Middle Cornish, Middle English, and Middle Scots"},
/* A7DA */ { "LATIN CAPITAL LETTER LAMBDA",NULL},
/* A7DB */ { "LATIN SMALL LETTER LAMBDA","	x (greek small letter lamda - 03BB)"},
/* A7DC */ { "LATIN CAPITAL LETTER LAMBDA WITH STROKE","	* lowercase is 019B "},
/* A7DD */ { NULL,NULL},
/* A7DE */ { NULL,NULL},
/* A7DF */ { NULL,NULL},
/* A7E0 */ { NULL,NULL},
/* A7E1 */ { NULL,NULL},
/* A7E2 */ { NULL,NULL},
/* A7E3 */ { NULL,NULL},
/* A7E4 */ { NULL,NULL},
/* A7E5 */ { NULL,NULL},
/* A7E6 */ { NULL,NULL},
/* A7E7 */ { NULL,NULL},
/* A7E8 */ { NULL,NULL},
/* A7E9 */ { NULL,NULL},
/* A7EA */ { NULL,NULL},
/* A7EB */ { NULL,NULL},
/* A7EC */ { NULL,NULL},
/* A7ED */ { NULL,NULL},
/* A7EE */ { NULL,NULL},
/* A7EF */ { NULL,NULL},
/* A7F0 */ { NULL,NULL},
/* A7F1 */ { "MODIFIER LETTER CAPITAL S","	# <super> 0053"},
/* A7F2 */ { "MODIFIER LETTER CAPITAL C","	# <super> 0043"},
/* A7F3 */ { "MODIFIER LETTER CAPITAL F","	# <super> 0046"},
/* A7F4 */ { "MODIFIER LETTER CAPITAL Q","	x (latin letter small capital q - A7AF)\n"
	"	# <super> 0051"},
/* A7F5 */ { "LATIN CAPITAL LETTER REVERSED HALF H","	= H dimidié\n"
	"	* appears in inscriptions from the Roman provinces of Gaul\n"
	"	x (latin capital letter half h - 2C75)"},
/* A7F6 */ { "LATIN SMALL LETTER REVERSED HALF H","	* the lowercase is not attested in inscriptions but is used by scholars when transcribing"},
/* A7F7 */ { "LATIN EPIGRAPHIC LETTER SIDEWAYS I","	* Celtic inscriptions"},
/* A7F8 */ { "MODIFIER LETTER CAPITAL H WITH STROKE","	# <super> 0126\n"
	"		A typographical distinction between a capital form and a small capital form is not distinctive for this character in IPA usage.\n"
	"	* faucalized\n"
	"	x (latin letter small capital h - 029C)"},
/* A7F9 */ { "MODIFIER LETTER SMALL LIGATURE OE","	* labialized: open-rounded\n"
	"	# <super> 0153"},
/* A7FA */ { "LATIN LETTER SMALL CAPITAL TURNED M","	* voiceless closed central vowel\n"
	"	x (latin small letter turned m - 026F)\n"
	"	x (cyrillic small letter sha - 0448)"},
/* A7FB */ { "LATIN EPIGRAPHIC LETTER REVERSED F","	= filia (daughter), femina (woman, female)"},
/* A7FC */ { "LATIN EPIGRAPHIC LETTER REVERSED P","	= puella (girl)"},
/* A7FD */ { "LATIN EPIGRAPHIC LETTER INVERTED M","	= mulier, matrona (married woman)\n"
	"	x (latin capital letter turned m - 019C)"},
/* A7FE */ { "LATIN EPIGRAPHIC LETTER I LONGA",NULL},
/* A7FF */ { "LATIN EPIGRAPHIC LETTER ARCHAIC M","	* logograph for the praenomen \"Manius\""}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_00_A8[] = {
/* A800 */ { "SYLOTI NAGRI LETTER A",NULL},
/* A801 */ { "SYLOTI NAGRI LETTER I",NULL},
/* A802 */ { "SYLOTI NAGRI SIGN DVISVARA",NULL},
/* A803 */ { "SYLOTI NAGRI LETTER U",NULL},
/* A804 */ { "SYLOTI NAGRI LETTER E",NULL},
/* A805 */ { "SYLOTI NAGRI LETTER O",NULL},
/* A806 */ { "SYLOTI NAGRI SIGN HASANTA","	= halant, virama\n"
	"	* forms conjuncts"},
/* A807 */ { "SYLOTI NAGRI LETTER KO",NULL},
/* A808 */ { "SYLOTI NAGRI LETTER KHO",NULL},
/* A809 */ { "SYLOTI NAGRI LETTER GO",NULL},
/* A80A */ { "SYLOTI NAGRI LETTER GHO",NULL},
/* A80B */ { "SYLOTI NAGRI SIGN ANUSVARA",NULL},
/* A80C */ { "SYLOTI NAGRI LETTER CO",NULL},
/* A80D */ { "SYLOTI NAGRI LETTER CHO",NULL},
/* A80E */ { "SYLOTI NAGRI LETTER JO",NULL},
/* A80F */ { "SYLOTI NAGRI LETTER JHO",NULL},
/* A810 */ { "SYLOTI NAGRI LETTER TTO",NULL},
/* A811 */ { "SYLOTI NAGRI LETTER TTHO",NULL},
/* A812 */ { "SYLOTI NAGRI LETTER DDO",NULL},
/* A813 */ { "SYLOTI NAGRI LETTER DDHO",NULL},
/* A814 */ { "SYLOTI NAGRI LETTER TO",NULL},
/* A815 */ { "SYLOTI NAGRI LETTER THO",NULL},
/* A816 */ { "SYLOTI NAGRI LETTER DO",NULL},
/* A817 */ { "SYLOTI NAGRI LETTER DHO",NULL},
/* A818 */ { "SYLOTI NAGRI LETTER NO",NULL},
/* A819 */ { "SYLOTI NAGRI LETTER PO",NULL},
/* A81A */ { "SYLOTI NAGRI LETTER PHO",NULL},
/* A81B */ { "SYLOTI NAGRI LETTER BO",NULL},
/* A81C */ { "SYLOTI NAGRI LETTER BHO",NULL},
/* A81D */ { "SYLOTI NAGRI LETTER MO",NULL},
/* A81E */ { "SYLOTI NAGRI LETTER RO",NULL},
/* A81F */ { "SYLOTI NAGRI LETTER LO",NULL},
/* A820 */ { "SYLOTI NAGRI LETTER RRO",NULL},
/* A821 */ { "SYLOTI NAGRI LETTER SO",NULL},
/* A822 */ { "SYLOTI NAGRI LETTER HO",NULL},
/* A823 */ { "SYLOTI NAGRI VOWEL SIGN A",NULL},
/* A824 */ { "SYLOTI NAGRI VOWEL SIGN I",NULL},
/* A825 */ { "SYLOTI NAGRI VOWEL SIGN U",NULL},
/* A826 */ { "SYLOTI NAGRI VOWEL SIGN E",NULL},
/* A827 */ { "SYLOTI NAGRI VOWEL SIGN OO",NULL},
/* A828 */ { "SYLOTI NAGRI POETRY MARK-1",NULL},
/* A829 */ { "SYLOTI NAGRI POETRY MARK-2",NULL},
/* A82A */ { "SYLOTI NAGRI POETRY MARK-3",NULL},
/* A82B */ { "SYLOTI NAGRI POETRY MARK-4",NULL},
/* A82C */ { "SYLOTI NAGRI SIGN ALTERNATE HASANTA","	= killer\n"
	"	* does not form conjuncts"},
/* A82D */ { NULL,NULL},
/* A82E */ { NULL,NULL},
/* A82F */ { NULL,NULL},
/* A830 */ { "NORTH INDIC FRACTION ONE QUARTER","	* this and some of the following fractions are also used in some South Indic scripts, including Kannada and Malayalam"},
/* A831 */ { "NORTH INDIC FRACTION ONE HALF",NULL},
/* A832 */ { "NORTH INDIC FRACTION THREE QUARTERS",NULL},
/* A833 */ { "NORTH INDIC FRACTION ONE SIXTEENTH",NULL},
/* A834 */ { "NORTH INDIC FRACTION ONE EIGHTH",NULL},
/* A835 */ { "NORTH INDIC FRACTION THREE SIXTEENTHS",NULL},
/* A836 */ { "NORTH INDIC QUARTER MARK",NULL},
/* A837 */ { "NORTH INDIC PLACEHOLDER MARK","	* indicates the absence of an intermediate unit in a currency value"},
/* A838 */ { "NORTH INDIC RUPEE MARK","	x (bengali rupee mark - 09F2)"},
/* A839 */ { "NORTH INDIC QUANTITY MARK","	* a unit mark for various weights and measures"},
/* A83A */ { NULL,NULL},
/* A83B */ { NULL,NULL},
/* A83C */ { NULL,NULL},
/* A83D */ { NULL,NULL},
/* A83E */ { NULL,NULL},
/* A83F */ { NULL,NULL},
/* A840 */ { "PHAGS-PA LETTER KA","	* Mongolian, Chinese, Tibetan, Sanskrit\n"
	"	x (tibetan letter ka - 0F40)"},
/* A841 */ { "PHAGS-PA LETTER KHA","	x (tibetan letter kha - 0F41)"},
/* A842 */ { "PHAGS-PA LETTER GA","	x (tibetan letter ga - 0F42)"},
/* A843 */ { "PHAGS-PA LETTER NGA","	* Mongolian, Chinese, Tibetan, Sanskrit\n"
	"	x (tibetan letter nga - 0F44)"},
/* A844 */ { "PHAGS-PA LETTER CA","	* Chinese, Tibetan\n"
	"	x (tibetan letter ca - 0F45)"},
/* A845 */ { "PHAGS-PA LETTER CHA","	* Mongolian, Chinese, Uyghur, Tibetan\n"
	"	x (tibetan letter cha - 0F46)"},
/* A846 */ { "PHAGS-PA LETTER JA","	* Mongolian, Chinese, Uyghur, Tibetan\n"
	"	x (tibetan letter ja - 0F47)"},
/* A847 */ { "PHAGS-PA LETTER NYA","	* Chinese, Tibetan, Sanskrit\n"
	"	x (tibetan letter nya - 0F49)"},
/* A848 */ { "PHAGS-PA LETTER TA","	* Mongolian, Chinese, Tibetan, Sanskrit\n"
	"	x (tibetan letter ta - 0F4F)"},
/* A849 */ { "PHAGS-PA LETTER THA","	x (tibetan letter tha - 0F50)"},
/* A84A */ { "PHAGS-PA LETTER DA","	x (tibetan letter da - 0F51)"},
/* A84B */ { "PHAGS-PA LETTER NA","	x (tibetan letter na - 0F53)"},
/* A84C */ { "PHAGS-PA LETTER PA","	* Mongolian, Chinese, Tibetan, Sanskrit\n"
	"	x (tibetan letter pa - 0F54)"},
/* A84D */ { "PHAGS-PA LETTER PHA","	* Chinese, Tibetan, Sanskrit\n"
	"	x (tibetan letter pha - 0F55)"},
/* A84E */ { "PHAGS-PA LETTER BA","	x (tibetan letter ba - 0F56)"},
/* A84F */ { "PHAGS-PA LETTER MA","	x (tibetan letter ma - 0F58)"},
/* A850 */ { "PHAGS-PA LETTER TSA","	* Chinese, Tibetan, Sanskrit\n"
	"	x (tibetan letter tsa - 0F59)"},
/* A851 */ { "PHAGS-PA LETTER TSHA","	* Mongolian, Chinese, Tibetan, Sanskrit\n"
	"	x (tibetan letter tsha - 0F5A)"},
/* A852 */ { "PHAGS-PA LETTER DZA","	* Chinese, Tibetan, Sanskrit\n"
	"	x (tibetan letter dza - 0F5B)"},
/* A853 */ { "PHAGS-PA LETTER WA","	x (tibetan letter wa - 0F5D)"},
/* A854 */ { "PHAGS-PA LETTER ZHA","	* Chinese, Tibetan\n"
	"	x (tibetan letter zha - 0F5E)"},
/* A855 */ { "PHAGS-PA LETTER ZA","	* Mongolian, Chinese, Tibetan\n"
	"	x (tibetan letter za - 0F5F)"},
/* A856 */ { "PHAGS-PA LETTER SMALL A","	x (tibetan letter -a - 0F60)\n"
	"	~ A856 FE00 phags-pa letter reversed shaping small a"},
/* A857 */ { "PHAGS-PA LETTER YA","	x (tibetan letter ya - 0F61)"},
/* A858 */ { "PHAGS-PA LETTER RA","	* Mongolian, Uyghur, Tibetan, Sanskrit\n"
	"	x (tibetan letter ra - 0F62)"},
/* A859 */ { "PHAGS-PA LETTER LA","	x (tibetan letter la - 0F63)"},
/* A85A */ { "PHAGS-PA LETTER SHA","	x (tibetan letter sha - 0F64)"},
/* A85B */ { "PHAGS-PA LETTER SA","	x (tibetan letter sa - 0F66)"},
/* A85C */ { "PHAGS-PA LETTER HA","	x (tibetan letter ha - 0F67)\n"
	"	~ A85C FE00 phags-pa letter reversed shaping ha"},
/* A85D */ { "PHAGS-PA LETTER A","	x (tibetan letter a - 0F68)"},
/* A85E */ { "PHAGS-PA LETTER I","	x (tibetan vowel sign i - 0F72)\n"
	"	~ A85E FE00 phags-pa letter reversed shaping i"},
/* A85F */ { "PHAGS-PA LETTER U","	x (tibetan vowel sign u - 0F74)\n"
	"	~ A85F FE00 phags-pa letter reversed shaping u"},
/* A860 */ { "PHAGS-PA LETTER E","	x (tibetan vowel sign e - 0F7A)\n"
	"	~ A860 FE00 phags-pa letter reversed shaping e"},
/* A861 */ { "PHAGS-PA LETTER O","	x (tibetan vowel sign o - 0F7C)"},
/* A862 */ { "PHAGS-PA LETTER QA","	* Mongolian, Uyghur"},
/* A863 */ { "PHAGS-PA LETTER XA","	* Mongolian, Chinese"},
/* A864 */ { "PHAGS-PA LETTER FA","	* Chinese, Uyghur\n"
	"	x (phags-pa letter ha - A85C)"},
/* A865 */ { "PHAGS-PA LETTER GGA","	* language usage unknown\n"
	"	* created by reversal of A862"},
/* A866 */ { "PHAGS-PA LETTER EE","	* Mongolian, Chinese, Uyghur"},
/* A867 */ { "PHAGS-PA SUBJOINED LETTER WA","	* Chinese, Tibetan, Sanskrit\n"
	"	x (tibetan subjoined letter wa - 0FAD)"},
/* A868 */ { "PHAGS-PA SUBJOINED LETTER YA","	* Chinese, Tibetan, Sanskrit\n"
	"	x (tibetan subjoined letter ya - 0FB1)\n"
	"	~ A868 FE00 phags-pa letter reversed shaping subjoined ya"},
/* A869 */ { "PHAGS-PA LETTER TTA","	* Sanskrit\n"
	"	x (tibetan letter tta - 0F4A)"},
/* A86A */ { "PHAGS-PA LETTER TTHA","	* Sanskrit\n"
	"	x (tibetan letter ttha - 0F4B)"},
/* A86B */ { "PHAGS-PA LETTER DDA","	* Sanskrit\n"
	"	x (tibetan letter dda - 0F4C)"},
/* A86C */ { "PHAGS-PA LETTER NNA","	* Sanskrit\n"
	"	x (tibetan letter nna - 0F4E)"},
/* A86D */ { "PHAGS-PA LETTER ALTERNATE YA","	* Chinese\n"
	"	x (phags-pa letter ya - A857)"},
/* A86E */ { "PHAGS-PA LETTER VOICELESS SHA","	* Chinese\n"
	"	x (phags-pa letter sha - A85A)"},
/* A86F */ { "PHAGS-PA LETTER VOICED HA","	* Chinese\n"
	"	x (phags-pa letter ha - A85C)"},
/* A870 */ { "PHAGS-PA LETTER ASPIRATED FA","	* Chinese\n"
	"	x (phags-pa letter fa - A864)"},
/* A871 */ { "PHAGS-PA SUBJOINED LETTER RA","	* Tibetan, Sanskrit\n"
	"	x (tibetan subjoined letter ra - 0FB2)"},
/* A872 */ { "PHAGS-PA SUPERFIXED LETTER RA","	* Tibetan\n"
	"	x (tibetan letter ra - 0F62)"},
/* A873 */ { "PHAGS-PA LETTER CANDRABINDU","	* Sanskrit\n"
	"	x (tibetan sign sna ldan - 0F83)\n"
	"	x (tibetan sign rjes su nga ro - 0F7E)\n"
	"	x (mongolian letter ali gali anusvara one - 1880)"},
/* A874 */ { "PHAGS-PA SINGLE HEAD MARK","	* Tibetan\n"
	"	* marks beginning of text\n"
	"	x (tibetan mark initial yig mgo mdun ma - 0F04)\n"
	"	x (mongolian birga - 1800)"},
/* A875 */ { "PHAGS-PA DOUBLE HEAD MARK","	* Tibetan\n"
	"	* marks beginning of text"},
/* A876 */ { "PHAGS-PA MARK SHAD","	* Tibetan\n"
	"	x (tibetan mark shad - 0F0D)"},
/* A877 */ { "PHAGS-PA MARK DOUBLE SHAD","	* Tibetan\n"
	"	x (tibetan mark nyis shad - 0F0E)"},
/* A878 */ { NULL,NULL},
/* A879 */ { NULL,NULL},
/* A87A */ { NULL,NULL},
/* A87B */ { NULL,NULL},
/* A87C */ { NULL,NULL},
/* A87D */ { NULL,NULL},
/* A87E */ { NULL,NULL},
/* A87F */ { NULL,NULL},
/* A880 */ { "SAURASHTRA SIGN ANUSVARA",NULL},
/* A881 */ { "SAURASHTRA SIGN VISARGA",NULL},
/* A882 */ { "SAURASHTRA LETTER A",NULL},
/* A883 */ { "SAURASHTRA LETTER AA",NULL},
/* A884 */ { "SAURASHTRA LETTER I",NULL},
/* A885 */ { "SAURASHTRA LETTER II",NULL},
/* A886 */ { "SAURASHTRA LETTER U",NULL},
/* A887 */ { "SAURASHTRA LETTER UU",NULL},
/* A888 */ { "SAURASHTRA LETTER VOCALIC R",NULL},
/* A889 */ { "SAURASHTRA LETTER VOCALIC RR",NULL},
/* A88A */ { "SAURASHTRA LETTER VOCALIC L",NULL},
/* A88B */ { "SAURASHTRA LETTER VOCALIC LL",NULL},
/* A88C */ { "SAURASHTRA LETTER E",NULL},
/* A88D */ { "SAURASHTRA LETTER EE",NULL},
/* A88E */ { "SAURASHTRA LETTER AI",NULL},
/* A88F */ { "SAURASHTRA LETTER O",NULL},
/* A890 */ { "SAURASHTRA LETTER OO",NULL},
/* A891 */ { "SAURASHTRA LETTER AU",NULL},
/* A892 */ { "SAURASHTRA LETTER KA",NULL},
/* A893 */ { "SAURASHTRA LETTER KHA",NULL},
/* A894 */ { "SAURASHTRA LETTER GA",NULL},
/* A895 */ { "SAURASHTRA LETTER GHA",NULL},
/* A896 */ { "SAURASHTRA LETTER NGA",NULL},
/* A897 */ { "SAURASHTRA LETTER CA",NULL},
/* A898 */ { "SAURASHTRA LETTER CHA",NULL},
/* A899 */ { "SAURASHTRA LETTER JA",NULL},
/* A89A */ { "SAURASHTRA LETTER JHA",NULL},
/* A89B */ { "SAURASHTRA LETTER NYA",NULL},
/* A89C */ { "SAURASHTRA LETTER TTA",NULL},
/* A89D */ { "SAURASHTRA LETTER TTHA",NULL},
/* A89E */ { "SAURASHTRA LETTER DDA",NULL},
/* A89F */ { "SAURASHTRA LETTER DDHA",NULL},
/* A8A0 */ { "SAURASHTRA LETTER NNA",NULL},
/* A8A1 */ { "SAURASHTRA LETTER TA",NULL},
/* A8A2 */ { "SAURASHTRA LETTER THA",NULL},
/* A8A3 */ { "SAURASHTRA LETTER DA",NULL},
/* A8A4 */ { "SAURASHTRA LETTER DHA",NULL},
/* A8A5 */ { "SAURASHTRA LETTER NA",NULL},
/* A8A6 */ { "SAURASHTRA LETTER PA",NULL},
/* A8A7 */ { "SAURASHTRA LETTER PHA",NULL},
/* A8A8 */ { "SAURASHTRA LETTER BA",NULL},
/* A8A9 */ { "SAURASHTRA LETTER BHA",NULL},
/* A8AA */ { "SAURASHTRA LETTER MA",NULL},
/* A8AB */ { "SAURASHTRA LETTER YA",NULL},
/* A8AC */ { "SAURASHTRA LETTER RA",NULL},
/* A8AD */ { "SAURASHTRA LETTER LA",NULL},
/* A8AE */ { "SAURASHTRA LETTER VA",NULL},
/* A8AF */ { "SAURASHTRA LETTER SHA",NULL},
/* A8B0 */ { "SAURASHTRA LETTER SSA",NULL},
/* A8B1 */ { "SAURASHTRA LETTER SA",NULL},
/* A8B2 */ { "SAURASHTRA LETTER HA",NULL},
/* A8B3 */ { "SAURASHTRA LETTER LLA",NULL},
/* A8B4 */ { "SAURASHTRA CONSONANT SIGN HAARU",NULL},
/* A8B5 */ { "SAURASHTRA VOWEL SIGN AA",NULL},
/* A8B6 */ { "SAURASHTRA VOWEL SIGN I",NULL},
/* A8B7 */ { "SAURASHTRA VOWEL SIGN II",NULL},
/* A8B8 */ { "SAURASHTRA VOWEL SIGN U",NULL},
/* A8B9 */ { "SAURASHTRA VOWEL SIGN UU",NULL},
/* A8BA */ { "SAURASHTRA VOWEL SIGN VOCALIC R",NULL},
/* A8BB */ { "SAURASHTRA VOWEL SIGN VOCALIC RR",NULL},
/* A8BC */ { "SAURASHTRA VOWEL SIGN VOCALIC L",NULL},
/* A8BD */ { "SAURASHTRA VOWEL SIGN VOCALIC LL",NULL},
/* A8BE */ { "SAURASHTRA VOWEL SIGN E",NULL},
/* A8BF */ { "SAURASHTRA VOWEL SIGN EE",NULL},
/* A8C0 */ { "SAURASHTRA VOWEL SIGN AI",NULL},
/* A8C1 */ { "SAURASHTRA VOWEL SIGN O",NULL},
/* A8C2 */ { "SAURASHTRA VOWEL SIGN OO",NULL},
/* A8C3 */ { "SAURASHTRA VOWEL SIGN AU",NULL},
/* A8C4 */ { "SAURASHTRA SIGN VIRAMA",NULL},
/* A8C5 */ { "SAURASHTRA SIGN CANDRABINDU",NULL},
/* A8C6 */ { NULL,NULL},
/* A8C7 */ { NULL,NULL},
/* A8C8 */ { NULL,NULL},
/* A8C9 */ { NULL,NULL},
/* A8CA */ { NULL,NULL},
/* A8CB */ { NULL,NULL},
/* A8CC */ { NULL,NULL},
/* A8CD */ { NULL,NULL},
/* A8CE */ { "SAURASHTRA DANDA",NULL},
/* A8CF */ { "SAURASHTRA DOUBLE DANDA",NULL},
/* A8D0 */ { "SAURASHTRA DIGIT ZERO",NULL},
/* A8D1 */ { "SAURASHTRA DIGIT ONE",NULL},
/* A8D2 */ { "SAURASHTRA DIGIT TWO",NULL},
/* A8D3 */ { "SAURASHTRA DIGIT THREE",NULL},
/* A8D4 */ { "SAURASHTRA DIGIT FOUR",NULL},
/* A8D5 */ { "SAURASHTRA DIGIT FIVE",NULL},
/* A8D6 */ { "SAURASHTRA DIGIT SIX",NULL},
/* A8D7 */ { "SAURASHTRA DIGIT SEVEN",NULL},
/* A8D8 */ { "SAURASHTRA DIGIT EIGHT",NULL},
/* A8D9 */ { "SAURASHTRA DIGIT NINE",NULL},
/* A8DA */ { NULL,NULL},
/* A8DB */ { NULL,NULL},
/* A8DC */ { NULL,NULL},
/* A8DD */ { NULL,NULL},
/* A8DE */ { NULL,NULL},
/* A8DF */ { NULL,NULL},
/* A8E0 */ { "COMBINING DEVANAGARI DIGIT ZERO","	= vaidika saamasvara anka shuunya"},
/* A8E1 */ { "COMBINING DEVANAGARI DIGIT ONE","	= vaidika saamasvara anka eka udaatta"},
/* A8E2 */ { "COMBINING DEVANAGARI DIGIT TWO","	= vaidika saamasvara anka dvi svarita"},
/* A8E3 */ { "COMBINING DEVANAGARI DIGIT THREE","	= vaidika saamasvara anka tri anudaatta"},
/* A8E4 */ { "COMBINING DEVANAGARI DIGIT FOUR","	= vaidika saamasvara anka chatur"},
/* A8E5 */ { "COMBINING DEVANAGARI DIGIT FIVE","	= vaidika saamasvara anka pancha"},
/* A8E6 */ { "COMBINING DEVANAGARI DIGIT SIX","	= vaidika saamasvara anka shatt"},
/* A8E7 */ { "COMBINING DEVANAGARI DIGIT SEVEN","	= vaidika saamasvara anka sapta"},
/* A8E8 */ { "COMBINING DEVANAGARI DIGIT EIGHT","	= vaidika saamasvara anka ashta"},
/* A8E9 */ { "COMBINING DEVANAGARI DIGIT NINE","	= vaidika saamasvara anka nava"},
/* A8EA */ { "COMBINING DEVANAGARI LETTER A","	= vaidika saamasvara abhinihita"},
/* A8EB */ { "COMBINING DEVANAGARI LETTER U","	= vaidika saamasvara u"},
/* A8EC */ { "COMBINING DEVANAGARI LETTER KA","	= vaidika saamasvara ka"},
/* A8ED */ { "COMBINING DEVANAGARI LETTER NA","	= vaidika saamasvara namana"},
/* A8EE */ { "COMBINING DEVANAGARI LETTER PA","	= vaidika saamasvara prannatam"},
/* A8EF */ { "COMBINING DEVANAGARI LETTER RA","	= vaidika saamasvara ra"},
/* A8F0 */ { "COMBINING DEVANAGARI LETTER VI","	= vaidika saamasvara vinata"},
/* A8F1 */ { "COMBINING DEVANAGARI SIGN AVAGRAHA","	= vaidika saamasvara diirghiibhaava"},
/* A8F2 */ { "DEVANAGARI SIGN SPACING CANDRABINDU","	= vaidika candrabindu\n"
	"	x (devanagari sign candrabindu - 0901)"},
/* A8F3 */ { "DEVANAGARI SIGN CANDRABINDU VIRAMA","	= vaidika anusvaara candrabindu tiryak"},
/* A8F4 */ { "DEVANAGARI SIGN DOUBLE CANDRABINDU VIRAMA","	= vaidika anusvaara dvi candrabindu tiryak"},
/* A8F5 */ { "DEVANAGARI SIGN CANDRABINDU TWO","	= vaidika anusvaara candrabindu sa-dvi"},
/* A8F6 */ { "DEVANAGARI SIGN CANDRABINDU THREE","	= vaidika anusvaara candrabindu sa-tri"},
/* A8F7 */ { "DEVANAGARI SIGN CANDRABINDU AVAGRAHA","	= vaidika anusvaara candrabindu sa-avagraha"},
/* A8F8 */ { "DEVANAGARI SIGN PUSHPIKA","	= vaidika pushpikaa\n"
	"	* used as a placeholder or \"filler\"\n"
	"	* often flanked by double dandas"},
/* A8F9 */ { "DEVANAGARI GAP FILLER","	* used to indicate that a gap in a manuscript or text is not a lacuna"},
/* A8FA */ { "DEVANAGARI CARET","	= vaidika trutikaa\n"
	"	* zero-advance character centered on the point between two orthographic syllables\n"
	"	* used for insertion of characters\n"
	"	x (caret - 2038)"},
/* A8FB */ { "DEVANAGARI HEADSTROKE","	= shirorekhaa\n"
	"	* used to indicate uncertain manuscript readings\n"
	"	x (sharada headstroke - 111DC)"},
/* A8FC */ { "DEVANAGARI SIGN SIDDHAM","	= siddhirastu\n"
	"	* used at the beginning of texts as an invocation\n"
	"	x (telugu sign siddham - 0C77)\n"
	"	x (kannada sign siddham - 0C84)\n"
	"	x (tibetan mark initial yig mgo mdun ma - 0F04)\n"
	"	x (mongolian birga - 1800)\n"
	"	x (sharada sign siddham - 111DB)"},
/* A8FD */ { "DEVANAGARI JAIN OM",NULL},
/* A8FE */ { "DEVANAGARI LETTER AY",NULL},
/* A8FF */ { "DEVANAGARI VOWEL SIGN AY",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_00_A9[] = {
/* A900 */ { "KAYAH LI DIGIT ZERO",NULL},
/* A901 */ { "KAYAH LI DIGIT ONE",NULL},
/* A902 */ { "KAYAH LI DIGIT TWO",NULL},
/* A903 */ { "KAYAH LI DIGIT THREE",NULL},
/* A904 */ { "KAYAH LI DIGIT FOUR",NULL},
/* A905 */ { "KAYAH LI DIGIT FIVE",NULL},
/* A906 */ { "KAYAH LI DIGIT SIX",NULL},
/* A907 */ { "KAYAH LI DIGIT SEVEN",NULL},
/* A908 */ { "KAYAH LI DIGIT EIGHT",NULL},
/* A909 */ { "KAYAH LI DIGIT NINE",NULL},
/* A90A */ { "KAYAH LI LETTER KA",NULL},
/* A90B */ { "KAYAH LI LETTER KHA",NULL},
/* A90C */ { "KAYAH LI LETTER GA",NULL},
/* A90D */ { "KAYAH LI LETTER NGA",NULL},
/* A90E */ { "KAYAH LI LETTER SA",NULL},
/* A90F */ { "KAYAH LI LETTER SHA",NULL},
/* A910 */ { "KAYAH LI LETTER ZA",NULL},
/* A911 */ { "KAYAH LI LETTER NYA",NULL},
/* A912 */ { "KAYAH LI LETTER TA",NULL},
/* A913 */ { "KAYAH LI LETTER HTA",NULL},
/* A914 */ { "KAYAH LI LETTER NA",NULL},
/* A915 */ { "KAYAH LI LETTER PA",NULL},
/* A916 */ { "KAYAH LI LETTER PHA",NULL},
/* A917 */ { "KAYAH LI LETTER MA",NULL},
/* A918 */ { "KAYAH LI LETTER DA",NULL},
/* A919 */ { "KAYAH LI LETTER BA",NULL},
/* A91A */ { "KAYAH LI LETTER RA",NULL},
/* A91B */ { "KAYAH LI LETTER YA",NULL},
/* A91C */ { "KAYAH LI LETTER LA",NULL},
/* A91D */ { "KAYAH LI LETTER WA",NULL},
/* A91E */ { "KAYAH LI LETTER THA",NULL},
/* A91F */ { "KAYAH LI LETTER HA",NULL},
/* A920 */ { "KAYAH LI LETTER VA",NULL},
/* A921 */ { "KAYAH LI LETTER CA",NULL},
/* A922 */ { "KAYAH LI LETTER A","	* serves as a vowel carrier for vowels indicated with combining marks"},
/* A923 */ { "KAYAH LI LETTER OE","	* also serves as a vowel carrier"},
/* A924 */ { "KAYAH LI LETTER I",NULL},
/* A925 */ { "KAYAH LI LETTER OO",NULL},
/* A926 */ { "KAYAH LI VOWEL UE",NULL},
/* A927 */ { "KAYAH LI VOWEL E",NULL},
/* A928 */ { "KAYAH LI VOWEL U",NULL},
/* A929 */ { "KAYAH LI VOWEL EE",NULL},
/* A92A */ { "KAYAH LI VOWEL O",NULL},
/* A92B */ { "KAYAH LI TONE PLOPHU",NULL},
/* A92C */ { "KAYAH LI TONE CALYA",NULL},
/* A92D */ { "KAYAH LI TONE CALYA PLOPHU",NULL},
/* A92E */ { "KAYAH LI SIGN CWI",NULL},
/* A92F */ { "KAYAH LI SIGN SHYA",NULL},
/* A930 */ { "REJANG LETTER KA",NULL},
/* A931 */ { "REJANG LETTER GA",NULL},
/* A932 */ { "REJANG LETTER NGA",NULL},
/* A933 */ { "REJANG LETTER TA",NULL},
/* A934 */ { "REJANG LETTER DA",NULL},
/* A935 */ { "REJANG LETTER NA",NULL},
/* A936 */ { "REJANG LETTER PA",NULL},
/* A937 */ { "REJANG LETTER BA",NULL},
/* A938 */ { "REJANG LETTER MA",NULL},
/* A939 */ { "REJANG LETTER CA",NULL},
/* A93A */ { "REJANG LETTER JA",NULL},
/* A93B */ { "REJANG LETTER NYA",NULL},
/* A93C */ { "REJANG LETTER SA",NULL},
/* A93D */ { "REJANG LETTER RA",NULL},
/* A93E */ { "REJANG LETTER LA",NULL},
/* A93F */ { "REJANG LETTER YA",NULL},
/* A940 */ { "REJANG LETTER WA",NULL},
/* A941 */ { "REJANG LETTER HA",NULL},
/* A942 */ { "REJANG LETTER MBA",NULL},
/* A943 */ { "REJANG LETTER NGGA",NULL},
/* A944 */ { "REJANG LETTER NDA",NULL},
/* A945 */ { "REJANG LETTER NYJA",NULL},
/* A946 */ { "REJANG LETTER A",NULL},
/* A947 */ { "REJANG VOWEL SIGN I","	= kaluan"},
/* A948 */ { "REJANG VOWEL SIGN U","	= kamitan"},
/* A949 */ { "REJANG VOWEL SIGN E","	= kamica"},
/* A94A */ { "REJANG VOWEL SIGN AI","	= katiling"},
/* A94B */ { "REJANG VOWEL SIGN O",NULL},
/* A94C */ { "REJANG VOWEL SIGN AU","	= katulung"},
/* A94D */ { "REJANG VOWEL SIGN EU",NULL},
/* A94E */ { "REJANG VOWEL SIGN EA","	= kajina"},
/* A94F */ { "REJANG CONSONANT SIGN NG","	= katulang"},
/* A950 */ { "REJANG CONSONANT SIGN N","	= duo deatas"},
/* A951 */ { "REJANG CONSONANT SIGN R","	= kajunjung"},
/* A952 */ { "REJANG CONSONANT SIGN H",NULL},
/* A953 */ { "REJANG VIRAMA","	* does not form conjuncts"},
/* A954 */ { NULL,NULL},
/* A955 */ { NULL,NULL},
/* A956 */ { NULL,NULL},
/* A957 */ { NULL,NULL},
/* A958 */ { NULL,NULL},
/* A959 */ { NULL,NULL},
/* A95A */ { NULL,NULL},
/* A95B */ { NULL,NULL},
/* A95C */ { NULL,NULL},
/* A95D */ { NULL,NULL},
/* A95E */ { NULL,NULL},
/* A95F */ { "REJANG SECTION MARK",NULL},
/* A960 */ { "HANGUL CHOSEONG TIKEUT-MIEUM",NULL},
/* A961 */ { "HANGUL CHOSEONG TIKEUT-PIEUP",NULL},
/* A962 */ { "HANGUL CHOSEONG TIKEUT-SIOS",NULL},
/* A963 */ { "HANGUL CHOSEONG TIKEUT-CIEUC",NULL},
/* A964 */ { "HANGUL CHOSEONG RIEUL-KIYEOK",NULL},
/* A965 */ { "HANGUL CHOSEONG RIEUL-SSANGKIYEOK",NULL},
/* A966 */ { "HANGUL CHOSEONG RIEUL-TIKEUT",NULL},
/* A967 */ { "HANGUL CHOSEONG RIEUL-SSANGTIKEUT",NULL},
/* A968 */ { "HANGUL CHOSEONG RIEUL-MIEUM",NULL},
/* A969 */ { "HANGUL CHOSEONG RIEUL-PIEUP",NULL},
/* A96A */ { "HANGUL CHOSEONG RIEUL-SSANGPIEUP",NULL},
/* A96B */ { "HANGUL CHOSEONG RIEUL-KAPYEOUNPIEUP",NULL},
/* A96C */ { "HANGUL CHOSEONG RIEUL-SIOS",NULL},
/* A96D */ { "HANGUL CHOSEONG RIEUL-CIEUC",NULL},
/* A96E */ { "HANGUL CHOSEONG RIEUL-KHIEUKH",NULL},
/* A96F */ { "HANGUL CHOSEONG MIEUM-KIYEOK",NULL},
/* A970 */ { "HANGUL CHOSEONG MIEUM-TIKEUT",NULL},
/* A971 */ { "HANGUL CHOSEONG MIEUM-SIOS",NULL},
/* A972 */ { "HANGUL CHOSEONG PIEUP-SIOS-THIEUTH",NULL},
/* A973 */ { "HANGUL CHOSEONG PIEUP-KHIEUKH",NULL},
/* A974 */ { "HANGUL CHOSEONG PIEUP-HIEUH",NULL},
/* A975 */ { "HANGUL CHOSEONG SSANGSIOS-PIEUP",NULL},
/* A976 */ { "HANGUL CHOSEONG IEUNG-RIEUL",NULL},
/* A977 */ { "HANGUL CHOSEONG IEUNG-HIEUH",NULL},
/* A978 */ { "HANGUL CHOSEONG SSANGCIEUC-HIEUH",NULL},
/* A979 */ { "HANGUL CHOSEONG SSANGTHIEUTH",NULL},
/* A97A */ { "HANGUL CHOSEONG PHIEUPH-HIEUH",NULL},
/* A97B */ { "HANGUL CHOSEONG HIEUH-SIOS",NULL},
/* A97C */ { "HANGUL CHOSEONG SSANGYEORINHIEUH",NULL},
/* A97D */ { NULL,NULL},
/* A97E */ { NULL,NULL},
/* A97F */ { NULL,NULL},
/* A980 */ { "JAVANESE SIGN PANYANGGA","	= candrabindu"},
/* A981 */ { "JAVANESE SIGN CECAK","	= anusvara"},
/* A982 */ { "JAVANESE SIGN LAYAR","	= final r\n"
	"	* also used for repha in transliteration of Kawi\n"
	"	x (balinese sign surang - 1B03)"},
/* A983 */ { "JAVANESE SIGN WIGNYAN","	= visarga"},
/* A984 */ { "JAVANESE LETTER A",NULL},
/* A985 */ { "JAVANESE LETTER I KAWI",NULL},
/* A986 */ { "JAVANESE LETTER I",NULL},
/* A987 */ { "JAVANESE LETTER II",NULL},
/* A988 */ { "JAVANESE LETTER U",NULL},
/* A989 */ { "JAVANESE LETTER PA CEREK","	= vocalic r\n"
	"	* rĕ in Javanese"},
/* A98A */ { "JAVANESE LETTER NGA LELET","	= vocalic l\n"
	"	* lĕ in Javanese"},
/* A98B */ { "JAVANESE LETTER NGA LELET RASWADI","	= vocalic ll\n"
	"	* leu in Javanese"},
/* A98C */ { "JAVANESE LETTER E",NULL},
/* A98D */ { "JAVANESE LETTER AI",NULL},
/* A98E */ { "JAVANESE LETTER O",NULL},
/* A98F */ { "JAVANESE LETTER KA",NULL},
/* A990 */ { "JAVANESE LETTER KA SASAK","	= qa"},
/* A991 */ { "JAVANESE LETTER KA MURDA","	= kha"},
/* A992 */ { "JAVANESE LETTER GA",NULL},
/* A993 */ { "JAVANESE LETTER GA MURDA","	= gha"},
/* A994 */ { "JAVANESE LETTER NGA",NULL},
/* A995 */ { "JAVANESE LETTER CA",NULL},
/* A996 */ { "JAVANESE LETTER CA MURDA","	= cha"},
/* A997 */ { "JAVANESE LETTER JA",NULL},
/* A998 */ { "JAVANESE LETTER NYA MURDA","	= jnya\n"
	"	x (balinese letter archaic jnya - 1B4C)"},
/* A999 */ { "JAVANESE LETTER JA MAHAPRANA","	= jha"},
/* A99A */ { "JAVANESE LETTER NYA",NULL},
/* A99B */ { "JAVANESE LETTER TTA",NULL},
/* A99C */ { "JAVANESE LETTER TTA MAHAPRANA","	= ttha"},
/* A99D */ { "JAVANESE LETTER DDA",NULL},
/* A99E */ { "JAVANESE LETTER DDA MAHAPRANA","	= ddha"},
/* A99F */ { "JAVANESE LETTER NA MURDA","	= nna"},
/* A9A0 */ { "JAVANESE LETTER TA",NULL},
/* A9A1 */ { "JAVANESE LETTER TA MURDA","	= tha"},
/* A9A2 */ { "JAVANESE LETTER DA",NULL},
/* A9A3 */ { "JAVANESE LETTER DA MAHAPRANA","	= dha"},
/* A9A4 */ { "JAVANESE LETTER NA",NULL},
/* A9A5 */ { "JAVANESE LETTER PA",NULL},
/* A9A6 */ { "JAVANESE LETTER PA MURDA","	= pha"},
/* A9A7 */ { "JAVANESE LETTER BA",NULL},
/* A9A8 */ { "JAVANESE LETTER BA MURDA","	= bha"},
/* A9A9 */ { "JAVANESE LETTER MA",NULL},
/* A9AA */ { "JAVANESE LETTER YA",NULL},
/* A9AB */ { "JAVANESE LETTER RA",NULL},
/* A9AC */ { "JAVANESE LETTER RA AGUNG",NULL},
/* A9AD */ { "JAVANESE LETTER LA",NULL},
/* A9AE */ { "JAVANESE LETTER WA",NULL},
/* A9AF */ { "JAVANESE LETTER SA MURDA","	= sha"},
/* A9B0 */ { "JAVANESE LETTER SA MAHAPRANA","	= ssa"},
/* A9B1 */ { "JAVANESE LETTER SA",NULL},
/* A9B2 */ { "JAVANESE LETTER HA",NULL},
/* A9B3 */ { "JAVANESE SIGN CECAK TELU","	= nukta"},
/* A9B4 */ { "JAVANESE VOWEL SIGN TARUNG","	= aa\n"
	"	* o in Sundanese, not used alone in Javanese"},
/* A9B5 */ { "JAVANESE VOWEL SIGN TOLONG","	* a glyph variant of A9B4"},
/* A9B6 */ { "JAVANESE VOWEL SIGN WULU","	= i"},
/* A9B7 */ { "JAVANESE VOWEL SIGN WULU MELIK","	= ii"},
/* A9B8 */ { "JAVANESE VOWEL SIGN SUKU","	= u"},
/* A9B9 */ { "JAVANESE VOWEL SIGN SUKU MENDUT","	= uu"},
/* A9BA */ { "JAVANESE VOWEL SIGN TALING","	= e"},
/* A9BB */ { "JAVANESE VOWEL SIGN DIRGA MURE","	= ai"},
/* A9BC */ { "JAVANESE VOWEL SIGN PEPET","	= ĕ"},
/* A9BD */ { "JAVANESE CONSONANT SIGN KERET","	= vocalic r\n"
	"	* medial rĕ in Javanese"},
/* A9BE */ { "JAVANESE CONSONANT SIGN PENGKAL","	= medial ya"},
/* A9BF */ { "JAVANESE CONSONANT SIGN CAKRA","	= medial ra"},
/* A9C0 */ { "JAVANESE PANGKON","	= virama"},
/* A9C1 */ { "JAVANESE LEFT RERENGGAN",NULL},
/* A9C2 */ { "JAVANESE RIGHT RERENGGAN",NULL},
/* A9C3 */ { "JAVANESE PADA ANDAP",NULL},
/* A9C4 */ { "JAVANESE PADA MADYA",NULL},
/* A9C5 */ { "JAVANESE PADA LUHUR",NULL},
/* A9C6 */ { "JAVANESE PADA WINDU",NULL},
/* A9C7 */ { "JAVANESE PADA PANGKAT",NULL},
/* A9C8 */ { "JAVANESE PADA LINGSA","	= danda"},
/* A9C9 */ { "JAVANESE PADA LUNGSI","	= double danda"},
/* A9CA */ { "JAVANESE PADA ADEG",NULL},
/* A9CB */ { "JAVANESE PADA ADEG ADEG",NULL},
/* A9CC */ { "JAVANESE PADA PISELEH",NULL},
/* A9CD */ { "JAVANESE TURNED PADA PISELEH",NULL},
/* A9CE */ { NULL,NULL},
/* A9CF */ { "JAVANESE PANGRANGKEP","	* also used in Buginese\n"
	"	x (arabic-indic digit two - 0662)"},
/* A9D0 */ { "JAVANESE DIGIT ZERO",NULL},
/* A9D1 */ { "JAVANESE DIGIT ONE",NULL},
/* A9D2 */ { "JAVANESE DIGIT TWO",NULL},
/* A9D3 */ { "JAVANESE DIGIT THREE",NULL},
/* A9D4 */ { "JAVANESE DIGIT FOUR",NULL},
/* A9D5 */ { "JAVANESE DIGIT FIVE",NULL},
/* A9D6 */ { "JAVANESE DIGIT SIX",NULL},
/* A9D7 */ { "JAVANESE DIGIT SEVEN",NULL},
/* A9D8 */ { "JAVANESE DIGIT EIGHT",NULL},
/* A9D9 */ { "JAVANESE DIGIT NINE",NULL},
/* A9DA */ { NULL,NULL},
/* A9DB */ { NULL,NULL},
/* A9DC */ { NULL,NULL},
/* A9DD */ { NULL,NULL},
/* A9DE */ { "JAVANESE PADA TIRTA TUMETES",NULL},
/* A9DF */ { "JAVANESE PADA ISEN-ISEN",NULL},
/* A9E0 */ { "MYANMAR LETTER SHAN GHA",NULL},
/* A9E1 */ { "MYANMAR LETTER SHAN CHA",NULL},
/* A9E2 */ { "MYANMAR LETTER SHAN JHA",NULL},
/* A9E3 */ { "MYANMAR LETTER SHAN NNA",NULL},
/* A9E4 */ { "MYANMAR LETTER SHAN BHA",NULL},
/* A9E5 */ { "MYANMAR SIGN SHAN SAW",NULL},
/* A9E6 */ { "MYANMAR MODIFIER LETTER SHAN REDUPLICATION","	x (myanmar modifier letter khamti reduplication - AA70)"},
/* A9E7 */ { "MYANMAR LETTER TAI LAING NYA",NULL},
/* A9E8 */ { "MYANMAR LETTER TAI LAING FA",NULL},
/* A9E9 */ { "MYANMAR LETTER TAI LAING GA",NULL},
/* A9EA */ { "MYANMAR LETTER TAI LAING GHA",NULL},
/* A9EB */ { "MYANMAR LETTER TAI LAING JA",NULL},
/* A9EC */ { "MYANMAR LETTER TAI LAING JHA",NULL},
/* A9ED */ { "MYANMAR LETTER TAI LAING DDA",NULL},
/* A9EE */ { "MYANMAR LETTER TAI LAING DDHA",NULL},
/* A9EF */ { "MYANMAR LETTER TAI LAING NNA",NULL},
/* A9F0 */ { "MYANMAR TAI LAING DIGIT ZERO",NULL},
/* A9F1 */ { "MYANMAR TAI LAING DIGIT ONE",NULL},
/* A9F2 */ { "MYANMAR TAI LAING DIGIT TWO",NULL},
/* A9F3 */ { "MYANMAR TAI LAING DIGIT THREE",NULL},
/* A9F4 */ { "MYANMAR TAI LAING DIGIT FOUR",NULL},
/* A9F5 */ { "MYANMAR TAI LAING DIGIT FIVE",NULL},
/* A9F6 */ { "MYANMAR TAI LAING DIGIT SIX",NULL},
/* A9F7 */ { "MYANMAR TAI LAING DIGIT SEVEN",NULL},
/* A9F8 */ { "MYANMAR TAI LAING DIGIT EIGHT",NULL},
/* A9F9 */ { "MYANMAR TAI LAING DIGIT NINE",NULL},
/* A9FA */ { "MYANMAR LETTER TAI LAING LLA",NULL},
/* A9FB */ { "MYANMAR LETTER TAI LAING DA",NULL},
/* A9FC */ { "MYANMAR LETTER TAI LAING DHA",NULL},
/* A9FD */ { "MYANMAR LETTER TAI LAING BA",NULL},
/* A9FE */ { "MYANMAR LETTER TAI LAING BHA",NULL},
/* A9FF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_00_AA[] = {
/* AA00 */ { "CHAM LETTER A",NULL},
/* AA01 */ { "CHAM LETTER I",NULL},
/* AA02 */ { "CHAM LETTER U",NULL},
/* AA03 */ { "CHAM LETTER E",NULL},
/* AA04 */ { "CHAM LETTER AI",NULL},
/* AA05 */ { "CHAM LETTER O",NULL},
/* AA06 */ { "CHAM LETTER KA",NULL},
/* AA07 */ { "CHAM LETTER KHA",NULL},
/* AA08 */ { "CHAM LETTER GA",NULL},
/* AA09 */ { "CHAM LETTER GHA",NULL},
/* AA0A */ { "CHAM LETTER NGUE",NULL},
/* AA0B */ { "CHAM LETTER NGA",NULL},
/* AA0C */ { "CHAM LETTER CHA",NULL},
/* AA0D */ { "CHAM LETTER CHHA",NULL},
/* AA0E */ { "CHAM LETTER JA",NULL},
/* AA0F */ { "CHAM LETTER JHA",NULL},
/* AA10 */ { "CHAM LETTER NHUE",NULL},
/* AA11 */ { "CHAM LETTER NHA",NULL},
/* AA12 */ { "CHAM LETTER NHJA",NULL},
/* AA13 */ { "CHAM LETTER TA",NULL},
/* AA14 */ { "CHAM LETTER THA",NULL},
/* AA15 */ { "CHAM LETTER DA",NULL},
/* AA16 */ { "CHAM LETTER DHA",NULL},
/* AA17 */ { "CHAM LETTER NUE",NULL},
/* AA18 */ { "CHAM LETTER NA",NULL},
/* AA19 */ { "CHAM LETTER DDA",NULL},
/* AA1A */ { "CHAM LETTER PA",NULL},
/* AA1B */ { "CHAM LETTER PPA",NULL},
/* AA1C */ { "CHAM LETTER PHA",NULL},
/* AA1D */ { "CHAM LETTER BA",NULL},
/* AA1E */ { "CHAM LETTER BHA",NULL},
/* AA1F */ { "CHAM LETTER MUE",NULL},
/* AA20 */ { "CHAM LETTER MA",NULL},
/* AA21 */ { "CHAM LETTER BBA",NULL},
/* AA22 */ { "CHAM LETTER YA",NULL},
/* AA23 */ { "CHAM LETTER RA",NULL},
/* AA24 */ { "CHAM LETTER LA",NULL},
/* AA25 */ { "CHAM LETTER VA",NULL},
/* AA26 */ { "CHAM LETTER SSA",NULL},
/* AA27 */ { "CHAM LETTER SA",NULL},
/* AA28 */ { "CHAM LETTER HA",NULL},
/* AA29 */ { "CHAM VOWEL SIGN AA",NULL},
/* AA2A */ { "CHAM VOWEL SIGN I",NULL},
/* AA2B */ { "CHAM VOWEL SIGN II",NULL},
/* AA2C */ { "CHAM VOWEL SIGN EI",NULL},
/* AA2D */ { "CHAM VOWEL SIGN U",NULL},
/* AA2E */ { "CHAM VOWEL SIGN OE",NULL},
/* AA2F */ { "CHAM VOWEL SIGN O",NULL},
/* AA30 */ { "CHAM VOWEL SIGN AI",NULL},
/* AA31 */ { "CHAM VOWEL SIGN AU",NULL},
/* AA32 */ { "CHAM VOWEL SIGN UE",NULL},
/* AA33 */ { "CHAM CONSONANT SIGN YA",NULL},
/* AA34 */ { "CHAM CONSONANT SIGN RA",NULL},
/* AA35 */ { "CHAM CONSONANT SIGN LA",NULL},
/* AA36 */ { "CHAM CONSONANT SIGN WA",NULL},
/* AA37 */ { NULL,NULL},
/* AA38 */ { NULL,NULL},
/* AA39 */ { NULL,NULL},
/* AA3A */ { NULL,NULL},
/* AA3B */ { NULL,NULL},
/* AA3C */ { NULL,NULL},
/* AA3D */ { NULL,NULL},
/* AA3E */ { NULL,NULL},
/* AA3F */ { NULL,NULL},
/* AA40 */ { "CHAM LETTER FINAL K",NULL},
/* AA41 */ { "CHAM LETTER FINAL G",NULL},
/* AA42 */ { "CHAM LETTER FINAL NG",NULL},
/* AA43 */ { "CHAM CONSONANT SIGN FINAL NG",NULL},
/* AA44 */ { "CHAM LETTER FINAL CH",NULL},
/* AA45 */ { "CHAM LETTER FINAL T",NULL},
/* AA46 */ { "CHAM LETTER FINAL N",NULL},
/* AA47 */ { "CHAM LETTER FINAL P",NULL},
/* AA48 */ { "CHAM LETTER FINAL Y",NULL},
/* AA49 */ { "CHAM LETTER FINAL R",NULL},
/* AA4A */ { "CHAM LETTER FINAL L",NULL},
/* AA4B */ { "CHAM LETTER FINAL SS",NULL},
/* AA4C */ { "CHAM CONSONANT SIGN FINAL M",NULL},
/* AA4D */ { "CHAM CONSONANT SIGN FINAL H",NULL},
/* AA4E */ { NULL,NULL},
/* AA4F */ { NULL,NULL},
/* AA50 */ { "CHAM DIGIT ZERO",NULL},
/* AA51 */ { "CHAM DIGIT ONE",NULL},
/* AA52 */ { "CHAM DIGIT TWO",NULL},
/* AA53 */ { "CHAM DIGIT THREE",NULL},
/* AA54 */ { "CHAM DIGIT FOUR",NULL},
/* AA55 */ { "CHAM DIGIT FIVE",NULL},
/* AA56 */ { "CHAM DIGIT SIX",NULL},
/* AA57 */ { "CHAM DIGIT SEVEN",NULL},
/* AA58 */ { "CHAM DIGIT EIGHT",NULL},
/* AA59 */ { "CHAM DIGIT NINE",NULL},
/* AA5A */ { NULL,NULL},
/* AA5B */ { NULL,NULL},
/* AA5C */ { "CHAM PUNCTUATION SPIRAL",NULL},
/* AA5D */ { "CHAM PUNCTUATION DANDA",NULL},
/* AA5E */ { "CHAM PUNCTUATION DOUBLE DANDA",NULL},
/* AA5F */ { "CHAM PUNCTUATION TRIPLE DANDA",NULL},
/* AA60 */ { "MYANMAR LETTER KHAMTI GA","	~ AA60 FE00 dotted form"},
/* AA61 */ { "MYANMAR LETTER KHAMTI CA","	~ AA61 FE00 dotted form"},
/* AA62 */ { "MYANMAR LETTER KHAMTI CHA","	~ AA62 FE00 dotted form"},
/* AA63 */ { "MYANMAR LETTER KHAMTI JA","	~ AA63 FE00 dotted form"},
/* AA64 */ { "MYANMAR LETTER KHAMTI JHA","	~ AA64 FE00 dotted form"},
/* AA65 */ { "MYANMAR LETTER KHAMTI NYA","	~ AA65 FE00 dotted form"},
/* AA66 */ { "MYANMAR LETTER KHAMTI TTA","	~ AA66 FE00 dotted form"},
/* AA67 */ { "MYANMAR LETTER KHAMTI TTHA",NULL},
/* AA68 */ { "MYANMAR LETTER KHAMTI DDA",NULL},
/* AA69 */ { "MYANMAR LETTER KHAMTI DDHA",NULL},
/* AA6A */ { "MYANMAR LETTER KHAMTI DHA",NULL},
/* AA6B */ { "MYANMAR LETTER KHAMTI NA","	~ AA6B FE00 dotted form"},
/* AA6C */ { "MYANMAR LETTER KHAMTI SA","	~ AA6C FE00 dotted form"},
/* AA6D */ { "MYANMAR LETTER KHAMTI HA",NULL},
/* AA6E */ { "MYANMAR LETTER KHAMTI HHA","	% MYANMAR LETTER KHAMTI LLA"},
/* AA6F */ { "MYANMAR LETTER KHAMTI FA","	~ AA6F FE00 dotted form"},
/* AA70 */ { "MYANMAR MODIFIER LETTER KHAMTI REDUPLICATION","	x (myanmar modifier letter shan reduplication - A9E6)"},
/* AA71 */ { "MYANMAR LETTER KHAMTI XA",NULL},
/* AA72 */ { "MYANMAR LETTER KHAMTI ZA",NULL},
/* AA73 */ { "MYANMAR LETTER KHAMTI RA",NULL},
/* AA74 */ { "MYANMAR LOGOGRAM KHAMTI OAY",NULL},
/* AA75 */ { "MYANMAR LOGOGRAM KHAMTI QN",NULL},
/* AA76 */ { "MYANMAR LOGOGRAM KHAMTI HM",NULL},
/* AA77 */ { "MYANMAR SYMBOL AITON EXCLAMATION",NULL},
/* AA78 */ { "MYANMAR SYMBOL AITON ONE",NULL},
/* AA79 */ { "MYANMAR SYMBOL AITON TWO",NULL},
/* AA7A */ { "MYANMAR LETTER AITON RA","	~ AA7A FE00 dotted form"},
/* AA7B */ { "MYANMAR SIGN PAO KAREN TONE",NULL},
/* AA7C */ { "MYANMAR SIGN TAI LAING TONE-2",NULL},
/* AA7D */ { "MYANMAR SIGN TAI LAING TONE-5",NULL},
/* AA7E */ { "MYANMAR LETTER SHWE PALAUNG CHA",NULL},
/* AA7F */ { "MYANMAR LETTER SHWE PALAUNG SHA",NULL},
/* AA80 */ { "TAI VIET LETTER LOW KO",NULL},
/* AA81 */ { "TAI VIET LETTER HIGH KO",NULL},
/* AA82 */ { "TAI VIET LETTER LOW KHO",NULL},
/* AA83 */ { "TAI VIET LETTER HIGH KHO",NULL},
/* AA84 */ { "TAI VIET LETTER LOW KHHO",NULL},
/* AA85 */ { "TAI VIET LETTER HIGH KHHO",NULL},
/* AA86 */ { "TAI VIET LETTER LOW GO",NULL},
/* AA87 */ { "TAI VIET LETTER HIGH GO",NULL},
/* AA88 */ { "TAI VIET LETTER LOW NGO",NULL},
/* AA89 */ { "TAI VIET LETTER HIGH NGO",NULL},
/* AA8A */ { "TAI VIET LETTER LOW CO",NULL},
/* AA8B */ { "TAI VIET LETTER HIGH CO",NULL},
/* AA8C */ { "TAI VIET LETTER LOW CHO",NULL},
/* AA8D */ { "TAI VIET LETTER HIGH CHO",NULL},
/* AA8E */ { "TAI VIET LETTER LOW SO",NULL},
/* AA8F */ { "TAI VIET LETTER HIGH SO",NULL},
/* AA90 */ { "TAI VIET LETTER LOW NYO",NULL},
/* AA91 */ { "TAI VIET LETTER HIGH NYO",NULL},
/* AA92 */ { "TAI VIET LETTER LOW DO",NULL},
/* AA93 */ { "TAI VIET LETTER HIGH DO",NULL},
/* AA94 */ { "TAI VIET LETTER LOW TO",NULL},
/* AA95 */ { "TAI VIET LETTER HIGH TO",NULL},
/* AA96 */ { "TAI VIET LETTER LOW THO",NULL},
/* AA97 */ { "TAI VIET LETTER HIGH THO",NULL},
/* AA98 */ { "TAI VIET LETTER LOW NO",NULL},
/* AA99 */ { "TAI VIET LETTER HIGH NO",NULL},
/* AA9A */ { "TAI VIET LETTER LOW BO",NULL},
/* AA9B */ { "TAI VIET LETTER HIGH BO",NULL},
/* AA9C */ { "TAI VIET LETTER LOW PO",NULL},
/* AA9D */ { "TAI VIET LETTER HIGH PO",NULL},
/* AA9E */ { "TAI VIET LETTER LOW PHO",NULL},
/* AA9F */ { "TAI VIET LETTER HIGH PHO",NULL},
/* AAA0 */ { "TAI VIET LETTER LOW FO",NULL},
/* AAA1 */ { "TAI VIET LETTER HIGH FO",NULL},
/* AAA2 */ { "TAI VIET LETTER LOW MO",NULL},
/* AAA3 */ { "TAI VIET LETTER HIGH MO",NULL},
/* AAA4 */ { "TAI VIET LETTER LOW YO",NULL},
/* AAA5 */ { "TAI VIET LETTER HIGH YO",NULL},
/* AAA6 */ { "TAI VIET LETTER LOW RO",NULL},
/* AAA7 */ { "TAI VIET LETTER HIGH RO",NULL},
/* AAA8 */ { "TAI VIET LETTER LOW LO",NULL},
/* AAA9 */ { "TAI VIET LETTER HIGH LO",NULL},
/* AAAA */ { "TAI VIET LETTER LOW VO",NULL},
/* AAAB */ { "TAI VIET LETTER HIGH VO",NULL},
/* AAAC */ { "TAI VIET LETTER LOW HO",NULL},
/* AAAD */ { "TAI VIET LETTER HIGH HO",NULL},
/* AAAE */ { "TAI VIET LETTER LOW O",NULL},
/* AAAF */ { "TAI VIET LETTER HIGH O",NULL},
/* AAB0 */ { "TAI VIET MAI KANG",NULL},
/* AAB1 */ { "TAI VIET VOWEL AA",NULL},
/* AAB2 */ { "TAI VIET VOWEL I",NULL},
/* AAB3 */ { "TAI VIET VOWEL UE",NULL},
/* AAB4 */ { "TAI VIET VOWEL U",NULL},
/* AAB5 */ { "TAI VIET VOWEL E","	* precedes consonant in visual order"},
/* AAB6 */ { "TAI VIET VOWEL O","	* precedes consonant in visual order"},
/* AAB7 */ { "TAI VIET MAI KHIT",NULL},
/* AAB8 */ { "TAI VIET VOWEL IA",NULL},
/* AAB9 */ { "TAI VIET VOWEL UEA","	* precedes consonant in visual order"},
/* AABA */ { "TAI VIET VOWEL UA",NULL},
/* AABB */ { "TAI VIET VOWEL AUE","	* precedes consonant in visual order"},
/* AABC */ { "TAI VIET VOWEL AY","	* precedes consonant in visual order"},
/* AABD */ { "TAI VIET VOWEL AN",NULL},
/* AABE */ { "TAI VIET VOWEL AM",NULL},
/* AABF */ { "TAI VIET TONE MAI EK",NULL},
/* AAC0 */ { "TAI VIET TONE MAI NUENG",NULL},
/* AAC1 */ { "TAI VIET TONE MAI THO",NULL},
/* AAC2 */ { "TAI VIET TONE MAI SONG",NULL},
/* AAC3 */ { NULL,NULL},
/* AAC4 */ { NULL,NULL},
/* AAC5 */ { NULL,NULL},
/* AAC6 */ { NULL,NULL},
/* AAC7 */ { NULL,NULL},
/* AAC8 */ { NULL,NULL},
/* AAC9 */ { NULL,NULL},
/* AACA */ { NULL,NULL},
/* AACB */ { NULL,NULL},
/* AACC */ { NULL,NULL},
/* AACD */ { NULL,NULL},
/* AACE */ { NULL,NULL},
/* AACF */ { NULL,NULL},
/* AAD0 */ { NULL,NULL},
/* AAD1 */ { NULL,NULL},
/* AAD2 */ { NULL,NULL},
/* AAD3 */ { NULL,NULL},
/* AAD4 */ { NULL,NULL},
/* AAD5 */ { NULL,NULL},
/* AAD6 */ { NULL,NULL},
/* AAD7 */ { NULL,NULL},
/* AAD8 */ { NULL,NULL},
/* AAD9 */ { NULL,NULL},
/* AADA */ { NULL,NULL},
/* AADB */ { "TAI VIET SYMBOL KON","	= person"},
/* AADC */ { "TAI VIET SYMBOL NUENG","	= one"},
/* AADD */ { "TAI VIET SYMBOL SAM","	x (thai character maiyamok - 0E46)"},
/* AADE */ { "TAI VIET SYMBOL HO HOI","	* marks start of text in songs and poems"},
/* AADF */ { "TAI VIET SYMBOL KOI KOI","	* marks end of text in songs and poems"},
/* AAE0 */ { "MEETEI MAYEK LETTER E",NULL},
/* AAE1 */ { "MEETEI MAYEK LETTER O",NULL},
/* AAE2 */ { "MEETEI MAYEK LETTER CHA",NULL},
/* AAE3 */ { "MEETEI MAYEK LETTER NYA",NULL},
/* AAE4 */ { "MEETEI MAYEK LETTER TTA",NULL},
/* AAE5 */ { "MEETEI MAYEK LETTER TTHA",NULL},
/* AAE6 */ { "MEETEI MAYEK LETTER DDA",NULL},
/* AAE7 */ { "MEETEI MAYEK LETTER DDHA",NULL},
/* AAE8 */ { "MEETEI MAYEK LETTER NNA",NULL},
/* AAE9 */ { "MEETEI MAYEK LETTER SHA",NULL},
/* AAEA */ { "MEETEI MAYEK LETTER SSA",NULL},
/* AAEB */ { "MEETEI MAYEK VOWEL SIGN II",NULL},
/* AAEC */ { "MEETEI MAYEK VOWEL SIGN UU",NULL},
/* AAED */ { "MEETEI MAYEK VOWEL SIGN AAI",NULL},
/* AAEE */ { "MEETEI MAYEK VOWEL SIGN AU",NULL},
/* AAEF */ { "MEETEI MAYEK VOWEL SIGN AAU",NULL},
/* AAF0 */ { "MEETEI MAYEK CHEIKHAN","	= danda"},
/* AAF1 */ { "MEETEI MAYEK AHANG KHUDAM","	= question mark"},
/* AAF2 */ { "MEETEI MAYEK ANJI","	* a philosophical sign\n"
	"	x (devanagari om - 0950)"},
/* AAF3 */ { "MEETEI MAYEK SYLLABLE REPETITION MARK",NULL},
/* AAF4 */ { "MEETEI MAYEK WORD REPETITION MARK",NULL},
/* AAF5 */ { "MEETEI MAYEK VOWEL SIGN VISARGA",NULL},
/* AAF6 */ { "MEETEI MAYEK VIRAMA","	* used to form conjuncts in historical orthographies\n"
	"	x (myanmar sign virama - 1039)"},
/* AAF7 */ { NULL,NULL},
/* AAF8 */ { NULL,NULL},
/* AAF9 */ { NULL,NULL},
/* AAFA */ { NULL,NULL},
/* AAFB */ { NULL,NULL},
/* AAFC */ { NULL,NULL},
/* AAFD */ { NULL,NULL},
/* AAFE */ { NULL,NULL},
/* AAFF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_00_AB[] = {
/* AB00 */ { NULL,NULL},
/* AB01 */ { "ETHIOPIC SYLLABLE TTHU",NULL},
/* AB02 */ { "ETHIOPIC SYLLABLE TTHI",NULL},
/* AB03 */ { "ETHIOPIC SYLLABLE TTHAA",NULL},
/* AB04 */ { "ETHIOPIC SYLLABLE TTHEE",NULL},
/* AB05 */ { "ETHIOPIC SYLLABLE TTHE",NULL},
/* AB06 */ { "ETHIOPIC SYLLABLE TTHO",NULL},
/* AB07 */ { NULL,NULL},
/* AB08 */ { NULL,NULL},
/* AB09 */ { "ETHIOPIC SYLLABLE DDHU",NULL},
/* AB0A */ { "ETHIOPIC SYLLABLE DDHI",NULL},
/* AB0B */ { "ETHIOPIC SYLLABLE DDHAA",NULL},
/* AB0C */ { "ETHIOPIC SYLLABLE DDHEE",NULL},
/* AB0D */ { "ETHIOPIC SYLLABLE DDHE",NULL},
/* AB0E */ { "ETHIOPIC SYLLABLE DDHO",NULL},
/* AB0F */ { NULL,NULL},
/* AB10 */ { NULL,NULL},
/* AB11 */ { "ETHIOPIC SYLLABLE DZU",NULL},
/* AB12 */ { "ETHIOPIC SYLLABLE DZI",NULL},
/* AB13 */ { "ETHIOPIC SYLLABLE DZAA",NULL},
/* AB14 */ { "ETHIOPIC SYLLABLE DZEE",NULL},
/* AB15 */ { "ETHIOPIC SYLLABLE DZE",NULL},
/* AB16 */ { "ETHIOPIC SYLLABLE DZO",NULL},
/* AB17 */ { NULL,NULL},
/* AB18 */ { NULL,NULL},
/* AB19 */ { NULL,NULL},
/* AB1A */ { NULL,NULL},
/* AB1B */ { NULL,NULL},
/* AB1C */ { NULL,NULL},
/* AB1D */ { NULL,NULL},
/* AB1E */ { NULL,NULL},
/* AB1F */ { NULL,NULL},
/* AB20 */ { "ETHIOPIC SYLLABLE CCHHA",NULL},
/* AB21 */ { "ETHIOPIC SYLLABLE CCHHU",NULL},
/* AB22 */ { "ETHIOPIC SYLLABLE CCHHI",NULL},
/* AB23 */ { "ETHIOPIC SYLLABLE CCHHAA",NULL},
/* AB24 */ { "ETHIOPIC SYLLABLE CCHHEE",NULL},
/* AB25 */ { "ETHIOPIC SYLLABLE CCHHE",NULL},
/* AB26 */ { "ETHIOPIC SYLLABLE CCHHO",NULL},
/* AB27 */ { NULL,NULL},
/* AB28 */ { "ETHIOPIC SYLLABLE BBA",NULL},
/* AB29 */ { "ETHIOPIC SYLLABLE BBU",NULL},
/* AB2A */ { "ETHIOPIC SYLLABLE BBI",NULL},
/* AB2B */ { "ETHIOPIC SYLLABLE BBAA",NULL},
/* AB2C */ { "ETHIOPIC SYLLABLE BBEE",NULL},
/* AB2D */ { "ETHIOPIC SYLLABLE BBE",NULL},
/* AB2E */ { "ETHIOPIC SYLLABLE BBO",NULL},
/* AB2F */ { NULL,NULL},
/* AB30 */ { "LATIN SMALL LETTER BARRED ALPHA","		* This letter is a Latin alpha with a horizontal strikethrough bar. In some font designs, the bar might not extend beyond the edge of the letter, and in such cases, the letter should not be confused with a ligature of epsilon and iota."},
/* AB31 */ { "LATIN SMALL LETTER A REVERSED-SCHWA",NULL},
/* AB32 */ { "LATIN SMALL LETTER BLACKLETTER E","	x (mathematical fraktur small e - 1D522)"},
/* AB33 */ { "LATIN SMALL LETTER BARRED E",NULL},
/* AB34 */ { "LATIN SMALL LETTER E WITH FLOURISH",NULL},
/* AB35 */ { "LATIN SMALL LETTER LENIS F","	x (latin small letter f - 0066)"},
/* AB36 */ { "LATIN SMALL LETTER SCRIPT G WITH CROSSED-TAIL",NULL},
/* AB37 */ { "LATIN SMALL LETTER L WITH INVERTED LAZY S",NULL},
/* AB38 */ { "LATIN SMALL LETTER L WITH DOUBLE MIDDLE TILDE","	x (latin small letter l with middle tilde - 026B)\n"
	"	x (latin small letter l with double bar - 2C61)"},
/* AB39 */ { "LATIN SMALL LETTER L WITH MIDDLE RING",NULL},
/* AB3A */ { "LATIN SMALL LETTER M WITH CROSSED-TAIL",NULL},
/* AB3B */ { "LATIN SMALL LETTER N WITH CROSSED-TAIL",NULL},
/* AB3C */ { "LATIN SMALL LETTER ENG WITH CROSSED-TAIL",NULL},
/* AB3D */ { "LATIN SMALL LETTER BLACKLETTER O","	x (mathematical fraktur small o - 1D52C)"},
/* AB3E */ { "LATIN SMALL LETTER BLACKLETTER O WITH STROKE","		* This letter was encoded based on a misinterpretation of a low quality copy of Sievers 1901. It is not actually used in German dialectology.\n"
	"	x (latin small letter o with stroke - 00F8)"},
/* AB3F */ { "LATIN SMALL LETTER OPEN O WITH STROKE",NULL},
/* AB40 */ { "LATIN SMALL LETTER INVERTED OE","	= latin small letter o reversed-schwa"},
/* AB41 */ { "LATIN SMALL LETTER TURNED OE WITH STROKE",NULL},
/* AB42 */ { "LATIN SMALL LETTER TURNED OE WITH HORIZONTAL STROKE",NULL},
/* AB43 */ { "LATIN SMALL LETTER TURNED O OPEN-O",NULL},
/* AB44 */ { "LATIN SMALL LETTER TURNED O OPEN-O WITH STROKE",NULL},
/* AB45 */ { "LATIN SMALL LETTER STIRRUP R",NULL},
/* AB46 */ { "LATIN LETTER SMALL CAPITAL R WITH RIGHT LEG",NULL},
/* AB47 */ { "LATIN SMALL LETTER R WITHOUT HANDLE",NULL},
/* AB48 */ { "LATIN SMALL LETTER DOUBLE R",NULL},
/* AB49 */ { "LATIN SMALL LETTER R WITH CROSSED-TAIL",NULL},
/* AB4A */ { "LATIN SMALL LETTER DOUBLE R WITH CROSSED-TAIL",NULL},
/* AB4B */ { "LATIN SMALL LETTER SCRIPT R","	x (mathematical script small r - 1D4C7)"},
/* AB4C */ { "LATIN SMALL LETTER SCRIPT R WITH RING",NULL},
/* AB4D */ { "LATIN SMALL LETTER BASELINE ESH","	x (latin small letter esh - 0283)"},
/* AB4E */ { "LATIN SMALL LETTER U WITH SHORT RIGHT LEG",NULL},
/* AB4F */ { "LATIN SMALL LETTER U BAR WITH SHORT RIGHT LEG",NULL},
/* AB50 */ { "LATIN SMALL LETTER UI",NULL},
/* AB51 */ { "LATIN SMALL LETTER TURNED UI",NULL},
/* AB52 */ { "LATIN SMALL LETTER U WITH LEFT HOOK",NULL},
/* AB53 */ { "LATIN SMALL LETTER CHI","	* uppercase is A7B3\n"
	"	x (greek small letter chi - 03C7)"},
/* AB54 */ { "LATIN SMALL LETTER CHI WITH LOW RIGHT RING",NULL},
/* AB55 */ { "LATIN SMALL LETTER CHI WITH LOW LEFT SERIF",NULL},
/* AB56 */ { "LATIN SMALL LETTER X WITH LOW RIGHT RING",NULL},
/* AB57 */ { "LATIN SMALL LETTER X WITH LONG LEFT LEG",NULL},
/* AB58 */ { "LATIN SMALL LETTER X WITH LONG LEFT LEG AND LOW RIGHT RING",NULL},
/* AB59 */ { "LATIN SMALL LETTER X WITH LONG LEFT LEG WITH SERIF",NULL},
/* AB5A */ { "LATIN SMALL LETTER Y WITH SHORT RIGHT LEG",NULL},
/* AB5B */ { "MODIFIER BREVE WITH INVERTED BREVE","	* indicates a short vowel\n"
	"	x (breve - 02D8)\n"
	"	x (equivalent to - 224D)\n"
	"	x (metrical breve - 23D1)\n"
	"	x (inverted low kavyka with kavyka above - 2E46)"},
/* AB5C */ { "MODIFIER LETTER SMALL HENG","	# <super> A727"},
/* AB5D */ { "MODIFIER LETTER SMALL L WITH INVERTED LAZY S","	# <super> AB37"},
/* AB5E */ { "MODIFIER LETTER SMALL L WITH MIDDLE TILDE","	# <super> 026B"},
/* AB5F */ { "MODIFIER LETTER SMALL U WITH LEFT HOOK","	# <super> AB52"},
/* AB60 */ { "LATIN SMALL LETTER SAKHA YAT","	x (cyrillic small letter yat - 0463)"},
/* AB61 */ { "LATIN SMALL LETTER IOTIFIED E","	x (cyrillic small letter iotified e - 0465)"},
/* AB62 */ { "LATIN SMALL LETTER OPEN OE","	x (latin small letter open o - 0254)"},
/* AB63 */ { "LATIN SMALL LETTER UO",NULL},
/* AB64 */ { "LATIN SMALL LETTER INVERTED ALPHA","	* unrounded low back vowel\n"
	"	x (latin small letter turned alpha - 0252)"},
/* AB65 */ { "GREEK LETTER SMALL CAPITAL OMEGA","	* obsolete for mid back rounded vowel\n"
	"		Other Greek small capital letters are located in the range 1D26-1D2A.\n"
	"	x (latin small letter closed omega - 0277)\n"
	"	x (greek capital letter omega - 03A9)"},
/* AB66 */ { "LATIN SMALL LETTER DZ DIGRAPH WITH RETROFLEX HOOK","	* voiced retroflex affricate\n"
	"	x (latin small letter z with retroflex hook - 0290)\n"
	"	x (latin small letter dz digraph - 02A3)"},
/* AB67 */ { "LATIN SMALL LETTER TS DIGRAPH WITH RETROFLEX HOOK","	* voiceless retroflex affricate\n"
	"	x (latin small letter s with hook - 0282)\n"
	"	x (latin small letter ts digraph - 02A6)"},
/* AB68 */ { "LATIN SMALL LETTER TURNED R WITH MIDDLE TILDE","	* velarized dento-alveolar approximant\n"
	"	x (latin small letter r with middle tilde - 1D72)"},
/* AB69 */ { "MODIFIER LETTER SMALL TURNED W","	* voiceless bilabial realization\n"
	"	x (combining latin small letter turned w below - 1AC0)\n"
	"	# <super> 028D"},
/* AB6A */ { "MODIFIER LETTER LEFT TACK","	* fronted vocalic realization\n"
	"	x (modifier letter up tack - 02D4)\n"
	"	x (combining left tack below - 0318)"},
/* AB6B */ { "MODIFIER LETTER RIGHT TACK","	* backed vocalic realization\n"
	"	x (combining right tack below - 0319)"},
/* AB6C */ { NULL,NULL},
/* AB6D */ { NULL,NULL},
/* AB6E */ { NULL,NULL},
/* AB6F */ { NULL,NULL},
/* AB70 */ { "CHEROKEE SMALL LETTER A",NULL},
/* AB71 */ { "CHEROKEE SMALL LETTER E",NULL},
/* AB72 */ { "CHEROKEE SMALL LETTER I",NULL},
/* AB73 */ { "CHEROKEE SMALL LETTER O",NULL},
/* AB74 */ { "CHEROKEE SMALL LETTER U",NULL},
/* AB75 */ { "CHEROKEE SMALL LETTER V",NULL},
/* AB76 */ { "CHEROKEE SMALL LETTER GA",NULL},
/* AB77 */ { "CHEROKEE SMALL LETTER KA",NULL},
/* AB78 */ { "CHEROKEE SMALL LETTER GE",NULL},
/* AB79 */ { "CHEROKEE SMALL LETTER GI",NULL},
/* AB7A */ { "CHEROKEE SMALL LETTER GO",NULL},
/* AB7B */ { "CHEROKEE SMALL LETTER GU",NULL},
/* AB7C */ { "CHEROKEE SMALL LETTER GV",NULL},
/* AB7D */ { "CHEROKEE SMALL LETTER HA",NULL},
/* AB7E */ { "CHEROKEE SMALL LETTER HE",NULL},
/* AB7F */ { "CHEROKEE SMALL LETTER HI",NULL},
/* AB80 */ { "CHEROKEE SMALL LETTER HO",NULL},
/* AB81 */ { "CHEROKEE SMALL LETTER HU",NULL},
/* AB82 */ { "CHEROKEE SMALL LETTER HV",NULL},
/* AB83 */ { "CHEROKEE SMALL LETTER LA",NULL},
/* AB84 */ { "CHEROKEE SMALL LETTER LE",NULL},
/* AB85 */ { "CHEROKEE SMALL LETTER LI",NULL},
/* AB86 */ { "CHEROKEE SMALL LETTER LO",NULL},
/* AB87 */ { "CHEROKEE SMALL LETTER LU",NULL},
/* AB88 */ { "CHEROKEE SMALL LETTER LV",NULL},
/* AB89 */ { "CHEROKEE SMALL LETTER MA",NULL},
/* AB8A */ { "CHEROKEE SMALL LETTER ME",NULL},
/* AB8B */ { "CHEROKEE SMALL LETTER MI",NULL},
/* AB8C */ { "CHEROKEE SMALL LETTER MO",NULL},
/* AB8D */ { "CHEROKEE SMALL LETTER MU",NULL},
/* AB8E */ { "CHEROKEE SMALL LETTER NA",NULL},
/* AB8F */ { "CHEROKEE SMALL LETTER HNA",NULL},
/* AB90 */ { "CHEROKEE SMALL LETTER NAH",NULL},
/* AB91 */ { "CHEROKEE SMALL LETTER NE",NULL},
/* AB92 */ { "CHEROKEE SMALL LETTER NI",NULL},
/* AB93 */ { "CHEROKEE SMALL LETTER NO",NULL},
/* AB94 */ { "CHEROKEE SMALL LETTER NU",NULL},
/* AB95 */ { "CHEROKEE SMALL LETTER NV",NULL},
/* AB96 */ { "CHEROKEE SMALL LETTER QUA",NULL},
/* AB97 */ { "CHEROKEE SMALL LETTER QUE",NULL},
/* AB98 */ { "CHEROKEE SMALL LETTER QUI",NULL},
/* AB99 */ { "CHEROKEE SMALL LETTER QUO",NULL},
/* AB9A */ { "CHEROKEE SMALL LETTER QUU",NULL},
/* AB9B */ { "CHEROKEE SMALL LETTER QUV",NULL},
/* AB9C */ { "CHEROKEE SMALL LETTER SA",NULL},
/* AB9D */ { "CHEROKEE SMALL LETTER S",NULL},
/* AB9E */ { "CHEROKEE SMALL LETTER SE",NULL},
/* AB9F */ { "CHEROKEE SMALL LETTER SI",NULL},
/* ABA0 */ { "CHEROKEE SMALL LETTER SO",NULL},
/* ABA1 */ { "CHEROKEE SMALL LETTER SU",NULL},
/* ABA2 */ { "CHEROKEE SMALL LETTER SV",NULL},
/* ABA3 */ { "CHEROKEE SMALL LETTER DA",NULL},
/* ABA4 */ { "CHEROKEE SMALL LETTER TA",NULL},
/* ABA5 */ { "CHEROKEE SMALL LETTER DE",NULL},
/* ABA6 */ { "CHEROKEE SMALL LETTER TE",NULL},
/* ABA7 */ { "CHEROKEE SMALL LETTER DI",NULL},
/* ABA8 */ { "CHEROKEE SMALL LETTER TI",NULL},
/* ABA9 */ { "CHEROKEE SMALL LETTER DO",NULL},
/* ABAA */ { "CHEROKEE SMALL LETTER DU",NULL},
/* ABAB */ { "CHEROKEE SMALL LETTER DV",NULL},
/* ABAC */ { "CHEROKEE SMALL LETTER DLA",NULL},
/* ABAD */ { "CHEROKEE SMALL LETTER TLA",NULL},
/* ABAE */ { "CHEROKEE SMALL LETTER TLE",NULL},
/* ABAF */ { "CHEROKEE SMALL LETTER TLI",NULL},
/* ABB0 */ { "CHEROKEE SMALL LETTER TLO",NULL},
/* ABB1 */ { "CHEROKEE SMALL LETTER TLU",NULL},
/* ABB2 */ { "CHEROKEE SMALL LETTER TLV",NULL},
/* ABB3 */ { "CHEROKEE SMALL LETTER TSA",NULL},
/* ABB4 */ { "CHEROKEE SMALL LETTER TSE",NULL},
/* ABB5 */ { "CHEROKEE SMALL LETTER TSI",NULL},
/* ABB6 */ { "CHEROKEE SMALL LETTER TSO",NULL},
/* ABB7 */ { "CHEROKEE SMALL LETTER TSU",NULL},
/* ABB8 */ { "CHEROKEE SMALL LETTER TSV",NULL},
/* ABB9 */ { "CHEROKEE SMALL LETTER WA",NULL},
/* ABBA */ { "CHEROKEE SMALL LETTER WE",NULL},
/* ABBB */ { "CHEROKEE SMALL LETTER WI",NULL},
/* ABBC */ { "CHEROKEE SMALL LETTER WO",NULL},
/* ABBD */ { "CHEROKEE SMALL LETTER WU",NULL},
/* ABBE */ { "CHEROKEE SMALL LETTER WV",NULL},
/* ABBF */ { "CHEROKEE SMALL LETTER YA",NULL},
/* ABC0 */ { "MEETEI MAYEK LETTER KOK","	= ka"},
/* ABC1 */ { "MEETEI MAYEK LETTER SAM","	= sa"},
/* ABC2 */ { "MEETEI MAYEK LETTER LAI","	= la"},
/* ABC3 */ { "MEETEI MAYEK LETTER MIT","	= ma"},
/* ABC4 */ { "MEETEI MAYEK LETTER PA",NULL},
/* ABC5 */ { "MEETEI MAYEK LETTER NA",NULL},
/* ABC6 */ { "MEETEI MAYEK LETTER CHIL","	= ca"},
/* ABC7 */ { "MEETEI MAYEK LETTER TIL","	= ta"},
/* ABC8 */ { "MEETEI MAYEK LETTER KHOU","	= kha"},
/* ABC9 */ { "MEETEI MAYEK LETTER NGOU","	= nga"},
/* ABCA */ { "MEETEI MAYEK LETTER THOU","	= tha"},
/* ABCB */ { "MEETEI MAYEK LETTER WAI","	= wa"},
/* ABCC */ { "MEETEI MAYEK LETTER YANG","	= ya"},
/* ABCD */ { "MEETEI MAYEK LETTER HUK","	= ha"},
/* ABCE */ { "MEETEI MAYEK LETTER UN","	= u"},
/* ABCF */ { "MEETEI MAYEK LETTER I",NULL},
/* ABD0 */ { "MEETEI MAYEK LETTER PHAM","	= pha"},
/* ABD1 */ { "MEETEI MAYEK LETTER ATIYA","	= a"},
/* ABD2 */ { "MEETEI MAYEK LETTER GOK","	= ga"},
/* ABD3 */ { "MEETEI MAYEK LETTER JHAM","	= jha"},
/* ABD4 */ { "MEETEI MAYEK LETTER RAI","	= ra"},
/* ABD5 */ { "MEETEI MAYEK LETTER BA",NULL},
/* ABD6 */ { "MEETEI MAYEK LETTER JIL","	= ja"},
/* ABD7 */ { "MEETEI MAYEK LETTER DIL","	= da"},
/* ABD8 */ { "MEETEI MAYEK LETTER GHOU","	= gha"},
/* ABD9 */ { "MEETEI MAYEK LETTER DHOU","	= dha"},
/* ABDA */ { "MEETEI MAYEK LETTER BHAM","	= bha"},
/* ABDB */ { "MEETEI MAYEK LETTER KOK LONSUM","	= k"},
/* ABDC */ { "MEETEI MAYEK LETTER LAI LONSUM","	= l"},
/* ABDD */ { "MEETEI MAYEK LETTER MIT LONSUM","	= m"},
/* ABDE */ { "MEETEI MAYEK LETTER PA LONSUM","	= p"},
/* ABDF */ { "MEETEI MAYEK LETTER NA LONSUM","	= n"},
/* ABE0 */ { "MEETEI MAYEK LETTER TIL LONSUM","	= t"},
/* ABE1 */ { "MEETEI MAYEK LETTER NGOU LONSUM","	= ng"},
/* ABE2 */ { "MEETEI MAYEK LETTER I LONSUM","	= i"},
/* ABE3 */ { "MEETEI MAYEK VOWEL SIGN ONAP","	= o"},
/* ABE4 */ { "MEETEI MAYEK VOWEL SIGN INAP","	= i"},
/* ABE5 */ { "MEETEI MAYEK VOWEL SIGN ANAP","	= aa"},
/* ABE6 */ { "MEETEI MAYEK VOWEL SIGN YENAP","	= e"},
/* ABE7 */ { "MEETEI MAYEK VOWEL SIGN SOUNAP","	= ou"},
/* ABE8 */ { "MEETEI MAYEK VOWEL SIGN UNAP","	= u"},
/* ABE9 */ { "MEETEI MAYEK VOWEL SIGN CHEINAP","	= ei"},
/* ABEA */ { "MEETEI MAYEK VOWEL SIGN NUNG","	= anusvara"},
/* ABEB */ { "MEETEI MAYEK CHEIKHEI","	= double danda"},
/* ABEC */ { "MEETEI MAYEK LUM IYEK","	= heavy tone"},
/* ABED */ { "MEETEI MAYEK APUN IYEK","	= killer\n"
	"	x (myanmar sign asat - 103A)"},
/* ABEE */ { NULL,NULL},
/* ABEF */ { NULL,NULL},
/* ABF0 */ { "MEETEI MAYEK DIGIT ZERO","	= phun"},
/* ABF1 */ { "MEETEI MAYEK DIGIT ONE","	= ama"},
/* ABF2 */ { "MEETEI MAYEK DIGIT TWO","	= ani"},
/* ABF3 */ { "MEETEI MAYEK DIGIT THREE","	= ahum"},
/* ABF4 */ { "MEETEI MAYEK DIGIT FOUR","	= mari"},
/* ABF5 */ { "MEETEI MAYEK DIGIT FIVE","	= manga"},
/* ABF6 */ { "MEETEI MAYEK DIGIT SIX","	= taruk"},
/* ABF7 */ { "MEETEI MAYEK DIGIT SEVEN","	= taret"},
/* ABF8 */ { "MEETEI MAYEK DIGIT EIGHT","	= nipal"},
/* ABF9 */ { "MEETEI MAYEK DIGIT NINE","	= mapal"},
/* ABFA */ { NULL,NULL},
/* ABFB */ { NULL,NULL},
/* ABFC */ { NULL,NULL},
/* ABFD */ { NULL,NULL},
/* ABFE */ { NULL,NULL},
/* ABFF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_00_D7[] = {
/* D700 */ { NULL,NULL},
/* D701 */ { NULL,NULL},
/* D702 */ { NULL,NULL},
/* D703 */ { NULL,NULL},
/* D704 */ { NULL,NULL},
/* D705 */ { NULL,NULL},
/* D706 */ { NULL,NULL},
/* D707 */ { NULL,NULL},
/* D708 */ { NULL,NULL},
/* D709 */ { NULL,NULL},
/* D70A */ { NULL,NULL},
/* D70B */ { NULL,NULL},
/* D70C */ { NULL,NULL},
/* D70D */ { NULL,NULL},
/* D70E */ { NULL,NULL},
/* D70F */ { NULL,NULL},
/* D710 */ { NULL,NULL},
/* D711 */ { NULL,NULL},
/* D712 */ { NULL,NULL},
/* D713 */ { NULL,NULL},
/* D714 */ { NULL,NULL},
/* D715 */ { NULL,NULL},
/* D716 */ { NULL,NULL},
/* D717 */ { NULL,NULL},
/* D718 */ { NULL,NULL},
/* D719 */ { NULL,NULL},
/* D71A */ { NULL,NULL},
/* D71B */ { NULL,NULL},
/* D71C */ { NULL,NULL},
/* D71D */ { NULL,NULL},
/* D71E */ { NULL,NULL},
/* D71F */ { NULL,NULL},
/* D720 */ { NULL,NULL},
/* D721 */ { NULL,NULL},
/* D722 */ { NULL,NULL},
/* D723 */ { NULL,NULL},
/* D724 */ { NULL,NULL},
/* D725 */ { NULL,NULL},
/* D726 */ { NULL,NULL},
/* D727 */ { NULL,NULL},
/* D728 */ { NULL,NULL},
/* D729 */ { NULL,NULL},
/* D72A */ { NULL,NULL},
/* D72B */ { NULL,NULL},
/* D72C */ { NULL,NULL},
/* D72D */ { NULL,NULL},
/* D72E */ { NULL,NULL},
/* D72F */ { NULL,NULL},
/* D730 */ { NULL,NULL},
/* D731 */ { NULL,NULL},
/* D732 */ { NULL,NULL},
/* D733 */ { NULL,NULL},
/* D734 */ { NULL,NULL},
/* D735 */ { NULL,NULL},
/* D736 */ { NULL,NULL},
/* D737 */ { NULL,NULL},
/* D738 */ { NULL,NULL},
/* D739 */ { NULL,NULL},
/* D73A */ { NULL,NULL},
/* D73B */ { NULL,NULL},
/* D73C */ { NULL,NULL},
/* D73D */ { NULL,NULL},
/* D73E */ { NULL,NULL},
/* D73F */ { NULL,NULL},
/* D740 */ { NULL,NULL},
/* D741 */ { NULL,NULL},
/* D742 */ { NULL,NULL},
/* D743 */ { NULL,NULL},
/* D744 */ { NULL,NULL},
/* D745 */ { NULL,NULL},
/* D746 */ { NULL,NULL},
/* D747 */ { NULL,NULL},
/* D748 */ { NULL,NULL},
/* D749 */ { NULL,NULL},
/* D74A */ { NULL,NULL},
/* D74B */ { NULL,NULL},
/* D74C */ { NULL,NULL},
/* D74D */ { NULL,NULL},
/* D74E */ { NULL,NULL},
/* D74F */ { NULL,NULL},
/* D750 */ { NULL,NULL},
/* D751 */ { NULL,NULL},
/* D752 */ { NULL,NULL},
/* D753 */ { NULL,NULL},
/* D754 */ { NULL,NULL},
/* D755 */ { NULL,NULL},
/* D756 */ { NULL,NULL},
/* D757 */ { NULL,NULL},
/* D758 */ { NULL,NULL},
/* D759 */ { NULL,NULL},
/* D75A */ { NULL,NULL},
/* D75B */ { NULL,NULL},
/* D75C */ { NULL,NULL},
/* D75D */ { NULL,NULL},
/* D75E */ { NULL,NULL},
/* D75F */ { NULL,NULL},
/* D760 */ { NULL,NULL},
/* D761 */ { NULL,NULL},
/* D762 */ { NULL,NULL},
/* D763 */ { NULL,NULL},
/* D764 */ { NULL,NULL},
/* D765 */ { NULL,NULL},
/* D766 */ { NULL,NULL},
/* D767 */ { NULL,NULL},
/* D768 */ { NULL,NULL},
/* D769 */ { NULL,NULL},
/* D76A */ { NULL,NULL},
/* D76B */ { NULL,NULL},
/* D76C */ { NULL,NULL},
/* D76D */ { NULL,NULL},
/* D76E */ { NULL,NULL},
/* D76F */ { NULL,NULL},
/* D770 */ { NULL,NULL},
/* D771 */ { NULL,NULL},
/* D772 */ { NULL,NULL},
/* D773 */ { NULL,NULL},
/* D774 */ { NULL,NULL},
/* D775 */ { NULL,NULL},
/* D776 */ { NULL,NULL},
/* D777 */ { NULL,NULL},
/* D778 */ { NULL,NULL},
/* D779 */ { NULL,NULL},
/* D77A */ { NULL,NULL},
/* D77B */ { NULL,NULL},
/* D77C */ { NULL,NULL},
/* D77D */ { NULL,NULL},
/* D77E */ { NULL,NULL},
/* D77F */ { NULL,NULL},
/* D780 */ { NULL,NULL},
/* D781 */ { NULL,NULL},
/* D782 */ { NULL,NULL},
/* D783 */ { NULL,NULL},
/* D784 */ { NULL,NULL},
/* D785 */ { NULL,NULL},
/* D786 */ { NULL,NULL},
/* D787 */ { NULL,NULL},
/* D788 */ { NULL,NULL},
/* D789 */ { NULL,NULL},
/* D78A */ { NULL,NULL},
/* D78B */ { NULL,NULL},
/* D78C */ { NULL,NULL},
/* D78D */ { NULL,NULL},
/* D78E */ { NULL,NULL},
/* D78F */ { NULL,NULL},
/* D790 */ { NULL,NULL},
/* D791 */ { NULL,NULL},
/* D792 */ { NULL,NULL},
/* D793 */ { NULL,NULL},
/* D794 */ { NULL,NULL},
/* D795 */ { NULL,NULL},
/* D796 */ { NULL,NULL},
/* D797 */ { NULL,NULL},
/* D798 */ { NULL,NULL},
/* D799 */ { NULL,NULL},
/* D79A */ { NULL,NULL},
/* D79B */ { NULL,NULL},
/* D79C */ { NULL,NULL},
/* D79D */ { NULL,NULL},
/* D79E */ { NULL,NULL},
/* D79F */ { NULL,NULL},
/* D7A0 */ { NULL,NULL},
/* D7A1 */ { NULL,NULL},
/* D7A2 */ { NULL,NULL},
/* D7A3 */ { NULL,NULL},
/* D7A4 */ { NULL,NULL},
/* D7A5 */ { NULL,NULL},
/* D7A6 */ { NULL,NULL},
/* D7A7 */ { NULL,NULL},
/* D7A8 */ { NULL,NULL},
/* D7A9 */ { NULL,NULL},
/* D7AA */ { NULL,NULL},
/* D7AB */ { NULL,NULL},
/* D7AC */ { NULL,NULL},
/* D7AD */ { NULL,NULL},
/* D7AE */ { NULL,NULL},
/* D7AF */ { NULL,NULL},
/* D7B0 */ { "HANGUL JUNGSEONG O-YEO",NULL},
/* D7B1 */ { "HANGUL JUNGSEONG O-O-I",NULL},
/* D7B2 */ { "HANGUL JUNGSEONG YO-A",NULL},
/* D7B3 */ { "HANGUL JUNGSEONG YO-AE",NULL},
/* D7B4 */ { "HANGUL JUNGSEONG YO-EO",NULL},
/* D7B5 */ { "HANGUL JUNGSEONG U-YEO",NULL},
/* D7B6 */ { "HANGUL JUNGSEONG U-I-I",NULL},
/* D7B7 */ { "HANGUL JUNGSEONG YU-AE",NULL},
/* D7B8 */ { "HANGUL JUNGSEONG YU-O",NULL},
/* D7B9 */ { "HANGUL JUNGSEONG EU-A",NULL},
/* D7BA */ { "HANGUL JUNGSEONG EU-EO",NULL},
/* D7BB */ { "HANGUL JUNGSEONG EU-E",NULL},
/* D7BC */ { "HANGUL JUNGSEONG EU-O",NULL},
/* D7BD */ { "HANGUL JUNGSEONG I-YA-O",NULL},
/* D7BE */ { "HANGUL JUNGSEONG I-YAE",NULL},
/* D7BF */ { "HANGUL JUNGSEONG I-YEO",NULL},
/* D7C0 */ { "HANGUL JUNGSEONG I-YE",NULL},
/* D7C1 */ { "HANGUL JUNGSEONG I-O-I",NULL},
/* D7C2 */ { "HANGUL JUNGSEONG I-YO",NULL},
/* D7C3 */ { "HANGUL JUNGSEONG I-YU",NULL},
/* D7C4 */ { "HANGUL JUNGSEONG I-I",NULL},
/* D7C5 */ { "HANGUL JUNGSEONG ARAEA-A",NULL},
/* D7C6 */ { "HANGUL JUNGSEONG ARAEA-E",NULL},
/* D7C7 */ { NULL,NULL},
/* D7C8 */ { NULL,NULL},
/* D7C9 */ { NULL,NULL},
/* D7CA */ { NULL,NULL},
/* D7CB */ { "HANGUL JONGSEONG NIEUN-RIEUL",NULL},
/* D7CC */ { "HANGUL JONGSEONG NIEUN-CHIEUCH",NULL},
/* D7CD */ { "HANGUL JONGSEONG SSANGTIKEUT",NULL},
/* D7CE */ { "HANGUL JONGSEONG SSANGTIKEUT-PIEUP",NULL},
/* D7CF */ { "HANGUL JONGSEONG TIKEUT-PIEUP",NULL},
/* D7D0 */ { "HANGUL JONGSEONG TIKEUT-SIOS",NULL},
/* D7D1 */ { "HANGUL JONGSEONG TIKEUT-SIOS-KIYEOK",NULL},
/* D7D2 */ { "HANGUL JONGSEONG TIKEUT-CIEUC",NULL},
/* D7D3 */ { "HANGUL JONGSEONG TIKEUT-CHIEUCH",NULL},
/* D7D4 */ { "HANGUL JONGSEONG TIKEUT-THIEUTH",NULL},
/* D7D5 */ { "HANGUL JONGSEONG RIEUL-SSANGKIYEOK",NULL},
/* D7D6 */ { "HANGUL JONGSEONG RIEUL-KIYEOK-HIEUH",NULL},
/* D7D7 */ { "HANGUL JONGSEONG SSANGRIEUL-KHIEUKH",NULL},
/* D7D8 */ { "HANGUL JONGSEONG RIEUL-MIEUM-HIEUH",NULL},
/* D7D9 */ { "HANGUL JONGSEONG RIEUL-PIEUP-TIKEUT",NULL},
/* D7DA */ { "HANGUL JONGSEONG RIEUL-PIEUP-PHIEUPH",NULL},
/* D7DB */ { "HANGUL JONGSEONG RIEUL-YESIEUNG",NULL},
/* D7DC */ { "HANGUL JONGSEONG RIEUL-YEORINHIEUH-HIEUH",NULL},
/* D7DD */ { "HANGUL JONGSEONG KAPYEOUNRIEUL",NULL},
/* D7DE */ { "HANGUL JONGSEONG MIEUM-NIEUN",NULL},
/* D7DF */ { "HANGUL JONGSEONG MIEUM-SSANGNIEUN",NULL},
/* D7E0 */ { "HANGUL JONGSEONG SSANGMIEUM",NULL},
/* D7E1 */ { "HANGUL JONGSEONG MIEUM-PIEUP-SIOS",NULL},
/* D7E2 */ { "HANGUL JONGSEONG MIEUM-CIEUC",NULL},
/* D7E3 */ { "HANGUL JONGSEONG PIEUP-TIKEUT",NULL},
/* D7E4 */ { "HANGUL JONGSEONG PIEUP-RIEUL-PHIEUPH",NULL},
/* D7E5 */ { "HANGUL JONGSEONG PIEUP-MIEUM",NULL},
/* D7E6 */ { "HANGUL JONGSEONG SSANGPIEUP",NULL},
/* D7E7 */ { "HANGUL JONGSEONG PIEUP-SIOS-TIKEUT",NULL},
/* D7E8 */ { "HANGUL JONGSEONG PIEUP-CIEUC",NULL},
/* D7E9 */ { "HANGUL JONGSEONG PIEUP-CHIEUCH",NULL},
/* D7EA */ { "HANGUL JONGSEONG SIOS-MIEUM",NULL},
/* D7EB */ { "HANGUL JONGSEONG SIOS-KAPYEOUNPIEUP",NULL},
/* D7EC */ { "HANGUL JONGSEONG SSANGSIOS-KIYEOK",NULL},
/* D7ED */ { "HANGUL JONGSEONG SSANGSIOS-TIKEUT",NULL},
/* D7EE */ { "HANGUL JONGSEONG SIOS-PANSIOS",NULL},
/* D7EF */ { "HANGUL JONGSEONG SIOS-CIEUC",NULL},
/* D7F0 */ { "HANGUL JONGSEONG SIOS-CHIEUCH",NULL},
/* D7F1 */ { "HANGUL JONGSEONG SIOS-THIEUTH",NULL},
/* D7F2 */ { "HANGUL JONGSEONG SIOS-HIEUH",NULL},
/* D7F3 */ { "HANGUL JONGSEONG PANSIOS-PIEUP",NULL},
/* D7F4 */ { "HANGUL JONGSEONG PANSIOS-KAPYEOUNPIEUP",NULL},
/* D7F5 */ { "HANGUL JONGSEONG YESIEUNG-MIEUM",NULL},
/* D7F6 */ { "HANGUL JONGSEONG YESIEUNG-HIEUH",NULL},
/* D7F7 */ { "HANGUL JONGSEONG CIEUC-PIEUP",NULL},
/* D7F8 */ { "HANGUL JONGSEONG CIEUC-SSANGPIEUP",NULL},
/* D7F9 */ { "HANGUL JONGSEONG SSANGCIEUC",NULL},
/* D7FA */ { "HANGUL JONGSEONG PHIEUPH-SIOS",NULL},
/* D7FB */ { "HANGUL JONGSEONG PHIEUPH-THIEUTH",NULL},
/* D7FC */ { NULL,NULL},
/* D7FD */ { NULL,NULL},
/* D7FE */ { NULL,NULL},
/* D7FF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_00_F9[] = {
/* F900 */ { "CJK COMPATIBILITY IDEOGRAPH-F900","	: 8C48"},
/* F901 */ { "CJK COMPATIBILITY IDEOGRAPH-F901","	: 66F4"},
/* F902 */ { "CJK COMPATIBILITY IDEOGRAPH-F902","	: 8ECA"},
/* F903 */ { "CJK COMPATIBILITY IDEOGRAPH-F903","	: 8CC8"},
/* F904 */ { "CJK COMPATIBILITY IDEOGRAPH-F904","	: 6ED1"},
/* F905 */ { "CJK COMPATIBILITY IDEOGRAPH-F905","	: 4E32"},
/* F906 */ { "CJK COMPATIBILITY IDEOGRAPH-F906","	: 53E5"},
/* F907 */ { "CJK COMPATIBILITY IDEOGRAPH-F907","	: 9F9C"},
/* F908 */ { "CJK COMPATIBILITY IDEOGRAPH-F908","	: 9F9C"},
/* F909 */ { "CJK COMPATIBILITY IDEOGRAPH-F909","	: 5951"},
/* F90A */ { "CJK COMPATIBILITY IDEOGRAPH-F90A","	: 91D1"},
/* F90B */ { "CJK COMPATIBILITY IDEOGRAPH-F90B","	: 5587"},
/* F90C */ { "CJK COMPATIBILITY IDEOGRAPH-F90C","	: 5948"},
/* F90D */ { "CJK COMPATIBILITY IDEOGRAPH-F90D","	: 61F6"},
/* F90E */ { "CJK COMPATIBILITY IDEOGRAPH-F90E","	: 7669"},
/* F90F */ { "CJK COMPATIBILITY IDEOGRAPH-F90F","	: 7F85"},
/* F910 */ { "CJK COMPATIBILITY IDEOGRAPH-F910","	: 863F"},
/* F911 */ { "CJK COMPATIBILITY IDEOGRAPH-F911","	: 87BA"},
/* F912 */ { "CJK COMPATIBILITY IDEOGRAPH-F912","	: 88F8"},
/* F913 */ { "CJK COMPATIBILITY IDEOGRAPH-F913","	: 908F"},
/* F914 */ { "CJK COMPATIBILITY IDEOGRAPH-F914","	: 6A02"},
/* F915 */ { "CJK COMPATIBILITY IDEOGRAPH-F915","	: 6D1B"},
/* F916 */ { "CJK COMPATIBILITY IDEOGRAPH-F916","	: 70D9"},
/* F917 */ { "CJK COMPATIBILITY IDEOGRAPH-F917","	: 73DE"},
/* F918 */ { "CJK COMPATIBILITY IDEOGRAPH-F918","	: 843D"},
/* F919 */ { "CJK COMPATIBILITY IDEOGRAPH-F919","	: 916A"},
/* F91A */ { "CJK COMPATIBILITY IDEOGRAPH-F91A","	: 99F1"},
/* F91B */ { "CJK COMPATIBILITY IDEOGRAPH-F91B","	: 4E82"},
/* F91C */ { "CJK COMPATIBILITY IDEOGRAPH-F91C","	: 5375"},
/* F91D */ { "CJK COMPATIBILITY IDEOGRAPH-F91D","	: 6B04"},
/* F91E */ { "CJK COMPATIBILITY IDEOGRAPH-F91E","	: 721B"},
/* F91F */ { "CJK COMPATIBILITY IDEOGRAPH-F91F","	: 862D"},
/* F920 */ { "CJK COMPATIBILITY IDEOGRAPH-F920","	: 9E1E"},
/* F921 */ { "CJK COMPATIBILITY IDEOGRAPH-F921","	: 5D50"},
/* F922 */ { "CJK COMPATIBILITY IDEOGRAPH-F922","	: 6FEB"},
/* F923 */ { "CJK COMPATIBILITY IDEOGRAPH-F923","	: 85CD"},
/* F924 */ { "CJK COMPATIBILITY IDEOGRAPH-F924","	: 8964"},
/* F925 */ { "CJK COMPATIBILITY IDEOGRAPH-F925","	: 62C9"},
/* F926 */ { "CJK COMPATIBILITY IDEOGRAPH-F926","	: 81D8"},
/* F927 */ { "CJK COMPATIBILITY IDEOGRAPH-F927","	: 881F"},
/* F928 */ { "CJK COMPATIBILITY IDEOGRAPH-F928","	: 5ECA"},
/* F929 */ { "CJK COMPATIBILITY IDEOGRAPH-F929","	: 6717"},
/* F92A */ { "CJK COMPATIBILITY IDEOGRAPH-F92A","	: 6D6A"},
/* F92B */ { "CJK COMPATIBILITY IDEOGRAPH-F92B","	: 72FC"},
/* F92C */ { "CJK COMPATIBILITY IDEOGRAPH-F92C","	* a mapping change removed the original K0 source\n"
	"	x 90DE\n"
	"	x (cjk compatibility ideograph-FA2E - FA2E)\n"
	"	: 90CE"},
/* F92D */ { "CJK COMPATIBILITY IDEOGRAPH-F92D","	: 4F86"},
/* F92E */ { "CJK COMPATIBILITY IDEOGRAPH-F92E","	: 51B7"},
/* F92F */ { "CJK COMPATIBILITY IDEOGRAPH-F92F","	: 52DE"},
/* F930 */ { "CJK COMPATIBILITY IDEOGRAPH-F930","	: 64C4"},
/* F931 */ { "CJK COMPATIBILITY IDEOGRAPH-F931","	: 6AD3"},
/* F932 */ { "CJK COMPATIBILITY IDEOGRAPH-F932","	: 7210"},
/* F933 */ { "CJK COMPATIBILITY IDEOGRAPH-F933","	: 76E7"},
/* F934 */ { "CJK COMPATIBILITY IDEOGRAPH-F934","	: 8001"},
/* F935 */ { "CJK COMPATIBILITY IDEOGRAPH-F935","	: 8606"},
/* F936 */ { "CJK COMPATIBILITY IDEOGRAPH-F936","	: 865C"},
/* F937 */ { "CJK COMPATIBILITY IDEOGRAPH-F937","	: 8DEF"},
/* F938 */ { "CJK COMPATIBILITY IDEOGRAPH-F938","	: 9732"},
/* F939 */ { "CJK COMPATIBILITY IDEOGRAPH-F939","	: 9B6F"},
/* F93A */ { "CJK COMPATIBILITY IDEOGRAPH-F93A","	: 9DFA"},
/* F93B */ { "CJK COMPATIBILITY IDEOGRAPH-F93B","	: 788C"},
/* F93C */ { "CJK COMPATIBILITY IDEOGRAPH-F93C","	: 797F"},
/* F93D */ { "CJK COMPATIBILITY IDEOGRAPH-F93D","	: 7DA0"},
/* F93E */ { "CJK COMPATIBILITY IDEOGRAPH-F93E","	: 83C9"},
/* F93F */ { "CJK COMPATIBILITY IDEOGRAPH-F93F","	: 9304"},
/* F940 */ { "CJK COMPATIBILITY IDEOGRAPH-F940","	: 9E7F"},
/* F941 */ { "CJK COMPATIBILITY IDEOGRAPH-F941","	: 8AD6"},
/* F942 */ { "CJK COMPATIBILITY IDEOGRAPH-F942","	: 58DF"},
/* F943 */ { "CJK COMPATIBILITY IDEOGRAPH-F943","	: 5F04"},
/* F944 */ { "CJK COMPATIBILITY IDEOGRAPH-F944","	: 7C60"},
/* F945 */ { "CJK COMPATIBILITY IDEOGRAPH-F945","	: 807E"},
/* F946 */ { "CJK COMPATIBILITY IDEOGRAPH-F946","	: 7262"},
/* F947 */ { "CJK COMPATIBILITY IDEOGRAPH-F947","	: 78CA"},
/* F948 */ { "CJK COMPATIBILITY IDEOGRAPH-F948","	: 8CC2"},
/* F949 */ { "CJK COMPATIBILITY IDEOGRAPH-F949","	: 96F7"},
/* F94A */ { "CJK COMPATIBILITY IDEOGRAPH-F94A","	: 58D8"},
/* F94B */ { "CJK COMPATIBILITY IDEOGRAPH-F94B","	: 5C62"},
/* F94C */ { "CJK COMPATIBILITY IDEOGRAPH-F94C","	: 6A13"},
/* F94D */ { "CJK COMPATIBILITY IDEOGRAPH-F94D","	: 6DDA"},
/* F94E */ { "CJK COMPATIBILITY IDEOGRAPH-F94E","	: 6F0F"},
/* F94F */ { "CJK COMPATIBILITY IDEOGRAPH-F94F","	: 7D2F"},
/* F950 */ { "CJK COMPATIBILITY IDEOGRAPH-F950","	: 7E37"},
/* F951 */ { "CJK COMPATIBILITY IDEOGRAPH-F951","	: 964B"},
/* F952 */ { "CJK COMPATIBILITY IDEOGRAPH-F952","	: 52D2"},
/* F953 */ { "CJK COMPATIBILITY IDEOGRAPH-F953","	: 808B"},
/* F954 */ { "CJK COMPATIBILITY IDEOGRAPH-F954","	: 51DC"},
/* F955 */ { "CJK COMPATIBILITY IDEOGRAPH-F955","	: 51CC"},
/* F956 */ { "CJK COMPATIBILITY IDEOGRAPH-F956","	: 7A1C"},
/* F957 */ { "CJK COMPATIBILITY IDEOGRAPH-F957","	: 7DBE"},
/* F958 */ { "CJK COMPATIBILITY IDEOGRAPH-F958","	: 83F1"},
/* F959 */ { "CJK COMPATIBILITY IDEOGRAPH-F959","	: 9675"},
/* F95A */ { "CJK COMPATIBILITY IDEOGRAPH-F95A","	: 8B80"},
/* F95B */ { "CJK COMPATIBILITY IDEOGRAPH-F95B","	: 62CF"},
/* F95C */ { "CJK COMPATIBILITY IDEOGRAPH-F95C","	: 6A02"},
/* F95D */ { "CJK COMPATIBILITY IDEOGRAPH-F95D","	: 8AFE"},
/* F95E */ { "CJK COMPATIBILITY IDEOGRAPH-F95E","	: 4E39"},
/* F95F */ { "CJK COMPATIBILITY IDEOGRAPH-F95F","	: 5BE7"},
/* F960 */ { "CJK COMPATIBILITY IDEOGRAPH-F960","	: 6012"},
/* F961 */ { "CJK COMPATIBILITY IDEOGRAPH-F961","	: 7387"},
/* F962 */ { "CJK COMPATIBILITY IDEOGRAPH-F962","	: 7570"},
/* F963 */ { "CJK COMPATIBILITY IDEOGRAPH-F963","	: 5317"},
/* F964 */ { "CJK COMPATIBILITY IDEOGRAPH-F964","	: 78FB"},
/* F965 */ { "CJK COMPATIBILITY IDEOGRAPH-F965","	: 4FBF"},
/* F966 */ { "CJK COMPATIBILITY IDEOGRAPH-F966","	: 5FA9"},
/* F967 */ { "CJK COMPATIBILITY IDEOGRAPH-F967","	: 4E0D"},
/* F968 */ { "CJK COMPATIBILITY IDEOGRAPH-F968","	: 6CCC"},
/* F969 */ { "CJK COMPATIBILITY IDEOGRAPH-F969","	: 6578"},
/* F96A */ { "CJK COMPATIBILITY IDEOGRAPH-F96A","	: 7D22"},
/* F96B */ { "CJK COMPATIBILITY IDEOGRAPH-F96B","	: 53C3"},
/* F96C */ { "CJK COMPATIBILITY IDEOGRAPH-F96C","	: 585E"},
/* F96D */ { "CJK COMPATIBILITY IDEOGRAPH-F96D","	: 7701"},
/* F96E */ { "CJK COMPATIBILITY IDEOGRAPH-F96E","	: 8449"},
/* F96F */ { "CJK COMPATIBILITY IDEOGRAPH-F96F","	: 8AAA"},
/* F970 */ { "CJK COMPATIBILITY IDEOGRAPH-F970","	: 6BBA"},
/* F971 */ { "CJK COMPATIBILITY IDEOGRAPH-F971","	: 8FB0"},
/* F972 */ { "CJK COMPATIBILITY IDEOGRAPH-F972","	: 6C88"},
/* F973 */ { "CJK COMPATIBILITY IDEOGRAPH-F973","	: 62FE"},
/* F974 */ { "CJK COMPATIBILITY IDEOGRAPH-F974","	: 82E5"},
/* F975 */ { "CJK COMPATIBILITY IDEOGRAPH-F975","	: 63A0"},
/* F976 */ { "CJK COMPATIBILITY IDEOGRAPH-F976","	: 7565"},
/* F977 */ { "CJK COMPATIBILITY IDEOGRAPH-F977","	: 4EAE"},
/* F978 */ { "CJK COMPATIBILITY IDEOGRAPH-F978","	: 5169"},
/* F979 */ { "CJK COMPATIBILITY IDEOGRAPH-F979","	: 51C9"},
/* F97A */ { "CJK COMPATIBILITY IDEOGRAPH-F97A","	: 6881"},
/* F97B */ { "CJK COMPATIBILITY IDEOGRAPH-F97B","	: 7CE7"},
/* F97C */ { "CJK COMPATIBILITY IDEOGRAPH-F97C","	: 826F"},
/* F97D */ { "CJK COMPATIBILITY IDEOGRAPH-F97D","	: 8AD2"},
/* F97E */ { "CJK COMPATIBILITY IDEOGRAPH-F97E","	: 91CF"},
/* F97F */ { "CJK COMPATIBILITY IDEOGRAPH-F97F","	: 52F5"},
/* F980 */ { "CJK COMPATIBILITY IDEOGRAPH-F980","	: 5442"},
/* F981 */ { "CJK COMPATIBILITY IDEOGRAPH-F981","	: 5973"},
/* F982 */ { "CJK COMPATIBILITY IDEOGRAPH-F982","	: 5EEC"},
/* F983 */ { "CJK COMPATIBILITY IDEOGRAPH-F983","	: 65C5"},
/* F984 */ { "CJK COMPATIBILITY IDEOGRAPH-F984","	: 6FFE"},
/* F985 */ { "CJK COMPATIBILITY IDEOGRAPH-F985","	: 792A"},
/* F986 */ { "CJK COMPATIBILITY IDEOGRAPH-F986","	: 95AD"},
/* F987 */ { "CJK COMPATIBILITY IDEOGRAPH-F987","	: 9A6A"},
/* F988 */ { "CJK COMPATIBILITY IDEOGRAPH-F988","	: 9E97"},
/* F989 */ { "CJK COMPATIBILITY IDEOGRAPH-F989","	: 9ECE"},
/* F98A */ { "CJK COMPATIBILITY IDEOGRAPH-F98A","	: 529B"},
/* F98B */ { "CJK COMPATIBILITY IDEOGRAPH-F98B","	: 66C6"},
/* F98C */ { "CJK COMPATIBILITY IDEOGRAPH-F98C","	: 6B77"},
/* F98D */ { "CJK COMPATIBILITY IDEOGRAPH-F98D","	: 8F62"},
/* F98E */ { "CJK COMPATIBILITY IDEOGRAPH-F98E","	: 5E74"},
/* F98F */ { "CJK COMPATIBILITY IDEOGRAPH-F98F","	: 6190"},
/* F990 */ { "CJK COMPATIBILITY IDEOGRAPH-F990","	: 6200"},
/* F991 */ { "CJK COMPATIBILITY IDEOGRAPH-F991","	: 649A"},
/* F992 */ { "CJK COMPATIBILITY IDEOGRAPH-F992","	: 6F23"},
/* F993 */ { "CJK COMPATIBILITY IDEOGRAPH-F993","	: 7149"},
/* F994 */ { "CJK COMPATIBILITY IDEOGRAPH-F994","	: 7489"},
/* F995 */ { "CJK COMPATIBILITY IDEOGRAPH-F995","	: 79CA"},
/* F996 */ { "CJK COMPATIBILITY IDEOGRAPH-F996","	: 7DF4"},
/* F997 */ { "CJK COMPATIBILITY IDEOGRAPH-F997","	: 806F"},
/* F998 */ { "CJK COMPATIBILITY IDEOGRAPH-F998","	: 8F26"},
/* F999 */ { "CJK COMPATIBILITY IDEOGRAPH-F999","	: 84EE"},
/* F99A */ { "CJK COMPATIBILITY IDEOGRAPH-F99A","	: 9023"},
/* F99B */ { "CJK COMPATIBILITY IDEOGRAPH-F99B","	: 934A"},
/* F99C */ { "CJK COMPATIBILITY IDEOGRAPH-F99C","	: 5217"},
/* F99D */ { "CJK COMPATIBILITY IDEOGRAPH-F99D","	: 52A3"},
/* F99E */ { "CJK COMPATIBILITY IDEOGRAPH-F99E","	: 54BD"},
/* F99F */ { "CJK COMPATIBILITY IDEOGRAPH-F99F","	: 70C8"},
/* F9A0 */ { "CJK COMPATIBILITY IDEOGRAPH-F9A0","	: 88C2"},
/* F9A1 */ { "CJK COMPATIBILITY IDEOGRAPH-F9A1","	: 8AAA"},
/* F9A2 */ { "CJK COMPATIBILITY IDEOGRAPH-F9A2","	: 5EC9"},
/* F9A3 */ { "CJK COMPATIBILITY IDEOGRAPH-F9A3","	: 5FF5"},
/* F9A4 */ { "CJK COMPATIBILITY IDEOGRAPH-F9A4","	: 637B"},
/* F9A5 */ { "CJK COMPATIBILITY IDEOGRAPH-F9A5","	: 6BAE"},
/* F9A6 */ { "CJK COMPATIBILITY IDEOGRAPH-F9A6","	: 7C3E"},
/* F9A7 */ { "CJK COMPATIBILITY IDEOGRAPH-F9A7","	: 7375"},
/* F9A8 */ { "CJK COMPATIBILITY IDEOGRAPH-F9A8","	: 4EE4"},
/* F9A9 */ { "CJK COMPATIBILITY IDEOGRAPH-F9A9","	: 56F9"},
/* F9AA */ { "CJK COMPATIBILITY IDEOGRAPH-F9AA","	: 5BE7"},
/* F9AB */ { "CJK COMPATIBILITY IDEOGRAPH-F9AB","	: 5DBA"},
/* F9AC */ { "CJK COMPATIBILITY IDEOGRAPH-F9AC","	: 601C"},
/* F9AD */ { "CJK COMPATIBILITY IDEOGRAPH-F9AD","	: 73B2"},
/* F9AE */ { "CJK COMPATIBILITY IDEOGRAPH-F9AE","	: 7469"},
/* F9AF */ { "CJK COMPATIBILITY IDEOGRAPH-F9AF","	: 7F9A"},
/* F9B0 */ { "CJK COMPATIBILITY IDEOGRAPH-F9B0","	: 8046"},
/* F9B1 */ { "CJK COMPATIBILITY IDEOGRAPH-F9B1","	: 9234"},
/* F9B2 */ { "CJK COMPATIBILITY IDEOGRAPH-F9B2","	: 96F6"},
/* F9B3 */ { "CJK COMPATIBILITY IDEOGRAPH-F9B3","	: 9748"},
/* F9B4 */ { "CJK COMPATIBILITY IDEOGRAPH-F9B4","	: 9818"},
/* F9B5 */ { "CJK COMPATIBILITY IDEOGRAPH-F9B5","	: 4F8B"},
/* F9B6 */ { "CJK COMPATIBILITY IDEOGRAPH-F9B6","	: 79AE"},
/* F9B7 */ { "CJK COMPATIBILITY IDEOGRAPH-F9B7","	: 91B4"},
/* F9B8 */ { "CJK COMPATIBILITY IDEOGRAPH-F9B8","	* a mapping change removed the original K0 source\n"
	"	x 96B7\n"
	"	x (cjk compatibility ideograph-FA2F - FA2F)\n"
	"	: 96B8"},
/* F9B9 */ { "CJK COMPATIBILITY IDEOGRAPH-F9B9","	: 60E1"},
/* F9BA */ { "CJK COMPATIBILITY IDEOGRAPH-F9BA","	: 4E86"},
/* F9BB */ { "CJK COMPATIBILITY IDEOGRAPH-F9BB","	: 50DA"},
/* F9BC */ { "CJK COMPATIBILITY IDEOGRAPH-F9BC","	: 5BEE"},
/* F9BD */ { "CJK COMPATIBILITY IDEOGRAPH-F9BD","	: 5C3F"},
/* F9BE */ { "CJK COMPATIBILITY IDEOGRAPH-F9BE","	: 6599"},
/* F9BF */ { "CJK COMPATIBILITY IDEOGRAPH-F9BF","	: 6A02"},
/* F9C0 */ { "CJK COMPATIBILITY IDEOGRAPH-F9C0","	: 71CE"},
/* F9C1 */ { "CJK COMPATIBILITY IDEOGRAPH-F9C1","	: 7642"},
/* F9C2 */ { "CJK COMPATIBILITY IDEOGRAPH-F9C2","	: 84FC"},
/* F9C3 */ { "CJK COMPATIBILITY IDEOGRAPH-F9C3","	: 907C"},
/* F9C4 */ { "CJK COMPATIBILITY IDEOGRAPH-F9C4","	: 9F8D"},
/* F9C5 */ { "CJK COMPATIBILITY IDEOGRAPH-F9C5","	: 6688"},
/* F9C6 */ { "CJK COMPATIBILITY IDEOGRAPH-F9C6","	: 962E"},
/* F9C7 */ { "CJK COMPATIBILITY IDEOGRAPH-F9C7","	: 5289"},
/* F9C8 */ { "CJK COMPATIBILITY IDEOGRAPH-F9C8","	: 677B"},
/* F9C9 */ { "CJK COMPATIBILITY IDEOGRAPH-F9C9","	: 67F3"},
/* F9CA */ { "CJK COMPATIBILITY IDEOGRAPH-F9CA","	: 6D41"},
/* F9CB */ { "CJK COMPATIBILITY IDEOGRAPH-F9CB","	: 6E9C"},
/* F9CC */ { "CJK COMPATIBILITY IDEOGRAPH-F9CC","	: 7409"},
/* F9CD */ { "CJK COMPATIBILITY IDEOGRAPH-F9CD","	: 7559"},
/* F9CE */ { "CJK COMPATIBILITY IDEOGRAPH-F9CE","	: 786B"},
/* F9CF */ { "CJK COMPATIBILITY IDEOGRAPH-F9CF","	: 7D10"},
/* F9D0 */ { "CJK COMPATIBILITY IDEOGRAPH-F9D0","	: 985E"},
/* F9D1 */ { "CJK COMPATIBILITY IDEOGRAPH-F9D1","	: 516D"},
/* F9D2 */ { "CJK COMPATIBILITY IDEOGRAPH-F9D2","	: 622E"},
/* F9D3 */ { "CJK COMPATIBILITY IDEOGRAPH-F9D3","	: 9678"},
/* F9D4 */ { "CJK COMPATIBILITY IDEOGRAPH-F9D4","	: 502B"},
/* F9D5 */ { "CJK COMPATIBILITY IDEOGRAPH-F9D5","	: 5D19"},
/* F9D6 */ { "CJK COMPATIBILITY IDEOGRAPH-F9D6","	: 6DEA"},
/* F9D7 */ { "CJK COMPATIBILITY IDEOGRAPH-F9D7","	: 8F2A"},
/* F9D8 */ { "CJK COMPATIBILITY IDEOGRAPH-F9D8","	: 5F8B"},
/* F9D9 */ { "CJK COMPATIBILITY IDEOGRAPH-F9D9","	: 6144"},
/* F9DA */ { "CJK COMPATIBILITY IDEOGRAPH-F9DA","	: 6817"},
/* F9DB */ { "CJK COMPATIBILITY IDEOGRAPH-F9DB","	: 7387"},
/* F9DC */ { "CJK COMPATIBILITY IDEOGRAPH-F9DC","	: 9686"},
/* F9DD */ { "CJK COMPATIBILITY IDEOGRAPH-F9DD","	: 5229"},
/* F9DE */ { "CJK COMPATIBILITY IDEOGRAPH-F9DE","	: 540F"},
/* F9DF */ { "CJK COMPATIBILITY IDEOGRAPH-F9DF","	: 5C65"},
/* F9E0 */ { "CJK COMPATIBILITY IDEOGRAPH-F9E0","	: 6613"},
/* F9E1 */ { "CJK COMPATIBILITY IDEOGRAPH-F9E1","	: 674E"},
/* F9E2 */ { "CJK COMPATIBILITY IDEOGRAPH-F9E2","	: 68A8"},
/* F9E3 */ { "CJK COMPATIBILITY IDEOGRAPH-F9E3","	: 6CE5"},
/* F9E4 */ { "CJK COMPATIBILITY IDEOGRAPH-F9E4","	: 7406"},
/* F9E5 */ { "CJK COMPATIBILITY IDEOGRAPH-F9E5","	: 75E2"},
/* F9E6 */ { "CJK COMPATIBILITY IDEOGRAPH-F9E6","	: 7F79"},
/* F9E7 */ { "CJK COMPATIBILITY IDEOGRAPH-F9E7","	: 88CF"},
/* F9E8 */ { "CJK COMPATIBILITY IDEOGRAPH-F9E8","	: 88E1"},
/* F9E9 */ { "CJK COMPATIBILITY IDEOGRAPH-F9E9","	: 91CC"},
/* F9EA */ { "CJK COMPATIBILITY IDEOGRAPH-F9EA","	: 96E2"},
/* F9EB */ { "CJK COMPATIBILITY IDEOGRAPH-F9EB","	: 533F"},
/* F9EC */ { "CJK COMPATIBILITY IDEOGRAPH-F9EC","	: 6EBA"},
/* F9ED */ { "CJK COMPATIBILITY IDEOGRAPH-F9ED","	: 541D"},
/* F9EE */ { "CJK COMPATIBILITY IDEOGRAPH-F9EE","	: 71D0"},
/* F9EF */ { "CJK COMPATIBILITY IDEOGRAPH-F9EF","	: 7498"},
/* F9F0 */ { "CJK COMPATIBILITY IDEOGRAPH-F9F0","	: 85FA"},
/* F9F1 */ { "CJK COMPATIBILITY IDEOGRAPH-F9F1","	: 96A3"},
/* F9F2 */ { "CJK COMPATIBILITY IDEOGRAPH-F9F2","	: 9C57"},
/* F9F3 */ { "CJK COMPATIBILITY IDEOGRAPH-F9F3","	: 9E9F"},
/* F9F4 */ { "CJK COMPATIBILITY IDEOGRAPH-F9F4","	: 6797"},
/* F9F5 */ { "CJK COMPATIBILITY IDEOGRAPH-F9F5","	: 6DCB"},
/* F9F6 */ { "CJK COMPATIBILITY IDEOGRAPH-F9F6","	: 81E8"},
/* F9F7 */ { "CJK COMPATIBILITY IDEOGRAPH-F9F7","	: 7ACB"},
/* F9F8 */ { "CJK COMPATIBILITY IDEOGRAPH-F9F8","	: 7B20"},
/* F9F9 */ { "CJK COMPATIBILITY IDEOGRAPH-F9F9","	: 7C92"},
/* F9FA */ { "CJK COMPATIBILITY IDEOGRAPH-F9FA","	: 72C0"},
/* F9FB */ { "CJK COMPATIBILITY IDEOGRAPH-F9FB","	: 7099"},
/* F9FC */ { "CJK COMPATIBILITY IDEOGRAPH-F9FC","	: 8B58"},
/* F9FD */ { "CJK COMPATIBILITY IDEOGRAPH-F9FD","	: 4EC0"},
/* F9FE */ { "CJK COMPATIBILITY IDEOGRAPH-F9FE","	: 8336"},
/* F9FF */ { "CJK COMPATIBILITY IDEOGRAPH-F9FF","	: 523A"}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_00_FA[] = {
/* FA00 */ { "CJK COMPATIBILITY IDEOGRAPH-FA00","	: 5207"},
/* FA01 */ { "CJK COMPATIBILITY IDEOGRAPH-FA01","	: 5EA6"},
/* FA02 */ { "CJK COMPATIBILITY IDEOGRAPH-FA02","	: 62D3"},
/* FA03 */ { "CJK COMPATIBILITY IDEOGRAPH-FA03","	: 7CD6"},
/* FA04 */ { "CJK COMPATIBILITY IDEOGRAPH-FA04","	: 5B85"},
/* FA05 */ { "CJK COMPATIBILITY IDEOGRAPH-FA05","	: 6D1E"},
/* FA06 */ { "CJK COMPATIBILITY IDEOGRAPH-FA06","	: 66B4"},
/* FA07 */ { "CJK COMPATIBILITY IDEOGRAPH-FA07","	: 8F3B"},
/* FA08 */ { "CJK COMPATIBILITY IDEOGRAPH-FA08","	: 884C"},
/* FA09 */ { "CJK COMPATIBILITY IDEOGRAPH-FA09","	: 964D"},
/* FA0A */ { "CJK COMPATIBILITY IDEOGRAPH-FA0A","	: 898B"},
/* FA0B */ { "CJK COMPATIBILITY IDEOGRAPH-FA0B","	: 5ED3"},
/* FA0C */ { "CJK COMPATIBILITY IDEOGRAPH-FA0C","	: 5140"},
/* FA0D */ { "CJK COMPATIBILITY IDEOGRAPH-FA0D","	: 55C0"},
/* FA0E */ { "CJK COMPATIBILITY IDEOGRAPH-FA0E","	* a CJK unified ideograph"},
/* FA0F */ { "CJK COMPATIBILITY IDEOGRAPH-FA0F","	* a CJK unified ideograph"},
/* FA10 */ { "CJK COMPATIBILITY IDEOGRAPH-FA10","	: 585A"},
/* FA11 */ { "CJK COMPATIBILITY IDEOGRAPH-FA11","	* a CJK unified ideograph"},
/* FA12 */ { "CJK COMPATIBILITY IDEOGRAPH-FA12","	: 6674"},
/* FA13 */ { "CJK COMPATIBILITY IDEOGRAPH-FA13","	* a CJK unified ideograph"},
/* FA14 */ { "CJK COMPATIBILITY IDEOGRAPH-FA14","	* a CJK unified ideograph"},
/* FA15 */ { "CJK COMPATIBILITY IDEOGRAPH-FA15","	: 51DE"},
/* FA16 */ { "CJK COMPATIBILITY IDEOGRAPH-FA16","	: 732A"},
/* FA17 */ { "CJK COMPATIBILITY IDEOGRAPH-FA17","	: 76CA"},
/* FA18 */ { "CJK COMPATIBILITY IDEOGRAPH-FA18","	: 793C"},
/* FA19 */ { "CJK COMPATIBILITY IDEOGRAPH-FA19","	: 795E"},
/* FA1A */ { "CJK COMPATIBILITY IDEOGRAPH-FA1A","	: 7965"},
/* FA1B */ { "CJK COMPATIBILITY IDEOGRAPH-FA1B","	: 798F"},
/* FA1C */ { "CJK COMPATIBILITY IDEOGRAPH-FA1C","	: 9756"},
/* FA1D */ { "CJK COMPATIBILITY IDEOGRAPH-FA1D","	: 7CBE"},
/* FA1E */ { "CJK COMPATIBILITY IDEOGRAPH-FA1E","	: 7FBD"},
/* FA1F */ { "CJK COMPATIBILITY IDEOGRAPH-FA1F","	* a CJK unified ideograph"},
/* FA20 */ { "CJK COMPATIBILITY IDEOGRAPH-FA20","	: 8612"},
/* FA21 */ { "CJK COMPATIBILITY IDEOGRAPH-FA21","	* a CJK unified ideograph"},
/* FA22 */ { "CJK COMPATIBILITY IDEOGRAPH-FA22","	: 8AF8"},
/* FA23 */ { "CJK COMPATIBILITY IDEOGRAPH-FA23","	* a CJK unified ideograph"},
/* FA24 */ { "CJK COMPATIBILITY IDEOGRAPH-FA24","	* a CJK unified ideograph"},
/* FA25 */ { "CJK COMPATIBILITY IDEOGRAPH-FA25","	: 9038"},
/* FA26 */ { "CJK COMPATIBILITY IDEOGRAPH-FA26","	: 90FD"},
/* FA27 */ { "CJK COMPATIBILITY IDEOGRAPH-FA27","	* a CJK unified ideograph"},
/* FA28 */ { "CJK COMPATIBILITY IDEOGRAPH-FA28","	* a CJK unified ideograph"},
/* FA29 */ { "CJK COMPATIBILITY IDEOGRAPH-FA29","	* a CJK unified ideograph"},
/* FA2A */ { "CJK COMPATIBILITY IDEOGRAPH-FA2A","	: 98EF"},
/* FA2B */ { "CJK COMPATIBILITY IDEOGRAPH-FA2B","	: 98FC"},
/* FA2C */ { "CJK COMPATIBILITY IDEOGRAPH-FA2C","	: 9928"},
/* FA2D */ { "CJK COMPATIBILITY IDEOGRAPH-FA2D","	: 9DB4"},
/* FA2E */ { "CJK COMPATIBILITY IDEOGRAPH-FA2E","	: 90DE"},
/* FA2F */ { "CJK COMPATIBILITY IDEOGRAPH-FA2F","	: 96B7"},
/* FA30 */ { "CJK COMPATIBILITY IDEOGRAPH-FA30","	: 4FAE"},
/* FA31 */ { "CJK COMPATIBILITY IDEOGRAPH-FA31","	: 50E7"},
/* FA32 */ { "CJK COMPATIBILITY IDEOGRAPH-FA32","	: 514D"},
/* FA33 */ { "CJK COMPATIBILITY IDEOGRAPH-FA33","	: 52C9"},
/* FA34 */ { "CJK COMPATIBILITY IDEOGRAPH-FA34","	: 52E4"},
/* FA35 */ { "CJK COMPATIBILITY IDEOGRAPH-FA35","	: 5351"},
/* FA36 */ { "CJK COMPATIBILITY IDEOGRAPH-FA36","	: 559D"},
/* FA37 */ { "CJK COMPATIBILITY IDEOGRAPH-FA37","	: 5606"},
/* FA38 */ { "CJK COMPATIBILITY IDEOGRAPH-FA38","	: 5668"},
/* FA39 */ { "CJK COMPATIBILITY IDEOGRAPH-FA39","	: 5840"},
/* FA3A */ { "CJK COMPATIBILITY IDEOGRAPH-FA3A","	: 58A8"},
/* FA3B */ { "CJK COMPATIBILITY IDEOGRAPH-FA3B","	: 5C64"},
/* FA3C */ { "CJK COMPATIBILITY IDEOGRAPH-FA3C","	: 5C6E"},
/* FA3D */ { "CJK COMPATIBILITY IDEOGRAPH-FA3D","	: 6094"},
/* FA3E */ { "CJK COMPATIBILITY IDEOGRAPH-FA3E","	: 6168"},
/* FA3F */ { "CJK COMPATIBILITY IDEOGRAPH-FA3F","	: 618E"},
/* FA40 */ { "CJK COMPATIBILITY IDEOGRAPH-FA40","	: 61F2"},
/* FA41 */ { "CJK COMPATIBILITY IDEOGRAPH-FA41","	: 654F"},
/* FA42 */ { "CJK COMPATIBILITY IDEOGRAPH-FA42","	: 65E2"},
/* FA43 */ { "CJK COMPATIBILITY IDEOGRAPH-FA43","	: 6691"},
/* FA44 */ { "CJK COMPATIBILITY IDEOGRAPH-FA44","	: 6885"},
/* FA45 */ { "CJK COMPATIBILITY IDEOGRAPH-FA45","	: 6D77"},
/* FA46 */ { "CJK COMPATIBILITY IDEOGRAPH-FA46","	: 6E1A"},
/* FA47 */ { "CJK COMPATIBILITY IDEOGRAPH-FA47","	: 6F22"},
/* FA48 */ { "CJK COMPATIBILITY IDEOGRAPH-FA48","	: 716E"},
/* FA49 */ { "CJK COMPATIBILITY IDEOGRAPH-FA49","	: 722B"},
/* FA4A */ { "CJK COMPATIBILITY IDEOGRAPH-FA4A","	: 7422"},
/* FA4B */ { "CJK COMPATIBILITY IDEOGRAPH-FA4B","	: 7891"},
/* FA4C */ { "CJK COMPATIBILITY IDEOGRAPH-FA4C","	: 793E"},
/* FA4D */ { "CJK COMPATIBILITY IDEOGRAPH-FA4D","	: 7949"},
/* FA4E */ { "CJK COMPATIBILITY IDEOGRAPH-FA4E","	: 7948"},
/* FA4F */ { "CJK COMPATIBILITY IDEOGRAPH-FA4F","	: 7950"},
/* FA50 */ { "CJK COMPATIBILITY IDEOGRAPH-FA50","	: 7956"},
/* FA51 */ { "CJK COMPATIBILITY IDEOGRAPH-FA51","	: 795D"},
/* FA52 */ { "CJK COMPATIBILITY IDEOGRAPH-FA52","	: 798D"},
/* FA53 */ { "CJK COMPATIBILITY IDEOGRAPH-FA53","	: 798E"},
/* FA54 */ { "CJK COMPATIBILITY IDEOGRAPH-FA54","	: 7A40"},
/* FA55 */ { "CJK COMPATIBILITY IDEOGRAPH-FA55","	: 7A81"},
/* FA56 */ { "CJK COMPATIBILITY IDEOGRAPH-FA56","	: 7BC0"},
/* FA57 */ { "CJK COMPATIBILITY IDEOGRAPH-FA57","	: 7DF4"},
/* FA58 */ { "CJK COMPATIBILITY IDEOGRAPH-FA58","	: 7E09"},
/* FA59 */ { "CJK COMPATIBILITY IDEOGRAPH-FA59","	: 7E41"},
/* FA5A */ { "CJK COMPATIBILITY IDEOGRAPH-FA5A","	: 7F72"},
/* FA5B */ { "CJK COMPATIBILITY IDEOGRAPH-FA5B","	: 8005"},
/* FA5C */ { "CJK COMPATIBILITY IDEOGRAPH-FA5C","	: 81ED"},
/* FA5D */ { "CJK COMPATIBILITY IDEOGRAPH-FA5D","	: 8279"},
/* FA5E */ { "CJK COMPATIBILITY IDEOGRAPH-FA5E","	: 8279"},
/* FA5F */ { "CJK COMPATIBILITY IDEOGRAPH-FA5F","	: 8457"},
/* FA60 */ { "CJK COMPATIBILITY IDEOGRAPH-FA60","	: 8910"},
/* FA61 */ { "CJK COMPATIBILITY IDEOGRAPH-FA61","	: 8996"},
/* FA62 */ { "CJK COMPATIBILITY IDEOGRAPH-FA62","	: 8B01"},
/* FA63 */ { "CJK COMPATIBILITY IDEOGRAPH-FA63","	: 8B39"},
/* FA64 */ { "CJK COMPATIBILITY IDEOGRAPH-FA64","	: 8CD3"},
/* FA65 */ { "CJK COMPATIBILITY IDEOGRAPH-FA65","	: 8D08"},
/* FA66 */ { "CJK COMPATIBILITY IDEOGRAPH-FA66","	: 8FB6"},
/* FA67 */ { "CJK COMPATIBILITY IDEOGRAPH-FA67","	: 9038"},
/* FA68 */ { "CJK COMPATIBILITY IDEOGRAPH-FA68","	: 96E3"},
/* FA69 */ { "CJK COMPATIBILITY IDEOGRAPH-FA69","	: 97FF"},
/* FA6A */ { "CJK COMPATIBILITY IDEOGRAPH-FA6A","	: 983B"},
/* FA6B */ { "CJK COMPATIBILITY IDEOGRAPH-FA6B","	: 6075"},
/* FA6C */ { "CJK COMPATIBILITY IDEOGRAPH-FA6C","	: 242EE"},
/* FA6D */ { "CJK COMPATIBILITY IDEOGRAPH-FA6D","	: 8218"},
/* FA6E */ { NULL,NULL},
/* FA6F */ { NULL,NULL},
/* FA70 */ { "CJK COMPATIBILITY IDEOGRAPH-FA70","	: 4E26"},
/* FA71 */ { "CJK COMPATIBILITY IDEOGRAPH-FA71","	: 51B5"},
/* FA72 */ { "CJK COMPATIBILITY IDEOGRAPH-FA72","	: 5168"},
/* FA73 */ { "CJK COMPATIBILITY IDEOGRAPH-FA73","	: 4F80"},
/* FA74 */ { "CJK COMPATIBILITY IDEOGRAPH-FA74","	: 5145"},
/* FA75 */ { "CJK COMPATIBILITY IDEOGRAPH-FA75","	: 5180"},
/* FA76 */ { "CJK COMPATIBILITY IDEOGRAPH-FA76","	: 52C7"},
/* FA77 */ { "CJK COMPATIBILITY IDEOGRAPH-FA77","	: 52FA"},
/* FA78 */ { "CJK COMPATIBILITY IDEOGRAPH-FA78","	: 559D"},
/* FA79 */ { "CJK COMPATIBILITY IDEOGRAPH-FA79","	: 5555"},
/* FA7A */ { "CJK COMPATIBILITY IDEOGRAPH-FA7A","	: 5599"},
/* FA7B */ { "CJK COMPATIBILITY IDEOGRAPH-FA7B","	: 55E2"},
/* FA7C */ { "CJK COMPATIBILITY IDEOGRAPH-FA7C","	: 585A"},
/* FA7D */ { "CJK COMPATIBILITY IDEOGRAPH-FA7D","	: 58B3"},
/* FA7E */ { "CJK COMPATIBILITY IDEOGRAPH-FA7E","	: 5944"},
/* FA7F */ { "CJK COMPATIBILITY IDEOGRAPH-FA7F","	: 5954"},
/* FA80 */ { "CJK COMPATIBILITY IDEOGRAPH-FA80","	: 5A62"},
/* FA81 */ { "CJK COMPATIBILITY IDEOGRAPH-FA81","	: 5B28"},
/* FA82 */ { "CJK COMPATIBILITY IDEOGRAPH-FA82","	: 5ED2"},
/* FA83 */ { "CJK COMPATIBILITY IDEOGRAPH-FA83","	: 5ED9"},
/* FA84 */ { "CJK COMPATIBILITY IDEOGRAPH-FA84","	: 5F69"},
/* FA85 */ { "CJK COMPATIBILITY IDEOGRAPH-FA85","	: 5FAD"},
/* FA86 */ { "CJK COMPATIBILITY IDEOGRAPH-FA86","	: 60D8"},
/* FA87 */ { "CJK COMPATIBILITY IDEOGRAPH-FA87","	: 614E"},
/* FA88 */ { "CJK COMPATIBILITY IDEOGRAPH-FA88","	: 6108"},
/* FA89 */ { "CJK COMPATIBILITY IDEOGRAPH-FA89","	: 618E"},
/* FA8A */ { "CJK COMPATIBILITY IDEOGRAPH-FA8A","	: 6160"},
/* FA8B */ { "CJK COMPATIBILITY IDEOGRAPH-FA8B","	: 61F2"},
/* FA8C */ { "CJK COMPATIBILITY IDEOGRAPH-FA8C","	: 6234"},
/* FA8D */ { "CJK COMPATIBILITY IDEOGRAPH-FA8D","	: 63C4"},
/* FA8E */ { "CJK COMPATIBILITY IDEOGRAPH-FA8E","	: 641C"},
/* FA8F */ { "CJK COMPATIBILITY IDEOGRAPH-FA8F","	: 6452"},
/* FA90 */ { "CJK COMPATIBILITY IDEOGRAPH-FA90","	: 6556"},
/* FA91 */ { "CJK COMPATIBILITY IDEOGRAPH-FA91","	: 6674"},
/* FA92 */ { "CJK COMPATIBILITY IDEOGRAPH-FA92","	: 6717"},
/* FA93 */ { "CJK COMPATIBILITY IDEOGRAPH-FA93","	: 671B"},
/* FA94 */ { "CJK COMPATIBILITY IDEOGRAPH-FA94","	: 6756"},
/* FA95 */ { "CJK COMPATIBILITY IDEOGRAPH-FA95","	: 6B79"},
/* FA96 */ { "CJK COMPATIBILITY IDEOGRAPH-FA96","	: 6BBA"},
/* FA97 */ { "CJK COMPATIBILITY IDEOGRAPH-FA97","	: 6D41"},
/* FA98 */ { "CJK COMPATIBILITY IDEOGRAPH-FA98","	: 6EDB"},
/* FA99 */ { "CJK COMPATIBILITY IDEOGRAPH-FA99","	: 6ECB"},
/* FA9A */ { "CJK COMPATIBILITY IDEOGRAPH-FA9A","	: 6F22"},
/* FA9B */ { "CJK COMPATIBILITY IDEOGRAPH-FA9B","	: 701E"},
/* FA9C */ { "CJK COMPATIBILITY IDEOGRAPH-FA9C","	: 716E"},
/* FA9D */ { "CJK COMPATIBILITY IDEOGRAPH-FA9D","	: 77A7"},
/* FA9E */ { "CJK COMPATIBILITY IDEOGRAPH-FA9E","	: 7235"},
/* FA9F */ { "CJK COMPATIBILITY IDEOGRAPH-FA9F","	: 72AF"},
/* FAA0 */ { "CJK COMPATIBILITY IDEOGRAPH-FAA0","	: 732A"},
/* FAA1 */ { "CJK COMPATIBILITY IDEOGRAPH-FAA1","	: 7471"},
/* FAA2 */ { "CJK COMPATIBILITY IDEOGRAPH-FAA2","	: 7506"},
/* FAA3 */ { "CJK COMPATIBILITY IDEOGRAPH-FAA3","	: 753B"},
/* FAA4 */ { "CJK COMPATIBILITY IDEOGRAPH-FAA4","	: 761D"},
/* FAA5 */ { "CJK COMPATIBILITY IDEOGRAPH-FAA5","	: 761F"},
/* FAA6 */ { "CJK COMPATIBILITY IDEOGRAPH-FAA6","	: 76CA"},
/* FAA7 */ { "CJK COMPATIBILITY IDEOGRAPH-FAA7","	: 76DB"},
/* FAA8 */ { "CJK COMPATIBILITY IDEOGRAPH-FAA8","	: 76F4"},
/* FAA9 */ { "CJK COMPATIBILITY IDEOGRAPH-FAA9","	: 774A"},
/* FAAA */ { "CJK COMPATIBILITY IDEOGRAPH-FAAA","	: 7740"},
/* FAAB */ { "CJK COMPATIBILITY IDEOGRAPH-FAAB","	: 78CC"},
/* FAAC */ { "CJK COMPATIBILITY IDEOGRAPH-FAAC","	: 7AB1"},
/* FAAD */ { "CJK COMPATIBILITY IDEOGRAPH-FAAD","	: 7BC0"},
/* FAAE */ { "CJK COMPATIBILITY IDEOGRAPH-FAAE","	: 7C7B"},
/* FAAF */ { "CJK COMPATIBILITY IDEOGRAPH-FAAF","	: 7D5B"},
/* FAB0 */ { "CJK COMPATIBILITY IDEOGRAPH-FAB0","	: 7DF4"},
/* FAB1 */ { "CJK COMPATIBILITY IDEOGRAPH-FAB1","	: 7F3E"},
/* FAB2 */ { "CJK COMPATIBILITY IDEOGRAPH-FAB2","	: 8005"},
/* FAB3 */ { "CJK COMPATIBILITY IDEOGRAPH-FAB3","	: 8352"},
/* FAB4 */ { "CJK COMPATIBILITY IDEOGRAPH-FAB4","	: 83EF"},
/* FAB5 */ { "CJK COMPATIBILITY IDEOGRAPH-FAB5","	: 8779"},
/* FAB6 */ { "CJK COMPATIBILITY IDEOGRAPH-FAB6","	: 8941"},
/* FAB7 */ { "CJK COMPATIBILITY IDEOGRAPH-FAB7","	: 8986"},
/* FAB8 */ { "CJK COMPATIBILITY IDEOGRAPH-FAB8","	: 8996"},
/* FAB9 */ { "CJK COMPATIBILITY IDEOGRAPH-FAB9","	: 8ABF"},
/* FABA */ { "CJK COMPATIBILITY IDEOGRAPH-FABA","	: 8AF8"},
/* FABB */ { "CJK COMPATIBILITY IDEOGRAPH-FABB","	: 8ACB"},
/* FABC */ { "CJK COMPATIBILITY IDEOGRAPH-FABC","	: 8B01"},
/* FABD */ { "CJK COMPATIBILITY IDEOGRAPH-FABD","	: 8AFE"},
/* FABE */ { "CJK COMPATIBILITY IDEOGRAPH-FABE","	: 8AED"},
/* FABF */ { "CJK COMPATIBILITY IDEOGRAPH-FABF","	: 8B39"},
/* FAC0 */ { "CJK COMPATIBILITY IDEOGRAPH-FAC0","	: 8B8A"},
/* FAC1 */ { "CJK COMPATIBILITY IDEOGRAPH-FAC1","	: 8D08"},
/* FAC2 */ { "CJK COMPATIBILITY IDEOGRAPH-FAC2","	: 8F38"},
/* FAC3 */ { "CJK COMPATIBILITY IDEOGRAPH-FAC3","	: 9072"},
/* FAC4 */ { "CJK COMPATIBILITY IDEOGRAPH-FAC4","	: 9199"},
/* FAC5 */ { "CJK COMPATIBILITY IDEOGRAPH-FAC5","	: 9276"},
/* FAC6 */ { "CJK COMPATIBILITY IDEOGRAPH-FAC6","	: 967C"},
/* FAC7 */ { "CJK COMPATIBILITY IDEOGRAPH-FAC7","	: 96E3"},
/* FAC8 */ { "CJK COMPATIBILITY IDEOGRAPH-FAC8","	: 9756"},
/* FAC9 */ { "CJK COMPATIBILITY IDEOGRAPH-FAC9","	: 97DB"},
/* FACA */ { "CJK COMPATIBILITY IDEOGRAPH-FACA","	: 97FF"},
/* FACB */ { "CJK COMPATIBILITY IDEOGRAPH-FACB","	: 980B"},
/* FACC */ { "CJK COMPATIBILITY IDEOGRAPH-FACC","	: 983B"},
/* FACD */ { "CJK COMPATIBILITY IDEOGRAPH-FACD","	: 9B12"},
/* FACE */ { "CJK COMPATIBILITY IDEOGRAPH-FACE","	: 9F9C"},
/* FACF */ { "CJK COMPATIBILITY IDEOGRAPH-FACF","	: 2284A"},
/* FAD0 */ { "CJK COMPATIBILITY IDEOGRAPH-FAD0","	: 22844"},
/* FAD1 */ { "CJK COMPATIBILITY IDEOGRAPH-FAD1","	: 233D5"},
/* FAD2 */ { "CJK COMPATIBILITY IDEOGRAPH-FAD2","	: 3B9D"},
/* FAD3 */ { "CJK COMPATIBILITY IDEOGRAPH-FAD3","	: 4018"},
/* FAD4 */ { "CJK COMPATIBILITY IDEOGRAPH-FAD4","	* mapping change removed original source\n"
	"	x (cjk compatibility ideograph-2F949 - 2F949)\n"
	"	: 4039"},
/* FAD5 */ { "CJK COMPATIBILITY IDEOGRAPH-FAD5","	: 25249"},
/* FAD6 */ { "CJK COMPATIBILITY IDEOGRAPH-FAD6","	: 25CD0"},
/* FAD7 */ { "CJK COMPATIBILITY IDEOGRAPH-FAD7","	: 27ED3"},
/* FAD8 */ { "CJK COMPATIBILITY IDEOGRAPH-FAD8","	: 9F43"},
/* FAD9 */ { "CJK COMPATIBILITY IDEOGRAPH-FAD9","	: 9F8E"},
/* FADA */ { NULL,NULL},
/* FADB */ { NULL,NULL},
/* FADC */ { NULL,NULL},
/* FADD */ { NULL,NULL},
/* FADE */ { NULL,NULL},
/* FADF */ { NULL,NULL},
/* FAE0 */ { NULL,NULL},
/* FAE1 */ { NULL,NULL},
/* FAE2 */ { NULL,NULL},
/* FAE3 */ { NULL,NULL},
/* FAE4 */ { NULL,NULL},
/* FAE5 */ { NULL,NULL},
/* FAE6 */ { NULL,NULL},
/* FAE7 */ { NULL,NULL},
/* FAE8 */ { NULL,NULL},
/* FAE9 */ { NULL,NULL},
/* FAEA */ { NULL,NULL},
/* FAEB */ { NULL,NULL},
/* FAEC */ { NULL,NULL},
/* FAED */ { NULL,NULL},
/* FAEE */ { NULL,NULL},
/* FAEF */ { NULL,NULL},
/* FAF0 */ { NULL,NULL},
/* FAF1 */ { NULL,NULL},
/* FAF2 */ { NULL,NULL},
/* FAF3 */ { NULL,NULL},
/* FAF4 */ { NULL,NULL},
/* FAF5 */ { NULL,NULL},
/* FAF6 */ { NULL,NULL},
/* FAF7 */ { NULL,NULL},
/* FAF8 */ { NULL,NULL},
/* FAF9 */ { NULL,NULL},
/* FAFA */ { NULL,NULL},
/* FAFB */ { NULL,NULL},
/* FAFC */ { NULL,NULL},
/* FAFD */ { NULL,NULL},
/* FAFE */ { NULL,NULL},
/* FAFF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_00_FB[] = {
/* FB00 */ { "LATIN SMALL LIGATURE FF","	# 0066 0066"},
/* FB01 */ { "LATIN SMALL LIGATURE FI","	# 0066 0069"},
/* FB02 */ { "LATIN SMALL LIGATURE FL","	# 0066 006C"},
/* FB03 */ { "LATIN SMALL LIGATURE FFI","	# 0066 0066 0069"},
/* FB04 */ { "LATIN SMALL LIGATURE FFL","	# 0066 0066 006C"},
/* FB05 */ { "LATIN SMALL LIGATURE LONG S T","	# 017F 0074"},
/* FB06 */ { "LATIN SMALL LIGATURE ST","	# 0073 0074"},
/* FB07 */ { NULL,NULL},
/* FB08 */ { NULL,NULL},
/* FB09 */ { NULL,NULL},
/* FB0A */ { NULL,NULL},
/* FB0B */ { NULL,NULL},
/* FB0C */ { NULL,NULL},
/* FB0D */ { NULL,NULL},
/* FB0E */ { NULL,NULL},
/* FB0F */ { NULL,NULL},
/* FB10 */ { NULL,NULL},
/* FB11 */ { NULL,NULL},
/* FB12 */ { NULL,NULL},
/* FB13 */ { "ARMENIAN SMALL LIGATURE MEN NOW","	# 0574 0576"},
/* FB14 */ { "ARMENIAN SMALL LIGATURE MEN ECH","	# 0574 0565"},
/* FB15 */ { "ARMENIAN SMALL LIGATURE MEN INI","	# 0574 056B"},
/* FB16 */ { "ARMENIAN SMALL LIGATURE VEW NOW","	# 057E 0576"},
/* FB17 */ { "ARMENIAN SMALL LIGATURE MEN XEH","	# 0574 056D"},
/* FB18 */ { NULL,NULL},
/* FB19 */ { NULL,NULL},
/* FB1A */ { NULL,NULL},
/* FB1B */ { NULL,NULL},
/* FB1C */ { NULL,NULL},
/* FB1D */ { "HEBREW LETTER YOD WITH HIRIQ","	: 05D9 05B4"},
/* FB1E */ { "HEBREW POINT JUDEO-SPANISH VARIKA","	* a glyph variant of 05BF"},
/* FB1F */ { "HEBREW LIGATURE YIDDISH YOD YOD PATAH","	: 05F2 05B7"},
/* FB20 */ { "HEBREW LETTER ALTERNATIVE AYIN","	* this form of AYIN has no descender, for use with marks placed below the letter\n"
	"	# <font> 05E2 hebrew letter ayin"},
/* FB21 */ { "HEBREW LETTER WIDE ALEF","	# <font> 05D0 hebrew letter alef"},
/* FB22 */ { "HEBREW LETTER WIDE DALET","	# <font> 05D3 hebrew letter dalet"},
/* FB23 */ { "HEBREW LETTER WIDE HE","	# <font> 05D4 hebrew letter he"},
/* FB24 */ { "HEBREW LETTER WIDE KAF","	# <font> 05DB hebrew letter kaf"},
/* FB25 */ { "HEBREW LETTER WIDE LAMED","	# <font> 05DC hebrew letter lamed"},
/* FB26 */ { "HEBREW LETTER WIDE FINAL MEM","	# <font> 05DD hebrew letter final mem"},
/* FB27 */ { "HEBREW LETTER WIDE RESH","	# <font> 05E8 hebrew letter resh"},
/* FB28 */ { "HEBREW LETTER WIDE TAV","	# <font> 05EA hebrew letter tav"},
/* FB29 */ { "HEBREW LETTER ALTERNATIVE PLUS SIGN","	# <font> 002B plus sign"},
/* FB2A */ { "HEBREW LETTER SHIN WITH SHIN DOT","	: 05E9 05C1"},
/* FB2B */ { "HEBREW LETTER SHIN WITH SIN DOT","	: 05E9 05C2"},
/* FB2C */ { "HEBREW LETTER SHIN WITH DAGESH AND SHIN DOT","	: FB49 05C1"},
/* FB2D */ { "HEBREW LETTER SHIN WITH DAGESH AND SIN DOT","	: FB49 05C2"},
/* FB2E */ { "HEBREW LETTER ALEF WITH PATAH","	: 05D0 05B7"},
/* FB2F */ { "HEBREW LETTER ALEF WITH QAMATS","	: 05D0 05B8"},
/* FB30 */ { "HEBREW LETTER ALEF WITH MAPIQ","	: 05D0 05BC"},
/* FB31 */ { "HEBREW LETTER BET WITH DAGESH","	: 05D1 05BC"},
/* FB32 */ { "HEBREW LETTER GIMEL WITH DAGESH","	: 05D2 05BC"},
/* FB33 */ { "HEBREW LETTER DALET WITH DAGESH","	: 05D3 05BC"},
/* FB34 */ { "HEBREW LETTER HE WITH MAPIQ","	: 05D4 05BC"},
/* FB35 */ { "HEBREW LETTER VAV WITH DAGESH","	: 05D5 05BC"},
/* FB36 */ { "HEBREW LETTER ZAYIN WITH DAGESH","	: 05D6 05BC"},
/* FB37 */ { NULL,NULL},
/* FB38 */ { "HEBREW LETTER TET WITH DAGESH","	: 05D8 05BC"},
/* FB39 */ { "HEBREW LETTER YOD WITH DAGESH","	: 05D9 05BC"},
/* FB3A */ { "HEBREW LETTER FINAL KAF WITH DAGESH","	: 05DA 05BC"},
/* FB3B */ { "HEBREW LETTER KAF WITH DAGESH","	: 05DB 05BC"},
/* FB3C */ { "HEBREW LETTER LAMED WITH DAGESH","	: 05DC 05BC"},
/* FB3D */ { NULL,NULL},
/* FB3E */ { "HEBREW LETTER MEM WITH DAGESH","	: 05DE 05BC"},
/* FB3F */ { NULL,NULL},
/* FB40 */ { "HEBREW LETTER NUN WITH DAGESH","	: 05E0 05BC"},
/* FB41 */ { "HEBREW LETTER SAMEKH WITH DAGESH","	: 05E1 05BC"},
/* FB42 */ { NULL,NULL},
/* FB43 */ { "HEBREW LETTER FINAL PE WITH DAGESH","	: 05E3 05BC"},
/* FB44 */ { "HEBREW LETTER PE WITH DAGESH","	: 05E4 05BC"},
/* FB45 */ { NULL,NULL},
/* FB46 */ { "HEBREW LETTER TSADI WITH DAGESH","	: 05E6 05BC"},
/* FB47 */ { "HEBREW LETTER QOF WITH DAGESH","	: 05E7 05BC"},
/* FB48 */ { "HEBREW LETTER RESH WITH DAGESH","	: 05E8 05BC"},
/* FB49 */ { "HEBREW LETTER SHIN WITH DAGESH","	: 05E9 05BC"},
/* FB4A */ { "HEBREW LETTER TAV WITH DAGESH","	: 05EA 05BC"},
/* FB4B */ { "HEBREW LETTER VAV WITH HOLAM","	: 05D5 05B9"},
/* FB4C */ { "HEBREW LETTER BET WITH RAFE","	: 05D1 05BF"},
/* FB4D */ { "HEBREW LETTER KAF WITH RAFE","	: 05DB 05BF"},
/* FB4E */ { "HEBREW LETTER PE WITH RAFE","	: 05E4 05BF"},
/* FB4F */ { "HEBREW LIGATURE ALEF LAMED","	# 05D0 05DC"},
/* FB50 */ { "ARABIC LETTER ALEF WASLA ISOLATED FORM","	# <isolated> 0671"},
/* FB51 */ { "ARABIC LETTER ALEF WASLA FINAL FORM","	# <final> 0671"},
/* FB52 */ { "ARABIC LETTER BEEH ISOLATED FORM","	# <isolated> 067B"},
/* FB53 */ { "ARABIC LETTER BEEH FINAL FORM","	# <final> 067B"},
/* FB54 */ { "ARABIC LETTER BEEH INITIAL FORM","	# <initial> 067B"},
/* FB55 */ { "ARABIC LETTER BEEH MEDIAL FORM","	# <medial> 067B"},
/* FB56 */ { "ARABIC LETTER PEH ISOLATED FORM","	# <isolated> 067E"},
/* FB57 */ { "ARABIC LETTER PEH FINAL FORM","	# <final> 067E"},
/* FB58 */ { "ARABIC LETTER PEH INITIAL FORM","	# <initial> 067E"},
/* FB59 */ { "ARABIC LETTER PEH MEDIAL FORM","	# <medial> 067E"},
/* FB5A */ { "ARABIC LETTER BEHEH ISOLATED FORM","	# <isolated> 0680"},
/* FB5B */ { "ARABIC LETTER BEHEH FINAL FORM","	# <final> 0680"},
/* FB5C */ { "ARABIC LETTER BEHEH INITIAL FORM","	# <initial> 0680"},
/* FB5D */ { "ARABIC LETTER BEHEH MEDIAL FORM","	# <medial> 0680"},
/* FB5E */ { "ARABIC LETTER TTEHEH ISOLATED FORM","	# <isolated> 067A"},
/* FB5F */ { "ARABIC LETTER TTEHEH FINAL FORM","	# <final> 067A"},
/* FB60 */ { "ARABIC LETTER TTEHEH INITIAL FORM","	# <initial> 067A"},
/* FB61 */ { "ARABIC LETTER TTEHEH MEDIAL FORM","	# <medial> 067A"},
/* FB62 */ { "ARABIC LETTER TEHEH ISOLATED FORM","	# <isolated> 067F"},
/* FB63 */ { "ARABIC LETTER TEHEH FINAL FORM","	# <final> 067F"},
/* FB64 */ { "ARABIC LETTER TEHEH INITIAL FORM","	# <initial> 067F"},
/* FB65 */ { "ARABIC LETTER TEHEH MEDIAL FORM","	# <medial> 067F"},
/* FB66 */ { "ARABIC LETTER TTEH ISOLATED FORM","	# <isolated> 0679"},
/* FB67 */ { "ARABIC LETTER TTEH FINAL FORM","	# <final> 0679"},
/* FB68 */ { "ARABIC LETTER TTEH INITIAL FORM","	# <initial> 0679"},
/* FB69 */ { "ARABIC LETTER TTEH MEDIAL FORM","	# <medial> 0679"},
/* FB6A */ { "ARABIC LETTER VEH ISOLATED FORM","	# <isolated> 06A4"},
/* FB6B */ { "ARABIC LETTER VEH FINAL FORM","	# <final> 06A4"},
/* FB6C */ { "ARABIC LETTER VEH INITIAL FORM","	# <initial> 06A4"},
/* FB6D */ { "ARABIC LETTER VEH MEDIAL FORM","	# <medial> 06A4"},
/* FB6E */ { "ARABIC LETTER PEHEH ISOLATED FORM","	# <isolated> 06A6"},
/* FB6F */ { "ARABIC LETTER PEHEH FINAL FORM","	# <final> 06A6"},
/* FB70 */ { "ARABIC LETTER PEHEH INITIAL FORM","	# <initial> 06A6"},
/* FB71 */ { "ARABIC LETTER PEHEH MEDIAL FORM","	# <medial> 06A6"},
/* FB72 */ { "ARABIC LETTER DYEH ISOLATED FORM","	# <isolated> 0684"},
/* FB73 */ { "ARABIC LETTER DYEH FINAL FORM","	# <final> 0684"},
/* FB74 */ { "ARABIC LETTER DYEH INITIAL FORM","	# <initial> 0684"},
/* FB75 */ { "ARABIC LETTER DYEH MEDIAL FORM","	# <medial> 0684"},
/* FB76 */ { "ARABIC LETTER NYEH ISOLATED FORM","	# <isolated> 0683"},
/* FB77 */ { "ARABIC LETTER NYEH FINAL FORM","	# <final> 0683"},
/* FB78 */ { "ARABIC LETTER NYEH INITIAL FORM","	# <initial> 0683"},
/* FB79 */ { "ARABIC LETTER NYEH MEDIAL FORM","	# <medial> 0683"},
/* FB7A */ { "ARABIC LETTER TCHEH ISOLATED FORM","	# <isolated> 0686"},
/* FB7B */ { "ARABIC LETTER TCHEH FINAL FORM","	# <final> 0686"},
/* FB7C */ { "ARABIC LETTER TCHEH INITIAL FORM","	# <initial> 0686"},
/* FB7D */ { "ARABIC LETTER TCHEH MEDIAL FORM","	# <medial> 0686"},
/* FB7E */ { "ARABIC LETTER TCHEHEH ISOLATED FORM","	# <isolated> 0687"},
/* FB7F */ { "ARABIC LETTER TCHEHEH FINAL FORM","	# <final> 0687"},
/* FB80 */ { "ARABIC LETTER TCHEHEH INITIAL FORM","	# <initial> 0687"},
/* FB81 */ { "ARABIC LETTER TCHEHEH MEDIAL FORM","	# <medial> 0687"},
/* FB82 */ { "ARABIC LETTER DDAHAL ISOLATED FORM","	# <isolated> 068D"},
/* FB83 */ { "ARABIC LETTER DDAHAL FINAL FORM","	# <final> 068D"},
/* FB84 */ { "ARABIC LETTER DAHAL ISOLATED FORM","	# <isolated> 068C"},
/* FB85 */ { "ARABIC LETTER DAHAL FINAL FORM","	# <final> 068C"},
/* FB86 */ { "ARABIC LETTER DUL ISOLATED FORM","	# <isolated> 068E"},
/* FB87 */ { "ARABIC LETTER DUL FINAL FORM","	# <final> 068E"},
/* FB88 */ { "ARABIC LETTER DDAL ISOLATED FORM","	# <isolated> 0688"},
/* FB89 */ { "ARABIC LETTER DDAL FINAL FORM","	# <final> 0688"},
/* FB8A */ { "ARABIC LETTER JEH ISOLATED FORM","	# <isolated> 0698"},
/* FB8B */ { "ARABIC LETTER JEH FINAL FORM","	# <final> 0698"},
/* FB8C */ { "ARABIC LETTER RREH ISOLATED FORM","	# <isolated> 0691"},
/* FB8D */ { "ARABIC LETTER RREH FINAL FORM","	# <final> 0691"},
/* FB8E */ { "ARABIC LETTER KEHEH ISOLATED FORM","	# <isolated> 06A9"},
/* FB8F */ { "ARABIC LETTER KEHEH FINAL FORM","	# <final> 06A9"},
/* FB90 */ { "ARABIC LETTER KEHEH INITIAL FORM","	# <initial> 06A9"},
/* FB91 */ { "ARABIC LETTER KEHEH MEDIAL FORM","	# <medial> 06A9"},
/* FB92 */ { "ARABIC LETTER GAF ISOLATED FORM","	# <isolated> 06AF"},
/* FB93 */ { "ARABIC LETTER GAF FINAL FORM","	# <final> 06AF"},
/* FB94 */ { "ARABIC LETTER GAF INITIAL FORM","	# <initial> 06AF"},
/* FB95 */ { "ARABIC LETTER GAF MEDIAL FORM","	# <medial> 06AF"},
/* FB96 */ { "ARABIC LETTER GUEH ISOLATED FORM","	# <isolated> 06B3"},
/* FB97 */ { "ARABIC LETTER GUEH FINAL FORM","	# <final> 06B3"},
/* FB98 */ { "ARABIC LETTER GUEH INITIAL FORM","	# <initial> 06B3"},
/* FB99 */ { "ARABIC LETTER GUEH MEDIAL FORM","	# <medial> 06B3"},
/* FB9A */ { "ARABIC LETTER NGOEH ISOLATED FORM","	# <isolated> 06B1"},
/* FB9B */ { "ARABIC LETTER NGOEH FINAL FORM","	# <final> 06B1"},
/* FB9C */ { "ARABIC LETTER NGOEH INITIAL FORM","	# <initial> 06B1"},
/* FB9D */ { "ARABIC LETTER NGOEH MEDIAL FORM","	# <medial> 06B1"},
/* FB9E */ { "ARABIC LETTER NOON GHUNNA ISOLATED FORM","	# <isolated> 06BA"},
/* FB9F */ { "ARABIC LETTER NOON GHUNNA FINAL FORM","	# <final> 06BA"},
/* FBA0 */ { "ARABIC LETTER RNOON ISOLATED FORM","	# <isolated> 06BB"},
/* FBA1 */ { "ARABIC LETTER RNOON FINAL FORM","	# <final> 06BB"},
/* FBA2 */ { "ARABIC LETTER RNOON INITIAL FORM","	# <initial> 06BB"},
/* FBA3 */ { "ARABIC LETTER RNOON MEDIAL FORM","	# <medial> 06BB"},
/* FBA4 */ { "ARABIC LETTER HEH WITH YEH ABOVE ISOLATED FORM","	# <isolated> 06C0"},
/* FBA5 */ { "ARABIC LETTER HEH WITH YEH ABOVE FINAL FORM","	# <final> 06C0"},
/* FBA6 */ { "ARABIC LETTER HEH GOAL ISOLATED FORM","	# <isolated> 06C1"},
/* FBA7 */ { "ARABIC LETTER HEH GOAL FINAL FORM","	# <final> 06C1"},
/* FBA8 */ { "ARABIC LETTER HEH GOAL INITIAL FORM","	# <initial> 06C1"},
/* FBA9 */ { "ARABIC LETTER HEH GOAL MEDIAL FORM","	# <medial> 06C1"},
/* FBAA */ { "ARABIC LETTER HEH DOACHASHMEE ISOLATED FORM","	# <isolated> 06BE"},
/* FBAB */ { "ARABIC LETTER HEH DOACHASHMEE FINAL FORM","	# <final> 06BE"},
/* FBAC */ { "ARABIC LETTER HEH DOACHASHMEE INITIAL FORM","	# <initial> 06BE"},
/* FBAD */ { "ARABIC LETTER HEH DOACHASHMEE MEDIAL FORM","	# <medial> 06BE"},
/* FBAE */ { "ARABIC LETTER YEH BARREE ISOLATED FORM","	# <isolated> 06D2"},
/* FBAF */ { "ARABIC LETTER YEH BARREE FINAL FORM","	# <final> 06D2"},
/* FBB0 */ { "ARABIC LETTER YEH BARREE WITH HAMZA ABOVE ISOLATED FORM","	# <isolated> 06D3"},
/* FBB1 */ { "ARABIC LETTER YEH BARREE WITH HAMZA ABOVE FINAL FORM","	# <final> 06D3"},
/* FBB2 */ { "ARABIC SYMBOL DOT ABOVE",NULL},
/* FBB3 */ { "ARABIC SYMBOL DOT BELOW",NULL},
/* FBB4 */ { "ARABIC SYMBOL TWO DOTS ABOVE",NULL},
/* FBB5 */ { "ARABIC SYMBOL TWO DOTS BELOW",NULL},
/* FBB6 */ { "ARABIC SYMBOL THREE DOTS ABOVE",NULL},
/* FBB7 */ { "ARABIC SYMBOL THREE DOTS BELOW",NULL},
/* FBB8 */ { "ARABIC SYMBOL THREE DOTS POINTING DOWNWARDS ABOVE",NULL},
/* FBB9 */ { "ARABIC SYMBOL THREE DOTS POINTING DOWNWARDS BELOW",NULL},
/* FBBA */ { "ARABIC SYMBOL FOUR DOTS ABOVE","	* Sindhi"},
/* FBBB */ { "ARABIC SYMBOL FOUR DOTS BELOW","	* Sindhi"},
/* FBBC */ { "ARABIC SYMBOL DOUBLE VERTICAL BAR BELOW","	* Sindhi"},
/* FBBD */ { "ARABIC SYMBOL TWO DOTS VERTICALLY ABOVE","	* Sindhi"},
/* FBBE */ { "ARABIC SYMBOL TWO DOTS VERTICALLY BELOW","	* Sindhi"},
/* FBBF */ { "ARABIC SYMBOL RING","	* Pashto"},
/* FBC0 */ { "ARABIC SYMBOL SMALL TAH ABOVE","	* Urdu"},
/* FBC1 */ { "ARABIC SYMBOL SMALL TAH BELOW","	* Urdu"},
/* FBC2 */ { "ARABIC SYMBOL WASLA ABOVE","	x (arabic letter alef wasla - 0671)"},
/* FBC3 */ { "ARABIC LIGATURE JALLA WA-ALAA",NULL},
/* FBC4 */ { "ARABIC LIGATURE DAAMAT BARAKAATUHUM",NULL},
/* FBC5 */ { "ARABIC LIGATURE RAHMATU ALLAAHI TAAALAA ALAYH",NULL},
/* FBC6 */ { "ARABIC LIGATURE RAHMATU ALLAAHI ALAYHIM",NULL},
/* FBC7 */ { "ARABIC LIGATURE RAHMATU ALLAAHI ALAYHIMAA",NULL},
/* FBC8 */ { "ARABIC LIGATURE RAHIMAHUM ALLAAHU TAAALAA",NULL},
/* FBC9 */ { "ARABIC LIGATURE RAHIMAHUMAA ALLAAH",NULL},
/* FBCA */ { "ARABIC LIGATURE RAHIMAHUMAA ALLAAHU TAAALAA",NULL},
/* FBCB */ { "ARABIC LIGATURE RADI ALLAAHU TAAALAA ANHUM",NULL},
/* FBCC */ { "ARABIC LIGATURE HAFIZAHU ALLAAH",NULL},
/* FBCD */ { "ARABIC LIGATURE HAFIZAHU ALLAAHU TAAALAA",NULL},
/* FBCE */ { "ARABIC LIGATURE HAFIZAHUM ALLAAHU TAAALAA",NULL},
/* FBCF */ { "ARABIC LIGATURE HAFIZAHUMAA ALLAAHU TAAALAA",NULL},
/* FBD0 */ { "ARABIC LIGATURE SALLALLAAHU TAAALAA ALAYHI WA-SALLAM",NULL},
/* FBD1 */ { "ARABIC LIGATURE AJJAL ALLAAHU FARAJAHU ASH-SHAREEF",NULL},
/* FBD2 */ { "ARABIC LIGATURE ALAYHI AR-RAHMAH",NULL},
/* FBD3 */ { "ARABIC LETTER NG ISOLATED FORM","	# <isolated> 06AD"},
/* FBD4 */ { "ARABIC LETTER NG FINAL FORM","	# <final> 06AD"},
/* FBD5 */ { "ARABIC LETTER NG INITIAL FORM","	# <initial> 06AD"},
/* FBD6 */ { "ARABIC LETTER NG MEDIAL FORM","	# <medial> 06AD"},
/* FBD7 */ { "ARABIC LETTER U ISOLATED FORM","	# <isolated> 06C7"},
/* FBD8 */ { "ARABIC LETTER U FINAL FORM","	# <final> 06C7"},
/* FBD9 */ { "ARABIC LETTER OE ISOLATED FORM","	# <isolated> 06C6"},
/* FBDA */ { "ARABIC LETTER OE FINAL FORM","	# <final> 06C6"},
/* FBDB */ { "ARABIC LETTER YU ISOLATED FORM","	# <isolated> 06C8"},
/* FBDC */ { "ARABIC LETTER YU FINAL FORM","	# <final> 06C8"},
/* FBDD */ { "ARABIC LETTER U WITH HAMZA ABOVE ISOLATED FORM","	# <isolated> 0677"},
/* FBDE */ { "ARABIC LETTER VE ISOLATED FORM","	# <isolated> 06CB"},
/* FBDF */ { "ARABIC LETTER VE FINAL FORM","	# <final> 06CB"},
/* FBE0 */ { "ARABIC LETTER KIRGHIZ OE ISOLATED FORM","	# <isolated> 06C5"},
/* FBE1 */ { "ARABIC LETTER KIRGHIZ OE FINAL FORM","	# <final> 06C5"},
/* FBE2 */ { "ARABIC LETTER KIRGHIZ YU ISOLATED FORM","	# <isolated> 06C9"},
/* FBE3 */ { "ARABIC LETTER KIRGHIZ YU FINAL FORM","	# <final> 06C9"},
/* FBE4 */ { "ARABIC LETTER E ISOLATED FORM","	# <isolated> 06D0"},
/* FBE5 */ { "ARABIC LETTER E FINAL FORM","	# <final> 06D0"},
/* FBE6 */ { "ARABIC LETTER E INITIAL FORM","	# <initial> 06D0"},
/* FBE7 */ { "ARABIC LETTER E MEDIAL FORM","	# <medial> 06D0"},
/* FBE8 */ { "ARABIC LETTER UIGHUR KAZAKH KIRGHIZ ALEF MAKSURA INITIAL FORM","	# <initial> 0649"},
/* FBE9 */ { "ARABIC LETTER UIGHUR KAZAKH KIRGHIZ ALEF MAKSURA MEDIAL FORM","	# <medial> 0649"},
/* FBEA */ { "ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH ALEF ISOLATED FORM","	# <isolated> 0626 0627"},
/* FBEB */ { "ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH ALEF FINAL FORM","	# <final> 0626 0627"},
/* FBEC */ { "ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH AE ISOLATED FORM","	# <isolated> 0626 06D5"},
/* FBED */ { "ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH AE FINAL FORM","	# <final> 0626 06D5"},
/* FBEE */ { "ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH WAW ISOLATED FORM","	# <isolated> 0626 0648"},
/* FBEF */ { "ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH WAW FINAL FORM","	# <final> 0626 0648"},
/* FBF0 */ { "ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH U ISOLATED FORM","	# <isolated> 0626 06C7"},
/* FBF1 */ { "ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH U FINAL FORM","	# <final> 0626 06C7"},
/* FBF2 */ { "ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH OE ISOLATED FORM","	# <isolated> 0626 06C6"},
/* FBF3 */ { "ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH OE FINAL FORM","	# <final> 0626 06C6"},
/* FBF4 */ { "ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH YU ISOLATED FORM","	# <isolated> 0626 06C8"},
/* FBF5 */ { "ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH YU FINAL FORM","	# <final> 0626 06C8"},
/* FBF6 */ { "ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH E ISOLATED FORM","	# <isolated> 0626 06D0"},
/* FBF7 */ { "ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH E FINAL FORM","	# <final> 0626 06D0"},
/* FBF8 */ { "ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH E INITIAL FORM","	# <initial> 0626 06D0"},
/* FBF9 */ { "ARABIC LIGATURE UIGHUR KIRGHIZ YEH WITH HAMZA ABOVE WITH ALEF MAKSURA ISOLATED FORM","	* FC03 has the same compatibility decomposition, but is a distinct presentation variant\n"
	"	x (arabic ligature yeh with hamza above with alef maksura isolated form - FC03)\n"
	"	# <isolated> 0626 0649"},
/* FBFA */ { "ARABIC LIGATURE UIGHUR KIRGHIZ YEH WITH HAMZA ABOVE WITH ALEF MAKSURA FINAL FORM","	* FC68 has the same compatibility decomposition, but is a distinct presentation variant\n"
	"	x (arabic ligature yeh with hamza above with alef maksura final form - FC68)\n"
	"	# <final> 0626 0649"},
/* FBFB */ { "ARABIC LIGATURE UIGHUR KIRGHIZ YEH WITH HAMZA ABOVE WITH ALEF MAKSURA INITIAL FORM","	# <initial> 0626 0649"},
/* FBFC */ { "ARABIC LETTER FARSI YEH ISOLATED FORM","	# <isolated> 06CC"},
/* FBFD */ { "ARABIC LETTER FARSI YEH FINAL FORM","	# <final> 06CC"},
/* FBFE */ { "ARABIC LETTER FARSI YEH INITIAL FORM","	# <initial> 06CC"},
/* FBFF */ { "ARABIC LETTER FARSI YEH MEDIAL FORM","	# <medial> 06CC"}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_00_FC[] = {
/* FC00 */ { "ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH JEEM ISOLATED FORM","	# <isolated> 0626 062C"},
/* FC01 */ { "ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH HAH ISOLATED FORM","	# <isolated> 0626 062D"},
/* FC02 */ { "ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH MEEM ISOLATED FORM","	# <isolated> 0626 0645"},
/* FC03 */ { "ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH ALEF MAKSURA ISOLATED FORM","	* FBF9 has the same compatibility decomposition, but is a distinct presentation variant\n"
	"	x (arabic ligature uighur kirghiz yeh with hamza above with alef maksura isolated form - FBF9)\n"
	"	# <isolated> 0626 0649"},
/* FC04 */ { "ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH YEH ISOLATED FORM","	# <isolated> 0626 064A"},
/* FC05 */ { "ARABIC LIGATURE BEH WITH JEEM ISOLATED FORM","	# <isolated> 0628 062C"},
/* FC06 */ { "ARABIC LIGATURE BEH WITH HAH ISOLATED FORM","	# <isolated> 0628 062D"},
/* FC07 */ { "ARABIC LIGATURE BEH WITH KHAH ISOLATED FORM","	# <isolated> 0628 062E"},
/* FC08 */ { "ARABIC LIGATURE BEH WITH MEEM ISOLATED FORM","	# <isolated> 0628 0645"},
/* FC09 */ { "ARABIC LIGATURE BEH WITH ALEF MAKSURA ISOLATED FORM","	# <isolated> 0628 0649"},
/* FC0A */ { "ARABIC LIGATURE BEH WITH YEH ISOLATED FORM","	# <isolated> 0628 064A"},
/* FC0B */ { "ARABIC LIGATURE TEH WITH JEEM ISOLATED FORM","	# <isolated> 062A 062C"},
/* FC0C */ { "ARABIC LIGATURE TEH WITH HAH ISOLATED FORM","	# <isolated> 062A 062D"},
/* FC0D */ { "ARABIC LIGATURE TEH WITH KHAH ISOLATED FORM","	# <isolated> 062A 062E"},
/* FC0E */ { "ARABIC LIGATURE TEH WITH MEEM ISOLATED FORM","	# <isolated> 062A 0645"},
/* FC0F */ { "ARABIC LIGATURE TEH WITH ALEF MAKSURA ISOLATED FORM","	# <isolated> 062A 0649"},
/* FC10 */ { "ARABIC LIGATURE TEH WITH YEH ISOLATED FORM","	# <isolated> 062A 064A"},
/* FC11 */ { "ARABIC LIGATURE THEH WITH JEEM ISOLATED FORM","	# <isolated> 062B 062C"},
/* FC12 */ { "ARABIC LIGATURE THEH WITH MEEM ISOLATED FORM","	# <isolated> 062B 0645"},
/* FC13 */ { "ARABIC LIGATURE THEH WITH ALEF MAKSURA ISOLATED FORM","	# <isolated> 062B 0649"},
/* FC14 */ { "ARABIC LIGATURE THEH WITH YEH ISOLATED FORM","	# <isolated> 062B 064A"},
/* FC15 */ { "ARABIC LIGATURE JEEM WITH HAH ISOLATED FORM","	# <isolated> 062C 062D"},
/* FC16 */ { "ARABIC LIGATURE JEEM WITH MEEM ISOLATED FORM","	# <isolated> 062C 0645"},
/* FC17 */ { "ARABIC LIGATURE HAH WITH JEEM ISOLATED FORM","	# <isolated> 062D 062C"},
/* FC18 */ { "ARABIC LIGATURE HAH WITH MEEM ISOLATED FORM","	# <isolated> 062D 0645"},
/* FC19 */ { "ARABIC LIGATURE KHAH WITH JEEM ISOLATED FORM","	# <isolated> 062E 062C"},
/* FC1A */ { "ARABIC LIGATURE KHAH WITH HAH ISOLATED FORM","	# <isolated> 062E 062D"},
/* FC1B */ { "ARABIC LIGATURE KHAH WITH MEEM ISOLATED FORM","	# <isolated> 062E 0645"},
/* FC1C */ { "ARABIC LIGATURE SEEN WITH JEEM ISOLATED FORM","	# <isolated> 0633 062C"},
/* FC1D */ { "ARABIC LIGATURE SEEN WITH HAH ISOLATED FORM","	# <isolated> 0633 062D"},
/* FC1E */ { "ARABIC LIGATURE SEEN WITH KHAH ISOLATED FORM","	# <isolated> 0633 062E"},
/* FC1F */ { "ARABIC LIGATURE SEEN WITH MEEM ISOLATED FORM","	# <isolated> 0633 0645"},
/* FC20 */ { "ARABIC LIGATURE SAD WITH HAH ISOLATED FORM","	# <isolated> 0635 062D"},
/* FC21 */ { "ARABIC LIGATURE SAD WITH MEEM ISOLATED FORM","	# <isolated> 0635 0645"},
/* FC22 */ { "ARABIC LIGATURE DAD WITH JEEM ISOLATED FORM","	# <isolated> 0636 062C"},
/* FC23 */ { "ARABIC LIGATURE DAD WITH HAH ISOLATED FORM","	# <isolated> 0636 062D"},
/* FC24 */ { "ARABIC LIGATURE DAD WITH KHAH ISOLATED FORM","	# <isolated> 0636 062E"},
/* FC25 */ { "ARABIC LIGATURE DAD WITH MEEM ISOLATED FORM","	# <isolated> 0636 0645"},
/* FC26 */ { "ARABIC LIGATURE TAH WITH HAH ISOLATED FORM","	# <isolated> 0637 062D"},
/* FC27 */ { "ARABIC LIGATURE TAH WITH MEEM ISOLATED FORM","	# <isolated> 0637 0645"},
/* FC28 */ { "ARABIC LIGATURE ZAH WITH MEEM ISOLATED FORM","	# <isolated> 0638 0645"},
/* FC29 */ { "ARABIC LIGATURE AIN WITH JEEM ISOLATED FORM","	# <isolated> 0639 062C"},
/* FC2A */ { "ARABIC LIGATURE AIN WITH MEEM ISOLATED FORM","	# <isolated> 0639 0645"},
/* FC2B */ { "ARABIC LIGATURE GHAIN WITH JEEM ISOLATED FORM","	# <isolated> 063A 062C"},
/* FC2C */ { "ARABIC LIGATURE GHAIN WITH MEEM ISOLATED FORM","	# <isolated> 063A 0645"},
/* FC2D */ { "ARABIC LIGATURE FEH WITH JEEM ISOLATED FORM","	# <isolated> 0641 062C"},
/* FC2E */ { "ARABIC LIGATURE FEH WITH HAH ISOLATED FORM","	# <isolated> 0641 062D"},
/* FC2F */ { "ARABIC LIGATURE FEH WITH KHAH ISOLATED FORM","	# <isolated> 0641 062E"},
/* FC30 */ { "ARABIC LIGATURE FEH WITH MEEM ISOLATED FORM","	# <isolated> 0641 0645"},
/* FC31 */ { "ARABIC LIGATURE FEH WITH ALEF MAKSURA ISOLATED FORM","	# <isolated> 0641 0649"},
/* FC32 */ { "ARABIC LIGATURE FEH WITH YEH ISOLATED FORM","	# <isolated> 0641 064A"},
/* FC33 */ { "ARABIC LIGATURE QAF WITH HAH ISOLATED FORM","	# <isolated> 0642 062D"},
/* FC34 */ { "ARABIC LIGATURE QAF WITH MEEM ISOLATED FORM","	# <isolated> 0642 0645"},
/* FC35 */ { "ARABIC LIGATURE QAF WITH ALEF MAKSURA ISOLATED FORM","	# <isolated> 0642 0649"},
/* FC36 */ { "ARABIC LIGATURE QAF WITH YEH ISOLATED FORM","	# <isolated> 0642 064A"},
/* FC37 */ { "ARABIC LIGATURE KAF WITH ALEF ISOLATED FORM","	# <isolated> 0643 0627"},
/* FC38 */ { "ARABIC LIGATURE KAF WITH JEEM ISOLATED FORM","	# <isolated> 0643 062C"},
/* FC39 */ { "ARABIC LIGATURE KAF WITH HAH ISOLATED FORM","	# <isolated> 0643 062D"},
/* FC3A */ { "ARABIC LIGATURE KAF WITH KHAH ISOLATED FORM","	# <isolated> 0643 062E"},
/* FC3B */ { "ARABIC LIGATURE KAF WITH LAM ISOLATED FORM","	# <isolated> 0643 0644"},
/* FC3C */ { "ARABIC LIGATURE KAF WITH MEEM ISOLATED FORM","	# <isolated> 0643 0645"},
/* FC3D */ { "ARABIC LIGATURE KAF WITH ALEF MAKSURA ISOLATED FORM","	# <isolated> 0643 0649"},
/* FC3E */ { "ARABIC LIGATURE KAF WITH YEH ISOLATED FORM","	# <isolated> 0643 064A"},
/* FC3F */ { "ARABIC LIGATURE LAM WITH JEEM ISOLATED FORM","	# <isolated> 0644 062C"},
/* FC40 */ { "ARABIC LIGATURE LAM WITH HAH ISOLATED FORM","	# <isolated> 0644 062D"},
/* FC41 */ { "ARABIC LIGATURE LAM WITH KHAH ISOLATED FORM","	# <isolated> 0644 062E"},
/* FC42 */ { "ARABIC LIGATURE LAM WITH MEEM ISOLATED FORM","	# <isolated> 0644 0645"},
/* FC43 */ { "ARABIC LIGATURE LAM WITH ALEF MAKSURA ISOLATED FORM","	# <isolated> 0644 0649"},
/* FC44 */ { "ARABIC LIGATURE LAM WITH YEH ISOLATED FORM","	# <isolated> 0644 064A"},
/* FC45 */ { "ARABIC LIGATURE MEEM WITH JEEM ISOLATED FORM","	# <isolated> 0645 062C"},
/* FC46 */ { "ARABIC LIGATURE MEEM WITH HAH ISOLATED FORM","	# <isolated> 0645 062D"},
/* FC47 */ { "ARABIC LIGATURE MEEM WITH KHAH ISOLATED FORM","	# <isolated> 0645 062E"},
/* FC48 */ { "ARABIC LIGATURE MEEM WITH MEEM ISOLATED FORM","	# <isolated> 0645 0645"},
/* FC49 */ { "ARABIC LIGATURE MEEM WITH ALEF MAKSURA ISOLATED FORM","	# <isolated> 0645 0649"},
/* FC4A */ { "ARABIC LIGATURE MEEM WITH YEH ISOLATED FORM","	# <isolated> 0645 064A"},
/* FC4B */ { "ARABIC LIGATURE NOON WITH JEEM ISOLATED FORM","	# <isolated> 0646 062C"},
/* FC4C */ { "ARABIC LIGATURE NOON WITH HAH ISOLATED FORM","	# <isolated> 0646 062D"},
/* FC4D */ { "ARABIC LIGATURE NOON WITH KHAH ISOLATED FORM","	# <isolated> 0646 062E"},
/* FC4E */ { "ARABIC LIGATURE NOON WITH MEEM ISOLATED FORM","	# <isolated> 0646 0645"},
/* FC4F */ { "ARABIC LIGATURE NOON WITH ALEF MAKSURA ISOLATED FORM","	# <isolated> 0646 0649"},
/* FC50 */ { "ARABIC LIGATURE NOON WITH YEH ISOLATED FORM","	# <isolated> 0646 064A"},
/* FC51 */ { "ARABIC LIGATURE HEH WITH JEEM ISOLATED FORM","	# <isolated> 0647 062C"},
/* FC52 */ { "ARABIC LIGATURE HEH WITH MEEM ISOLATED FORM","	# <isolated> 0647 0645"},
/* FC53 */ { "ARABIC LIGATURE HEH WITH ALEF MAKSURA ISOLATED FORM","	# <isolated> 0647 0649"},
/* FC54 */ { "ARABIC LIGATURE HEH WITH YEH ISOLATED FORM","	# <isolated> 0647 064A"},
/* FC55 */ { "ARABIC LIGATURE YEH WITH JEEM ISOLATED FORM","	# <isolated> 064A 062C"},
/* FC56 */ { "ARABIC LIGATURE YEH WITH HAH ISOLATED FORM","	# <isolated> 064A 062D"},
/* FC57 */ { "ARABIC LIGATURE YEH WITH KHAH ISOLATED FORM","	# <isolated> 064A 062E"},
/* FC58 */ { "ARABIC LIGATURE YEH WITH MEEM ISOLATED FORM","	# <isolated> 064A 0645"},
/* FC59 */ { "ARABIC LIGATURE YEH WITH ALEF MAKSURA ISOLATED FORM","	# <isolated> 064A 0649"},
/* FC5A */ { "ARABIC LIGATURE YEH WITH YEH ISOLATED FORM","	# <isolated> 064A 064A"},
/* FC5B */ { "ARABIC LIGATURE THAL WITH SUPERSCRIPT ALEF ISOLATED FORM","	# <isolated> 0630 0670"},
/* FC5C */ { "ARABIC LIGATURE REH WITH SUPERSCRIPT ALEF ISOLATED FORM","	# <isolated> 0631 0670"},
/* FC5D */ { "ARABIC LIGATURE ALEF MAKSURA WITH SUPERSCRIPT ALEF ISOLATED FORM","	# <isolated> 0649 0670"},
/* FC5E */ { "ARABIC LIGATURE SHADDA WITH DAMMATAN ISOLATED FORM","	# <isolated> 0020 064C 0651"},
/* FC5F */ { "ARABIC LIGATURE SHADDA WITH KASRATAN ISOLATED FORM","	# <isolated> 0020 064D 0651"},
/* FC60 */ { "ARABIC LIGATURE SHADDA WITH FATHA ISOLATED FORM","	# <isolated> 0020 064E 0651"},
/* FC61 */ { "ARABIC LIGATURE SHADDA WITH DAMMA ISOLATED FORM","	# <isolated> 0020 064F 0651"},
/* FC62 */ { "ARABIC LIGATURE SHADDA WITH KASRA ISOLATED FORM","	# <isolated> 0020 0650 0651"},
/* FC63 */ { "ARABIC LIGATURE SHADDA WITH SUPERSCRIPT ALEF ISOLATED FORM","	# <isolated> 0020 0651 0670"},
/* FC64 */ { "ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH REH FINAL FORM","	# <final> 0626 0631"},
/* FC65 */ { "ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH ZAIN FINAL FORM","	# <final> 0626 0632"},
/* FC66 */ { "ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH MEEM FINAL FORM","	# <final> 0626 0645"},
/* FC67 */ { "ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH NOON FINAL FORM","	# <final> 0626 0646"},
/* FC68 */ { "ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH ALEF MAKSURA FINAL FORM","	* FBFA has the same compatibility decomposition, but is a distinct presentation variant\n"
	"	x (arabic ligature uighur kirghiz yeh with hamza above with alef maksura final form - FBFA)\n"
	"	# <final> 0626 0649"},
/* FC69 */ { "ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH YEH FINAL FORM","	# <final> 0626 064A"},
/* FC6A */ { "ARABIC LIGATURE BEH WITH REH FINAL FORM","	# <final> 0628 0631"},
/* FC6B */ { "ARABIC LIGATURE BEH WITH ZAIN FINAL FORM","	# <final> 0628 0632"},
/* FC6C */ { "ARABIC LIGATURE BEH WITH MEEM FINAL FORM","	# <final> 0628 0645"},
/* FC6D */ { "ARABIC LIGATURE BEH WITH NOON FINAL FORM","	# <final> 0628 0646"},
/* FC6E */ { "ARABIC LIGATURE BEH WITH ALEF MAKSURA FINAL FORM","	# <final> 0628 0649"},
/* FC6F */ { "ARABIC LIGATURE BEH WITH YEH FINAL FORM","	# <final> 0628 064A"},
/* FC70 */ { "ARABIC LIGATURE TEH WITH REH FINAL FORM","	# <final> 062A 0631"},
/* FC71 */ { "ARABIC LIGATURE TEH WITH ZAIN FINAL FORM","	# <final> 062A 0632"},
/* FC72 */ { "ARABIC LIGATURE TEH WITH MEEM FINAL FORM","	# <final> 062A 0645"},
/* FC73 */ { "ARABIC LIGATURE TEH WITH NOON FINAL FORM","	# <final> 062A 0646"},
/* FC74 */ { "ARABIC LIGATURE TEH WITH ALEF MAKSURA FINAL FORM","	# <final> 062A 0649"},
/* FC75 */ { "ARABIC LIGATURE TEH WITH YEH FINAL FORM","	# <final> 062A 064A"},
/* FC76 */ { "ARABIC LIGATURE THEH WITH REH FINAL FORM","	# <final> 062B 0631"},
/* FC77 */ { "ARABIC LIGATURE THEH WITH ZAIN FINAL FORM","	# <final> 062B 0632"},
/* FC78 */ { "ARABIC LIGATURE THEH WITH MEEM FINAL FORM","	# <final> 062B 0645"},
/* FC79 */ { "ARABIC LIGATURE THEH WITH NOON FINAL FORM","	# <final> 062B 0646"},
/* FC7A */ { "ARABIC LIGATURE THEH WITH ALEF MAKSURA FINAL FORM","	# <final> 062B 0649"},
/* FC7B */ { "ARABIC LIGATURE THEH WITH YEH FINAL FORM","	# <final> 062B 064A"},
/* FC7C */ { "ARABIC LIGATURE FEH WITH ALEF MAKSURA FINAL FORM","	# <final> 0641 0649"},
/* FC7D */ { "ARABIC LIGATURE FEH WITH YEH FINAL FORM","	# <final> 0641 064A"},
/* FC7E */ { "ARABIC LIGATURE QAF WITH ALEF MAKSURA FINAL FORM","	# <final> 0642 0649"},
/* FC7F */ { "ARABIC LIGATURE QAF WITH YEH FINAL FORM","	# <final> 0642 064A"},
/* FC80 */ { "ARABIC LIGATURE KAF WITH ALEF FINAL FORM","	# <final> 0643 0627"},
/* FC81 */ { "ARABIC LIGATURE KAF WITH LAM FINAL FORM","	# <final> 0643 0644"},
/* FC82 */ { "ARABIC LIGATURE KAF WITH MEEM FINAL FORM","	# <final> 0643 0645"},
/* FC83 */ { "ARABIC LIGATURE KAF WITH ALEF MAKSURA FINAL FORM","	# <final> 0643 0649"},
/* FC84 */ { "ARABIC LIGATURE KAF WITH YEH FINAL FORM","	# <final> 0643 064A"},
/* FC85 */ { "ARABIC LIGATURE LAM WITH MEEM FINAL FORM","	# <final> 0644 0645"},
/* FC86 */ { "ARABIC LIGATURE LAM WITH ALEF MAKSURA FINAL FORM","	# <final> 0644 0649"},
/* FC87 */ { "ARABIC LIGATURE LAM WITH YEH FINAL FORM","	# <final> 0644 064A"},
/* FC88 */ { "ARABIC LIGATURE MEEM WITH ALEF FINAL FORM","	# <final> 0645 0627"},
/* FC89 */ { "ARABIC LIGATURE MEEM WITH MEEM FINAL FORM","	# <final> 0645 0645"},
/* FC8A */ { "ARABIC LIGATURE NOON WITH REH FINAL FORM","	# <final> 0646 0631"},
/* FC8B */ { "ARABIC LIGATURE NOON WITH ZAIN FINAL FORM","	# <final> 0646 0632"},
/* FC8C */ { "ARABIC LIGATURE NOON WITH MEEM FINAL FORM","	# <final> 0646 0645"},
/* FC8D */ { "ARABIC LIGATURE NOON WITH NOON FINAL FORM","	# <final> 0646 0646"},
/* FC8E */ { "ARABIC LIGATURE NOON WITH ALEF MAKSURA FINAL FORM","	# <final> 0646 0649"},
/* FC8F */ { "ARABIC LIGATURE NOON WITH YEH FINAL FORM","	# <final> 0646 064A"},
/* FC90 */ { "ARABIC LIGATURE ALEF MAKSURA WITH SUPERSCRIPT ALEF FINAL FORM","	# <final> 0649 0670"},
/* FC91 */ { "ARABIC LIGATURE YEH WITH REH FINAL FORM","	# <final> 064A 0631"},
/* FC92 */ { "ARABIC LIGATURE YEH WITH ZAIN FINAL FORM","	# <final> 064A 0632"},
/* FC93 */ { "ARABIC LIGATURE YEH WITH MEEM FINAL FORM","	# <final> 064A 0645"},
/* FC94 */ { "ARABIC LIGATURE YEH WITH NOON FINAL FORM","	# <final> 064A 0646"},
/* FC95 */ { "ARABIC LIGATURE YEH WITH ALEF MAKSURA FINAL FORM","	# <final> 064A 0649"},
/* FC96 */ { "ARABIC LIGATURE YEH WITH YEH FINAL FORM","	# <final> 064A 064A"},
/* FC97 */ { "ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH JEEM INITIAL FORM","	# <initial> 0626 062C"},
/* FC98 */ { "ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH HAH INITIAL FORM","	# <initial> 0626 062D"},
/* FC99 */ { "ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH KHAH INITIAL FORM","	# <initial> 0626 062E"},
/* FC9A */ { "ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH MEEM INITIAL FORM","	# <initial> 0626 0645"},
/* FC9B */ { "ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH HEH INITIAL FORM","	# <initial> 0626 0647"},
/* FC9C */ { "ARABIC LIGATURE BEH WITH JEEM INITIAL FORM","	# <initial> 0628 062C"},
/* FC9D */ { "ARABIC LIGATURE BEH WITH HAH INITIAL FORM","	# <initial> 0628 062D"},
/* FC9E */ { "ARABIC LIGATURE BEH WITH KHAH INITIAL FORM","	# <initial> 0628 062E"},
/* FC9F */ { "ARABIC LIGATURE BEH WITH MEEM INITIAL FORM","	# <initial> 0628 0645"},
/* FCA0 */ { "ARABIC LIGATURE BEH WITH HEH INITIAL FORM","	# <initial> 0628 0647"},
/* FCA1 */ { "ARABIC LIGATURE TEH WITH JEEM INITIAL FORM","	# <initial> 062A 062C"},
/* FCA2 */ { "ARABIC LIGATURE TEH WITH HAH INITIAL FORM","	# <initial> 062A 062D"},
/* FCA3 */ { "ARABIC LIGATURE TEH WITH KHAH INITIAL FORM","	# <initial> 062A 062E"},
/* FCA4 */ { "ARABIC LIGATURE TEH WITH MEEM INITIAL FORM","	# <initial> 062A 0645"},
/* FCA5 */ { "ARABIC LIGATURE TEH WITH HEH INITIAL FORM","	# <initial> 062A 0647"},
/* FCA6 */ { "ARABIC LIGATURE THEH WITH MEEM INITIAL FORM","	# <initial> 062B 0645"},
/* FCA7 */ { "ARABIC LIGATURE JEEM WITH HAH INITIAL FORM","	# <initial> 062C 062D"},
/* FCA8 */ { "ARABIC LIGATURE JEEM WITH MEEM INITIAL FORM","	# <initial> 062C 0645"},
/* FCA9 */ { "ARABIC LIGATURE HAH WITH JEEM INITIAL FORM","	# <initial> 062D 062C"},
/* FCAA */ { "ARABIC LIGATURE HAH WITH MEEM INITIAL FORM","	# <initial> 062D 0645"},
/* FCAB */ { "ARABIC LIGATURE KHAH WITH JEEM INITIAL FORM","	# <initial> 062E 062C"},
/* FCAC */ { "ARABIC LIGATURE KHAH WITH MEEM INITIAL FORM","	# <initial> 062E 0645"},
/* FCAD */ { "ARABIC LIGATURE SEEN WITH JEEM INITIAL FORM","	# <initial> 0633 062C"},
/* FCAE */ { "ARABIC LIGATURE SEEN WITH HAH INITIAL FORM","	# <initial> 0633 062D"},
/* FCAF */ { "ARABIC LIGATURE SEEN WITH KHAH INITIAL FORM","	# <initial> 0633 062E"},
/* FCB0 */ { "ARABIC LIGATURE SEEN WITH MEEM INITIAL FORM","	# <initial> 0633 0645"},
/* FCB1 */ { "ARABIC LIGATURE SAD WITH HAH INITIAL FORM","	# <initial> 0635 062D"},
/* FCB2 */ { "ARABIC LIGATURE SAD WITH KHAH INITIAL FORM","	# <initial> 0635 062E"},
/* FCB3 */ { "ARABIC LIGATURE SAD WITH MEEM INITIAL FORM","	# <initial> 0635 0645"},
/* FCB4 */ { "ARABIC LIGATURE DAD WITH JEEM INITIAL FORM","	# <initial> 0636 062C"},
/* FCB5 */ { "ARABIC LIGATURE DAD WITH HAH INITIAL FORM","	# <initial> 0636 062D"},
/* FCB6 */ { "ARABIC LIGATURE DAD WITH KHAH INITIAL FORM","	# <initial> 0636 062E"},
/* FCB7 */ { "ARABIC LIGATURE DAD WITH MEEM INITIAL FORM","	# <initial> 0636 0645"},
/* FCB8 */ { "ARABIC LIGATURE TAH WITH HAH INITIAL FORM","	# <initial> 0637 062D"},
/* FCB9 */ { "ARABIC LIGATURE ZAH WITH MEEM INITIAL FORM","	# <initial> 0638 0645"},
/* FCBA */ { "ARABIC LIGATURE AIN WITH JEEM INITIAL FORM","	# <initial> 0639 062C"},
/* FCBB */ { "ARABIC LIGATURE AIN WITH MEEM INITIAL FORM","	# <initial> 0639 0645"},
/* FCBC */ { "ARABIC LIGATURE GHAIN WITH JEEM INITIAL FORM","	# <initial> 063A 062C"},
/* FCBD */ { "ARABIC LIGATURE GHAIN WITH MEEM INITIAL FORM","	# <initial> 063A 0645"},
/* FCBE */ { "ARABIC LIGATURE FEH WITH JEEM INITIAL FORM","	# <initial> 0641 062C"},
/* FCBF */ { "ARABIC LIGATURE FEH WITH HAH INITIAL FORM","	# <initial> 0641 062D"},
/* FCC0 */ { "ARABIC LIGATURE FEH WITH KHAH INITIAL FORM","	# <initial> 0641 062E"},
/* FCC1 */ { "ARABIC LIGATURE FEH WITH MEEM INITIAL FORM","	# <initial> 0641 0645"},
/* FCC2 */ { "ARABIC LIGATURE QAF WITH HAH INITIAL FORM","	# <initial> 0642 062D"},
/* FCC3 */ { "ARABIC LIGATURE QAF WITH MEEM INITIAL FORM","	# <initial> 0642 0645"},
/* FCC4 */ { "ARABIC LIGATURE KAF WITH JEEM INITIAL FORM","	# <initial> 0643 062C"},
/* FCC5 */ { "ARABIC LIGATURE KAF WITH HAH INITIAL FORM","	# <initial> 0643 062D"},
/* FCC6 */ { "ARABIC LIGATURE KAF WITH KHAH INITIAL FORM","	# <initial> 0643 062E"},
/* FCC7 */ { "ARABIC LIGATURE KAF WITH LAM INITIAL FORM","	# <initial> 0643 0644"},
/* FCC8 */ { "ARABIC LIGATURE KAF WITH MEEM INITIAL FORM","	# <initial> 0643 0645"},
/* FCC9 */ { "ARABIC LIGATURE LAM WITH JEEM INITIAL FORM","	# <initial> 0644 062C"},
/* FCCA */ { "ARABIC LIGATURE LAM WITH HAH INITIAL FORM","	# <initial> 0644 062D"},
/* FCCB */ { "ARABIC LIGATURE LAM WITH KHAH INITIAL FORM","	# <initial> 0644 062E"},
/* FCCC */ { "ARABIC LIGATURE LAM WITH MEEM INITIAL FORM","	# <initial> 0644 0645"},
/* FCCD */ { "ARABIC LIGATURE LAM WITH HEH INITIAL FORM","	# <initial> 0644 0647"},
/* FCCE */ { "ARABIC LIGATURE MEEM WITH JEEM INITIAL FORM","	# <initial> 0645 062C"},
/* FCCF */ { "ARABIC LIGATURE MEEM WITH HAH INITIAL FORM","	# <initial> 0645 062D"},
/* FCD0 */ { "ARABIC LIGATURE MEEM WITH KHAH INITIAL FORM","	# <initial> 0645 062E"},
/* FCD1 */ { "ARABIC LIGATURE MEEM WITH MEEM INITIAL FORM","	# <initial> 0645 0645"},
/* FCD2 */ { "ARABIC LIGATURE NOON WITH JEEM INITIAL FORM","	# <initial> 0646 062C"},
/* FCD3 */ { "ARABIC LIGATURE NOON WITH HAH INITIAL FORM","	# <initial> 0646 062D"},
/* FCD4 */ { "ARABIC LIGATURE NOON WITH KHAH INITIAL FORM","	# <initial> 0646 062E"},
/* FCD5 */ { "ARABIC LIGATURE NOON WITH MEEM INITIAL FORM","	# <initial> 0646 0645"},
/* FCD6 */ { "ARABIC LIGATURE NOON WITH HEH INITIAL FORM","	# <initial> 0646 0647"},
/* FCD7 */ { "ARABIC LIGATURE HEH WITH JEEM INITIAL FORM","	# <initial> 0647 062C"},
/* FCD8 */ { "ARABIC LIGATURE HEH WITH MEEM INITIAL FORM","	# <initial> 0647 0645"},
/* FCD9 */ { "ARABIC LIGATURE HEH WITH SUPERSCRIPT ALEF INITIAL FORM","	# <initial> 0647 0670"},
/* FCDA */ { "ARABIC LIGATURE YEH WITH JEEM INITIAL FORM","	# <initial> 064A 062C"},
/* FCDB */ { "ARABIC LIGATURE YEH WITH HAH INITIAL FORM","	# <initial> 064A 062D"},
/* FCDC */ { "ARABIC LIGATURE YEH WITH KHAH INITIAL FORM","	# <initial> 064A 062E"},
/* FCDD */ { "ARABIC LIGATURE YEH WITH MEEM INITIAL FORM","	# <initial> 064A 0645"},
/* FCDE */ { "ARABIC LIGATURE YEH WITH HEH INITIAL FORM","	# <initial> 064A 0647"},
/* FCDF */ { "ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH MEEM MEDIAL FORM","	# <medial> 0626 0645"},
/* FCE0 */ { "ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH HEH MEDIAL FORM","	# <medial> 0626 0647"},
/* FCE1 */ { "ARABIC LIGATURE BEH WITH MEEM MEDIAL FORM","	# <medial> 0628 0645"},
/* FCE2 */ { "ARABIC LIGATURE BEH WITH HEH MEDIAL FORM","	# <medial> 0628 0647"},
/* FCE3 */ { "ARABIC LIGATURE TEH WITH MEEM MEDIAL FORM","	# <medial> 062A 0645"},
/* FCE4 */ { "ARABIC LIGATURE TEH WITH HEH MEDIAL FORM","	# <medial> 062A 0647"},
/* FCE5 */ { "ARABIC LIGATURE THEH WITH MEEM MEDIAL FORM","	# <medial> 062B 0645"},
/* FCE6 */ { "ARABIC LIGATURE THEH WITH HEH MEDIAL FORM","	# <medial> 062B 0647"},
/* FCE7 */ { "ARABIC LIGATURE SEEN WITH MEEM MEDIAL FORM","	# <medial> 0633 0645"},
/* FCE8 */ { "ARABIC LIGATURE SEEN WITH HEH MEDIAL FORM","	# <medial> 0633 0647"},
/* FCE9 */ { "ARABIC LIGATURE SHEEN WITH MEEM MEDIAL FORM","	# <medial> 0634 0645"},
/* FCEA */ { "ARABIC LIGATURE SHEEN WITH HEH MEDIAL FORM","	# <medial> 0634 0647"},
/* FCEB */ { "ARABIC LIGATURE KAF WITH LAM MEDIAL FORM","	# <medial> 0643 0644"},
/* FCEC */ { "ARABIC LIGATURE KAF WITH MEEM MEDIAL FORM","	# <medial> 0643 0645"},
/* FCED */ { "ARABIC LIGATURE LAM WITH MEEM MEDIAL FORM","	# <medial> 0644 0645"},
/* FCEE */ { "ARABIC LIGATURE NOON WITH MEEM MEDIAL FORM","	# <medial> 0646 0645"},
/* FCEF */ { "ARABIC LIGATURE NOON WITH HEH MEDIAL FORM","	# <medial> 0646 0647"},
/* FCF0 */ { "ARABIC LIGATURE YEH WITH MEEM MEDIAL FORM","	# <medial> 064A 0645"},
/* FCF1 */ { "ARABIC LIGATURE YEH WITH HEH MEDIAL FORM","	# <medial> 064A 0647"},
/* FCF2 */ { "ARABIC LIGATURE SHADDA WITH FATHA MEDIAL FORM","	# <medial> 0640 064E 0651"},
/* FCF3 */ { "ARABIC LIGATURE SHADDA WITH DAMMA MEDIAL FORM","	# <medial> 0640 064F 0651"},
/* FCF4 */ { "ARABIC LIGATURE SHADDA WITH KASRA MEDIAL FORM","	# <medial> 0640 0650 0651"},
/* FCF5 */ { "ARABIC LIGATURE TAH WITH ALEF MAKSURA ISOLATED FORM","	# <isolated> 0637 0649"},
/* FCF6 */ { "ARABIC LIGATURE TAH WITH YEH ISOLATED FORM","	# <isolated> 0637 064A"},
/* FCF7 */ { "ARABIC LIGATURE AIN WITH ALEF MAKSURA ISOLATED FORM","	# <isolated> 0639 0649"},
/* FCF8 */ { "ARABIC LIGATURE AIN WITH YEH ISOLATED FORM","	# <isolated> 0639 064A"},
/* FCF9 */ { "ARABIC LIGATURE GHAIN WITH ALEF MAKSURA ISOLATED FORM","	# <isolated> 063A 0649"},
/* FCFA */ { "ARABIC LIGATURE GHAIN WITH YEH ISOLATED FORM","	# <isolated> 063A 064A"},
/* FCFB */ { "ARABIC LIGATURE SEEN WITH ALEF MAKSURA ISOLATED FORM","	# <isolated> 0633 0649"},
/* FCFC */ { "ARABIC LIGATURE SEEN WITH YEH ISOLATED FORM","	# <isolated> 0633 064A"},
/* FCFD */ { "ARABIC LIGATURE SHEEN WITH ALEF MAKSURA ISOLATED FORM","	# <isolated> 0634 0649"},
/* FCFE */ { "ARABIC LIGATURE SHEEN WITH YEH ISOLATED FORM","	# <isolated> 0634 064A"},
/* FCFF */ { "ARABIC LIGATURE HAH WITH ALEF MAKSURA ISOLATED FORM","	# <isolated> 062D 0649"}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_00_FD[] = {
/* FD00 */ { "ARABIC LIGATURE HAH WITH YEH ISOLATED FORM","	# <isolated> 062D 064A"},
/* FD01 */ { "ARABIC LIGATURE JEEM WITH ALEF MAKSURA ISOLATED FORM","	# <isolated> 062C 0649"},
/* FD02 */ { "ARABIC LIGATURE JEEM WITH YEH ISOLATED FORM","	# <isolated> 062C 064A"},
/* FD03 */ { "ARABIC LIGATURE KHAH WITH ALEF MAKSURA ISOLATED FORM","	# <isolated> 062E 0649"},
/* FD04 */ { "ARABIC LIGATURE KHAH WITH YEH ISOLATED FORM","	# <isolated> 062E 064A"},
/* FD05 */ { "ARABIC LIGATURE SAD WITH ALEF MAKSURA ISOLATED FORM","	# <isolated> 0635 0649"},
/* FD06 */ { "ARABIC LIGATURE SAD WITH YEH ISOLATED FORM","	# <isolated> 0635 064A"},
/* FD07 */ { "ARABIC LIGATURE DAD WITH ALEF MAKSURA ISOLATED FORM","	# <isolated> 0636 0649"},
/* FD08 */ { "ARABIC LIGATURE DAD WITH YEH ISOLATED FORM","	# <isolated> 0636 064A"},
/* FD09 */ { "ARABIC LIGATURE SHEEN WITH JEEM ISOLATED FORM","	# <isolated> 0634 062C"},
/* FD0A */ { "ARABIC LIGATURE SHEEN WITH HAH ISOLATED FORM","	# <isolated> 0634 062D"},
/* FD0B */ { "ARABIC LIGATURE SHEEN WITH KHAH ISOLATED FORM","	# <isolated> 0634 062E"},
/* FD0C */ { "ARABIC LIGATURE SHEEN WITH MEEM ISOLATED FORM","	# <isolated> 0634 0645"},
/* FD0D */ { "ARABIC LIGATURE SHEEN WITH REH ISOLATED FORM","	# <isolated> 0634 0631"},
/* FD0E */ { "ARABIC LIGATURE SEEN WITH REH ISOLATED FORM","	# <isolated> 0633 0631"},
/* FD0F */ { "ARABIC LIGATURE SAD WITH REH ISOLATED FORM","	# <isolated> 0635 0631"},
/* FD10 */ { "ARABIC LIGATURE DAD WITH REH ISOLATED FORM","	# <isolated> 0636 0631"},
/* FD11 */ { "ARABIC LIGATURE TAH WITH ALEF MAKSURA FINAL FORM","	# <final> 0637 0649"},
/* FD12 */ { "ARABIC LIGATURE TAH WITH YEH FINAL FORM","	# <final> 0637 064A"},
/* FD13 */ { "ARABIC LIGATURE AIN WITH ALEF MAKSURA FINAL FORM","	# <final> 0639 0649"},
/* FD14 */ { "ARABIC LIGATURE AIN WITH YEH FINAL FORM","	# <final> 0639 064A"},
/* FD15 */ { "ARABIC LIGATURE GHAIN WITH ALEF MAKSURA FINAL FORM","	# <final> 063A 0649"},
/* FD16 */ { "ARABIC LIGATURE GHAIN WITH YEH FINAL FORM","	# <final> 063A 064A"},
/* FD17 */ { "ARABIC LIGATURE SEEN WITH ALEF MAKSURA FINAL FORM","	# <final> 0633 0649"},
/* FD18 */ { "ARABIC LIGATURE SEEN WITH YEH FINAL FORM","	# <final> 0633 064A"},
/* FD19 */ { "ARABIC LIGATURE SHEEN WITH ALEF MAKSURA FINAL FORM","	# <final> 0634 0649"},
/* FD1A */ { "ARABIC LIGATURE SHEEN WITH YEH FINAL FORM","	# <final> 0634 064A"},
/* FD1B */ { "ARABIC LIGATURE HAH WITH ALEF MAKSURA FINAL FORM","	# <final> 062D 0649"},
/* FD1C */ { "ARABIC LIGATURE HAH WITH YEH FINAL FORM","	# <final> 062D 064A"},
/* FD1D */ { "ARABIC LIGATURE JEEM WITH ALEF MAKSURA FINAL FORM","	# <final> 062C 0649"},
/* FD1E */ { "ARABIC LIGATURE JEEM WITH YEH FINAL FORM","	# <final> 062C 064A"},
/* FD1F */ { "ARABIC LIGATURE KHAH WITH ALEF MAKSURA FINAL FORM","	# <final> 062E 0649"},
/* FD20 */ { "ARABIC LIGATURE KHAH WITH YEH FINAL FORM","	# <final> 062E 064A"},
/* FD21 */ { "ARABIC LIGATURE SAD WITH ALEF MAKSURA FINAL FORM","	# <final> 0635 0649"},
/* FD22 */ { "ARABIC LIGATURE SAD WITH YEH FINAL FORM","	# <final> 0635 064A"},
/* FD23 */ { "ARABIC LIGATURE DAD WITH ALEF MAKSURA FINAL FORM","	# <final> 0636 0649"},
/* FD24 */ { "ARABIC LIGATURE DAD WITH YEH FINAL FORM","	# <final> 0636 064A"},
/* FD25 */ { "ARABIC LIGATURE SHEEN WITH JEEM FINAL FORM","	# <final> 0634 062C"},
/* FD26 */ { "ARABIC LIGATURE SHEEN WITH HAH FINAL FORM","	# <final> 0634 062D"},
/* FD27 */ { "ARABIC LIGATURE SHEEN WITH KHAH FINAL FORM","	# <final> 0634 062E"},
/* FD28 */ { "ARABIC LIGATURE SHEEN WITH MEEM FINAL FORM","	# <final> 0634 0645"},
/* FD29 */ { "ARABIC LIGATURE SHEEN WITH REH FINAL FORM","	# <final> 0634 0631"},
/* FD2A */ { "ARABIC LIGATURE SEEN WITH REH FINAL FORM","	# <final> 0633 0631"},
/* FD2B */ { "ARABIC LIGATURE SAD WITH REH FINAL FORM","	# <final> 0635 0631"},
/* FD2C */ { "ARABIC LIGATURE DAD WITH REH FINAL FORM","	# <final> 0636 0631"},
/* FD2D */ { "ARABIC LIGATURE SHEEN WITH JEEM INITIAL FORM","	# <initial> 0634 062C"},
/* FD2E */ { "ARABIC LIGATURE SHEEN WITH HAH INITIAL FORM","	# <initial> 0634 062D"},
/* FD2F */ { "ARABIC LIGATURE SHEEN WITH KHAH INITIAL FORM","	# <initial> 0634 062E"},
/* FD30 */ { "ARABIC LIGATURE SHEEN WITH MEEM INITIAL FORM","	# <initial> 0634 0645"},
/* FD31 */ { "ARABIC LIGATURE SEEN WITH HEH INITIAL FORM","	# <initial> 0633 0647"},
/* FD32 */ { "ARABIC LIGATURE SHEEN WITH HEH INITIAL FORM","	# <initial> 0634 0647"},
/* FD33 */ { "ARABIC LIGATURE TAH WITH MEEM INITIAL FORM","	# <initial> 0637 0645"},
/* FD34 */ { "ARABIC LIGATURE SEEN WITH JEEM MEDIAL FORM","	# <medial> 0633 062C"},
/* FD35 */ { "ARABIC LIGATURE SEEN WITH HAH MEDIAL FORM","	# <medial> 0633 062D"},
/* FD36 */ { "ARABIC LIGATURE SEEN WITH KHAH MEDIAL FORM","	# <medial> 0633 062E"},
/* FD37 */ { "ARABIC LIGATURE SHEEN WITH JEEM MEDIAL FORM","	# <medial> 0634 062C"},
/* FD38 */ { "ARABIC LIGATURE SHEEN WITH HAH MEDIAL FORM","	# <medial> 0634 062D"},
/* FD39 */ { "ARABIC LIGATURE SHEEN WITH KHAH MEDIAL FORM","	# <medial> 0634 062E"},
/* FD3A */ { "ARABIC LIGATURE TAH WITH MEEM MEDIAL FORM","	# <medial> 0637 0645"},
/* FD3B */ { "ARABIC LIGATURE ZAH WITH MEEM MEDIAL FORM","	# <medial> 0638 0645"},
/* FD3C */ { "ARABIC LIGATURE ALEF WITH FATHATAN FINAL FORM","	# <final> 0627 064B"},
/* FD3D */ { "ARABIC LIGATURE ALEF WITH FATHATAN ISOLATED FORM","	# <isolated> 0627 064B"},
/* FD3E */ { "ORNATE LEFT PARENTHESIS",NULL},
/* FD3F */ { "ORNATE RIGHT PARENTHESIS",NULL},
/* FD40 */ { "ARABIC LIGATURE RAHIMAHU ALLAAH","	x (arabic sign rahmatullah alayhe - 0612)"},
/* FD41 */ { "ARABIC LIGATURE RADI ALLAAHU ANH","	x (arabic sign radi allahou anhu - 0613)"},
/* FD42 */ { "ARABIC LIGATURE RADI ALLAAHU ANHAA",NULL},
/* FD43 */ { "ARABIC LIGATURE RADI ALLAAHU ANHUM",NULL},
/* FD44 */ { "ARABIC LIGATURE RADI ALLAAHU ANHUMAA",NULL},
/* FD45 */ { "ARABIC LIGATURE RADI ALLAAHU ANHUNNA",NULL},
/* FD46 */ { "ARABIC LIGATURE SALLALLAAHU ALAYHI WA-AALIH","	x (arabic ligature sallallahou alayhe wasallam - FDFA)"},
/* FD47 */ { "ARABIC LIGATURE ALAYHI AS-SALAAM","	x (arabic sign alayhe assallam - 0611)"},
/* FD48 */ { "ARABIC LIGATURE ALAYHIM AS-SALAAM",NULL},
/* FD49 */ { "ARABIC LIGATURE ALAYHIMAA AS-SALAAM",NULL},
/* FD4A */ { "ARABIC LIGATURE ALAYHI AS-SALAATU WAS-SALAAM",NULL},
/* FD4B */ { "ARABIC LIGATURE QUDDISA SIRRAH",NULL},
/* FD4C */ { "ARABIC LIGATURE SALLALLAHU ALAYHI WAAALIHEE WA-SALLAM","	x (arabic ligature sallallahou alayhe wasallam - FDFA)\n"
	"	x (arabic ligature sallallaahu alayhi wa-aalih - FD46)"},
/* FD4D */ { "ARABIC LIGATURE ALAYHAA AS-SALAAM",NULL},
/* FD4E */ { "ARABIC LIGATURE TABAARAKA WA-TAAALAA",NULL},
/* FD4F */ { "ARABIC LIGATURE RAHIMAHUM ALLAAH",NULL},
/* FD50 */ { "ARABIC LIGATURE TEH WITH JEEM WITH MEEM INITIAL FORM","	# <initial> 062A 062C 0645"},
/* FD51 */ { "ARABIC LIGATURE TEH WITH HAH WITH JEEM FINAL FORM","	# <final> 062A 062D 062C"},
/* FD52 */ { "ARABIC LIGATURE TEH WITH HAH WITH JEEM INITIAL FORM","	# <initial> 062A 062D 062C"},
/* FD53 */ { "ARABIC LIGATURE TEH WITH HAH WITH MEEM INITIAL FORM","	# <initial> 062A 062D 0645"},
/* FD54 */ { "ARABIC LIGATURE TEH WITH KHAH WITH MEEM INITIAL FORM","	# <initial> 062A 062E 0645"},
/* FD55 */ { "ARABIC LIGATURE TEH WITH MEEM WITH JEEM INITIAL FORM","	# <initial> 062A 0645 062C"},
/* FD56 */ { "ARABIC LIGATURE TEH WITH MEEM WITH HAH INITIAL FORM","	# <initial> 062A 0645 062D"},
/* FD57 */ { "ARABIC LIGATURE TEH WITH MEEM WITH KHAH INITIAL FORM","	# <initial> 062A 0645 062E"},
/* FD58 */ { "ARABIC LIGATURE JEEM WITH MEEM WITH HAH FINAL FORM","	# <final> 062C 0645 062D"},
/* FD59 */ { "ARABIC LIGATURE JEEM WITH MEEM WITH HAH INITIAL FORM","	# <initial> 062C 0645 062D"},
/* FD5A */ { "ARABIC LIGATURE HAH WITH MEEM WITH YEH FINAL FORM","	# <final> 062D 0645 064A"},
/* FD5B */ { "ARABIC LIGATURE HAH WITH MEEM WITH ALEF MAKSURA FINAL FORM","	# <final> 062D 0645 0649"},
/* FD5C */ { "ARABIC LIGATURE SEEN WITH HAH WITH JEEM INITIAL FORM","	# <initial> 0633 062D 062C"},
/* FD5D */ { "ARABIC LIGATURE SEEN WITH JEEM WITH HAH INITIAL FORM","	# <initial> 0633 062C 062D"},
/* FD5E */ { "ARABIC LIGATURE SEEN WITH JEEM WITH ALEF MAKSURA FINAL FORM","	# <final> 0633 062C 0649"},
/* FD5F */ { "ARABIC LIGATURE SEEN WITH MEEM WITH HAH FINAL FORM","	# <final> 0633 0645 062D"},
/* FD60 */ { "ARABIC LIGATURE SEEN WITH MEEM WITH HAH INITIAL FORM","	# <initial> 0633 0645 062D"},
/* FD61 */ { "ARABIC LIGATURE SEEN WITH MEEM WITH JEEM INITIAL FORM","	# <initial> 0633 0645 062C"},
/* FD62 */ { "ARABIC LIGATURE SEEN WITH MEEM WITH MEEM FINAL FORM","	# <final> 0633 0645 0645"},
/* FD63 */ { "ARABIC LIGATURE SEEN WITH MEEM WITH MEEM INITIAL FORM","	# <initial> 0633 0645 0645"},
/* FD64 */ { "ARABIC LIGATURE SAD WITH HAH WITH HAH FINAL FORM","	# <final> 0635 062D 062D"},
/* FD65 */ { "ARABIC LIGATURE SAD WITH HAH WITH HAH INITIAL FORM","	# <initial> 0635 062D 062D"},
/* FD66 */ { "ARABIC LIGATURE SAD WITH MEEM WITH MEEM FINAL FORM","	# <final> 0635 0645 0645"},
/* FD67 */ { "ARABIC LIGATURE SHEEN WITH HAH WITH MEEM FINAL FORM","	# <final> 0634 062D 0645"},
/* FD68 */ { "ARABIC LIGATURE SHEEN WITH HAH WITH MEEM INITIAL FORM","	# <initial> 0634 062D 0645"},
/* FD69 */ { "ARABIC LIGATURE SHEEN WITH JEEM WITH YEH FINAL FORM","	# <final> 0634 062C 064A"},
/* FD6A */ { "ARABIC LIGATURE SHEEN WITH MEEM WITH KHAH FINAL FORM","	# <final> 0634 0645 062E"},
/* FD6B */ { "ARABIC LIGATURE SHEEN WITH MEEM WITH KHAH INITIAL FORM","	# <initial> 0634 0645 062E"},
/* FD6C */ { "ARABIC LIGATURE SHEEN WITH MEEM WITH MEEM FINAL FORM","	# <final> 0634 0645 0645"},
/* FD6D */ { "ARABIC LIGATURE SHEEN WITH MEEM WITH MEEM INITIAL FORM","	# <initial> 0634 0645 0645"},
/* FD6E */ { "ARABIC LIGATURE DAD WITH HAH WITH ALEF MAKSURA FINAL FORM","	# <final> 0636 062D 0649"},
/* FD6F */ { "ARABIC LIGATURE DAD WITH KHAH WITH MEEM FINAL FORM","	# <final> 0636 062E 0645"},
/* FD70 */ { "ARABIC LIGATURE DAD WITH KHAH WITH MEEM INITIAL FORM","	# <initial> 0636 062E 0645"},
/* FD71 */ { "ARABIC LIGATURE TAH WITH MEEM WITH HAH FINAL FORM","	# <final> 0637 0645 062D"},
/* FD72 */ { "ARABIC LIGATURE TAH WITH MEEM WITH HAH INITIAL FORM","	# <initial> 0637 0645 062D"},
/* FD73 */ { "ARABIC LIGATURE TAH WITH MEEM WITH MEEM INITIAL FORM","	# <initial> 0637 0645 0645"},
/* FD74 */ { "ARABIC LIGATURE TAH WITH MEEM WITH YEH FINAL FORM","	# <final> 0637 0645 064A"},
/* FD75 */ { "ARABIC LIGATURE AIN WITH JEEM WITH MEEM FINAL FORM","	# <final> 0639 062C 0645"},
/* FD76 */ { "ARABIC LIGATURE AIN WITH MEEM WITH MEEM FINAL FORM","	# <final> 0639 0645 0645"},
/* FD77 */ { "ARABIC LIGATURE AIN WITH MEEM WITH MEEM INITIAL FORM","	# <initial> 0639 0645 0645"},
/* FD78 */ { "ARABIC LIGATURE AIN WITH MEEM WITH ALEF MAKSURA FINAL FORM","	# <final> 0639 0645 0649"},
/* FD79 */ { "ARABIC LIGATURE GHAIN WITH MEEM WITH MEEM FINAL FORM","	# <final> 063A 0645 0645"},
/* FD7A */ { "ARABIC LIGATURE GHAIN WITH MEEM WITH YEH FINAL FORM","	# <final> 063A 0645 064A"},
/* FD7B */ { "ARABIC LIGATURE GHAIN WITH MEEM WITH ALEF MAKSURA FINAL FORM","	# <final> 063A 0645 0649"},
/* FD7C */ { "ARABIC LIGATURE FEH WITH KHAH WITH MEEM FINAL FORM","	# <final> 0641 062E 0645"},
/* FD7D */ { "ARABIC LIGATURE FEH WITH KHAH WITH MEEM INITIAL FORM","	# <initial> 0641 062E 0645"},
/* FD7E */ { "ARABIC LIGATURE QAF WITH MEEM WITH HAH FINAL FORM","	# <final> 0642 0645 062D"},
/* FD7F */ { "ARABIC LIGATURE QAF WITH MEEM WITH MEEM FINAL FORM","	# <final> 0642 0645 0645"},
/* FD80 */ { "ARABIC LIGATURE LAM WITH HAH WITH MEEM FINAL FORM","	# <final> 0644 062D 0645"},
/* FD81 */ { "ARABIC LIGATURE LAM WITH HAH WITH YEH FINAL FORM","	# <final> 0644 062D 064A"},
/* FD82 */ { "ARABIC LIGATURE LAM WITH HAH WITH ALEF MAKSURA FINAL FORM","	# <final> 0644 062D 0649"},
/* FD83 */ { "ARABIC LIGATURE LAM WITH JEEM WITH JEEM INITIAL FORM","	# <initial> 0644 062C 062C"},
/* FD84 */ { "ARABIC LIGATURE LAM WITH JEEM WITH JEEM FINAL FORM","	# <final> 0644 062C 062C"},
/* FD85 */ { "ARABIC LIGATURE LAM WITH KHAH WITH MEEM FINAL FORM","	# <final> 0644 062E 0645"},
/* FD86 */ { "ARABIC LIGATURE LAM WITH KHAH WITH MEEM INITIAL FORM","	# <initial> 0644 062E 0645"},
/* FD87 */ { "ARABIC LIGATURE LAM WITH MEEM WITH HAH FINAL FORM","	# <final> 0644 0645 062D"},
/* FD88 */ { "ARABIC LIGATURE LAM WITH MEEM WITH HAH INITIAL FORM","	# <initial> 0644 0645 062D"},
/* FD89 */ { "ARABIC LIGATURE MEEM WITH HAH WITH JEEM INITIAL FORM","	# <initial> 0645 062D 062C"},
/* FD8A */ { "ARABIC LIGATURE MEEM WITH HAH WITH MEEM INITIAL FORM","	# <initial> 0645 062D 0645"},
/* FD8B */ { "ARABIC LIGATURE MEEM WITH HAH WITH YEH FINAL FORM","	# <final> 0645 062D 064A"},
/* FD8C */ { "ARABIC LIGATURE MEEM WITH JEEM WITH HAH INITIAL FORM","	# <initial> 0645 062C 062D"},
/* FD8D */ { "ARABIC LIGATURE MEEM WITH JEEM WITH MEEM INITIAL FORM","	# <initial> 0645 062C 0645"},
/* FD8E */ { "ARABIC LIGATURE MEEM WITH KHAH WITH JEEM INITIAL FORM","	# <initial> 0645 062E 062C"},
/* FD8F */ { "ARABIC LIGATURE MEEM WITH KHAH WITH MEEM INITIAL FORM","	# <initial> 0645 062E 0645"},
/* FD90 */ { "ARABIC LIGATURE RAHMATU ALLAAHI ALAYH",NULL},
/* FD91 */ { "ARABIC LIGATURE RAHMATU ALLAAHI ALAYHAA",NULL},
/* FD92 */ { "ARABIC LIGATURE MEEM WITH JEEM WITH KHAH INITIAL FORM","	# <initial> 0645 062C 062E"},
/* FD93 */ { "ARABIC LIGATURE HEH WITH MEEM WITH JEEM INITIAL FORM","	# <initial> 0647 0645 062C"},
/* FD94 */ { "ARABIC LIGATURE HEH WITH MEEM WITH MEEM INITIAL FORM","	# <initial> 0647 0645 0645"},
/* FD95 */ { "ARABIC LIGATURE NOON WITH HAH WITH MEEM INITIAL FORM","	# <initial> 0646 062D 0645"},
/* FD96 */ { "ARABIC LIGATURE NOON WITH HAH WITH ALEF MAKSURA FINAL FORM","	# <final> 0646 062D 0649"},
/* FD97 */ { "ARABIC LIGATURE NOON WITH JEEM WITH MEEM FINAL FORM","	# <final> 0646 062C 0645"},
/* FD98 */ { "ARABIC LIGATURE NOON WITH JEEM WITH MEEM INITIAL FORM","	# <initial> 0646 062C 0645"},
/* FD99 */ { "ARABIC LIGATURE NOON WITH JEEM WITH ALEF MAKSURA FINAL FORM","	# <final> 0646 062C 0649"},
/* FD9A */ { "ARABIC LIGATURE NOON WITH MEEM WITH YEH FINAL FORM","	# <final> 0646 0645 064A"},
/* FD9B */ { "ARABIC LIGATURE NOON WITH MEEM WITH ALEF MAKSURA FINAL FORM","	# <final> 0646 0645 0649"},
/* FD9C */ { "ARABIC LIGATURE YEH WITH MEEM WITH MEEM FINAL FORM","	# <final> 064A 0645 0645"},
/* FD9D */ { "ARABIC LIGATURE YEH WITH MEEM WITH MEEM INITIAL FORM","	# <initial> 064A 0645 0645"},
/* FD9E */ { "ARABIC LIGATURE BEH WITH KHAH WITH YEH FINAL FORM","	# <final> 0628 062E 064A"},
/* FD9F */ { "ARABIC LIGATURE TEH WITH JEEM WITH YEH FINAL FORM","	# <final> 062A 062C 064A"},
/* FDA0 */ { "ARABIC LIGATURE TEH WITH JEEM WITH ALEF MAKSURA FINAL FORM","	# <final> 062A 062C 0649"},
/* FDA1 */ { "ARABIC LIGATURE TEH WITH KHAH WITH YEH FINAL FORM","	# <final> 062A 062E 064A"},
/* FDA2 */ { "ARABIC LIGATURE TEH WITH KHAH WITH ALEF MAKSURA FINAL FORM","	# <final> 062A 062E 0649"},
/* FDA3 */ { "ARABIC LIGATURE TEH WITH MEEM WITH YEH FINAL FORM","	# <final> 062A 0645 064A"},
/* FDA4 */ { "ARABIC LIGATURE TEH WITH MEEM WITH ALEF MAKSURA FINAL FORM","	# <final> 062A 0645 0649"},
/* FDA5 */ { "ARABIC LIGATURE JEEM WITH MEEM WITH YEH FINAL FORM","	# <final> 062C 0645 064A"},
/* FDA6 */ { "ARABIC LIGATURE JEEM WITH HAH WITH ALEF MAKSURA FINAL FORM","	# <final> 062C 062D 0649"},
/* FDA7 */ { "ARABIC LIGATURE JEEM WITH MEEM WITH ALEF MAKSURA FINAL FORM","	# <final> 062C 0645 0649"},
/* FDA8 */ { "ARABIC LIGATURE SEEN WITH KHAH WITH ALEF MAKSURA FINAL FORM","	# <final> 0633 062E 0649"},
/* FDA9 */ { "ARABIC LIGATURE SAD WITH HAH WITH YEH FINAL FORM","	# <final> 0635 062D 064A"},
/* FDAA */ { "ARABIC LIGATURE SHEEN WITH HAH WITH YEH FINAL FORM","	# <final> 0634 062D 064A"},
/* FDAB */ { "ARABIC LIGATURE DAD WITH HAH WITH YEH FINAL FORM","	# <final> 0636 062D 064A"},
/* FDAC */ { "ARABIC LIGATURE LAM WITH JEEM WITH YEH FINAL FORM","	# <final> 0644 062C 064A"},
/* FDAD */ { "ARABIC LIGATURE LAM WITH MEEM WITH YEH FINAL FORM","	# <final> 0644 0645 064A"},
/* FDAE */ { "ARABIC LIGATURE YEH WITH HAH WITH YEH FINAL FORM","	# <final> 064A 062D 064A"},
/* FDAF */ { "ARABIC LIGATURE YEH WITH JEEM WITH YEH FINAL FORM","	# <final> 064A 062C 064A"},
/* FDB0 */ { "ARABIC LIGATURE YEH WITH MEEM WITH YEH FINAL FORM","	# <final> 064A 0645 064A"},
/* FDB1 */ { "ARABIC LIGATURE MEEM WITH MEEM WITH YEH FINAL FORM","	# <final> 0645 0645 064A"},
/* FDB2 */ { "ARABIC LIGATURE QAF WITH MEEM WITH YEH FINAL FORM","	# <final> 0642 0645 064A"},
/* FDB3 */ { "ARABIC LIGATURE NOON WITH HAH WITH YEH FINAL FORM","	# <final> 0646 062D 064A"},
/* FDB4 */ { "ARABIC LIGATURE QAF WITH MEEM WITH HAH INITIAL FORM","	# <initial> 0642 0645 062D"},
/* FDB5 */ { "ARABIC LIGATURE LAM WITH HAH WITH MEEM INITIAL FORM","	# <initial> 0644 062D 0645"},
/* FDB6 */ { "ARABIC LIGATURE AIN WITH MEEM WITH YEH FINAL FORM","	# <final> 0639 0645 064A"},
/* FDB7 */ { "ARABIC LIGATURE KAF WITH MEEM WITH YEH FINAL FORM","	# <final> 0643 0645 064A"},
/* FDB8 */ { "ARABIC LIGATURE NOON WITH JEEM WITH HAH INITIAL FORM","	# <initial> 0646 062C 062D"},
/* FDB9 */ { "ARABIC LIGATURE MEEM WITH KHAH WITH YEH FINAL FORM","	# <final> 0645 062E 064A"},
/* FDBA */ { "ARABIC LIGATURE LAM WITH JEEM WITH MEEM INITIAL FORM","	# <initial> 0644 062C 0645"},
/* FDBB */ { "ARABIC LIGATURE KAF WITH MEEM WITH MEEM FINAL FORM","	# <final> 0643 0645 0645"},
/* FDBC */ { "ARABIC LIGATURE LAM WITH JEEM WITH MEEM FINAL FORM","	# <final> 0644 062C 0645"},
/* FDBD */ { "ARABIC LIGATURE NOON WITH JEEM WITH HAH FINAL FORM","	# <final> 0646 062C 062D"},
/* FDBE */ { "ARABIC LIGATURE JEEM WITH HAH WITH YEH FINAL FORM","	# <final> 062C 062D 064A"},
/* FDBF */ { "ARABIC LIGATURE HAH WITH JEEM WITH YEH FINAL FORM","	# <final> 062D 062C 064A"},
/* FDC0 */ { "ARABIC LIGATURE MEEM WITH JEEM WITH YEH FINAL FORM","	# <final> 0645 062C 064A"},
/* FDC1 */ { "ARABIC LIGATURE FEH WITH MEEM WITH YEH FINAL FORM","	# <final> 0641 0645 064A"},
/* FDC2 */ { "ARABIC LIGATURE BEH WITH HAH WITH YEH FINAL FORM","	# <final> 0628 062D 064A"},
/* FDC3 */ { "ARABIC LIGATURE KAF WITH MEEM WITH MEEM INITIAL FORM","	# <initial> 0643 0645 0645"},
/* FDC4 */ { "ARABIC LIGATURE AIN WITH JEEM WITH MEEM INITIAL FORM","	# <initial> 0639 062C 0645"},
/* FDC5 */ { "ARABIC LIGATURE SAD WITH MEEM WITH MEEM INITIAL FORM","	# <initial> 0635 0645 0645"},
/* FDC6 */ { "ARABIC LIGATURE SEEN WITH KHAH WITH YEH FINAL FORM","	# <final> 0633 062E 064A"},
/* FDC7 */ { "ARABIC LIGATURE NOON WITH JEEM WITH YEH FINAL FORM","	# <final> 0646 062C 064A"},
/* FDC8 */ { "ARABIC LIGATURE RAHIMAHU ALLAAH TAAALAA",NULL},
/* FDC9 */ { "ARABIC LIGATURE RADI ALLAAHU TAAALAA ANH",NULL},
/* FDCA */ { "ARABIC LIGATURE RADI ALLAAHU TAAALAA ANHAA",NULL},
/* FDCB */ { "ARABIC LIGATURE RADI ALLAAHU TAAALAA ANHUMAA",NULL},
/* FDCC */ { "ARABIC LIGATURE SALLALLAHU ALAYHI WA-ALAA AALIHEE WA-SALLAM",NULL},
/* FDCD */ { "ARABIC LIGATURE AJJAL ALLAAHU TAAALAA FARAJAHU ASH-SHAREEF",NULL},
/* FDCE */ { "ARABIC LIGATURE KARRAMA ALLAAHU WAJHAH",NULL},
/* FDCF */ { "ARABIC LIGATURE SALAAMUHU ALAYNAA","	* his blessing on us\n"
	"	* used in Christian texts"},
/* FDD0 */ { NULL,NULL},
/* FDD1 */ { NULL,NULL},
/* FDD2 */ { NULL,NULL},
/* FDD3 */ { NULL,NULL},
/* FDD4 */ { NULL,NULL},
/* FDD5 */ { NULL,NULL},
/* FDD6 */ { NULL,NULL},
/* FDD7 */ { NULL,NULL},
/* FDD8 */ { NULL,NULL},
/* FDD9 */ { NULL,NULL},
/* FDDA */ { NULL,NULL},
/* FDDB */ { NULL,NULL},
/* FDDC */ { NULL,NULL},
/* FDDD */ { NULL,NULL},
/* FDDE */ { NULL,NULL},
/* FDDF */ { NULL,NULL},
/* FDE0 */ { NULL,NULL},
/* FDE1 */ { NULL,NULL},
/* FDE2 */ { NULL,NULL},
/* FDE3 */ { NULL,NULL},
/* FDE4 */ { NULL,NULL},
/* FDE5 */ { NULL,NULL},
/* FDE6 */ { NULL,NULL},
/* FDE7 */ { NULL,NULL},
/* FDE8 */ { NULL,NULL},
/* FDE9 */ { NULL,NULL},
/* FDEA */ { NULL,NULL},
/* FDEB */ { NULL,NULL},
/* FDEC */ { NULL,NULL},
/* FDED */ { NULL,NULL},
/* FDEE */ { NULL,NULL},
/* FDEF */ { NULL,NULL},
/* FDF0 */ { "ARABIC LIGATURE SALLA USED AS KORANIC STOP SIGN ISOLATED FORM","	# <isolated> 0635 0644 06D2"},
/* FDF1 */ { "ARABIC LIGATURE QALA USED AS KORANIC STOP SIGN ISOLATED FORM","	# <isolated> 0642 0644 06D2"},
/* FDF2 */ { "ARABIC LIGATURE ALLAH ISOLATED FORM","	# <isolated> 0627 0644 0644 0647"},
/* FDF3 */ { "ARABIC LIGATURE AKBAR ISOLATED FORM","	# <isolated> 0627 0643 0628 0631"},
/* FDF4 */ { "ARABIC LIGATURE MOHAMMAD ISOLATED FORM","	# <isolated> 0645 062D 0645 062F"},
/* FDF5 */ { "ARABIC LIGATURE SALAM ISOLATED FORM","	* common abbreviation for sallallahou alayhe wasallam\n"
	"	x (arabic ligature sallallahou alayhe wasallam - FDFA)\n"
	"	# <isolated> 0635 0644 0639 0645"},
/* FDF6 */ { "ARABIC LIGATURE RASOUL ISOLATED FORM","	# <isolated> 0631 0633 0648 0644"},
/* FDF7 */ { "ARABIC LIGATURE ALAYHE ISOLATED FORM","	# <isolated> 0639 0644 064A 0647"},
/* FDF8 */ { "ARABIC LIGATURE WASALLAM ISOLATED FORM","	# <isolated> 0648 0633 0644 0645"},
/* FDF9 */ { "ARABIC LIGATURE SALLA ISOLATED FORM","	# <isolated> 0635 0644 0649"},
/* FDFA */ { "ARABIC LIGATURE SALLALLAHOU ALAYHE WASALLAM","	# <isolated> 0635 0644 0649 0020 0627 0644 0644 0647 0020 0639 0644 064A 0647 0020 0648 0633 0644 0645"},
/* FDFB */ { "ARABIC LIGATURE JALLAJALALOUHOU","	# <isolated> 062C 0644 0020 062C 0644 0627 0644 0647"},
/* FDFC */ { "RIAL SIGN","	# <isolated> 0631 06CC 0627 0644"},
/* FDFD */ { "ARABIC LIGATURE BISMILLAH AR-RAHMAN AR-RAHEEM",NULL},
/* FDFE */ { "ARABIC LIGATURE SUBHAANAHU WA TAAALAA",NULL},
/* FDFF */ { "ARABIC LIGATURE AZZA WA JALL",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_00_FE[] = {
/* FE00 */ { "VARIATION SELECTOR-1","	* these are abbreviated VS1, and so on"},
/* FE01 */ { "VARIATION SELECTOR-2",NULL},
/* FE02 */ { "VARIATION SELECTOR-3",NULL},
/* FE03 */ { "VARIATION SELECTOR-4",NULL},
/* FE04 */ { "VARIATION SELECTOR-5",NULL},
/* FE05 */ { "VARIATION SELECTOR-6",NULL},
/* FE06 */ { "VARIATION SELECTOR-7",NULL},
/* FE07 */ { "VARIATION SELECTOR-8",NULL},
/* FE08 */ { "VARIATION SELECTOR-9",NULL},
/* FE09 */ { "VARIATION SELECTOR-10",NULL},
/* FE0A */ { "VARIATION SELECTOR-11",NULL},
/* FE0B */ { "VARIATION SELECTOR-12",NULL},
/* FE0C */ { "VARIATION SELECTOR-13",NULL},
/* FE0D */ { "VARIATION SELECTOR-14",NULL},
/* FE0E */ { "VARIATION SELECTOR-15","	= text variation selector"},
/* FE0F */ { "VARIATION SELECTOR-16","	= emoji variation selector"},
/* FE10 */ { "PRESENTATION FORM FOR VERTICAL COMMA","	x (small comma - FE50)\n"
	"	# <vertical> 002C"},
/* FE11 */ { "PRESENTATION FORM FOR VERTICAL IDEOGRAPHIC COMMA","	x (sesame dot - FE45)\n"
	"	x (small ideographic comma - FE51)\n"
	"	# <vertical> 3001"},
/* FE12 */ { "PRESENTATION FORM FOR VERTICAL IDEOGRAPHIC FULL STOP","	# <vertical> 3002"},
/* FE13 */ { "PRESENTATION FORM FOR VERTICAL COLON","	x (small colon - FE55)\n"
	"	# <vertical> 003A"},
/* FE14 */ { "PRESENTATION FORM FOR VERTICAL SEMICOLON","	x (small semicolon - FE54)\n"
	"	# <vertical> 003B"},
/* FE15 */ { "PRESENTATION FORM FOR VERTICAL EXCLAMATION MARK","	x (small exclamation mark - FE57)\n"
	"	# <vertical> 0021"},
/* FE16 */ { "PRESENTATION FORM FOR VERTICAL QUESTION MARK","	x (small question mark - FE56)\n"
	"	# <vertical> 003F"},
/* FE17 */ { "PRESENTATION FORM FOR VERTICAL LEFT WHITE LENTICULAR BRACKET","	# <vertical> 3016"},
/* FE18 */ { "PRESENTATION FORM FOR VERTICAL RIGHT WHITE LENTICULAR BRAKCET","	% PRESENTATION FORM FOR VERTICAL RIGHT WHITE LENTICULAR BRACKET\n"
	"	* misspelling of \"BRACKET\" in character name is a known defect\n"
	"	# <vertical> 3017"},
/* FE19 */ { "PRESENTATION FORM FOR VERTICAL HORIZONTAL ELLIPSIS","	x (vertical ellipsis - 22EE)\n"
	"	# <vertical> 2026"},
/* FE1A */ { NULL,NULL},
/* FE1B */ { NULL,NULL},
/* FE1C */ { NULL,NULL},
/* FE1D */ { NULL,NULL},
/* FE1E */ { NULL,NULL},
/* FE1F */ { NULL,NULL},
/* FE20 */ { "COMBINING LIGATURE LEFT HALF",NULL},
/* FE21 */ { "COMBINING LIGATURE RIGHT HALF","	x (combining double inverted breve - 0361)"},
/* FE22 */ { "COMBINING DOUBLE TILDE LEFT HALF",NULL},
/* FE23 */ { "COMBINING DOUBLE TILDE RIGHT HALF","	x (combining double tilde - 0360)"},
/* FE24 */ { "COMBINING MACRON LEFT HALF",NULL},
/* FE25 */ { "COMBINING MACRON RIGHT HALF",NULL},
/* FE26 */ { "COMBINING CONJOINING MACRON","	x (combining macron - 0304)\n"
	"	x (combining double macron - 035E)"},
/* FE27 */ { "COMBINING LIGATURE LEFT HALF BELOW",NULL},
/* FE28 */ { "COMBINING LIGATURE RIGHT HALF BELOW","	x (combining double breve below - 035C)"},
/* FE29 */ { "COMBINING TILDE LEFT HALF BELOW",NULL},
/* FE2A */ { "COMBINING TILDE RIGHT HALF BELOW",NULL},
/* FE2B */ { "COMBINING MACRON LEFT HALF BELOW",NULL},
/* FE2C */ { "COMBINING MACRON RIGHT HALF BELOW",NULL},
/* FE2D */ { "COMBINING CONJOINING MACRON BELOW","	x (combining macron below - 0331)\n"
	"	x (combining double macron below - 035F)"},
/* FE2E */ { "COMBINING CYRILLIC TITLO LEFT HALF",NULL},
/* FE2F */ { "COMBINING CYRILLIC TITLO RIGHT HALF","	x (combining cyrillic titlo - 0483)"},
/* FE30 */ { "PRESENTATION FORM FOR VERTICAL TWO DOT LEADER","	# <vertical> 2025"},
/* FE31 */ { "PRESENTATION FORM FOR VERTICAL EM DASH","	# <vertical> 2014"},
/* FE32 */ { "PRESENTATION FORM FOR VERTICAL EN DASH","	# <vertical> 2013"},
/* FE33 */ { "PRESENTATION FORM FOR VERTICAL LOW LINE","	# <vertical> 005F"},
/* FE34 */ { "PRESENTATION FORM FOR VERTICAL WAVY LOW LINE","	# <vertical> 005F"},
/* FE35 */ { "PRESENTATION FORM FOR VERTICAL LEFT PARENTHESIS","	x (top parenthesis - 23DC)\n"
	"	# <vertical> 0028"},
/* FE36 */ { "PRESENTATION FORM FOR VERTICAL RIGHT PARENTHESIS","	x (bottom parenthesis - 23DD)\n"
	"	# <vertical> 0029"},
/* FE37 */ { "PRESENTATION FORM FOR VERTICAL LEFT CURLY BRACKET","	x (top curly bracket - 23DE)\n"
	"	# <vertical> 007B"},
/* FE38 */ { "PRESENTATION FORM FOR VERTICAL RIGHT CURLY BRACKET","	x (bottom curly bracket - 23DF)\n"
	"	# <vertical> 007D"},
/* FE39 */ { "PRESENTATION FORM FOR VERTICAL LEFT TORTOISE SHELL BRACKET","	x (top tortoise shell bracket - 23E0)\n"
	"	# <vertical> 3014"},
/* FE3A */ { "PRESENTATION FORM FOR VERTICAL RIGHT TORTOISE SHELL BRACKET","	x (bottom tortoise shell bracket - 23E1)\n"
	"	# <vertical> 3015"},
/* FE3B */ { "PRESENTATION FORM FOR VERTICAL LEFT BLACK LENTICULAR BRACKET","	# <vertical> 3010"},
/* FE3C */ { "PRESENTATION FORM FOR VERTICAL RIGHT BLACK LENTICULAR BRACKET","	# <vertical> 3011"},
/* FE3D */ { "PRESENTATION FORM FOR VERTICAL LEFT DOUBLE ANGLE BRACKET","	# <vertical> 300A"},
/* FE3E */ { "PRESENTATION FORM FOR VERTICAL RIGHT DOUBLE ANGLE BRACKET","	# <vertical> 300B"},
/* FE3F */ { "PRESENTATION FORM FOR VERTICAL LEFT ANGLE BRACKET","	# <vertical> 3008"},
/* FE40 */ { "PRESENTATION FORM FOR VERTICAL RIGHT ANGLE BRACKET","	# <vertical> 3009"},
/* FE41 */ { "PRESENTATION FORM FOR VERTICAL LEFT CORNER BRACKET","	# <vertical> 300C"},
/* FE42 */ { "PRESENTATION FORM FOR VERTICAL RIGHT CORNER BRACKET","	# <vertical> 300D"},
/* FE43 */ { "PRESENTATION FORM FOR VERTICAL LEFT WHITE CORNER BRACKET","	# <vertical> 300E"},
/* FE44 */ { "PRESENTATION FORM FOR VERTICAL RIGHT WHITE CORNER BRACKET","	# <vertical> 300F"},
/* FE45 */ { "SESAME DOT","	x (small ideographic comma - FE51)"},
/* FE46 */ { "WHITE SESAME DOT","	* sesame dots are used beside vertical text for emphasis"},
/* FE47 */ { "PRESENTATION FORM FOR VERTICAL LEFT SQUARE BRACKET","	x (top square bracket - 23B4)\n"
	"	# <vertical> 005B"},
/* FE48 */ { "PRESENTATION FORM FOR VERTICAL RIGHT SQUARE BRACKET","	x (bottom square bracket - 23B5)\n"
	"	# <vertical> 005D"},
/* FE49 */ { "DASHED OVERLINE","	# 203E overline"},
/* FE4A */ { "CENTRELINE OVERLINE","	# 203E overline"},
/* FE4B */ { "WAVY OVERLINE","	# 203E overline"},
/* FE4C */ { "DOUBLE WAVY OVERLINE","	# 203E overline"},
/* FE4D */ { "DASHED LOW LINE","	# 005F low line"},
/* FE4E */ { "CENTRELINE LOW LINE","	# 005F low line"},
/* FE4F */ { "WAVY LOW LINE","	# 005F low line"},
/* FE50 */ { "SMALL COMMA","	x (presentation form for vertical comma - FE10)\n"
	"	# <small> 002C"},
/* FE51 */ { "SMALL IDEOGRAPHIC COMMA","	x (presentation form for vertical ideographic comma - FE11)\n"
	"	x (sesame dot - FE45)\n"
	"	# <small> 3001"},
/* FE52 */ { "SMALL FULL STOP","	# <small> 002E"},
/* FE53 */ { NULL,NULL},
/* FE54 */ { "SMALL SEMICOLON","	x (presentation form for vertical semicolon - FE14)\n"
	"	# <small> 003B"},
/* FE55 */ { "SMALL COLON","	x (presentation form for vertical colon - FE13)\n"
	"	# <small> 003A"},
/* FE56 */ { "SMALL QUESTION MARK","	# <small> 003F"},
/* FE57 */ { "SMALL EXCLAMATION MARK","	# <small> 0021"},
/* FE58 */ { "SMALL EM DASH","	# <small> 2014"},
/* FE59 */ { "SMALL LEFT PARENTHESIS","	# <small> 0028"},
/* FE5A */ { "SMALL RIGHT PARENTHESIS","	# <small> 0029"},
/* FE5B */ { "SMALL LEFT CURLY BRACKET","	# <small> 007B"},
/* FE5C */ { "SMALL RIGHT CURLY BRACKET","	# <small> 007D"},
/* FE5D */ { "SMALL LEFT TORTOISE SHELL BRACKET","	# <small> 3014"},
/* FE5E */ { "SMALL RIGHT TORTOISE SHELL BRACKET","	# <small> 3015"},
/* FE5F */ { "SMALL NUMBER SIGN","	# <small> 0023"},
/* FE60 */ { "SMALL AMPERSAND","	# <small> 0026"},
/* FE61 */ { "SMALL ASTERISK","	# <small> 002A"},
/* FE62 */ { "SMALL PLUS SIGN","	# <small> 002B"},
/* FE63 */ { "SMALL HYPHEN-MINUS","	# <small> 002D"},
/* FE64 */ { "SMALL LESS-THAN SIGN","	# <small> 003C"},
/* FE65 */ { "SMALL GREATER-THAN SIGN","	# <small> 003E"},
/* FE66 */ { "SMALL EQUALS SIGN","	# <small> 003D"},
/* FE67 */ { NULL,NULL},
/* FE68 */ { "SMALL REVERSE SOLIDUS","	# <small> 005C"},
/* FE69 */ { "SMALL DOLLAR SIGN","	# <small> 0024"},
/* FE6A */ { "SMALL PERCENT SIGN","	# <small> 0025"},
/* FE6B */ { "SMALL COMMERCIAL AT","	# <small> 0040"},
/* FE6C */ { NULL,NULL},
/* FE6D */ { NULL,NULL},
/* FE6E */ { NULL,NULL},
/* FE6F */ { NULL,NULL},
/* FE70 */ { "ARABIC FATHATAN ISOLATED FORM","	# <isolated> 0020 064B"},
/* FE71 */ { "ARABIC TATWEEL WITH FATHATAN ABOVE","	# <medial> 0640 064B"},
/* FE72 */ { "ARABIC DAMMATAN ISOLATED FORM","	# <isolated> 0020 064C"},
/* FE73 */ { "ARABIC TAIL FRAGMENT","	* for compatibility with certain legacy character sets"},
/* FE74 */ { "ARABIC KASRATAN ISOLATED FORM","	# <isolated> 0020 064D"},
/* FE75 */ { NULL,NULL},
/* FE76 */ { "ARABIC FATHA ISOLATED FORM","	# <isolated> 0020 064E"},
/* FE77 */ { "ARABIC FATHA MEDIAL FORM","	# <medial> 0640 064E"},
/* FE78 */ { "ARABIC DAMMA ISOLATED FORM","	# <isolated> 0020 064F"},
/* FE79 */ { "ARABIC DAMMA MEDIAL FORM","	# <medial> 0640 064F"},
/* FE7A */ { "ARABIC KASRA ISOLATED FORM","	# <isolated> 0020 0650"},
/* FE7B */ { "ARABIC KASRA MEDIAL FORM","	# <medial> 0640 0650"},
/* FE7C */ { "ARABIC SHADDA ISOLATED FORM","	# <isolated> 0020 0651"},
/* FE7D */ { "ARABIC SHADDA MEDIAL FORM","	# <medial> 0640 0651"},
/* FE7E */ { "ARABIC SUKUN ISOLATED FORM","	# <isolated> 0020 0652"},
/* FE7F */ { "ARABIC SUKUN MEDIAL FORM","	# <medial> 0640 0652"},
/* FE80 */ { "ARABIC LETTER HAMZA ISOLATED FORM","	# <isolated> 0621"},
/* FE81 */ { "ARABIC LETTER ALEF WITH MADDA ABOVE ISOLATED FORM","	# <isolated> 0622"},
/* FE82 */ { "ARABIC LETTER ALEF WITH MADDA ABOVE FINAL FORM","	# <final> 0622"},
/* FE83 */ { "ARABIC LETTER ALEF WITH HAMZA ABOVE ISOLATED FORM","	# <isolated> 0623"},
/* FE84 */ { "ARABIC LETTER ALEF WITH HAMZA ABOVE FINAL FORM","	# <final> 0623"},
/* FE85 */ { "ARABIC LETTER WAW WITH HAMZA ABOVE ISOLATED FORM","	# <isolated> 0624"},
/* FE86 */ { "ARABIC LETTER WAW WITH HAMZA ABOVE FINAL FORM","	# <final> 0624"},
/* FE87 */ { "ARABIC LETTER ALEF WITH HAMZA BELOW ISOLATED FORM","	# <isolated> 0625"},
/* FE88 */ { "ARABIC LETTER ALEF WITH HAMZA BELOW FINAL FORM","	# <final> 0625"},
/* FE89 */ { "ARABIC LETTER YEH WITH HAMZA ABOVE ISOLATED FORM","	# <isolated> 0626"},
/* FE8A */ { "ARABIC LETTER YEH WITH HAMZA ABOVE FINAL FORM","	# <final> 0626"},
/* FE8B */ { "ARABIC LETTER YEH WITH HAMZA ABOVE INITIAL FORM","	# <initial> 0626"},
/* FE8C */ { "ARABIC LETTER YEH WITH HAMZA ABOVE MEDIAL FORM","	# <medial> 0626"},
/* FE8D */ { "ARABIC LETTER ALEF ISOLATED FORM","	# <isolated> 0627"},
/* FE8E */ { "ARABIC LETTER ALEF FINAL FORM","	# <final> 0627"},
/* FE8F */ { "ARABIC LETTER BEH ISOLATED FORM","	# <isolated> 0628"},
/* FE90 */ { "ARABIC LETTER BEH FINAL FORM","	# <final> 0628"},
/* FE91 */ { "ARABIC LETTER BEH INITIAL FORM","	# <initial> 0628"},
/* FE92 */ { "ARABIC LETTER BEH MEDIAL FORM","	# <medial> 0628"},
/* FE93 */ { "ARABIC LETTER TEH MARBUTA ISOLATED FORM","	# <isolated> 0629"},
/* FE94 */ { "ARABIC LETTER TEH MARBUTA FINAL FORM","	# <final> 0629"},
/* FE95 */ { "ARABIC LETTER TEH ISOLATED FORM","	# <isolated> 062A"},
/* FE96 */ { "ARABIC LETTER TEH FINAL FORM","	# <final> 062A"},
/* FE97 */ { "ARABIC LETTER TEH INITIAL FORM","	# <initial> 062A"},
/* FE98 */ { "ARABIC LETTER TEH MEDIAL FORM","	# <medial> 062A"},
/* FE99 */ { "ARABIC LETTER THEH ISOLATED FORM","	# <isolated> 062B"},
/* FE9A */ { "ARABIC LETTER THEH FINAL FORM","	# <final> 062B"},
/* FE9B */ { "ARABIC LETTER THEH INITIAL FORM","	# <initial> 062B"},
/* FE9C */ { "ARABIC LETTER THEH MEDIAL FORM","	# <medial> 062B"},
/* FE9D */ { "ARABIC LETTER JEEM ISOLATED FORM","	# <isolated> 062C"},
/* FE9E */ { "ARABIC LETTER JEEM FINAL FORM","	# <final> 062C"},
/* FE9F */ { "ARABIC LETTER JEEM INITIAL FORM","	# <initial> 062C"},
/* FEA0 */ { "ARABIC LETTER JEEM MEDIAL FORM","	# <medial> 062C"},
/* FEA1 */ { "ARABIC LETTER HAH ISOLATED FORM","	# <isolated> 062D"},
/* FEA2 */ { "ARABIC LETTER HAH FINAL FORM","	# <final> 062D"},
/* FEA3 */ { "ARABIC LETTER HAH INITIAL FORM","	# <initial> 062D"},
/* FEA4 */ { "ARABIC LETTER HAH MEDIAL FORM","	# <medial> 062D"},
/* FEA5 */ { "ARABIC LETTER KHAH ISOLATED FORM","	# <isolated> 062E"},
/* FEA6 */ { "ARABIC LETTER KHAH FINAL FORM","	# <final> 062E"},
/* FEA7 */ { "ARABIC LETTER KHAH INITIAL FORM","	# <initial> 062E"},
/* FEA8 */ { "ARABIC LETTER KHAH MEDIAL FORM","	# <medial> 062E"},
/* FEA9 */ { "ARABIC LETTER DAL ISOLATED FORM","	# <isolated> 062F"},
/* FEAA */ { "ARABIC LETTER DAL FINAL FORM","	# <final> 062F"},
/* FEAB */ { "ARABIC LETTER THAL ISOLATED FORM","	# <isolated> 0630"},
/* FEAC */ { "ARABIC LETTER THAL FINAL FORM","	# <final> 0630"},
/* FEAD */ { "ARABIC LETTER REH ISOLATED FORM","	# <isolated> 0631"},
/* FEAE */ { "ARABIC LETTER REH FINAL FORM","	# <final> 0631"},
/* FEAF */ { "ARABIC LETTER ZAIN ISOLATED FORM","	# <isolated> 0632"},
/* FEB0 */ { "ARABIC LETTER ZAIN FINAL FORM","	# <final> 0632"},
/* FEB1 */ { "ARABIC LETTER SEEN ISOLATED FORM","	# <isolated> 0633"},
/* FEB2 */ { "ARABIC LETTER SEEN FINAL FORM","	# <final> 0633"},
/* FEB3 */ { "ARABIC LETTER SEEN INITIAL FORM","	# <initial> 0633"},
/* FEB4 */ { "ARABIC LETTER SEEN MEDIAL FORM","	# <medial> 0633"},
/* FEB5 */ { "ARABIC LETTER SHEEN ISOLATED FORM","	# <isolated> 0634"},
/* FEB6 */ { "ARABIC LETTER SHEEN FINAL FORM","	# <final> 0634"},
/* FEB7 */ { "ARABIC LETTER SHEEN INITIAL FORM","	# <initial> 0634"},
/* FEB8 */ { "ARABIC LETTER SHEEN MEDIAL FORM","	# <medial> 0634"},
/* FEB9 */ { "ARABIC LETTER SAD ISOLATED FORM","	# <isolated> 0635"},
/* FEBA */ { "ARABIC LETTER SAD FINAL FORM","	# <final> 0635"},
/* FEBB */ { "ARABIC LETTER SAD INITIAL FORM","	# <initial> 0635"},
/* FEBC */ { "ARABIC LETTER SAD MEDIAL FORM","	# <medial> 0635"},
/* FEBD */ { "ARABIC LETTER DAD ISOLATED FORM","	# <isolated> 0636"},
/* FEBE */ { "ARABIC LETTER DAD FINAL FORM","	# <final> 0636"},
/* FEBF */ { "ARABIC LETTER DAD INITIAL FORM","	# <initial> 0636"},
/* FEC0 */ { "ARABIC LETTER DAD MEDIAL FORM","	# <medial> 0636"},
/* FEC1 */ { "ARABIC LETTER TAH ISOLATED FORM","	# <isolated> 0637"},
/* FEC2 */ { "ARABIC LETTER TAH FINAL FORM","	# <final> 0637"},
/* FEC3 */ { "ARABIC LETTER TAH INITIAL FORM","	# <initial> 0637"},
/* FEC4 */ { "ARABIC LETTER TAH MEDIAL FORM","	# <medial> 0637"},
/* FEC5 */ { "ARABIC LETTER ZAH ISOLATED FORM","	# <isolated> 0638"},
/* FEC6 */ { "ARABIC LETTER ZAH FINAL FORM","	# <final> 0638"},
/* FEC7 */ { "ARABIC LETTER ZAH INITIAL FORM","	# <initial> 0638"},
/* FEC8 */ { "ARABIC LETTER ZAH MEDIAL FORM","	# <medial> 0638"},
/* FEC9 */ { "ARABIC LETTER AIN ISOLATED FORM","	# <isolated> 0639"},
/* FECA */ { "ARABIC LETTER AIN FINAL FORM","	# <final> 0639"},
/* FECB */ { "ARABIC LETTER AIN INITIAL FORM","	# <initial> 0639"},
/* FECC */ { "ARABIC LETTER AIN MEDIAL FORM","	# <medial> 0639"},
/* FECD */ { "ARABIC LETTER GHAIN ISOLATED FORM","	# <isolated> 063A"},
/* FECE */ { "ARABIC LETTER GHAIN FINAL FORM","	# <final> 063A"},
/* FECF */ { "ARABIC LETTER GHAIN INITIAL FORM","	# <initial> 063A"},
/* FED0 */ { "ARABIC LETTER GHAIN MEDIAL FORM","	# <medial> 063A"},
/* FED1 */ { "ARABIC LETTER FEH ISOLATED FORM","	# <isolated> 0641"},
/* FED2 */ { "ARABIC LETTER FEH FINAL FORM","	# <final> 0641"},
/* FED3 */ { "ARABIC LETTER FEH INITIAL FORM","	# <initial> 0641"},
/* FED4 */ { "ARABIC LETTER FEH MEDIAL FORM","	# <medial> 0641"},
/* FED5 */ { "ARABIC LETTER QAF ISOLATED FORM","	# <isolated> 0642"},
/* FED6 */ { "ARABIC LETTER QAF FINAL FORM","	# <final> 0642"},
/* FED7 */ { "ARABIC LETTER QAF INITIAL FORM","	# <initial> 0642"},
/* FED8 */ { "ARABIC LETTER QAF MEDIAL FORM","	# <medial> 0642"},
/* FED9 */ { "ARABIC LETTER KAF ISOLATED FORM","	# <isolated> 0643"},
/* FEDA */ { "ARABIC LETTER KAF FINAL FORM","	# <final> 0643"},
/* FEDB */ { "ARABIC LETTER KAF INITIAL FORM","	# <initial> 0643"},
/* FEDC */ { "ARABIC LETTER KAF MEDIAL FORM","	# <medial> 0643"},
/* FEDD */ { "ARABIC LETTER LAM ISOLATED FORM","	# <isolated> 0644"},
/* FEDE */ { "ARABIC LETTER LAM FINAL FORM","	# <final> 0644"},
/* FEDF */ { "ARABIC LETTER LAM INITIAL FORM","	# <initial> 0644"},
/* FEE0 */ { "ARABIC LETTER LAM MEDIAL FORM","	# <medial> 0644"},
/* FEE1 */ { "ARABIC LETTER MEEM ISOLATED FORM","	# <isolated> 0645"},
/* FEE2 */ { "ARABIC LETTER MEEM FINAL FORM","	# <final> 0645"},
/* FEE3 */ { "ARABIC LETTER MEEM INITIAL FORM","	# <initial> 0645"},
/* FEE4 */ { "ARABIC LETTER MEEM MEDIAL FORM","	# <medial> 0645"},
/* FEE5 */ { "ARABIC LETTER NOON ISOLATED FORM","	# <isolated> 0646"},
/* FEE6 */ { "ARABIC LETTER NOON FINAL FORM","	# <final> 0646"},
/* FEE7 */ { "ARABIC LETTER NOON INITIAL FORM","	# <initial> 0646"},
/* FEE8 */ { "ARABIC LETTER NOON MEDIAL FORM","	# <medial> 0646"},
/* FEE9 */ { "ARABIC LETTER HEH ISOLATED FORM","	# <isolated> 0647"},
/* FEEA */ { "ARABIC LETTER HEH FINAL FORM","	# <final> 0647"},
/* FEEB */ { "ARABIC LETTER HEH INITIAL FORM","	# <initial> 0647"},
/* FEEC */ { "ARABIC LETTER HEH MEDIAL FORM","	# <medial> 0647"},
/* FEED */ { "ARABIC LETTER WAW ISOLATED FORM","	# <isolated> 0648"},
/* FEEE */ { "ARABIC LETTER WAW FINAL FORM","	# <final> 0648"},
/* FEEF */ { "ARABIC LETTER ALEF MAKSURA ISOLATED FORM","	# <isolated> 0649"},
/* FEF0 */ { "ARABIC LETTER ALEF MAKSURA FINAL FORM","	# <final> 0649"},
/* FEF1 */ { "ARABIC LETTER YEH ISOLATED FORM","	# <isolated> 064A"},
/* FEF2 */ { "ARABIC LETTER YEH FINAL FORM","	# <final> 064A"},
/* FEF3 */ { "ARABIC LETTER YEH INITIAL FORM","	# <initial> 064A"},
/* FEF4 */ { "ARABIC LETTER YEH MEDIAL FORM","	# <medial> 064A"},
/* FEF5 */ { "ARABIC LIGATURE LAM WITH ALEF WITH MADDA ABOVE ISOLATED FORM","	# <isolated> 0644 0622"},
/* FEF6 */ { "ARABIC LIGATURE LAM WITH ALEF WITH MADDA ABOVE FINAL FORM","	# <final> 0644 0622"},
/* FEF7 */ { "ARABIC LIGATURE LAM WITH ALEF WITH HAMZA ABOVE ISOLATED FORM","	# <isolated> 0644 0623"},
/* FEF8 */ { "ARABIC LIGATURE LAM WITH ALEF WITH HAMZA ABOVE FINAL FORM","	# <final> 0644 0623"},
/* FEF9 */ { "ARABIC LIGATURE LAM WITH ALEF WITH HAMZA BELOW ISOLATED FORM","	# <isolated> 0644 0625"},
/* FEFA */ { "ARABIC LIGATURE LAM WITH ALEF WITH HAMZA BELOW FINAL FORM","	# <final> 0644 0625"},
/* FEFB */ { "ARABIC LIGATURE LAM WITH ALEF ISOLATED FORM","	# <isolated> 0644 0627"},
/* FEFC */ { "ARABIC LIGATURE LAM WITH ALEF FINAL FORM","	# <final> 0644 0627"},
/* FEFD */ { NULL,NULL},
/* FEFE */ { NULL,NULL},
/* FEFF */ { "ZERO WIDTH NO-BREAK SPACE","	% BYTE ORDER MARK\n"
	"	= BOM, ZWNBSP\n"
	"	* may be used to detect byte order by contrast with the noncharacter code point FFFE\n"
	"	* use as an indication of non-breaking is deprecated; see 2060 instead\n"
	"	x (zero width space - 200B)\n"
	"	x (word joiner - 2060)\n"
	"	x (<not a character> - FFFE)"}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_00_FF[] = {
/* FF00 */ { NULL,NULL},
/* FF01 */ { "FULLWIDTH EXCLAMATION MARK","	~ FF01 FE00 corner-justified form\n"
	"	~ FF01 FE01 centered form\n"
	"	# <wide> 0021"},
/* FF02 */ { "FULLWIDTH QUOTATION MARK","	# <wide> 0022"},
/* FF03 */ { "FULLWIDTH NUMBER SIGN","	# <wide> 0023"},
/* FF04 */ { "FULLWIDTH DOLLAR SIGN","	# <wide> 0024"},
/* FF05 */ { "FULLWIDTH PERCENT SIGN","	# <wide> 0025"},
/* FF06 */ { "FULLWIDTH AMPERSAND","	# <wide> 0026"},
/* FF07 */ { "FULLWIDTH APOSTROPHE","	# <wide> 0027"},
/* FF08 */ { "FULLWIDTH LEFT PARENTHESIS","	# <wide> 0028"},
/* FF09 */ { "FULLWIDTH RIGHT PARENTHESIS","	# <wide> 0029"},
/* FF0A */ { "FULLWIDTH ASTERISK","	# <wide> 002A"},
/* FF0B */ { "FULLWIDTH PLUS SIGN","	# <wide> 002B"},
/* FF0C */ { "FULLWIDTH COMMA","	* in Chinese, indicates a pause\n"
	"	x (ideographic comma - 3001)\n"
	"	~ FF0C FE00 corner-justified form\n"
	"	~ FF0C FE01 centered form\n"
	"	# <wide> 002C"},
/* FF0D */ { "FULLWIDTH HYPHEN-MINUS","	# <wide> 002D"},
/* FF0E */ { "FULLWIDTH FULL STOP","	~ FF0E FE00 corner-justified form\n"
	"	~ FF0E FE01 centered form\n"
	"	# <wide> 002E"},
/* FF0F */ { "FULLWIDTH SOLIDUS","	# <wide> 002F"},
/* FF10 */ { "FULLWIDTH DIGIT ZERO","	~ FF10 FE00 short diagonal stroke form\n"
	"	# <wide> 0030"},
/* FF11 */ { "FULLWIDTH DIGIT ONE","	# <wide> 0031"},
/* FF12 */ { "FULLWIDTH DIGIT TWO","	# <wide> 0032"},
/* FF13 */ { "FULLWIDTH DIGIT THREE","	# <wide> 0033"},
/* FF14 */ { "FULLWIDTH DIGIT FOUR","	# <wide> 0034"},
/* FF15 */ { "FULLWIDTH DIGIT FIVE","	# <wide> 0035"},
/* FF16 */ { "FULLWIDTH DIGIT SIX","	# <wide> 0036"},
/* FF17 */ { "FULLWIDTH DIGIT SEVEN","	# <wide> 0037"},
/* FF18 */ { "FULLWIDTH DIGIT EIGHT","	# <wide> 0038"},
/* FF19 */ { "FULLWIDTH DIGIT NINE","	# <wide> 0039"},
/* FF1A */ { "FULLWIDTH COLON","	~ FF1A FE00 corner-justified form\n"
	"	~ FF1A FE01 centered form\n"
	"	# <wide> 003A"},
/* FF1B */ { "FULLWIDTH SEMICOLON","	~ FF1B FE00 corner-justified form\n"
	"	~ FF1B FE01 centered form\n"
	"	# <wide> 003B"},
/* FF1C */ { "FULLWIDTH LESS-THAN SIGN","	# <wide> 003C"},
/* FF1D */ { "FULLWIDTH EQUALS SIGN","	# <wide> 003D"},
/* FF1E */ { "FULLWIDTH GREATER-THAN SIGN","	# <wide> 003E"},
/* FF1F */ { "FULLWIDTH QUESTION MARK","	~ FF1F FE00 corner-justified form\n"
	"	~ FF1F FE01 centered form\n"
	"	# <wide> 003F"},
/* FF20 */ { "FULLWIDTH COMMERCIAL AT","	# <wide> 0040"},
/* FF21 */ { "FULLWIDTH LATIN CAPITAL LETTER A","	# <wide> 0041"},
/* FF22 */ { "FULLWIDTH LATIN CAPITAL LETTER B","	# <wide> 0042"},
/* FF23 */ { "FULLWIDTH LATIN CAPITAL LETTER C","	# <wide> 0043"},
/* FF24 */ { "FULLWIDTH LATIN CAPITAL LETTER D","	# <wide> 0044"},
/* FF25 */ { "FULLWIDTH LATIN CAPITAL LETTER E","	# <wide> 0045"},
/* FF26 */ { "FULLWIDTH LATIN CAPITAL LETTER F","	# <wide> 0046"},
/* FF27 */ { "FULLWIDTH LATIN CAPITAL LETTER G","	# <wide> 0047"},
/* FF28 */ { "FULLWIDTH LATIN CAPITAL LETTER H","	# <wide> 0048"},
/* FF29 */ { "FULLWIDTH LATIN CAPITAL LETTER I","	# <wide> 0049"},
/* FF2A */ { "FULLWIDTH LATIN CAPITAL LETTER J","	# <wide> 004A"},
/* FF2B */ { "FULLWIDTH LATIN CAPITAL LETTER K","	# <wide> 004B"},
/* FF2C */ { "FULLWIDTH LATIN CAPITAL LETTER L","	# <wide> 004C"},
/* FF2D */ { "FULLWIDTH LATIN CAPITAL LETTER M","	# <wide> 004D"},
/* FF2E */ { "FULLWIDTH LATIN CAPITAL LETTER N","	# <wide> 004E"},
/* FF2F */ { "FULLWIDTH LATIN CAPITAL LETTER O","	# <wide> 004F"},
/* FF30 */ { "FULLWIDTH LATIN CAPITAL LETTER P","	# <wide> 0050"},
/* FF31 */ { "FULLWIDTH LATIN CAPITAL LETTER Q","	# <wide> 0051"},
/* FF32 */ { "FULLWIDTH LATIN CAPITAL LETTER R","	# <wide> 0052"},
/* FF33 */ { "FULLWIDTH LATIN CAPITAL LETTER S","	# <wide> 0053"},
/* FF34 */ { "FULLWIDTH LATIN CAPITAL LETTER T","	# <wide> 0054"},
/* FF35 */ { "FULLWIDTH LATIN CAPITAL LETTER U","	# <wide> 0055"},
/* FF36 */ { "FULLWIDTH LATIN CAPITAL LETTER V","	# <wide> 0056"},
/* FF37 */ { "FULLWIDTH LATIN CAPITAL LETTER W","	# <wide> 0057"},
/* FF38 */ { "FULLWIDTH LATIN CAPITAL LETTER X","	# <wide> 0058"},
/* FF39 */ { "FULLWIDTH LATIN CAPITAL LETTER Y","	# <wide> 0059"},
/* FF3A */ { "FULLWIDTH LATIN CAPITAL LETTER Z","	# <wide> 005A"},
/* FF3B */ { "FULLWIDTH LEFT SQUARE BRACKET","	# <wide> 005B"},
/* FF3C */ { "FULLWIDTH REVERSE SOLIDUS","	# <wide> 005C"},
/* FF3D */ { "FULLWIDTH RIGHT SQUARE BRACKET","	# <wide> 005D"},
/* FF3E */ { "FULLWIDTH CIRCUMFLEX ACCENT","	# <wide> 005E"},
/* FF3F */ { "FULLWIDTH LOW LINE","	# <wide> 005F"},
/* FF40 */ { "FULLWIDTH GRAVE ACCENT","	# <wide> 0060"},
/* FF41 */ { "FULLWIDTH LATIN SMALL LETTER A","	# <wide> 0061"},
/* FF42 */ { "FULLWIDTH LATIN SMALL LETTER B","	# <wide> 0062"},
/* FF43 */ { "FULLWIDTH LATIN SMALL LETTER C","	# <wide> 0063"},
/* FF44 */ { "FULLWIDTH LATIN SMALL LETTER D","	# <wide> 0064"},
/* FF45 */ { "FULLWIDTH LATIN SMALL LETTER E","	# <wide> 0065"},
/* FF46 */ { "FULLWIDTH LATIN SMALL LETTER F","	# <wide> 0066"},
/* FF47 */ { "FULLWIDTH LATIN SMALL LETTER G","	# <wide> 0067"},
/* FF48 */ { "FULLWIDTH LATIN SMALL LETTER H","	# <wide> 0068"},
/* FF49 */ { "FULLWIDTH LATIN SMALL LETTER I","	# <wide> 0069"},
/* FF4A */ { "FULLWIDTH LATIN SMALL LETTER J","	# <wide> 006A"},
/* FF4B */ { "FULLWIDTH LATIN SMALL LETTER K","	# <wide> 006B"},
/* FF4C */ { "FULLWIDTH LATIN SMALL LETTER L","	# <wide> 006C"},
/* FF4D */ { "FULLWIDTH LATIN SMALL LETTER M","	# <wide> 006D"},
/* FF4E */ { "FULLWIDTH LATIN SMALL LETTER N","	# <wide> 006E"},
/* FF4F */ { "FULLWIDTH LATIN SMALL LETTER O","	# <wide> 006F"},
/* FF50 */ { "FULLWIDTH LATIN SMALL LETTER P","	# <wide> 0070"},
/* FF51 */ { "FULLWIDTH LATIN SMALL LETTER Q","	# <wide> 0071"},
/* FF52 */ { "FULLWIDTH LATIN SMALL LETTER R","	# <wide> 0072"},
/* FF53 */ { "FULLWIDTH LATIN SMALL LETTER S","	# <wide> 0073"},
/* FF54 */ { "FULLWIDTH LATIN SMALL LETTER T","	# <wide> 0074"},
/* FF55 */ { "FULLWIDTH LATIN SMALL LETTER U","	# <wide> 0075"},
/* FF56 */ { "FULLWIDTH LATIN SMALL LETTER V","	# <wide> 0076"},
/* FF57 */ { "FULLWIDTH LATIN SMALL LETTER W","	# <wide> 0077"},
/* FF58 */ { "FULLWIDTH LATIN SMALL LETTER X","	# <wide> 0078"},
/* FF59 */ { "FULLWIDTH LATIN SMALL LETTER Y","	# <wide> 0079"},
/* FF5A */ { "FULLWIDTH LATIN SMALL LETTER Z","	# <wide> 007A"},
/* FF5B */ { "FULLWIDTH LEFT CURLY BRACKET","	# <wide> 007B"},
/* FF5C */ { "FULLWIDTH VERTICAL LINE","	# <wide> 007C"},
/* FF5D */ { "FULLWIDTH RIGHT CURLY BRACKET","	# <wide> 007D"},
/* FF5E */ { "FULLWIDTH TILDE","	x (wave dash - 301C)\n"
	"	# <wide> 007E"},
/* FF5F */ { "FULLWIDTH LEFT WHITE PARENTHESIS","	* the most commonly occurring glyph variant looks like doubled parentheses\n"
	"	x (left double parenthesis - 2E28)\n"
	"	# <wide> 2985"},
/* FF60 */ { "FULLWIDTH RIGHT WHITE PARENTHESIS","	# <wide> 2986"},
/* FF61 */ { "HALFWIDTH IDEOGRAPHIC FULL STOP","	# <narrow> 3002"},
/* FF62 */ { "HALFWIDTH LEFT CORNER BRACKET","	# <narrow> 300C"},
/* FF63 */ { "HALFWIDTH RIGHT CORNER BRACKET","	# <narrow> 300D"},
/* FF64 */ { "HALFWIDTH IDEOGRAPHIC COMMA","	# <narrow> 3001"},
/* FF65 */ { "HALFWIDTH KATAKANA MIDDLE DOT","	# <narrow> 30FB"},
/* FF66 */ { "HALFWIDTH KATAKANA LETTER WO","	# <narrow> 30F2"},
/* FF67 */ { "HALFWIDTH KATAKANA LETTER SMALL A","	# <narrow> 30A1"},
/* FF68 */ { "HALFWIDTH KATAKANA LETTER SMALL I","	# <narrow> 30A3"},
/* FF69 */ { "HALFWIDTH KATAKANA LETTER SMALL U","	# <narrow> 30A5"},
/* FF6A */ { "HALFWIDTH KATAKANA LETTER SMALL E","	# <narrow> 30A7"},
/* FF6B */ { "HALFWIDTH KATAKANA LETTER SMALL O","	# <narrow> 30A9"},
/* FF6C */ { "HALFWIDTH KATAKANA LETTER SMALL YA","	# <narrow> 30E3"},
/* FF6D */ { "HALFWIDTH KATAKANA LETTER SMALL YU","	# <narrow> 30E5"},
/* FF6E */ { "HALFWIDTH KATAKANA LETTER SMALL YO","	# <narrow> 30E7"},
/* FF6F */ { "HALFWIDTH KATAKANA LETTER SMALL TU","	# <narrow> 30C3"},
/* FF70 */ { "HALFWIDTH KATAKANA-HIRAGANA PROLONGED SOUND MARK","	# <narrow> 30FC"},
/* FF71 */ { "HALFWIDTH KATAKANA LETTER A","	# <narrow> 30A2"},
/* FF72 */ { "HALFWIDTH KATAKANA LETTER I","	# <narrow> 30A4"},
/* FF73 */ { "HALFWIDTH KATAKANA LETTER U","	# <narrow> 30A6"},
/* FF74 */ { "HALFWIDTH KATAKANA LETTER E","	# <narrow> 30A8"},
/* FF75 */ { "HALFWIDTH KATAKANA LETTER O","	# <narrow> 30AA"},
/* FF76 */ { "HALFWIDTH KATAKANA LETTER KA","	# <narrow> 30AB"},
/* FF77 */ { "HALFWIDTH KATAKANA LETTER KI","	# <narrow> 30AD"},
/* FF78 */ { "HALFWIDTH KATAKANA LETTER KU","	# <narrow> 30AF"},
/* FF79 */ { "HALFWIDTH KATAKANA LETTER KE","	# <narrow> 30B1"},
/* FF7A */ { "HALFWIDTH KATAKANA LETTER KO","	# <narrow> 30B3"},
/* FF7B */ { "HALFWIDTH KATAKANA LETTER SA","	# <narrow> 30B5"},
/* FF7C */ { "HALFWIDTH KATAKANA LETTER SI","	# <narrow> 30B7"},
/* FF7D */ { "HALFWIDTH KATAKANA LETTER SU","	# <narrow> 30B9"},
/* FF7E */ { "HALFWIDTH KATAKANA LETTER SE","	# <narrow> 30BB"},
/* FF7F */ { "HALFWIDTH KATAKANA LETTER SO","	# <narrow> 30BD"},
/* FF80 */ { "HALFWIDTH KATAKANA LETTER TA","	# <narrow> 30BF"},
/* FF81 */ { "HALFWIDTH KATAKANA LETTER TI","	# <narrow> 30C1"},
/* FF82 */ { "HALFWIDTH KATAKANA LETTER TU","	# <narrow> 30C4"},
/* FF83 */ { "HALFWIDTH KATAKANA LETTER TE","	# <narrow> 30C6"},
/* FF84 */ { "HALFWIDTH KATAKANA LETTER TO","	# <narrow> 30C8"},
/* FF85 */ { "HALFWIDTH KATAKANA LETTER NA","	# <narrow> 30CA"},
/* FF86 */ { "HALFWIDTH KATAKANA LETTER NI","	# <narrow> 30CB"},
/* FF87 */ { "HALFWIDTH KATAKANA LETTER NU","	# <narrow> 30CC"},
/* FF88 */ { "HALFWIDTH KATAKANA LETTER NE","	# <narrow> 30CD"},
/* FF89 */ { "HALFWIDTH KATAKANA LETTER NO","	# <narrow> 30CE"},
/* FF8A */ { "HALFWIDTH KATAKANA LETTER HA","	# <narrow> 30CF"},
/* FF8B */ { "HALFWIDTH KATAKANA LETTER HI","	# <narrow> 30D2"},
/* FF8C */ { "HALFWIDTH KATAKANA LETTER HU","	# <narrow> 30D5"},
/* FF8D */ { "HALFWIDTH KATAKANA LETTER HE","	# <narrow> 30D8"},
/* FF8E */ { "HALFWIDTH KATAKANA LETTER HO","	# <narrow> 30DB"},
/* FF8F */ { "HALFWIDTH KATAKANA LETTER MA","	# <narrow> 30DE"},
/* FF90 */ { "HALFWIDTH KATAKANA LETTER MI","	# <narrow> 30DF"},
/* FF91 */ { "HALFWIDTH KATAKANA LETTER MU","	# <narrow> 30E0"},
/* FF92 */ { "HALFWIDTH KATAKANA LETTER ME","	# <narrow> 30E1"},
/* FF93 */ { "HALFWIDTH KATAKANA LETTER MO","	# <narrow> 30E2"},
/* FF94 */ { "HALFWIDTH KATAKANA LETTER YA","	# <narrow> 30E4"},
/* FF95 */ { "HALFWIDTH KATAKANA LETTER YU","	# <narrow> 30E6"},
/* FF96 */ { "HALFWIDTH KATAKANA LETTER YO","	# <narrow> 30E8"},
/* FF97 */ { "HALFWIDTH KATAKANA LETTER RA","	# <narrow> 30E9"},
/* FF98 */ { "HALFWIDTH KATAKANA LETTER RI","	# <narrow> 30EA"},
/* FF99 */ { "HALFWIDTH KATAKANA LETTER RU","	# <narrow> 30EB"},
/* FF9A */ { "HALFWIDTH KATAKANA LETTER RE","	# <narrow> 30EC"},
/* FF9B */ { "HALFWIDTH KATAKANA LETTER RO","	# <narrow> 30ED"},
/* FF9C */ { "HALFWIDTH KATAKANA LETTER WA","	# <narrow> 30EF"},
/* FF9D */ { "HALFWIDTH KATAKANA LETTER N","	# <narrow> 30F3"},
/* FF9E */ { "HALFWIDTH KATAKANA VOICED SOUND MARK","	# <narrow> 3099"},
/* FF9F */ { "HALFWIDTH KATAKANA SEMI-VOICED SOUND MARK","	# <narrow> 309A"},
/* FFA0 */ { "HALFWIDTH HANGUL FILLER","	# <narrow> 3164"},
/* FFA1 */ { "HALFWIDTH HANGUL LETTER KIYEOK","	# <narrow> 3131"},
/* FFA2 */ { "HALFWIDTH HANGUL LETTER SSANGKIYEOK","	# <narrow> 3132"},
/* FFA3 */ { "HALFWIDTH HANGUL LETTER KIYEOK-SIOS","	# <narrow> 3133"},
/* FFA4 */ { "HALFWIDTH HANGUL LETTER NIEUN","	# <narrow> 3134"},
/* FFA5 */ { "HALFWIDTH HANGUL LETTER NIEUN-CIEUC","	# <narrow> 3135"},
/* FFA6 */ { "HALFWIDTH HANGUL LETTER NIEUN-HIEUH","	# <narrow> 3136"},
/* FFA7 */ { "HALFWIDTH HANGUL LETTER TIKEUT","	# <narrow> 3137"},
/* FFA8 */ { "HALFWIDTH HANGUL LETTER SSANGTIKEUT","	# <narrow> 3138"},
/* FFA9 */ { "HALFWIDTH HANGUL LETTER RIEUL","	# <narrow> 3139"},
/* FFAA */ { "HALFWIDTH HANGUL LETTER RIEUL-KIYEOK","	# <narrow> 313A"},
/* FFAB */ { "HALFWIDTH HANGUL LETTER RIEUL-MIEUM","	# <narrow> 313B"},
/* FFAC */ { "HALFWIDTH HANGUL LETTER RIEUL-PIEUP","	# <narrow> 313C"},
/* FFAD */ { "HALFWIDTH HANGUL LETTER RIEUL-SIOS","	# <narrow> 313D"},
/* FFAE */ { "HALFWIDTH HANGUL LETTER RIEUL-THIEUTH","	# <narrow> 313E"},
/* FFAF */ { "HALFWIDTH HANGUL LETTER RIEUL-PHIEUPH","	# <narrow> 313F"},
/* FFB0 */ { "HALFWIDTH HANGUL LETTER RIEUL-HIEUH","	# <narrow> 3140"},
/* FFB1 */ { "HALFWIDTH HANGUL LETTER MIEUM","	# <narrow> 3141"},
/* FFB2 */ { "HALFWIDTH HANGUL LETTER PIEUP","	# <narrow> 3142"},
/* FFB3 */ { "HALFWIDTH HANGUL LETTER SSANGPIEUP","	# <narrow> 3143"},
/* FFB4 */ { "HALFWIDTH HANGUL LETTER PIEUP-SIOS","	# <narrow> 3144"},
/* FFB5 */ { "HALFWIDTH HANGUL LETTER SIOS","	# <narrow> 3145"},
/* FFB6 */ { "HALFWIDTH HANGUL LETTER SSANGSIOS","	# <narrow> 3146"},
/* FFB7 */ { "HALFWIDTH HANGUL LETTER IEUNG","	# <narrow> 3147"},
/* FFB8 */ { "HALFWIDTH HANGUL LETTER CIEUC","	# <narrow> 3148"},
/* FFB9 */ { "HALFWIDTH HANGUL LETTER SSANGCIEUC","	# <narrow> 3149"},
/* FFBA */ { "HALFWIDTH HANGUL LETTER CHIEUCH","	# <narrow> 314A"},
/* FFBB */ { "HALFWIDTH HANGUL LETTER KHIEUKH","	# <narrow> 314B"},
/* FFBC */ { "HALFWIDTH HANGUL LETTER THIEUTH","	# <narrow> 314C"},
/* FFBD */ { "HALFWIDTH HANGUL LETTER PHIEUPH","	# <narrow> 314D"},
/* FFBE */ { "HALFWIDTH HANGUL LETTER HIEUH","	# <narrow> 314E"},
/* FFBF */ { NULL,NULL},
/* FFC0 */ { NULL,NULL},
/* FFC1 */ { NULL,NULL},
/* FFC2 */ { "HALFWIDTH HANGUL LETTER A","	# <narrow> 314F"},
/* FFC3 */ { "HALFWIDTH HANGUL LETTER AE","	# <narrow> 3150"},
/* FFC4 */ { "HALFWIDTH HANGUL LETTER YA","	# <narrow> 3151"},
/* FFC5 */ { "HALFWIDTH HANGUL LETTER YAE","	# <narrow> 3152"},
/* FFC6 */ { "HALFWIDTH HANGUL LETTER EO","	# <narrow> 3153"},
/* FFC7 */ { "HALFWIDTH HANGUL LETTER E","	# <narrow> 3154"},
/* FFC8 */ { NULL,NULL},
/* FFC9 */ { NULL,NULL},
/* FFCA */ { "HALFWIDTH HANGUL LETTER YEO","	# <narrow> 3155"},
/* FFCB */ { "HALFWIDTH HANGUL LETTER YE","	# <narrow> 3156"},
/* FFCC */ { "HALFWIDTH HANGUL LETTER O","	# <narrow> 3157"},
/* FFCD */ { "HALFWIDTH HANGUL LETTER WA","	# <narrow> 3158"},
/* FFCE */ { "HALFWIDTH HANGUL LETTER WAE","	# <narrow> 3159"},
/* FFCF */ { "HALFWIDTH HANGUL LETTER OE","	# <narrow> 315A"},
/* FFD0 */ { NULL,NULL},
/* FFD1 */ { NULL,NULL},
/* FFD2 */ { "HALFWIDTH HANGUL LETTER YO","	# <narrow> 315B"},
/* FFD3 */ { "HALFWIDTH HANGUL LETTER U","	# <narrow> 315C"},
/* FFD4 */ { "HALFWIDTH HANGUL LETTER WEO","	# <narrow> 315D"},
/* FFD5 */ { "HALFWIDTH HANGUL LETTER WE","	# <narrow> 315E"},
/* FFD6 */ { "HALFWIDTH HANGUL LETTER WI","	# <narrow> 315F"},
/* FFD7 */ { "HALFWIDTH HANGUL LETTER YU","	# <narrow> 3160"},
/* FFD8 */ { NULL,NULL},
/* FFD9 */ { NULL,NULL},
/* FFDA */ { "HALFWIDTH HANGUL LETTER EU","	# <narrow> 3161"},
/* FFDB */ { "HALFWIDTH HANGUL LETTER YI","	# <narrow> 3162"},
/* FFDC */ { "HALFWIDTH HANGUL LETTER I","	# <narrow> 3163"},
/* FFDD */ { NULL,NULL},
/* FFDE */ { NULL,NULL},
/* FFDF */ { NULL,NULL},
/* FFE0 */ { "FULLWIDTH CENT SIGN","	# <wide> 00A2"},
/* FFE1 */ { "FULLWIDTH POUND SIGN","	# <wide> 00A3"},
/* FFE2 */ { "FULLWIDTH NOT SIGN","	# <wide> 00AC"},
/* FFE3 */ { "FULLWIDTH MACRON","	* sometimes treated as fullwidth overline\n"
	"	x (overline - 203E)\n"
	"	# <wide> 00AF"},
/* FFE4 */ { "FULLWIDTH BROKEN BAR","	# <wide> 00A6"},
/* FFE5 */ { "FULLWIDTH YEN SIGN","	# <wide> 00A5"},
/* FFE6 */ { "FULLWIDTH WON SIGN","	# <wide> 20A9"},
/* FFE7 */ { NULL,NULL},
/* FFE8 */ { "HALFWIDTH FORMS LIGHT VERTICAL","	# <narrow> 2502"},
/* FFE9 */ { "HALFWIDTH LEFTWARDS ARROW","	# <narrow> 2190"},
/* FFEA */ { "HALFWIDTH UPWARDS ARROW","	# <narrow> 2191"},
/* FFEB */ { "HALFWIDTH RIGHTWARDS ARROW","	# <narrow> 2192"},
/* FFEC */ { "HALFWIDTH DOWNWARDS ARROW","	# <narrow> 2193"},
/* FFED */ { "HALFWIDTH BLACK SQUARE","	# <narrow> 25A0"},
/* FFEE */ { "HALFWIDTH WHITE CIRCLE","	# <narrow> 25CB"},
/* FFEF */ { NULL,NULL},
/* FFF0 */ { NULL,NULL},
/* FFF1 */ { NULL,NULL},
/* FFF2 */ { NULL,NULL},
/* FFF3 */ { NULL,NULL},
/* FFF4 */ { NULL,NULL},
/* FFF5 */ { NULL,NULL},
/* FFF6 */ { NULL,NULL},
/* FFF7 */ { NULL,NULL},
/* FFF8 */ { NULL,NULL},
/* FFF9 */ { "INTERLINEAR ANNOTATION ANCHOR","	* marks start of annotated text"},
/* FFFA */ { "INTERLINEAR ANNOTATION SEPARATOR","	* marks start of annotating character(s)"},
/* FFFB */ { "INTERLINEAR ANNOTATION TERMINATOR","	* marks end of annotation block"},
/* FFFC */ { "OBJECT REPLACEMENT CHARACTER","	* used as placeholder in text for an otherwise unspecified object"},
/* FFFD */ { "REPLACEMENT CHARACTER","	* used to replace an incoming character whose value is unknown or unrepresentable in Unicode\n"
	"	* compare the use of 001A as a control character to indicate the substitute function\n"
	"	x (uncertainty sign - 2BD1)\n"
	"	x (negative squared question mark - 1FBC4)"},
/* FFFE */ { NULL,"	* may be used to detect byte order by contrast with FEFF\n"
	"	x (zero width no-break space - FEFF)"},
/* FFFF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_00[] = {
/* 10000 */ { "LINEAR B SYLLABLE B008 A",NULL},
/* 10001 */ { "LINEAR B SYLLABLE B038 E",NULL},
/* 10002 */ { "LINEAR B SYLLABLE B028 I",NULL},
/* 10003 */ { "LINEAR B SYLLABLE B061 O",NULL},
/* 10004 */ { "LINEAR B SYLLABLE B010 U",NULL},
/* 10005 */ { "LINEAR B SYLLABLE B001 DA",NULL},
/* 10006 */ { "LINEAR B SYLLABLE B045 DE",NULL},
/* 10007 */ { "LINEAR B SYLLABLE B007 DI",NULL},
/* 10008 */ { "LINEAR B SYLLABLE B014 DO",NULL},
/* 10009 */ { "LINEAR B SYLLABLE B051 DU",NULL},
/* 1000A */ { "LINEAR B SYLLABLE B057 JA",NULL},
/* 1000B */ { "LINEAR B SYLLABLE B046 JE",NULL},
/* 1000C */ { NULL,NULL},
/* 1000D */ { "LINEAR B SYLLABLE B036 JO",NULL},
/* 1000E */ { "LINEAR B SYLLABLE B065 JU","	= ideogram B129 flour"},
/* 1000F */ { "LINEAR B SYLLABLE B077 KA",NULL},
/* 10010 */ { "LINEAR B SYLLABLE B044 KE",NULL},
/* 10011 */ { "LINEAR B SYLLABLE B067 KI",NULL},
/* 10012 */ { "LINEAR B SYLLABLE B070 KO",NULL},
/* 10013 */ { "LINEAR B SYLLABLE B081 KU",NULL},
/* 10014 */ { "LINEAR B SYLLABLE B080 MA",NULL},
/* 10015 */ { "LINEAR B SYLLABLE B013 ME",NULL},
/* 10016 */ { "LINEAR B SYLLABLE B073 MI",NULL},
/* 10017 */ { "LINEAR B SYLLABLE B015 MO",NULL},
/* 10018 */ { "LINEAR B SYLLABLE B023 MU","	= ideogram B109 ox"},
/* 10019 */ { "LINEAR B SYLLABLE B006 NA",NULL},
/* 1001A */ { "LINEAR B SYLLABLE B024 NE",NULL},
/* 1001B */ { "LINEAR B SYLLABLE B030 NI","	= ideogram B030 figs"},
/* 1001C */ { "LINEAR B SYLLABLE B052 NO",NULL},
/* 1001D */ { "LINEAR B SYLLABLE B055 NU",NULL},
/* 1001E */ { "LINEAR B SYLLABLE B003 PA",NULL},
/* 1001F */ { "LINEAR B SYLLABLE B072 PE",NULL},
/* 10020 */ { "LINEAR B SYLLABLE B039 PI",NULL},
/* 10021 */ { "LINEAR B SYLLABLE B011 PO",NULL},
/* 10022 */ { "LINEAR B SYLLABLE B050 PU",NULL},
/* 10023 */ { "LINEAR B SYLLABLE B016 QA",NULL},
/* 10024 */ { "LINEAR B SYLLABLE B078 QE",NULL},
/* 10025 */ { "LINEAR B SYLLABLE B021 QI","	= ideogram B106 sheep"},
/* 10026 */ { "LINEAR B SYLLABLE B032 QO",NULL},
/* 10027 */ { NULL,NULL},
/* 10028 */ { "LINEAR B SYLLABLE B060 RA",NULL},
/* 10029 */ { "LINEAR B SYLLABLE B027 RE",NULL},
/* 1002A */ { "LINEAR B SYLLABLE B053 RI",NULL},
/* 1002B */ { "LINEAR B SYLLABLE B002 RO",NULL},
/* 1002C */ { "LINEAR B SYLLABLE B026 RU",NULL},
/* 1002D */ { "LINEAR B SYLLABLE B031 SA","	= ideogram B031 flax"},
/* 1002E */ { "LINEAR B SYLLABLE B009 SE",NULL},
/* 1002F */ { "LINEAR B SYLLABLE B041 SI",NULL},
/* 10030 */ { "LINEAR B SYLLABLE B012 SO",NULL},
/* 10031 */ { "LINEAR B SYLLABLE B058 SU",NULL},
/* 10032 */ { "LINEAR B SYLLABLE B059 TA",NULL},
/* 10033 */ { "LINEAR B SYLLABLE B004 TE",NULL},
/* 10034 */ { "LINEAR B SYLLABLE B037 TI",NULL},
/* 10035 */ { "LINEAR B SYLLABLE B005 TO",NULL},
/* 10036 */ { "LINEAR B SYLLABLE B069 TU",NULL},
/* 10037 */ { "LINEAR B SYLLABLE B054 WA",NULL},
/* 10038 */ { "LINEAR B SYLLABLE B075 WE",NULL},
/* 10039 */ { "LINEAR B SYLLABLE B040 WI",NULL},
/* 1003A */ { "LINEAR B SYLLABLE B042 WO",NULL},
/* 1003B */ { NULL,NULL},
/* 1003C */ { "LINEAR B SYLLABLE B017 ZA",NULL},
/* 1003D */ { "LINEAR B SYLLABLE B074 ZE",NULL},
/* 1003E */ { NULL,NULL},
/* 1003F */ { "LINEAR B SYLLABLE B020 ZO",NULL},
/* 10040 */ { "LINEAR B SYLLABLE B025 A2",NULL},
/* 10041 */ { "LINEAR B SYLLABLE B043 A3",NULL},
/* 10042 */ { "LINEAR B SYLLABLE B085 AU","	= ideogram B108 pig"},
/* 10043 */ { "LINEAR B SYLLABLE B071 DWE",NULL},
/* 10044 */ { "LINEAR B SYLLABLE B090 DWO",NULL},
/* 10045 */ { "LINEAR B SYLLABLE B048 NWA",NULL},
/* 10046 */ { "LINEAR B SYLLABLE B029 PU2",NULL},
/* 10047 */ { "LINEAR B SYLLABLE B062 PTE",NULL},
/* 10048 */ { "LINEAR B SYLLABLE B076 RA2",NULL},
/* 10049 */ { "LINEAR B SYLLABLE B033 RA3","	= ideogram B144 saffron"},
/* 1004A */ { "LINEAR B SYLLABLE B068 RO2",NULL},
/* 1004B */ { "LINEAR B SYLLABLE B066 TA2",NULL},
/* 1004C */ { "LINEAR B SYLLABLE B087 TWE",NULL},
/* 1004D */ { "LINEAR B SYLLABLE B091 TWO",NULL},
/* 1004E */ { NULL,NULL},
/* 1004F */ { NULL,NULL},
/* 10050 */ { "LINEAR B SYMBOL B018",NULL},
/* 10051 */ { "LINEAR B SYMBOL B019",NULL},
/* 10052 */ { "LINEAR B SYMBOL B022","	= ideogram B107 goat"},
/* 10053 */ { "LINEAR B SYMBOL B034",NULL},
/* 10054 */ { "LINEAR B SYMBOL B047",NULL},
/* 10055 */ { "LINEAR B SYMBOL B049",NULL},
/* 10056 */ { "LINEAR B SYMBOL B056",NULL},
/* 10057 */ { "LINEAR B SYMBOL B063",NULL},
/* 10058 */ { "LINEAR B SYMBOL B064",NULL},
/* 10059 */ { "LINEAR B SYMBOL B079",NULL},
/* 1005A */ { "LINEAR B SYMBOL B082",NULL},
/* 1005B */ { "LINEAR B SYMBOL B083",NULL},
/* 1005C */ { "LINEAR B SYMBOL B086",NULL},
/* 1005D */ { "LINEAR B SYMBOL B089",NULL},
/* 1005E */ { NULL,NULL},
/* 1005F */ { NULL,NULL},
/* 10060 */ { NULL,NULL},
/* 10061 */ { NULL,NULL},
/* 10062 */ { NULL,NULL},
/* 10063 */ { NULL,NULL},
/* 10064 */ { NULL,NULL},
/* 10065 */ { NULL,NULL},
/* 10066 */ { NULL,NULL},
/* 10067 */ { NULL,NULL},
/* 10068 */ { NULL,NULL},
/* 10069 */ { NULL,NULL},
/* 1006A */ { NULL,NULL},
/* 1006B */ { NULL,NULL},
/* 1006C */ { NULL,NULL},
/* 1006D */ { NULL,NULL},
/* 1006E */ { NULL,NULL},
/* 1006F */ { NULL,NULL},
/* 10070 */ { NULL,NULL},
/* 10071 */ { NULL,NULL},
/* 10072 */ { NULL,NULL},
/* 10073 */ { NULL,NULL},
/* 10074 */ { NULL,NULL},
/* 10075 */ { NULL,NULL},
/* 10076 */ { NULL,NULL},
/* 10077 */ { NULL,NULL},
/* 10078 */ { NULL,NULL},
/* 10079 */ { NULL,NULL},
/* 1007A */ { NULL,NULL},
/* 1007B */ { NULL,NULL},
/* 1007C */ { NULL,NULL},
/* 1007D */ { NULL,NULL},
/* 1007E */ { NULL,NULL},
/* 1007F */ { NULL,NULL},
/* 10080 */ { "LINEAR B IDEOGRAM B100 MAN",NULL},
/* 10081 */ { "LINEAR B IDEOGRAM B102 WOMAN",NULL},
/* 10082 */ { "LINEAR B IDEOGRAM B104 DEER",NULL},
/* 10083 */ { "LINEAR B IDEOGRAM B105 EQUID",NULL},
/* 10084 */ { "LINEAR B IDEOGRAM B105F MARE",NULL},
/* 10085 */ { "LINEAR B IDEOGRAM B105M STALLION",NULL},
/* 10086 */ { "LINEAR B IDEOGRAM B106F EWE",NULL},
/* 10087 */ { "LINEAR B IDEOGRAM B106M RAM",NULL},
/* 10088 */ { "LINEAR B IDEOGRAM B107F SHE-GOAT",NULL},
/* 10089 */ { "LINEAR B IDEOGRAM B107M HE-GOAT",NULL},
/* 1008A */ { "LINEAR B IDEOGRAM B108F SOW",NULL},
/* 1008B */ { "LINEAR B IDEOGRAM B108M BOAR",NULL},
/* 1008C */ { "LINEAR B IDEOGRAM B109F COW",NULL},
/* 1008D */ { "LINEAR B IDEOGRAM B109M BULL",NULL},
/* 1008E */ { "LINEAR B IDEOGRAM B120 WHEAT",NULL},
/* 1008F */ { "LINEAR B IDEOGRAM B121 BARLEY",NULL},
/* 10090 */ { "LINEAR B IDEOGRAM B122 OLIVE",NULL},
/* 10091 */ { "LINEAR B IDEOGRAM B123 SPICE",NULL},
/* 10092 */ { "LINEAR B IDEOGRAM B125 CYPERUS",NULL},
/* 10093 */ { "LINEAR B MONOGRAM B127 KAPO","	= fruit"},
/* 10094 */ { "LINEAR B MONOGRAM B128 KANAKO","	= saffron"},
/* 10095 */ { "LINEAR B IDEOGRAM B130 OIL",NULL},
/* 10096 */ { "LINEAR B IDEOGRAM B131 WINE",NULL},
/* 10097 */ { "LINEAR B IDEOGRAM B132",NULL},
/* 10098 */ { "LINEAR B MONOGRAM B133 AREPA","	= ointment"},
/* 10099 */ { "LINEAR B MONOGRAM B135 MERI","	= honey"},
/* 1009A */ { "LINEAR B IDEOGRAM B140 BRONZE",NULL},
/* 1009B */ { "LINEAR B IDEOGRAM B141 GOLD",NULL},
/* 1009C */ { "LINEAR B IDEOGRAM B142",NULL},
/* 1009D */ { "LINEAR B IDEOGRAM B145 WOOL",NULL},
/* 1009E */ { "LINEAR B IDEOGRAM B146",NULL},
/* 1009F */ { "LINEAR B IDEOGRAM B150",NULL},
/* 100A0 */ { "LINEAR B IDEOGRAM B151 HORN",NULL},
/* 100A1 */ { "LINEAR B IDEOGRAM B152",NULL},
/* 100A2 */ { "LINEAR B IDEOGRAM B153",NULL},
/* 100A3 */ { "LINEAR B IDEOGRAM B154",NULL},
/* 100A4 */ { "LINEAR B MONOGRAM B156 TURO2","	= cheese"},
/* 100A5 */ { "LINEAR B IDEOGRAM B157",NULL},
/* 100A6 */ { "LINEAR B IDEOGRAM B158",NULL},
/* 100A7 */ { "LINEAR B IDEOGRAM B159 CLOTH",NULL},
/* 100A8 */ { "LINEAR B IDEOGRAM B160",NULL},
/* 100A9 */ { "LINEAR B IDEOGRAM B161",NULL},
/* 100AA */ { "LINEAR B IDEOGRAM B162 GARMENT",NULL},
/* 100AB */ { "LINEAR B IDEOGRAM B163 ARMOUR",NULL},
/* 100AC */ { "LINEAR B IDEOGRAM B164",NULL},
/* 100AD */ { "LINEAR B IDEOGRAM B165",NULL},
/* 100AE */ { "LINEAR B IDEOGRAM B166",NULL},
/* 100AF */ { "LINEAR B IDEOGRAM B167",NULL},
/* 100B0 */ { "LINEAR B IDEOGRAM B168",NULL},
/* 100B1 */ { "LINEAR B IDEOGRAM B169",NULL},
/* 100B2 */ { "LINEAR B IDEOGRAM B170",NULL},
/* 100B3 */ { "LINEAR B IDEOGRAM B171",NULL},
/* 100B4 */ { "LINEAR B IDEOGRAM B172",NULL},
/* 100B5 */ { "LINEAR B IDEOGRAM B173 MONTH",NULL},
/* 100B6 */ { "LINEAR B IDEOGRAM B174",NULL},
/* 100B7 */ { "LINEAR B IDEOGRAM B176 TREE",NULL},
/* 100B8 */ { "LINEAR B IDEOGRAM B177",NULL},
/* 100B9 */ { "LINEAR B IDEOGRAM B178",NULL},
/* 100BA */ { "LINEAR B IDEOGRAM B179",NULL},
/* 100BB */ { "LINEAR B IDEOGRAM B180",NULL},
/* 100BC */ { "LINEAR B IDEOGRAM B181",NULL},
/* 100BD */ { "LINEAR B IDEOGRAM B182",NULL},
/* 100BE */ { "LINEAR B IDEOGRAM B183",NULL},
/* 100BF */ { "LINEAR B IDEOGRAM B184","	* the shape of this ideogram is only partially known"},
/* 100C0 */ { "LINEAR B IDEOGRAM B185",NULL},
/* 100C1 */ { "LINEAR B IDEOGRAM B189",NULL},
/* 100C2 */ { "LINEAR B IDEOGRAM B190",NULL},
/* 100C3 */ { "LINEAR B IDEOGRAM B191 HELMET",NULL},
/* 100C4 */ { "LINEAR B IDEOGRAM B220 FOOTSTOOL",NULL},
/* 100C5 */ { "LINEAR B IDEOGRAM B225 BATHTUB",NULL},
/* 100C6 */ { "LINEAR B IDEOGRAM B230 SPEAR",NULL},
/* 100C7 */ { "LINEAR B IDEOGRAM B231 ARROW",NULL},
/* 100C8 */ { "LINEAR B IDEOGRAM B232",NULL},
/* 100C9 */ { "LINEAR B IDEOGRAM B233 SWORD","	= pugio"},
/* 100CA */ { "LINEAR B IDEOGRAM B234",NULL},
/* 100CB */ { "LINEAR B IDEOGRAM B236","	= \"gupio\", inverted sword"},
/* 100CC */ { "LINEAR B IDEOGRAM B240 WHEELED CHARIOT",NULL},
/* 100CD */ { "LINEAR B IDEOGRAM B241 CHARIOT",NULL},
/* 100CE */ { "LINEAR B IDEOGRAM B242 CHARIOT FRAME",NULL},
/* 100CF */ { "LINEAR B IDEOGRAM B243 WHEEL",NULL},
/* 100D0 */ { "LINEAR B IDEOGRAM B245",NULL},
/* 100D1 */ { "LINEAR B IDEOGRAM B246",NULL},
/* 100D2 */ { "LINEAR B MONOGRAM B247 DIPTE",NULL},
/* 100D3 */ { "LINEAR B IDEOGRAM B248",NULL},
/* 100D4 */ { "LINEAR B IDEOGRAM B249",NULL},
/* 100D5 */ { "LINEAR B IDEOGRAM B251","	* the shape of this ideogram is only partially known"},
/* 100D6 */ { "LINEAR B IDEOGRAM B252","	* the shape of this ideogram is only partially known"},
/* 100D7 */ { "LINEAR B IDEOGRAM B253",NULL},
/* 100D8 */ { "LINEAR B IDEOGRAM B254 DART",NULL},
/* 100D9 */ { "LINEAR B IDEOGRAM B255",NULL},
/* 100DA */ { "LINEAR B IDEOGRAM B256",NULL},
/* 100DB */ { "LINEAR B IDEOGRAM B257",NULL},
/* 100DC */ { "LINEAR B IDEOGRAM B258",NULL},
/* 100DD */ { "LINEAR B IDEOGRAM B259",NULL},
/* 100DE */ { "LINEAR B IDEOGRAM VESSEL B155",NULL},
/* 100DF */ { "LINEAR B IDEOGRAM VESSEL B200",NULL},
/* 100E0 */ { "LINEAR B IDEOGRAM VESSEL B201",NULL},
/* 100E1 */ { "LINEAR B IDEOGRAM VESSEL B202",NULL},
/* 100E2 */ { "LINEAR B IDEOGRAM VESSEL B203",NULL},
/* 100E3 */ { "LINEAR B IDEOGRAM VESSEL B204",NULL},
/* 100E4 */ { "LINEAR B IDEOGRAM VESSEL B205",NULL},
/* 100E5 */ { "LINEAR B IDEOGRAM VESSEL B206",NULL},
/* 100E6 */ { "LINEAR B IDEOGRAM VESSEL B207",NULL},
/* 100E7 */ { "LINEAR B IDEOGRAM VESSEL B208",NULL},
/* 100E8 */ { "LINEAR B IDEOGRAM VESSEL B209","	x (amphora - 1F3FA)"},
/* 100E9 */ { "LINEAR B IDEOGRAM VESSEL B210",NULL},
/* 100EA */ { "LINEAR B IDEOGRAM VESSEL B211",NULL},
/* 100EB */ { "LINEAR B IDEOGRAM VESSEL B212",NULL},
/* 100EC */ { "LINEAR B IDEOGRAM VESSEL B213",NULL},
/* 100ED */ { "LINEAR B IDEOGRAM VESSEL B214",NULL},
/* 100EE */ { "LINEAR B IDEOGRAM VESSEL B215",NULL},
/* 100EF */ { "LINEAR B IDEOGRAM VESSEL B216",NULL},
/* 100F0 */ { "LINEAR B IDEOGRAM VESSEL B217",NULL},
/* 100F1 */ { "LINEAR B IDEOGRAM VESSEL B218",NULL},
/* 100F2 */ { "LINEAR B IDEOGRAM VESSEL B219",NULL},
/* 100F3 */ { "LINEAR B IDEOGRAM VESSEL B221",NULL},
/* 100F4 */ { "LINEAR B IDEOGRAM VESSEL B222",NULL},
/* 100F5 */ { "LINEAR B IDEOGRAM VESSEL B226",NULL},
/* 100F6 */ { "LINEAR B IDEOGRAM VESSEL B227",NULL},
/* 100F7 */ { "LINEAR B IDEOGRAM VESSEL B228",NULL},
/* 100F8 */ { "LINEAR B IDEOGRAM VESSEL B229",NULL},
/* 100F9 */ { "LINEAR B IDEOGRAM VESSEL B250",NULL},
/* 100FA */ { "LINEAR B IDEOGRAM VESSEL B305","	* the shape of this ideogram is only partially known"},
/* 100FB */ { NULL,NULL},
/* 100FC */ { NULL,NULL},
/* 100FD */ { NULL,NULL},
/* 100FE */ { NULL,NULL},
/* 100FF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_01[] = {
/* 10100 */ { "AEGEAN WORD SEPARATOR LINE",NULL},
/* 10101 */ { "AEGEAN WORD SEPARATOR DOT",NULL},
/* 10102 */ { "AEGEAN CHECK MARK",NULL},
/* 10103 */ { NULL,NULL},
/* 10104 */ { NULL,NULL},
/* 10105 */ { NULL,NULL},
/* 10106 */ { NULL,NULL},
/* 10107 */ { "AEGEAN NUMBER ONE",NULL},
/* 10108 */ { "AEGEAN NUMBER TWO",NULL},
/* 10109 */ { "AEGEAN NUMBER THREE",NULL},
/* 1010A */ { "AEGEAN NUMBER FOUR",NULL},
/* 1010B */ { "AEGEAN NUMBER FIVE",NULL},
/* 1010C */ { "AEGEAN NUMBER SIX",NULL},
/* 1010D */ { "AEGEAN NUMBER SEVEN",NULL},
/* 1010E */ { "AEGEAN NUMBER EIGHT",NULL},
/* 1010F */ { "AEGEAN NUMBER NINE",NULL},
/* 10110 */ { "AEGEAN NUMBER TEN",NULL},
/* 10111 */ { "AEGEAN NUMBER TWENTY",NULL},
/* 10112 */ { "AEGEAN NUMBER THIRTY",NULL},
/* 10113 */ { "AEGEAN NUMBER FORTY",NULL},
/* 10114 */ { "AEGEAN NUMBER FIFTY",NULL},
/* 10115 */ { "AEGEAN NUMBER SIXTY",NULL},
/* 10116 */ { "AEGEAN NUMBER SEVENTY",NULL},
/* 10117 */ { "AEGEAN NUMBER EIGHTY",NULL},
/* 10118 */ { "AEGEAN NUMBER NINETY",NULL},
/* 10119 */ { "AEGEAN NUMBER ONE HUNDRED",NULL},
/* 1011A */ { "AEGEAN NUMBER TWO HUNDRED",NULL},
/* 1011B */ { "AEGEAN NUMBER THREE HUNDRED",NULL},
/* 1011C */ { "AEGEAN NUMBER FOUR HUNDRED",NULL},
/* 1011D */ { "AEGEAN NUMBER FIVE HUNDRED",NULL},
/* 1011E */ { "AEGEAN NUMBER SIX HUNDRED",NULL},
/* 1011F */ { "AEGEAN NUMBER SEVEN HUNDRED",NULL},
/* 10120 */ { "AEGEAN NUMBER EIGHT HUNDRED",NULL},
/* 10121 */ { "AEGEAN NUMBER NINE HUNDRED",NULL},
/* 10122 */ { "AEGEAN NUMBER ONE THOUSAND",NULL},
/* 10123 */ { "AEGEAN NUMBER TWO THOUSAND",NULL},
/* 10124 */ { "AEGEAN NUMBER THREE THOUSAND",NULL},
/* 10125 */ { "AEGEAN NUMBER FOUR THOUSAND",NULL},
/* 10126 */ { "AEGEAN NUMBER FIVE THOUSAND",NULL},
/* 10127 */ { "AEGEAN NUMBER SIX THOUSAND",NULL},
/* 10128 */ { "AEGEAN NUMBER SEVEN THOUSAND",NULL},
/* 10129 */ { "AEGEAN NUMBER EIGHT THOUSAND",NULL},
/* 1012A */ { "AEGEAN NUMBER NINE THOUSAND",NULL},
/* 1012B */ { "AEGEAN NUMBER TEN THOUSAND",NULL},
/* 1012C */ { "AEGEAN NUMBER TWENTY THOUSAND",NULL},
/* 1012D */ { "AEGEAN NUMBER THIRTY THOUSAND",NULL},
/* 1012E */ { "AEGEAN NUMBER FORTY THOUSAND",NULL},
/* 1012F */ { "AEGEAN NUMBER FIFTY THOUSAND",NULL},
/* 10130 */ { "AEGEAN NUMBER SIXTY THOUSAND",NULL},
/* 10131 */ { "AEGEAN NUMBER SEVENTY THOUSAND",NULL},
/* 10132 */ { "AEGEAN NUMBER EIGHTY THOUSAND",NULL},
/* 10133 */ { "AEGEAN NUMBER NINETY THOUSAND",NULL},
/* 10134 */ { NULL,NULL},
/* 10135 */ { NULL,NULL},
/* 10136 */ { NULL,NULL},
/* 10137 */ { "AEGEAN WEIGHT BASE UNIT",NULL},
/* 10138 */ { "AEGEAN WEIGHT FIRST SUBUNIT",NULL},
/* 10139 */ { "AEGEAN WEIGHT SECOND SUBUNIT",NULL},
/* 1013A */ { "AEGEAN WEIGHT THIRD SUBUNIT",NULL},
/* 1013B */ { "AEGEAN WEIGHT FOURTH SUBUNIT",NULL},
/* 1013C */ { "AEGEAN DRY MEASURE FIRST SUBUNIT",NULL},
/* 1013D */ { "AEGEAN LIQUID MEASURE FIRST SUBUNIT",NULL},
/* 1013E */ { "AEGEAN MEASURE SECOND SUBUNIT",NULL},
/* 1013F */ { "AEGEAN MEASURE THIRD SUBUNIT",NULL},
/* 10140 */ { "GREEK ACROPHONIC ATTIC ONE QUARTER",NULL},
/* 10141 */ { "GREEK ACROPHONIC ATTIC ONE HALF",NULL},
/* 10142 */ { "GREEK ACROPHONIC ATTIC ONE DRACHMA",NULL},
/* 10143 */ { "GREEK ACROPHONIC ATTIC FIVE",NULL},
/* 10144 */ { "GREEK ACROPHONIC ATTIC FIFTY",NULL},
/* 10145 */ { "GREEK ACROPHONIC ATTIC FIVE HUNDRED",NULL},
/* 10146 */ { "GREEK ACROPHONIC ATTIC FIVE THOUSAND",NULL},
/* 10147 */ { "GREEK ACROPHONIC ATTIC FIFTY THOUSAND",NULL},
/* 10148 */ { "GREEK ACROPHONIC ATTIC FIVE TALENTS",NULL},
/* 10149 */ { "GREEK ACROPHONIC ATTIC TEN TALENTS",NULL},
/* 1014A */ { "GREEK ACROPHONIC ATTIC FIFTY TALENTS",NULL},
/* 1014B */ { "GREEK ACROPHONIC ATTIC ONE HUNDRED TALENTS",NULL},
/* 1014C */ { "GREEK ACROPHONIC ATTIC FIVE HUNDRED TALENTS",NULL},
/* 1014D */ { "GREEK ACROPHONIC ATTIC ONE THOUSAND TALENTS",NULL},
/* 1014E */ { "GREEK ACROPHONIC ATTIC FIVE THOUSAND TALENTS",NULL},
/* 1014F */ { "GREEK ACROPHONIC ATTIC FIVE STATERS",NULL},
/* 10150 */ { "GREEK ACROPHONIC ATTIC TEN STATERS",NULL},
/* 10151 */ { "GREEK ACROPHONIC ATTIC FIFTY STATERS",NULL},
/* 10152 */ { "GREEK ACROPHONIC ATTIC ONE HUNDRED STATERS",NULL},
/* 10153 */ { "GREEK ACROPHONIC ATTIC FIVE HUNDRED STATERS",NULL},
/* 10154 */ { "GREEK ACROPHONIC ATTIC ONE THOUSAND STATERS",NULL},
/* 10155 */ { "GREEK ACROPHONIC ATTIC TEN THOUSAND STATERS",NULL},
/* 10156 */ { "GREEK ACROPHONIC ATTIC FIFTY THOUSAND STATERS",NULL},
/* 10157 */ { "GREEK ACROPHONIC ATTIC TEN MNAS",NULL},
/* 10158 */ { "GREEK ACROPHONIC HERAEUM ONE PLETHRON",NULL},
/* 10159 */ { "GREEK ACROPHONIC THESPIAN ONE",NULL},
/* 1015A */ { "GREEK ACROPHONIC HERMIONIAN ONE",NULL},
/* 1015B */ { "GREEK ACROPHONIC EPIDAUREAN TWO","	x (two dot punctuation - 205A)"},
/* 1015C */ { "GREEK ACROPHONIC THESPIAN TWO",NULL},
/* 1015D */ { "GREEK ACROPHONIC CYRENAIC TWO DRACHMAS",NULL},
/* 1015E */ { "GREEK ACROPHONIC EPIDAUREAN TWO DRACHMAS","	* top line is at cap height, unlike 10111\n"
	"	x (aegean number twenty - 10111)"},
/* 1015F */ { "GREEK ACROPHONIC TROEZENIAN FIVE",NULL},
/* 10160 */ { "GREEK ACROPHONIC TROEZENIAN TEN",NULL},
/* 10161 */ { "GREEK ACROPHONIC TROEZENIAN TEN ALTERNATE FORM",NULL},
/* 10162 */ { "GREEK ACROPHONIC HERMIONIAN TEN",NULL},
/* 10163 */ { "GREEK ACROPHONIC MESSENIAN TEN",NULL},
/* 10164 */ { "GREEK ACROPHONIC THESPIAN TEN",NULL},
/* 10165 */ { "GREEK ACROPHONIC THESPIAN THIRTY",NULL},
/* 10166 */ { "GREEK ACROPHONIC TROEZENIAN FIFTY",NULL},
/* 10167 */ { "GREEK ACROPHONIC TROEZENIAN FIFTY ALTERNATE FORM",NULL},
/* 10168 */ { "GREEK ACROPHONIC HERMIONIAN FIFTY",NULL},
/* 10169 */ { "GREEK ACROPHONIC THESPIAN FIFTY",NULL},
/* 1016A */ { "GREEK ACROPHONIC THESPIAN ONE HUNDRED",NULL},
/* 1016B */ { "GREEK ACROPHONIC THESPIAN THREE HUNDRED",NULL},
/* 1016C */ { "GREEK ACROPHONIC EPIDAUREAN FIVE HUNDRED",NULL},
/* 1016D */ { "GREEK ACROPHONIC TROEZENIAN FIVE HUNDRED",NULL},
/* 1016E */ { "GREEK ACROPHONIC THESPIAN FIVE HUNDRED",NULL},
/* 1016F */ { "GREEK ACROPHONIC CARYSTIAN FIVE HUNDRED",NULL},
/* 10170 */ { "GREEK ACROPHONIC NAXIAN FIVE HUNDRED",NULL},
/* 10171 */ { "GREEK ACROPHONIC THESPIAN ONE THOUSAND",NULL},
/* 10172 */ { "GREEK ACROPHONIC THESPIAN FIVE THOUSAND",NULL},
/* 10173 */ { "GREEK ACROPHONIC DELPHIC FIVE MNAS",NULL},
/* 10174 */ { "GREEK ACROPHONIC STRATIAN FIFTY MNAS",NULL},
/* 10175 */ { "GREEK ONE HALF SIGN",NULL},
/* 10176 */ { "GREEK ONE HALF SIGN ALTERNATE FORM",NULL},
/* 10177 */ { "GREEK TWO THIRDS SIGN",NULL},
/* 10178 */ { "GREEK THREE QUARTERS SIGN",NULL},
/* 10179 */ { "GREEK YEAR SIGN",NULL},
/* 1017A */ { "GREEK TALENT SIGN",NULL},
/* 1017B */ { "GREEK DRACHMA SIGN",NULL},
/* 1017C */ { "GREEK OBOL SIGN",NULL},
/* 1017D */ { "GREEK TWO OBOLS SIGN",NULL},
/* 1017E */ { "GREEK THREE OBOLS SIGN",NULL},
/* 1017F */ { "GREEK FOUR OBOLS SIGN",NULL},
/* 10180 */ { "GREEK FIVE OBOLS SIGN",NULL},
/* 10181 */ { "GREEK METRETES SIGN",NULL},
/* 10182 */ { "GREEK KYATHOS BASE SIGN",NULL},
/* 10183 */ { "GREEK LITRA SIGN",NULL},
/* 10184 */ { "GREEK OUNKIA SIGN",NULL},
/* 10185 */ { "GREEK XESTES SIGN",NULL},
/* 10186 */ { "GREEK ARTABE SIGN",NULL},
/* 10187 */ { "GREEK AROURA SIGN",NULL},
/* 10188 */ { "GREEK GRAMMA SIGN",NULL},
/* 10189 */ { "GREEK TRYBLION BASE SIGN",NULL},
/* 1018A */ { "GREEK ZERO SIGN",NULL},
/* 1018B */ { "GREEK ONE QUARTER SIGN",NULL},
/* 1018C */ { "GREEK SINUSOID SIGN","	* designates year"},
/* 1018D */ { "GREEK INDICTION SIGN","	* timekeeping"},
/* 1018E */ { "NOMISMA SIGN","	* currency sign and marker of weight"},
/* 1018F */ { NULL,NULL},
/* 10190 */ { "ROMAN SEXTANS SIGN","	x (equals sign - 003D)"},
/* 10191 */ { "ROMAN UNCIA SIGN","	x (hyphen-minus - 002D)"},
/* 10192 */ { "ROMAN SEMUNCIA SIGN","	x (pound sign - 00A3)"},
/* 10193 */ { "ROMAN SEXTULA SIGN","	x (cyrillic capital letter reversed dze - A644)"},
/* 10194 */ { "ROMAN DIMIDIA SEXTULA SIGN",NULL},
/* 10195 */ { "ROMAN SILIQUA SIGN",NULL},
/* 10196 */ { "ROMAN DENARIUS SIGN",NULL},
/* 10197 */ { "ROMAN QUINARIUS SIGN",NULL},
/* 10198 */ { "ROMAN SESTERTIUS SIGN",NULL},
/* 10199 */ { "ROMAN DUPONDIUS SIGN",NULL},
/* 1019A */ { "ROMAN AS SIGN","	x (apl functional symbol slash bar - 233F)"},
/* 1019B */ { "ROMAN CENTURIAL SIGN",NULL},
/* 1019C */ { "ASCIA SYMBOL",NULL},
/* 1019D */ { NULL,NULL},
/* 1019E */ { NULL,NULL},
/* 1019F */ { NULL,NULL},
/* 101A0 */ { "GREEK SYMBOL TAU RHO","	= rho-cross, staurogram\n"
	"	x (chi rho - 2627)\n"
	"	x (coptic symbol tau ro - 2CE8)"},
/* 101A1 */ { NULL,NULL},
/* 101A2 */ { NULL,NULL},
/* 101A3 */ { NULL,NULL},
/* 101A4 */ { NULL,NULL},
/* 101A5 */ { NULL,NULL},
/* 101A6 */ { NULL,NULL},
/* 101A7 */ { NULL,NULL},
/* 101A8 */ { NULL,NULL},
/* 101A9 */ { NULL,NULL},
/* 101AA */ { NULL,NULL},
/* 101AB */ { NULL,NULL},
/* 101AC */ { NULL,NULL},
/* 101AD */ { NULL,NULL},
/* 101AE */ { NULL,NULL},
/* 101AF */ { NULL,NULL},
/* 101B0 */ { NULL,NULL},
/* 101B1 */ { NULL,NULL},
/* 101B2 */ { NULL,NULL},
/* 101B3 */ { NULL,NULL},
/* 101B4 */ { NULL,NULL},
/* 101B5 */ { NULL,NULL},
/* 101B6 */ { NULL,NULL},
/* 101B7 */ { NULL,NULL},
/* 101B8 */ { NULL,NULL},
/* 101B9 */ { NULL,NULL},
/* 101BA */ { NULL,NULL},
/* 101BB */ { NULL,NULL},
/* 101BC */ { NULL,NULL},
/* 101BD */ { NULL,NULL},
/* 101BE */ { NULL,NULL},
/* 101BF */ { NULL,NULL},
/* 101C0 */ { NULL,NULL},
/* 101C1 */ { NULL,NULL},
/* 101C2 */ { NULL,NULL},
/* 101C3 */ { NULL,NULL},
/* 101C4 */ { NULL,NULL},
/* 101C5 */ { NULL,NULL},
/* 101C6 */ { NULL,NULL},
/* 101C7 */ { NULL,NULL},
/* 101C8 */ { NULL,NULL},
/* 101C9 */ { NULL,NULL},
/* 101CA */ { NULL,NULL},
/* 101CB */ { NULL,NULL},
/* 101CC */ { NULL,NULL},
/* 101CD */ { NULL,NULL},
/* 101CE */ { NULL,NULL},
/* 101CF */ { NULL,NULL},
/* 101D0 */ { "PHAISTOS DISC SIGN PEDESTRIAN",NULL},
/* 101D1 */ { "PHAISTOS DISC SIGN PLUMED HEAD",NULL},
/* 101D2 */ { "PHAISTOS DISC SIGN TATTOOED HEAD",NULL},
/* 101D3 */ { "PHAISTOS DISC SIGN CAPTIVE",NULL},
/* 101D4 */ { "PHAISTOS DISC SIGN CHILD",NULL},
/* 101D5 */ { "PHAISTOS DISC SIGN WOMAN",NULL},
/* 101D6 */ { "PHAISTOS DISC SIGN HELMET",NULL},
/* 101D7 */ { "PHAISTOS DISC SIGN GAUNTLET",NULL},
/* 101D8 */ { "PHAISTOS DISC SIGN TIARA",NULL},
/* 101D9 */ { "PHAISTOS DISC SIGN ARROW",NULL},
/* 101DA */ { "PHAISTOS DISC SIGN BOW",NULL},
/* 101DB */ { "PHAISTOS DISC SIGN SHIELD",NULL},
/* 101DC */ { "PHAISTOS DISC SIGN CLUB",NULL},
/* 101DD */ { "PHAISTOS DISC SIGN MANACLES",NULL},
/* 101DE */ { "PHAISTOS DISC SIGN MATTOCK",NULL},
/* 101DF */ { "PHAISTOS DISC SIGN SAW",NULL},
/* 101E0 */ { "PHAISTOS DISC SIGN LID",NULL},
/* 101E1 */ { "PHAISTOS DISC SIGN BOOMERANG",NULL},
/* 101E2 */ { "PHAISTOS DISC SIGN CARPENTRY PLANE",NULL},
/* 101E3 */ { "PHAISTOS DISC SIGN DOLIUM",NULL},
/* 101E4 */ { "PHAISTOS DISC SIGN COMB",NULL},
/* 101E5 */ { "PHAISTOS DISC SIGN SLING",NULL},
/* 101E6 */ { "PHAISTOS DISC SIGN COLUMN",NULL},
/* 101E7 */ { "PHAISTOS DISC SIGN BEEHIVE",NULL},
/* 101E8 */ { "PHAISTOS DISC SIGN SHIP",NULL},
/* 101E9 */ { "PHAISTOS DISC SIGN HORN",NULL},
/* 101EA */ { "PHAISTOS DISC SIGN HIDE",NULL},
/* 101EB */ { "PHAISTOS DISC SIGN BULLS LEG",NULL},
/* 101EC */ { "PHAISTOS DISC SIGN CAT",NULL},
/* 101ED */ { "PHAISTOS DISC SIGN RAM",NULL},
/* 101EE */ { "PHAISTOS DISC SIGN EAGLE",NULL},
/* 101EF */ { "PHAISTOS DISC SIGN DOVE",NULL},
/* 101F0 */ { "PHAISTOS DISC SIGN TUNNY",NULL},
/* 101F1 */ { "PHAISTOS DISC SIGN BEE",NULL},
/* 101F2 */ { "PHAISTOS DISC SIGN PLANE TREE",NULL},
/* 101F3 */ { "PHAISTOS DISC SIGN VINE",NULL},
/* 101F4 */ { "PHAISTOS DISC SIGN PAPYRUS",NULL},
/* 101F5 */ { "PHAISTOS DISC SIGN ROSETTE",NULL},
/* 101F6 */ { "PHAISTOS DISC SIGN LILY",NULL},
/* 101F7 */ { "PHAISTOS DISC SIGN OX BACK",NULL},
/* 101F8 */ { "PHAISTOS DISC SIGN FLUTE",NULL},
/* 101F9 */ { "PHAISTOS DISC SIGN GRATER",NULL},
/* 101FA */ { "PHAISTOS DISC SIGN STRAINER",NULL},
/* 101FB */ { "PHAISTOS DISC SIGN SMALL AXE",NULL},
/* 101FC */ { "PHAISTOS DISC SIGN WAVY BAND",NULL},
/* 101FD */ { "PHAISTOS DISC SIGN COMBINING OBLIQUE STROKE",NULL},
/* 101FE */ { NULL,NULL},
/* 101FF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_02[] = {
/* 10200 */ { NULL,NULL},
/* 10201 */ { NULL,NULL},
/* 10202 */ { NULL,NULL},
/* 10203 */ { NULL,NULL},
/* 10204 */ { NULL,NULL},
/* 10205 */ { NULL,NULL},
/* 10206 */ { NULL,NULL},
/* 10207 */ { NULL,NULL},
/* 10208 */ { NULL,NULL},
/* 10209 */ { NULL,NULL},
/* 1020A */ { NULL,NULL},
/* 1020B */ { NULL,NULL},
/* 1020C */ { NULL,NULL},
/* 1020D */ { NULL,NULL},
/* 1020E */ { NULL,NULL},
/* 1020F */ { NULL,NULL},
/* 10210 */ { NULL,NULL},
/* 10211 */ { NULL,NULL},
/* 10212 */ { NULL,NULL},
/* 10213 */ { NULL,NULL},
/* 10214 */ { NULL,NULL},
/* 10215 */ { NULL,NULL},
/* 10216 */ { NULL,NULL},
/* 10217 */ { NULL,NULL},
/* 10218 */ { NULL,NULL},
/* 10219 */ { NULL,NULL},
/* 1021A */ { NULL,NULL},
/* 1021B */ { NULL,NULL},
/* 1021C */ { NULL,NULL},
/* 1021D */ { NULL,NULL},
/* 1021E */ { NULL,NULL},
/* 1021F */ { NULL,NULL},
/* 10220 */ { NULL,NULL},
/* 10221 */ { NULL,NULL},
/* 10222 */ { NULL,NULL},
/* 10223 */ { NULL,NULL},
/* 10224 */ { NULL,NULL},
/* 10225 */ { NULL,NULL},
/* 10226 */ { NULL,NULL},
/* 10227 */ { NULL,NULL},
/* 10228 */ { NULL,NULL},
/* 10229 */ { NULL,NULL},
/* 1022A */ { NULL,NULL},
/* 1022B */ { NULL,NULL},
/* 1022C */ { NULL,NULL},
/* 1022D */ { NULL,NULL},
/* 1022E */ { NULL,NULL},
/* 1022F */ { NULL,NULL},
/* 10230 */ { NULL,NULL},
/* 10231 */ { NULL,NULL},
/* 10232 */ { NULL,NULL},
/* 10233 */ { NULL,NULL},
/* 10234 */ { NULL,NULL},
/* 10235 */ { NULL,NULL},
/* 10236 */ { NULL,NULL},
/* 10237 */ { NULL,NULL},
/* 10238 */ { NULL,NULL},
/* 10239 */ { NULL,NULL},
/* 1023A */ { NULL,NULL},
/* 1023B */ { NULL,NULL},
/* 1023C */ { NULL,NULL},
/* 1023D */ { NULL,NULL},
/* 1023E */ { NULL,NULL},
/* 1023F */ { NULL,NULL},
/* 10240 */ { NULL,NULL},
/* 10241 */ { NULL,NULL},
/* 10242 */ { NULL,NULL},
/* 10243 */ { NULL,NULL},
/* 10244 */ { NULL,NULL},
/* 10245 */ { NULL,NULL},
/* 10246 */ { NULL,NULL},
/* 10247 */ { NULL,NULL},
/* 10248 */ { NULL,NULL},
/* 10249 */ { NULL,NULL},
/* 1024A */ { NULL,NULL},
/* 1024B */ { NULL,NULL},
/* 1024C */ { NULL,NULL},
/* 1024D */ { NULL,NULL},
/* 1024E */ { NULL,NULL},
/* 1024F */ { NULL,NULL},
/* 10250 */ { NULL,NULL},
/* 10251 */ { NULL,NULL},
/* 10252 */ { NULL,NULL},
/* 10253 */ { NULL,NULL},
/* 10254 */ { NULL,NULL},
/* 10255 */ { NULL,NULL},
/* 10256 */ { NULL,NULL},
/* 10257 */ { NULL,NULL},
/* 10258 */ { NULL,NULL},
/* 10259 */ { NULL,NULL},
/* 1025A */ { NULL,NULL},
/* 1025B */ { NULL,NULL},
/* 1025C */ { NULL,NULL},
/* 1025D */ { NULL,NULL},
/* 1025E */ { NULL,NULL},
/* 1025F */ { NULL,NULL},
/* 10260 */ { NULL,NULL},
/* 10261 */ { NULL,NULL},
/* 10262 */ { NULL,NULL},
/* 10263 */ { NULL,NULL},
/* 10264 */ { NULL,NULL},
/* 10265 */ { NULL,NULL},
/* 10266 */ { NULL,NULL},
/* 10267 */ { NULL,NULL},
/* 10268 */ { NULL,NULL},
/* 10269 */ { NULL,NULL},
/* 1026A */ { NULL,NULL},
/* 1026B */ { NULL,NULL},
/* 1026C */ { NULL,NULL},
/* 1026D */ { NULL,NULL},
/* 1026E */ { NULL,NULL},
/* 1026F */ { NULL,NULL},
/* 10270 */ { NULL,NULL},
/* 10271 */ { NULL,NULL},
/* 10272 */ { NULL,NULL},
/* 10273 */ { NULL,NULL},
/* 10274 */ { NULL,NULL},
/* 10275 */ { NULL,NULL},
/* 10276 */ { NULL,NULL},
/* 10277 */ { NULL,NULL},
/* 10278 */ { NULL,NULL},
/* 10279 */ { NULL,NULL},
/* 1027A */ { NULL,NULL},
/* 1027B */ { NULL,NULL},
/* 1027C */ { NULL,NULL},
/* 1027D */ { NULL,NULL},
/* 1027E */ { NULL,NULL},
/* 1027F */ { NULL,NULL},
/* 10280 */ { "LYCIAN LETTER A",NULL},
/* 10281 */ { "LYCIAN LETTER E",NULL},
/* 10282 */ { "LYCIAN LETTER B",NULL},
/* 10283 */ { "LYCIAN LETTER BH",NULL},
/* 10284 */ { "LYCIAN LETTER G",NULL},
/* 10285 */ { "LYCIAN LETTER D",NULL},
/* 10286 */ { "LYCIAN LETTER I",NULL},
/* 10287 */ { "LYCIAN LETTER W",NULL},
/* 10288 */ { "LYCIAN LETTER Z",NULL},
/* 10289 */ { "LYCIAN LETTER TH",NULL},
/* 1028A */ { "LYCIAN LETTER J",NULL},
/* 1028B */ { "LYCIAN LETTER K",NULL},
/* 1028C */ { "LYCIAN LETTER Q",NULL},
/* 1028D */ { "LYCIAN LETTER L",NULL},
/* 1028E */ { "LYCIAN LETTER M",NULL},
/* 1028F */ { "LYCIAN LETTER N",NULL},
/* 10290 */ { "LYCIAN LETTER MM",NULL},
/* 10291 */ { "LYCIAN LETTER NN",NULL},
/* 10292 */ { "LYCIAN LETTER U",NULL},
/* 10293 */ { "LYCIAN LETTER P",NULL},
/* 10294 */ { "LYCIAN LETTER KK",NULL},
/* 10295 */ { "LYCIAN LETTER R",NULL},
/* 10296 */ { "LYCIAN LETTER S",NULL},
/* 10297 */ { "LYCIAN LETTER T",NULL},
/* 10298 */ { "LYCIAN LETTER TT",NULL},
/* 10299 */ { "LYCIAN LETTER AN",NULL},
/* 1029A */ { "LYCIAN LETTER EN",NULL},
/* 1029B */ { "LYCIAN LETTER H",NULL},
/* 1029C */ { "LYCIAN LETTER X",NULL},
/* 1029D */ { NULL,NULL},
/* 1029E */ { NULL,NULL},
/* 1029F */ { NULL,NULL},
/* 102A0 */ { "CARIAN LETTER A",NULL},
/* 102A1 */ { "CARIAN LETTER P2",NULL},
/* 102A2 */ { "CARIAN LETTER D",NULL},
/* 102A3 */ { "CARIAN LETTER L",NULL},
/* 102A4 */ { "CARIAN LETTER UUU",NULL},
/* 102A5 */ { "CARIAN LETTER R",NULL},
/* 102A6 */ { "CARIAN LETTER LD",NULL},
/* 102A7 */ { "CARIAN LETTER A2",NULL},
/* 102A8 */ { "CARIAN LETTER Q",NULL},
/* 102A9 */ { "CARIAN LETTER B",NULL},
/* 102AA */ { "CARIAN LETTER M",NULL},
/* 102AB */ { "CARIAN LETTER O",NULL},
/* 102AC */ { "CARIAN LETTER D2",NULL},
/* 102AD */ { "CARIAN LETTER T",NULL},
/* 102AE */ { "CARIAN LETTER SH",NULL},
/* 102AF */ { "CARIAN LETTER SH2",NULL},
/* 102B0 */ { "CARIAN LETTER S",NULL},
/* 102B1 */ { "CARIAN LETTER C-18",NULL},
/* 102B2 */ { "CARIAN LETTER U",NULL},
/* 102B3 */ { "CARIAN LETTER NN",NULL},
/* 102B4 */ { "CARIAN LETTER X",NULL},
/* 102B5 */ { "CARIAN LETTER N",NULL},
/* 102B6 */ { "CARIAN LETTER TT2",NULL},
/* 102B7 */ { "CARIAN LETTER P",NULL},
/* 102B8 */ { "CARIAN LETTER SS",NULL},
/* 102B9 */ { "CARIAN LETTER I",NULL},
/* 102BA */ { "CARIAN LETTER E",NULL},
/* 102BB */ { "CARIAN LETTER UUUU",NULL},
/* 102BC */ { "CARIAN LETTER K",NULL},
/* 102BD */ { "CARIAN LETTER K2",NULL},
/* 102BE */ { "CARIAN LETTER ND",NULL},
/* 102BF */ { "CARIAN LETTER UU",NULL},
/* 102C0 */ { "CARIAN LETTER G",NULL},
/* 102C1 */ { "CARIAN LETTER G2",NULL},
/* 102C2 */ { "CARIAN LETTER ST",NULL},
/* 102C3 */ { "CARIAN LETTER ST2",NULL},
/* 102C4 */ { "CARIAN LETTER NG",NULL},
/* 102C5 */ { "CARIAN LETTER II",NULL},
/* 102C6 */ { "CARIAN LETTER C-39",NULL},
/* 102C7 */ { "CARIAN LETTER TT",NULL},
/* 102C8 */ { "CARIAN LETTER UUU2",NULL},
/* 102C9 */ { "CARIAN LETTER RR",NULL},
/* 102CA */ { "CARIAN LETTER MB",NULL},
/* 102CB */ { "CARIAN LETTER MB2",NULL},
/* 102CC */ { "CARIAN LETTER MB3",NULL},
/* 102CD */ { "CARIAN LETTER MB4",NULL},
/* 102CE */ { "CARIAN LETTER LD2",NULL},
/* 102CF */ { "CARIAN LETTER E2",NULL},
/* 102D0 */ { "CARIAN LETTER UUU3",NULL},
/* 102D1 */ { NULL,NULL},
/* 102D2 */ { NULL,NULL},
/* 102D3 */ { NULL,NULL},
/* 102D4 */ { NULL,NULL},
/* 102D5 */ { NULL,NULL},
/* 102D6 */ { NULL,NULL},
/* 102D7 */ { NULL,NULL},
/* 102D8 */ { NULL,NULL},
/* 102D9 */ { NULL,NULL},
/* 102DA */ { NULL,NULL},
/* 102DB */ { NULL,NULL},
/* 102DC */ { NULL,NULL},
/* 102DD */ { NULL,NULL},
/* 102DE */ { NULL,NULL},
/* 102DF */ { NULL,NULL},
/* 102E0 */ { "COPTIC EPACT THOUSANDS MARK",NULL},
/* 102E1 */ { "COPTIC EPACT DIGIT ONE",NULL},
/* 102E2 */ { "COPTIC EPACT DIGIT TWO",NULL},
/* 102E3 */ { "COPTIC EPACT DIGIT THREE",NULL},
/* 102E4 */ { "COPTIC EPACT DIGIT FOUR",NULL},
/* 102E5 */ { "COPTIC EPACT DIGIT FIVE",NULL},
/* 102E6 */ { "COPTIC EPACT DIGIT SIX",NULL},
/* 102E7 */ { "COPTIC EPACT DIGIT SEVEN",NULL},
/* 102E8 */ { "COPTIC EPACT DIGIT EIGHT",NULL},
/* 102E9 */ { "COPTIC EPACT DIGIT NINE",NULL},
/* 102EA */ { "COPTIC EPACT NUMBER TEN",NULL},
/* 102EB */ { "COPTIC EPACT NUMBER TWENTY",NULL},
/* 102EC */ { "COPTIC EPACT NUMBER THIRTY",NULL},
/* 102ED */ { "COPTIC EPACT NUMBER FORTY",NULL},
/* 102EE */ { "COPTIC EPACT NUMBER FIFTY",NULL},
/* 102EF */ { "COPTIC EPACT NUMBER SIXTY",NULL},
/* 102F0 */ { "COPTIC EPACT NUMBER SEVENTY",NULL},
/* 102F1 */ { "COPTIC EPACT NUMBER EIGHTY",NULL},
/* 102F2 */ { "COPTIC EPACT NUMBER NINETY",NULL},
/* 102F3 */ { "COPTIC EPACT NUMBER ONE HUNDRED",NULL},
/* 102F4 */ { "COPTIC EPACT NUMBER TWO HUNDRED",NULL},
/* 102F5 */ { "COPTIC EPACT NUMBER THREE HUNDRED",NULL},
/* 102F6 */ { "COPTIC EPACT NUMBER FOUR HUNDRED",NULL},
/* 102F7 */ { "COPTIC EPACT NUMBER FIVE HUNDRED",NULL},
/* 102F8 */ { "COPTIC EPACT NUMBER SIX HUNDRED",NULL},
/* 102F9 */ { "COPTIC EPACT NUMBER SEVEN HUNDRED",NULL},
/* 102FA */ { "COPTIC EPACT NUMBER EIGHT HUNDRED",NULL},
/* 102FB */ { "COPTIC EPACT NUMBER NINE HUNDRED",NULL},
/* 102FC */ { NULL,NULL},
/* 102FD */ { NULL,NULL},
/* 102FE */ { NULL,NULL},
/* 102FF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_03[] = {
/* 10300 */ { "OLD ITALIC LETTER A",NULL},
/* 10301 */ { "OLD ITALIC LETTER BE",NULL},
/* 10302 */ { "OLD ITALIC LETTER KE",NULL},
/* 10303 */ { "OLD ITALIC LETTER DE",NULL},
/* 10304 */ { "OLD ITALIC LETTER E",NULL},
/* 10305 */ { "OLD ITALIC LETTER VE",NULL},
/* 10306 */ { "OLD ITALIC LETTER ZE",NULL},
/* 10307 */ { "OLD ITALIC LETTER HE",NULL},
/* 10308 */ { "OLD ITALIC LETTER THE",NULL},
/* 10309 */ { "OLD ITALIC LETTER I",NULL},
/* 1030A */ { "OLD ITALIC LETTER KA",NULL},
/* 1030B */ { "OLD ITALIC LETTER EL",NULL},
/* 1030C */ { "OLD ITALIC LETTER EM",NULL},
/* 1030D */ { "OLD ITALIC LETTER EN",NULL},
/* 1030E */ { "OLD ITALIC LETTER ESH",NULL},
/* 1030F */ { "OLD ITALIC LETTER O","	* Faliscan"},
/* 10310 */ { "OLD ITALIC LETTER PE",NULL},
/* 10311 */ { "OLD ITALIC LETTER SHE",NULL},
/* 10312 */ { "OLD ITALIC LETTER KU",NULL},
/* 10313 */ { "OLD ITALIC LETTER ER",NULL},
/* 10314 */ { "OLD ITALIC LETTER ES",NULL},
/* 10315 */ { "OLD ITALIC LETTER TE",NULL},
/* 10316 */ { "OLD ITALIC LETTER U",NULL},
/* 10317 */ { "OLD ITALIC LETTER EKS","	* Faliscan"},
/* 10318 */ { "OLD ITALIC LETTER PHE",NULL},
/* 10319 */ { "OLD ITALIC LETTER KHE",NULL},
/* 1031A */ { "OLD ITALIC LETTER EF",NULL},
/* 1031B */ { "OLD ITALIC LETTER ERS",NULL},
/* 1031C */ { "OLD ITALIC LETTER CHE",NULL},
/* 1031D */ { "OLD ITALIC LETTER II",NULL},
/* 1031E */ { "OLD ITALIC LETTER UU",NULL},
/* 1031F */ { "OLD ITALIC LETTER ESS",NULL},
/* 10320 */ { "OLD ITALIC NUMERAL ONE",NULL},
/* 10321 */ { "OLD ITALIC NUMERAL FIVE",NULL},
/* 10322 */ { "OLD ITALIC NUMERAL TEN",NULL},
/* 10323 */ { "OLD ITALIC NUMERAL FIFTY",NULL},
/* 10324 */ { NULL,NULL},
/* 10325 */ { NULL,NULL},
/* 10326 */ { NULL,NULL},
/* 10327 */ { NULL,NULL},
/* 10328 */ { NULL,NULL},
/* 10329 */ { NULL,NULL},
/* 1032A */ { NULL,NULL},
/* 1032B */ { NULL,NULL},
/* 1032C */ { NULL,NULL},
/* 1032D */ { "OLD ITALIC LETTER YE",NULL},
/* 1032E */ { "OLD ITALIC LETTER NORTHERN TSE",NULL},
/* 1032F */ { "OLD ITALIC LETTER SOUTHERN TSE",NULL},
/* 10330 */ { "GOTHIC LETTER AHSA",NULL},
/* 10331 */ { "GOTHIC LETTER BAIRKAN",NULL},
/* 10332 */ { "GOTHIC LETTER GIBA",NULL},
/* 10333 */ { "GOTHIC LETTER DAGS",NULL},
/* 10334 */ { "GOTHIC LETTER AIHVUS",NULL},
/* 10335 */ { "GOTHIC LETTER QAIRTHRA",NULL},
/* 10336 */ { "GOTHIC LETTER IUJA",NULL},
/* 10337 */ { "GOTHIC LETTER HAGL",NULL},
/* 10338 */ { "GOTHIC LETTER THIUTH",NULL},
/* 10339 */ { "GOTHIC LETTER EIS",NULL},
/* 1033A */ { "GOTHIC LETTER KUSMA",NULL},
/* 1033B */ { "GOTHIC LETTER LAGUS",NULL},
/* 1033C */ { "GOTHIC LETTER MANNA",NULL},
/* 1033D */ { "GOTHIC LETTER NAUTHS",NULL},
/* 1033E */ { "GOTHIC LETTER JER",NULL},
/* 1033F */ { "GOTHIC LETTER URUS",NULL},
/* 10340 */ { "GOTHIC LETTER PAIRTHRA",NULL},
/* 10341 */ { "GOTHIC LETTER NINETY",NULL},
/* 10342 */ { "GOTHIC LETTER RAIDA",NULL},
/* 10343 */ { "GOTHIC LETTER SAUIL",NULL},
/* 10344 */ { "GOTHIC LETTER TEIWS",NULL},
/* 10345 */ { "GOTHIC LETTER WINJA",NULL},
/* 10346 */ { "GOTHIC LETTER FAIHU",NULL},
/* 10347 */ { "GOTHIC LETTER IGGWS",NULL},
/* 10348 */ { "GOTHIC LETTER HWAIR",NULL},
/* 10349 */ { "GOTHIC LETTER OTHAL",NULL},
/* 1034A */ { "GOTHIC LETTER NINE HUNDRED",NULL},
/* 1034B */ { NULL,NULL},
/* 1034C */ { NULL,NULL},
/* 1034D */ { NULL,NULL},
/* 1034E */ { NULL,NULL},
/* 1034F */ { NULL,NULL},
/* 10350 */ { "OLD PERMIC LETTER AN",NULL},
/* 10351 */ { "OLD PERMIC LETTER BUR",NULL},
/* 10352 */ { "OLD PERMIC LETTER GAI",NULL},
/* 10353 */ { "OLD PERMIC LETTER DOI",NULL},
/* 10354 */ { "OLD PERMIC LETTER E",NULL},
/* 10355 */ { "OLD PERMIC LETTER ZHOI",NULL},
/* 10356 */ { "OLD PERMIC LETTER DZHOI",NULL},
/* 10357 */ { "OLD PERMIC LETTER ZATA",NULL},
/* 10358 */ { "OLD PERMIC LETTER DZITA",NULL},
/* 10359 */ { "OLD PERMIC LETTER I",NULL},
/* 1035A */ { "OLD PERMIC LETTER KOKE",NULL},
/* 1035B */ { "OLD PERMIC LETTER LEI",NULL},
/* 1035C */ { "OLD PERMIC LETTER MENOE",NULL},
/* 1035D */ { "OLD PERMIC LETTER NENOE",NULL},
/* 1035E */ { "OLD PERMIC LETTER VOOI",NULL},
/* 1035F */ { "OLD PERMIC LETTER PEEI",NULL},
/* 10360 */ { "OLD PERMIC LETTER REI",NULL},
/* 10361 */ { "OLD PERMIC LETTER SII",NULL},
/* 10362 */ { "OLD PERMIC LETTER TAI",NULL},
/* 10363 */ { "OLD PERMIC LETTER U",NULL},
/* 10364 */ { "OLD PERMIC LETTER CHERY",NULL},
/* 10365 */ { "OLD PERMIC LETTER SHOOI",NULL},
/* 10366 */ { "OLD PERMIC LETTER SHCHOOI",NULL},
/* 10367 */ { "OLD PERMIC LETTER YRY",NULL},
/* 10368 */ { "OLD PERMIC LETTER YERU",NULL},
/* 10369 */ { "OLD PERMIC LETTER O",NULL},
/* 1036A */ { "OLD PERMIC LETTER OO",NULL},
/* 1036B */ { "OLD PERMIC LETTER EF",NULL},
/* 1036C */ { "OLD PERMIC LETTER HA",NULL},
/* 1036D */ { "OLD PERMIC LETTER TSIU",NULL},
/* 1036E */ { "OLD PERMIC LETTER VER",NULL},
/* 1036F */ { "OLD PERMIC LETTER YER",NULL},
/* 10370 */ { "OLD PERMIC LETTER YERI",NULL},
/* 10371 */ { "OLD PERMIC LETTER YAT",NULL},
/* 10372 */ { "OLD PERMIC LETTER IE",NULL},
/* 10373 */ { "OLD PERMIC LETTER YU",NULL},
/* 10374 */ { "OLD PERMIC LETTER YA",NULL},
/* 10375 */ { "OLD PERMIC LETTER IA",NULL},
/* 10376 */ { "COMBINING OLD PERMIC LETTER AN",NULL},
/* 10377 */ { "COMBINING OLD PERMIC LETTER DOI",NULL},
/* 10378 */ { "COMBINING OLD PERMIC LETTER ZATA",NULL},
/* 10379 */ { "COMBINING OLD PERMIC LETTER NENOE",NULL},
/* 1037A */ { "COMBINING OLD PERMIC LETTER SII",NULL},
/* 1037B */ { NULL,NULL},
/* 1037C */ { NULL,NULL},
/* 1037D */ { NULL,NULL},
/* 1037E */ { NULL,NULL},
/* 1037F */ { NULL,NULL},
/* 10380 */ { "UGARITIC LETTER ALPA",NULL},
/* 10381 */ { "UGARITIC LETTER BETA",NULL},
/* 10382 */ { "UGARITIC LETTER GAMLA",NULL},
/* 10383 */ { "UGARITIC LETTER KHA",NULL},
/* 10384 */ { "UGARITIC LETTER DELTA",NULL},
/* 10385 */ { "UGARITIC LETTER HO",NULL},
/* 10386 */ { "UGARITIC LETTER WO",NULL},
/* 10387 */ { "UGARITIC LETTER ZETA",NULL},
/* 10388 */ { "UGARITIC LETTER HOTA",NULL},
/* 10389 */ { "UGARITIC LETTER TET",NULL},
/* 1038A */ { "UGARITIC LETTER YOD",NULL},
/* 1038B */ { "UGARITIC LETTER KAF",NULL},
/* 1038C */ { "UGARITIC LETTER SHIN",NULL},
/* 1038D */ { "UGARITIC LETTER LAMDA",NULL},
/* 1038E */ { "UGARITIC LETTER MEM",NULL},
/* 1038F */ { "UGARITIC LETTER DHAL",NULL},
/* 10390 */ { "UGARITIC LETTER NUN",NULL},
/* 10391 */ { "UGARITIC LETTER ZU",NULL},
/* 10392 */ { "UGARITIC LETTER SAMKA",NULL},
/* 10393 */ { "UGARITIC LETTER AIN",NULL},
/* 10394 */ { "UGARITIC LETTER PU",NULL},
/* 10395 */ { "UGARITIC LETTER SADE",NULL},
/* 10396 */ { "UGARITIC LETTER QOPA",NULL},
/* 10397 */ { "UGARITIC LETTER RASHA",NULL},
/* 10398 */ { "UGARITIC LETTER THANNA",NULL},
/* 10399 */ { "UGARITIC LETTER GHAIN",NULL},
/* 1039A */ { "UGARITIC LETTER TO",NULL},
/* 1039B */ { "UGARITIC LETTER I",NULL},
/* 1039C */ { "UGARITIC LETTER U",NULL},
/* 1039D */ { "UGARITIC LETTER SSU",NULL},
/* 1039E */ { NULL,NULL},
/* 1039F */ { "UGARITIC WORD DIVIDER",NULL},
/* 103A0 */ { "OLD PERSIAN SIGN A",NULL},
/* 103A1 */ { "OLD PERSIAN SIGN I",NULL},
/* 103A2 */ { "OLD PERSIAN SIGN U",NULL},
/* 103A3 */ { "OLD PERSIAN SIGN KA",NULL},
/* 103A4 */ { "OLD PERSIAN SIGN KU",NULL},
/* 103A5 */ { "OLD PERSIAN SIGN GA",NULL},
/* 103A6 */ { "OLD PERSIAN SIGN GU",NULL},
/* 103A7 */ { "OLD PERSIAN SIGN XA",NULL},
/* 103A8 */ { "OLD PERSIAN SIGN CA",NULL},
/* 103A9 */ { "OLD PERSIAN SIGN JA",NULL},
/* 103AA */ { "OLD PERSIAN SIGN JI",NULL},
/* 103AB */ { "OLD PERSIAN SIGN TA",NULL},
/* 103AC */ { "OLD PERSIAN SIGN TU",NULL},
/* 103AD */ { "OLD PERSIAN SIGN DA",NULL},
/* 103AE */ { "OLD PERSIAN SIGN DI",NULL},
/* 103AF */ { "OLD PERSIAN SIGN DU",NULL},
/* 103B0 */ { "OLD PERSIAN SIGN THA",NULL},
/* 103B1 */ { "OLD PERSIAN SIGN PA",NULL},
/* 103B2 */ { "OLD PERSIAN SIGN BA",NULL},
/* 103B3 */ { "OLD PERSIAN SIGN FA",NULL},
/* 103B4 */ { "OLD PERSIAN SIGN NA",NULL},
/* 103B5 */ { "OLD PERSIAN SIGN NU",NULL},
/* 103B6 */ { "OLD PERSIAN SIGN MA",NULL},
/* 103B7 */ { "OLD PERSIAN SIGN MI",NULL},
/* 103B8 */ { "OLD PERSIAN SIGN MU",NULL},
/* 103B9 */ { "OLD PERSIAN SIGN YA",NULL},
/* 103BA */ { "OLD PERSIAN SIGN VA",NULL},
/* 103BB */ { "OLD PERSIAN SIGN VI",NULL},
/* 103BC */ { "OLD PERSIAN SIGN RA",NULL},
/* 103BD */ { "OLD PERSIAN SIGN RU",NULL},
/* 103BE */ { "OLD PERSIAN SIGN LA",NULL},
/* 103BF */ { "OLD PERSIAN SIGN SA",NULL},
/* 103C0 */ { "OLD PERSIAN SIGN ZA",NULL},
/* 103C1 */ { "OLD PERSIAN SIGN SHA",NULL},
/* 103C2 */ { "OLD PERSIAN SIGN SSA",NULL},
/* 103C3 */ { "OLD PERSIAN SIGN HA",NULL},
/* 103C4 */ { NULL,NULL},
/* 103C5 */ { NULL,NULL},
/* 103C6 */ { NULL,NULL},
/* 103C7 */ { NULL,NULL},
/* 103C8 */ { "OLD PERSIAN SIGN AURAMAZDAA",NULL},
/* 103C9 */ { "OLD PERSIAN SIGN AURAMAZDAA-2",NULL},
/* 103CA */ { "OLD PERSIAN SIGN AURAMAZDAAHA",NULL},
/* 103CB */ { "OLD PERSIAN SIGN XSHAAYATHIYA",NULL},
/* 103CC */ { "OLD PERSIAN SIGN DAHYAAUSH",NULL},
/* 103CD */ { "OLD PERSIAN SIGN DAHYAAUSH-2",NULL},
/* 103CE */ { "OLD PERSIAN SIGN BAGA",NULL},
/* 103CF */ { "OLD PERSIAN SIGN BUUMISH",NULL},
/* 103D0 */ { "OLD PERSIAN WORD DIVIDER",NULL},
/* 103D1 */ { "OLD PERSIAN NUMBER ONE",NULL},
/* 103D2 */ { "OLD PERSIAN NUMBER TWO",NULL},
/* 103D3 */ { "OLD PERSIAN NUMBER TEN",NULL},
/* 103D4 */ { "OLD PERSIAN NUMBER TWENTY",NULL},
/* 103D5 */ { "OLD PERSIAN NUMBER HUNDRED",NULL},
/* 103D6 */ { NULL,NULL},
/* 103D7 */ { NULL,NULL},
/* 103D8 */ { NULL,NULL},
/* 103D9 */ { NULL,NULL},
/* 103DA */ { NULL,NULL},
/* 103DB */ { NULL,NULL},
/* 103DC */ { NULL,NULL},
/* 103DD */ { NULL,NULL},
/* 103DE */ { NULL,NULL},
/* 103DF */ { NULL,NULL},
/* 103E0 */ { NULL,NULL},
/* 103E1 */ { NULL,NULL},
/* 103E2 */ { NULL,NULL},
/* 103E3 */ { NULL,NULL},
/* 103E4 */ { NULL,NULL},
/* 103E5 */ { NULL,NULL},
/* 103E6 */ { NULL,NULL},
/* 103E7 */ { NULL,NULL},
/* 103E8 */ { NULL,NULL},
/* 103E9 */ { NULL,NULL},
/* 103EA */ { NULL,NULL},
/* 103EB */ { NULL,NULL},
/* 103EC */ { NULL,NULL},
/* 103ED */ { NULL,NULL},
/* 103EE */ { NULL,NULL},
/* 103EF */ { NULL,NULL},
/* 103F0 */ { NULL,NULL},
/* 103F1 */ { NULL,NULL},
/* 103F2 */ { NULL,NULL},
/* 103F3 */ { NULL,NULL},
/* 103F4 */ { NULL,NULL},
/* 103F5 */ { NULL,NULL},
/* 103F6 */ { NULL,NULL},
/* 103F7 */ { NULL,NULL},
/* 103F8 */ { NULL,NULL},
/* 103F9 */ { NULL,NULL},
/* 103FA */ { NULL,NULL},
/* 103FB */ { NULL,NULL},
/* 103FC */ { NULL,NULL},
/* 103FD */ { NULL,NULL},
/* 103FE */ { NULL,NULL},
/* 103FF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_04[] = {
/* 10400 */ { "DESERET CAPITAL LETTER LONG I",NULL},
/* 10401 */ { "DESERET CAPITAL LETTER LONG E",NULL},
/* 10402 */ { "DESERET CAPITAL LETTER LONG A",NULL},
/* 10403 */ { "DESERET CAPITAL LETTER LONG AH",NULL},
/* 10404 */ { "DESERET CAPITAL LETTER LONG O",NULL},
/* 10405 */ { "DESERET CAPITAL LETTER LONG OO",NULL},
/* 10406 */ { "DESERET CAPITAL LETTER SHORT I",NULL},
/* 10407 */ { "DESERET CAPITAL LETTER SHORT E",NULL},
/* 10408 */ { "DESERET CAPITAL LETTER SHORT A",NULL},
/* 10409 */ { "DESERET CAPITAL LETTER SHORT AH",NULL},
/* 1040A */ { "DESERET CAPITAL LETTER SHORT O",NULL},
/* 1040B */ { "DESERET CAPITAL LETTER SHORT OO",NULL},
/* 1040C */ { "DESERET CAPITAL LETTER AY",NULL},
/* 1040D */ { "DESERET CAPITAL LETTER OW",NULL},
/* 1040E */ { "DESERET CAPITAL LETTER WU",NULL},
/* 1040F */ { "DESERET CAPITAL LETTER YEE",NULL},
/* 10410 */ { "DESERET CAPITAL LETTER H",NULL},
/* 10411 */ { "DESERET CAPITAL LETTER PEE",NULL},
/* 10412 */ { "DESERET CAPITAL LETTER BEE",NULL},
/* 10413 */ { "DESERET CAPITAL LETTER TEE",NULL},
/* 10414 */ { "DESERET CAPITAL LETTER DEE",NULL},
/* 10415 */ { "DESERET CAPITAL LETTER CHEE",NULL},
/* 10416 */ { "DESERET CAPITAL LETTER JEE",NULL},
/* 10417 */ { "DESERET CAPITAL LETTER KAY",NULL},
/* 10418 */ { "DESERET CAPITAL LETTER GAY",NULL},
/* 10419 */ { "DESERET CAPITAL LETTER EF",NULL},
/* 1041A */ { "DESERET CAPITAL LETTER VEE",NULL},
/* 1041B */ { "DESERET CAPITAL LETTER ETH",NULL},
/* 1041C */ { "DESERET CAPITAL LETTER THEE",NULL},
/* 1041D */ { "DESERET CAPITAL LETTER ES",NULL},
/* 1041E */ { "DESERET CAPITAL LETTER ZEE",NULL},
/* 1041F */ { "DESERET CAPITAL LETTER ESH",NULL},
/* 10420 */ { "DESERET CAPITAL LETTER ZHEE",NULL},
/* 10421 */ { "DESERET CAPITAL LETTER ER",NULL},
/* 10422 */ { "DESERET CAPITAL LETTER EL",NULL},
/* 10423 */ { "DESERET CAPITAL LETTER EM",NULL},
/* 10424 */ { "DESERET CAPITAL LETTER EN",NULL},
/* 10425 */ { "DESERET CAPITAL LETTER ENG",NULL},
/* 10426 */ { "DESERET CAPITAL LETTER OI",NULL},
/* 10427 */ { "DESERET CAPITAL LETTER EW",NULL},
/* 10428 */ { "DESERET SMALL LETTER LONG I",NULL},
/* 10429 */ { "DESERET SMALL LETTER LONG E",NULL},
/* 1042A */ { "DESERET SMALL LETTER LONG A",NULL},
/* 1042B */ { "DESERET SMALL LETTER LONG AH",NULL},
/* 1042C */ { "DESERET SMALL LETTER LONG O",NULL},
/* 1042D */ { "DESERET SMALL LETTER LONG OO",NULL},
/* 1042E */ { "DESERET SMALL LETTER SHORT I",NULL},
/* 1042F */ { "DESERET SMALL LETTER SHORT E",NULL},
/* 10430 */ { "DESERET SMALL LETTER SHORT A",NULL},
/* 10431 */ { "DESERET SMALL LETTER SHORT AH",NULL},
/* 10432 */ { "DESERET SMALL LETTER SHORT O",NULL},
/* 10433 */ { "DESERET SMALL LETTER SHORT OO",NULL},
/* 10434 */ { "DESERET SMALL LETTER AY",NULL},
/* 10435 */ { "DESERET SMALL LETTER OW",NULL},
/* 10436 */ { "DESERET SMALL LETTER WU",NULL},
/* 10437 */ { "DESERET SMALL LETTER YEE",NULL},
/* 10438 */ { "DESERET SMALL LETTER H",NULL},
/* 10439 */ { "DESERET SMALL LETTER PEE",NULL},
/* 1043A */ { "DESERET SMALL LETTER BEE",NULL},
/* 1043B */ { "DESERET SMALL LETTER TEE",NULL},
/* 1043C */ { "DESERET SMALL LETTER DEE",NULL},
/* 1043D */ { "DESERET SMALL LETTER CHEE",NULL},
/* 1043E */ { "DESERET SMALL LETTER JEE",NULL},
/* 1043F */ { "DESERET SMALL LETTER KAY",NULL},
/* 10440 */ { "DESERET SMALL LETTER GAY",NULL},
/* 10441 */ { "DESERET SMALL LETTER EF",NULL},
/* 10442 */ { "DESERET SMALL LETTER VEE",NULL},
/* 10443 */ { "DESERET SMALL LETTER ETH",NULL},
/* 10444 */ { "DESERET SMALL LETTER THEE",NULL},
/* 10445 */ { "DESERET SMALL LETTER ES",NULL},
/* 10446 */ { "DESERET SMALL LETTER ZEE",NULL},
/* 10447 */ { "DESERET SMALL LETTER ESH",NULL},
/* 10448 */ { "DESERET SMALL LETTER ZHEE",NULL},
/* 10449 */ { "DESERET SMALL LETTER ER",NULL},
/* 1044A */ { "DESERET SMALL LETTER EL",NULL},
/* 1044B */ { "DESERET SMALL LETTER EM",NULL},
/* 1044C */ { "DESERET SMALL LETTER EN",NULL},
/* 1044D */ { "DESERET SMALL LETTER ENG",NULL},
/* 1044E */ { "DESERET SMALL LETTER OI",NULL},
/* 1044F */ { "DESERET SMALL LETTER EW",NULL},
/* 10450 */ { "SHAVIAN LETTER PEEP",NULL},
/* 10451 */ { "SHAVIAN LETTER TOT",NULL},
/* 10452 */ { "SHAVIAN LETTER KICK",NULL},
/* 10453 */ { "SHAVIAN LETTER FEE",NULL},
/* 10454 */ { "SHAVIAN LETTER THIGH",NULL},
/* 10455 */ { "SHAVIAN LETTER SO",NULL},
/* 10456 */ { "SHAVIAN LETTER SURE",NULL},
/* 10457 */ { "SHAVIAN LETTER CHURCH",NULL},
/* 10458 */ { "SHAVIAN LETTER YEA","	* voiced palatal approximant"},
/* 10459 */ { "SHAVIAN LETTER HUNG","	* voiced velar nasal"},
/* 1045A */ { "SHAVIAN LETTER BIB",NULL},
/* 1045B */ { "SHAVIAN LETTER DEAD",NULL},
/* 1045C */ { "SHAVIAN LETTER GAG",NULL},
/* 1045D */ { "SHAVIAN LETTER VOW",NULL},
/* 1045E */ { "SHAVIAN LETTER THEY",NULL},
/* 1045F */ { "SHAVIAN LETTER ZOO",NULL},
/* 10460 */ { "SHAVIAN LETTER MEASURE",NULL},
/* 10461 */ { "SHAVIAN LETTER JUDGE",NULL},
/* 10462 */ { "SHAVIAN LETTER WOE","	* voiced labiovelar approximant"},
/* 10463 */ { "SHAVIAN LETTER HA-HA","	* voiceless glottal fricative"},
/* 10464 */ { "SHAVIAN LETTER LOLL",NULL},
/* 10465 */ { "SHAVIAN LETTER MIME",NULL},
/* 10466 */ { "SHAVIAN LETTER IF",NULL},
/* 10467 */ { "SHAVIAN LETTER EGG",NULL},
/* 10468 */ { "SHAVIAN LETTER ASH",NULL},
/* 10469 */ { "SHAVIAN LETTER ADO",NULL},
/* 1046A */ { "SHAVIAN LETTER ON",NULL},
/* 1046B */ { "SHAVIAN LETTER WOOL",NULL},
/* 1046C */ { "SHAVIAN LETTER OUT",NULL},
/* 1046D */ { "SHAVIAN LETTER AH",NULL},
/* 1046E */ { "SHAVIAN LETTER ROAR",NULL},
/* 1046F */ { "SHAVIAN LETTER NUN",NULL},
/* 10470 */ { "SHAVIAN LETTER EAT",NULL},
/* 10471 */ { "SHAVIAN LETTER AGE",NULL},
/* 10472 */ { "SHAVIAN LETTER ICE",NULL},
/* 10473 */ { "SHAVIAN LETTER UP",NULL},
/* 10474 */ { "SHAVIAN LETTER OAK",NULL},
/* 10475 */ { "SHAVIAN LETTER OOZE",NULL},
/* 10476 */ { "SHAVIAN LETTER OIL",NULL},
/* 10477 */ { "SHAVIAN LETTER AWE",NULL},
/* 10478 */ { "SHAVIAN LETTER ARE",NULL},
/* 10479 */ { "SHAVIAN LETTER OR",NULL},
/* 1047A */ { "SHAVIAN LETTER AIR",NULL},
/* 1047B */ { "SHAVIAN LETTER ERR",NULL},
/* 1047C */ { "SHAVIAN LETTER ARRAY",NULL},
/* 1047D */ { "SHAVIAN LETTER EAR",NULL},
/* 1047E */ { "SHAVIAN LETTER IAN",NULL},
/* 1047F */ { "SHAVIAN LETTER YEW",NULL},
/* 10480 */ { "OSMANYA LETTER ALEF",NULL},
/* 10481 */ { "OSMANYA LETTER BA",NULL},
/* 10482 */ { "OSMANYA LETTER TA",NULL},
/* 10483 */ { "OSMANYA LETTER JA",NULL},
/* 10484 */ { "OSMANYA LETTER XA",NULL},
/* 10485 */ { "OSMANYA LETTER KHA",NULL},
/* 10486 */ { "OSMANYA LETTER DEEL",NULL},
/* 10487 */ { "OSMANYA LETTER RA",NULL},
/* 10488 */ { "OSMANYA LETTER SA",NULL},
/* 10489 */ { "OSMANYA LETTER SHIIN",NULL},
/* 1048A */ { "OSMANYA LETTER DHA",NULL},
/* 1048B */ { "OSMANYA LETTER CAYN",NULL},
/* 1048C */ { "OSMANYA LETTER GA",NULL},
/* 1048D */ { "OSMANYA LETTER FA",NULL},
/* 1048E */ { "OSMANYA LETTER QAAF",NULL},
/* 1048F */ { "OSMANYA LETTER KAAF",NULL},
/* 10490 */ { "OSMANYA LETTER LAAN",NULL},
/* 10491 */ { "OSMANYA LETTER MIIN",NULL},
/* 10492 */ { "OSMANYA LETTER NUUN",NULL},
/* 10493 */ { "OSMANYA LETTER WAW",NULL},
/* 10494 */ { "OSMANYA LETTER HA",NULL},
/* 10495 */ { "OSMANYA LETTER YA",NULL},
/* 10496 */ { "OSMANYA LETTER A",NULL},
/* 10497 */ { "OSMANYA LETTER E",NULL},
/* 10498 */ { "OSMANYA LETTER I",NULL},
/* 10499 */ { "OSMANYA LETTER O",NULL},
/* 1049A */ { "OSMANYA LETTER U",NULL},
/* 1049B */ { "OSMANYA LETTER AA",NULL},
/* 1049C */ { "OSMANYA LETTER EE",NULL},
/* 1049D */ { "OSMANYA LETTER OO",NULL},
/* 1049E */ { NULL,NULL},
/* 1049F */ { NULL,NULL},
/* 104A0 */ { "OSMANYA DIGIT ZERO",NULL},
/* 104A1 */ { "OSMANYA DIGIT ONE",NULL},
/* 104A2 */ { "OSMANYA DIGIT TWO",NULL},
/* 104A3 */ { "OSMANYA DIGIT THREE",NULL},
/* 104A4 */ { "OSMANYA DIGIT FOUR",NULL},
/* 104A5 */ { "OSMANYA DIGIT FIVE",NULL},
/* 104A6 */ { "OSMANYA DIGIT SIX",NULL},
/* 104A7 */ { "OSMANYA DIGIT SEVEN",NULL},
/* 104A8 */ { "OSMANYA DIGIT EIGHT",NULL},
/* 104A9 */ { "OSMANYA DIGIT NINE",NULL},
/* 104AA */ { NULL,NULL},
/* 104AB */ { NULL,NULL},
/* 104AC */ { NULL,NULL},
/* 104AD */ { NULL,NULL},
/* 104AE */ { NULL,NULL},
/* 104AF */ { NULL,NULL},
/* 104B0 */ { "OSAGE CAPITAL LETTER A",NULL},
/* 104B1 */ { "OSAGE CAPITAL LETTER AI",NULL},
/* 104B2 */ { "OSAGE CAPITAL LETTER AIN",NULL},
/* 104B3 */ { "OSAGE CAPITAL LETTER AH",NULL},
/* 104B4 */ { "OSAGE CAPITAL LETTER BRA",NULL},
/* 104B5 */ { "OSAGE CAPITAL LETTER CHA",NULL},
/* 104B6 */ { "OSAGE CAPITAL LETTER EHCHA",NULL},
/* 104B7 */ { "OSAGE CAPITAL LETTER E",NULL},
/* 104B8 */ { "OSAGE CAPITAL LETTER EIN",NULL},
/* 104B9 */ { "OSAGE CAPITAL LETTER HA",NULL},
/* 104BA */ { "OSAGE CAPITAL LETTER HYA",NULL},
/* 104BB */ { "OSAGE CAPITAL LETTER I",NULL},
/* 104BC */ { "OSAGE CAPITAL LETTER KA",NULL},
/* 104BD */ { "OSAGE CAPITAL LETTER EHKA",NULL},
/* 104BE */ { "OSAGE CAPITAL LETTER KYA",NULL},
/* 104BF */ { "OSAGE CAPITAL LETTER LA",NULL},
/* 104C0 */ { "OSAGE CAPITAL LETTER MA",NULL},
/* 104C1 */ { "OSAGE CAPITAL LETTER NA",NULL},
/* 104C2 */ { "OSAGE CAPITAL LETTER O",NULL},
/* 104C3 */ { "OSAGE CAPITAL LETTER OIN",NULL},
/* 104C4 */ { "OSAGE CAPITAL LETTER PA",NULL},
/* 104C5 */ { "OSAGE CAPITAL LETTER EHPA",NULL},
/* 104C6 */ { "OSAGE CAPITAL LETTER SA",NULL},
/* 104C7 */ { "OSAGE CAPITAL LETTER SHA",NULL},
/* 104C8 */ { "OSAGE CAPITAL LETTER TA",NULL},
/* 104C9 */ { "OSAGE CAPITAL LETTER EHTA",NULL},
/* 104CA */ { "OSAGE CAPITAL LETTER TSA",NULL},
/* 104CB */ { "OSAGE CAPITAL LETTER EHTSA",NULL},
/* 104CC */ { "OSAGE CAPITAL LETTER TSHA",NULL},
/* 104CD */ { "OSAGE CAPITAL LETTER DHA",NULL},
/* 104CE */ { "OSAGE CAPITAL LETTER U",NULL},
/* 104CF */ { "OSAGE CAPITAL LETTER WA",NULL},
/* 104D0 */ { "OSAGE CAPITAL LETTER KHA",NULL},
/* 104D1 */ { "OSAGE CAPITAL LETTER GHA",NULL},
/* 104D2 */ { "OSAGE CAPITAL LETTER ZA",NULL},
/* 104D3 */ { "OSAGE CAPITAL LETTER ZHA",NULL},
/* 104D4 */ { NULL,NULL},
/* 104D5 */ { NULL,NULL},
/* 104D6 */ { NULL,NULL},
/* 104D7 */ { NULL,NULL},
/* 104D8 */ { "OSAGE SMALL LETTER A",NULL},
/* 104D9 */ { "OSAGE SMALL LETTER AI",NULL},
/* 104DA */ { "OSAGE SMALL LETTER AIN",NULL},
/* 104DB */ { "OSAGE SMALL LETTER AH",NULL},
/* 104DC */ { "OSAGE SMALL LETTER BRA",NULL},
/* 104DD */ { "OSAGE SMALL LETTER CHA",NULL},
/* 104DE */ { "OSAGE SMALL LETTER EHCHA",NULL},
/* 104DF */ { "OSAGE SMALL LETTER E",NULL},
/* 104E0 */ { "OSAGE SMALL LETTER EIN",NULL},
/* 104E1 */ { "OSAGE SMALL LETTER HA",NULL},
/* 104E2 */ { "OSAGE SMALL LETTER HYA",NULL},
/* 104E3 */ { "OSAGE SMALL LETTER I",NULL},
/* 104E4 */ { "OSAGE SMALL LETTER KA",NULL},
/* 104E5 */ { "OSAGE SMALL LETTER EHKA",NULL},
/* 104E6 */ { "OSAGE SMALL LETTER KYA",NULL},
/* 104E7 */ { "OSAGE SMALL LETTER LA",NULL},
/* 104E8 */ { "OSAGE SMALL LETTER MA",NULL},
/* 104E9 */ { "OSAGE SMALL LETTER NA",NULL},
/* 104EA */ { "OSAGE SMALL LETTER O",NULL},
/* 104EB */ { "OSAGE SMALL LETTER OIN",NULL},
/* 104EC */ { "OSAGE SMALL LETTER PA",NULL},
/* 104ED */ { "OSAGE SMALL LETTER EHPA",NULL},
/* 104EE */ { "OSAGE SMALL LETTER SA",NULL},
/* 104EF */ { "OSAGE SMALL LETTER SHA",NULL},
/* 104F0 */ { "OSAGE SMALL LETTER TA",NULL},
/* 104F1 */ { "OSAGE SMALL LETTER EHTA",NULL},
/* 104F2 */ { "OSAGE SMALL LETTER TSA",NULL},
/* 104F3 */ { "OSAGE SMALL LETTER EHTSA",NULL},
/* 104F4 */ { "OSAGE SMALL LETTER TSHA",NULL},
/* 104F5 */ { "OSAGE SMALL LETTER DHA",NULL},
/* 104F6 */ { "OSAGE SMALL LETTER U",NULL},
/* 104F7 */ { "OSAGE SMALL LETTER WA",NULL},
/* 104F8 */ { "OSAGE SMALL LETTER KHA",NULL},
/* 104F9 */ { "OSAGE SMALL LETTER GHA",NULL},
/* 104FA */ { "OSAGE SMALL LETTER ZA",NULL},
/* 104FB */ { "OSAGE SMALL LETTER ZHA",NULL},
/* 104FC */ { NULL,NULL},
/* 104FD */ { NULL,NULL},
/* 104FE */ { NULL,NULL},
/* 104FF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_05[] = {
/* 10500 */ { "ELBASAN LETTER A",NULL},
/* 10501 */ { "ELBASAN LETTER BE",NULL},
/* 10502 */ { "ELBASAN LETTER CE",NULL},
/* 10503 */ { "ELBASAN LETTER CHE",NULL},
/* 10504 */ { "ELBASAN LETTER DE",NULL},
/* 10505 */ { "ELBASAN LETTER NDE",NULL},
/* 10506 */ { "ELBASAN LETTER DHE",NULL},
/* 10507 */ { "ELBASAN LETTER EI",NULL},
/* 10508 */ { "ELBASAN LETTER E",NULL},
/* 10509 */ { "ELBASAN LETTER FE",NULL},
/* 1050A */ { "ELBASAN LETTER GE",NULL},
/* 1050B */ { "ELBASAN LETTER GJE",NULL},
/* 1050C */ { "ELBASAN LETTER HE",NULL},
/* 1050D */ { "ELBASAN LETTER I",NULL},
/* 1050E */ { "ELBASAN LETTER JE",NULL},
/* 1050F */ { "ELBASAN LETTER KE",NULL},
/* 10510 */ { "ELBASAN LETTER LE",NULL},
/* 10511 */ { "ELBASAN LETTER LLE",NULL},
/* 10512 */ { "ELBASAN LETTER ME",NULL},
/* 10513 */ { "ELBASAN LETTER NE",NULL},
/* 10514 */ { "ELBASAN LETTER NA",NULL},
/* 10515 */ { "ELBASAN LETTER NJE",NULL},
/* 10516 */ { "ELBASAN LETTER O",NULL},
/* 10517 */ { "ELBASAN LETTER PE",NULL},
/* 10518 */ { "ELBASAN LETTER QE",NULL},
/* 10519 */ { "ELBASAN LETTER RE",NULL},
/* 1051A */ { "ELBASAN LETTER RRE",NULL},
/* 1051B */ { "ELBASAN LETTER SE",NULL},
/* 1051C */ { "ELBASAN LETTER SHE",NULL},
/* 1051D */ { "ELBASAN LETTER TE",NULL},
/* 1051E */ { "ELBASAN LETTER THE",NULL},
/* 1051F */ { "ELBASAN LETTER U",NULL},
/* 10520 */ { "ELBASAN LETTER VE",NULL},
/* 10521 */ { "ELBASAN LETTER XE",NULL},
/* 10522 */ { "ELBASAN LETTER Y",NULL},
/* 10523 */ { "ELBASAN LETTER ZE",NULL},
/* 10524 */ { "ELBASAN LETTER ZHE",NULL},
/* 10525 */ { "ELBASAN LETTER GHE",NULL},
/* 10526 */ { "ELBASAN LETTER GHAMMA",NULL},
/* 10527 */ { "ELBASAN LETTER KHE",NULL},
/* 10528 */ { NULL,NULL},
/* 10529 */ { NULL,NULL},
/* 1052A */ { NULL,NULL},
/* 1052B */ { NULL,NULL},
/* 1052C */ { NULL,NULL},
/* 1052D */ { NULL,NULL},
/* 1052E */ { NULL,NULL},
/* 1052F */ { NULL,NULL},
/* 10530 */ { "CAUCASIAN ALBANIAN LETTER ALT",NULL},
/* 10531 */ { "CAUCASIAN ALBANIAN LETTER BET",NULL},
/* 10532 */ { "CAUCASIAN ALBANIAN LETTER GIM",NULL},
/* 10533 */ { "CAUCASIAN ALBANIAN LETTER DAT",NULL},
/* 10534 */ { "CAUCASIAN ALBANIAN LETTER EB",NULL},
/* 10535 */ { "CAUCASIAN ALBANIAN LETTER ZARL",NULL},
/* 10536 */ { "CAUCASIAN ALBANIAN LETTER EYN",NULL},
/* 10537 */ { "CAUCASIAN ALBANIAN LETTER ZHIL",NULL},
/* 10538 */ { "CAUCASIAN ALBANIAN LETTER TAS",NULL},
/* 10539 */ { "CAUCASIAN ALBANIAN LETTER CHA",NULL},
/* 1053A */ { "CAUCASIAN ALBANIAN LETTER YOWD",NULL},
/* 1053B */ { "CAUCASIAN ALBANIAN LETTER ZHA",NULL},
/* 1053C */ { "CAUCASIAN ALBANIAN LETTER IRB",NULL},
/* 1053D */ { "CAUCASIAN ALBANIAN LETTER SHA",NULL},
/* 1053E */ { "CAUCASIAN ALBANIAN LETTER LAN",NULL},
/* 1053F */ { "CAUCASIAN ALBANIAN LETTER INYA",NULL},
/* 10540 */ { "CAUCASIAN ALBANIAN LETTER XEYN",NULL},
/* 10541 */ { "CAUCASIAN ALBANIAN LETTER DYAN",NULL},
/* 10542 */ { "CAUCASIAN ALBANIAN LETTER CAR",NULL},
/* 10543 */ { "CAUCASIAN ALBANIAN LETTER JHOX",NULL},
/* 10544 */ { "CAUCASIAN ALBANIAN LETTER KAR",NULL},
/* 10545 */ { "CAUCASIAN ALBANIAN LETTER LYIT",NULL},
/* 10546 */ { "CAUCASIAN ALBANIAN LETTER HEYT",NULL},
/* 10547 */ { "CAUCASIAN ALBANIAN LETTER QAY",NULL},
/* 10548 */ { "CAUCASIAN ALBANIAN LETTER AOR",NULL},
/* 10549 */ { "CAUCASIAN ALBANIAN LETTER CHOY",NULL},
/* 1054A */ { "CAUCASIAN ALBANIAN LETTER CHI",NULL},
/* 1054B */ { "CAUCASIAN ALBANIAN LETTER CYAY",NULL},
/* 1054C */ { "CAUCASIAN ALBANIAN LETTER MAQ",NULL},
/* 1054D */ { "CAUCASIAN ALBANIAN LETTER QAR",NULL},
/* 1054E */ { "CAUCASIAN ALBANIAN LETTER NOWC",NULL},
/* 1054F */ { "CAUCASIAN ALBANIAN LETTER DZYAY",NULL},
/* 10550 */ { "CAUCASIAN ALBANIAN LETTER SHAK",NULL},
/* 10551 */ { "CAUCASIAN ALBANIAN LETTER JAYN",NULL},
/* 10552 */ { "CAUCASIAN ALBANIAN LETTER ON",NULL},
/* 10553 */ { "CAUCASIAN ALBANIAN LETTER TYAY",NULL},
/* 10554 */ { "CAUCASIAN ALBANIAN LETTER FAM",NULL},
/* 10555 */ { "CAUCASIAN ALBANIAN LETTER DZAY",NULL},
/* 10556 */ { "CAUCASIAN ALBANIAN LETTER CHAT",NULL},
/* 10557 */ { "CAUCASIAN ALBANIAN LETTER PEN",NULL},
/* 10558 */ { "CAUCASIAN ALBANIAN LETTER GHEYS",NULL},
/* 10559 */ { "CAUCASIAN ALBANIAN LETTER RAT",NULL},
/* 1055A */ { "CAUCASIAN ALBANIAN LETTER SEYK",NULL},
/* 1055B */ { "CAUCASIAN ALBANIAN LETTER VEYZ",NULL},
/* 1055C */ { "CAUCASIAN ALBANIAN LETTER TIWR",NULL},
/* 1055D */ { "CAUCASIAN ALBANIAN LETTER SHOY",NULL},
/* 1055E */ { "CAUCASIAN ALBANIAN LETTER IWN",NULL},
/* 1055F */ { "CAUCASIAN ALBANIAN LETTER CYAW",NULL},
/* 10560 */ { "CAUCASIAN ALBANIAN LETTER CAYN",NULL},
/* 10561 */ { "CAUCASIAN ALBANIAN LETTER YAYD",NULL},
/* 10562 */ { "CAUCASIAN ALBANIAN LETTER PIWR",NULL},
/* 10563 */ { "CAUCASIAN ALBANIAN LETTER KIW",NULL},
/* 10564 */ { NULL,NULL},
/* 10565 */ { NULL,NULL},
/* 10566 */ { NULL,NULL},
/* 10567 */ { NULL,NULL},
/* 10568 */ { NULL,NULL},
/* 10569 */ { NULL,NULL},
/* 1056A */ { NULL,NULL},
/* 1056B */ { NULL,NULL},
/* 1056C */ { NULL,NULL},
/* 1056D */ { NULL,NULL},
/* 1056E */ { NULL,NULL},
/* 1056F */ { "CAUCASIAN ALBANIAN CITATION MARK",NULL},
/* 10570 */ { "VITHKUQI CAPITAL LETTER A",NULL},
/* 10571 */ { "VITHKUQI CAPITAL LETTER BBE",NULL},
/* 10572 */ { "VITHKUQI CAPITAL LETTER BE",NULL},
/* 10573 */ { "VITHKUQI CAPITAL LETTER CE",NULL},
/* 10574 */ { "VITHKUQI CAPITAL LETTER CHE",NULL},
/* 10575 */ { "VITHKUQI CAPITAL LETTER DE",NULL},
/* 10576 */ { "VITHKUQI CAPITAL LETTER DHE",NULL},
/* 10577 */ { "VITHKUQI CAPITAL LETTER EI",NULL},
/* 10578 */ { "VITHKUQI CAPITAL LETTER E",NULL},
/* 10579 */ { "VITHKUQI CAPITAL LETTER FE",NULL},
/* 1057A */ { "VITHKUQI CAPITAL LETTER GA",NULL},
/* 1057B */ { NULL,NULL},
/* 1057C */ { "VITHKUQI CAPITAL LETTER HA",NULL},
/* 1057D */ { "VITHKUQI CAPITAL LETTER HHA","	* used in 19th-century orthography"},
/* 1057E */ { "VITHKUQI CAPITAL LETTER I",NULL},
/* 1057F */ { "VITHKUQI CAPITAL LETTER IJE","	* used in 19th-century orthography"},
/* 10580 */ { "VITHKUQI CAPITAL LETTER JE",NULL},
/* 10581 */ { "VITHKUQI CAPITAL LETTER KA",NULL},
/* 10582 */ { "VITHKUQI CAPITAL LETTER LA",NULL},
/* 10583 */ { "VITHKUQI CAPITAL LETTER LLA",NULL},
/* 10584 */ { "VITHKUQI CAPITAL LETTER ME",NULL},
/* 10585 */ { "VITHKUQI CAPITAL LETTER NE",NULL},
/* 10586 */ { "VITHKUQI CAPITAL LETTER NJE",NULL},
/* 10587 */ { "VITHKUQI CAPITAL LETTER O",NULL},
/* 10588 */ { "VITHKUQI CAPITAL LETTER PE",NULL},
/* 10589 */ { "VITHKUQI CAPITAL LETTER QA",NULL},
/* 1058A */ { "VITHKUQI CAPITAL LETTER RE",NULL},
/* 1058B */ { NULL,NULL},
/* 1058C */ { "VITHKUQI CAPITAL LETTER SE",NULL},
/* 1058D */ { "VITHKUQI CAPITAL LETTER SHE",NULL},
/* 1058E */ { "VITHKUQI CAPITAL LETTER TE",NULL},
/* 1058F */ { "VITHKUQI CAPITAL LETTER THE",NULL},
/* 10590 */ { "VITHKUQI CAPITAL LETTER U",NULL},
/* 10591 */ { "VITHKUQI CAPITAL LETTER VE",NULL},
/* 10592 */ { "VITHKUQI CAPITAL LETTER XE",NULL},
/* 10593 */ { NULL,NULL},
/* 10594 */ { "VITHKUQI CAPITAL LETTER Y",NULL},
/* 10595 */ { "VITHKUQI CAPITAL LETTER ZE",NULL},
/* 10596 */ { NULL,NULL},
/* 10597 */ { "VITHKUQI SMALL LETTER A",NULL},
/* 10598 */ { "VITHKUQI SMALL LETTER BBE",NULL},
/* 10599 */ { "VITHKUQI SMALL LETTER BE",NULL},
/* 1059A */ { "VITHKUQI SMALL LETTER CE",NULL},
/* 1059B */ { "VITHKUQI SMALL LETTER CHE",NULL},
/* 1059C */ { "VITHKUQI SMALL LETTER DE",NULL},
/* 1059D */ { "VITHKUQI SMALL LETTER DHE",NULL},
/* 1059E */ { "VITHKUQI SMALL LETTER EI",NULL},
/* 1059F */ { "VITHKUQI SMALL LETTER E",NULL},
/* 105A0 */ { "VITHKUQI SMALL LETTER FE",NULL},
/* 105A1 */ { "VITHKUQI SMALL LETTER GA",NULL},
/* 105A2 */ { NULL,NULL},
/* 105A3 */ { "VITHKUQI SMALL LETTER HA",NULL},
/* 105A4 */ { "VITHKUQI SMALL LETTER HHA","	* used in 19th-century orthography"},
/* 105A5 */ { "VITHKUQI SMALL LETTER I",NULL},
/* 105A6 */ { "VITHKUQI SMALL LETTER IJE","	* used in 19th-century orthography"},
/* 105A7 */ { "VITHKUQI SMALL LETTER JE",NULL},
/* 105A8 */ { "VITHKUQI SMALL LETTER KA",NULL},
/* 105A9 */ { "VITHKUQI SMALL LETTER LA",NULL},
/* 105AA */ { "VITHKUQI SMALL LETTER LLA",NULL},
/* 105AB */ { "VITHKUQI SMALL LETTER ME",NULL},
/* 105AC */ { "VITHKUQI SMALL LETTER NE",NULL},
/* 105AD */ { "VITHKUQI SMALL LETTER NJE",NULL},
/* 105AE */ { "VITHKUQI SMALL LETTER O",NULL},
/* 105AF */ { "VITHKUQI SMALL LETTER PE",NULL},
/* 105B0 */ { "VITHKUQI SMALL LETTER QA",NULL},
/* 105B1 */ { "VITHKUQI SMALL LETTER RE",NULL},
/* 105B2 */ { NULL,NULL},
/* 105B3 */ { "VITHKUQI SMALL LETTER SE",NULL},
/* 105B4 */ { "VITHKUQI SMALL LETTER SHE",NULL},
/* 105B5 */ { "VITHKUQI SMALL LETTER TE",NULL},
/* 105B6 */ { "VITHKUQI SMALL LETTER THE",NULL},
/* 105B7 */ { "VITHKUQI SMALL LETTER U",NULL},
/* 105B8 */ { "VITHKUQI SMALL LETTER VE",NULL},
/* 105B9 */ { "VITHKUQI SMALL LETTER XE",NULL},
/* 105BA */ { NULL,NULL},
/* 105BB */ { "VITHKUQI SMALL LETTER Y",NULL},
/* 105BC */ { "VITHKUQI SMALL LETTER ZE",NULL},
/* 105BD */ { NULL,NULL},
/* 105BE */ { NULL,NULL},
/* 105BF */ { NULL,NULL},
/* 105C0 */ { "TODHRI LETTER A",NULL},
/* 105C1 */ { "TODHRI LETTER AS",NULL},
/* 105C2 */ { "TODHRI LETTER BA",NULL},
/* 105C3 */ { "TODHRI LETTER MBA",NULL},
/* 105C4 */ { "TODHRI LETTER CA",NULL},
/* 105C5 */ { "TODHRI LETTER CHA",NULL},
/* 105C6 */ { "TODHRI LETTER DA",NULL},
/* 105C7 */ { "TODHRI LETTER NDA",NULL},
/* 105C8 */ { "TODHRI LETTER DHA",NULL},
/* 105C9 */ { "TODHRI LETTER EI","	: 105D2 0307"},
/* 105CA */ { "TODHRI LETTER E",NULL},
/* 105CB */ { "TODHRI LETTER FA",NULL},
/* 105CC */ { "TODHRI LETTER GA",NULL},
/* 105CD */ { "TODHRI LETTER NGA",NULL},
/* 105CE */ { "TODHRI LETTER GJA",NULL},
/* 105CF */ { "TODHRI LETTER NGJA",NULL},
/* 105D0 */ { "TODHRI LETTER HA",NULL},
/* 105D1 */ { "TODHRI LETTER HJA",NULL},
/* 105D2 */ { "TODHRI LETTER I",NULL},
/* 105D3 */ { "TODHRI LETTER JA",NULL},
/* 105D4 */ { "TODHRI LETTER KA",NULL},
/* 105D5 */ { "TODHRI LETTER LA",NULL},
/* 105D6 */ { "TODHRI LETTER LLA",NULL},
/* 105D7 */ { "TODHRI LETTER MA",NULL},
/* 105D8 */ { "TODHRI LETTER NA",NULL},
/* 105D9 */ { "TODHRI LETTER NJAN",NULL},
/* 105DA */ { "TODHRI LETTER O",NULL},
/* 105DB */ { "TODHRI LETTER PA",NULL},
/* 105DC */ { "TODHRI LETTER QA",NULL},
/* 105DD */ { "TODHRI LETTER RA",NULL},
/* 105DE */ { "TODHRI LETTER RRA",NULL},
/* 105DF */ { "TODHRI LETTER SA",NULL},
/* 105E0 */ { "TODHRI LETTER SHA",NULL},
/* 105E1 */ { "TODHRI LETTER SHTA",NULL},
/* 105E2 */ { "TODHRI LETTER TA",NULL},
/* 105E3 */ { "TODHRI LETTER THA",NULL},
/* 105E4 */ { "TODHRI LETTER U","	: 105DA 0307"},
/* 105E5 */ { "TODHRI LETTER VA",NULL},
/* 105E6 */ { "TODHRI LETTER XA",NULL},
/* 105E7 */ { "TODHRI LETTER NXA",NULL},
/* 105E8 */ { "TODHRI LETTER XHA",NULL},
/* 105E9 */ { "TODHRI LETTER NXHA",NULL},
/* 105EA */ { "TODHRI LETTER Y",NULL},
/* 105EB */ { "TODHRI LETTER JY",NULL},
/* 105EC */ { "TODHRI LETTER ZA",NULL},
/* 105ED */ { "TODHRI LETTER ZHA",NULL},
/* 105EE */ { "TODHRI LETTER GHA",NULL},
/* 105EF */ { "TODHRI LETTER STA",NULL},
/* 105F0 */ { "TODHRI LETTER SKAN",NULL},
/* 105F1 */ { "TODHRI LETTER KHA",NULL},
/* 105F2 */ { "TODHRI LETTER PSA",NULL},
/* 105F3 */ { "TODHRI LETTER OO",NULL},
/* 105F4 */ { NULL,NULL},
/* 105F5 */ { NULL,NULL},
/* 105F6 */ { NULL,NULL},
/* 105F7 */ { NULL,NULL},
/* 105F8 */ { NULL,NULL},
/* 105F9 */ { NULL,NULL},
/* 105FA */ { NULL,NULL},
/* 105FB */ { NULL,NULL},
/* 105FC */ { NULL,NULL},
/* 105FD */ { NULL,NULL},
/* 105FE */ { NULL,NULL},
/* 105FF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_06[] = {
/* 10600 */ { "LINEAR A SIGN AB001",NULL},
/* 10601 */ { "LINEAR A SIGN AB002",NULL},
/* 10602 */ { "LINEAR A SIGN AB003",NULL},
/* 10603 */ { "LINEAR A SIGN AB004",NULL},
/* 10604 */ { "LINEAR A SIGN AB005",NULL},
/* 10605 */ { "LINEAR A SIGN AB006",NULL},
/* 10606 */ { "LINEAR A SIGN AB007",NULL},
/* 10607 */ { "LINEAR A SIGN AB008",NULL},
/* 10608 */ { "LINEAR A SIGN AB009",NULL},
/* 10609 */ { "LINEAR A SIGN AB010",NULL},
/* 1060A */ { "LINEAR A SIGN AB011",NULL},
/* 1060B */ { "LINEAR A SIGN AB013",NULL},
/* 1060C */ { "LINEAR A SIGN AB016",NULL},
/* 1060D */ { "LINEAR A SIGN AB017",NULL},
/* 1060E */ { "LINEAR A SIGN AB020",NULL},
/* 1060F */ { "LINEAR A SIGN AB021","	* sheep\n"
	"	x (linear b syllable b021 qi - 10025)"},
/* 10610 */ { "LINEAR A SIGN AB021F","	* ewe\n"
	"	x (linear b ideogram b106f ewe - 10086)"},
/* 10611 */ { "LINEAR A SIGN AB021M","	* ram\n"
	"	x (linear b ideogram b106m ram - 10087)"},
/* 10612 */ { "LINEAR A SIGN AB022","	* goat\n"
	"	x (linear b symbol b022 - 10052)"},
/* 10613 */ { "LINEAR A SIGN AB022F","	* she-goat\n"
	"	x (linear b ideogram b107f she-goat - 10088)"},
/* 10614 */ { "LINEAR A SIGN AB022M","	* he-goat\n"
	"	x (linear b ideogram b107m he-goat - 10089)"},
/* 10615 */ { "LINEAR A SIGN AB023","	* bovine\n"
	"	x (linear b syllable b023 mu - 10018)"},
/* 10616 */ { "LINEAR A SIGN AB023M","	* bull\n"
	"	x (linear b ideogram b109m bull - 1008D)"},
/* 10617 */ { "LINEAR A SIGN AB024",NULL},
/* 10618 */ { "LINEAR A SIGN AB026",NULL},
/* 10619 */ { "LINEAR A SIGN AB027",NULL},
/* 1061A */ { "LINEAR A SIGN AB028",NULL},
/* 1061B */ { "LINEAR A SIGN A028B",NULL},
/* 1061C */ { "LINEAR A SIGN AB029",NULL},
/* 1061D */ { "LINEAR A SIGN AB030","	* figs\n"
	"	x (linear b syllable b030 ni - 1001B)"},
/* 1061E */ { "LINEAR A SIGN AB031",NULL},
/* 1061F */ { "LINEAR A SIGN AB034",NULL},
/* 10620 */ { "LINEAR A SIGN AB037",NULL},
/* 10621 */ { "LINEAR A SIGN AB038",NULL},
/* 10622 */ { "LINEAR A SIGN AB039",NULL},
/* 10623 */ { "LINEAR A SIGN AB040",NULL},
/* 10624 */ { "LINEAR A SIGN AB041",NULL},
/* 10625 */ { "LINEAR A SIGN AB044",NULL},
/* 10626 */ { "LINEAR A SIGN AB045",NULL},
/* 10627 */ { "LINEAR A SIGN AB046",NULL},
/* 10628 */ { "LINEAR A SIGN AB047",NULL},
/* 10629 */ { "LINEAR A SIGN AB048","	x (linear b syllable b048 nwa - 10045)"},
/* 1062A */ { "LINEAR A SIGN AB049",NULL},
/* 1062B */ { "LINEAR A SIGN AB050",NULL},
/* 1062C */ { "LINEAR A SIGN AB051",NULL},
/* 1062D */ { "LINEAR A SIGN AB053",NULL},
/* 1062E */ { "LINEAR A SIGN AB054","	* cloth\n"
	"	x (linear b ideogram b159 cloth - 100A7)"},
/* 1062F */ { "LINEAR A SIGN AB055",NULL},
/* 10630 */ { "LINEAR A SIGN AB056",NULL},
/* 10631 */ { "LINEAR A SIGN AB057",NULL},
/* 10632 */ { "LINEAR A SIGN AB058",NULL},
/* 10633 */ { "LINEAR A SIGN AB059",NULL},
/* 10634 */ { "LINEAR A SIGN AB060",NULL},
/* 10635 */ { "LINEAR A SIGN AB061",NULL},
/* 10636 */ { "LINEAR A SIGN AB065",NULL},
/* 10637 */ { "LINEAR A SIGN AB066",NULL},
/* 10638 */ { "LINEAR A SIGN AB067",NULL},
/* 10639 */ { "LINEAR A SIGN AB069",NULL},
/* 1063A */ { "LINEAR A SIGN AB070",NULL},
/* 1063B */ { "LINEAR A SIGN AB073",NULL},
/* 1063C */ { "LINEAR A SIGN AB074",NULL},
/* 1063D */ { "LINEAR A SIGN AB076",NULL},
/* 1063E */ { "LINEAR A SIGN AB077",NULL},
/* 1063F */ { "LINEAR A SIGN AB078",NULL},
/* 10640 */ { "LINEAR A SIGN AB079",NULL},
/* 10641 */ { "LINEAR A SIGN AB080",NULL},
/* 10642 */ { "LINEAR A SIGN AB081",NULL},
/* 10643 */ { "LINEAR A SIGN AB082",NULL},
/* 10644 */ { "LINEAR A SIGN AB085","	* pig\n"
	"	x (linear b syllable b085 au - 10042)"},
/* 10645 */ { "LINEAR A SIGN AB086",NULL},
/* 10646 */ { "LINEAR A SIGN AB087",NULL},
/* 10647 */ { "LINEAR A SIGN A100-102","	* man or woman\n"
	"	x (linear b ideogram b100 man - 10080)\n"
	"	x (linear b ideogram b102 woman - 10081)"},
/* 10648 */ { "LINEAR A SIGN AB118",NULL},
/* 10649 */ { "LINEAR A SIGN AB120","	* grain\n"
	"	x (linear b ideogram b120 wheat - 1008E)"},
/* 1064A */ { "LINEAR A SIGN A120B","	* grain"},
/* 1064B */ { "LINEAR A SIGN AB122","	* olives\n"
	"	x (linear b ideogram b122 olive - 10090)"},
/* 1064C */ { "LINEAR A SIGN AB123",NULL},
/* 1064D */ { "LINEAR A SIGN AB131A","	* wine\n"
	"	x (linear b ideogram b131 wine - 10096)"},
/* 1064E */ { "LINEAR A SIGN AB131B","	* wine"},
/* 1064F */ { "LINEAR A SIGN A131C","	* wine"},
/* 10650 */ { "LINEAR A SIGN AB164",NULL},
/* 10651 */ { "LINEAR A SIGN AB171",NULL},
/* 10652 */ { "LINEAR A SIGN AB180",NULL},
/* 10653 */ { "LINEAR A SIGN AB188",NULL},
/* 10654 */ { "LINEAR A SIGN AB191",NULL},
/* 10655 */ { "LINEAR A SIGN A301",NULL},
/* 10656 */ { "LINEAR A SIGN A302","	* olive oil\n"
	"	x (linear b ideogram b130 oil - 10095)"},
/* 10657 */ { "LINEAR A SIGN A303","	* cyperus\n"
	"	x (linear b ideogram b125 cyperus - 10092)"},
/* 10658 */ { "LINEAR A SIGN A304",NULL},
/* 10659 */ { "LINEAR A SIGN A305",NULL},
/* 1065A */ { "LINEAR A SIGN A306",NULL},
/* 1065B */ { "LINEAR A SIGN A307",NULL},
/* 1065C */ { "LINEAR A SIGN A308",NULL},
/* 1065D */ { "LINEAR A SIGN A309A",NULL},
/* 1065E */ { "LINEAR A SIGN A309B",NULL},
/* 1065F */ { "LINEAR A SIGN A309C",NULL},
/* 10660 */ { "LINEAR A SIGN A310",NULL},
/* 10661 */ { "LINEAR A SIGN A311","	* used with 10655 linear a sign a301"},
/* 10662 */ { "LINEAR A SIGN A312",NULL},
/* 10663 */ { "LINEAR A SIGN A313A","	* used with 10647 linear a sign a100-102"},
/* 10664 */ { "LINEAR A SIGN A313B","	* used with 10647 linear a sign a100-102"},
/* 10665 */ { "LINEAR A SIGN A313C","	* used with 10647 linear a sign a100-102"},
/* 10666 */ { "LINEAR A SIGN A314",NULL},
/* 10667 */ { "LINEAR A SIGN A315",NULL},
/* 10668 */ { "LINEAR A SIGN A316",NULL},
/* 10669 */ { "LINEAR A SIGN A317",NULL},
/* 1066A */ { "LINEAR A SIGN A318",NULL},
/* 1066B */ { "LINEAR A SIGN A319",NULL},
/* 1066C */ { "LINEAR A SIGN A320",NULL},
/* 1066D */ { "LINEAR A SIGN A321",NULL},
/* 1066E */ { "LINEAR A SIGN A322",NULL},
/* 1066F */ { "LINEAR A SIGN A323",NULL},
/* 10670 */ { "LINEAR A SIGN A324",NULL},
/* 10671 */ { "LINEAR A SIGN A325",NULL},
/* 10672 */ { "LINEAR A SIGN A326",NULL},
/* 10673 */ { "LINEAR A SIGN A327",NULL},
/* 10674 */ { "LINEAR A SIGN A328",NULL},
/* 10675 */ { "LINEAR A SIGN A329",NULL},
/* 10676 */ { "LINEAR A SIGN A330","	* used with 10600 linear a sign ab001 and 1061E linear a sign ab031"},
/* 10677 */ { "LINEAR A SIGN A331",NULL},
/* 10678 */ { "LINEAR A SIGN A332",NULL},
/* 10679 */ { "LINEAR A SIGN A333",NULL},
/* 1067A */ { "LINEAR A SIGN A334",NULL},
/* 1067B */ { "LINEAR A SIGN A335",NULL},
/* 1067C */ { "LINEAR A SIGN A336",NULL},
/* 1067D */ { "LINEAR A SIGN A337","	* used with 10653 linear a sign ab188"},
/* 1067E */ { "LINEAR A SIGN A338",NULL},
/* 1067F */ { "LINEAR A SIGN A339",NULL},
/* 10680 */ { "LINEAR A SIGN A340",NULL},
/* 10681 */ { "LINEAR A SIGN A341","	* used with 10622 linear a sign ab039"},
/* 10682 */ { "LINEAR A SIGN A342",NULL},
/* 10683 */ { "LINEAR A SIGN A343",NULL},
/* 10684 */ { "LINEAR A SIGN A344",NULL},
/* 10685 */ { "LINEAR A SIGN A345",NULL},
/* 10686 */ { "LINEAR A SIGN A346",NULL},
/* 10687 */ { "LINEAR A SIGN A347",NULL},
/* 10688 */ { "LINEAR A SIGN A348","	* used with 10657 linear a sign a303"},
/* 10689 */ { "LINEAR A SIGN A349",NULL},
/* 1068A */ { "LINEAR A SIGN A350",NULL},
/* 1068B */ { "LINEAR A SIGN A351","	* used with 10655 linear a sign a301"},
/* 1068C */ { "LINEAR A SIGN A352",NULL},
/* 1068D */ { "LINEAR A SIGN A353",NULL},
/* 1068E */ { "LINEAR A SIGN A354",NULL},
/* 1068F */ { "LINEAR A SIGN A355",NULL},
/* 10690 */ { "LINEAR A SIGN A356",NULL},
/* 10691 */ { "LINEAR A SIGN A357",NULL},
/* 10692 */ { "LINEAR A SIGN A358",NULL},
/* 10693 */ { "LINEAR A SIGN A359",NULL},
/* 10694 */ { "LINEAR A SIGN A360",NULL},
/* 10695 */ { "LINEAR A SIGN A361",NULL},
/* 10696 */ { "LINEAR A SIGN A362",NULL},
/* 10697 */ { "LINEAR A SIGN A363",NULL},
/* 10698 */ { "LINEAR A SIGN A364",NULL},
/* 10699 */ { "LINEAR A SIGN A365",NULL},
/* 1069A */ { "LINEAR A SIGN A366",NULL},
/* 1069B */ { "LINEAR A SIGN A367",NULL},
/* 1069C */ { "LINEAR A SIGN A368",NULL},
/* 1069D */ { "LINEAR A SIGN A369",NULL},
/* 1069E */ { "LINEAR A SIGN A370",NULL},
/* 1069F */ { "LINEAR A SIGN A371",NULL},
/* 106A0 */ { "LINEAR A SIGN A400-VAS",NULL},
/* 106A1 */ { "LINEAR A SIGN A401-VAS",NULL},
/* 106A2 */ { "LINEAR A SIGN A402-VAS",NULL},
/* 106A3 */ { "LINEAR A SIGN A403-VAS",NULL},
/* 106A4 */ { "LINEAR A SIGN A404-VAS",NULL},
/* 106A5 */ { "LINEAR A SIGN A405-VAS",NULL},
/* 106A6 */ { "LINEAR A SIGN A406-VAS",NULL},
/* 106A7 */ { "LINEAR A SIGN A407-VAS",NULL},
/* 106A8 */ { "LINEAR A SIGN A408-VAS",NULL},
/* 106A9 */ { "LINEAR A SIGN A409-VAS",NULL},
/* 106AA */ { "LINEAR A SIGN A410-VAS",NULL},
/* 106AB */ { "LINEAR A SIGN A411-VAS",NULL},
/* 106AC */ { "LINEAR A SIGN A412-VAS",NULL},
/* 106AD */ { "LINEAR A SIGN A413-VAS",NULL},
/* 106AE */ { "LINEAR A SIGN A414-VAS",NULL},
/* 106AF */ { "LINEAR A SIGN A415-VAS",NULL},
/* 106B0 */ { "LINEAR A SIGN A416-VAS",NULL},
/* 106B1 */ { "LINEAR A SIGN A417-VAS",NULL},
/* 106B2 */ { "LINEAR A SIGN A418-VAS",NULL},
/* 106B3 */ { "LINEAR A SIGN A501","	* 10600 ab001, 10601 ab002"},
/* 106B4 */ { "LINEAR A SIGN A502","	* 10600 ab001, 10619 ab027, 10608 ab009"},
/* 106B5 */ { "LINEAR A SIGN A503","	* 10600 ab001, 10655 a301"},
/* 106B6 */ { "LINEAR A SIGN A504","	* 10601 ab002, 10601 ab002"},
/* 106B7 */ { "LINEAR A SIGN A505","	* 10603 ab004, 10601 ab002"},
/* 106B8 */ { "LINEAR A SIGN A506","	* 10606 ab007, 1063F ab078"},
/* 106B9 */ { "LINEAR A SIGN A508","	* 1060C ab016, 10619 ab027"},
/* 106BA */ { "LINEAR A SIGN A509","	* 1060C ab016, 10619 ab027, 1062B ab050"},
/* 106BB */ { "LINEAR A SIGN A510","	* 1060C ab016, 1062B ab050"},
/* 106BC */ { "LINEAR A SIGN A511","	* 1060C ab016, 1062B ab050, 10619 ab027"},
/* 106BD */ { "LINEAR A SIGN A512","	* 1060F ab021, 10624 ab041"},
/* 106BE */ { "LINEAR A SIGN A513","	* 10614 ab022m, 10642 ab081"},
/* 106BF */ { "LINEAR A SIGN A515","	* 10619 ab027, 10608 ab009"},
/* 106C0 */ { "LINEAR A SIGN A516","	x (linear a sign ab028 - 1061A)"},
/* 106C1 */ { "LINEAR A SIGN A520","	* 1061A ab028, 10655 a301"},
/* 106C2 */ { "LINEAR A SIGN A521","	* 1061E ab031, 10615 ab023, 10642 ab081"},
/* 106C3 */ { "LINEAR A SIGN A523","	* 10620 ab037, 10607 ab008"},
/* 106C4 */ { "LINEAR A SIGN A524","	* 10620 ab037, 106AC a412-vas"},
/* 106C5 */ { "LINEAR A SIGN A525","	x (linear a sign ab038 - 10621)"},
/* 106C6 */ { "LINEAR A SIGN A526","	* 10621 ab038, 1063E ab077"},
/* 106C7 */ { "LINEAR A SIGN A527","	* 10623 ab040, 1063C ab074"},
/* 106C8 */ { "LINEAR A SIGN A528","	* 10624 ab041, 10606 ab007"},
/* 106C9 */ { "LINEAR A SIGN A529","	* 10624 ab041, 10608 ab009"},
/* 106CA */ { "LINEAR A SIGN A530","	* 10624 ab041, 1060B ab013"},
/* 106CB */ { "LINEAR A SIGN A531","	* 10624 ab041, 1060B ab013, 10638 ab067"},
/* 106CC */ { "LINEAR A SIGN A532","	* 10624 ab041, 10637 ab066"},
/* 106CD */ { "LINEAR A SIGN A534","	x (linear a sign ab051 - 1062C)"},
/* 106CE */ { "LINEAR A SIGN A535","	* 1062E ab054, 10642 ab081"},
/* 106CF */ { "LINEAR A SIGN A536","	* 1062E ab054, 10662 a312"},
/* 106D0 */ { "LINEAR A SIGN A537","	* 10630 ab056, 1063F ab078"},
/* 106D1 */ { "LINEAR A SIGN A538","	* 10631 ab057, 10618 ab026"},
/* 106D2 */ { "LINEAR A SIGN A539","	* 10631 ab057, 1063E ab077"},
/* 106D3 */ { "LINEAR A SIGN A540","	* 10632 ab058, 1063B ab073"},
/* 106D4 */ { "LINEAR A SIGN A541","	* 10634 ab060, 1063E ab077"},
/* 106D5 */ { "LINEAR A SIGN A542","	* 10636 ab065, 10669 a317, 1063F ab078"},
/* 106D6 */ { "LINEAR A SIGN A545","	* 10638 ab067, 10615 ab023"},
/* 106D7 */ { "LINEAR A SIGN A547","	* 10639 ab069, 10601 ab002"},
/* 106D8 */ { "LINEAR A SIGN A548","	* 1063B ab073, 10631 ab057"},
/* 106D9 */ { "LINEAR A SIGN A549","	x (linear a sign a548 - 106D8)"},
/* 106DA */ { "LINEAR A SIGN A550","	* 1063B ab073, 10631 ab057, 10618 ab026"},
/* 106DB */ { "LINEAR A SIGN A551","	* 1063B ab073, 10631 ab057, 1061A ab028"},
/* 106DC */ { "LINEAR A SIGN A552","	* 1063B ab073, 10631 ab057, 1063E ab077"},
/* 106DD */ { "LINEAR A SIGN A553","	* 1063B ab073, 10655 a301"},
/* 106DE */ { "LINEAR A SIGN A554","	* 1063E ab077, 10607 ab008"},
/* 106DF */ { "LINEAR A SIGN A555","	* 1063F ab078, 10649 ab120, 10602 ab003"},
/* 106E0 */ { "LINEAR A SIGN A556","	x (linear a sign ab080 - 10641)"},
/* 106E1 */ { "LINEAR A SIGN A557","	* 10641 ab080, 10607 ab008"},
/* 106E2 */ { "LINEAR A SIGN A559","	* 10641 ab080, 10618 ab026"},
/* 106E3 */ { "LINEAR A SIGN A563","	* 10641 ab080, 10641 ab080"},
/* 106E4 */ { "LINEAR A SIGN A564","	x (linear a sign ab081 - 10642)"},
/* 106E5 */ { "LINEAR A SIGN A565","	* 10645 ab086, 10653 ab188"},
/* 106E6 */ { "LINEAR A SIGN A566","	* 10645 ab086, 10653 ab188"},
/* 106E7 */ { "LINEAR A SIGN A568","	* 10647 a100-102, 1063E ab077"},
/* 106E8 */ { "LINEAR A SIGN A569","	* 10647 a100-102, 1065B a307"},
/* 106E9 */ { "LINEAR A SIGN A570","	* 10647 a100-102, 10663 a313a"},
/* 106EA */ { "LINEAR A SIGN A571","	* 10647 a100-102, 10664 a313b"},
/* 106EB */ { "LINEAR A SIGN A572","	* 10647 a100-102, 10665 a313c"},
/* 106EC */ { "LINEAR A SIGN A573","	* 10649 ab120, 10600 ab001"},
/* 106ED */ { "LINEAR A SIGN A574","	* 10649 ab120, 10602 ab003"},
/* 106EE */ { "LINEAR A SIGN A575","	* 10649 ab120, 10610 ab021f"},
/* 106EF */ { "LINEAR A SIGN A576","	* 10649 ab120, 10614 ab022m"},
/* 106F0 */ { "LINEAR A SIGN A577","	* 10649 ab120, 1062F ab056"},
/* 106F1 */ { "LINEAR A SIGN A578","	* 10649 ab120, 1063F ab078"},
/* 106F2 */ { "LINEAR A SIGN A579","	* 10649 ab120, 10642 ab081"},
/* 106F3 */ { "LINEAR A SIGN A580","	* 10649 ab120, 10741 a702 b"},
/* 106F4 */ { "LINEAR A SIGN A581","	* 10649 ab120, 10743 a704 e"},
/* 106F5 */ { "LINEAR A SIGN A582","	* 10649 ab120, 10744 a705 f"},
/* 106F6 */ { "LINEAR A SIGN A583","	* 10649 ab120, 10745 a706 h"},
/* 106F7 */ { "LINEAR A SIGN A584","	* 10649 ab120, 10747 a708 k, 10749 a709-2 l2"},
/* 106F8 */ { "LINEAR A SIGN A585","	* 10649 ab120, 10749 a709-2 l2"},
/* 106F9 */ { "LINEAR A SIGN A586","	* 10649 ab120, 1074A a709-3 l3, 1074A a709-3 l3"},
/* 106FA */ { "LINEAR A SIGN A587","	* 1064B ab122, 10639 ab069"},
/* 106FB */ { "LINEAR A SIGN A588","	* 1064D ab131a, 10603 ab004"},
/* 106FC */ { "LINEAR A SIGN A589","	* 1064D ab131a, 1061E ab031"},
/* 106FD */ { "LINEAR A SIGN A591","	* 1064D ab131a, 1062E ab054"},
/* 106FE */ { "LINEAR A SIGN A592","	* 1064D ab131a, 1062E ab054"},
/* 106FF */ { "LINEAR A SIGN A594","	* 1064D ab131a, 10634 ab060"}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_07[] = {
/* 10700 */ { "LINEAR A SIGN A595","	* 1064D ab131a, 10634 ab060"},
/* 10701 */ { "LINEAR A SIGN A596","	* 1064D ab131a, 1063E ab077"},
/* 10702 */ { "LINEAR A SIGN A598","	* 1064D ab131b, 10623 ab040"},
/* 10703 */ { "LINEAR A SIGN A600","	* 10764 a804, 10741 a702 b"},
/* 10704 */ { "LINEAR A SIGN A601","	* 10764 a804, 10748 a709 l"},
/* 10705 */ { "LINEAR A SIGN A602","	* 10652 ab180, 10741 a702 b"},
/* 10706 */ { "LINEAR A SIGN A603","	* 10652 ab180, 10748 a709 l"},
/* 10707 */ { "LINEAR A SIGN A604","	* 10653 ab188, 10642 ab081"},
/* 10708 */ { "LINEAR A SIGN A606","	* 10655 a301, 10661 a311"},
/* 10709 */ { "LINEAR A SIGN A608","	* 10656 a302, 10606 ab007"},
/* 1070A */ { "LINEAR A SIGN A609","	* 10656 a302, 10607 ab008"},
/* 1070B */ { "LINEAR A SIGN A610","	* 10656 a302, 10609 ab010"},
/* 1070C */ { "LINEAR A SIGN A611","	* 10656 a302, 10610 ab021f"},
/* 1070D */ { "LINEAR A SIGN A612","	* 10656 a302, 10617 ab024"},
/* 1070E */ { "LINEAR A SIGN A613","	* 10656 a302, 10621 ab038"},
/* 1070F */ { "LINEAR A SIGN A614","	* 10656 a302, 1062D ab053"},
/* 10710 */ { "LINEAR A SIGN A615","	* 10656 a302, 10633 ab059"},
/* 10711 */ { "LINEAR A SIGN A616","	* 10656 a302, 10634 ab060"},
/* 10712 */ { "LINEAR A SIGN A617","	* 10656 a302, 10638 ab067"},
/* 10713 */ { "LINEAR A SIGN A618","	* 10656 a302, 10638 ab067"},
/* 10714 */ { "LINEAR A SIGN A619","	* 10656 a302, 10638 ab067, 10609 ab010"},
/* 10715 */ { "LINEAR A SIGN A620","	* 10656 a302, 10638 ab067, 1060B ab013"},
/* 10716 */ { "LINEAR A SIGN A621","	* 10656 a302, 10639 ab069"},
/* 10717 */ { "LINEAR A SIGN A622","	* 10656 a302, 1063B ab073"},
/* 10718 */ { "LINEAR A SIGN A623","	* 10656 a302, 1063F ab078, 10606 ab007"},
/* 10719 */ { "LINEAR A SIGN A624","	* 10657 a303, 10742 a703 d"},
/* 1071A */ { "LINEAR A SIGN A626","	* 10657 a303, 10743 a704 e"},
/* 1071B */ { "LINEAR A SIGN A627","	* 10657 a303, 10747 a708 k"},
/* 1071C */ { "LINEAR A SIGN A628","	x (linear a sign a304 - 10658)"},
/* 1071D */ { "LINEAR A SIGN A629","	* 10658 a304, 10602 ab003"},
/* 1071E */ { "LINEAR A SIGN A634","	* 1065A a306, 1063B ab073"},
/* 1071F */ { "LINEAR A SIGN A637","	* 1065B a307, 10655 a301"},
/* 10720 */ { "LINEAR A SIGN A638","	* 1065B a307, 1065B a307"},
/* 10721 */ { "LINEAR A SIGN A640","	* 10668 a316, 10638 ab067"},
/* 10722 */ { "LINEAR A SIGN A642","	x (linear a sign a318 - 1066A)"},
/* 10723 */ { "LINEAR A SIGN A643","	* 10676 a330, 10600 ab001"},
/* 10724 */ { "LINEAR A SIGN A644","	* 10676 a330, 1061E ab031"},
/* 10725 */ { "LINEAR A SIGN A645","	* 1067D a337, 10653 ab188"},
/* 10726 */ { "LINEAR A SIGN A646","	* 10681 a341, 10622 ab039"},
/* 10727 */ { "LINEAR A SIGN A648","	* 106A0 a400-vas, 1062D ab053"},
/* 10728 */ { "LINEAR A SIGN A649","	x (linear a sign a401-vas - 106A1)"},
/* 10729 */ { "LINEAR A SIGN A651","	* 106A1 a401-vas, 10618 ab026"},
/* 1072A */ { "LINEAR A SIGN A652","	* 106A1 a401-vas, 10634 ab060"},
/* 1072B */ { "LINEAR A SIGN A653","	* 106A1 a401-vas, 10658 a304"},
/* 1072C */ { "LINEAR A SIGN A654","	* 106A4 a404-vas, 10607 ab008"},
/* 1072D */ { "LINEAR A SIGN A655","	* 106A5 a405-vas, 10750 a713 omega"},
/* 1072E */ { "LINEAR A SIGN A656","	* 106A6 a406-vas, 10625 ab044"},
/* 1072F */ { "LINEAR A SIGN A657","	* 106A7 a407-vas, 10607 ab008"},
/* 10730 */ { "LINEAR A SIGN A658","	* 106AC a412-vas, 10743 a704 e"},
/* 10731 */ { "LINEAR A SIGN A659","	* 106AC a412-vas, 10744 a705 f"},
/* 10732 */ { "LINEAR A SIGN A660","	* 106AD a413-vas, 10632 ab058"},
/* 10733 */ { "LINEAR A SIGN A661","	x (linear a sign a414-vas - 106AE)"},
/* 10734 */ { "LINEAR A SIGN A662","	* 106AE a414-vas, 10744 a705 f"},
/* 10735 */ { "LINEAR A SIGN A663","	* 106B1 a417-vas, 10749 a709-2 l2"},
/* 10736 */ { "LINEAR A SIGN A664","	* 106B2 a418-vas, 10749 a709-2 l2"},
/* 10737 */ { NULL,NULL},
/* 10738 */ { NULL,NULL},
/* 10739 */ { NULL,NULL},
/* 1073A */ { NULL,NULL},
/* 1073B */ { NULL,NULL},
/* 1073C */ { NULL,NULL},
/* 1073D */ { NULL,NULL},
/* 1073E */ { NULL,NULL},
/* 1073F */ { NULL,NULL},
/* 10740 */ { "LINEAR A SIGN A701 A","	* possibly one sixth (value uncertain)\n"
	"	x (thermodynamic - 29E7)"},
/* 10741 */ { "LINEAR A SIGN A702 B","	* one third"},
/* 10742 */ { "LINEAR A SIGN A703 D","	* one fifth"},
/* 10743 */ { "LINEAR A SIGN A704 E","	* one quarter"},
/* 10744 */ { "LINEAR A SIGN A705 F","	* one eighth"},
/* 10745 */ { "LINEAR A SIGN A706 H","	* possibly one sixth (value uncertain)"},
/* 10746 */ { "LINEAR A SIGN A707 J","	* one half"},
/* 10747 */ { "LINEAR A SIGN A708 K","	* one sixteenth\n"
	"	x (aegean dry measure first subunit - 1013C)"},
/* 10748 */ { "LINEAR A SIGN A709 L",NULL},
/* 10749 */ { "LINEAR A SIGN A709-2 L2",NULL},
/* 1074A */ { "LINEAR A SIGN A709-3 L3",NULL},
/* 1074B */ { "LINEAR A SIGN A709-4 L4",NULL},
/* 1074C */ { "LINEAR A SIGN A709-6 L6","	* used with 10655 linear a sign a301"},
/* 1074D */ { "LINEAR A SIGN A710 W",NULL},
/* 1074E */ { "LINEAR A SIGN A711 X","	x (aegean weight second subunit - 10139)"},
/* 1074F */ { "LINEAR A SIGN A712 Y","	x (runic letter wunjo wynn w - 16B9)"},
/* 10750 */ { "LINEAR A SIGN A713 OMEGA","	* used with 106A5 linear a sign a405-vas"},
/* 10751 */ { "LINEAR A SIGN A714 ABB",NULL},
/* 10752 */ { "LINEAR A SIGN A715 BB",NULL},
/* 10753 */ { "LINEAR A SIGN A717 DD",NULL},
/* 10754 */ { "LINEAR A SIGN A726 EYYY",NULL},
/* 10755 */ { "LINEAR A SIGN A732 JE","	* three quarters"},
/* 10756 */ { NULL,NULL},
/* 10757 */ { NULL,NULL},
/* 10758 */ { NULL,NULL},
/* 10759 */ { NULL,NULL},
/* 1075A */ { NULL,NULL},
/* 1075B */ { NULL,NULL},
/* 1075C */ { NULL,NULL},
/* 1075D */ { NULL,NULL},
/* 1075E */ { NULL,NULL},
/* 1075F */ { NULL,NULL},
/* 10760 */ { "LINEAR A SIGN A800","	* 10603 ab004, 10607 ab008"},
/* 10761 */ { "LINEAR A SIGN A801","	* 1062E ab054, 10608 ab009"},
/* 10762 */ { "LINEAR A SIGN A802","	x (linear a sign ab060 - 10634)"},
/* 10763 */ { "LINEAR A SIGN A803","	* 1064D ab131a, 10762 a802"},
/* 10764 */ { "LINEAR A SIGN A804","	* 10652 ab180, 1061E ab031"},
/* 10765 */ { "LINEAR A SIGN A805","	x (linear a sign a301 - 10655)"},
/* 10766 */ { "LINEAR A SIGN A806","	* 10668 a316, 10601 ab002"},
/* 10767 */ { "LINEAR A SIGN A807","	* 10668 a316, 10742 a703 d"},
/* 10768 */ { NULL,NULL},
/* 10769 */ { NULL,NULL},
/* 1076A */ { NULL,NULL},
/* 1076B */ { NULL,NULL},
/* 1076C */ { NULL,NULL},
/* 1076D */ { NULL,NULL},
/* 1076E */ { NULL,NULL},
/* 1076F */ { NULL,NULL},
/* 10770 */ { NULL,NULL},
/* 10771 */ { NULL,NULL},
/* 10772 */ { NULL,NULL},
/* 10773 */ { NULL,NULL},
/* 10774 */ { NULL,NULL},
/* 10775 */ { NULL,NULL},
/* 10776 */ { NULL,NULL},
/* 10777 */ { NULL,NULL},
/* 10778 */ { NULL,NULL},
/* 10779 */ { NULL,NULL},
/* 1077A */ { NULL,NULL},
/* 1077B */ { NULL,NULL},
/* 1077C */ { NULL,NULL},
/* 1077D */ { NULL,NULL},
/* 1077E */ { NULL,NULL},
/* 1077F */ { NULL,NULL},
/* 10780 */ { "MODIFIER LETTER SMALL CAPITAL AA","	* actually a small capital in VoQS (voice quality symbol) usage, with no semantic distinction from a full capital\n"
	"	x (latin capital letter aa - A732)"},
/* 10781 */ { "MODIFIER LETTER SUPERSCRIPT TRIANGULAR COLON","	# <super> 02D0"},
/* 10782 */ { "MODIFIER LETTER SUPERSCRIPT HALF TRIANGULAR COLON","	# <super> 02D1"},
/* 10783 */ { "MODIFIER LETTER SMALL AE","	# <super> 00E6"},
/* 10784 */ { "MODIFIER LETTER SMALL CAPITAL B","	# <super> 0299"},
/* 10785 */ { "MODIFIER LETTER SMALL B WITH HOOK","	# <super> 0253"},
/* 10786 */ { NULL,NULL},
/* 10787 */ { "MODIFIER LETTER SMALL DZ DIGRAPH","	# <super> 02A3"},
/* 10788 */ { "MODIFIER LETTER SMALL DZ DIGRAPH WITH RETROFLEX HOOK","	# <super> AB66"},
/* 10789 */ { "MODIFIER LETTER SMALL DZ DIGRAPH WITH CURL","	# <super> 02A5"},
/* 1078A */ { "MODIFIER LETTER SMALL DEZH DIGRAPH","	# <super> 02A4"},
/* 1078B */ { "MODIFIER LETTER SMALL D WITH TAIL","	# <super> 0256"},
/* 1078C */ { "MODIFIER LETTER SMALL D WITH HOOK","	# <super> 0257"},
/* 1078D */ { "MODIFIER LETTER SMALL D WITH HOOK AND TAIL","	# <super> 1D91"},
/* 1078E */ { "MODIFIER LETTER SMALL REVERSED E","	# <super> 0258"},
/* 1078F */ { "MODIFIER LETTER SMALL CLOSED REVERSED OPEN E","	# <super> 025E"},
/* 10790 */ { "MODIFIER LETTER SMALL FENG DIGRAPH","	# <super> 02A9"},
/* 10791 */ { "MODIFIER LETTER SMALL RAMS HORN","	# <super> 0264"},
/* 10792 */ { "MODIFIER LETTER SMALL CAPITAL G","	# <super> 0262"},
/* 10793 */ { "MODIFIER LETTER SMALL G WITH HOOK","	# <super> 0260"},
/* 10794 */ { "MODIFIER LETTER SMALL CAPITAL G WITH HOOK","	# <super> 029B"},
/* 10795 */ { "MODIFIER LETTER SMALL H WITH STROKE","	# <super> 0127"},
/* 10796 */ { "MODIFIER LETTER SMALL CAPITAL H","	# <super> 029C"},
/* 10797 */ { "MODIFIER LETTER SMALL HENG WITH HOOK","	# <super> 0267"},
/* 10798 */ { "MODIFIER LETTER SMALL DOTLESS J WITH STROKE AND HOOK","	# <super> 0284"},
/* 10799 */ { "MODIFIER LETTER SMALL LS DIGRAPH","	# <super> 02AA"},
/* 1079A */ { "MODIFIER LETTER SMALL LZ DIGRAPH","	# <super> 02AB"},
/* 1079B */ { "MODIFIER LETTER SMALL L WITH BELT","	# <super> 026C"},
/* 1079C */ { "MODIFIER LETTER SMALL CAPITAL L WITH BELT","	# <super> 1DF04"},
/* 1079D */ { "MODIFIER LETTER SMALL L WITH RETROFLEX HOOK AND BELT","	# <super> A78E"},
/* 1079E */ { "MODIFIER LETTER SMALL LEZH","	# <super> 026E"},
/* 1079F */ { "MODIFIER LETTER SMALL LEZH WITH RETROFLEX HOOK","	# <super> 1DF05"},
/* 107A0 */ { "MODIFIER LETTER SMALL TURNED Y","	# <super> 028E"},
/* 107A1 */ { "MODIFIER LETTER SMALL TURNED Y WITH BELT","	# <super> 1DF06"},
/* 107A2 */ { "MODIFIER LETTER SMALL O WITH STROKE","	# <super> 00F8"},
/* 107A3 */ { "MODIFIER LETTER SMALL CAPITAL OE","	# <super> 0276"},
/* 107A4 */ { "MODIFIER LETTER SMALL CLOSED OMEGA","	# <super> 0277"},
/* 107A5 */ { "MODIFIER LETTER SMALL Q","	# <super> 0071"},
/* 107A6 */ { "MODIFIER LETTER SMALL TURNED R WITH LONG LEG","	# <super> 027A"},
/* 107A7 */ { "MODIFIER LETTER SMALL TURNED R WITH LONG LEG AND RETROFLEX HOOK","	# <super> 1DF08"},
/* 107A8 */ { "MODIFIER LETTER SMALL R WITH TAIL","	# <super> 027D"},
/* 107A9 */ { "MODIFIER LETTER SMALL R WITH FISHHOOK","	# <super> 027E"},
/* 107AA */ { "MODIFIER LETTER SMALL CAPITAL R","	# <super> 0280"},
/* 107AB */ { "MODIFIER LETTER SMALL TC DIGRAPH WITH CURL","	# <super> 02A8"},
/* 107AC */ { "MODIFIER LETTER SMALL TS DIGRAPH","	# <super> 02A6"},
/* 107AD */ { "MODIFIER LETTER SMALL TS DIGRAPH WITH RETROFLEX HOOK","	# <super> AB67"},
/* 107AE */ { "MODIFIER LETTER SMALL TESH DIGRAPH","	# <super> 02A7"},
/* 107AF */ { "MODIFIER LETTER SMALL T WITH RETROFLEX HOOK","	# <super> 0288"},
/* 107B0 */ { "MODIFIER LETTER SMALL V WITH RIGHT HOOK","	# <super> 2C71"},
/* 107B1 */ { NULL,NULL},
/* 107B2 */ { "MODIFIER LETTER SMALL CAPITAL Y","	# <super> 028F"},
/* 107B3 */ { "MODIFIER LETTER GLOTTAL STOP WITH STROKE","	# <super> 02A1"},
/* 107B4 */ { "MODIFIER LETTER REVERSED GLOTTAL STOP WITH STROKE","	# <super> 02A2"},
/* 107B5 */ { "MODIFIER LETTER BILABIAL CLICK","	# <super> 0298"},
/* 107B6 */ { "MODIFIER LETTER DENTAL CLICK","	# <super> 01C0"},
/* 107B7 */ { "MODIFIER LETTER LATERAL CLICK","	# <super> 01C1"},
/* 107B8 */ { "MODIFIER LETTER ALVEOLAR CLICK","	# <super> 01C2"},
/* 107B9 */ { "MODIFIER LETTER RETROFLEX CLICK WITH RETROFLEX HOOK","	x (modifier letter raised exclamation mark - A71D)\n"
	"	# <super> 1DF0A"},
/* 107BA */ { "MODIFIER LETTER SMALL S WITH CURL","	# <super> 1DF1E"},
/* 107BB */ { NULL,NULL},
/* 107BC */ { NULL,NULL},
/* 107BD */ { NULL,NULL},
/* 107BE */ { NULL,NULL},
/* 107BF */ { NULL,NULL},
/* 107C0 */ { NULL,NULL},
/* 107C1 */ { NULL,NULL},
/* 107C2 */ { NULL,NULL},
/* 107C3 */ { NULL,NULL},
/* 107C4 */ { NULL,NULL},
/* 107C5 */ { NULL,NULL},
/* 107C6 */ { NULL,NULL},
/* 107C7 */ { NULL,NULL},
/* 107C8 */ { NULL,NULL},
/* 107C9 */ { NULL,NULL},
/* 107CA */ { NULL,NULL},
/* 107CB */ { NULL,NULL},
/* 107CC */ { NULL,NULL},
/* 107CD */ { NULL,NULL},
/* 107CE */ { NULL,NULL},
/* 107CF */ { NULL,NULL},
/* 107D0 */ { NULL,NULL},
/* 107D1 */ { NULL,NULL},
/* 107D2 */ { NULL,NULL},
/* 107D3 */ { NULL,NULL},
/* 107D4 */ { NULL,NULL},
/* 107D5 */ { NULL,NULL},
/* 107D6 */ { NULL,NULL},
/* 107D7 */ { NULL,NULL},
/* 107D8 */ { NULL,NULL},
/* 107D9 */ { NULL,NULL},
/* 107DA */ { NULL,NULL},
/* 107DB */ { NULL,NULL},
/* 107DC */ { NULL,NULL},
/* 107DD */ { NULL,NULL},
/* 107DE */ { NULL,NULL},
/* 107DF */ { NULL,NULL},
/* 107E0 */ { NULL,NULL},
/* 107E1 */ { NULL,NULL},
/* 107E2 */ { NULL,NULL},
/* 107E3 */ { NULL,NULL},
/* 107E4 */ { NULL,NULL},
/* 107E5 */ { NULL,NULL},
/* 107E6 */ { NULL,NULL},
/* 107E7 */ { NULL,NULL},
/* 107E8 */ { NULL,NULL},
/* 107E9 */ { NULL,NULL},
/* 107EA */ { NULL,NULL},
/* 107EB */ { NULL,NULL},
/* 107EC */ { NULL,NULL},
/* 107ED */ { NULL,NULL},
/* 107EE */ { NULL,NULL},
/* 107EF */ { NULL,NULL},
/* 107F0 */ { NULL,NULL},
/* 107F1 */ { NULL,NULL},
/* 107F2 */ { NULL,NULL},
/* 107F3 */ { NULL,NULL},
/* 107F4 */ { NULL,NULL},
/* 107F5 */ { NULL,NULL},
/* 107F6 */ { NULL,NULL},
/* 107F7 */ { NULL,NULL},
/* 107F8 */ { NULL,NULL},
/* 107F9 */ { NULL,NULL},
/* 107FA */ { NULL,NULL},
/* 107FB */ { NULL,NULL},
/* 107FC */ { NULL,NULL},
/* 107FD */ { NULL,NULL},
/* 107FE */ { NULL,NULL},
/* 107FF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_08[] = {
/* 10800 */ { "CYPRIOT SYLLABLE A",NULL},
/* 10801 */ { "CYPRIOT SYLLABLE E",NULL},
/* 10802 */ { "CYPRIOT SYLLABLE I",NULL},
/* 10803 */ { "CYPRIOT SYLLABLE O",NULL},
/* 10804 */ { "CYPRIOT SYLLABLE U",NULL},
/* 10805 */ { "CYPRIOT SYLLABLE JA",NULL},
/* 10806 */ { NULL,NULL},
/* 10807 */ { NULL,NULL},
/* 10808 */ { "CYPRIOT SYLLABLE JO",NULL},
/* 10809 */ { NULL,NULL},
/* 1080A */ { "CYPRIOT SYLLABLE KA",NULL},
/* 1080B */ { "CYPRIOT SYLLABLE KE",NULL},
/* 1080C */ { "CYPRIOT SYLLABLE KI",NULL},
/* 1080D */ { "CYPRIOT SYLLABLE KO",NULL},
/* 1080E */ { "CYPRIOT SYLLABLE KU",NULL},
/* 1080F */ { "CYPRIOT SYLLABLE LA",NULL},
/* 10810 */ { "CYPRIOT SYLLABLE LE",NULL},
/* 10811 */ { "CYPRIOT SYLLABLE LI",NULL},
/* 10812 */ { "CYPRIOT SYLLABLE LO",NULL},
/* 10813 */ { "CYPRIOT SYLLABLE LU",NULL},
/* 10814 */ { "CYPRIOT SYLLABLE MA",NULL},
/* 10815 */ { "CYPRIOT SYLLABLE ME",NULL},
/* 10816 */ { "CYPRIOT SYLLABLE MI",NULL},
/* 10817 */ { "CYPRIOT SYLLABLE MO",NULL},
/* 10818 */ { "CYPRIOT SYLLABLE MU",NULL},
/* 10819 */ { "CYPRIOT SYLLABLE NA",NULL},
/* 1081A */ { "CYPRIOT SYLLABLE NE",NULL},
/* 1081B */ { "CYPRIOT SYLLABLE NI",NULL},
/* 1081C */ { "CYPRIOT SYLLABLE NO",NULL},
/* 1081D */ { "CYPRIOT SYLLABLE NU",NULL},
/* 1081E */ { "CYPRIOT SYLLABLE PA",NULL},
/* 1081F */ { "CYPRIOT SYLLABLE PE",NULL},
/* 10820 */ { "CYPRIOT SYLLABLE PI",NULL},
/* 10821 */ { "CYPRIOT SYLLABLE PO",NULL},
/* 10822 */ { "CYPRIOT SYLLABLE PU",NULL},
/* 10823 */ { "CYPRIOT SYLLABLE RA",NULL},
/* 10824 */ { "CYPRIOT SYLLABLE RE",NULL},
/* 10825 */ { "CYPRIOT SYLLABLE RI",NULL},
/* 10826 */ { "CYPRIOT SYLLABLE RO",NULL},
/* 10827 */ { "CYPRIOT SYLLABLE RU",NULL},
/* 10828 */ { "CYPRIOT SYLLABLE SA",NULL},
/* 10829 */ { "CYPRIOT SYLLABLE SE",NULL},
/* 1082A */ { "CYPRIOT SYLLABLE SI",NULL},
/* 1082B */ { "CYPRIOT SYLLABLE SO",NULL},
/* 1082C */ { "CYPRIOT SYLLABLE SU",NULL},
/* 1082D */ { "CYPRIOT SYLLABLE TA",NULL},
/* 1082E */ { "CYPRIOT SYLLABLE TE",NULL},
/* 1082F */ { "CYPRIOT SYLLABLE TI",NULL},
/* 10830 */ { "CYPRIOT SYLLABLE TO",NULL},
/* 10831 */ { "CYPRIOT SYLLABLE TU",NULL},
/* 10832 */ { "CYPRIOT SYLLABLE WA",NULL},
/* 10833 */ { "CYPRIOT SYLLABLE WE",NULL},
/* 10834 */ { "CYPRIOT SYLLABLE WI",NULL},
/* 10835 */ { "CYPRIOT SYLLABLE WO",NULL},
/* 10836 */ { NULL,NULL},
/* 10837 */ { "CYPRIOT SYLLABLE XA",NULL},
/* 10838 */ { "CYPRIOT SYLLABLE XE",NULL},
/* 10839 */ { NULL,NULL},
/* 1083A */ { NULL,NULL},
/* 1083B */ { NULL,NULL},
/* 1083C */ { "CYPRIOT SYLLABLE ZA",NULL},
/* 1083D */ { NULL,NULL},
/* 1083E */ { NULL,NULL},
/* 1083F */ { "CYPRIOT SYLLABLE ZO",NULL},
/* 10840 */ { "IMPERIAL ARAMAIC LETTER ALEPH",NULL},
/* 10841 */ { "IMPERIAL ARAMAIC LETTER BETH",NULL},
/* 10842 */ { "IMPERIAL ARAMAIC LETTER GIMEL",NULL},
/* 10843 */ { "IMPERIAL ARAMAIC LETTER DALETH",NULL},
/* 10844 */ { "IMPERIAL ARAMAIC LETTER HE",NULL},
/* 10845 */ { "IMPERIAL ARAMAIC LETTER WAW",NULL},
/* 10846 */ { "IMPERIAL ARAMAIC LETTER ZAYIN",NULL},
/* 10847 */ { "IMPERIAL ARAMAIC LETTER HETH",NULL},
/* 10848 */ { "IMPERIAL ARAMAIC LETTER TETH",NULL},
/* 10849 */ { "IMPERIAL ARAMAIC LETTER YODH",NULL},
/* 1084A */ { "IMPERIAL ARAMAIC LETTER KAPH",NULL},
/* 1084B */ { "IMPERIAL ARAMAIC LETTER LAMEDH",NULL},
/* 1084C */ { "IMPERIAL ARAMAIC LETTER MEM",NULL},
/* 1084D */ { "IMPERIAL ARAMAIC LETTER NUN",NULL},
/* 1084E */ { "IMPERIAL ARAMAIC LETTER SAMEKH",NULL},
/* 1084F */ { "IMPERIAL ARAMAIC LETTER AYIN",NULL},
/* 10850 */ { "IMPERIAL ARAMAIC LETTER PE",NULL},
/* 10851 */ { "IMPERIAL ARAMAIC LETTER SADHE",NULL},
/* 10852 */ { "IMPERIAL ARAMAIC LETTER QOPH",NULL},
/* 10853 */ { "IMPERIAL ARAMAIC LETTER RESH",NULL},
/* 10854 */ { "IMPERIAL ARAMAIC LETTER SHIN",NULL},
/* 10855 */ { "IMPERIAL ARAMAIC LETTER TAW",NULL},
/* 10856 */ { NULL,NULL},
/* 10857 */ { "IMPERIAL ARAMAIC SECTION SIGN",NULL},
/* 10858 */ { "IMPERIAL ARAMAIC NUMBER ONE",NULL},
/* 10859 */ { "IMPERIAL ARAMAIC NUMBER TWO",NULL},
/* 1085A */ { "IMPERIAL ARAMAIC NUMBER THREE",NULL},
/* 1085B */ { "IMPERIAL ARAMAIC NUMBER TEN",NULL},
/* 1085C */ { "IMPERIAL ARAMAIC NUMBER TWENTY",NULL},
/* 1085D */ { "IMPERIAL ARAMAIC NUMBER ONE HUNDRED",NULL},
/* 1085E */ { "IMPERIAL ARAMAIC NUMBER ONE THOUSAND",NULL},
/* 1085F */ { "IMPERIAL ARAMAIC NUMBER TEN THOUSAND",NULL},
/* 10860 */ { "PALMYRENE LETTER ALEPH",NULL},
/* 10861 */ { "PALMYRENE LETTER BETH",NULL},
/* 10862 */ { "PALMYRENE LETTER GIMEL",NULL},
/* 10863 */ { "PALMYRENE LETTER DALETH",NULL},
/* 10864 */ { "PALMYRENE LETTER HE",NULL},
/* 10865 */ { "PALMYRENE LETTER WAW",NULL},
/* 10866 */ { "PALMYRENE LETTER ZAYIN",NULL},
/* 10867 */ { "PALMYRENE LETTER HETH",NULL},
/* 10868 */ { "PALMYRENE LETTER TETH",NULL},
/* 10869 */ { "PALMYRENE LETTER YODH",NULL},
/* 1086A */ { "PALMYRENE LETTER KAPH",NULL},
/* 1086B */ { "PALMYRENE LETTER LAMEDH",NULL},
/* 1086C */ { "PALMYRENE LETTER MEM",NULL},
/* 1086D */ { "PALMYRENE LETTER FINAL NUN",NULL},
/* 1086E */ { "PALMYRENE LETTER NUN",NULL},
/* 1086F */ { "PALMYRENE LETTER SAMEKH",NULL},
/* 10870 */ { "PALMYRENE LETTER AYIN",NULL},
/* 10871 */ { "PALMYRENE LETTER PE",NULL},
/* 10872 */ { "PALMYRENE LETTER SADHE",NULL},
/* 10873 */ { "PALMYRENE LETTER QOPH",NULL},
/* 10874 */ { "PALMYRENE LETTER RESH",NULL},
/* 10875 */ { "PALMYRENE LETTER SHIN",NULL},
/* 10876 */ { "PALMYRENE LETTER TAW",NULL},
/* 10877 */ { "PALMYRENE LEFT-POINTING FLEURON",NULL},
/* 10878 */ { "PALMYRENE RIGHT-POINTING FLEURON",NULL},
/* 10879 */ { "PALMYRENE NUMBER ONE",NULL},
/* 1087A */ { "PALMYRENE NUMBER TWO",NULL},
/* 1087B */ { "PALMYRENE NUMBER THREE",NULL},
/* 1087C */ { "PALMYRENE NUMBER FOUR",NULL},
/* 1087D */ { "PALMYRENE NUMBER FIVE",NULL},
/* 1087E */ { "PALMYRENE NUMBER TEN","	* also used for hundreds"},
/* 1087F */ { "PALMYRENE NUMBER TWENTY",NULL},
/* 10880 */ { "NABATAEAN LETTER FINAL ALEPH",NULL},
/* 10881 */ { "NABATAEAN LETTER ALEPH",NULL},
/* 10882 */ { "NABATAEAN LETTER FINAL BETH",NULL},
/* 10883 */ { "NABATAEAN LETTER BETH",NULL},
/* 10884 */ { "NABATAEAN LETTER GIMEL",NULL},
/* 10885 */ { "NABATAEAN LETTER DALETH",NULL},
/* 10886 */ { "NABATAEAN LETTER FINAL HE",NULL},
/* 10887 */ { "NABATAEAN LETTER HE",NULL},
/* 10888 */ { "NABATAEAN LETTER WAW",NULL},
/* 10889 */ { "NABATAEAN LETTER ZAYIN",NULL},
/* 1088A */ { "NABATAEAN LETTER HETH",NULL},
/* 1088B */ { "NABATAEAN LETTER TETH",NULL},
/* 1088C */ { "NABATAEAN LETTER FINAL YODH",NULL},
/* 1088D */ { "NABATAEAN LETTER YODH",NULL},
/* 1088E */ { "NABATAEAN LETTER FINAL KAPH",NULL},
/* 1088F */ { "NABATAEAN LETTER KAPH",NULL},
/* 10890 */ { "NABATAEAN LETTER FINAL LAMEDH",NULL},
/* 10891 */ { "NABATAEAN LETTER LAMEDH",NULL},
/* 10892 */ { "NABATAEAN LETTER FINAL MEM",NULL},
/* 10893 */ { "NABATAEAN LETTER MEM",NULL},
/* 10894 */ { "NABATAEAN LETTER FINAL NUN",NULL},
/* 10895 */ { "NABATAEAN LETTER NUN",NULL},
/* 10896 */ { "NABATAEAN LETTER SAMEKH",NULL},
/* 10897 */ { "NABATAEAN LETTER AYIN",NULL},
/* 10898 */ { "NABATAEAN LETTER PE",NULL},
/* 10899 */ { "NABATAEAN LETTER SADHE",NULL},
/* 1089A */ { "NABATAEAN LETTER QOPH",NULL},
/* 1089B */ { "NABATAEAN LETTER RESH",NULL},
/* 1089C */ { "NABATAEAN LETTER FINAL SHIN",NULL},
/* 1089D */ { "NABATAEAN LETTER SHIN",NULL},
/* 1089E */ { "NABATAEAN LETTER TAW",NULL},
/* 1089F */ { NULL,NULL},
/* 108A0 */ { NULL,NULL},
/* 108A1 */ { NULL,NULL},
/* 108A2 */ { NULL,NULL},
/* 108A3 */ { NULL,NULL},
/* 108A4 */ { NULL,NULL},
/* 108A5 */ { NULL,NULL},
/* 108A6 */ { NULL,NULL},
/* 108A7 */ { "NABATAEAN NUMBER ONE",NULL},
/* 108A8 */ { "NABATAEAN NUMBER TWO",NULL},
/* 108A9 */ { "NABATAEAN NUMBER THREE",NULL},
/* 108AA */ { "NABATAEAN NUMBER FOUR",NULL},
/* 108AB */ { "NABATAEAN CRUCIFORM NUMBER FOUR",NULL},
/* 108AC */ { "NABATAEAN NUMBER FIVE",NULL},
/* 108AD */ { "NABATAEAN NUMBER TEN",NULL},
/* 108AE */ { "NABATAEAN NUMBER TWENTY",NULL},
/* 108AF */ { "NABATAEAN NUMBER ONE HUNDRED",NULL},
/* 108B0 */ { NULL,NULL},
/* 108B1 */ { NULL,NULL},
/* 108B2 */ { NULL,NULL},
/* 108B3 */ { NULL,NULL},
/* 108B4 */ { NULL,NULL},
/* 108B5 */ { NULL,NULL},
/* 108B6 */ { NULL,NULL},
/* 108B7 */ { NULL,NULL},
/* 108B8 */ { NULL,NULL},
/* 108B9 */ { NULL,NULL},
/* 108BA */ { NULL,NULL},
/* 108BB */ { NULL,NULL},
/* 108BC */ { NULL,NULL},
/* 108BD */ { NULL,NULL},
/* 108BE */ { NULL,NULL},
/* 108BF */ { NULL,NULL},
/* 108C0 */ { NULL,NULL},
/* 108C1 */ { NULL,NULL},
/* 108C2 */ { NULL,NULL},
/* 108C3 */ { NULL,NULL},
/* 108C4 */ { NULL,NULL},
/* 108C5 */ { NULL,NULL},
/* 108C6 */ { NULL,NULL},
/* 108C7 */ { NULL,NULL},
/* 108C8 */ { NULL,NULL},
/* 108C9 */ { NULL,NULL},
/* 108CA */ { NULL,NULL},
/* 108CB */ { NULL,NULL},
/* 108CC */ { NULL,NULL},
/* 108CD */ { NULL,NULL},
/* 108CE */ { NULL,NULL},
/* 108CF */ { NULL,NULL},
/* 108D0 */ { NULL,NULL},
/* 108D1 */ { NULL,NULL},
/* 108D2 */ { NULL,NULL},
/* 108D3 */ { NULL,NULL},
/* 108D4 */ { NULL,NULL},
/* 108D5 */ { NULL,NULL},
/* 108D6 */ { NULL,NULL},
/* 108D7 */ { NULL,NULL},
/* 108D8 */ { NULL,NULL},
/* 108D9 */ { NULL,NULL},
/* 108DA */ { NULL,NULL},
/* 108DB */ { NULL,NULL},
/* 108DC */ { NULL,NULL},
/* 108DD */ { NULL,NULL},
/* 108DE */ { NULL,NULL},
/* 108DF */ { NULL,NULL},
/* 108E0 */ { "HATRAN LETTER ALEPH",NULL},
/* 108E1 */ { "HATRAN LETTER BETH",NULL},
/* 108E2 */ { "HATRAN LETTER GIMEL",NULL},
/* 108E3 */ { "HATRAN LETTER DALETH-RESH",NULL},
/* 108E4 */ { "HATRAN LETTER HE",NULL},
/* 108E5 */ { "HATRAN LETTER WAW",NULL},
/* 108E6 */ { "HATRAN LETTER ZAYN",NULL},
/* 108E7 */ { "HATRAN LETTER HETH",NULL},
/* 108E8 */ { "HATRAN LETTER TETH",NULL},
/* 108E9 */ { "HATRAN LETTER YODH",NULL},
/* 108EA */ { "HATRAN LETTER KAPH",NULL},
/* 108EB */ { "HATRAN LETTER LAMEDH",NULL},
/* 108EC */ { "HATRAN LETTER MEM",NULL},
/* 108ED */ { "HATRAN LETTER NUN",NULL},
/* 108EE */ { "HATRAN LETTER SAMEKH",NULL},
/* 108EF */ { "HATRAN LETTER AYN",NULL},
/* 108F0 */ { "HATRAN LETTER PE",NULL},
/* 108F1 */ { "HATRAN LETTER SADHE",NULL},
/* 108F2 */ { "HATRAN LETTER QOPH",NULL},
/* 108F3 */ { NULL,NULL},
/* 108F4 */ { "HATRAN LETTER SHIN",NULL},
/* 108F5 */ { "HATRAN LETTER TAW",NULL},
/* 108F6 */ { NULL,NULL},
/* 108F7 */ { NULL,NULL},
/* 108F8 */ { NULL,NULL},
/* 108F9 */ { NULL,NULL},
/* 108FA */ { NULL,NULL},
/* 108FB */ { "HATRAN NUMBER ONE",NULL},
/* 108FC */ { "HATRAN NUMBER FIVE",NULL},
/* 108FD */ { "HATRAN NUMBER TEN",NULL},
/* 108FE */ { "HATRAN NUMBER TWENTY",NULL},
/* 108FF */ { "HATRAN NUMBER ONE HUNDRED",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_09[] = {
/* 10900 */ { "PHOENICIAN LETTER ALF","	x (hebrew letter alef - 05D0)"},
/* 10901 */ { "PHOENICIAN LETTER BET","	x (hebrew letter bet - 05D1)"},
/* 10902 */ { "PHOENICIAN LETTER GAML","	x (hebrew letter gimel - 05D2)"},
/* 10903 */ { "PHOENICIAN LETTER DELT","	x (hebrew letter dalet - 05D3)"},
/* 10904 */ { "PHOENICIAN LETTER HE","	x (hebrew letter he - 05D4)"},
/* 10905 */ { "PHOENICIAN LETTER WAU","	x (hebrew letter vav - 05D5)"},
/* 10906 */ { "PHOENICIAN LETTER ZAI","	x (hebrew letter zayin - 05D6)"},
/* 10907 */ { "PHOENICIAN LETTER HET","	x (hebrew letter het - 05D7)"},
/* 10908 */ { "PHOENICIAN LETTER TET","	x (hebrew letter tet - 05D8)"},
/* 10909 */ { "PHOENICIAN LETTER YOD","	x (hebrew letter yod - 05D9)"},
/* 1090A */ { "PHOENICIAN LETTER KAF","	x (hebrew letter kaf - 05DB)"},
/* 1090B */ { "PHOENICIAN LETTER LAMD","	x (hebrew letter lamed - 05DC)"},
/* 1090C */ { "PHOENICIAN LETTER MEM","	x (hebrew letter mem - 05DE)"},
/* 1090D */ { "PHOENICIAN LETTER NUN","	x (hebrew letter nun - 05E0)"},
/* 1090E */ { "PHOENICIAN LETTER SEMK","	x (hebrew letter samekh - 05E1)"},
/* 1090F */ { "PHOENICIAN LETTER AIN","	x (hebrew letter ayin - 05E2)"},
/* 10910 */ { "PHOENICIAN LETTER PE","	x (hebrew letter pe - 05E4)"},
/* 10911 */ { "PHOENICIAN LETTER SADE","	x (hebrew letter tsadi - 05E6)"},
/* 10912 */ { "PHOENICIAN LETTER QOF","	x (hebrew letter qof - 05E7)"},
/* 10913 */ { "PHOENICIAN LETTER ROSH","	x (hebrew letter resh - 05E8)"},
/* 10914 */ { "PHOENICIAN LETTER SHIN","	x (hebrew letter shin - 05E9)"},
/* 10915 */ { "PHOENICIAN LETTER TAU","	x (hebrew letter tav - 05EA)"},
/* 10916 */ { "PHOENICIAN NUMBER ONE",NULL},
/* 10917 */ { "PHOENICIAN NUMBER TEN",NULL},
/* 10918 */ { "PHOENICIAN NUMBER TWENTY",NULL},
/* 10919 */ { "PHOENICIAN NUMBER ONE HUNDRED",NULL},
/* 1091A */ { "PHOENICIAN NUMBER TWO",NULL},
/* 1091B */ { "PHOENICIAN NUMBER THREE",NULL},
/* 1091C */ { NULL,NULL},
/* 1091D */ { NULL,NULL},
/* 1091E */ { NULL,NULL},
/* 1091F */ { "PHOENICIAN WORD SEPARATOR","	* sometimes shown with a glyph for a short vertical bar\n"
	"	x (full stop - 002E)\n"
	"	x (middle dot - 00B7)\n"
	"	x (word separator middle dot - 2E31)"},
/* 10920 */ { "LYDIAN LETTER A",NULL},
/* 10921 */ { "LYDIAN LETTER B",NULL},
/* 10922 */ { "LYDIAN LETTER G",NULL},
/* 10923 */ { "LYDIAN LETTER D",NULL},
/* 10924 */ { "LYDIAN LETTER E",NULL},
/* 10925 */ { "LYDIAN LETTER V",NULL},
/* 10926 */ { "LYDIAN LETTER I",NULL},
/* 10927 */ { "LYDIAN LETTER Y",NULL},
/* 10928 */ { "LYDIAN LETTER K",NULL},
/* 10929 */ { "LYDIAN LETTER L",NULL},
/* 1092A */ { "LYDIAN LETTER M",NULL},
/* 1092B */ { "LYDIAN LETTER N",NULL},
/* 1092C */ { "LYDIAN LETTER O",NULL},
/* 1092D */ { "LYDIAN LETTER R",NULL},
/* 1092E */ { "LYDIAN LETTER SS",NULL},
/* 1092F */ { "LYDIAN LETTER T",NULL},
/* 10930 */ { "LYDIAN LETTER U",NULL},
/* 10931 */ { "LYDIAN LETTER F",NULL},
/* 10932 */ { "LYDIAN LETTER Q",NULL},
/* 10933 */ { "LYDIAN LETTER S",NULL},
/* 10934 */ { "LYDIAN LETTER TT",NULL},
/* 10935 */ { "LYDIAN LETTER AN",NULL},
/* 10936 */ { "LYDIAN LETTER EN",NULL},
/* 10937 */ { "LYDIAN LETTER LY",NULL},
/* 10938 */ { "LYDIAN LETTER NN",NULL},
/* 10939 */ { "LYDIAN LETTER C",NULL},
/* 1093A */ { NULL,NULL},
/* 1093B */ { NULL,NULL},
/* 1093C */ { NULL,NULL},
/* 1093D */ { NULL,NULL},
/* 1093E */ { NULL,NULL},
/* 1093F */ { "LYDIAN TRIANGULAR MARK",NULL},
/* 10940 */ { "SIDETIC LETTER N01","	* vowel a"},
/* 10941 */ { "SIDETIC LETTER N02","	* vowel e"},
/* 10942 */ { "SIDETIC LETTER N03","	* vowel i"},
/* 10943 */ { "SIDETIC LETTER N04","	* vowel o"},
/* 10944 */ { "SIDETIC LETTER N05","	* vowel u"},
/* 10945 */ { "SIDETIC LETTER N06","	* semivowel w"},
/* 10946 */ { "SIDETIC LETTER N07","	* semivowel y"},
/* 10947 */ { "SIDETIC LETTER N08","	* consonant p"},
/* 10948 */ { "SIDETIC LETTER N09","	* consonant d2"},
/* 10949 */ { "SIDETIC LETTER N10","	* consonant m"},
/* 1094A */ { "SIDETIC LETTER N11","	* consonant t"},
/* 1094B */ { "SIDETIC LETTER N12","	* consonant d"},
/* 1094C */ { "SIDETIC LETTER N13","	* consonant θ"},
/* 1094D */ { "SIDETIC LETTER N14","	* fricative consonant s"},
/* 1094E */ { "SIDETIC LETTER N15","	* fricative consonant s2"},
/* 1094F */ { "SIDETIC LETTER N16","	* consonant n"},
/* 10950 */ { "SIDETIC LETTER N17","	* consonant l"},
/* 10951 */ { "SIDETIC LETTER N18","	* consonant"},
/* 10952 */ { "SIDETIC LETTER N19","	* consonant g"},
/* 10953 */ { "SIDETIC LETTER N20","	* Greek chi"},
/* 10954 */ { "SIDETIC LETTER N21","	* consonant r"},
/* 10955 */ { "SIDETIC LETTER N22","	* vowel"},
/* 10956 */ { "SIDETIC LETTER N23","	* consonant k"},
/* 10957 */ { "SIDETIC LETTER N24","	* consonant b"},
/* 10958 */ { "SIDETIC LETTER N25","	* consonant n2"},
/* 10959 */ { "SIDETIC LETTER N26","	* consonant z"},
/* 1095A */ { NULL,NULL},
/* 1095B */ { NULL,NULL},
/* 1095C */ { NULL,NULL},
/* 1095D */ { NULL,NULL},
/* 1095E */ { NULL,NULL},
/* 1095F */ { NULL,NULL},
/* 10960 */ { NULL,NULL},
/* 10961 */ { NULL,NULL},
/* 10962 */ { NULL,NULL},
/* 10963 */ { NULL,NULL},
/* 10964 */ { NULL,NULL},
/* 10965 */ { NULL,NULL},
/* 10966 */ { NULL,NULL},
/* 10967 */ { NULL,NULL},
/* 10968 */ { NULL,NULL},
/* 10969 */ { NULL,NULL},
/* 1096A */ { NULL,NULL},
/* 1096B */ { NULL,NULL},
/* 1096C */ { NULL,NULL},
/* 1096D */ { NULL,NULL},
/* 1096E */ { NULL,NULL},
/* 1096F */ { NULL,NULL},
/* 10970 */ { NULL,NULL},
/* 10971 */ { NULL,NULL},
/* 10972 */ { NULL,NULL},
/* 10973 */ { NULL,NULL},
/* 10974 */ { NULL,NULL},
/* 10975 */ { NULL,NULL},
/* 10976 */ { NULL,NULL},
/* 10977 */ { NULL,NULL},
/* 10978 */ { NULL,NULL},
/* 10979 */ { NULL,NULL},
/* 1097A */ { NULL,NULL},
/* 1097B */ { NULL,NULL},
/* 1097C */ { NULL,NULL},
/* 1097D */ { NULL,NULL},
/* 1097E */ { NULL,NULL},
/* 1097F */ { NULL,NULL},
/* 10980 */ { "MEROITIC HIEROGLYPHIC LETTER A","	x (egyptian hieroglyph a001 - 13000)"},
/* 10981 */ { "MEROITIC HIEROGLYPHIC LETTER E","	x (egyptian hieroglyph h006 - 13184)"},
/* 10982 */ { "MEROITIC HIEROGLYPHIC LETTER I","	x (egyptian hieroglyph a026 - 1301E)"},
/* 10983 */ { "MEROITIC HIEROGLYPHIC LETTER O","	x (egyptian hieroglyph f001 - 130FE)"},
/* 10984 */ { "MEROITIC HIEROGLYPHIC LETTER YA","	x (egyptian hieroglyph m017a - 131CC)"},
/* 10985 */ { "MEROITIC HIEROGLYPHIC LETTER WA","	x (egyptian hieroglyph v004 - 1336F)"},
/* 10986 */ { "MEROITIC HIEROGLYPHIC LETTER BA","	x (egyptian hieroglyph e011 - 130DE)"},
/* 10987 */ { "MEROITIC HIEROGLYPHIC LETTER BA-2","	x (egyptian hieroglyph d058 - 130C0)"},
/* 10988 */ { "MEROITIC HIEROGLYPHIC LETTER PA","	x (egyptian hieroglyph q003 - 132AA)"},
/* 10989 */ { "MEROITIC HIEROGLYPHIC LETTER MA","	x (egyptian hieroglyph g017 - 13153)"},
/* 1098A */ { "MEROITIC HIEROGLYPHIC LETTER NA","	x (egyptian hieroglyph n035 - 13216)"},
/* 1098B */ { "MEROITIC HIEROGLYPHIC LETTER NA-2",NULL},
/* 1098C */ { "MEROITIC HIEROGLYPHIC LETTER NE","	x (egyptian hieroglyph m022a - 131D2)"},
/* 1098D */ { "MEROITIC HIEROGLYPHIC LETTER NE-2",NULL},
/* 1098E */ { "MEROITIC HIEROGLYPHIC LETTER RA","	x (egyptian hieroglyph d021 - 1308B)"},
/* 1098F */ { "MEROITIC HIEROGLYPHIC LETTER RA-2",NULL},
/* 10990 */ { "MEROITIC HIEROGLYPHIC LETTER LA","	x (egyptian hieroglyph e023 - 130ED)"},
/* 10991 */ { "MEROITIC HIEROGLYPHIC LETTER KHA","	x (egyptian hieroglyph aa001 - 1340D)"},
/* 10992 */ { "MEROITIC HIEROGLYPHIC LETTER HHA","	x (egyptian hieroglyph w011 - 133BC)"},
/* 10993 */ { "MEROITIC HIEROGLYPHIC LETTER SA","	x (egyptian hieroglyph m008 - 131B7)"},
/* 10994 */ { "MEROITIC HIEROGLYPHIC LETTER SA-2","	x (egyptian hieroglyph o034 - 13283)"},
/* 10995 */ { "MEROITIC HIEROGLYPHIC LETTER SE","	x (egyptian hieroglyph o034 - 13283)"},
/* 10996 */ { "MEROITIC HIEROGLYPHIC LETTER KA","	x (egyptian hieroglyph g038 - 1316C)"},
/* 10997 */ { "MEROITIC HIEROGLYPHIC LETTER QA","	x (egyptian hieroglyph n029 - 1320E)"},
/* 10998 */ { "MEROITIC HIEROGLYPHIC LETTER TA","	x (egyptian hieroglyph v013 - 1337F)"},
/* 10999 */ { "MEROITIC HIEROGLYPHIC LETTER TA-2","	x (egyptian hieroglyph n016 - 131FE)"},
/* 1099A */ { "MEROITIC HIEROGLYPHIC LETTER TE","	x (egyptian hieroglyph n016 - 131FE)\n"
	"	x (egyptian hieroglyph o004 - 13254)"},
/* 1099B */ { "MEROITIC HIEROGLYPHIC LETTER TE-2","	x (egyptian hieroglyph o004 - 13254)"},
/* 1099C */ { "MEROITIC HIEROGLYPHIC LETTER TO","	x (egyptian hieroglyph n021 - 13205)"},
/* 1099D */ { "MEROITIC HIEROGLYPHIC LETTER DA","	x (egyptian hieroglyph d006 - 1307B)"},
/* 1099E */ { "MEROITIC HIEROGLYPHIC SYMBOL VIDJ","	x (ankh - 2625)\n"
	"	x (egyptian hieroglyph s034 - 132F9)"},
/* 1099F */ { "MEROITIC HIEROGLYPHIC SYMBOL VIDJ-2",NULL},
/* 109A0 */ { "MEROITIC CURSIVE LETTER A",NULL},
/* 109A1 */ { "MEROITIC CURSIVE LETTER E",NULL},
/* 109A2 */ { "MEROITIC CURSIVE LETTER I",NULL},
/* 109A3 */ { "MEROITIC CURSIVE LETTER O",NULL},
/* 109A4 */ { "MEROITIC CURSIVE LETTER YA",NULL},
/* 109A5 */ { "MEROITIC CURSIVE LETTER WA",NULL},
/* 109A6 */ { "MEROITIC CURSIVE LETTER BA",NULL},
/* 109A7 */ { "MEROITIC CURSIVE LETTER PA",NULL},
/* 109A8 */ { "MEROITIC CURSIVE LETTER MA",NULL},
/* 109A9 */ { "MEROITIC CURSIVE LETTER NA",NULL},
/* 109AA */ { "MEROITIC CURSIVE LETTER NE",NULL},
/* 109AB */ { "MEROITIC CURSIVE LETTER RA",NULL},
/* 109AC */ { "MEROITIC CURSIVE LETTER LA",NULL},
/* 109AD */ { "MEROITIC CURSIVE LETTER KHA",NULL},
/* 109AE */ { "MEROITIC CURSIVE LETTER HHA",NULL},
/* 109AF */ { "MEROITIC CURSIVE LETTER SA",NULL},
/* 109B0 */ { "MEROITIC CURSIVE LETTER ARCHAIC SA",NULL},
/* 109B1 */ { "MEROITIC CURSIVE LETTER SE",NULL},
/* 109B2 */ { "MEROITIC CURSIVE LETTER KA",NULL},
/* 109B3 */ { "MEROITIC CURSIVE LETTER QA",NULL},
/* 109B4 */ { "MEROITIC CURSIVE LETTER TA",NULL},
/* 109B5 */ { "MEROITIC CURSIVE LETTER TE",NULL},
/* 109B6 */ { "MEROITIC CURSIVE LETTER TO",NULL},
/* 109B7 */ { "MEROITIC CURSIVE LETTER DA",NULL},
/* 109B8 */ { NULL,NULL},
/* 109B9 */ { NULL,NULL},
/* 109BA */ { NULL,NULL},
/* 109BB */ { NULL,NULL},
/* 109BC */ { "MEROITIC CURSIVE FRACTION ELEVEN TWELFTHS",NULL},
/* 109BD */ { "MEROITIC CURSIVE FRACTION ONE HALF",NULL},
/* 109BE */ { "MEROITIC CURSIVE LOGOGRAM RMT",NULL},
/* 109BF */ { "MEROITIC CURSIVE LOGOGRAM IMN",NULL},
/* 109C0 */ { "MEROITIC CURSIVE NUMBER ONE",NULL},
/* 109C1 */ { "MEROITIC CURSIVE NUMBER TWO",NULL},
/* 109C2 */ { "MEROITIC CURSIVE NUMBER THREE",NULL},
/* 109C3 */ { "MEROITIC CURSIVE NUMBER FOUR",NULL},
/* 109C4 */ { "MEROITIC CURSIVE NUMBER FIVE",NULL},
/* 109C5 */ { "MEROITIC CURSIVE NUMBER SIX",NULL},
/* 109C6 */ { "MEROITIC CURSIVE NUMBER SEVEN",NULL},
/* 109C7 */ { "MEROITIC CURSIVE NUMBER EIGHT",NULL},
/* 109C8 */ { "MEROITIC CURSIVE NUMBER NINE",NULL},
/* 109C9 */ { "MEROITIC CURSIVE NUMBER TEN",NULL},
/* 109CA */ { "MEROITIC CURSIVE NUMBER TWENTY",NULL},
/* 109CB */ { "MEROITIC CURSIVE NUMBER THIRTY",NULL},
/* 109CC */ { "MEROITIC CURSIVE NUMBER FORTY",NULL},
/* 109CD */ { "MEROITIC CURSIVE NUMBER FIFTY",NULL},
/* 109CE */ { "MEROITIC CURSIVE NUMBER SIXTY",NULL},
/* 109CF */ { "MEROITIC CURSIVE NUMBER SEVENTY",NULL},
/* 109D0 */ { NULL,NULL},
/* 109D1 */ { NULL,NULL},
/* 109D2 */ { "MEROITIC CURSIVE NUMBER ONE HUNDRED",NULL},
/* 109D3 */ { "MEROITIC CURSIVE NUMBER TWO HUNDRED",NULL},
/* 109D4 */ { "MEROITIC CURSIVE NUMBER THREE HUNDRED",NULL},
/* 109D5 */ { "MEROITIC CURSIVE NUMBER FOUR HUNDRED",NULL},
/* 109D6 */ { "MEROITIC CURSIVE NUMBER FIVE HUNDRED",NULL},
/* 109D7 */ { "MEROITIC CURSIVE NUMBER SIX HUNDRED",NULL},
/* 109D8 */ { "MEROITIC CURSIVE NUMBER SEVEN HUNDRED",NULL},
/* 109D9 */ { "MEROITIC CURSIVE NUMBER EIGHT HUNDRED",NULL},
/* 109DA */ { "MEROITIC CURSIVE NUMBER NINE HUNDRED",NULL},
/* 109DB */ { "MEROITIC CURSIVE NUMBER ONE THOUSAND",NULL},
/* 109DC */ { "MEROITIC CURSIVE NUMBER TWO THOUSAND",NULL},
/* 109DD */ { "MEROITIC CURSIVE NUMBER THREE THOUSAND",NULL},
/* 109DE */ { "MEROITIC CURSIVE NUMBER FOUR THOUSAND",NULL},
/* 109DF */ { "MEROITIC CURSIVE NUMBER FIVE THOUSAND",NULL},
/* 109E0 */ { "MEROITIC CURSIVE NUMBER SIX THOUSAND",NULL},
/* 109E1 */ { "MEROITIC CURSIVE NUMBER SEVEN THOUSAND",NULL},
/* 109E2 */ { "MEROITIC CURSIVE NUMBER EIGHT THOUSAND",NULL},
/* 109E3 */ { "MEROITIC CURSIVE NUMBER NINE THOUSAND",NULL},
/* 109E4 */ { "MEROITIC CURSIVE NUMBER TEN THOUSAND",NULL},
/* 109E5 */ { "MEROITIC CURSIVE NUMBER TWENTY THOUSAND",NULL},
/* 109E6 */ { "MEROITIC CURSIVE NUMBER THIRTY THOUSAND",NULL},
/* 109E7 */ { "MEROITIC CURSIVE NUMBER FORTY THOUSAND",NULL},
/* 109E8 */ { "MEROITIC CURSIVE NUMBER FIFTY THOUSAND",NULL},
/* 109E9 */ { "MEROITIC CURSIVE NUMBER SIXTY THOUSAND",NULL},
/* 109EA */ { "MEROITIC CURSIVE NUMBER SEVENTY THOUSAND",NULL},
/* 109EB */ { "MEROITIC CURSIVE NUMBER EIGHTY THOUSAND",NULL},
/* 109EC */ { "MEROITIC CURSIVE NUMBER NINETY THOUSAND",NULL},
/* 109ED */ { "MEROITIC CURSIVE NUMBER ONE HUNDRED THOUSAND",NULL},
/* 109EE */ { "MEROITIC CURSIVE NUMBER TWO HUNDRED THOUSAND",NULL},
/* 109EF */ { "MEROITIC CURSIVE NUMBER THREE HUNDRED THOUSAND",NULL},
/* 109F0 */ { "MEROITIC CURSIVE NUMBER FOUR HUNDRED THOUSAND",NULL},
/* 109F1 */ { "MEROITIC CURSIVE NUMBER FIVE HUNDRED THOUSAND",NULL},
/* 109F2 */ { "MEROITIC CURSIVE NUMBER SIX HUNDRED THOUSAND",NULL},
/* 109F3 */ { "MEROITIC CURSIVE NUMBER SEVEN HUNDRED THOUSAND",NULL},
/* 109F4 */ { "MEROITIC CURSIVE NUMBER EIGHT HUNDRED THOUSAND",NULL},
/* 109F5 */ { "MEROITIC CURSIVE NUMBER NINE HUNDRED THOUSAND",NULL},
/* 109F6 */ { "MEROITIC CURSIVE FRACTION ONE TWELFTH",NULL},
/* 109F7 */ { "MEROITIC CURSIVE FRACTION TWO TWELFTHS",NULL},
/* 109F8 */ { "MEROITIC CURSIVE FRACTION THREE TWELFTHS",NULL},
/* 109F9 */ { "MEROITIC CURSIVE FRACTION FOUR TWELFTHS",NULL},
/* 109FA */ { "MEROITIC CURSIVE FRACTION FIVE TWELFTHS",NULL},
/* 109FB */ { "MEROITIC CURSIVE FRACTION SIX TWELFTHS",NULL},
/* 109FC */ { "MEROITIC CURSIVE FRACTION SEVEN TWELFTHS",NULL},
/* 109FD */ { "MEROITIC CURSIVE FRACTION EIGHT TWELFTHS",NULL},
/* 109FE */ { "MEROITIC CURSIVE FRACTION NINE TWELFTHS",NULL},
/* 109FF */ { "MEROITIC CURSIVE FRACTION TEN TWELFTHS",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_0A[] = {
/* 10A00 */ { "KHAROSHTHI LETTER A",NULL},
/* 10A01 */ { "KHAROSHTHI VOWEL SIGN I",NULL},
/* 10A02 */ { "KHAROSHTHI VOWEL SIGN U",NULL},
/* 10A03 */ { "KHAROSHTHI VOWEL SIGN VOCALIC R",NULL},
/* 10A04 */ { NULL,NULL},
/* 10A05 */ { "KHAROSHTHI VOWEL SIGN E",NULL},
/* 10A06 */ { "KHAROSHTHI VOWEL SIGN O",NULL},
/* 10A07 */ { NULL,NULL},
/* 10A08 */ { NULL,NULL},
/* 10A09 */ { NULL,NULL},
/* 10A0A */ { NULL,NULL},
/* 10A0B */ { NULL,NULL},
/* 10A0C */ { "KHAROSHTHI VOWEL LENGTH MARK",NULL},
/* 10A0D */ { "KHAROSHTHI SIGN DOUBLE RING BELOW",NULL},
/* 10A0E */ { "KHAROSHTHI SIGN ANUSVARA",NULL},
/* 10A0F */ { "KHAROSHTHI SIGN VISARGA",NULL},
/* 10A10 */ { "KHAROSHTHI LETTER KA",NULL},
/* 10A11 */ { "KHAROSHTHI LETTER KHA",NULL},
/* 10A12 */ { "KHAROSHTHI LETTER GA",NULL},
/* 10A13 */ { "KHAROSHTHI LETTER GHA",NULL},
/* 10A14 */ { NULL,NULL},
/* 10A15 */ { "KHAROSHTHI LETTER CA",NULL},
/* 10A16 */ { "KHAROSHTHI LETTER CHA",NULL},
/* 10A17 */ { "KHAROSHTHI LETTER JA",NULL},
/* 10A18 */ { NULL,NULL},
/* 10A19 */ { "KHAROSHTHI LETTER NYA",NULL},
/* 10A1A */ { "KHAROSHTHI LETTER TTA",NULL},
/* 10A1B */ { "KHAROSHTHI LETTER TTHA",NULL},
/* 10A1C */ { "KHAROSHTHI LETTER DDA",NULL},
/* 10A1D */ { "KHAROSHTHI LETTER DDHA",NULL},
/* 10A1E */ { "KHAROSHTHI LETTER NNA",NULL},
/* 10A1F */ { "KHAROSHTHI LETTER TA",NULL},
/* 10A20 */ { "KHAROSHTHI LETTER THA",NULL},
/* 10A21 */ { "KHAROSHTHI LETTER DA",NULL},
/* 10A22 */ { "KHAROSHTHI LETTER DHA",NULL},
/* 10A23 */ { "KHAROSHTHI LETTER NA",NULL},
/* 10A24 */ { "KHAROSHTHI LETTER PA",NULL},
/* 10A25 */ { "KHAROSHTHI LETTER PHA",NULL},
/* 10A26 */ { "KHAROSHTHI LETTER BA",NULL},
/* 10A27 */ { "KHAROSHTHI LETTER BHA",NULL},
/* 10A28 */ { "KHAROSHTHI LETTER MA",NULL},
/* 10A29 */ { "KHAROSHTHI LETTER YA",NULL},
/* 10A2A */ { "KHAROSHTHI LETTER RA",NULL},
/* 10A2B */ { "KHAROSHTHI LETTER LA",NULL},
/* 10A2C */ { "KHAROSHTHI LETTER VA",NULL},
/* 10A2D */ { "KHAROSHTHI LETTER SHA",NULL},
/* 10A2E */ { "KHAROSHTHI LETTER SSA",NULL},
/* 10A2F */ { "KHAROSHTHI LETTER SA",NULL},
/* 10A30 */ { "KHAROSHTHI LETTER ZA",NULL},
/* 10A31 */ { "KHAROSHTHI LETTER HA",NULL},
/* 10A32 */ { "KHAROSHTHI LETTER KKA",NULL},
/* 10A33 */ { "KHAROSHTHI LETTER TTTHA",NULL},
/* 10A34 */ { "KHAROSHTHI LETTER TTTA",NULL},
/* 10A35 */ { "KHAROSHTHI LETTER VHA",NULL},
/* 10A36 */ { NULL,NULL},
/* 10A37 */ { NULL,NULL},
/* 10A38 */ { "KHAROSHTHI SIGN BAR ABOVE",NULL},
/* 10A39 */ { "KHAROSHTHI SIGN CAUDA",NULL},
/* 10A3A */ { "KHAROSHTHI SIGN DOT BELOW",NULL},
/* 10A3B */ { NULL,NULL},
/* 10A3C */ { NULL,NULL},
/* 10A3D */ { NULL,NULL},
/* 10A3E */ { NULL,NULL},
/* 10A3F */ { "KHAROSHTHI VIRAMA","	= halant\n"
	"	* suppresses inherent vowel\n"
	"	* shape shown is arbitrary and is not visibly rendered"},
/* 10A40 */ { "KHAROSHTHI DIGIT ONE",NULL},
/* 10A41 */ { "KHAROSHTHI DIGIT TWO",NULL},
/* 10A42 */ { "KHAROSHTHI DIGIT THREE",NULL},
/* 10A43 */ { "KHAROSHTHI DIGIT FOUR",NULL},
/* 10A44 */ { "KHAROSHTHI NUMBER TEN",NULL},
/* 10A45 */ { "KHAROSHTHI NUMBER TWENTY",NULL},
/* 10A46 */ { "KHAROSHTHI NUMBER ONE HUNDRED",NULL},
/* 10A47 */ { "KHAROSHTHI NUMBER ONE THOUSAND",NULL},
/* 10A48 */ { "KHAROSHTHI FRACTION ONE HALF",NULL},
/* 10A49 */ { NULL,NULL},
/* 10A4A */ { NULL,NULL},
/* 10A4B */ { NULL,NULL},
/* 10A4C */ { NULL,NULL},
/* 10A4D */ { NULL,NULL},
/* 10A4E */ { NULL,NULL},
/* 10A4F */ { NULL,NULL},
/* 10A50 */ { "KHAROSHTHI PUNCTUATION DOT",NULL},
/* 10A51 */ { "KHAROSHTHI PUNCTUATION SMALL CIRCLE",NULL},
/* 10A52 */ { "KHAROSHTHI PUNCTUATION CIRCLE",NULL},
/* 10A53 */ { "KHAROSHTHI PUNCTUATION CRESCENT BAR",NULL},
/* 10A54 */ { "KHAROSHTHI PUNCTUATION MANGALAM",NULL},
/* 10A55 */ { "KHAROSHTHI PUNCTUATION LOTUS",NULL},
/* 10A56 */ { "KHAROSHTHI PUNCTUATION DANDA",NULL},
/* 10A57 */ { "KHAROSHTHI PUNCTUATION DOUBLE DANDA",NULL},
/* 10A58 */ { "KHAROSHTHI PUNCTUATION LINES",NULL},
/* 10A59 */ { NULL,NULL},
/* 10A5A */ { NULL,NULL},
/* 10A5B */ { NULL,NULL},
/* 10A5C */ { NULL,NULL},
/* 10A5D */ { NULL,NULL},
/* 10A5E */ { NULL,NULL},
/* 10A5F */ { NULL,NULL},
/* 10A60 */ { "OLD SOUTH ARABIAN LETTER HE","	= heh\n"
	"	* transliterated as h\n"
	"	x (ethiopic syllable ha - 1200)"},
/* 10A61 */ { "OLD SOUTH ARABIAN LETTER LAMEDH","	= lam\n"
	"	* transliterated as l\n"
	"	x (ethiopic syllable la - 1208)"},
/* 10A62 */ { "OLD SOUTH ARABIAN LETTER HETH","	= hah\n"
	"	* transliterated as 1E25\n"
	"	x (ethiopic syllable hha - 1210)"},
/* 10A63 */ { "OLD SOUTH ARABIAN LETTER MEM","	= meem\n"
	"	* transliterated as m\n"
	"	x (ethiopic syllable ma - 1218)"},
/* 10A64 */ { "OLD SOUTH ARABIAN LETTER QOPH","	= qaf\n"
	"	* transliterated as q\n"
	"	x (ethiopic syllable qa - 1240)"},
/* 10A65 */ { "OLD SOUTH ARABIAN LETTER WAW","	= waw\n"
	"	* transliterated as w\n"
	"	x (ethiopic syllable wa - 12C8)"},
/* 10A66 */ { "OLD SOUTH ARABIAN LETTER SHIN","	= sheen\n"
	"	* transliterated as 0161 or s2\n"
	"	x (ethiopic syllable sza - 1220)"},
/* 10A67 */ { "OLD SOUTH ARABIAN LETTER RESH","	= reh\n"
	"	* transliterated as r\n"
	"	x (ethiopic syllable ra - 1228)"},
/* 10A68 */ { "OLD SOUTH ARABIAN LETTER BETH","	= beh\n"
	"	* transliterated as b\n"
	"	x (ethiopic syllable ba - 1260)"},
/* 10A69 */ { "OLD SOUTH ARABIAN LETTER TAW","	= teh\n"
	"	* transliterated as t\n"
	"	x (ethiopic syllable ta - 1270)"},
/* 10A6A */ { "OLD SOUTH ARABIAN LETTER SAT","	* transliterated as s or s1\n"
	"	x (ethiopic syllable sa - 1230)"},
/* 10A6B */ { "OLD SOUTH ARABIAN LETTER KAPH","	= kaf\n"
	"	* transliterated as k\n"
	"	x (ethiopic syllable ka - 12A8)"},
/* 10A6C */ { "OLD SOUTH ARABIAN LETTER NUN","	= noon\n"
	"	* transliterated as n\n"
	"	x (ethiopic syllable na - 1290)"},
/* 10A6D */ { "OLD SOUTH ARABIAN LETTER KHETH","	= khah\n"
	"	* transliterated as 1E2B\n"
	"	x (ethiopic syllable xa - 1280)"},
/* 10A6E */ { "OLD SOUTH ARABIAN LETTER SADHE","	= sad\n"
	"	* transliterated as 1E63\n"
	"	x (ethiopic syllable tsa - 1338)"},
/* 10A6F */ { "OLD SOUTH ARABIAN LETTER SAMEKH","	* transliterated as 015B or s3"},
/* 10A70 */ { "OLD SOUTH ARABIAN LETTER FE","	= feh\n"
	"	* transliterated as f\n"
	"	x (ethiopic syllable fa - 1348)"},
/* 10A71 */ { "OLD SOUTH ARABIAN LETTER ALEF","	= alef\n"
	"	* transliterated as 02BC\n"
	"	x (ethiopic syllable glottal a - 12A0)"},
/* 10A72 */ { "OLD SOUTH ARABIAN LETTER AYN","	= ain\n"
	"	* transliterated as 02BD\n"
	"	x (ethiopic syllable pharyngeal a - 12D0)"},
/* 10A73 */ { "OLD SOUTH ARABIAN LETTER DHADHE","	= dad\n"
	"	* transliterated as 1E0D\n"
	"	x (ethiopic syllable tza - 1340)"},
/* 10A74 */ { "OLD SOUTH ARABIAN LETTER GIMEL","	= jeem\n"
	"	* transliterated as g\n"
	"	x (ethiopic syllable ga - 1308)"},
/* 10A75 */ { "OLD SOUTH ARABIAN LETTER DALETH","	= dal\n"
	"	* transliterated as d\n"
	"	x (ethiopic syllable da - 12F0)"},
/* 10A76 */ { "OLD SOUTH ARABIAN LETTER GHAYN","	= ghain\n"
	"	* transliterated as 0121"},
/* 10A77 */ { "OLD SOUTH ARABIAN LETTER TETH","	= tah\n"
	"	* transliterated as 1E6D\n"
	"	x (ethiopic syllable tha - 1320)"},
/* 10A78 */ { "OLD SOUTH ARABIAN LETTER ZAYN","	= zain\n"
	"	* transliterated as z\n"
	"	x (ethiopic syllable za - 12D8)"},
/* 10A79 */ { "OLD SOUTH ARABIAN LETTER DHALETH","	= thal\n"
	"	* transliterated as 1E0F"},
/* 10A7A */ { "OLD SOUTH ARABIAN LETTER YODH","	= yeh\n"
	"	* transliterated as y\n"
	"	x (ethiopic syllable ya - 12E8)"},
/* 10A7B */ { "OLD SOUTH ARABIAN LETTER THAW","	= theh\n"
	"	* transliterated as 1E6F"},
/* 10A7C */ { "OLD SOUTH ARABIAN LETTER THETH","	= zah\n"
	"	* transliterated as 1E93"},
/* 10A7D */ { "OLD SOUTH ARABIAN NUMBER ONE",NULL},
/* 10A7E */ { "OLD SOUTH ARABIAN NUMBER FIFTY",NULL},
/* 10A7F */ { "OLD SOUTH ARABIAN NUMERIC INDICATOR",NULL},
/* 10A80 */ { "OLD NORTH ARABIAN LETTER HEH","	* transliterated as h\n"
	"	x (ethiopic syllable ha - 1200)\n"
	"	x (old south arabian letter he - 10A60)"},
/* 10A81 */ { "OLD NORTH ARABIAN LETTER LAM","	* transliterated as l\n"
	"	x (ethiopic syllable la - 1208)\n"
	"	x (old south arabian letter lamedh - 10A61)"},
/* 10A82 */ { "OLD NORTH ARABIAN LETTER HAH","	* transliterated as 1E25\n"
	"	x (ethiopic syllable hha - 1210)\n"
	"	x (old south arabian letter heth - 10A62)"},
/* 10A83 */ { "OLD NORTH ARABIAN LETTER MEEM","	* transliterated as m\n"
	"	x (ethiopic syllable ma - 1218)\n"
	"	x (old south arabian letter mem - 10A63)"},
/* 10A84 */ { "OLD NORTH ARABIAN LETTER QAF","	* transliterated as q\n"
	"	x (ethiopic syllable qa - 1240)\n"
	"	x (old south arabian letter qoph - 10A64)"},
/* 10A85 */ { "OLD NORTH ARABIAN LETTER WAW","	* transliterated as w\n"
	"	x (ethiopic syllable wa - 12C8)\n"
	"	x (old south arabian letter waw - 10A65)"},
/* 10A86 */ { "OLD NORTH ARABIAN LETTER ES-2","	* transliterated as s2\n"
	"	x (ethiopic syllable sza - 1220)\n"
	"	x (old south arabian letter shin - 10A66)"},
/* 10A87 */ { "OLD NORTH ARABIAN LETTER REH","	* transliterated as r\n"
	"	x (ethiopic syllable ra - 1228)\n"
	"	x (old south arabian letter resh - 10A67)"},
/* 10A88 */ { "OLD NORTH ARABIAN LETTER BEH","	* transliterated as b\n"
	"	x (ethiopic syllable ba - 1260)\n"
	"	x (old south arabian letter beth - 10A68)"},
/* 10A89 */ { "OLD NORTH ARABIAN LETTER TEH","	* transliterated as t\n"
	"	x (ethiopic syllable ta - 1270)\n"
	"	x (old south arabian letter taw - 10A69)"},
/* 10A8A */ { "OLD NORTH ARABIAN LETTER ES-1","	* transliterated as s1\n"
	"	x (ethiopic syllable sa - 1230)\n"
	"	x (old south arabian letter sat - 10A6A)"},
/* 10A8B */ { "OLD NORTH ARABIAN LETTER KAF","	* transliterated as k\n"
	"	x (ethiopic syllable ka - 12A8)\n"
	"	x (old south arabian letter kaph - 10A6B)"},
/* 10A8C */ { "OLD NORTH ARABIAN LETTER NOON","	* transliterated as n\n"
	"	x (ethiopic syllable na - 1290)\n"
	"	x (old south arabian letter nun - 10A6C)"},
/* 10A8D */ { "OLD NORTH ARABIAN LETTER KHAH","	* transliterated as 1E2B\n"
	"	x (ethiopic syllable xa - 1280)\n"
	"	x (old south arabian letter kheth - 10A6D)"},
/* 10A8E */ { "OLD NORTH ARABIAN LETTER SAD","	* transliterated as 1E63\n"
	"	x (ethiopic syllable tsa - 1338)\n"
	"	x (old south arabian letter sadhe - 10A6E)"},
/* 10A8F */ { "OLD NORTH ARABIAN LETTER ES-3","	* transliterated as s3\n"
	"	x (old south arabian letter samekh - 10A6F)"},
/* 10A90 */ { "OLD NORTH ARABIAN LETTER FEH","	* transliterated as f\n"
	"	x (ethiopic syllable fa - 1348)\n"
	"	x (old south arabian letter fe - 10A70)"},
/* 10A91 */ { "OLD NORTH ARABIAN LETTER ALEF","	* transliterated as 02BC\n"
	"	x (ethiopic syllable glottal a - 12A0)\n"
	"	x (old south arabian letter alef - 10A71)"},
/* 10A92 */ { "OLD NORTH ARABIAN LETTER AIN","	* transliterated as 02BD\n"
	"	x (ethiopic syllable pharyngeal a - 12D0)\n"
	"	x (old south arabian letter ayn - 10A72)"},
/* 10A93 */ { "OLD NORTH ARABIAN LETTER DAD","	* transliterated as 1E0D\n"
	"	x (ethiopic syllable tza - 1340)\n"
	"	x (old south arabian letter dhadhe - 10A73)"},
/* 10A94 */ { "OLD NORTH ARABIAN LETTER GEEM","	* transliterated as g\n"
	"	x (ethiopic syllable ga - 1308)\n"
	"	x (old south arabian letter gimel - 10A74)"},
/* 10A95 */ { "OLD NORTH ARABIAN LETTER DAL","	* transliterated as d\n"
	"	x (ethiopic syllable da - 12F0)\n"
	"	x (old south arabian letter daleth - 10A75)"},
/* 10A96 */ { "OLD NORTH ARABIAN LETTER GHAIN","	* transliterated as 0121\n"
	"	x (old south arabian letter ghayn - 10A76)"},
/* 10A97 */ { "OLD NORTH ARABIAN LETTER TAH","	* transliterated as 1E6D\n"
	"	x (ethiopic syllable tha - 1320)\n"
	"	x (old south arabian letter teth - 10A77)"},
/* 10A98 */ { "OLD NORTH ARABIAN LETTER ZAIN","	* transliterated as z\n"
	"	x (ethiopic syllable za - 12D8)\n"
	"	x (old south arabian letter zayn - 10A78)"},
/* 10A99 */ { "OLD NORTH ARABIAN LETTER THAL","	* transliterated as 1E0F\n"
	"	x (old south arabian letter dhaleth - 10A79)"},
/* 10A9A */ { "OLD NORTH ARABIAN LETTER YEH","	* transliterated as y\n"
	"	x (ethiopic syllable ya - 12E8)\n"
	"	x (old south arabian letter yodh - 10A7A)"},
/* 10A9B */ { "OLD NORTH ARABIAN LETTER THEH","	* transliterated as 1E6F\n"
	"	x (old south arabian letter thaw - 10A7B)"},
/* 10A9C */ { "OLD NORTH ARABIAN LETTER ZAH","	* transliterated as 1E93\n"
	"	x (old south arabian letter theth - 10A7C)"},
/* 10A9D */ { "OLD NORTH ARABIAN NUMBER ONE",NULL},
/* 10A9E */ { "OLD NORTH ARABIAN NUMBER TEN",NULL},
/* 10A9F */ { "OLD NORTH ARABIAN NUMBER TWENTY",NULL},
/* 10AA0 */ { NULL,NULL},
/* 10AA1 */ { NULL,NULL},
/* 10AA2 */ { NULL,NULL},
/* 10AA3 */ { NULL,NULL},
/* 10AA4 */ { NULL,NULL},
/* 10AA5 */ { NULL,NULL},
/* 10AA6 */ { NULL,NULL},
/* 10AA7 */ { NULL,NULL},
/* 10AA8 */ { NULL,NULL},
/* 10AA9 */ { NULL,NULL},
/* 10AAA */ { NULL,NULL},
/* 10AAB */ { NULL,NULL},
/* 10AAC */ { NULL,NULL},
/* 10AAD */ { NULL,NULL},
/* 10AAE */ { NULL,NULL},
/* 10AAF */ { NULL,NULL},
/* 10AB0 */ { NULL,NULL},
/* 10AB1 */ { NULL,NULL},
/* 10AB2 */ { NULL,NULL},
/* 10AB3 */ { NULL,NULL},
/* 10AB4 */ { NULL,NULL},
/* 10AB5 */ { NULL,NULL},
/* 10AB6 */ { NULL,NULL},
/* 10AB7 */ { NULL,NULL},
/* 10AB8 */ { NULL,NULL},
/* 10AB9 */ { NULL,NULL},
/* 10ABA */ { NULL,NULL},
/* 10ABB */ { NULL,NULL},
/* 10ABC */ { NULL,NULL},
/* 10ABD */ { NULL,NULL},
/* 10ABE */ { NULL,NULL},
/* 10ABF */ { NULL,NULL},
/* 10AC0 */ { "MANICHAEAN LETTER ALEPH",NULL},
/* 10AC1 */ { "MANICHAEAN LETTER BETH",NULL},
/* 10AC2 */ { "MANICHAEAN LETTER BHETH",NULL},
/* 10AC3 */ { "MANICHAEAN LETTER GIMEL",NULL},
/* 10AC4 */ { "MANICHAEAN LETTER GHIMEL",NULL},
/* 10AC5 */ { "MANICHAEAN LETTER DALETH","	~ 10AC5 FE00 alternate form (isolate)"},
/* 10AC6 */ { "MANICHAEAN LETTER HE","	~ 10AC6 FE00 alternate form (isolate)"},
/* 10AC7 */ { "MANICHAEAN LETTER WAW",NULL},
/* 10AC8 */ { "MANICHAEAN SIGN UD","	* represents the conjunction \"and\""},
/* 10AC9 */ { "MANICHAEAN LETTER ZAYIN",NULL},
/* 10ACA */ { "MANICHAEAN LETTER ZHAYIN",NULL},
/* 10ACB */ { "MANICHAEAN LETTER JAYIN",NULL},
/* 10ACC */ { "MANICHAEAN LETTER JHAYIN",NULL},
/* 10ACD */ { "MANICHAEAN LETTER HETH",NULL},
/* 10ACE */ { "MANICHAEAN LETTER TETH",NULL},
/* 10ACF */ { "MANICHAEAN LETTER YODH",NULL},
/* 10AD0 */ { "MANICHAEAN LETTER KAPH",NULL},
/* 10AD1 */ { "MANICHAEAN LETTER XAPH",NULL},
/* 10AD2 */ { "MANICHAEAN LETTER KHAPH",NULL},
/* 10AD3 */ { "MANICHAEAN LETTER LAMEDH",NULL},
/* 10AD4 */ { "MANICHAEAN LETTER DHAMEDH",NULL},
/* 10AD5 */ { "MANICHAEAN LETTER THAMEDH",NULL},
/* 10AD6 */ { "MANICHAEAN LETTER MEM","	~ 10AD6 FE00 alternate form (isolate)\n"
	"	~ 10AD6 FE00 alternate form (final)"},
/* 10AD7 */ { "MANICHAEAN LETTER NUN","	~ 10AD7 FE00 alternate form (isolate)"},
/* 10AD8 */ { "MANICHAEAN LETTER SAMEKH",NULL},
/* 10AD9 */ { "MANICHAEAN LETTER AYIN",NULL},
/* 10ADA */ { "MANICHAEAN LETTER AAYIN",NULL},
/* 10ADB */ { "MANICHAEAN LETTER PE",NULL},
/* 10ADC */ { "MANICHAEAN LETTER FE",NULL},
/* 10ADD */ { "MANICHAEAN LETTER SADHE",NULL},
/* 10ADE */ { "MANICHAEAN LETTER QOPH",NULL},
/* 10ADF */ { "MANICHAEAN LETTER XOPH",NULL},
/* 10AE0 */ { "MANICHAEAN LETTER QHOPH",NULL},
/* 10AE1 */ { "MANICHAEAN LETTER RESH","	~ 10AE1 FE00 alternate form (isolate)"},
/* 10AE2 */ { "MANICHAEAN LETTER SHIN",NULL},
/* 10AE3 */ { "MANICHAEAN LETTER SSHIN",NULL},
/* 10AE4 */ { "MANICHAEAN LETTER TAW",NULL},
/* 10AE5 */ { "MANICHAEAN ABBREVIATION MARK ABOVE",NULL},
/* 10AE6 */ { "MANICHAEAN ABBREVIATION MARK BELOW",NULL},
/* 10AE7 */ { NULL,NULL},
/* 10AE8 */ { NULL,NULL},
/* 10AE9 */ { NULL,NULL},
/* 10AEA */ { NULL,NULL},
/* 10AEB */ { "MANICHAEAN NUMBER ONE",NULL},
/* 10AEC */ { "MANICHAEAN NUMBER FIVE",NULL},
/* 10AED */ { "MANICHAEAN NUMBER TEN",NULL},
/* 10AEE */ { "MANICHAEAN NUMBER TWENTY",NULL},
/* 10AEF */ { "MANICHAEAN NUMBER ONE HUNDRED",NULL},
/* 10AF0 */ { "MANICHAEAN PUNCTUATION STAR",NULL},
/* 10AF1 */ { "MANICHAEAN PUNCTUATION FLEURON",NULL},
/* 10AF2 */ { "MANICHAEAN PUNCTUATION DOUBLE DOT WITHIN DOT",NULL},
/* 10AF3 */ { "MANICHAEAN PUNCTUATION DOT WITHIN DOT",NULL},
/* 10AF4 */ { "MANICHAEAN PUNCTUATION DOT",NULL},
/* 10AF5 */ { "MANICHAEAN PUNCTUATION TWO DOTS",NULL},
/* 10AF6 */ { "MANICHAEAN PUNCTUATION LINE FILLER",NULL},
/* 10AF7 */ { NULL,NULL},
/* 10AF8 */ { NULL,NULL},
/* 10AF9 */ { NULL,NULL},
/* 10AFA */ { NULL,NULL},
/* 10AFB */ { NULL,NULL},
/* 10AFC */ { NULL,NULL},
/* 10AFD */ { NULL,NULL},
/* 10AFE */ { NULL,NULL},
/* 10AFF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_0B[] = {
/* 10B00 */ { "AVESTAN LETTER A",NULL},
/* 10B01 */ { "AVESTAN LETTER AA",NULL},
/* 10B02 */ { "AVESTAN LETTER AO",NULL},
/* 10B03 */ { "AVESTAN LETTER AAO",NULL},
/* 10B04 */ { "AVESTAN LETTER AN",NULL},
/* 10B05 */ { "AVESTAN LETTER AAN",NULL},
/* 10B06 */ { "AVESTAN LETTER AE",NULL},
/* 10B07 */ { "AVESTAN LETTER AEE",NULL},
/* 10B08 */ { "AVESTAN LETTER E",NULL},
/* 10B09 */ { "AVESTAN LETTER EE",NULL},
/* 10B0A */ { "AVESTAN LETTER O",NULL},
/* 10B0B */ { "AVESTAN LETTER OO",NULL},
/* 10B0C */ { "AVESTAN LETTER I",NULL},
/* 10B0D */ { "AVESTAN LETTER II",NULL},
/* 10B0E */ { "AVESTAN LETTER U",NULL},
/* 10B0F */ { "AVESTAN LETTER UU",NULL},
/* 10B10 */ { "AVESTAN LETTER KE",NULL},
/* 10B11 */ { "AVESTAN LETTER XE",NULL},
/* 10B12 */ { "AVESTAN LETTER XYE",NULL},
/* 10B13 */ { "AVESTAN LETTER XVE",NULL},
/* 10B14 */ { "AVESTAN LETTER GE",NULL},
/* 10B15 */ { "AVESTAN LETTER GGE",NULL},
/* 10B16 */ { "AVESTAN LETTER GHE",NULL},
/* 10B17 */ { "AVESTAN LETTER CE",NULL},
/* 10B18 */ { "AVESTAN LETTER JE",NULL},
/* 10B19 */ { "AVESTAN LETTER TE",NULL},
/* 10B1A */ { "AVESTAN LETTER THE",NULL},
/* 10B1B */ { "AVESTAN LETTER DE",NULL},
/* 10B1C */ { "AVESTAN LETTER DHE",NULL},
/* 10B1D */ { "AVESTAN LETTER TTE",NULL},
/* 10B1E */ { "AVESTAN LETTER PE",NULL},
/* 10B1F */ { "AVESTAN LETTER FE",NULL},
/* 10B20 */ { "AVESTAN LETTER BE",NULL},
/* 10B21 */ { "AVESTAN LETTER BHE",NULL},
/* 10B22 */ { "AVESTAN LETTER NGE",NULL},
/* 10B23 */ { "AVESTAN LETTER NGYE",NULL},
/* 10B24 */ { "AVESTAN LETTER NGVE",NULL},
/* 10B25 */ { "AVESTAN LETTER NE",NULL},
/* 10B26 */ { "AVESTAN LETTER NYE",NULL},
/* 10B27 */ { "AVESTAN LETTER NNE",NULL},
/* 10B28 */ { "AVESTAN LETTER ME",NULL},
/* 10B29 */ { "AVESTAN LETTER HME",NULL},
/* 10B2A */ { "AVESTAN LETTER YYE",NULL},
/* 10B2B */ { "AVESTAN LETTER YE",NULL},
/* 10B2C */ { "AVESTAN LETTER VE",NULL},
/* 10B2D */ { "AVESTAN LETTER RE",NULL},
/* 10B2E */ { "AVESTAN LETTER LE",NULL},
/* 10B2F */ { "AVESTAN LETTER SE",NULL},
/* 10B30 */ { "AVESTAN LETTER ZE",NULL},
/* 10B31 */ { "AVESTAN LETTER SHE",NULL},
/* 10B32 */ { "AVESTAN LETTER ZHE",NULL},
/* 10B33 */ { "AVESTAN LETTER SHYE",NULL},
/* 10B34 */ { "AVESTAN LETTER SSHE",NULL},
/* 10B35 */ { "AVESTAN LETTER HE",NULL},
/* 10B36 */ { NULL,NULL},
/* 10B37 */ { NULL,NULL},
/* 10B38 */ { NULL,NULL},
/* 10B39 */ { "AVESTAN ABBREVIATION MARK","	x (ring operator - 2218)\n"
	"	x (ring point - 2E30)\n"
	"	x (word separator middle dot - 2E31)"},
/* 10B3A */ { "TINY TWO DOTS OVER ONE DOT PUNCTUATION",NULL},
/* 10B3B */ { "SMALL TWO DOTS OVER ONE DOT PUNCTUATION",NULL},
/* 10B3C */ { "LARGE TWO DOTS OVER ONE DOT PUNCTUATION",NULL},
/* 10B3D */ { "LARGE ONE DOT OVER TWO DOTS PUNCTUATION",NULL},
/* 10B3E */ { "LARGE TWO RINGS OVER ONE RING PUNCTUATION",NULL},
/* 10B3F */ { "LARGE ONE RING OVER TWO RINGS PUNCTUATION",NULL},
/* 10B40 */ { "INSCRIPTIONAL PARTHIAN LETTER ALEPH",NULL},
/* 10B41 */ { "INSCRIPTIONAL PARTHIAN LETTER BETH",NULL},
/* 10B42 */ { "INSCRIPTIONAL PARTHIAN LETTER GIMEL",NULL},
/* 10B43 */ { "INSCRIPTIONAL PARTHIAN LETTER DALETH",NULL},
/* 10B44 */ { "INSCRIPTIONAL PARTHIAN LETTER HE",NULL},
/* 10B45 */ { "INSCRIPTIONAL PARTHIAN LETTER WAW",NULL},
/* 10B46 */ { "INSCRIPTIONAL PARTHIAN LETTER ZAYIN",NULL},
/* 10B47 */ { "INSCRIPTIONAL PARTHIAN LETTER HETH",NULL},
/* 10B48 */ { "INSCRIPTIONAL PARTHIAN LETTER TETH",NULL},
/* 10B49 */ { "INSCRIPTIONAL PARTHIAN LETTER YODH",NULL},
/* 10B4A */ { "INSCRIPTIONAL PARTHIAN LETTER KAPH",NULL},
/* 10B4B */ { "INSCRIPTIONAL PARTHIAN LETTER LAMEDH",NULL},
/* 10B4C */ { "INSCRIPTIONAL PARTHIAN LETTER MEM",NULL},
/* 10B4D */ { "INSCRIPTIONAL PARTHIAN LETTER NUN",NULL},
/* 10B4E */ { "INSCRIPTIONAL PARTHIAN LETTER SAMEKH",NULL},
/* 10B4F */ { "INSCRIPTIONAL PARTHIAN LETTER AYIN",NULL},
/* 10B50 */ { "INSCRIPTIONAL PARTHIAN LETTER PE",NULL},
/* 10B51 */ { "INSCRIPTIONAL PARTHIAN LETTER SADHE",NULL},
/* 10B52 */ { "INSCRIPTIONAL PARTHIAN LETTER QOPH",NULL},
/* 10B53 */ { "INSCRIPTIONAL PARTHIAN LETTER RESH",NULL},
/* 10B54 */ { "INSCRIPTIONAL PARTHIAN LETTER SHIN",NULL},
/* 10B55 */ { "INSCRIPTIONAL PARTHIAN LETTER TAW",NULL},
/* 10B56 */ { NULL,NULL},
/* 10B57 */ { NULL,NULL},
/* 10B58 */ { "INSCRIPTIONAL PARTHIAN NUMBER ONE",NULL},
/* 10B59 */ { "INSCRIPTIONAL PARTHIAN NUMBER TWO",NULL},
/* 10B5A */ { "INSCRIPTIONAL PARTHIAN NUMBER THREE",NULL},
/* 10B5B */ { "INSCRIPTIONAL PARTHIAN NUMBER FOUR",NULL},
/* 10B5C */ { "INSCRIPTIONAL PARTHIAN NUMBER TEN",NULL},
/* 10B5D */ { "INSCRIPTIONAL PARTHIAN NUMBER TWENTY",NULL},
/* 10B5E */ { "INSCRIPTIONAL PARTHIAN NUMBER ONE HUNDRED",NULL},
/* 10B5F */ { "INSCRIPTIONAL PARTHIAN NUMBER ONE THOUSAND",NULL},
/* 10B60 */ { "INSCRIPTIONAL PAHLAVI LETTER ALEPH",NULL},
/* 10B61 */ { "INSCRIPTIONAL PAHLAVI LETTER BETH",NULL},
/* 10B62 */ { "INSCRIPTIONAL PAHLAVI LETTER GIMEL",NULL},
/* 10B63 */ { "INSCRIPTIONAL PAHLAVI LETTER DALETH",NULL},
/* 10B64 */ { "INSCRIPTIONAL PAHLAVI LETTER HE",NULL},
/* 10B65 */ { "INSCRIPTIONAL PAHLAVI LETTER WAW-AYIN-RESH",NULL},
/* 10B66 */ { "INSCRIPTIONAL PAHLAVI LETTER ZAYIN",NULL},
/* 10B67 */ { "INSCRIPTIONAL PAHLAVI LETTER HETH",NULL},
/* 10B68 */ { "INSCRIPTIONAL PAHLAVI LETTER TETH",NULL},
/* 10B69 */ { "INSCRIPTIONAL PAHLAVI LETTER YODH",NULL},
/* 10B6A */ { "INSCRIPTIONAL PAHLAVI LETTER KAPH",NULL},
/* 10B6B */ { "INSCRIPTIONAL PAHLAVI LETTER LAMEDH",NULL},
/* 10B6C */ { "INSCRIPTIONAL PAHLAVI LETTER MEM-QOPH",NULL},
/* 10B6D */ { "INSCRIPTIONAL PAHLAVI LETTER NUN",NULL},
/* 10B6E */ { "INSCRIPTIONAL PAHLAVI LETTER SAMEKH",NULL},
/* 10B6F */ { "INSCRIPTIONAL PAHLAVI LETTER PE",NULL},
/* 10B70 */ { "INSCRIPTIONAL PAHLAVI LETTER SADHE",NULL},
/* 10B71 */ { "INSCRIPTIONAL PAHLAVI LETTER SHIN",NULL},
/* 10B72 */ { "INSCRIPTIONAL PAHLAVI LETTER TAW",NULL},
/* 10B73 */ { NULL,NULL},
/* 10B74 */ { NULL,NULL},
/* 10B75 */ { NULL,NULL},
/* 10B76 */ { NULL,NULL},
/* 10B77 */ { NULL,NULL},
/* 10B78 */ { "INSCRIPTIONAL PAHLAVI NUMBER ONE",NULL},
/* 10B79 */ { "INSCRIPTIONAL PAHLAVI NUMBER TWO",NULL},
/* 10B7A */ { "INSCRIPTIONAL PAHLAVI NUMBER THREE",NULL},
/* 10B7B */ { "INSCRIPTIONAL PAHLAVI NUMBER FOUR",NULL},
/* 10B7C */ { "INSCRIPTIONAL PAHLAVI NUMBER TEN",NULL},
/* 10B7D */ { "INSCRIPTIONAL PAHLAVI NUMBER TWENTY",NULL},
/* 10B7E */ { "INSCRIPTIONAL PAHLAVI NUMBER ONE HUNDRED",NULL},
/* 10B7F */ { "INSCRIPTIONAL PAHLAVI NUMBER ONE THOUSAND",NULL},
/* 10B80 */ { "PSALTER PAHLAVI LETTER ALEPH",NULL},
/* 10B81 */ { "PSALTER PAHLAVI LETTER BETH",NULL},
/* 10B82 */ { "PSALTER PAHLAVI LETTER GIMEL",NULL},
/* 10B83 */ { "PSALTER PAHLAVI LETTER DALETH",NULL},
/* 10B84 */ { "PSALTER PAHLAVI LETTER HE",NULL},
/* 10B85 */ { "PSALTER PAHLAVI LETTER WAW-AYIN-RESH",NULL},
/* 10B86 */ { "PSALTER PAHLAVI LETTER ZAYIN",NULL},
/* 10B87 */ { "PSALTER PAHLAVI LETTER HETH",NULL},
/* 10B88 */ { "PSALTER PAHLAVI LETTER YODH",NULL},
/* 10B89 */ { "PSALTER PAHLAVI LETTER KAPH",NULL},
/* 10B8A */ { "PSALTER PAHLAVI LETTER LAMEDH",NULL},
/* 10B8B */ { "PSALTER PAHLAVI LETTER MEM-QOPH",NULL},
/* 10B8C */ { "PSALTER PAHLAVI LETTER NUN",NULL},
/* 10B8D */ { "PSALTER PAHLAVI LETTER SAMEKH",NULL},
/* 10B8E */ { "PSALTER PAHLAVI LETTER PE",NULL},
/* 10B8F */ { "PSALTER PAHLAVI LETTER SADHE",NULL},
/* 10B90 */ { "PSALTER PAHLAVI LETTER SHIN",NULL},
/* 10B91 */ { "PSALTER PAHLAVI LETTER TAW",NULL},
/* 10B92 */ { NULL,NULL},
/* 10B93 */ { NULL,NULL},
/* 10B94 */ { NULL,NULL},
/* 10B95 */ { NULL,NULL},
/* 10B96 */ { NULL,NULL},
/* 10B97 */ { NULL,NULL},
/* 10B98 */ { NULL,NULL},
/* 10B99 */ { "PSALTER PAHLAVI SECTION MARK",NULL},
/* 10B9A */ { "PSALTER PAHLAVI TURNED SECTION MARK",NULL},
/* 10B9B */ { "PSALTER PAHLAVI FOUR DOTS WITH CROSS",NULL},
/* 10B9C */ { "PSALTER PAHLAVI FOUR DOTS WITH DOT",NULL},
/* 10B9D */ { NULL,NULL},
/* 10B9E */ { NULL,NULL},
/* 10B9F */ { NULL,NULL},
/* 10BA0 */ { NULL,NULL},
/* 10BA1 */ { NULL,NULL},
/* 10BA2 */ { NULL,NULL},
/* 10BA3 */ { NULL,NULL},
/* 10BA4 */ { NULL,NULL},
/* 10BA5 */ { NULL,NULL},
/* 10BA6 */ { NULL,NULL},
/* 10BA7 */ { NULL,NULL},
/* 10BA8 */ { NULL,NULL},
/* 10BA9 */ { "PSALTER PAHLAVI NUMBER ONE",NULL},
/* 10BAA */ { "PSALTER PAHLAVI NUMBER TWO",NULL},
/* 10BAB */ { "PSALTER PAHLAVI NUMBER THREE",NULL},
/* 10BAC */ { "PSALTER PAHLAVI NUMBER FOUR",NULL},
/* 10BAD */ { "PSALTER PAHLAVI NUMBER TEN",NULL},
/* 10BAE */ { "PSALTER PAHLAVI NUMBER TWENTY",NULL},
/* 10BAF */ { "PSALTER PAHLAVI NUMBER ONE HUNDRED",NULL},
/* 10BB0 */ { NULL,NULL},
/* 10BB1 */ { NULL,NULL},
/* 10BB2 */ { NULL,NULL},
/* 10BB3 */ { NULL,NULL},
/* 10BB4 */ { NULL,NULL},
/* 10BB5 */ { NULL,NULL},
/* 10BB6 */ { NULL,NULL},
/* 10BB7 */ { NULL,NULL},
/* 10BB8 */ { NULL,NULL},
/* 10BB9 */ { NULL,NULL},
/* 10BBA */ { NULL,NULL},
/* 10BBB */ { NULL,NULL},
/* 10BBC */ { NULL,NULL},
/* 10BBD */ { NULL,NULL},
/* 10BBE */ { NULL,NULL},
/* 10BBF */ { NULL,NULL},
/* 10BC0 */ { NULL,NULL},
/* 10BC1 */ { NULL,NULL},
/* 10BC2 */ { NULL,NULL},
/* 10BC3 */ { NULL,NULL},
/* 10BC4 */ { NULL,NULL},
/* 10BC5 */ { NULL,NULL},
/* 10BC6 */ { NULL,NULL},
/* 10BC7 */ { NULL,NULL},
/* 10BC8 */ { NULL,NULL},
/* 10BC9 */ { NULL,NULL},
/* 10BCA */ { NULL,NULL},
/* 10BCB */ { NULL,NULL},
/* 10BCC */ { NULL,NULL},
/* 10BCD */ { NULL,NULL},
/* 10BCE */ { NULL,NULL},
/* 10BCF */ { NULL,NULL},
/* 10BD0 */ { NULL,NULL},
/* 10BD1 */ { NULL,NULL},
/* 10BD2 */ { NULL,NULL},
/* 10BD3 */ { NULL,NULL},
/* 10BD4 */ { NULL,NULL},
/* 10BD5 */ { NULL,NULL},
/* 10BD6 */ { NULL,NULL},
/* 10BD7 */ { NULL,NULL},
/* 10BD8 */ { NULL,NULL},
/* 10BD9 */ { NULL,NULL},
/* 10BDA */ { NULL,NULL},
/* 10BDB */ { NULL,NULL},
/* 10BDC */ { NULL,NULL},
/* 10BDD */ { NULL,NULL},
/* 10BDE */ { NULL,NULL},
/* 10BDF */ { NULL,NULL},
/* 10BE0 */ { NULL,NULL},
/* 10BE1 */ { NULL,NULL},
/* 10BE2 */ { NULL,NULL},
/* 10BE3 */ { NULL,NULL},
/* 10BE4 */ { NULL,NULL},
/* 10BE5 */ { NULL,NULL},
/* 10BE6 */ { NULL,NULL},
/* 10BE7 */ { NULL,NULL},
/* 10BE8 */ { NULL,NULL},
/* 10BE9 */ { NULL,NULL},
/* 10BEA */ { NULL,NULL},
/* 10BEB */ { NULL,NULL},
/* 10BEC */ { NULL,NULL},
/* 10BED */ { NULL,NULL},
/* 10BEE */ { NULL,NULL},
/* 10BEF */ { NULL,NULL},
/* 10BF0 */ { NULL,NULL},
/* 10BF1 */ { NULL,NULL},
/* 10BF2 */ { NULL,NULL},
/* 10BF3 */ { NULL,NULL},
/* 10BF4 */ { NULL,NULL},
/* 10BF5 */ { NULL,NULL},
/* 10BF6 */ { NULL,NULL},
/* 10BF7 */ { NULL,NULL},
/* 10BF8 */ { NULL,NULL},
/* 10BF9 */ { NULL,NULL},
/* 10BFA */ { NULL,NULL},
/* 10BFB */ { NULL,NULL},
/* 10BFC */ { NULL,NULL},
/* 10BFD */ { NULL,NULL},
/* 10BFE */ { NULL,NULL},
/* 10BFF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_0C[] = {
/* 10C00 */ { "OLD TURKIC LETTER ORKHON A",NULL},
/* 10C01 */ { "OLD TURKIC LETTER YENISEI A",NULL},
/* 10C02 */ { "OLD TURKIC LETTER YENISEI AE",NULL},
/* 10C03 */ { "OLD TURKIC LETTER ORKHON I",NULL},
/* 10C04 */ { "OLD TURKIC LETTER YENISEI I",NULL},
/* 10C05 */ { "OLD TURKIC LETTER YENISEI E",NULL},
/* 10C06 */ { "OLD TURKIC LETTER ORKHON O",NULL},
/* 10C07 */ { "OLD TURKIC LETTER ORKHON OE",NULL},
/* 10C08 */ { "OLD TURKIC LETTER YENISEI OE",NULL},
/* 10C09 */ { "OLD TURKIC LETTER ORKHON AB",NULL},
/* 10C0A */ { "OLD TURKIC LETTER YENISEI AB",NULL},
/* 10C0B */ { "OLD TURKIC LETTER ORKHON AEB",NULL},
/* 10C0C */ { "OLD TURKIC LETTER YENISEI AEB",NULL},
/* 10C0D */ { "OLD TURKIC LETTER ORKHON AG",NULL},
/* 10C0E */ { "OLD TURKIC LETTER YENISEI AG",NULL},
/* 10C0F */ { "OLD TURKIC LETTER ORKHON AEG",NULL},
/* 10C10 */ { "OLD TURKIC LETTER YENISEI AEG",NULL},
/* 10C11 */ { "OLD TURKIC LETTER ORKHON AD",NULL},
/* 10C12 */ { "OLD TURKIC LETTER YENISEI AD",NULL},
/* 10C13 */ { "OLD TURKIC LETTER ORKHON AED",NULL},
/* 10C14 */ { "OLD TURKIC LETTER ORKHON EZ",NULL},
/* 10C15 */ { "OLD TURKIC LETTER YENISEI EZ",NULL},
/* 10C16 */ { "OLD TURKIC LETTER ORKHON AY",NULL},
/* 10C17 */ { "OLD TURKIC LETTER YENISEI AY",NULL},
/* 10C18 */ { "OLD TURKIC LETTER ORKHON AEY",NULL},
/* 10C19 */ { "OLD TURKIC LETTER YENISEI AEY",NULL},
/* 10C1A */ { "OLD TURKIC LETTER ORKHON AEK",NULL},
/* 10C1B */ { "OLD TURKIC LETTER YENISEI AEK",NULL},
/* 10C1C */ { "OLD TURKIC LETTER ORKHON OEK",NULL},
/* 10C1D */ { "OLD TURKIC LETTER YENISEI OEK",NULL},
/* 10C1E */ { "OLD TURKIC LETTER ORKHON AL",NULL},
/* 10C1F */ { "OLD TURKIC LETTER YENISEI AL",NULL},
/* 10C20 */ { "OLD TURKIC LETTER ORKHON AEL",NULL},
/* 10C21 */ { "OLD TURKIC LETTER ORKHON ELT",NULL},
/* 10C22 */ { "OLD TURKIC LETTER ORKHON EM",NULL},
/* 10C23 */ { "OLD TURKIC LETTER ORKHON AN",NULL},
/* 10C24 */ { "OLD TURKIC LETTER ORKHON AEN",NULL},
/* 10C25 */ { "OLD TURKIC LETTER YENISEI AEN",NULL},
/* 10C26 */ { "OLD TURKIC LETTER ORKHON ENT",NULL},
/* 10C27 */ { "OLD TURKIC LETTER YENISEI ENT",NULL},
/* 10C28 */ { "OLD TURKIC LETTER ORKHON ENC",NULL},
/* 10C29 */ { "OLD TURKIC LETTER YENISEI ENC",NULL},
/* 10C2A */ { "OLD TURKIC LETTER ORKHON ENY",NULL},
/* 10C2B */ { "OLD TURKIC LETTER YENISEI ENY",NULL},
/* 10C2C */ { "OLD TURKIC LETTER YENISEI ANG",NULL},
/* 10C2D */ { "OLD TURKIC LETTER ORKHON ENG",NULL},
/* 10C2E */ { "OLD TURKIC LETTER YENISEI AENG",NULL},
/* 10C2F */ { "OLD TURKIC LETTER ORKHON EP",NULL},
/* 10C30 */ { "OLD TURKIC LETTER ORKHON OP",NULL},
/* 10C31 */ { "OLD TURKIC LETTER ORKHON IC",NULL},
/* 10C32 */ { "OLD TURKIC LETTER ORKHON EC",NULL},
/* 10C33 */ { "OLD TURKIC LETTER YENISEI EC",NULL},
/* 10C34 */ { "OLD TURKIC LETTER ORKHON AQ",NULL},
/* 10C35 */ { "OLD TURKIC LETTER YENISEI AQ",NULL},
/* 10C36 */ { "OLD TURKIC LETTER ORKHON IQ",NULL},
/* 10C37 */ { "OLD TURKIC LETTER YENISEI IQ",NULL},
/* 10C38 */ { "OLD TURKIC LETTER ORKHON OQ",NULL},
/* 10C39 */ { "OLD TURKIC LETTER YENISEI OQ",NULL},
/* 10C3A */ { "OLD TURKIC LETTER ORKHON AR",NULL},
/* 10C3B */ { "OLD TURKIC LETTER YENISEI AR",NULL},
/* 10C3C */ { "OLD TURKIC LETTER ORKHON AER",NULL},
/* 10C3D */ { "OLD TURKIC LETTER ORKHON AS",NULL},
/* 10C3E */ { "OLD TURKIC LETTER ORKHON AES",NULL},
/* 10C3F */ { "OLD TURKIC LETTER ORKHON ASH",NULL},
/* 10C40 */ { "OLD TURKIC LETTER YENISEI ASH",NULL},
/* 10C41 */ { "OLD TURKIC LETTER ORKHON ESH",NULL},
/* 10C42 */ { "OLD TURKIC LETTER YENISEI ESH",NULL},
/* 10C43 */ { "OLD TURKIC LETTER ORKHON AT",NULL},
/* 10C44 */ { "OLD TURKIC LETTER YENISEI AT",NULL},
/* 10C45 */ { "OLD TURKIC LETTER ORKHON AET",NULL},
/* 10C46 */ { "OLD TURKIC LETTER YENISEI AET",NULL},
/* 10C47 */ { "OLD TURKIC LETTER ORKHON OT",NULL},
/* 10C48 */ { "OLD TURKIC LETTER ORKHON BASH",NULL},
/* 10C49 */ { NULL,NULL},
/* 10C4A */ { NULL,NULL},
/* 10C4B */ { NULL,NULL},
/* 10C4C */ { NULL,NULL},
/* 10C4D */ { NULL,NULL},
/* 10C4E */ { NULL,NULL},
/* 10C4F */ { NULL,NULL},
/* 10C50 */ { NULL,NULL},
/* 10C51 */ { NULL,NULL},
/* 10C52 */ { NULL,NULL},
/* 10C53 */ { NULL,NULL},
/* 10C54 */ { NULL,NULL},
/* 10C55 */ { NULL,NULL},
/* 10C56 */ { NULL,NULL},
/* 10C57 */ { NULL,NULL},
/* 10C58 */ { NULL,NULL},
/* 10C59 */ { NULL,NULL},
/* 10C5A */ { NULL,NULL},
/* 10C5B */ { NULL,NULL},
/* 10C5C */ { NULL,NULL},
/* 10C5D */ { NULL,NULL},
/* 10C5E */ { NULL,NULL},
/* 10C5F */ { NULL,NULL},
/* 10C60 */ { NULL,NULL},
/* 10C61 */ { NULL,NULL},
/* 10C62 */ { NULL,NULL},
/* 10C63 */ { NULL,NULL},
/* 10C64 */ { NULL,NULL},
/* 10C65 */ { NULL,NULL},
/* 10C66 */ { NULL,NULL},
/* 10C67 */ { NULL,NULL},
/* 10C68 */ { NULL,NULL},
/* 10C69 */ { NULL,NULL},
/* 10C6A */ { NULL,NULL},
/* 10C6B */ { NULL,NULL},
/* 10C6C */ { NULL,NULL},
/* 10C6D */ { NULL,NULL},
/* 10C6E */ { NULL,NULL},
/* 10C6F */ { NULL,NULL},
/* 10C70 */ { NULL,NULL},
/* 10C71 */ { NULL,NULL},
/* 10C72 */ { NULL,NULL},
/* 10C73 */ { NULL,NULL},
/* 10C74 */ { NULL,NULL},
/* 10C75 */ { NULL,NULL},
/* 10C76 */ { NULL,NULL},
/* 10C77 */ { NULL,NULL},
/* 10C78 */ { NULL,NULL},
/* 10C79 */ { NULL,NULL},
/* 10C7A */ { NULL,NULL},
/* 10C7B */ { NULL,NULL},
/* 10C7C */ { NULL,NULL},
/* 10C7D */ { NULL,NULL},
/* 10C7E */ { NULL,NULL},
/* 10C7F */ { NULL,NULL},
/* 10C80 */ { "OLD HUNGARIAN CAPITAL LETTER A",NULL},
/* 10C81 */ { "OLD HUNGARIAN CAPITAL LETTER AA","	= Á"},
/* 10C82 */ { "OLD HUNGARIAN CAPITAL LETTER EB","	= B"},
/* 10C83 */ { "OLD HUNGARIAN CAPITAL LETTER AMB",NULL},
/* 10C84 */ { "OLD HUNGARIAN CAPITAL LETTER EC","	= C"},
/* 10C85 */ { "OLD HUNGARIAN CAPITAL LETTER ENC",NULL},
/* 10C86 */ { "OLD HUNGARIAN CAPITAL LETTER ECS","	= Cs"},
/* 10C87 */ { "OLD HUNGARIAN CAPITAL LETTER ED","	= D"},
/* 10C88 */ { "OLD HUNGARIAN CAPITAL LETTER AND",NULL},
/* 10C89 */ { "OLD HUNGARIAN CAPITAL LETTER E",NULL},
/* 10C8A */ { "OLD HUNGARIAN CAPITAL LETTER CLOSE E","	= Ë"},
/* 10C8B */ { "OLD HUNGARIAN CAPITAL LETTER EE","	= É"},
/* 10C8C */ { "OLD HUNGARIAN CAPITAL LETTER EF","	= F"},
/* 10C8D */ { "OLD HUNGARIAN CAPITAL LETTER EG","	= G"},
/* 10C8E */ { "OLD HUNGARIAN CAPITAL LETTER EGY","	= Gy"},
/* 10C8F */ { "OLD HUNGARIAN CAPITAL LETTER EH","	= H"},
/* 10C90 */ { "OLD HUNGARIAN CAPITAL LETTER I",NULL},
/* 10C91 */ { "OLD HUNGARIAN CAPITAL LETTER II","	= Í"},
/* 10C92 */ { "OLD HUNGARIAN CAPITAL LETTER EJ","	= J"},
/* 10C93 */ { "OLD HUNGARIAN CAPITAL LETTER EK","	= K"},
/* 10C94 */ { "OLD HUNGARIAN CAPITAL LETTER AK",NULL},
/* 10C95 */ { "OLD HUNGARIAN CAPITAL LETTER UNK",NULL},
/* 10C96 */ { "OLD HUNGARIAN CAPITAL LETTER EL","	= L"},
/* 10C97 */ { "OLD HUNGARIAN CAPITAL LETTER ELY","	= Ly"},
/* 10C98 */ { "OLD HUNGARIAN CAPITAL LETTER EM","	= M"},
/* 10C99 */ { "OLD HUNGARIAN CAPITAL LETTER EN","	= N"},
/* 10C9A */ { "OLD HUNGARIAN CAPITAL LETTER ENY","	= Ny"},
/* 10C9B */ { "OLD HUNGARIAN CAPITAL LETTER O","	= O"},
/* 10C9C */ { "OLD HUNGARIAN CAPITAL LETTER OO","	= Ó"},
/* 10C9D */ { "OLD HUNGARIAN CAPITAL LETTER NIKOLSBURG OE","	= Ö"},
/* 10C9E */ { "OLD HUNGARIAN CAPITAL LETTER RUDIMENTA OE","	= Ö"},
/* 10C9F */ { "OLD HUNGARIAN CAPITAL LETTER OEE","	= Ő"},
/* 10CA0 */ { "OLD HUNGARIAN CAPITAL LETTER EP","	= P"},
/* 10CA1 */ { "OLD HUNGARIAN CAPITAL LETTER EMP",NULL},
/* 10CA2 */ { "OLD HUNGARIAN CAPITAL LETTER ER","	= R"},
/* 10CA3 */ { "OLD HUNGARIAN CAPITAL LETTER SHORT ER",NULL},
/* 10CA4 */ { "OLD HUNGARIAN CAPITAL LETTER ES","	= S"},
/* 10CA5 */ { "OLD HUNGARIAN CAPITAL LETTER ESZ","	= Sz"},
/* 10CA6 */ { "OLD HUNGARIAN CAPITAL LETTER ET","	= T"},
/* 10CA7 */ { "OLD HUNGARIAN CAPITAL LETTER ENT","	* also used for Ant and Int"},
/* 10CA8 */ { "OLD HUNGARIAN CAPITAL LETTER ETY","	= Ty"},
/* 10CA9 */ { "OLD HUNGARIAN CAPITAL LETTER ECH",NULL},
/* 10CAA */ { "OLD HUNGARIAN CAPITAL LETTER U",NULL},
/* 10CAB */ { "OLD HUNGARIAN CAPITAL LETTER UU","	= Ú"},
/* 10CAC */ { "OLD HUNGARIAN CAPITAL LETTER NIKOLSBURG UE","	= Ü\n"
	"	* also used for Ö\n"
	"	* used for Ű in Sándor Forrai's orthography"},
/* 10CAD */ { "OLD HUNGARIAN CAPITAL LETTER RUDIMENTA UE","	= Ü, Ű\n"
	"	* used for Ü in Sándor Forrai's orthography"},
/* 10CAE */ { "OLD HUNGARIAN CAPITAL LETTER EV","	= V"},
/* 10CAF */ { "OLD HUNGARIAN CAPITAL LETTER EZ","	= Z"},
/* 10CB0 */ { "OLD HUNGARIAN CAPITAL LETTER EZS","	= Zs"},
/* 10CB1 */ { "OLD HUNGARIAN CAPITAL LETTER ENT-SHAPED SIGN",NULL},
/* 10CB2 */ { "OLD HUNGARIAN CAPITAL LETTER US",NULL},
/* 10CB3 */ { NULL,NULL},
/* 10CB4 */ { NULL,NULL},
/* 10CB5 */ { NULL,NULL},
/* 10CB6 */ { NULL,NULL},
/* 10CB7 */ { NULL,NULL},
/* 10CB8 */ { NULL,NULL},
/* 10CB9 */ { NULL,NULL},
/* 10CBA */ { NULL,NULL},
/* 10CBB */ { NULL,NULL},
/* 10CBC */ { NULL,NULL},
/* 10CBD */ { NULL,NULL},
/* 10CBE */ { NULL,NULL},
/* 10CBF */ { NULL,NULL},
/* 10CC0 */ { "OLD HUNGARIAN SMALL LETTER A",NULL},
/* 10CC1 */ { "OLD HUNGARIAN SMALL LETTER AA","	= á"},
/* 10CC2 */ { "OLD HUNGARIAN SMALL LETTER EB","	= b"},
/* 10CC3 */ { "OLD HUNGARIAN SMALL LETTER AMB",NULL},
/* 10CC4 */ { "OLD HUNGARIAN SMALL LETTER EC","	= c"},
/* 10CC5 */ { "OLD HUNGARIAN SMALL LETTER ENC",NULL},
/* 10CC6 */ { "OLD HUNGARIAN SMALL LETTER ECS","	= cs"},
/* 10CC7 */ { "OLD HUNGARIAN SMALL LETTER ED","	= d"},
/* 10CC8 */ { "OLD HUNGARIAN SMALL LETTER AND",NULL},
/* 10CC9 */ { "OLD HUNGARIAN SMALL LETTER E",NULL},
/* 10CCA */ { "OLD HUNGARIAN SMALL LETTER CLOSE E","	= ë"},
/* 10CCB */ { "OLD HUNGARIAN SMALL LETTER EE","	= é"},
/* 10CCC */ { "OLD HUNGARIAN SMALL LETTER EF","	= f"},
/* 10CCD */ { "OLD HUNGARIAN SMALL LETTER EG","	= g"},
/* 10CCE */ { "OLD HUNGARIAN SMALL LETTER EGY","	= gy"},
/* 10CCF */ { "OLD HUNGARIAN SMALL LETTER EH","	= h"},
/* 10CD0 */ { "OLD HUNGARIAN SMALL LETTER I",NULL},
/* 10CD1 */ { "OLD HUNGARIAN SMALL LETTER II","	= í"},
/* 10CD2 */ { "OLD HUNGARIAN SMALL LETTER EJ","	= j"},
/* 10CD3 */ { "OLD HUNGARIAN SMALL LETTER EK","	= k"},
/* 10CD4 */ { "OLD HUNGARIAN SMALL LETTER AK",NULL},
/* 10CD5 */ { "OLD HUNGARIAN SMALL LETTER UNK",NULL},
/* 10CD6 */ { "OLD HUNGARIAN SMALL LETTER EL","	= l"},
/* 10CD7 */ { "OLD HUNGARIAN SMALL LETTER ELY","	= ly"},
/* 10CD8 */ { "OLD HUNGARIAN SMALL LETTER EM","	= m"},
/* 10CD9 */ { "OLD HUNGARIAN SMALL LETTER EN","	= n"},
/* 10CDA */ { "OLD HUNGARIAN SMALL LETTER ENY","	= ny"},
/* 10CDB */ { "OLD HUNGARIAN SMALL LETTER O",NULL},
/* 10CDC */ { "OLD HUNGARIAN SMALL LETTER OO","	= ó"},
/* 10CDD */ { "OLD HUNGARIAN SMALL LETTER NIKOLSBURG OE","	= ö\n"
	"	* also used for ü"},
/* 10CDE */ { "OLD HUNGARIAN SMALL LETTER RUDIMENTA OE","	= ö"},
/* 10CDF */ { "OLD HUNGARIAN SMALL LETTER OEE","	= ő"},
/* 10CE0 */ { "OLD HUNGARIAN SMALL LETTER EP","	= p"},
/* 10CE1 */ { "OLD HUNGARIAN SMALL LETTER EMP",NULL},
/* 10CE2 */ { "OLD HUNGARIAN SMALL LETTER ER","	= r"},
/* 10CE3 */ { "OLD HUNGARIAN SMALL LETTER SHORT ER",NULL},
/* 10CE4 */ { "OLD HUNGARIAN SMALL LETTER ES","	= s"},
/* 10CE5 */ { "OLD HUNGARIAN SMALL LETTER ESZ","	= sz"},
/* 10CE6 */ { "OLD HUNGARIAN SMALL LETTER ET","	= t"},
/* 10CE7 */ { "OLD HUNGARIAN SMALL LETTER ENT","	* also used for ant and int"},
/* 10CE8 */ { "OLD HUNGARIAN SMALL LETTER ETY","	= ty"},
/* 10CE9 */ { "OLD HUNGARIAN SMALL LETTER ECH",NULL},
/* 10CEA */ { "OLD HUNGARIAN SMALL LETTER U",NULL},
/* 10CEB */ { "OLD HUNGARIAN SMALL LETTER UU","	= ú"},
/* 10CEC */ { "OLD HUNGARIAN SMALL LETTER NIKOLSBURG UE","	= ü\n"
	"	* also used for ö\n"
	"	* used for ű in Sándor Forrai's orthography"},
/* 10CED */ { "OLD HUNGARIAN SMALL LETTER RUDIMENTA UE","	= ü, ű\n"
	"	* used for ü in Sándor Forrai's orthography"},
/* 10CEE */ { "OLD HUNGARIAN SMALL LETTER EV","	= v"},
/* 10CEF */ { "OLD HUNGARIAN SMALL LETTER EZ","	= z"},
/* 10CF0 */ { "OLD HUNGARIAN SMALL LETTER EZS","	= zs"},
/* 10CF1 */ { "OLD HUNGARIAN SMALL LETTER ENT-SHAPED SIGN","	* in earlier literature called \"tprus\" (later recognized as an abbreviation for \"temperius\")"},
/* 10CF2 */ { "OLD HUNGARIAN SMALL LETTER US",NULL},
/* 10CF3 */ { NULL,NULL},
/* 10CF4 */ { NULL,NULL},
/* 10CF5 */ { NULL,NULL},
/* 10CF6 */ { NULL,NULL},
/* 10CF7 */ { NULL,NULL},
/* 10CF8 */ { NULL,NULL},
/* 10CF9 */ { NULL,NULL},
/* 10CFA */ { "OLD HUNGARIAN NUMBER ONE",NULL},
/* 10CFB */ { "OLD HUNGARIAN NUMBER FIVE",NULL},
/* 10CFC */ { "OLD HUNGARIAN NUMBER TEN",NULL},
/* 10CFD */ { "OLD HUNGARIAN NUMBER FIFTY",NULL},
/* 10CFE */ { "OLD HUNGARIAN NUMBER ONE HUNDRED",NULL},
/* 10CFF */ { "OLD HUNGARIAN NUMBER ONE THOUSAND",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_0D[] = {
/* 10D00 */ { "HANIFI ROHINGYA LETTER A",NULL},
/* 10D01 */ { "HANIFI ROHINGYA LETTER BA",NULL},
/* 10D02 */ { "HANIFI ROHINGYA LETTER PA",NULL},
/* 10D03 */ { "HANIFI ROHINGYA LETTER TA",NULL},
/* 10D04 */ { "HANIFI ROHINGYA LETTER TTA",NULL},
/* 10D05 */ { "HANIFI ROHINGYA LETTER JA",NULL},
/* 10D06 */ { "HANIFI ROHINGYA LETTER CA",NULL},
/* 10D07 */ { "HANIFI ROHINGYA LETTER HA",NULL},
/* 10D08 */ { "HANIFI ROHINGYA LETTER KHA",NULL},
/* 10D09 */ { "HANIFI ROHINGYA LETTER FA",NULL},
/* 10D0A */ { "HANIFI ROHINGYA LETTER DA",NULL},
/* 10D0B */ { "HANIFI ROHINGYA LETTER DDA",NULL},
/* 10D0C */ { "HANIFI ROHINGYA LETTER RA",NULL},
/* 10D0D */ { "HANIFI ROHINGYA LETTER RRA",NULL},
/* 10D0E */ { "HANIFI ROHINGYA LETTER ZA",NULL},
/* 10D0F */ { "HANIFI ROHINGYA LETTER SA",NULL},
/* 10D10 */ { "HANIFI ROHINGYA LETTER SHA",NULL},
/* 10D11 */ { "HANIFI ROHINGYA LETTER KA",NULL},
/* 10D12 */ { "HANIFI ROHINGYA LETTER GA",NULL},
/* 10D13 */ { "HANIFI ROHINGYA LETTER LA",NULL},
/* 10D14 */ { "HANIFI ROHINGYA LETTER MA",NULL},
/* 10D15 */ { "HANIFI ROHINGYA LETTER NA",NULL},
/* 10D16 */ { "HANIFI ROHINGYA LETTER WA",NULL},
/* 10D17 */ { "HANIFI ROHINGYA LETTER KINNA WA",NULL},
/* 10D18 */ { "HANIFI ROHINGYA LETTER YA",NULL},
/* 10D19 */ { "HANIFI ROHINGYA LETTER KINNA YA",NULL},
/* 10D1A */ { "HANIFI ROHINGYA LETTER NGA","	= gan"},
/* 10D1B */ { "HANIFI ROHINGYA LETTER NYA","	= nayya"},
/* 10D1C */ { "HANIFI ROHINGYA LETTER VA","	* was not used widely and its usage has been discontinued"},
/* 10D1D */ { "HANIFI ROHINGYA VOWEL A","	= aa-for"},
/* 10D1E */ { "HANIFI ROHINGYA VOWEL I","	= i-for"},
/* 10D1F */ { "HANIFI ROHINGYA VOWEL U","	= u-for"},
/* 10D20 */ { "HANIFI ROHINGYA VOWEL E","	= e-for"},
/* 10D21 */ { "HANIFI ROHINGYA VOWEL O","	= o-for"},
/* 10D22 */ { "HANIFI ROHINGYA MARK SAKIN",NULL},
/* 10D23 */ { "HANIFI ROHINGYA MARK NA KHONNA",NULL},
/* 10D24 */ { "HANIFI ROHINGYA SIGN HARBAHAY","	* short high tone"},
/* 10D25 */ { "HANIFI ROHINGYA SIGN TAHALA","	* long falling tone"},
/* 10D26 */ { "HANIFI ROHINGYA SIGN TANA","	* long rising tone"},
/* 10D27 */ { "HANIFI ROHINGYA SIGN TASSI",NULL},
/* 10D28 */ { NULL,NULL},
/* 10D29 */ { NULL,NULL},
/* 10D2A */ { NULL,NULL},
/* 10D2B */ { NULL,NULL},
/* 10D2C */ { NULL,NULL},
/* 10D2D */ { NULL,NULL},
/* 10D2E */ { NULL,NULL},
/* 10D2F */ { NULL,NULL},
/* 10D30 */ { "HANIFI ROHINGYA DIGIT ZERO",NULL},
/* 10D31 */ { "HANIFI ROHINGYA DIGIT ONE",NULL},
/* 10D32 */ { "HANIFI ROHINGYA DIGIT TWO",NULL},
/* 10D33 */ { "HANIFI ROHINGYA DIGIT THREE",NULL},
/* 10D34 */ { "HANIFI ROHINGYA DIGIT FOUR",NULL},
/* 10D35 */ { "HANIFI ROHINGYA DIGIT FIVE",NULL},
/* 10D36 */ { "HANIFI ROHINGYA DIGIT SIX",NULL},
/* 10D37 */ { "HANIFI ROHINGYA DIGIT SEVEN",NULL},
/* 10D38 */ { "HANIFI ROHINGYA DIGIT EIGHT",NULL},
/* 10D39 */ { "HANIFI ROHINGYA DIGIT NINE",NULL},
/* 10D3A */ { NULL,NULL},
/* 10D3B */ { NULL,NULL},
/* 10D3C */ { NULL,NULL},
/* 10D3D */ { NULL,NULL},
/* 10D3E */ { NULL,NULL},
/* 10D3F */ { NULL,NULL},
/* 10D40 */ { "GARAY DIGIT ZERO",NULL},
/* 10D41 */ { "GARAY DIGIT ONE",NULL},
/* 10D42 */ { "GARAY DIGIT TWO",NULL},
/* 10D43 */ { "GARAY DIGIT THREE",NULL},
/* 10D44 */ { "GARAY DIGIT FOUR",NULL},
/* 10D45 */ { "GARAY DIGIT FIVE",NULL},
/* 10D46 */ { "GARAY DIGIT SIX",NULL},
/* 10D47 */ { "GARAY DIGIT SEVEN",NULL},
/* 10D48 */ { "GARAY DIGIT EIGHT",NULL},
/* 10D49 */ { "GARAY DIGIT NINE",NULL},
/* 10D4A */ { "GARAY VOWEL SIGN A",NULL},
/* 10D4B */ { "GARAY VOWEL SIGN I",NULL},
/* 10D4C */ { "GARAY VOWEL SIGN O",NULL},
/* 10D4D */ { "GARAY VOWEL SIGN EE",NULL},
/* 10D4E */ { "GARAY VOWEL LENGTH MARK",NULL},
/* 10D4F */ { "GARAY SUKUN",NULL},
/* 10D50 */ { "GARAY CAPITAL LETTER A",NULL},
/* 10D51 */ { "GARAY CAPITAL LETTER CA",NULL},
/* 10D52 */ { "GARAY CAPITAL LETTER MA",NULL},
/* 10D53 */ { "GARAY CAPITAL LETTER KA",NULL},
/* 10D54 */ { "GARAY CAPITAL LETTER BA",NULL},
/* 10D55 */ { "GARAY CAPITAL LETTER JA",NULL},
/* 10D56 */ { "GARAY CAPITAL LETTER SA",NULL},
/* 10D57 */ { "GARAY CAPITAL LETTER WA",NULL},
/* 10D58 */ { "GARAY CAPITAL LETTER LA",NULL},
/* 10D59 */ { "GARAY CAPITAL LETTER GA",NULL},
/* 10D5A */ { "GARAY CAPITAL LETTER DA",NULL},
/* 10D5B */ { "GARAY CAPITAL LETTER XA",NULL},
/* 10D5C */ { "GARAY CAPITAL LETTER YA",NULL},
/* 10D5D */ { "GARAY CAPITAL LETTER TA",NULL},
/* 10D5E */ { "GARAY CAPITAL LETTER RA",NULL},
/* 10D5F */ { "GARAY CAPITAL LETTER NYA",NULL},
/* 10D60 */ { "GARAY CAPITAL LETTER FA",NULL},
/* 10D61 */ { "GARAY CAPITAL LETTER NA",NULL},
/* 10D62 */ { "GARAY CAPITAL LETTER PA",NULL},
/* 10D63 */ { "GARAY CAPITAL LETTER HA",NULL},
/* 10D64 */ { "GARAY CAPITAL LETTER OLD KA",NULL},
/* 10D65 */ { "GARAY CAPITAL LETTER OLD NA",NULL},
/* 10D66 */ { NULL,NULL},
/* 10D67 */ { NULL,NULL},
/* 10D68 */ { NULL,NULL},
/* 10D69 */ { "GARAY VOWEL SIGN E",NULL},
/* 10D6A */ { "GARAY CONSONANT GEMINATION MARK",NULL},
/* 10D6B */ { "GARAY COMBINING DOT ABOVE",NULL},
/* 10D6C */ { "GARAY COMBINING DOUBLE DOT ABOVE",NULL},
/* 10D6D */ { "GARAY CONSONANT NASALIZATION MARK",NULL},
/* 10D6E */ { "GARAY HYPHEN",NULL},
/* 10D6F */ { "GARAY REDUPLICATION MARK",NULL},
/* 10D70 */ { "GARAY SMALL LETTER A",NULL},
/* 10D71 */ { "GARAY SMALL LETTER CA",NULL},
/* 10D72 */ { "GARAY SMALL LETTER MA",NULL},
/* 10D73 */ { "GARAY SMALL LETTER KA",NULL},
/* 10D74 */ { "GARAY SMALL LETTER BA",NULL},
/* 10D75 */ { "GARAY SMALL LETTER JA",NULL},
/* 10D76 */ { "GARAY SMALL LETTER SA",NULL},
/* 10D77 */ { "GARAY SMALL LETTER WA",NULL},
/* 10D78 */ { "GARAY SMALL LETTER LA",NULL},
/* 10D79 */ { "GARAY SMALL LETTER GA",NULL},
/* 10D7A */ { "GARAY SMALL LETTER DA",NULL},
/* 10D7B */ { "GARAY SMALL LETTER XA",NULL},
/* 10D7C */ { "GARAY SMALL LETTER YA",NULL},
/* 10D7D */ { "GARAY SMALL LETTER TA",NULL},
/* 10D7E */ { "GARAY SMALL LETTER RA",NULL},
/* 10D7F */ { "GARAY SMALL LETTER NYA",NULL},
/* 10D80 */ { "GARAY SMALL LETTER FA",NULL},
/* 10D81 */ { "GARAY SMALL LETTER NA",NULL},
/* 10D82 */ { "GARAY SMALL LETTER PA",NULL},
/* 10D83 */ { "GARAY SMALL LETTER HA",NULL},
/* 10D84 */ { "GARAY SMALL LETTER OLD KA",NULL},
/* 10D85 */ { "GARAY SMALL LETTER OLD NA",NULL},
/* 10D86 */ { NULL,NULL},
/* 10D87 */ { NULL,NULL},
/* 10D88 */ { NULL,NULL},
/* 10D89 */ { NULL,NULL},
/* 10D8A */ { NULL,NULL},
/* 10D8B */ { NULL,NULL},
/* 10D8C */ { NULL,NULL},
/* 10D8D */ { NULL,NULL},
/* 10D8E */ { "GARAY PLUS SIGN",NULL},
/* 10D8F */ { "GARAY MINUS SIGN",NULL},
/* 10D90 */ { NULL,NULL},
/* 10D91 */ { NULL,NULL},
/* 10D92 */ { NULL,NULL},
/* 10D93 */ { NULL,NULL},
/* 10D94 */ { NULL,NULL},
/* 10D95 */ { NULL,NULL},
/* 10D96 */ { NULL,NULL},
/* 10D97 */ { NULL,NULL},
/* 10D98 */ { NULL,NULL},
/* 10D99 */ { NULL,NULL},
/* 10D9A */ { NULL,NULL},
/* 10D9B */ { NULL,NULL},
/* 10D9C */ { NULL,NULL},
/* 10D9D */ { NULL,NULL},
/* 10D9E */ { NULL,NULL},
/* 10D9F */ { NULL,NULL},
/* 10DA0 */ { NULL,NULL},
/* 10DA1 */ { NULL,NULL},
/* 10DA2 */ { NULL,NULL},
/* 10DA3 */ { NULL,NULL},
/* 10DA4 */ { NULL,NULL},
/* 10DA5 */ { NULL,NULL},
/* 10DA6 */ { NULL,NULL},
/* 10DA7 */ { NULL,NULL},
/* 10DA8 */ { NULL,NULL},
/* 10DA9 */ { NULL,NULL},
/* 10DAA */ { NULL,NULL},
/* 10DAB */ { NULL,NULL},
/* 10DAC */ { NULL,NULL},
/* 10DAD */ { NULL,NULL},
/* 10DAE */ { NULL,NULL},
/* 10DAF */ { NULL,NULL},
/* 10DB0 */ { NULL,NULL},
/* 10DB1 */ { NULL,NULL},
/* 10DB2 */ { NULL,NULL},
/* 10DB3 */ { NULL,NULL},
/* 10DB4 */ { NULL,NULL},
/* 10DB5 */ { NULL,NULL},
/* 10DB6 */ { NULL,NULL},
/* 10DB7 */ { NULL,NULL},
/* 10DB8 */ { NULL,NULL},
/* 10DB9 */ { NULL,NULL},
/* 10DBA */ { NULL,NULL},
/* 10DBB */ { NULL,NULL},
/* 10DBC */ { NULL,NULL},
/* 10DBD */ { NULL,NULL},
/* 10DBE */ { NULL,NULL},
/* 10DBF */ { NULL,NULL},
/* 10DC0 */ { NULL,NULL},
/* 10DC1 */ { NULL,NULL},
/* 10DC2 */ { NULL,NULL},
/* 10DC3 */ { NULL,NULL},
/* 10DC4 */ { NULL,NULL},
/* 10DC5 */ { NULL,NULL},
/* 10DC6 */ { NULL,NULL},
/* 10DC7 */ { NULL,NULL},
/* 10DC8 */ { NULL,NULL},
/* 10DC9 */ { NULL,NULL},
/* 10DCA */ { NULL,NULL},
/* 10DCB */ { NULL,NULL},
/* 10DCC */ { NULL,NULL},
/* 10DCD */ { NULL,NULL},
/* 10DCE */ { NULL,NULL},
/* 10DCF */ { NULL,NULL},
/* 10DD0 */ { NULL,NULL},
/* 10DD1 */ { NULL,NULL},
/* 10DD2 */ { NULL,NULL},
/* 10DD3 */ { NULL,NULL},
/* 10DD4 */ { NULL,NULL},
/* 10DD5 */ { NULL,NULL},
/* 10DD6 */ { NULL,NULL},
/* 10DD7 */ { NULL,NULL},
/* 10DD8 */ { NULL,NULL},
/* 10DD9 */ { NULL,NULL},
/* 10DDA */ { NULL,NULL},
/* 10DDB */ { NULL,NULL},
/* 10DDC */ { NULL,NULL},
/* 10DDD */ { NULL,NULL},
/* 10DDE */ { NULL,NULL},
/* 10DDF */ { NULL,NULL},
/* 10DE0 */ { NULL,NULL},
/* 10DE1 */ { NULL,NULL},
/* 10DE2 */ { NULL,NULL},
/* 10DE3 */ { NULL,NULL},
/* 10DE4 */ { NULL,NULL},
/* 10DE5 */ { NULL,NULL},
/* 10DE6 */ { NULL,NULL},
/* 10DE7 */ { NULL,NULL},
/* 10DE8 */ { NULL,NULL},
/* 10DE9 */ { NULL,NULL},
/* 10DEA */ { NULL,NULL},
/* 10DEB */ { NULL,NULL},
/* 10DEC */ { NULL,NULL},
/* 10DED */ { NULL,NULL},
/* 10DEE */ { NULL,NULL},
/* 10DEF */ { NULL,NULL},
/* 10DF0 */ { NULL,NULL},
/* 10DF1 */ { NULL,NULL},
/* 10DF2 */ { NULL,NULL},
/* 10DF3 */ { NULL,NULL},
/* 10DF4 */ { NULL,NULL},
/* 10DF5 */ { NULL,NULL},
/* 10DF6 */ { NULL,NULL},
/* 10DF7 */ { NULL,NULL},
/* 10DF8 */ { NULL,NULL},
/* 10DF9 */ { NULL,NULL},
/* 10DFA */ { NULL,NULL},
/* 10DFB */ { NULL,NULL},
/* 10DFC */ { NULL,NULL},
/* 10DFD */ { NULL,NULL},
/* 10DFE */ { NULL,NULL},
/* 10DFF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_0E[] = {
/* 10E00 */ { NULL,NULL},
/* 10E01 */ { NULL,NULL},
/* 10E02 */ { NULL,NULL},
/* 10E03 */ { NULL,NULL},
/* 10E04 */ { NULL,NULL},
/* 10E05 */ { NULL,NULL},
/* 10E06 */ { NULL,NULL},
/* 10E07 */ { NULL,NULL},
/* 10E08 */ { NULL,NULL},
/* 10E09 */ { NULL,NULL},
/* 10E0A */ { NULL,NULL},
/* 10E0B */ { NULL,NULL},
/* 10E0C */ { NULL,NULL},
/* 10E0D */ { NULL,NULL},
/* 10E0E */ { NULL,NULL},
/* 10E0F */ { NULL,NULL},
/* 10E10 */ { NULL,NULL},
/* 10E11 */ { NULL,NULL},
/* 10E12 */ { NULL,NULL},
/* 10E13 */ { NULL,NULL},
/* 10E14 */ { NULL,NULL},
/* 10E15 */ { NULL,NULL},
/* 10E16 */ { NULL,NULL},
/* 10E17 */ { NULL,NULL},
/* 10E18 */ { NULL,NULL},
/* 10E19 */ { NULL,NULL},
/* 10E1A */ { NULL,NULL},
/* 10E1B */ { NULL,NULL},
/* 10E1C */ { NULL,NULL},
/* 10E1D */ { NULL,NULL},
/* 10E1E */ { NULL,NULL},
/* 10E1F */ { NULL,NULL},
/* 10E20 */ { NULL,NULL},
/* 10E21 */ { NULL,NULL},
/* 10E22 */ { NULL,NULL},
/* 10E23 */ { NULL,NULL},
/* 10E24 */ { NULL,NULL},
/* 10E25 */ { NULL,NULL},
/* 10E26 */ { NULL,NULL},
/* 10E27 */ { NULL,NULL},
/* 10E28 */ { NULL,NULL},
/* 10E29 */ { NULL,NULL},
/* 10E2A */ { NULL,NULL},
/* 10E2B */ { NULL,NULL},
/* 10E2C */ { NULL,NULL},
/* 10E2D */ { NULL,NULL},
/* 10E2E */ { NULL,NULL},
/* 10E2F */ { NULL,NULL},
/* 10E30 */ { NULL,NULL},
/* 10E31 */ { NULL,NULL},
/* 10E32 */ { NULL,NULL},
/* 10E33 */ { NULL,NULL},
/* 10E34 */ { NULL,NULL},
/* 10E35 */ { NULL,NULL},
/* 10E36 */ { NULL,NULL},
/* 10E37 */ { NULL,NULL},
/* 10E38 */ { NULL,NULL},
/* 10E39 */ { NULL,NULL},
/* 10E3A */ { NULL,NULL},
/* 10E3B */ { NULL,NULL},
/* 10E3C */ { NULL,NULL},
/* 10E3D */ { NULL,NULL},
/* 10E3E */ { NULL,NULL},
/* 10E3F */ { NULL,NULL},
/* 10E40 */ { NULL,NULL},
/* 10E41 */ { NULL,NULL},
/* 10E42 */ { NULL,NULL},
/* 10E43 */ { NULL,NULL},
/* 10E44 */ { NULL,NULL},
/* 10E45 */ { NULL,NULL},
/* 10E46 */ { NULL,NULL},
/* 10E47 */ { NULL,NULL},
/* 10E48 */ { NULL,NULL},
/* 10E49 */ { NULL,NULL},
/* 10E4A */ { NULL,NULL},
/* 10E4B */ { NULL,NULL},
/* 10E4C */ { NULL,NULL},
/* 10E4D */ { NULL,NULL},
/* 10E4E */ { NULL,NULL},
/* 10E4F */ { NULL,NULL},
/* 10E50 */ { NULL,NULL},
/* 10E51 */ { NULL,NULL},
/* 10E52 */ { NULL,NULL},
/* 10E53 */ { NULL,NULL},
/* 10E54 */ { NULL,NULL},
/* 10E55 */ { NULL,NULL},
/* 10E56 */ { NULL,NULL},
/* 10E57 */ { NULL,NULL},
/* 10E58 */ { NULL,NULL},
/* 10E59 */ { NULL,NULL},
/* 10E5A */ { NULL,NULL},
/* 10E5B */ { NULL,NULL},
/* 10E5C */ { NULL,NULL},
/* 10E5D */ { NULL,NULL},
/* 10E5E */ { NULL,NULL},
/* 10E5F */ { NULL,NULL},
/* 10E60 */ { "RUMI DIGIT ONE",NULL},
/* 10E61 */ { "RUMI DIGIT TWO",NULL},
/* 10E62 */ { "RUMI DIGIT THREE",NULL},
/* 10E63 */ { "RUMI DIGIT FOUR",NULL},
/* 10E64 */ { "RUMI DIGIT FIVE",NULL},
/* 10E65 */ { "RUMI DIGIT SIX",NULL},
/* 10E66 */ { "RUMI DIGIT SEVEN",NULL},
/* 10E67 */ { "RUMI DIGIT EIGHT",NULL},
/* 10E68 */ { "RUMI DIGIT NINE",NULL},
/* 10E69 */ { "RUMI NUMBER TEN",NULL},
/* 10E6A */ { "RUMI NUMBER TWENTY",NULL},
/* 10E6B */ { "RUMI NUMBER THIRTY",NULL},
/* 10E6C */ { "RUMI NUMBER FORTY",NULL},
/* 10E6D */ { "RUMI NUMBER FIFTY",NULL},
/* 10E6E */ { "RUMI NUMBER SIXTY",NULL},
/* 10E6F */ { "RUMI NUMBER SEVENTY",NULL},
/* 10E70 */ { "RUMI NUMBER EIGHTY",NULL},
/* 10E71 */ { "RUMI NUMBER NINETY",NULL},
/* 10E72 */ { "RUMI NUMBER ONE HUNDRED",NULL},
/* 10E73 */ { "RUMI NUMBER TWO HUNDRED",NULL},
/* 10E74 */ { "RUMI NUMBER THREE HUNDRED",NULL},
/* 10E75 */ { "RUMI NUMBER FOUR HUNDRED",NULL},
/* 10E76 */ { "RUMI NUMBER FIVE HUNDRED",NULL},
/* 10E77 */ { "RUMI NUMBER SIX HUNDRED",NULL},
/* 10E78 */ { "RUMI NUMBER SEVEN HUNDRED",NULL},
/* 10E79 */ { "RUMI NUMBER EIGHT HUNDRED",NULL},
/* 10E7A */ { "RUMI NUMBER NINE HUNDRED",NULL},
/* 10E7B */ { "RUMI FRACTION ONE HALF",NULL},
/* 10E7C */ { "RUMI FRACTION ONE QUARTER",NULL},
/* 10E7D */ { "RUMI FRACTION ONE THIRD",NULL},
/* 10E7E */ { "RUMI FRACTION TWO THIRDS",NULL},
/* 10E7F */ { NULL,NULL},
/* 10E80 */ { "YEZIDI LETTER ELIF",NULL},
/* 10E81 */ { "YEZIDI LETTER BE",NULL},
/* 10E82 */ { "YEZIDI LETTER PE",NULL},
/* 10E83 */ { "YEZIDI LETTER PHE",NULL},
/* 10E84 */ { "YEZIDI LETTER THE",NULL},
/* 10E85 */ { "YEZIDI LETTER SE",NULL},
/* 10E86 */ { "YEZIDI LETTER CIM",NULL},
/* 10E87 */ { "YEZIDI LETTER CHIM",NULL},
/* 10E88 */ { "YEZIDI LETTER CHHIM",NULL},
/* 10E89 */ { "YEZIDI LETTER HHA",NULL},
/* 10E8A */ { "YEZIDI LETTER XA",NULL},
/* 10E8B */ { "YEZIDI LETTER DAL",NULL},
/* 10E8C */ { "YEZIDI LETTER ZAL",NULL},
/* 10E8D */ { "YEZIDI LETTER RA",NULL},
/* 10E8E */ { "YEZIDI LETTER RHA",NULL},
/* 10E8F */ { "YEZIDI LETTER ZA",NULL},
/* 10E90 */ { "YEZIDI LETTER JA",NULL},
/* 10E91 */ { "YEZIDI LETTER SIN",NULL},
/* 10E92 */ { "YEZIDI LETTER SHIN",NULL},
/* 10E93 */ { "YEZIDI LETTER SAD",NULL},
/* 10E94 */ { "YEZIDI LETTER DAD",NULL},
/* 10E95 */ { "YEZIDI LETTER TA",NULL},
/* 10E96 */ { "YEZIDI LETTER ZE",NULL},
/* 10E97 */ { "YEZIDI LETTER EYN",NULL},
/* 10E98 */ { "YEZIDI LETTER XHEYN",NULL},
/* 10E99 */ { "YEZIDI LETTER FA",NULL},
/* 10E9A */ { "YEZIDI LETTER VA",NULL},
/* 10E9B */ { "YEZIDI LETTER VA ALTERNATE FORM",NULL},
/* 10E9C */ { "YEZIDI LETTER QAF",NULL},
/* 10E9D */ { "YEZIDI LETTER KAF",NULL},
/* 10E9E */ { "YEZIDI LETTER KHAF",NULL},
/* 10E9F */ { "YEZIDI LETTER GAF",NULL},
/* 10EA0 */ { "YEZIDI LETTER LAM",NULL},
/* 10EA1 */ { "YEZIDI LETTER MIM",NULL},
/* 10EA2 */ { "YEZIDI LETTER NUN",NULL},
/* 10EA3 */ { "YEZIDI LETTER UM",NULL},
/* 10EA4 */ { "YEZIDI LETTER WAW",NULL},
/* 10EA5 */ { "YEZIDI LETTER OW",NULL},
/* 10EA6 */ { "YEZIDI LETTER EW",NULL},
/* 10EA7 */ { "YEZIDI LETTER HAY",NULL},
/* 10EA8 */ { "YEZIDI LETTER YOT",NULL},
/* 10EA9 */ { "YEZIDI LETTER ET",NULL},
/* 10EAA */ { NULL,NULL},
/* 10EAB */ { "YEZIDI COMBINING HAMZA MARK","	* denotes a glottal stop"},
/* 10EAC */ { "YEZIDI COMBINING MADDA MARK","	* denotes long /a/ at the beginning of some words"},
/* 10EAD */ { "YEZIDI HYPHENATION MARK",NULL},
/* 10EAE */ { NULL,NULL},
/* 10EAF */ { NULL,NULL},
/* 10EB0 */ { "YEZIDI LETTER LAM WITH DOT ABOVE",NULL},
/* 10EB1 */ { "YEZIDI LETTER YOT WITH CIRCUMFLEX ABOVE",NULL},
/* 10EB2 */ { NULL,NULL},
/* 10EB3 */ { NULL,NULL},
/* 10EB4 */ { NULL,NULL},
/* 10EB5 */ { NULL,NULL},
/* 10EB6 */ { NULL,NULL},
/* 10EB7 */ { NULL,NULL},
/* 10EB8 */ { NULL,NULL},
/* 10EB9 */ { NULL,NULL},
/* 10EBA */ { NULL,NULL},
/* 10EBB */ { NULL,NULL},
/* 10EBC */ { NULL,NULL},
/* 10EBD */ { NULL,NULL},
/* 10EBE */ { NULL,NULL},
/* 10EBF */ { NULL,NULL},
/* 10EC0 */ { NULL,NULL},
/* 10EC1 */ { NULL,NULL},
/* 10EC2 */ { "ARABIC LETTER DAL WITH TWO DOTS VERTICALLY BELOW",NULL},
/* 10EC3 */ { "ARABIC LETTER TAH WITH TWO DOTS VERTICALLY BELOW",NULL},
/* 10EC4 */ { "ARABIC LETTER KAF WITH TWO DOTS VERTICALLY BELOW",NULL},
/* 10EC5 */ { "ARABIC SMALL YEH BARREE WITH TWO DOTS BELOW","	* used to mark unwritten yeh in Uthmanic rasm\n"
	"	x (arabic small yeh - 06E6)\n"
	"	x (arabic small high yeh barree with two dots below - 08CB)"},
/* 10EC6 */ { "ARABIC LETTER THIN NOON","	* only medial form is attested"},
/* 10EC7 */ { "ARABIC LETTER YEH WITH FOUR DOTS BELOW",NULL},
/* 10EC8 */ { NULL,NULL},
/* 10EC9 */ { NULL,NULL},
/* 10ECA */ { NULL,NULL},
/* 10ECB */ { NULL,NULL},
/* 10ECC */ { NULL,NULL},
/* 10ECD */ { NULL,NULL},
/* 10ECE */ { NULL,NULL},
/* 10ECF */ { NULL,NULL},
/* 10ED0 */ { "ARABIC BIBLICAL END OF VERSE","	* used as end of verse marker in Urdu"},
/* 10ED1 */ { "ARABIC LIGATURE ALAYHAA AS-SALAATU WAS-SALAAM",NULL},
/* 10ED2 */ { "ARABIC LIGATURE ALAYHIM AS-SALAATU WAS-SALAAM",NULL},
/* 10ED3 */ { "ARABIC LIGATURE ALAYHIMAA AS-SALAATU WAS-SALAAM",NULL},
/* 10ED4 */ { "ARABIC LIGATURE QADDASA ALLAAHU SIRRAH",NULL},
/* 10ED5 */ { "ARABIC LIGATURE QUDDISA SIRRUHUM",NULL},
/* 10ED6 */ { "ARABIC LIGATURE QUDDISA SIRRUHUMAA",NULL},
/* 10ED7 */ { "ARABIC LIGATURE QUDDISAT ASRAARUHUM",NULL},
/* 10ED8 */ { "ARABIC LIGATURE NAWWARA ALLAAHU MARQADAH",NULL},
/* 10ED9 */ { NULL,NULL},
/* 10EDA */ { NULL,NULL},
/* 10EDB */ { NULL,NULL},
/* 10EDC */ { NULL,NULL},
/* 10EDD */ { NULL,NULL},
/* 10EDE */ { NULL,NULL},
/* 10EDF */ { NULL,NULL},
/* 10EE0 */ { NULL,NULL},
/* 10EE1 */ { NULL,NULL},
/* 10EE2 */ { NULL,NULL},
/* 10EE3 */ { NULL,NULL},
/* 10EE4 */ { NULL,NULL},
/* 10EE5 */ { NULL,NULL},
/* 10EE6 */ { NULL,NULL},
/* 10EE7 */ { NULL,NULL},
/* 10EE8 */ { NULL,NULL},
/* 10EE9 */ { NULL,NULL},
/* 10EEA */ { NULL,NULL},
/* 10EEB */ { NULL,NULL},
/* 10EEC */ { NULL,NULL},
/* 10EED */ { NULL,NULL},
/* 10EEE */ { NULL,NULL},
/* 10EEF */ { NULL,NULL},
/* 10EF0 */ { NULL,NULL},
/* 10EF1 */ { NULL,NULL},
/* 10EF2 */ { NULL,NULL},
/* 10EF3 */ { NULL,NULL},
/* 10EF4 */ { NULL,NULL},
/* 10EF5 */ { NULL,NULL},
/* 10EF6 */ { NULL,NULL},
/* 10EF7 */ { NULL,NULL},
/* 10EF8 */ { NULL,NULL},
/* 10EF9 */ { NULL,NULL},
/* 10EFA */ { "ARABIC DOUBLE VERTICAL BAR BELOW","	x (arabic kasratan - 064D)"},
/* 10EFB */ { "ARABIC SMALL LOW NOON","	x (arabic small low noon with kasra - 08D9)"},
/* 10EFC */ { "ARABIC COMBINING ALEF OVERLAY",NULL},
/* 10EFD */ { "ARABIC SMALL LOW WORD SAKTA","	x (arabic small high word sakta - 08DD)"},
/* 10EFE */ { "ARABIC SMALL LOW WORD QASR",NULL},
/* 10EFF */ { "ARABIC SMALL LOW WORD MADDA",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_0F[] = {
/* 10F00 */ { "OLD SOGDIAN LETTER ALEPH",NULL},
/* 10F01 */ { "OLD SOGDIAN LETTER FINAL ALEPH",NULL},
/* 10F02 */ { "OLD SOGDIAN LETTER BETH",NULL},
/* 10F03 */ { "OLD SOGDIAN LETTER FINAL BETH",NULL},
/* 10F04 */ { "OLD SOGDIAN LETTER GIMEL",NULL},
/* 10F05 */ { "OLD SOGDIAN LETTER HE",NULL},
/* 10F06 */ { "OLD SOGDIAN LETTER FINAL HE",NULL},
/* 10F07 */ { "OLD SOGDIAN LETTER WAW",NULL},
/* 10F08 */ { "OLD SOGDIAN LETTER ZAYIN",NULL},
/* 10F09 */ { "OLD SOGDIAN LETTER HETH",NULL},
/* 10F0A */ { "OLD SOGDIAN LETTER YODH",NULL},
/* 10F0B */ { "OLD SOGDIAN LETTER KAPH",NULL},
/* 10F0C */ { "OLD SOGDIAN LETTER LAMEDH",NULL},
/* 10F0D */ { "OLD SOGDIAN LETTER MEM",NULL},
/* 10F0E */ { "OLD SOGDIAN LETTER NUN",NULL},
/* 10F0F */ { "OLD SOGDIAN LETTER FINAL NUN",NULL},
/* 10F10 */ { "OLD SOGDIAN LETTER FINAL NUN WITH VERTICAL TAIL",NULL},
/* 10F11 */ { "OLD SOGDIAN LETTER SAMEKH",NULL},
/* 10F12 */ { "OLD SOGDIAN LETTER AYIN","	* used only in the Aramaic heterogram ʿD\n"
	"	* resh-ayin-daleth is used in other heterograms"},
/* 10F13 */ { "OLD SOGDIAN LETTER ALTERNATE AYIN","	* used only in the Aramaic heterogram ʿD\n"
	"	* resh-ayin-daleth is used in other heterograms"},
/* 10F14 */ { "OLD SOGDIAN LETTER PE",NULL},
/* 10F15 */ { "OLD SOGDIAN LETTER SADHE",NULL},
/* 10F16 */ { "OLD SOGDIAN LETTER FINAL SADHE",NULL},
/* 10F17 */ { "OLD SOGDIAN LETTER FINAL SADHE WITH VERTICAL TAIL",NULL},
/* 10F18 */ { "OLD SOGDIAN LETTER RESH-AYIN-DALETH",NULL},
/* 10F19 */ { "OLD SOGDIAN LETTER SHIN",NULL},
/* 10F1A */ { "OLD SOGDIAN LETTER TAW",NULL},
/* 10F1B */ { "OLD SOGDIAN LETTER FINAL TAW",NULL},
/* 10F1C */ { "OLD SOGDIAN LETTER FINAL TAW WITH VERTICAL TAIL",NULL},
/* 10F1D */ { "OLD SOGDIAN NUMBER ONE",NULL},
/* 10F1E */ { "OLD SOGDIAN NUMBER TWO",NULL},
/* 10F1F */ { "OLD SOGDIAN NUMBER THREE",NULL},
/* 10F20 */ { "OLD SOGDIAN NUMBER FOUR",NULL},
/* 10F21 */ { "OLD SOGDIAN NUMBER FIVE",NULL},
/* 10F22 */ { "OLD SOGDIAN NUMBER TEN",NULL},
/* 10F23 */ { "OLD SOGDIAN NUMBER TWENTY",NULL},
/* 10F24 */ { "OLD SOGDIAN NUMBER THIRTY",NULL},
/* 10F25 */ { "OLD SOGDIAN NUMBER ONE HUNDRED",NULL},
/* 10F26 */ { "OLD SOGDIAN FRACTION ONE HALF",NULL},
/* 10F27 */ { "OLD SOGDIAN LIGATURE AYIN-DALETH","	* represents the Aramaic heterogram ʿD"},
/* 10F28 */ { NULL,NULL},
/* 10F29 */ { NULL,NULL},
/* 10F2A */ { NULL,NULL},
/* 10F2B */ { NULL,NULL},
/* 10F2C */ { NULL,NULL},
/* 10F2D */ { NULL,NULL},
/* 10F2E */ { NULL,NULL},
/* 10F2F */ { NULL,NULL},
/* 10F30 */ { "SOGDIAN LETTER ALEPH",NULL},
/* 10F31 */ { "SOGDIAN LETTER BETH",NULL},
/* 10F32 */ { "SOGDIAN LETTER GIMEL",NULL},
/* 10F33 */ { "SOGDIAN LETTER HE",NULL},
/* 10F34 */ { "SOGDIAN LETTER WAW",NULL},
/* 10F35 */ { "SOGDIAN LETTER ZAYIN",NULL},
/* 10F36 */ { "SOGDIAN LETTER HETH",NULL},
/* 10F37 */ { "SOGDIAN LETTER YODH",NULL},
/* 10F38 */ { "SOGDIAN LETTER KAPH",NULL},
/* 10F39 */ { "SOGDIAN LETTER LAMEDH",NULL},
/* 10F3A */ { "SOGDIAN LETTER MEM",NULL},
/* 10F3B */ { "SOGDIAN LETTER NUN",NULL},
/* 10F3C */ { "SOGDIAN LETTER SAMEKH",NULL},
/* 10F3D */ { "SOGDIAN LETTER AYIN","	* used only in Aramaic heterograms"},
/* 10F3E */ { "SOGDIAN LETTER PE",NULL},
/* 10F3F */ { "SOGDIAN LETTER SADHE",NULL},
/* 10F40 */ { "SOGDIAN LETTER RESH-AYIN",NULL},
/* 10F41 */ { "SOGDIAN LETTER SHIN",NULL},
/* 10F42 */ { "SOGDIAN LETTER TAW",NULL},
/* 10F43 */ { "SOGDIAN LETTER FETH",NULL},
/* 10F44 */ { "SOGDIAN LETTER LESH","	= hooked resh"},
/* 10F45 */ { "SOGDIAN INDEPENDENT SHIN","	x 6240"},
/* 10F46 */ { "SOGDIAN COMBINING DOT BELOW",NULL},
/* 10F47 */ { "SOGDIAN COMBINING TWO DOTS BELOW",NULL},
/* 10F48 */ { "SOGDIAN COMBINING DOT ABOVE",NULL},
/* 10F49 */ { "SOGDIAN COMBINING TWO DOTS ABOVE",NULL},
/* 10F4A */ { "SOGDIAN COMBINING CURVE ABOVE",NULL},
/* 10F4B */ { "SOGDIAN COMBINING CURVE BELOW",NULL},
/* 10F4C */ { "SOGDIAN COMBINING HOOK ABOVE",NULL},
/* 10F4D */ { "SOGDIAN COMBINING HOOK BELOW",NULL},
/* 10F4E */ { "SOGDIAN COMBINING LONG HOOK BELOW",NULL},
/* 10F4F */ { "SOGDIAN COMBINING RESH BELOW",NULL},
/* 10F50 */ { "SOGDIAN COMBINING STROKE BELOW",NULL},
/* 10F51 */ { "SOGDIAN NUMBER ONE",NULL},
/* 10F52 */ { "SOGDIAN NUMBER TEN",NULL},
/* 10F53 */ { "SOGDIAN NUMBER TWENTY",NULL},
/* 10F54 */ { "SOGDIAN NUMBER ONE HUNDRED",NULL},
/* 10F55 */ { "SOGDIAN PUNCTUATION TWO VERTICAL BARS",NULL},
/* 10F56 */ { "SOGDIAN PUNCTUATION TWO VERTICAL BARS WITH DOTS",NULL},
/* 10F57 */ { "SOGDIAN PUNCTUATION CIRCLE WITH DOT",NULL},
/* 10F58 */ { "SOGDIAN PUNCTUATION TWO CIRCLES WITH DOTS",NULL},
/* 10F59 */ { "SOGDIAN PUNCTUATION HALF CIRCLE WITH DOT",NULL},
/* 10F5A */ { NULL,NULL},
/* 10F5B */ { NULL,NULL},
/* 10F5C */ { NULL,NULL},
/* 10F5D */ { NULL,NULL},
/* 10F5E */ { NULL,NULL},
/* 10F5F */ { NULL,NULL},
/* 10F60 */ { NULL,NULL},
/* 10F61 */ { NULL,NULL},
/* 10F62 */ { NULL,NULL},
/* 10F63 */ { NULL,NULL},
/* 10F64 */ { NULL,NULL},
/* 10F65 */ { NULL,NULL},
/* 10F66 */ { NULL,NULL},
/* 10F67 */ { NULL,NULL},
/* 10F68 */ { NULL,NULL},
/* 10F69 */ { NULL,NULL},
/* 10F6A */ { NULL,NULL},
/* 10F6B */ { NULL,NULL},
/* 10F6C */ { NULL,NULL},
/* 10F6D */ { NULL,NULL},
/* 10F6E */ { NULL,NULL},
/* 10F6F */ { NULL,NULL},
/* 10F70 */ { "OLD UYGHUR LETTER ALEPH",NULL},
/* 10F71 */ { "OLD UYGHUR LETTER BETH",NULL},
/* 10F72 */ { "OLD UYGHUR LETTER GIMEL-HETH",NULL},
/* 10F73 */ { "OLD UYGHUR LETTER WAW",NULL},
/* 10F74 */ { "OLD UYGHUR LETTER ZAYIN",NULL},
/* 10F75 */ { "OLD UYGHUR LETTER FINAL HETH",NULL},
/* 10F76 */ { "OLD UYGHUR LETTER YODH",NULL},
/* 10F77 */ { "OLD UYGHUR LETTER KAPH",NULL},
/* 10F78 */ { "OLD UYGHUR LETTER LAMEDH",NULL},
/* 10F79 */ { "OLD UYGHUR LETTER MEM",NULL},
/* 10F7A */ { "OLD UYGHUR LETTER NUN",NULL},
/* 10F7B */ { "OLD UYGHUR LETTER SAMEKH",NULL},
/* 10F7C */ { "OLD UYGHUR LETTER PE",NULL},
/* 10F7D */ { "OLD UYGHUR LETTER SADHE",NULL},
/* 10F7E */ { "OLD UYGHUR LETTER RESH",NULL},
/* 10F7F */ { "OLD UYGHUR LETTER SHIN",NULL},
/* 10F80 */ { "OLD UYGHUR LETTER TAW",NULL},
/* 10F81 */ { "OLD UYGHUR LETTER LESH","	= hooked resh"},
/* 10F82 */ { "OLD UYGHUR COMBINING DOT ABOVE",NULL},
/* 10F83 */ { "OLD UYGHUR COMBINING DOT BELOW",NULL},
/* 10F84 */ { "OLD UYGHUR COMBINING TWO DOTS ABOVE",NULL},
/* 10F85 */ { "OLD UYGHUR COMBINING TWO DOTS BELOW",NULL},
/* 10F86 */ { "OLD UYGHUR PUNCTUATION BAR",NULL},
/* 10F87 */ { "OLD UYGHUR PUNCTUATION TWO BARS",NULL},
/* 10F88 */ { "OLD UYGHUR PUNCTUATION TWO DOTS",NULL},
/* 10F89 */ { "OLD UYGHUR PUNCTUATION FOUR DOTS",NULL},
/* 10F8A */ { NULL,NULL},
/* 10F8B */ { NULL,NULL},
/* 10F8C */ { NULL,NULL},
/* 10F8D */ { NULL,NULL},
/* 10F8E */ { NULL,NULL},
/* 10F8F */ { NULL,NULL},
/* 10F90 */ { NULL,NULL},
/* 10F91 */ { NULL,NULL},
/* 10F92 */ { NULL,NULL},
/* 10F93 */ { NULL,NULL},
/* 10F94 */ { NULL,NULL},
/* 10F95 */ { NULL,NULL},
/* 10F96 */ { NULL,NULL},
/* 10F97 */ { NULL,NULL},
/* 10F98 */ { NULL,NULL},
/* 10F99 */ { NULL,NULL},
/* 10F9A */ { NULL,NULL},
/* 10F9B */ { NULL,NULL},
/* 10F9C */ { NULL,NULL},
/* 10F9D */ { NULL,NULL},
/* 10F9E */ { NULL,NULL},
/* 10F9F */ { NULL,NULL},
/* 10FA0 */ { NULL,NULL},
/* 10FA1 */ { NULL,NULL},
/* 10FA2 */ { NULL,NULL},
/* 10FA3 */ { NULL,NULL},
/* 10FA4 */ { NULL,NULL},
/* 10FA5 */ { NULL,NULL},
/* 10FA6 */ { NULL,NULL},
/* 10FA7 */ { NULL,NULL},
/* 10FA8 */ { NULL,NULL},
/* 10FA9 */ { NULL,NULL},
/* 10FAA */ { NULL,NULL},
/* 10FAB */ { NULL,NULL},
/* 10FAC */ { NULL,NULL},
/* 10FAD */ { NULL,NULL},
/* 10FAE */ { NULL,NULL},
/* 10FAF */ { NULL,NULL},
/* 10FB0 */ { "CHORASMIAN LETTER ALEPH",NULL},
/* 10FB1 */ { "CHORASMIAN LETTER SMALL ALEPH",NULL},
/* 10FB2 */ { "CHORASMIAN LETTER BETH",NULL},
/* 10FB3 */ { "CHORASMIAN LETTER GIMEL",NULL},
/* 10FB4 */ { "CHORASMIAN LETTER DALETH",NULL},
/* 10FB5 */ { "CHORASMIAN LETTER HE",NULL},
/* 10FB6 */ { "CHORASMIAN LETTER WAW",NULL},
/* 10FB7 */ { "CHORASMIAN LETTER CURLED WAW",NULL},
/* 10FB8 */ { "CHORASMIAN LETTER ZAYIN",NULL},
/* 10FB9 */ { "CHORASMIAN LETTER HETH",NULL},
/* 10FBA */ { "CHORASMIAN LETTER YODH",NULL},
/* 10FBB */ { "CHORASMIAN LETTER KAPH",NULL},
/* 10FBC */ { "CHORASMIAN LETTER LAMEDH",NULL},
/* 10FBD */ { "CHORASMIAN LETTER MEM",NULL},
/* 10FBE */ { "CHORASMIAN LETTER NUN",NULL},
/* 10FBF */ { "CHORASMIAN LETTER SAMEKH",NULL},
/* 10FC0 */ { "CHORASMIAN LETTER AYIN",NULL},
/* 10FC1 */ { "CHORASMIAN LETTER PE",NULL},
/* 10FC2 */ { "CHORASMIAN LETTER RESH",NULL},
/* 10FC3 */ { "CHORASMIAN LETTER SHIN",NULL},
/* 10FC4 */ { "CHORASMIAN LETTER TAW",NULL},
/* 10FC5 */ { "CHORASMIAN NUMBER ONE",NULL},
/* 10FC6 */ { "CHORASMIAN NUMBER TWO",NULL},
/* 10FC7 */ { "CHORASMIAN NUMBER THREE",NULL},
/* 10FC8 */ { "CHORASMIAN NUMBER FOUR",NULL},
/* 10FC9 */ { "CHORASMIAN NUMBER TEN",NULL},
/* 10FCA */ { "CHORASMIAN NUMBER TWENTY",NULL},
/* 10FCB */ { "CHORASMIAN NUMBER ONE HUNDRED",NULL},
/* 10FCC */ { NULL,NULL},
/* 10FCD */ { NULL,NULL},
/* 10FCE */ { NULL,NULL},
/* 10FCF */ { NULL,NULL},
/* 10FD0 */ { NULL,NULL},
/* 10FD1 */ { NULL,NULL},
/* 10FD2 */ { NULL,NULL},
/* 10FD3 */ { NULL,NULL},
/* 10FD4 */ { NULL,NULL},
/* 10FD5 */ { NULL,NULL},
/* 10FD6 */ { NULL,NULL},
/* 10FD7 */ { NULL,NULL},
/* 10FD8 */ { NULL,NULL},
/* 10FD9 */ { NULL,NULL},
/* 10FDA */ { NULL,NULL},
/* 10FDB */ { NULL,NULL},
/* 10FDC */ { NULL,NULL},
/* 10FDD */ { NULL,NULL},
/* 10FDE */ { NULL,NULL},
/* 10FDF */ { NULL,NULL},
/* 10FE0 */ { "ELYMAIC LETTER ALEPH",NULL},
/* 10FE1 */ { "ELYMAIC LETTER BETH",NULL},
/* 10FE2 */ { "ELYMAIC LETTER GIMEL",NULL},
/* 10FE3 */ { "ELYMAIC LETTER DALETH",NULL},
/* 10FE4 */ { "ELYMAIC LETTER HE",NULL},
/* 10FE5 */ { "ELYMAIC LETTER WAW",NULL},
/* 10FE6 */ { "ELYMAIC LETTER ZAYIN",NULL},
/* 10FE7 */ { "ELYMAIC LETTER HETH",NULL},
/* 10FE8 */ { "ELYMAIC LETTER TETH",NULL},
/* 10FE9 */ { "ELYMAIC LETTER YODH",NULL},
/* 10FEA */ { "ELYMAIC LETTER KAPH",NULL},
/* 10FEB */ { "ELYMAIC LETTER LAMEDH",NULL},
/* 10FEC */ { "ELYMAIC LETTER MEM",NULL},
/* 10FED */ { "ELYMAIC LETTER NUN",NULL},
/* 10FEE */ { "ELYMAIC LETTER SAMEKH",NULL},
/* 10FEF */ { "ELYMAIC LETTER AYIN",NULL},
/* 10FF0 */ { "ELYMAIC LETTER PE",NULL},
/* 10FF1 */ { "ELYMAIC LETTER SADHE",NULL},
/* 10FF2 */ { "ELYMAIC LETTER QOPH",NULL},
/* 10FF3 */ { "ELYMAIC LETTER RESH",NULL},
/* 10FF4 */ { "ELYMAIC LETTER SHIN",NULL},
/* 10FF5 */ { "ELYMAIC LETTER TAW",NULL},
/* 10FF6 */ { "ELYMAIC LIGATURE ZAYIN-YODH","	* used for the Aramaic heterogram zy"},
/* 10FF7 */ { NULL,NULL},
/* 10FF8 */ { NULL,NULL},
/* 10FF9 */ { NULL,NULL},
/* 10FFA */ { NULL,NULL},
/* 10FFB */ { NULL,NULL},
/* 10FFC */ { NULL,NULL},
/* 10FFD */ { NULL,NULL},
/* 10FFE */ { NULL,NULL},
/* 10FFF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_10[] = {
/* 11000 */ { "BRAHMI SIGN CANDRABINDU",NULL},
/* 11001 */ { "BRAHMI SIGN ANUSVARA",NULL},
/* 11002 */ { "BRAHMI SIGN VISARGA",NULL},
/* 11003 */ { "BRAHMI SIGN JIHVAMULIYA",NULL},
/* 11004 */ { "BRAHMI SIGN UPADHMANIYA",NULL},
/* 11005 */ { "BRAHMI LETTER A",NULL},
/* 11006 */ { "BRAHMI LETTER AA",NULL},
/* 11007 */ { "BRAHMI LETTER I",NULL},
/* 11008 */ { "BRAHMI LETTER II",NULL},
/* 11009 */ { "BRAHMI LETTER U",NULL},
/* 1100A */ { "BRAHMI LETTER UU",NULL},
/* 1100B */ { "BRAHMI LETTER VOCALIC R",NULL},
/* 1100C */ { "BRAHMI LETTER VOCALIC RR",NULL},
/* 1100D */ { "BRAHMI LETTER VOCALIC L",NULL},
/* 1100E */ { "BRAHMI LETTER VOCALIC LL",NULL},
/* 1100F */ { "BRAHMI LETTER E",NULL},
/* 11010 */ { "BRAHMI LETTER AI",NULL},
/* 11011 */ { "BRAHMI LETTER O",NULL},
/* 11012 */ { "BRAHMI LETTER AU",NULL},
/* 11013 */ { "BRAHMI LETTER KA",NULL},
/* 11014 */ { "BRAHMI LETTER KHA",NULL},
/* 11015 */ { "BRAHMI LETTER GA",NULL},
/* 11016 */ { "BRAHMI LETTER GHA",NULL},
/* 11017 */ { "BRAHMI LETTER NGA",NULL},
/* 11018 */ { "BRAHMI LETTER CA",NULL},
/* 11019 */ { "BRAHMI LETTER CHA",NULL},
/* 1101A */ { "BRAHMI LETTER JA",NULL},
/* 1101B */ { "BRAHMI LETTER JHA",NULL},
/* 1101C */ { "BRAHMI LETTER NYA",NULL},
/* 1101D */ { "BRAHMI LETTER TTA",NULL},
/* 1101E */ { "BRAHMI LETTER TTHA",NULL},
/* 1101F */ { "BRAHMI LETTER DDA",NULL},
/* 11020 */ { "BRAHMI LETTER DDHA",NULL},
/* 11021 */ { "BRAHMI LETTER NNA",NULL},
/* 11022 */ { "BRAHMI LETTER TA",NULL},
/* 11023 */ { "BRAHMI LETTER THA",NULL},
/* 11024 */ { "BRAHMI LETTER DA",NULL},
/* 11025 */ { "BRAHMI LETTER DHA",NULL},
/* 11026 */ { "BRAHMI LETTER NA",NULL},
/* 11027 */ { "BRAHMI LETTER PA",NULL},
/* 11028 */ { "BRAHMI LETTER PHA",NULL},
/* 11029 */ { "BRAHMI LETTER BA",NULL},
/* 1102A */ { "BRAHMI LETTER BHA",NULL},
/* 1102B */ { "BRAHMI LETTER MA",NULL},
/* 1102C */ { "BRAHMI LETTER YA",NULL},
/* 1102D */ { "BRAHMI LETTER RA",NULL},
/* 1102E */ { "BRAHMI LETTER LA",NULL},
/* 1102F */ { "BRAHMI LETTER VA",NULL},
/* 11030 */ { "BRAHMI LETTER SHA",NULL},
/* 11031 */ { "BRAHMI LETTER SSA",NULL},
/* 11032 */ { "BRAHMI LETTER SA",NULL},
/* 11033 */ { "BRAHMI LETTER HA",NULL},
/* 11034 */ { "BRAHMI LETTER LLA",NULL},
/* 11035 */ { "BRAHMI LETTER OLD TAMIL LLLA",NULL},
/* 11036 */ { "BRAHMI LETTER OLD TAMIL RRA",NULL},
/* 11037 */ { "BRAHMI LETTER OLD TAMIL NNNA",NULL},
/* 11038 */ { "BRAHMI VOWEL SIGN AA",NULL},
/* 11039 */ { "BRAHMI VOWEL SIGN BHATTIPROLU AA",NULL},
/* 1103A */ { "BRAHMI VOWEL SIGN I",NULL},
/* 1103B */ { "BRAHMI VOWEL SIGN II",NULL},
/* 1103C */ { "BRAHMI VOWEL SIGN U",NULL},
/* 1103D */ { "BRAHMI VOWEL SIGN UU",NULL},
/* 1103E */ { "BRAHMI VOWEL SIGN VOCALIC R",NULL},
/* 1103F */ { "BRAHMI VOWEL SIGN VOCALIC RR",NULL},
/* 11040 */ { "BRAHMI VOWEL SIGN VOCALIC L",NULL},
/* 11041 */ { "BRAHMI VOWEL SIGN VOCALIC LL",NULL},
/* 11042 */ { "BRAHMI VOWEL SIGN E",NULL},
/* 11043 */ { "BRAHMI VOWEL SIGN AI",NULL},
/* 11044 */ { "BRAHMI VOWEL SIGN O",NULL},
/* 11045 */ { "BRAHMI VOWEL SIGN AU",NULL},
/* 11046 */ { "BRAHMI VIRAMA",NULL},
/* 11047 */ { "BRAHMI DANDA",NULL},
/* 11048 */ { "BRAHMI DOUBLE DANDA",NULL},
/* 11049 */ { "BRAHMI PUNCTUATION DOT",NULL},
/* 1104A */ { "BRAHMI PUNCTUATION DOUBLE DOT",NULL},
/* 1104B */ { "BRAHMI PUNCTUATION LINE",NULL},
/* 1104C */ { "BRAHMI PUNCTUATION CRESCENT BAR",NULL},
/* 1104D */ { "BRAHMI PUNCTUATION LOTUS",NULL},
/* 1104E */ { NULL,NULL},
/* 1104F */ { NULL,NULL},
/* 11050 */ { NULL,NULL},
/* 11051 */ { NULL,NULL},
/* 11052 */ { "BRAHMI NUMBER ONE",NULL},
/* 11053 */ { "BRAHMI NUMBER TWO",NULL},
/* 11054 */ { "BRAHMI NUMBER THREE",NULL},
/* 11055 */ { "BRAHMI NUMBER FOUR",NULL},
/* 11056 */ { "BRAHMI NUMBER FIVE",NULL},
/* 11057 */ { "BRAHMI NUMBER SIX",NULL},
/* 11058 */ { "BRAHMI NUMBER SEVEN",NULL},
/* 11059 */ { "BRAHMI NUMBER EIGHT",NULL},
/* 1105A */ { "BRAHMI NUMBER NINE",NULL},
/* 1105B */ { "BRAHMI NUMBER TEN",NULL},
/* 1105C */ { "BRAHMI NUMBER TWENTY",NULL},
/* 1105D */ { "BRAHMI NUMBER THIRTY",NULL},
/* 1105E */ { "BRAHMI NUMBER FORTY",NULL},
/* 1105F */ { "BRAHMI NUMBER FIFTY",NULL},
/* 11060 */ { "BRAHMI NUMBER SIXTY",NULL},
/* 11061 */ { "BRAHMI NUMBER SEVENTY",NULL},
/* 11062 */ { "BRAHMI NUMBER EIGHTY",NULL},
/* 11063 */ { "BRAHMI NUMBER NINETY",NULL},
/* 11064 */ { "BRAHMI NUMBER ONE HUNDRED",NULL},
/* 11065 */ { "BRAHMI NUMBER ONE THOUSAND",NULL},
/* 11066 */ { "BRAHMI DIGIT ZERO",NULL},
/* 11067 */ { "BRAHMI DIGIT ONE",NULL},
/* 11068 */ { "BRAHMI DIGIT TWO",NULL},
/* 11069 */ { "BRAHMI DIGIT THREE",NULL},
/* 1106A */ { "BRAHMI DIGIT FOUR",NULL},
/* 1106B */ { "BRAHMI DIGIT FIVE",NULL},
/* 1106C */ { "BRAHMI DIGIT SIX",NULL},
/* 1106D */ { "BRAHMI DIGIT SEVEN",NULL},
/* 1106E */ { "BRAHMI DIGIT EIGHT",NULL},
/* 1106F */ { "BRAHMI DIGIT NINE",NULL},
/* 11070 */ { "BRAHMI SIGN OLD TAMIL VIRAMA",NULL},
/* 11071 */ { "BRAHMI LETTER OLD TAMIL SHORT E",NULL},
/* 11072 */ { "BRAHMI LETTER OLD TAMIL SHORT O",NULL},
/* 11073 */ { "BRAHMI VOWEL SIGN OLD TAMIL SHORT E",NULL},
/* 11074 */ { "BRAHMI VOWEL SIGN OLD TAMIL SHORT O",NULL},
/* 11075 */ { "BRAHMI LETTER OLD TAMIL LLA",NULL},
/* 11076 */ { NULL,NULL},
/* 11077 */ { NULL,NULL},
/* 11078 */ { NULL,NULL},
/* 11079 */ { NULL,NULL},
/* 1107A */ { NULL,NULL},
/* 1107B */ { NULL,NULL},
/* 1107C */ { NULL,NULL},
/* 1107D */ { NULL,NULL},
/* 1107E */ { NULL,NULL},
/* 1107F */ { "BRAHMI NUMBER JOINER","	* a virama used to form ligatures between Brahmi numbers signifying multiplication"},
/* 11080 */ { "KAITHI SIGN CANDRABINDU",NULL},
/* 11081 */ { "KAITHI SIGN ANUSVARA",NULL},
/* 11082 */ { "KAITHI SIGN VISARGA",NULL},
/* 11083 */ { "KAITHI LETTER A",NULL},
/* 11084 */ { "KAITHI LETTER AA",NULL},
/* 11085 */ { "KAITHI LETTER I",NULL},
/* 11086 */ { "KAITHI LETTER II",NULL},
/* 11087 */ { "KAITHI LETTER U",NULL},
/* 11088 */ { "KAITHI LETTER UU",NULL},
/* 11089 */ { "KAITHI LETTER E",NULL},
/* 1108A */ { "KAITHI LETTER AI",NULL},
/* 1108B */ { "KAITHI LETTER O",NULL},
/* 1108C */ { "KAITHI LETTER AU",NULL},
/* 1108D */ { "KAITHI LETTER KA",NULL},
/* 1108E */ { "KAITHI LETTER KHA",NULL},
/* 1108F */ { "KAITHI LETTER GA",NULL},
/* 11090 */ { "KAITHI LETTER GHA",NULL},
/* 11091 */ { "KAITHI LETTER NGA",NULL},
/* 11092 */ { "KAITHI LETTER CA",NULL},
/* 11093 */ { "KAITHI LETTER CHA",NULL},
/* 11094 */ { "KAITHI LETTER JA",NULL},
/* 11095 */ { "KAITHI LETTER JHA",NULL},
/* 11096 */ { "KAITHI LETTER NYA",NULL},
/* 11097 */ { "KAITHI LETTER TTA",NULL},
/* 11098 */ { "KAITHI LETTER TTHA",NULL},
/* 11099 */ { "KAITHI LETTER DDA",NULL},
/* 1109A */ { "KAITHI LETTER DDDHA","	: 11099 110BA"},
/* 1109B */ { "KAITHI LETTER DDHA",NULL},
/* 1109C */ { "KAITHI LETTER RHA","	: 1109B 110BA"},
/* 1109D */ { "KAITHI LETTER NNA",NULL},
/* 1109E */ { "KAITHI LETTER TA",NULL},
/* 1109F */ { "KAITHI LETTER THA",NULL},
/* 110A0 */ { "KAITHI LETTER DA",NULL},
/* 110A1 */ { "KAITHI LETTER DHA",NULL},
/* 110A2 */ { "KAITHI LETTER NA",NULL},
/* 110A3 */ { "KAITHI LETTER PA",NULL},
/* 110A4 */ { "KAITHI LETTER PHA",NULL},
/* 110A5 */ { "KAITHI LETTER BA",NULL},
/* 110A6 */ { "KAITHI LETTER BHA",NULL},
/* 110A7 */ { "KAITHI LETTER MA",NULL},
/* 110A8 */ { "KAITHI LETTER YA","	* glyph may be rendered with or without the visible dot"},
/* 110A9 */ { "KAITHI LETTER RA",NULL},
/* 110AA */ { "KAITHI LETTER LA",NULL},
/* 110AB */ { "KAITHI LETTER VA","	: 110A5 110BA"},
/* 110AC */ { "KAITHI LETTER SHA",NULL},
/* 110AD */ { "KAITHI LETTER SSA",NULL},
/* 110AE */ { "KAITHI LETTER SA",NULL},
/* 110AF */ { "KAITHI LETTER HA",NULL},
/* 110B0 */ { "KAITHI VOWEL SIGN AA",NULL},
/* 110B1 */ { "KAITHI VOWEL SIGN I",NULL},
/* 110B2 */ { "KAITHI VOWEL SIGN II",NULL},
/* 110B3 */ { "KAITHI VOWEL SIGN U",NULL},
/* 110B4 */ { "KAITHI VOWEL SIGN UU",NULL},
/* 110B5 */ { "KAITHI VOWEL SIGN E",NULL},
/* 110B6 */ { "KAITHI VOWEL SIGN AI",NULL},
/* 110B7 */ { "KAITHI VOWEL SIGN O",NULL},
/* 110B8 */ { "KAITHI VOWEL SIGN AU",NULL},
/* 110B9 */ { "KAITHI SIGN VIRAMA",NULL},
/* 110BA */ { "KAITHI SIGN NUKTA",NULL},
/* 110BB */ { "KAITHI ABBREVIATION SIGN",NULL},
/* 110BC */ { "KAITHI ENUMERATION SIGN",NULL},
/* 110BD */ { "KAITHI NUMBER SIGN","	* used to indicate a numerical reference"},
/* 110BE */ { "KAITHI SECTION MARK","	* marks end of sentence\n"
	"	x (khojki section mark - 1123B)"},
/* 110BF */ { "KAITHI DOUBLE SECTION MARK","	* delimits larger chunks of text, such as paragraphs\n"
	"	x (khojki double section mark - 1123C)"},
/* 110C0 */ { "KAITHI DANDA",NULL},
/* 110C1 */ { "KAITHI DOUBLE DANDA",NULL},
/* 110C2 */ { "KAITHI VOWEL SIGN VOCALIC R",NULL},
/* 110C3 */ { NULL,NULL},
/* 110C4 */ { NULL,NULL},
/* 110C5 */ { NULL,NULL},
/* 110C6 */ { NULL,NULL},
/* 110C7 */ { NULL,NULL},
/* 110C8 */ { NULL,NULL},
/* 110C9 */ { NULL,NULL},
/* 110CA */ { NULL,NULL},
/* 110CB */ { NULL,NULL},
/* 110CC */ { NULL,NULL},
/* 110CD */ { "KAITHI NUMBER SIGN ABOVE","	* used to indicate a number in an itemized list"},
/* 110CE */ { NULL,NULL},
/* 110CF */ { NULL,NULL},
/* 110D0 */ { "SORA SOMPENG LETTER SAH",NULL},
/* 110D1 */ { "SORA SOMPENG LETTER TAH",NULL},
/* 110D2 */ { "SORA SOMPENG LETTER BAH",NULL},
/* 110D3 */ { "SORA SOMPENG LETTER CAH",NULL},
/* 110D4 */ { "SORA SOMPENG LETTER DAH",NULL},
/* 110D5 */ { "SORA SOMPENG LETTER GAH",NULL},
/* 110D6 */ { "SORA SOMPENG LETTER MAH",NULL},
/* 110D7 */ { "SORA SOMPENG LETTER NGAH",NULL},
/* 110D8 */ { "SORA SOMPENG LETTER LAH",NULL},
/* 110D9 */ { "SORA SOMPENG LETTER NAH",NULL},
/* 110DA */ { "SORA SOMPENG LETTER VAH",NULL},
/* 110DB */ { "SORA SOMPENG LETTER PAH",NULL},
/* 110DC */ { "SORA SOMPENG LETTER YAH",NULL},
/* 110DD */ { "SORA SOMPENG LETTER RAH",NULL},
/* 110DE */ { "SORA SOMPENG LETTER HAH",NULL},
/* 110DF */ { "SORA SOMPENG LETTER KAH",NULL},
/* 110E0 */ { "SORA SOMPENG LETTER JAH",NULL},
/* 110E1 */ { "SORA SOMPENG LETTER NYAH",NULL},
/* 110E2 */ { "SORA SOMPENG LETTER AH",NULL},
/* 110E3 */ { "SORA SOMPENG LETTER EEH",NULL},
/* 110E4 */ { "SORA SOMPENG LETTER IH",NULL},
/* 110E5 */ { "SORA SOMPENG LETTER UH",NULL},
/* 110E6 */ { "SORA SOMPENG LETTER OH",NULL},
/* 110E7 */ { "SORA SOMPENG LETTER EH",NULL},
/* 110E8 */ { "SORA SOMPENG LETTER MAE",NULL},
/* 110E9 */ { NULL,NULL},
/* 110EA */ { NULL,NULL},
/* 110EB */ { NULL,NULL},
/* 110EC */ { NULL,NULL},
/* 110ED */ { NULL,NULL},
/* 110EE */ { NULL,NULL},
/* 110EF */ { NULL,NULL},
/* 110F0 */ { "SORA SOMPENG DIGIT ZERO",NULL},
/* 110F1 */ { "SORA SOMPENG DIGIT ONE",NULL},
/* 110F2 */ { "SORA SOMPENG DIGIT TWO",NULL},
/* 110F3 */ { "SORA SOMPENG DIGIT THREE",NULL},
/* 110F4 */ { "SORA SOMPENG DIGIT FOUR",NULL},
/* 110F5 */ { "SORA SOMPENG DIGIT FIVE",NULL},
/* 110F6 */ { "SORA SOMPENG DIGIT SIX",NULL},
/* 110F7 */ { "SORA SOMPENG DIGIT SEVEN",NULL},
/* 110F8 */ { "SORA SOMPENG DIGIT EIGHT",NULL},
/* 110F9 */ { "SORA SOMPENG DIGIT NINE",NULL},
/* 110FA */ { NULL,NULL},
/* 110FB */ { NULL,NULL},
/* 110FC */ { NULL,NULL},
/* 110FD */ { NULL,NULL},
/* 110FE */ { NULL,NULL},
/* 110FF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_11[] = {
/* 11100 */ { "CHAKMA SIGN CANDRABINDU",NULL},
/* 11101 */ { "CHAKMA SIGN ANUSVARA",NULL},
/* 11102 */ { "CHAKMA SIGN VISARGA",NULL},
/* 11103 */ { "CHAKMA LETTER AA",NULL},
/* 11104 */ { "CHAKMA LETTER I",NULL},
/* 11105 */ { "CHAKMA LETTER U",NULL},
/* 11106 */ { "CHAKMA LETTER E",NULL},
/* 11107 */ { "CHAKMA LETTER KAA",NULL},
/* 11108 */ { "CHAKMA LETTER KHAA",NULL},
/* 11109 */ { "CHAKMA LETTER GAA",NULL},
/* 1110A */ { "CHAKMA LETTER GHAA",NULL},
/* 1110B */ { "CHAKMA LETTER NGAA",NULL},
/* 1110C */ { "CHAKMA LETTER CAA",NULL},
/* 1110D */ { "CHAKMA LETTER CHAA",NULL},
/* 1110E */ { "CHAKMA LETTER JAA",NULL},
/* 1110F */ { "CHAKMA LETTER JHAA",NULL},
/* 11110 */ { "CHAKMA LETTER NYAA",NULL},
/* 11111 */ { "CHAKMA LETTER TTAA",NULL},
/* 11112 */ { "CHAKMA LETTER TTHAA",NULL},
/* 11113 */ { "CHAKMA LETTER DDAA",NULL},
/* 11114 */ { "CHAKMA LETTER DDHAA",NULL},
/* 11115 */ { "CHAKMA LETTER NNAA",NULL},
/* 11116 */ { "CHAKMA LETTER TAA",NULL},
/* 11117 */ { "CHAKMA LETTER THAA",NULL},
/* 11118 */ { "CHAKMA LETTER DAA",NULL},
/* 11119 */ { "CHAKMA LETTER DHAA",NULL},
/* 1111A */ { "CHAKMA LETTER NAA",NULL},
/* 1111B */ { "CHAKMA LETTER PAA",NULL},
/* 1111C */ { "CHAKMA LETTER PHAA",NULL},
/* 1111D */ { "CHAKMA LETTER BAA",NULL},
/* 1111E */ { "CHAKMA LETTER BHAA",NULL},
/* 1111F */ { "CHAKMA LETTER MAA",NULL},
/* 11120 */ { "CHAKMA LETTER YYAA",NULL},
/* 11121 */ { "CHAKMA LETTER YAA",NULL},
/* 11122 */ { "CHAKMA LETTER RAA",NULL},
/* 11123 */ { "CHAKMA LETTER LAA",NULL},
/* 11124 */ { "CHAKMA LETTER WAA",NULL},
/* 11125 */ { "CHAKMA LETTER SAA",NULL},
/* 11126 */ { "CHAKMA LETTER HAA",NULL},
/* 11127 */ { "CHAKMA VOWEL SIGN A",NULL},
/* 11128 */ { "CHAKMA VOWEL SIGN I",NULL},
/* 11129 */ { "CHAKMA VOWEL SIGN II",NULL},
/* 1112A */ { "CHAKMA VOWEL SIGN U",NULL},
/* 1112B */ { "CHAKMA VOWEL SIGN UU",NULL},
/* 1112C */ { "CHAKMA VOWEL SIGN E",NULL},
/* 1112D */ { "CHAKMA VOWEL SIGN AI",NULL},
/* 1112E */ { "CHAKMA VOWEL SIGN O","	: 11131 11127"},
/* 1112F */ { "CHAKMA VOWEL SIGN AU","	: 11132 11127"},
/* 11130 */ { "CHAKMA VOWEL SIGN OI",NULL},
/* 11131 */ { "CHAKMA O MARK",NULL},
/* 11132 */ { "CHAKMA AU MARK",NULL},
/* 11133 */ { "CHAKMA VIRAMA","	* used to form conjuncts\n"
	"	x (myanmar sign virama - 1039)"},
/* 11134 */ { "CHAKMA MAAYYAA","	* killer\n"
	"	* also used distinctly as a gemination mark which can occur with vowels\n"
	"	x (myanmar sign asat - 103A)"},
/* 11135 */ { NULL,NULL},
/* 11136 */ { "CHAKMA DIGIT ZERO",NULL},
/* 11137 */ { "CHAKMA DIGIT ONE",NULL},
/* 11138 */ { "CHAKMA DIGIT TWO",NULL},
/* 11139 */ { "CHAKMA DIGIT THREE",NULL},
/* 1113A */ { "CHAKMA DIGIT FOUR",NULL},
/* 1113B */ { "CHAKMA DIGIT FIVE",NULL},
/* 1113C */ { "CHAKMA DIGIT SIX",NULL},
/* 1113D */ { "CHAKMA DIGIT SEVEN",NULL},
/* 1113E */ { "CHAKMA DIGIT EIGHT",NULL},
/* 1113F */ { "CHAKMA DIGIT NINE",NULL},
/* 11140 */ { "CHAKMA SECTION MARK",NULL},
/* 11141 */ { "CHAKMA DANDA",NULL},
/* 11142 */ { "CHAKMA DOUBLE DANDA",NULL},
/* 11143 */ { "CHAKMA QUESTION MARK",NULL},
/* 11144 */ { "CHAKMA LETTER LHAA",NULL},
/* 11145 */ { "CHAKMA VOWEL SIGN AA",NULL},
/* 11146 */ { "CHAKMA VOWEL SIGN EI",NULL},
/* 11147 */ { "CHAKMA LETTER VAA","	* used in Pali text"},
/* 11148 */ { NULL,NULL},
/* 11149 */ { NULL,NULL},
/* 1114A */ { NULL,NULL},
/* 1114B */ { NULL,NULL},
/* 1114C */ { NULL,NULL},
/* 1114D */ { NULL,NULL},
/* 1114E */ { NULL,NULL},
/* 1114F */ { NULL,NULL},
/* 11150 */ { "MAHAJANI LETTER A",NULL},
/* 11151 */ { "MAHAJANI LETTER I",NULL},
/* 11152 */ { "MAHAJANI LETTER U",NULL},
/* 11153 */ { "MAHAJANI LETTER E",NULL},
/* 11154 */ { "MAHAJANI LETTER O",NULL},
/* 11155 */ { "MAHAJANI LETTER KA",NULL},
/* 11156 */ { "MAHAJANI LETTER KHA",NULL},
/* 11157 */ { "MAHAJANI LETTER GA",NULL},
/* 11158 */ { "MAHAJANI LETTER GHA",NULL},
/* 11159 */ { "MAHAJANI LETTER CA",NULL},
/* 1115A */ { "MAHAJANI LETTER CHA",NULL},
/* 1115B */ { "MAHAJANI LETTER JA",NULL},
/* 1115C */ { "MAHAJANI LETTER JHA",NULL},
/* 1115D */ { "MAHAJANI LETTER NYA",NULL},
/* 1115E */ { "MAHAJANI LETTER TTA",NULL},
/* 1115F */ { "MAHAJANI LETTER TTHA",NULL},
/* 11160 */ { "MAHAJANI LETTER DDA",NULL},
/* 11161 */ { "MAHAJANI LETTER DDHA",NULL},
/* 11162 */ { "MAHAJANI LETTER NNA",NULL},
/* 11163 */ { "MAHAJANI LETTER TA",NULL},
/* 11164 */ { "MAHAJANI LETTER THA",NULL},
/* 11165 */ { "MAHAJANI LETTER DA",NULL},
/* 11166 */ { "MAHAJANI LETTER DHA",NULL},
/* 11167 */ { "MAHAJANI LETTER NA",NULL},
/* 11168 */ { "MAHAJANI LETTER PA",NULL},
/* 11169 */ { "MAHAJANI LETTER PHA",NULL},
/* 1116A */ { "MAHAJANI LETTER BA",NULL},
/* 1116B */ { "MAHAJANI LETTER BHA",NULL},
/* 1116C */ { "MAHAJANI LETTER MA",NULL},
/* 1116D */ { "MAHAJANI LETTER RA",NULL},
/* 1116E */ { "MAHAJANI LETTER LA",NULL},
/* 1116F */ { "MAHAJANI LETTER VA",NULL},
/* 11170 */ { "MAHAJANI LETTER SA",NULL},
/* 11171 */ { "MAHAJANI LETTER HA",NULL},
/* 11172 */ { "MAHAJANI LETTER RRA",NULL},
/* 11173 */ { "MAHAJANI SIGN NUKTA",NULL},
/* 11174 */ { "MAHAJANI ABBREVIATION SIGN",NULL},
/* 11175 */ { "MAHAJANI SECTION MARK",NULL},
/* 11176 */ { "MAHAJANI LIGATURE SHRI",NULL},
/* 11177 */ { NULL,NULL},
/* 11178 */ { NULL,NULL},
/* 11179 */ { NULL,NULL},
/* 1117A */ { NULL,NULL},
/* 1117B */ { NULL,NULL},
/* 1117C */ { NULL,NULL},
/* 1117D */ { NULL,NULL},
/* 1117E */ { NULL,NULL},
/* 1117F */ { NULL,NULL},
/* 11180 */ { "SHARADA SIGN CANDRABINDU",NULL},
/* 11181 */ { "SHARADA SIGN ANUSVARA",NULL},
/* 11182 */ { "SHARADA SIGN VISARGA",NULL},
/* 11183 */ { "SHARADA LETTER A",NULL},
/* 11184 */ { "SHARADA LETTER AA",NULL},
/* 11185 */ { "SHARADA LETTER I",NULL},
/* 11186 */ { "SHARADA LETTER II",NULL},
/* 11187 */ { "SHARADA LETTER U",NULL},
/* 11188 */ { "SHARADA LETTER UU",NULL},
/* 11189 */ { "SHARADA LETTER VOCALIC R",NULL},
/* 1118A */ { "SHARADA LETTER VOCALIC RR",NULL},
/* 1118B */ { "SHARADA LETTER VOCALIC L",NULL},
/* 1118C */ { "SHARADA LETTER VOCALIC LL",NULL},
/* 1118D */ { "SHARADA LETTER E",NULL},
/* 1118E */ { "SHARADA LETTER AI",NULL},
/* 1118F */ { "SHARADA LETTER O",NULL},
/* 11190 */ { "SHARADA LETTER AU",NULL},
/* 11191 */ { "SHARADA LETTER KA",NULL},
/* 11192 */ { "SHARADA LETTER KHA",NULL},
/* 11193 */ { "SHARADA LETTER GA",NULL},
/* 11194 */ { "SHARADA LETTER GHA",NULL},
/* 11195 */ { "SHARADA LETTER NGA",NULL},
/* 11196 */ { "SHARADA LETTER CA",NULL},
/* 11197 */ { "SHARADA LETTER CHA",NULL},
/* 11198 */ { "SHARADA LETTER JA",NULL},
/* 11199 */ { "SHARADA LETTER JHA",NULL},
/* 1119A */ { "SHARADA LETTER NYA",NULL},
/* 1119B */ { "SHARADA LETTER TTA",NULL},
/* 1119C */ { "SHARADA LETTER TTHA",NULL},
/* 1119D */ { "SHARADA LETTER DDA",NULL},
/* 1119E */ { "SHARADA LETTER DDHA",NULL},
/* 1119F */ { "SHARADA LETTER NNA",NULL},
/* 111A0 */ { "SHARADA LETTER TA",NULL},
/* 111A1 */ { "SHARADA LETTER THA",NULL},
/* 111A2 */ { "SHARADA LETTER DA",NULL},
/* 111A3 */ { "SHARADA LETTER DHA",NULL},
/* 111A4 */ { "SHARADA LETTER NA",NULL},
/* 111A5 */ { "SHARADA LETTER PA",NULL},
/* 111A6 */ { "SHARADA LETTER PHA",NULL},
/* 111A7 */ { "SHARADA LETTER BA",NULL},
/* 111A8 */ { "SHARADA LETTER BHA",NULL},
/* 111A9 */ { "SHARADA LETTER MA",NULL},
/* 111AA */ { "SHARADA LETTER YA",NULL},
/* 111AB */ { "SHARADA LETTER RA",NULL},
/* 111AC */ { "SHARADA LETTER LA",NULL},
/* 111AD */ { "SHARADA LETTER LLA",NULL},
/* 111AE */ { "SHARADA LETTER VA",NULL},
/* 111AF */ { "SHARADA LETTER SHA",NULL},
/* 111B0 */ { "SHARADA LETTER SSA",NULL},
/* 111B1 */ { "SHARADA LETTER SA",NULL},
/* 111B2 */ { "SHARADA LETTER HA",NULL},
/* 111B3 */ { "SHARADA VOWEL SIGN AA",NULL},
/* 111B4 */ { "SHARADA VOWEL SIGN I",NULL},
/* 111B5 */ { "SHARADA VOWEL SIGN II",NULL},
/* 111B6 */ { "SHARADA VOWEL SIGN U",NULL},
/* 111B7 */ { "SHARADA VOWEL SIGN UU",NULL},
/* 111B8 */ { "SHARADA VOWEL SIGN VOCALIC R",NULL},
/* 111B9 */ { "SHARADA VOWEL SIGN VOCALIC RR",NULL},
/* 111BA */ { "SHARADA VOWEL SIGN VOCALIC L",NULL},
/* 111BB */ { "SHARADA VOWEL SIGN VOCALIC LL",NULL},
/* 111BC */ { "SHARADA VOWEL SIGN E",NULL},
/* 111BD */ { "SHARADA VOWEL SIGN AI",NULL},
/* 111BE */ { "SHARADA VOWEL SIGN O",NULL},
/* 111BF */ { "SHARADA VOWEL SIGN AU",NULL},
/* 111C0 */ { "SHARADA SIGN VIRAMA",NULL},
/* 111C1 */ { "SHARADA SIGN AVAGRAHA",NULL},
/* 111C2 */ { "SHARADA SIGN JIHVAMULIYA",NULL},
/* 111C3 */ { "SHARADA SIGN UPADHMANIYA",NULL},
/* 111C4 */ { "SHARADA OM","	* use of this character is discouraged\n"
	"	* recommended sequence is 1118F 11180"},
/* 111C5 */ { "SHARADA DANDA",NULL},
/* 111C6 */ { "SHARADA DOUBLE DANDA",NULL},
/* 111C7 */ { "SHARADA ABBREVIATION SIGN",NULL},
/* 111C8 */ { "SHARADA SEPARATOR",NULL},
/* 111C9 */ { "SHARADA SANDHI MARK","	* indicates external sandhi in Sanskrit documents\n"
	"	x (bengali sandhi mark - 09FE)"},
/* 111CA */ { "SHARADA SIGN NUKTA","	* for extending the alphabet to new letters"},
/* 111CB */ { "SHARADA VOWEL MODIFIER MARK","	* represents regressive metaphony"},
/* 111CC */ { "SHARADA EXTRA SHORT VOWEL MARK","	* used for writing \"matra-vowels\""},
/* 111CD */ { "SHARADA SUTRA MARK","	* used for indicating the end of a sutra in the Bakhshali manuscript"},
/* 111CE */ { "SHARADA VOWEL SIGN PRISHTHAMATRA E","	x (devanagari vowel sign prishthamatra e - 094E)"},
/* 111CF */ { "SHARADA SIGN INVERTED CANDRABINDU",NULL},
/* 111D0 */ { "SHARADA DIGIT ZERO",NULL},
/* 111D1 */ { "SHARADA DIGIT ONE",NULL},
/* 111D2 */ { "SHARADA DIGIT TWO",NULL},
/* 111D3 */ { "SHARADA DIGIT THREE",NULL},
/* 111D4 */ { "SHARADA DIGIT FOUR",NULL},
/* 111D5 */ { "SHARADA DIGIT FIVE",NULL},
/* 111D6 */ { "SHARADA DIGIT SIX",NULL},
/* 111D7 */ { "SHARADA DIGIT SEVEN",NULL},
/* 111D8 */ { "SHARADA DIGIT EIGHT",NULL},
/* 111D9 */ { "SHARADA DIGIT NINE",NULL},
/* 111DA */ { "SHARADA EKAM","	* invocation symbol used at the beginning or end of texts"},
/* 111DB */ { "SHARADA SIGN SIDDHAM","	= siddhirastu\n"
	"	* used at the beginning of texts as an invocation\n"
	"	x (kannada sign siddham - 0C84)\n"
	"	x (devanagari sign siddham - A8FC)"},
/* 111DC */ { "SHARADA HEADSTROKE","	* used for joining words across imperfections\n"
	"	x (devanagari headstroke - A8FB)"},
/* 111DD */ { "SHARADA CONTINUATION SIGN","	* indicates a breaking opportunity within a word"},
/* 111DE */ { "SHARADA SECTION MARK-1",NULL},
/* 111DF */ { "SHARADA SECTION MARK-2",NULL},
/* 111E0 */ { NULL,NULL},
/* 111E1 */ { "SINHALA ARCHAIC DIGIT ONE",NULL},
/* 111E2 */ { "SINHALA ARCHAIC DIGIT TWO",NULL},
/* 111E3 */ { "SINHALA ARCHAIC DIGIT THREE",NULL},
/* 111E4 */ { "SINHALA ARCHAIC DIGIT FOUR",NULL},
/* 111E5 */ { "SINHALA ARCHAIC DIGIT FIVE",NULL},
/* 111E6 */ { "SINHALA ARCHAIC DIGIT SIX",NULL},
/* 111E7 */ { "SINHALA ARCHAIC DIGIT SEVEN",NULL},
/* 111E8 */ { "SINHALA ARCHAIC DIGIT EIGHT",NULL},
/* 111E9 */ { "SINHALA ARCHAIC DIGIT NINE",NULL},
/* 111EA */ { "SINHALA ARCHAIC NUMBER TEN",NULL},
/* 111EB */ { "SINHALA ARCHAIC NUMBER TWENTY",NULL},
/* 111EC */ { "SINHALA ARCHAIC NUMBER THIRTY",NULL},
/* 111ED */ { "SINHALA ARCHAIC NUMBER FORTY",NULL},
/* 111EE */ { "SINHALA ARCHAIC NUMBER FIFTY",NULL},
/* 111EF */ { "SINHALA ARCHAIC NUMBER SIXTY",NULL},
/* 111F0 */ { "SINHALA ARCHAIC NUMBER SEVENTY",NULL},
/* 111F1 */ { "SINHALA ARCHAIC NUMBER EIGHTY",NULL},
/* 111F2 */ { "SINHALA ARCHAIC NUMBER NINETY",NULL},
/* 111F3 */ { "SINHALA ARCHAIC NUMBER ONE HUNDRED",NULL},
/* 111F4 */ { "SINHALA ARCHAIC NUMBER ONE THOUSAND",NULL},
/* 111F5 */ { NULL,NULL},
/* 111F6 */ { NULL,NULL},
/* 111F7 */ { NULL,NULL},
/* 111F8 */ { NULL,NULL},
/* 111F9 */ { NULL,NULL},
/* 111FA */ { NULL,NULL},
/* 111FB */ { NULL,NULL},
/* 111FC */ { NULL,NULL},
/* 111FD */ { NULL,NULL},
/* 111FE */ { NULL,NULL},
/* 111FF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_12[] = {
/* 11200 */ { "KHOJKI LETTER A",NULL},
/* 11201 */ { "KHOJKI LETTER AA",NULL},
/* 11202 */ { "KHOJKI LETTER I",NULL},
/* 11203 */ { "KHOJKI LETTER U",NULL},
/* 11204 */ { "KHOJKI LETTER E",NULL},
/* 11205 */ { "KHOJKI LETTER AI",NULL},
/* 11206 */ { "KHOJKI LETTER O",NULL},
/* 11207 */ { "KHOJKI LETTER AU",NULL},
/* 11208 */ { "KHOJKI LETTER KA",NULL},
/* 11209 */ { "KHOJKI LETTER KHA",NULL},
/* 1120A */ { "KHOJKI LETTER GA",NULL},
/* 1120B */ { "KHOJKI LETTER GGA",NULL},
/* 1120C */ { "KHOJKI LETTER GHA",NULL},
/* 1120D */ { "KHOJKI LETTER NGA",NULL},
/* 1120E */ { "KHOJKI LETTER CA",NULL},
/* 1120F */ { "KHOJKI LETTER CHA",NULL},
/* 11210 */ { "KHOJKI LETTER JA",NULL},
/* 11211 */ { "KHOJKI LETTER JJA",NULL},
/* 11212 */ { NULL,NULL},
/* 11213 */ { "KHOJKI LETTER NYA",NULL},
/* 11214 */ { "KHOJKI LETTER TTA",NULL},
/* 11215 */ { "KHOJKI LETTER TTHA",NULL},
/* 11216 */ { "KHOJKI LETTER DDA",NULL},
/* 11217 */ { "KHOJKI LETTER DDHA",NULL},
/* 11218 */ { "KHOJKI LETTER NNA",NULL},
/* 11219 */ { "KHOJKI LETTER TA",NULL},
/* 1121A */ { "KHOJKI LETTER THA",NULL},
/* 1121B */ { "KHOJKI LETTER DA",NULL},
/* 1121C */ { "KHOJKI LETTER DDDA",NULL},
/* 1121D */ { "KHOJKI LETTER DHA",NULL},
/* 1121E */ { "KHOJKI LETTER NA",NULL},
/* 1121F */ { "KHOJKI LETTER PA",NULL},
/* 11220 */ { "KHOJKI LETTER PHA",NULL},
/* 11221 */ { "KHOJKI LETTER BA",NULL},
/* 11222 */ { "KHOJKI LETTER BBA",NULL},
/* 11223 */ { "KHOJKI LETTER BHA",NULL},
/* 11224 */ { "KHOJKI LETTER MA",NULL},
/* 11225 */ { "KHOJKI LETTER YA",NULL},
/* 11226 */ { "KHOJKI LETTER RA",NULL},
/* 11227 */ { "KHOJKI LETTER LA",NULL},
/* 11228 */ { "KHOJKI LETTER VA",NULL},
/* 11229 */ { "KHOJKI LETTER SA",NULL},
/* 1122A */ { "KHOJKI LETTER HA",NULL},
/* 1122B */ { "KHOJKI LETTER LLA",NULL},
/* 1122C */ { "KHOJKI VOWEL SIGN AA",NULL},
/* 1122D */ { "KHOJKI VOWEL SIGN I",NULL},
/* 1122E */ { "KHOJKI VOWEL SIGN II",NULL},
/* 1122F */ { "KHOJKI VOWEL SIGN U",NULL},
/* 11230 */ { "KHOJKI VOWEL SIGN E",NULL},
/* 11231 */ { "KHOJKI VOWEL SIGN AI",NULL},
/* 11232 */ { "KHOJKI VOWEL SIGN O",NULL},
/* 11233 */ { "KHOJKI VOWEL SIGN AU",NULL},
/* 11234 */ { "KHOJKI SIGN ANUSVARA",NULL},
/* 11235 */ { "KHOJKI SIGN VIRAMA",NULL},
/* 11236 */ { "KHOJKI SIGN NUKTA",NULL},
/* 11237 */ { "KHOJKI SIGN SHADDA",NULL},
/* 11238 */ { "KHOJKI DANDA",NULL},
/* 11239 */ { "KHOJKI DOUBLE DANDA",NULL},
/* 1123A */ { "KHOJKI WORD SEPARATOR",NULL},
/* 1123B */ { "KHOJKI SECTION MARK","	* marks end of sentence\n"
	"	x (kaithi section mark - 110BE)"},
/* 1123C */ { "KHOJKI DOUBLE SECTION MARK","	* delimits larger chunks of text, such as paragraphs\n"
	"	x (kaithi double section mark - 110BF)"},
/* 1123D */ { "KHOJKI ABBREVIATION SIGN",NULL},
/* 1123E */ { "KHOJKI SIGN SUKUN","	* used for Arabic transliteration"},
/* 1123F */ { "KHOJKI LETTER QA",NULL},
/* 11240 */ { "KHOJKI LETTER SHORT I",NULL},
/* 11241 */ { "KHOJKI VOWEL SIGN VOCALIC R",NULL},
/* 11242 */ { NULL,NULL},
/* 11243 */ { NULL,NULL},
/* 11244 */ { NULL,NULL},
/* 11245 */ { NULL,NULL},
/* 11246 */ { NULL,NULL},
/* 11247 */ { NULL,NULL},
/* 11248 */ { NULL,NULL},
/* 11249 */ { NULL,NULL},
/* 1124A */ { NULL,NULL},
/* 1124B */ { NULL,NULL},
/* 1124C */ { NULL,NULL},
/* 1124D */ { NULL,NULL},
/* 1124E */ { NULL,NULL},
/* 1124F */ { NULL,NULL},
/* 11250 */ { NULL,NULL},
/* 11251 */ { NULL,NULL},
/* 11252 */ { NULL,NULL},
/* 11253 */ { NULL,NULL},
/* 11254 */ { NULL,NULL},
/* 11255 */ { NULL,NULL},
/* 11256 */ { NULL,NULL},
/* 11257 */ { NULL,NULL},
/* 11258 */ { NULL,NULL},
/* 11259 */ { NULL,NULL},
/* 1125A */ { NULL,NULL},
/* 1125B */ { NULL,NULL},
/* 1125C */ { NULL,NULL},
/* 1125D */ { NULL,NULL},
/* 1125E */ { NULL,NULL},
/* 1125F */ { NULL,NULL},
/* 11260 */ { NULL,NULL},
/* 11261 */ { NULL,NULL},
/* 11262 */ { NULL,NULL},
/* 11263 */ { NULL,NULL},
/* 11264 */ { NULL,NULL},
/* 11265 */ { NULL,NULL},
/* 11266 */ { NULL,NULL},
/* 11267 */ { NULL,NULL},
/* 11268 */ { NULL,NULL},
/* 11269 */ { NULL,NULL},
/* 1126A */ { NULL,NULL},
/* 1126B */ { NULL,NULL},
/* 1126C */ { NULL,NULL},
/* 1126D */ { NULL,NULL},
/* 1126E */ { NULL,NULL},
/* 1126F */ { NULL,NULL},
/* 11270 */ { NULL,NULL},
/* 11271 */ { NULL,NULL},
/* 11272 */ { NULL,NULL},
/* 11273 */ { NULL,NULL},
/* 11274 */ { NULL,NULL},
/* 11275 */ { NULL,NULL},
/* 11276 */ { NULL,NULL},
/* 11277 */ { NULL,NULL},
/* 11278 */ { NULL,NULL},
/* 11279 */ { NULL,NULL},
/* 1127A */ { NULL,NULL},
/* 1127B */ { NULL,NULL},
/* 1127C */ { NULL,NULL},
/* 1127D */ { NULL,NULL},
/* 1127E */ { NULL,NULL},
/* 1127F */ { NULL,NULL},
/* 11280 */ { "MULTANI LETTER A",NULL},
/* 11281 */ { "MULTANI LETTER I",NULL},
/* 11282 */ { "MULTANI LETTER U",NULL},
/* 11283 */ { "MULTANI LETTER E",NULL},
/* 11284 */ { "MULTANI LETTER KA",NULL},
/* 11285 */ { "MULTANI LETTER KHA",NULL},
/* 11286 */ { "MULTANI LETTER GA",NULL},
/* 11287 */ { NULL,NULL},
/* 11288 */ { "MULTANI LETTER GHA",NULL},
/* 11289 */ { NULL,NULL},
/* 1128A */ { "MULTANI LETTER CA",NULL},
/* 1128B */ { "MULTANI LETTER CHA",NULL},
/* 1128C */ { "MULTANI LETTER JA",NULL},
/* 1128D */ { "MULTANI LETTER JJA",NULL},
/* 1128E */ { NULL,NULL},
/* 1128F */ { "MULTANI LETTER NYA",NULL},
/* 11290 */ { "MULTANI LETTER TTA",NULL},
/* 11291 */ { "MULTANI LETTER TTHA",NULL},
/* 11292 */ { "MULTANI LETTER DDA",NULL},
/* 11293 */ { "MULTANI LETTER DDDA","	= tra"},
/* 11294 */ { "MULTANI LETTER DDHA",NULL},
/* 11295 */ { "MULTANI LETTER NNA",NULL},
/* 11296 */ { "MULTANI LETTER TA",NULL},
/* 11297 */ { "MULTANI LETTER THA",NULL},
/* 11298 */ { "MULTANI LETTER DA",NULL},
/* 11299 */ { "MULTANI LETTER DHA",NULL},
/* 1129A */ { "MULTANI LETTER NA",NULL},
/* 1129B */ { "MULTANI LETTER PA",NULL},
/* 1129C */ { "MULTANI LETTER PHA",NULL},
/* 1129D */ { "MULTANI LETTER BA",NULL},
/* 1129E */ { NULL,NULL},
/* 1129F */ { "MULTANI LETTER BHA",NULL},
/* 112A0 */ { "MULTANI LETTER MA",NULL},
/* 112A1 */ { "MULTANI LETTER YA",NULL},
/* 112A2 */ { "MULTANI LETTER RA",NULL},
/* 112A3 */ { "MULTANI LETTER LA",NULL},
/* 112A4 */ { "MULTANI LETTER VA",NULL},
/* 112A5 */ { "MULTANI LETTER SA",NULL},
/* 112A6 */ { "MULTANI LETTER HA",NULL},
/* 112A7 */ { "MULTANI LETTER RRA",NULL},
/* 112A8 */ { "MULTANI LETTER RHA",NULL},
/* 112A9 */ { "MULTANI SECTION MARK",NULL},
/* 112AA */ { NULL,NULL},
/* 112AB */ { NULL,NULL},
/* 112AC */ { NULL,NULL},
/* 112AD */ { NULL,NULL},
/* 112AE */ { NULL,NULL},
/* 112AF */ { NULL,NULL},
/* 112B0 */ { "KHUDAWADI LETTER A",NULL},
/* 112B1 */ { "KHUDAWADI LETTER AA",NULL},
/* 112B2 */ { "KHUDAWADI LETTER I",NULL},
/* 112B3 */ { "KHUDAWADI LETTER II",NULL},
/* 112B4 */ { "KHUDAWADI LETTER U",NULL},
/* 112B5 */ { "KHUDAWADI LETTER UU",NULL},
/* 112B6 */ { "KHUDAWADI LETTER E",NULL},
/* 112B7 */ { "KHUDAWADI LETTER AI",NULL},
/* 112B8 */ { "KHUDAWADI LETTER O",NULL},
/* 112B9 */ { "KHUDAWADI LETTER AU",NULL},
/* 112BA */ { "KHUDAWADI LETTER KA",NULL},
/* 112BB */ { "KHUDAWADI LETTER KHA",NULL},
/* 112BC */ { "KHUDAWADI LETTER GA",NULL},
/* 112BD */ { "KHUDAWADI LETTER GGA",NULL},
/* 112BE */ { "KHUDAWADI LETTER GHA",NULL},
/* 112BF */ { "KHUDAWADI LETTER NGA",NULL},
/* 112C0 */ { "KHUDAWADI LETTER CA",NULL},
/* 112C1 */ { "KHUDAWADI LETTER CHA",NULL},
/* 112C2 */ { "KHUDAWADI LETTER JA",NULL},
/* 112C3 */ { "KHUDAWADI LETTER JJA",NULL},
/* 112C4 */ { "KHUDAWADI LETTER JHA",NULL},
/* 112C5 */ { "KHUDAWADI LETTER NYA",NULL},
/* 112C6 */ { "KHUDAWADI LETTER TTA",NULL},
/* 112C7 */ { "KHUDAWADI LETTER TTHA",NULL},
/* 112C8 */ { "KHUDAWADI LETTER DDA",NULL},
/* 112C9 */ { "KHUDAWADI LETTER DDDA",NULL},
/* 112CA */ { "KHUDAWADI LETTER RRA",NULL},
/* 112CB */ { "KHUDAWADI LETTER DDHA",NULL},
/* 112CC */ { "KHUDAWADI LETTER NNA",NULL},
/* 112CD */ { "KHUDAWADI LETTER TA",NULL},
/* 112CE */ { "KHUDAWADI LETTER THA",NULL},
/* 112CF */ { "KHUDAWADI LETTER DA",NULL},
/* 112D0 */ { "KHUDAWADI LETTER DHA",NULL},
/* 112D1 */ { "KHUDAWADI LETTER NA",NULL},
/* 112D2 */ { "KHUDAWADI LETTER PA",NULL},
/* 112D3 */ { "KHUDAWADI LETTER PHA",NULL},
/* 112D4 */ { "KHUDAWADI LETTER BA",NULL},
/* 112D5 */ { "KHUDAWADI LETTER BBA",NULL},
/* 112D6 */ { "KHUDAWADI LETTER BHA",NULL},
/* 112D7 */ { "KHUDAWADI LETTER MA",NULL},
/* 112D8 */ { "KHUDAWADI LETTER YA",NULL},
/* 112D9 */ { "KHUDAWADI LETTER RA",NULL},
/* 112DA */ { "KHUDAWADI LETTER LA",NULL},
/* 112DB */ { "KHUDAWADI LETTER VA",NULL},
/* 112DC */ { "KHUDAWADI LETTER SHA",NULL},
/* 112DD */ { "KHUDAWADI LETTER SA",NULL},
/* 112DE */ { "KHUDAWADI LETTER HA",NULL},
/* 112DF */ { "KHUDAWADI SIGN ANUSVARA",NULL},
/* 112E0 */ { "KHUDAWADI VOWEL SIGN AA",NULL},
/* 112E1 */ { "KHUDAWADI VOWEL SIGN I",NULL},
/* 112E2 */ { "KHUDAWADI VOWEL SIGN II",NULL},
/* 112E3 */ { "KHUDAWADI VOWEL SIGN U",NULL},
/* 112E4 */ { "KHUDAWADI VOWEL SIGN UU",NULL},
/* 112E5 */ { "KHUDAWADI VOWEL SIGN E",NULL},
/* 112E6 */ { "KHUDAWADI VOWEL SIGN AI",NULL},
/* 112E7 */ { "KHUDAWADI VOWEL SIGN O",NULL},
/* 112E8 */ { "KHUDAWADI VOWEL SIGN AU",NULL},
/* 112E9 */ { "KHUDAWADI SIGN NUKTA",NULL},
/* 112EA */ { "KHUDAWADI SIGN VIRAMA",NULL},
/* 112EB */ { NULL,NULL},
/* 112EC */ { NULL,NULL},
/* 112ED */ { NULL,NULL},
/* 112EE */ { NULL,NULL},
/* 112EF */ { NULL,NULL},
/* 112F0 */ { "KHUDAWADI DIGIT ZERO",NULL},
/* 112F1 */ { "KHUDAWADI DIGIT ONE",NULL},
/* 112F2 */ { "KHUDAWADI DIGIT TWO",NULL},
/* 112F3 */ { "KHUDAWADI DIGIT THREE",NULL},
/* 112F4 */ { "KHUDAWADI DIGIT FOUR",NULL},
/* 112F5 */ { "KHUDAWADI DIGIT FIVE",NULL},
/* 112F6 */ { "KHUDAWADI DIGIT SIX",NULL},
/* 112F7 */ { "KHUDAWADI DIGIT SEVEN",NULL},
/* 112F8 */ { "KHUDAWADI DIGIT EIGHT",NULL},
/* 112F9 */ { "KHUDAWADI DIGIT NINE",NULL},
/* 112FA */ { NULL,NULL},
/* 112FB */ { NULL,NULL},
/* 112FC */ { NULL,NULL},
/* 112FD */ { NULL,NULL},
/* 112FE */ { NULL,NULL},
/* 112FF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_13[] = {
/* 11300 */ { "GRANTHA SIGN COMBINING ANUSVARA ABOVE","	* used in Prakrit language Jain texts for the linguistic anusvara"},
/* 11301 */ { "GRANTHA SIGN CANDRABINDU",NULL},
/* 11302 */ { "GRANTHA SIGN ANUSVARA","	* used in Prakrit language Jain texts to indicate gemination of the following consonant"},
/* 11303 */ { "GRANTHA SIGN VISARGA",NULL},
/* 11304 */ { NULL,NULL},
/* 11305 */ { "GRANTHA LETTER A",NULL},
/* 11306 */ { "GRANTHA LETTER AA",NULL},
/* 11307 */ { "GRANTHA LETTER I",NULL},
/* 11308 */ { "GRANTHA LETTER II",NULL},
/* 11309 */ { "GRANTHA LETTER U",NULL},
/* 1130A */ { "GRANTHA LETTER UU",NULL},
/* 1130B */ { "GRANTHA LETTER VOCALIC R",NULL},
/* 1130C */ { "GRANTHA LETTER VOCALIC L",NULL},
/* 1130D */ { NULL,NULL},
/* 1130E */ { NULL,NULL},
/* 1130F */ { "GRANTHA LETTER EE",NULL},
/* 11310 */ { "GRANTHA LETTER AI",NULL},
/* 11311 */ { NULL,NULL},
/* 11312 */ { NULL,NULL},
/* 11313 */ { "GRANTHA LETTER OO",NULL},
/* 11314 */ { "GRANTHA LETTER AU",NULL},
/* 11315 */ { "GRANTHA LETTER KA",NULL},
/* 11316 */ { "GRANTHA LETTER KHA",NULL},
/* 11317 */ { "GRANTHA LETTER GA",NULL},
/* 11318 */ { "GRANTHA LETTER GHA",NULL},
/* 11319 */ { "GRANTHA LETTER NGA",NULL},
/* 1131A */ { "GRANTHA LETTER CA",NULL},
/* 1131B */ { "GRANTHA LETTER CHA",NULL},
/* 1131C */ { "GRANTHA LETTER JA",NULL},
/* 1131D */ { "GRANTHA LETTER JHA",NULL},
/* 1131E */ { "GRANTHA LETTER NYA",NULL},
/* 1131F */ { "GRANTHA LETTER TTA",NULL},
/* 11320 */ { "GRANTHA LETTER TTHA",NULL},
/* 11321 */ { "GRANTHA LETTER DDA",NULL},
/* 11322 */ { "GRANTHA LETTER DDHA",NULL},
/* 11323 */ { "GRANTHA LETTER NNA",NULL},
/* 11324 */ { "GRANTHA LETTER TA",NULL},
/* 11325 */ { "GRANTHA LETTER THA",NULL},
/* 11326 */ { "GRANTHA LETTER DA",NULL},
/* 11327 */ { "GRANTHA LETTER DHA",NULL},
/* 11328 */ { "GRANTHA LETTER NA",NULL},
/* 11329 */ { NULL,NULL},
/* 1132A */ { "GRANTHA LETTER PA",NULL},
/* 1132B */ { "GRANTHA LETTER PHA",NULL},
/* 1132C */ { "GRANTHA LETTER BA",NULL},
/* 1132D */ { "GRANTHA LETTER BHA",NULL},
/* 1132E */ { "GRANTHA LETTER MA",NULL},
/* 1132F */ { "GRANTHA LETTER YA",NULL},
/* 11330 */ { "GRANTHA LETTER RA",NULL},
/* 11331 */ { NULL,NULL},
/* 11332 */ { "GRANTHA LETTER LA",NULL},
/* 11333 */ { "GRANTHA LETTER LLA",NULL},
/* 11334 */ { NULL,NULL},
/* 11335 */ { "GRANTHA LETTER VA",NULL},
/* 11336 */ { "GRANTHA LETTER SHA",NULL},
/* 11337 */ { "GRANTHA LETTER SSA",NULL},
/* 11338 */ { "GRANTHA LETTER SA",NULL},
/* 11339 */ { "GRANTHA LETTER HA",NULL},
/* 1133A */ { NULL,NULL},
/* 1133B */ { "COMBINING BINDU BELOW","	= vindu\n"
	"	* used as nukta for Betta Kurumba and other languages"},
/* 1133C */ { "GRANTHA SIGN NUKTA",NULL},
/* 1133D */ { "GRANTHA SIGN AVAGRAHA",NULL},
/* 1133E */ { "GRANTHA VOWEL SIGN AA",NULL},
/* 1133F */ { "GRANTHA VOWEL SIGN I",NULL},
/* 11340 */ { "GRANTHA VOWEL SIGN II",NULL},
/* 11341 */ { "GRANTHA VOWEL SIGN U",NULL},
/* 11342 */ { "GRANTHA VOWEL SIGN UU",NULL},
/* 11343 */ { "GRANTHA VOWEL SIGN VOCALIC R",NULL},
/* 11344 */ { "GRANTHA VOWEL SIGN VOCALIC RR",NULL},
/* 11345 */ { NULL,NULL},
/* 11346 */ { NULL,NULL},
/* 11347 */ { "GRANTHA VOWEL SIGN EE",NULL},
/* 11348 */ { "GRANTHA VOWEL SIGN AI",NULL},
/* 11349 */ { NULL,NULL},
/* 1134A */ { NULL,NULL},
/* 1134B */ { "GRANTHA VOWEL SIGN OO","	: 11347 1133E"},
/* 1134C */ { "GRANTHA VOWEL SIGN AU","	: 11347 11357"},
/* 1134D */ { "GRANTHA SIGN VIRAMA",NULL},
/* 1134E */ { NULL,NULL},
/* 1134F */ { NULL,NULL},
/* 11350 */ { "GRANTHA OM",NULL},
/* 11351 */ { NULL,NULL},
/* 11352 */ { NULL,NULL},
/* 11353 */ { NULL,NULL},
/* 11354 */ { NULL,NULL},
/* 11355 */ { NULL,NULL},
/* 11356 */ { NULL,NULL},
/* 11357 */ { "GRANTHA AU LENGTH MARK",NULL},
/* 11358 */ { NULL,NULL},
/* 11359 */ { NULL,NULL},
/* 1135A */ { NULL,NULL},
/* 1135B */ { NULL,NULL},
/* 1135C */ { NULL,NULL},
/* 1135D */ { "GRANTHA SIGN PLUTA","	* vowel-lengthening mark"},
/* 1135E */ { "GRANTHA LETTER VEDIC ANUSVARA",NULL},
/* 1135F */ { "GRANTHA LETTER VEDIC DOUBLE ANUSVARA",NULL},
/* 11360 */ { "GRANTHA LETTER VOCALIC RR",NULL},
/* 11361 */ { "GRANTHA LETTER VOCALIC LL",NULL},
/* 11362 */ { "GRANTHA VOWEL SIGN VOCALIC L",NULL},
/* 11363 */ { "GRANTHA VOWEL SIGN VOCALIC LL",NULL},
/* 11364 */ { NULL,NULL},
/* 11365 */ { NULL,NULL},
/* 11366 */ { "COMBINING GRANTHA DIGIT ZERO",NULL},
/* 11367 */ { "COMBINING GRANTHA DIGIT ONE",NULL},
/* 11368 */ { "COMBINING GRANTHA DIGIT TWO",NULL},
/* 11369 */ { "COMBINING GRANTHA DIGIT THREE",NULL},
/* 1136A */ { "COMBINING GRANTHA DIGIT FOUR",NULL},
/* 1136B */ { "COMBINING GRANTHA DIGIT FIVE",NULL},
/* 1136C */ { "COMBINING GRANTHA DIGIT SIX",NULL},
/* 1136D */ { NULL,NULL},
/* 1136E */ { NULL,NULL},
/* 1136F */ { NULL,NULL},
/* 11370 */ { "COMBINING GRANTHA LETTER A",NULL},
/* 11371 */ { "COMBINING GRANTHA LETTER KA",NULL},
/* 11372 */ { "COMBINING GRANTHA LETTER NA",NULL},
/* 11373 */ { "COMBINING GRANTHA LETTER VI",NULL},
/* 11374 */ { "COMBINING GRANTHA LETTER PA",NULL},
/* 11375 */ { NULL,NULL},
/* 11376 */ { NULL,NULL},
/* 11377 */ { NULL,NULL},
/* 11378 */ { NULL,NULL},
/* 11379 */ { NULL,NULL},
/* 1137A */ { NULL,NULL},
/* 1137B */ { NULL,NULL},
/* 1137C */ { NULL,NULL},
/* 1137D */ { NULL,NULL},
/* 1137E */ { NULL,NULL},
/* 1137F */ { NULL,NULL},
/* 11380 */ { "TULU-TIGALARI LETTER A",NULL},
/* 11381 */ { "TULU-TIGALARI LETTER AA",NULL},
/* 11382 */ { "TULU-TIGALARI LETTER I",NULL},
/* 11383 */ { "TULU-TIGALARI LETTER II","	: 11382 113C9"},
/* 11384 */ { "TULU-TIGALARI LETTER U",NULL},
/* 11385 */ { "TULU-TIGALARI LETTER UU","	: 11384 113BB"},
/* 11386 */ { "TULU-TIGALARI LETTER VOCALIC R",NULL},
/* 11387 */ { "TULU-TIGALARI LETTER VOCALIC RR",NULL},
/* 11388 */ { "TULU-TIGALARI LETTER VOCALIC L",NULL},
/* 11389 */ { "TULU-TIGALARI LETTER VOCALIC LL",NULL},
/* 1138A */ { NULL,NULL},
/* 1138B */ { "TULU-TIGALARI LETTER EE",NULL},
/* 1138C */ { NULL,NULL},
/* 1138D */ { NULL,NULL},
/* 1138E */ { "TULU-TIGALARI LETTER AI","	: 1138B 113C2"},
/* 1138F */ { NULL,NULL},
/* 11390 */ { "TULU-TIGALARI LETTER OO",NULL},
/* 11391 */ { "TULU-TIGALARI LETTER AU","	: 11390 113C9"},
/* 11392 */ { "TULU-TIGALARI LETTER KA",NULL},
/* 11393 */ { "TULU-TIGALARI LETTER KHA",NULL},
/* 11394 */ { "TULU-TIGALARI LETTER GA",NULL},
/* 11395 */ { "TULU-TIGALARI LETTER GHA",NULL},
/* 11396 */ { "TULU-TIGALARI LETTER NGA",NULL},
/* 11397 */ { "TULU-TIGALARI LETTER CA",NULL},
/* 11398 */ { "TULU-TIGALARI LETTER CHA",NULL},
/* 11399 */ { "TULU-TIGALARI LETTER JA",NULL},
/* 1139A */ { "TULU-TIGALARI LETTER JHA",NULL},
/* 1139B */ { "TULU-TIGALARI LETTER NYA",NULL},
/* 1139C */ { "TULU-TIGALARI LETTER TTA",NULL},
/* 1139D */ { "TULU-TIGALARI LETTER TTHA",NULL},
/* 1139E */ { "TULU-TIGALARI LETTER DDA",NULL},
/* 1139F */ { "TULU-TIGALARI LETTER DDHA",NULL},
/* 113A0 */ { "TULU-TIGALARI LETTER NNA",NULL},
/* 113A1 */ { "TULU-TIGALARI LETTER TA",NULL},
/* 113A2 */ { "TULU-TIGALARI LETTER THA",NULL},
/* 113A3 */ { "TULU-TIGALARI LETTER DA",NULL},
/* 113A4 */ { "TULU-TIGALARI LETTER DHA",NULL},
/* 113A5 */ { "TULU-TIGALARI LETTER NA",NULL},
/* 113A6 */ { "TULU-TIGALARI LETTER PA",NULL},
/* 113A7 */ { "TULU-TIGALARI LETTER PHA",NULL},
/* 113A8 */ { "TULU-TIGALARI LETTER BA",NULL},
/* 113A9 */ { "TULU-TIGALARI LETTER BHA",NULL},
/* 113AA */ { "TULU-TIGALARI LETTER MA",NULL},
/* 113AB */ { "TULU-TIGALARI LETTER YA",NULL},
/* 113AC */ { "TULU-TIGALARI LETTER RA",NULL},
/* 113AD */ { "TULU-TIGALARI LETTER LA",NULL},
/* 113AE */ { "TULU-TIGALARI LETTER VA",NULL},
/* 113AF */ { "TULU-TIGALARI LETTER SHA",NULL},
/* 113B0 */ { "TULU-TIGALARI LETTER SSA",NULL},
/* 113B1 */ { "TULU-TIGALARI LETTER SA",NULL},
/* 113B2 */ { "TULU-TIGALARI LETTER HA",NULL},
/* 113B3 */ { "TULU-TIGALARI LETTER LLA",NULL},
/* 113B4 */ { "TULU-TIGALARI LETTER RRA",NULL},
/* 113B5 */ { "TULU-TIGALARI LETTER LLLA",NULL},
/* 113B6 */ { NULL,NULL},
/* 113B7 */ { "TULU-TIGALARI SIGN AVAGRAHA",NULL},
/* 113B8 */ { "TULU-TIGALARI VOWEL SIGN AA",NULL},
/* 113B9 */ { "TULU-TIGALARI VOWEL SIGN I",NULL},
/* 113BA */ { "TULU-TIGALARI VOWEL SIGN II",NULL},
/* 113BB */ { "TULU-TIGALARI VOWEL SIGN U",NULL},
/* 113BC */ { "TULU-TIGALARI VOWEL SIGN UU",NULL},
/* 113BD */ { "TULU-TIGALARI VOWEL SIGN VOCALIC R",NULL},
/* 113BE */ { "TULU-TIGALARI VOWEL SIGN VOCALIC RR",NULL},
/* 113BF */ { "TULU-TIGALARI VOWEL SIGN VOCALIC L",NULL},
/* 113C0 */ { "TULU-TIGALARI VOWEL SIGN VOCALIC LL",NULL},
/* 113C1 */ { NULL,NULL},
/* 113C2 */ { "TULU-TIGALARI VOWEL SIGN EE",NULL},
/* 113C3 */ { NULL,NULL},
/* 113C4 */ { NULL,NULL},
/* 113C5 */ { "TULU-TIGALARI VOWEL SIGN AI","	: 113C2 113C2"},
/* 113C6 */ { NULL,NULL},
/* 113C7 */ { "TULU-TIGALARI VOWEL SIGN OO","	: 113C2 113B8"},
/* 113C8 */ { "TULU-TIGALARI VOWEL SIGN AU","	: 113C2 113C9"},
/* 113C9 */ { "TULU-TIGALARI AU LENGTH MARK",NULL},
/* 113CA */ { "TULU-TIGALARI SIGN CANDRA ANUNASIKA",NULL},
/* 113CB */ { NULL,NULL},
/* 113CC */ { "TULU-TIGALARI SIGN ANUSVARA",NULL},
/* 113CD */ { "TULU-TIGALARI SIGN VISARGA",NULL},
/* 113CE */ { "TULU-TIGALARI SIGN VIRAMA",NULL},
/* 113CF */ { "TULU-TIGALARI SIGN LOOPED VIRAMA",NULL},
/* 113D0 */ { "TULU-TIGALARI CONJOINER",NULL},
/* 113D1 */ { "TULU-TIGALARI REPHA",NULL},
/* 113D2 */ { "TULU-TIGALARI GEMINATION MARK",NULL},
/* 113D3 */ { "TULU-TIGALARI SIGN PLUTA","	x (grantha sign pluta - 1135D)"},
/* 113D4 */ { "TULU-TIGALARI DANDA",NULL},
/* 113D5 */ { "TULU-TIGALARI DOUBLE DANDA",NULL},
/* 113D6 */ { NULL,NULL},
/* 113D7 */ { "TULU-TIGALARI SIGN OM PUSHPIKA",NULL},
/* 113D8 */ { "TULU-TIGALARI SIGN SHRII PUSHPIKA",NULL},
/* 113D9 */ { NULL,NULL},
/* 113DA */ { NULL,NULL},
/* 113DB */ { NULL,NULL},
/* 113DC */ { NULL,NULL},
/* 113DD */ { NULL,NULL},
/* 113DE */ { NULL,NULL},
/* 113DF */ { NULL,NULL},
/* 113E0 */ { NULL,NULL},
/* 113E1 */ { "TULU-TIGALARI VEDIC TONE SVARITA",NULL},
/* 113E2 */ { "TULU-TIGALARI VEDIC TONE ANUDATTA",NULL},
/* 113E3 */ { NULL,NULL},
/* 113E4 */ { NULL,NULL},
/* 113E5 */ { NULL,NULL},
/* 113E6 */ { NULL,NULL},
/* 113E7 */ { NULL,NULL},
/* 113E8 */ { NULL,NULL},
/* 113E9 */ { NULL,NULL},
/* 113EA */ { NULL,NULL},
/* 113EB */ { NULL,NULL},
/* 113EC */ { NULL,NULL},
/* 113ED */ { NULL,NULL},
/* 113EE */ { NULL,NULL},
/* 113EF */ { NULL,NULL},
/* 113F0 */ { NULL,NULL},
/* 113F1 */ { NULL,NULL},
/* 113F2 */ { NULL,NULL},
/* 113F3 */ { NULL,NULL},
/* 113F4 */ { NULL,NULL},
/* 113F5 */ { NULL,NULL},
/* 113F6 */ { NULL,NULL},
/* 113F7 */ { NULL,NULL},
/* 113F8 */ { NULL,NULL},
/* 113F9 */ { NULL,NULL},
/* 113FA */ { NULL,NULL},
/* 113FB */ { NULL,NULL},
/* 113FC */ { NULL,NULL},
/* 113FD */ { NULL,NULL},
/* 113FE */ { NULL,NULL},
/* 113FF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_14[] = {
/* 11400 */ { "NEWA LETTER A",NULL},
/* 11401 */ { "NEWA LETTER AA",NULL},
/* 11402 */ { "NEWA LETTER I",NULL},
/* 11403 */ { "NEWA LETTER II",NULL},
/* 11404 */ { "NEWA LETTER U",NULL},
/* 11405 */ { "NEWA LETTER UU",NULL},
/* 11406 */ { "NEWA LETTER VOCALIC R",NULL},
/* 11407 */ { "NEWA LETTER VOCALIC RR",NULL},
/* 11408 */ { "NEWA LETTER VOCALIC L",NULL},
/* 11409 */ { "NEWA LETTER VOCALIC LL",NULL},
/* 1140A */ { "NEWA LETTER E",NULL},
/* 1140B */ { "NEWA LETTER AI",NULL},
/* 1140C */ { "NEWA LETTER O",NULL},
/* 1140D */ { "NEWA LETTER AU",NULL},
/* 1140E */ { "NEWA LETTER KA",NULL},
/* 1140F */ { "NEWA LETTER KHA",NULL},
/* 11410 */ { "NEWA LETTER GA",NULL},
/* 11411 */ { "NEWA LETTER GHA",NULL},
/* 11412 */ { "NEWA LETTER NGA",NULL},
/* 11413 */ { "NEWA LETTER NGHA","	* murmured nasal for Nepal Bhasa language"},
/* 11414 */ { "NEWA LETTER CA",NULL},
/* 11415 */ { "NEWA LETTER CHA",NULL},
/* 11416 */ { "NEWA LETTER JA",NULL},
/* 11417 */ { "NEWA LETTER JHA",NULL},
/* 11418 */ { "NEWA LETTER NYA",NULL},
/* 11419 */ { "NEWA LETTER NYHA","	* murmured nasal for Nepal Bhasa language"},
/* 1141A */ { "NEWA LETTER TTA",NULL},
/* 1141B */ { "NEWA LETTER TTHA",NULL},
/* 1141C */ { "NEWA LETTER DDA",NULL},
/* 1141D */ { "NEWA LETTER DDHA",NULL},
/* 1141E */ { "NEWA LETTER NNA",NULL},
/* 1141F */ { "NEWA LETTER TA",NULL},
/* 11420 */ { "NEWA LETTER THA",NULL},
/* 11421 */ { "NEWA LETTER DA",NULL},
/* 11422 */ { "NEWA LETTER DHA",NULL},
/* 11423 */ { "NEWA LETTER NA",NULL},
/* 11424 */ { "NEWA LETTER NHA","	* murmured nasal for Nepal Bhasa language"},
/* 11425 */ { "NEWA LETTER PA",NULL},
/* 11426 */ { "NEWA LETTER PHA",NULL},
/* 11427 */ { "NEWA LETTER BA",NULL},
/* 11428 */ { "NEWA LETTER BHA",NULL},
/* 11429 */ { "NEWA LETTER MA",NULL},
/* 1142A */ { "NEWA LETTER MHA","	* murmured nasal for Nepal Bhasa language"},
/* 1142B */ { "NEWA LETTER YA",NULL},
/* 1142C */ { "NEWA LETTER RA",NULL},
/* 1142D */ { "NEWA LETTER RHA","	* murmured tap for Nepal Bhasa language"},
/* 1142E */ { "NEWA LETTER LA",NULL},
/* 1142F */ { "NEWA LETTER LHA","	* murmured lateral for Nepal Bhasa language"},
/* 11430 */ { "NEWA LETTER WA",NULL},
/* 11431 */ { "NEWA LETTER SHA",NULL},
/* 11432 */ { "NEWA LETTER SSA",NULL},
/* 11433 */ { "NEWA LETTER SA",NULL},
/* 11434 */ { "NEWA LETTER HA",NULL},
/* 11435 */ { "NEWA VOWEL SIGN AA",NULL},
/* 11436 */ { "NEWA VOWEL SIGN I",NULL},
/* 11437 */ { "NEWA VOWEL SIGN II",NULL},
/* 11438 */ { "NEWA VOWEL SIGN U",NULL},
/* 11439 */ { "NEWA VOWEL SIGN UU",NULL},
/* 1143A */ { "NEWA VOWEL SIGN VOCALIC R",NULL},
/* 1143B */ { "NEWA VOWEL SIGN VOCALIC RR",NULL},
/* 1143C */ { "NEWA VOWEL SIGN VOCALIC L",NULL},
/* 1143D */ { "NEWA VOWEL SIGN VOCALIC LL",NULL},
/* 1143E */ { "NEWA VOWEL SIGN E",NULL},
/* 1143F */ { "NEWA VOWEL SIGN AI",NULL},
/* 11440 */ { "NEWA VOWEL SIGN O",NULL},
/* 11441 */ { "NEWA VOWEL SIGN AU",NULL},
/* 11442 */ { "NEWA SIGN VIRAMA","	= tutisaalaa"},
/* 11443 */ { "NEWA SIGN CANDRABINDU","	= milaaphuti"},
/* 11444 */ { "NEWA SIGN ANUSVARA","	= sinhaphuti"},
/* 11445 */ { "NEWA SIGN VISARGA","	= liphuti"},
/* 11446 */ { "NEWA SIGN NUKTA",NULL},
/* 11447 */ { "NEWA SIGN AVAGRAHA","	= sulaa"},
/* 11448 */ { "NEWA SIGN FINAL ANUSVARA","	= baadipu"},
/* 11449 */ { "NEWA OM",NULL},
/* 1144A */ { "NEWA SIDDHI",NULL},
/* 1144B */ { "NEWA DANDA","	= dipu"},
/* 1144C */ { "NEWA DOUBLE DANDA",NULL},
/* 1144D */ { "NEWA COMMA","	= jhaasu"},
/* 1144E */ { "NEWA GAP FILLER","	= thaayjaayekaa"},
/* 1144F */ { "NEWA ABBREVIATION SIGN",NULL},
/* 11450 */ { "NEWA DIGIT ZERO","	= guli"},
/* 11451 */ { "NEWA DIGIT ONE","	= chi"},
/* 11452 */ { "NEWA DIGIT TWO","	= nasi"},
/* 11453 */ { "NEWA DIGIT THREE","	= swa"},
/* 11454 */ { "NEWA DIGIT FOUR","	= pi"},
/* 11455 */ { "NEWA DIGIT FIVE","	= njaa"},
/* 11456 */ { "NEWA DIGIT SIX","	= khu"},
/* 11457 */ { "NEWA DIGIT SEVEN","	= nhasa"},
/* 11458 */ { "NEWA DIGIT EIGHT","	= cyaa"},
/* 11459 */ { "NEWA DIGIT NINE","	= gu"},
/* 1145A */ { "NEWA DOUBLE COMMA",NULL},
/* 1145B */ { "NEWA PLACEHOLDER MARK","	= jaayekaa"},
/* 1145C */ { NULL,NULL},
/* 1145D */ { "NEWA INSERTION SIGN","	= tansaa"},
/* 1145E */ { "NEWA SANDHI MARK","	* indicates external sandhi in Sanskrit documents\n"
	"	x (bengali sandhi mark - 09FE)"},
/* 1145F */ { "NEWA LETTER VEDIC ANUSVARA",NULL},
/* 11460 */ { "NEWA SIGN JIHVAMULIYA","	x (vedic sign jihvamuliya - 1CF5)"},
/* 11461 */ { "NEWA SIGN UPADHMANIYA","	x (vedic sign upadhmaniya - 1CF6)"},
/* 11462 */ { NULL,NULL},
/* 11463 */ { NULL,NULL},
/* 11464 */ { NULL,NULL},
/* 11465 */ { NULL,NULL},
/* 11466 */ { NULL,NULL},
/* 11467 */ { NULL,NULL},
/* 11468 */ { NULL,NULL},
/* 11469 */ { NULL,NULL},
/* 1146A */ { NULL,NULL},
/* 1146B */ { NULL,NULL},
/* 1146C */ { NULL,NULL},
/* 1146D */ { NULL,NULL},
/* 1146E */ { NULL,NULL},
/* 1146F */ { NULL,NULL},
/* 11470 */ { NULL,NULL},
/* 11471 */ { NULL,NULL},
/* 11472 */ { NULL,NULL},
/* 11473 */ { NULL,NULL},
/* 11474 */ { NULL,NULL},
/* 11475 */ { NULL,NULL},
/* 11476 */ { NULL,NULL},
/* 11477 */ { NULL,NULL},
/* 11478 */ { NULL,NULL},
/* 11479 */ { NULL,NULL},
/* 1147A */ { NULL,NULL},
/* 1147B */ { NULL,NULL},
/* 1147C */ { NULL,NULL},
/* 1147D */ { NULL,NULL},
/* 1147E */ { NULL,NULL},
/* 1147F */ { NULL,NULL},
/* 11480 */ { "TIRHUTA ANJI",NULL},
/* 11481 */ { "TIRHUTA LETTER A",NULL},
/* 11482 */ { "TIRHUTA LETTER AA",NULL},
/* 11483 */ { "TIRHUTA LETTER I",NULL},
/* 11484 */ { "TIRHUTA LETTER II",NULL},
/* 11485 */ { "TIRHUTA LETTER U",NULL},
/* 11486 */ { "TIRHUTA LETTER UU",NULL},
/* 11487 */ { "TIRHUTA LETTER VOCALIC R",NULL},
/* 11488 */ { "TIRHUTA LETTER VOCALIC RR",NULL},
/* 11489 */ { "TIRHUTA LETTER VOCALIC L",NULL},
/* 1148A */ { "TIRHUTA LETTER VOCALIC LL",NULL},
/* 1148B */ { "TIRHUTA LETTER E",NULL},
/* 1148C */ { "TIRHUTA LETTER AI",NULL},
/* 1148D */ { "TIRHUTA LETTER O",NULL},
/* 1148E */ { "TIRHUTA LETTER AU",NULL},
/* 1148F */ { "TIRHUTA LETTER KA",NULL},
/* 11490 */ { "TIRHUTA LETTER KHA",NULL},
/* 11491 */ { "TIRHUTA LETTER GA",NULL},
/* 11492 */ { "TIRHUTA LETTER GHA",NULL},
/* 11493 */ { "TIRHUTA LETTER NGA",NULL},
/* 11494 */ { "TIRHUTA LETTER CA",NULL},
/* 11495 */ { "TIRHUTA LETTER CHA",NULL},
/* 11496 */ { "TIRHUTA LETTER JA",NULL},
/* 11497 */ { "TIRHUTA LETTER JHA",NULL},
/* 11498 */ { "TIRHUTA LETTER NYA",NULL},
/* 11499 */ { "TIRHUTA LETTER TTA",NULL},
/* 1149A */ { "TIRHUTA LETTER TTHA",NULL},
/* 1149B */ { "TIRHUTA LETTER DDA",NULL},
/* 1149C */ { "TIRHUTA LETTER DDHA",NULL},
/* 1149D */ { "TIRHUTA LETTER NNA",NULL},
/* 1149E */ { "TIRHUTA LETTER TA",NULL},
/* 1149F */ { "TIRHUTA LETTER THA",NULL},
/* 114A0 */ { "TIRHUTA LETTER DA",NULL},
/* 114A1 */ { "TIRHUTA LETTER DHA",NULL},
/* 114A2 */ { "TIRHUTA LETTER NA",NULL},
/* 114A3 */ { "TIRHUTA LETTER PA",NULL},
/* 114A4 */ { "TIRHUTA LETTER PHA",NULL},
/* 114A5 */ { "TIRHUTA LETTER BA",NULL},
/* 114A6 */ { "TIRHUTA LETTER BHA",NULL},
/* 114A7 */ { "TIRHUTA LETTER MA",NULL},
/* 114A8 */ { "TIRHUTA LETTER YA",NULL},
/* 114A9 */ { "TIRHUTA LETTER RA",NULL},
/* 114AA */ { "TIRHUTA LETTER LA",NULL},
/* 114AB */ { "TIRHUTA LETTER VA",NULL},
/* 114AC */ { "TIRHUTA LETTER SHA",NULL},
/* 114AD */ { "TIRHUTA LETTER SSA",NULL},
/* 114AE */ { "TIRHUTA LETTER SA",NULL},
/* 114AF */ { "TIRHUTA LETTER HA",NULL},
/* 114B0 */ { "TIRHUTA VOWEL SIGN AA",NULL},
/* 114B1 */ { "TIRHUTA VOWEL SIGN I",NULL},
/* 114B2 */ { "TIRHUTA VOWEL SIGN II",NULL},
/* 114B3 */ { "TIRHUTA VOWEL SIGN U",NULL},
/* 114B4 */ { "TIRHUTA VOWEL SIGN UU",NULL},
/* 114B5 */ { "TIRHUTA VOWEL SIGN VOCALIC R",NULL},
/* 114B6 */ { "TIRHUTA VOWEL SIGN VOCALIC RR",NULL},
/* 114B7 */ { "TIRHUTA VOWEL SIGN VOCALIC L",NULL},
/* 114B8 */ { "TIRHUTA VOWEL SIGN VOCALIC LL",NULL},
/* 114B9 */ { "TIRHUTA VOWEL SIGN E",NULL},
/* 114BA */ { "TIRHUTA VOWEL SIGN SHORT E",NULL},
/* 114BB */ { "TIRHUTA VOWEL SIGN AI","	: 114B9 114BA"},
/* 114BC */ { "TIRHUTA VOWEL SIGN O","	: 114B9 114B0"},
/* 114BD */ { "TIRHUTA VOWEL SIGN SHORT O",NULL},
/* 114BE */ { "TIRHUTA VOWEL SIGN AU","	: 114B9 114BD"},
/* 114BF */ { "TIRHUTA SIGN CANDRABINDU",NULL},
/* 114C0 */ { "TIRHUTA SIGN ANUSVARA",NULL},
/* 114C1 */ { "TIRHUTA SIGN VISARGA",NULL},
/* 114C2 */ { "TIRHUTA SIGN VIRAMA","	= halant"},
/* 114C3 */ { "TIRHUTA SIGN NUKTA",NULL},
/* 114C4 */ { "TIRHUTA SIGN AVAGRAHA",NULL},
/* 114C5 */ { "TIRHUTA GVANG","	= vedic anusvara"},
/* 114C6 */ { "TIRHUTA ABBREVIATION SIGN",NULL},
/* 114C7 */ { "TIRHUTA OM",NULL},
/* 114C8 */ { NULL,NULL},
/* 114C9 */ { NULL,NULL},
/* 114CA */ { NULL,NULL},
/* 114CB */ { NULL,NULL},
/* 114CC */ { NULL,NULL},
/* 114CD */ { NULL,NULL},
/* 114CE */ { NULL,NULL},
/* 114CF */ { NULL,NULL},
/* 114D0 */ { "TIRHUTA DIGIT ZERO",NULL},
/* 114D1 */ { "TIRHUTA DIGIT ONE",NULL},
/* 114D2 */ { "TIRHUTA DIGIT TWO",NULL},
/* 114D3 */ { "TIRHUTA DIGIT THREE",NULL},
/* 114D4 */ { "TIRHUTA DIGIT FOUR",NULL},
/* 114D5 */ { "TIRHUTA DIGIT FIVE",NULL},
/* 114D6 */ { "TIRHUTA DIGIT SIX",NULL},
/* 114D7 */ { "TIRHUTA DIGIT SEVEN",NULL},
/* 114D8 */ { "TIRHUTA DIGIT EIGHT",NULL},
/* 114D9 */ { "TIRHUTA DIGIT NINE",NULL},
/* 114DA */ { NULL,NULL},
/* 114DB */ { NULL,NULL},
/* 114DC */ { NULL,NULL},
/* 114DD */ { NULL,NULL},
/* 114DE */ { NULL,NULL},
/* 114DF */ { NULL,NULL},
/* 114E0 */ { NULL,NULL},
/* 114E1 */ { NULL,NULL},
/* 114E2 */ { NULL,NULL},
/* 114E3 */ { NULL,NULL},
/* 114E4 */ { NULL,NULL},
/* 114E5 */ { NULL,NULL},
/* 114E6 */ { NULL,NULL},
/* 114E7 */ { NULL,NULL},
/* 114E8 */ { NULL,NULL},
/* 114E9 */ { NULL,NULL},
/* 114EA */ { NULL,NULL},
/* 114EB */ { NULL,NULL},
/* 114EC */ { NULL,NULL},
/* 114ED */ { NULL,NULL},
/* 114EE */ { NULL,NULL},
/* 114EF */ { NULL,NULL},
/* 114F0 */ { NULL,NULL},
/* 114F1 */ { NULL,NULL},
/* 114F2 */ { NULL,NULL},
/* 114F3 */ { NULL,NULL},
/* 114F4 */ { NULL,NULL},
/* 114F5 */ { NULL,NULL},
/* 114F6 */ { NULL,NULL},
/* 114F7 */ { NULL,NULL},
/* 114F8 */ { NULL,NULL},
/* 114F9 */ { NULL,NULL},
/* 114FA */ { NULL,NULL},
/* 114FB */ { NULL,NULL},
/* 114FC */ { NULL,NULL},
/* 114FD */ { NULL,NULL},
/* 114FE */ { NULL,NULL},
/* 114FF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_15[] = {
/* 11500 */ { NULL,NULL},
/* 11501 */ { NULL,NULL},
/* 11502 */ { NULL,NULL},
/* 11503 */ { NULL,NULL},
/* 11504 */ { NULL,NULL},
/* 11505 */ { NULL,NULL},
/* 11506 */ { NULL,NULL},
/* 11507 */ { NULL,NULL},
/* 11508 */ { NULL,NULL},
/* 11509 */ { NULL,NULL},
/* 1150A */ { NULL,NULL},
/* 1150B */ { NULL,NULL},
/* 1150C */ { NULL,NULL},
/* 1150D */ { NULL,NULL},
/* 1150E */ { NULL,NULL},
/* 1150F */ { NULL,NULL},
/* 11510 */ { NULL,NULL},
/* 11511 */ { NULL,NULL},
/* 11512 */ { NULL,NULL},
/* 11513 */ { NULL,NULL},
/* 11514 */ { NULL,NULL},
/* 11515 */ { NULL,NULL},
/* 11516 */ { NULL,NULL},
/* 11517 */ { NULL,NULL},
/* 11518 */ { NULL,NULL},
/* 11519 */ { NULL,NULL},
/* 1151A */ { NULL,NULL},
/* 1151B */ { NULL,NULL},
/* 1151C */ { NULL,NULL},
/* 1151D */ { NULL,NULL},
/* 1151E */ { NULL,NULL},
/* 1151F */ { NULL,NULL},
/* 11520 */ { NULL,NULL},
/* 11521 */ { NULL,NULL},
/* 11522 */ { NULL,NULL},
/* 11523 */ { NULL,NULL},
/* 11524 */ { NULL,NULL},
/* 11525 */ { NULL,NULL},
/* 11526 */ { NULL,NULL},
/* 11527 */ { NULL,NULL},
/* 11528 */ { NULL,NULL},
/* 11529 */ { NULL,NULL},
/* 1152A */ { NULL,NULL},
/* 1152B */ { NULL,NULL},
/* 1152C */ { NULL,NULL},
/* 1152D */ { NULL,NULL},
/* 1152E */ { NULL,NULL},
/* 1152F */ { NULL,NULL},
/* 11530 */ { NULL,NULL},
/* 11531 */ { NULL,NULL},
/* 11532 */ { NULL,NULL},
/* 11533 */ { NULL,NULL},
/* 11534 */ { NULL,NULL},
/* 11535 */ { NULL,NULL},
/* 11536 */ { NULL,NULL},
/* 11537 */ { NULL,NULL},
/* 11538 */ { NULL,NULL},
/* 11539 */ { NULL,NULL},
/* 1153A */ { NULL,NULL},
/* 1153B */ { NULL,NULL},
/* 1153C */ { NULL,NULL},
/* 1153D */ { NULL,NULL},
/* 1153E */ { NULL,NULL},
/* 1153F */ { NULL,NULL},
/* 11540 */ { NULL,NULL},
/* 11541 */ { NULL,NULL},
/* 11542 */ { NULL,NULL},
/* 11543 */ { NULL,NULL},
/* 11544 */ { NULL,NULL},
/* 11545 */ { NULL,NULL},
/* 11546 */ { NULL,NULL},
/* 11547 */ { NULL,NULL},
/* 11548 */ { NULL,NULL},
/* 11549 */ { NULL,NULL},
/* 1154A */ { NULL,NULL},
/* 1154B */ { NULL,NULL},
/* 1154C */ { NULL,NULL},
/* 1154D */ { NULL,NULL},
/* 1154E */ { NULL,NULL},
/* 1154F */ { NULL,NULL},
/* 11550 */ { NULL,NULL},
/* 11551 */ { NULL,NULL},
/* 11552 */ { NULL,NULL},
/* 11553 */ { NULL,NULL},
/* 11554 */ { NULL,NULL},
/* 11555 */ { NULL,NULL},
/* 11556 */ { NULL,NULL},
/* 11557 */ { NULL,NULL},
/* 11558 */ { NULL,NULL},
/* 11559 */ { NULL,NULL},
/* 1155A */ { NULL,NULL},
/* 1155B */ { NULL,NULL},
/* 1155C */ { NULL,NULL},
/* 1155D */ { NULL,NULL},
/* 1155E */ { NULL,NULL},
/* 1155F */ { NULL,NULL},
/* 11560 */ { NULL,NULL},
/* 11561 */ { NULL,NULL},
/* 11562 */ { NULL,NULL},
/* 11563 */ { NULL,NULL},
/* 11564 */ { NULL,NULL},
/* 11565 */ { NULL,NULL},
/* 11566 */ { NULL,NULL},
/* 11567 */ { NULL,NULL},
/* 11568 */ { NULL,NULL},
/* 11569 */ { NULL,NULL},
/* 1156A */ { NULL,NULL},
/* 1156B */ { NULL,NULL},
/* 1156C */ { NULL,NULL},
/* 1156D */ { NULL,NULL},
/* 1156E */ { NULL,NULL},
/* 1156F */ { NULL,NULL},
/* 11570 */ { NULL,NULL},
/* 11571 */ { NULL,NULL},
/* 11572 */ { NULL,NULL},
/* 11573 */ { NULL,NULL},
/* 11574 */ { NULL,NULL},
/* 11575 */ { NULL,NULL},
/* 11576 */ { NULL,NULL},
/* 11577 */ { NULL,NULL},
/* 11578 */ { NULL,NULL},
/* 11579 */ { NULL,NULL},
/* 1157A */ { NULL,NULL},
/* 1157B */ { NULL,NULL},
/* 1157C */ { NULL,NULL},
/* 1157D */ { NULL,NULL},
/* 1157E */ { NULL,NULL},
/* 1157F */ { NULL,NULL},
/* 11580 */ { "SIDDHAM LETTER A",NULL},
/* 11581 */ { "SIDDHAM LETTER AA",NULL},
/* 11582 */ { "SIDDHAM LETTER I",NULL},
/* 11583 */ { "SIDDHAM LETTER II",NULL},
/* 11584 */ { "SIDDHAM LETTER U",NULL},
/* 11585 */ { "SIDDHAM LETTER UU",NULL},
/* 11586 */ { "SIDDHAM LETTER VOCALIC R",NULL},
/* 11587 */ { "SIDDHAM LETTER VOCALIC RR",NULL},
/* 11588 */ { "SIDDHAM LETTER VOCALIC L",NULL},
/* 11589 */ { "SIDDHAM LETTER VOCALIC LL",NULL},
/* 1158A */ { "SIDDHAM LETTER E",NULL},
/* 1158B */ { "SIDDHAM LETTER AI",NULL},
/* 1158C */ { "SIDDHAM LETTER O",NULL},
/* 1158D */ { "SIDDHAM LETTER AU",NULL},
/* 1158E */ { "SIDDHAM LETTER KA",NULL},
/* 1158F */ { "SIDDHAM LETTER KHA",NULL},
/* 11590 */ { "SIDDHAM LETTER GA",NULL},
/* 11591 */ { "SIDDHAM LETTER GHA",NULL},
/* 11592 */ { "SIDDHAM LETTER NGA",NULL},
/* 11593 */ { "SIDDHAM LETTER CA",NULL},
/* 11594 */ { "SIDDHAM LETTER CHA",NULL},
/* 11595 */ { "SIDDHAM LETTER JA",NULL},
/* 11596 */ { "SIDDHAM LETTER JHA",NULL},
/* 11597 */ { "SIDDHAM LETTER NYA",NULL},
/* 11598 */ { "SIDDHAM LETTER TTA",NULL},
/* 11599 */ { "SIDDHAM LETTER TTHA",NULL},
/* 1159A */ { "SIDDHAM LETTER DDA",NULL},
/* 1159B */ { "SIDDHAM LETTER DDHA",NULL},
/* 1159C */ { "SIDDHAM LETTER NNA",NULL},
/* 1159D */ { "SIDDHAM LETTER TA",NULL},
/* 1159E */ { "SIDDHAM LETTER THA",NULL},
/* 1159F */ { "SIDDHAM LETTER DA",NULL},
/* 115A0 */ { "SIDDHAM LETTER DHA",NULL},
/* 115A1 */ { "SIDDHAM LETTER NA",NULL},
/* 115A2 */ { "SIDDHAM LETTER PA",NULL},
/* 115A3 */ { "SIDDHAM LETTER PHA",NULL},
/* 115A4 */ { "SIDDHAM LETTER BA",NULL},
/* 115A5 */ { "SIDDHAM LETTER BHA",NULL},
/* 115A6 */ { "SIDDHAM LETTER MA",NULL},
/* 115A7 */ { "SIDDHAM LETTER YA",NULL},
/* 115A8 */ { "SIDDHAM LETTER RA",NULL},
/* 115A9 */ { "SIDDHAM LETTER LA",NULL},
/* 115AA */ { "SIDDHAM LETTER VA",NULL},
/* 115AB */ { "SIDDHAM LETTER SHA",NULL},
/* 115AC */ { "SIDDHAM LETTER SSA",NULL},
/* 115AD */ { "SIDDHAM LETTER SA",NULL},
/* 115AE */ { "SIDDHAM LETTER HA",NULL},
/* 115AF */ { "SIDDHAM VOWEL SIGN AA",NULL},
/* 115B0 */ { "SIDDHAM VOWEL SIGN I",NULL},
/* 115B1 */ { "SIDDHAM VOWEL SIGN II",NULL},
/* 115B2 */ { "SIDDHAM VOWEL SIGN U",NULL},
/* 115B3 */ { "SIDDHAM VOWEL SIGN UU",NULL},
/* 115B4 */ { "SIDDHAM VOWEL SIGN VOCALIC R",NULL},
/* 115B5 */ { "SIDDHAM VOWEL SIGN VOCALIC RR",NULL},
/* 115B6 */ { NULL,NULL},
/* 115B7 */ { NULL,NULL},
/* 115B8 */ { "SIDDHAM VOWEL SIGN E",NULL},
/* 115B9 */ { "SIDDHAM VOWEL SIGN AI",NULL},
/* 115BA */ { "SIDDHAM VOWEL SIGN O","	: 115B8 115AF"},
/* 115BB */ { "SIDDHAM VOWEL SIGN AU","	: 115B9 115AF"},
/* 115BC */ { "SIDDHAM SIGN CANDRABINDU",NULL},
/* 115BD */ { "SIDDHAM SIGN ANUSVARA",NULL},
/* 115BE */ { "SIDDHAM SIGN VISARGA",NULL},
/* 115BF */ { "SIDDHAM SIGN VIRAMA",NULL},
/* 115C0 */ { "SIDDHAM SIGN NUKTA","	* used for writing foreign sounds"},
/* 115C1 */ { "SIDDHAM SIGN SIDDHAM","	= siddhirastu\n"
	"	* used at the beginning of texts"},
/* 115C2 */ { "SIDDHAM DANDA",NULL},
/* 115C3 */ { "SIDDHAM DOUBLE DANDA",NULL},
/* 115C4 */ { "SIDDHAM SEPARATOR DOT","	* used for separating syllables and words"},
/* 115C5 */ { "SIDDHAM SEPARATOR BAR","	* used for separating syllables and words"},
/* 115C6 */ { "SIDDHAM REPETITION MARK-1",NULL},
/* 115C7 */ { "SIDDHAM REPETITION MARK-2",NULL},
/* 115C8 */ { "SIDDHAM REPETITION MARK-3",NULL},
/* 115C9 */ { "SIDDHAM END OF TEXT MARK","	* indicates the completion of a text"},
/* 115CA */ { "SIDDHAM SECTION MARK WITH TRIDENT AND U-SHAPED ORNAMENTS",NULL},
/* 115CB */ { "SIDDHAM SECTION MARK WITH TRIDENT AND DOTTED CRESCENTS",NULL},
/* 115CC */ { "SIDDHAM SECTION MARK WITH RAYS AND DOTTED CRESCENTS",NULL},
/* 115CD */ { "SIDDHAM SECTION MARK WITH RAYS AND DOTTED DOUBLE CRESCENTS",NULL},
/* 115CE */ { "SIDDHAM SECTION MARK WITH RAYS AND DOTTED TRIPLE CRESCENTS",NULL},
/* 115CF */ { "SIDDHAM SECTION MARK DOUBLE RING",NULL},
/* 115D0 */ { "SIDDHAM SECTION MARK DOUBLE RING WITH RAYS",NULL},
/* 115D1 */ { "SIDDHAM SECTION MARK WITH DOUBLE CRESCENTS",NULL},
/* 115D2 */ { "SIDDHAM SECTION MARK WITH TRIPLE CRESCENTS",NULL},
/* 115D3 */ { "SIDDHAM SECTION MARK WITH QUADRUPLE CRESCENTS",NULL},
/* 115D4 */ { "SIDDHAM SECTION MARK WITH SEPTUPLE CRESCENTS",NULL},
/* 115D5 */ { "SIDDHAM SECTION MARK WITH CIRCLES AND RAYS",NULL},
/* 115D6 */ { "SIDDHAM SECTION MARK WITH CIRCLES AND TWO ENCLOSURES",NULL},
/* 115D7 */ { "SIDDHAM SECTION MARK WITH CIRCLES AND FOUR ENCLOSURES",NULL},
/* 115D8 */ { "SIDDHAM LETTER THREE-CIRCLE ALTERNATE I","	x (siddham letter i - 11582)"},
/* 115D9 */ { "SIDDHAM LETTER TWO-CIRCLE ALTERNATE I",NULL},
/* 115DA */ { "SIDDHAM LETTER TWO-CIRCLE ALTERNATE II","	x (siddham letter ii - 11583)"},
/* 115DB */ { "SIDDHAM LETTER ALTERNATE U","	x (siddham letter u - 11584)"},
/* 115DC */ { "SIDDHAM VOWEL SIGN ALTERNATE U",NULL},
/* 115DD */ { "SIDDHAM VOWEL SIGN ALTERNATE UU",NULL},
/* 115DE */ { NULL,NULL},
/* 115DF */ { NULL,NULL},
/* 115E0 */ { NULL,NULL},
/* 115E1 */ { NULL,NULL},
/* 115E2 */ { NULL,NULL},
/* 115E3 */ { NULL,NULL},
/* 115E4 */ { NULL,NULL},
/* 115E5 */ { NULL,NULL},
/* 115E6 */ { NULL,NULL},
/* 115E7 */ { NULL,NULL},
/* 115E8 */ { NULL,NULL},
/* 115E9 */ { NULL,NULL},
/* 115EA */ { NULL,NULL},
/* 115EB */ { NULL,NULL},
/* 115EC */ { NULL,NULL},
/* 115ED */ { NULL,NULL},
/* 115EE */ { NULL,NULL},
/* 115EF */ { NULL,NULL},
/* 115F0 */ { NULL,NULL},
/* 115F1 */ { NULL,NULL},
/* 115F2 */ { NULL,NULL},
/* 115F3 */ { NULL,NULL},
/* 115F4 */ { NULL,NULL},
/* 115F5 */ { NULL,NULL},
/* 115F6 */ { NULL,NULL},
/* 115F7 */ { NULL,NULL},
/* 115F8 */ { NULL,NULL},
/* 115F9 */ { NULL,NULL},
/* 115FA */ { NULL,NULL},
/* 115FB */ { NULL,NULL},
/* 115FC */ { NULL,NULL},
/* 115FD */ { NULL,NULL},
/* 115FE */ { NULL,NULL},
/* 115FF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_16[] = {
/* 11600 */ { "MODI LETTER A",NULL},
/* 11601 */ { "MODI LETTER AA",NULL},
/* 11602 */ { "MODI LETTER I",NULL},
/* 11603 */ { "MODI LETTER II",NULL},
/* 11604 */ { "MODI LETTER U",NULL},
/* 11605 */ { "MODI LETTER UU",NULL},
/* 11606 */ { "MODI LETTER VOCALIC R",NULL},
/* 11607 */ { "MODI LETTER VOCALIC RR",NULL},
/* 11608 */ { "MODI LETTER VOCALIC L",NULL},
/* 11609 */ { "MODI LETTER VOCALIC LL",NULL},
/* 1160A */ { "MODI LETTER E",NULL},
/* 1160B */ { "MODI LETTER AI",NULL},
/* 1160C */ { "MODI LETTER O",NULL},
/* 1160D */ { "MODI LETTER AU",NULL},
/* 1160E */ { "MODI LETTER KA",NULL},
/* 1160F */ { "MODI LETTER KHA",NULL},
/* 11610 */ { "MODI LETTER GA",NULL},
/* 11611 */ { "MODI LETTER GHA",NULL},
/* 11612 */ { "MODI LETTER NGA",NULL},
/* 11613 */ { "MODI LETTER CA",NULL},
/* 11614 */ { "MODI LETTER CHA",NULL},
/* 11615 */ { "MODI LETTER JA",NULL},
/* 11616 */ { "MODI LETTER JHA",NULL},
/* 11617 */ { "MODI LETTER NYA",NULL},
/* 11618 */ { "MODI LETTER TTA",NULL},
/* 11619 */ { "MODI LETTER TTHA",NULL},
/* 1161A */ { "MODI LETTER DDA",NULL},
/* 1161B */ { "MODI LETTER DDHA",NULL},
/* 1161C */ { "MODI LETTER NNA",NULL},
/* 1161D */ { "MODI LETTER TA",NULL},
/* 1161E */ { "MODI LETTER THA",NULL},
/* 1161F */ { "MODI LETTER DA",NULL},
/* 11620 */ { "MODI LETTER DHA",NULL},
/* 11621 */ { "MODI LETTER NA",NULL},
/* 11622 */ { "MODI LETTER PA",NULL},
/* 11623 */ { "MODI LETTER PHA",NULL},
/* 11624 */ { "MODI LETTER BA",NULL},
/* 11625 */ { "MODI LETTER BHA",NULL},
/* 11626 */ { "MODI LETTER MA",NULL},
/* 11627 */ { "MODI LETTER YA",NULL},
/* 11628 */ { "MODI LETTER RA",NULL},
/* 11629 */ { "MODI LETTER LA",NULL},
/* 1162A */ { "MODI LETTER VA",NULL},
/* 1162B */ { "MODI LETTER SHA",NULL},
/* 1162C */ { "MODI LETTER SSA",NULL},
/* 1162D */ { "MODI LETTER SA",NULL},
/* 1162E */ { "MODI LETTER HA",NULL},
/* 1162F */ { "MODI LETTER LLA",NULL},
/* 11630 */ { "MODI VOWEL SIGN AA",NULL},
/* 11631 */ { "MODI VOWEL SIGN I",NULL},
/* 11632 */ { "MODI VOWEL SIGN II",NULL},
/* 11633 */ { "MODI VOWEL SIGN U",NULL},
/* 11634 */ { "MODI VOWEL SIGN UU",NULL},
/* 11635 */ { "MODI VOWEL SIGN VOCALIC R",NULL},
/* 11636 */ { "MODI VOWEL SIGN VOCALIC RR",NULL},
/* 11637 */ { "MODI VOWEL SIGN VOCALIC L",NULL},
/* 11638 */ { "MODI VOWEL SIGN VOCALIC LL",NULL},
/* 11639 */ { "MODI VOWEL SIGN E",NULL},
/* 1163A */ { "MODI VOWEL SIGN AI",NULL},
/* 1163B */ { "MODI VOWEL SIGN O",NULL},
/* 1163C */ { "MODI VOWEL SIGN AU",NULL},
/* 1163D */ { "MODI SIGN ANUSVARA",NULL},
/* 1163E */ { "MODI SIGN VISARGA",NULL},
/* 1163F */ { "MODI SIGN VIRAMA","	= halant"},
/* 11640 */ { "MODI SIGN ARDHACANDRA","	* used for transcribing English"},
/* 11641 */ { "MODI DANDA",NULL},
/* 11642 */ { "MODI DOUBLE DANDA",NULL},
/* 11643 */ { "MODI ABBREVIATION SIGN",NULL},
/* 11644 */ { "MODI SIGN HUVA","	* used as an invocation"},
/* 11645 */ { NULL,NULL},
/* 11646 */ { NULL,NULL},
/* 11647 */ { NULL,NULL},
/* 11648 */ { NULL,NULL},
/* 11649 */ { NULL,NULL},
/* 1164A */ { NULL,NULL},
/* 1164B */ { NULL,NULL},
/* 1164C */ { NULL,NULL},
/* 1164D */ { NULL,NULL},
/* 1164E */ { NULL,NULL},
/* 1164F */ { NULL,NULL},
/* 11650 */ { "MODI DIGIT ZERO",NULL},
/* 11651 */ { "MODI DIGIT ONE",NULL},
/* 11652 */ { "MODI DIGIT TWO",NULL},
/* 11653 */ { "MODI DIGIT THREE",NULL},
/* 11654 */ { "MODI DIGIT FOUR",NULL},
/* 11655 */ { "MODI DIGIT FIVE",NULL},
/* 11656 */ { "MODI DIGIT SIX",NULL},
/* 11657 */ { "MODI DIGIT SEVEN",NULL},
/* 11658 */ { "MODI DIGIT EIGHT",NULL},
/* 11659 */ { "MODI DIGIT NINE",NULL},
/* 1165A */ { NULL,NULL},
/* 1165B */ { NULL,NULL},
/* 1165C */ { NULL,NULL},
/* 1165D */ { NULL,NULL},
/* 1165E */ { NULL,NULL},
/* 1165F */ { NULL,NULL},
/* 11660 */ { "MONGOLIAN BIRGA WITH ORNAMENT","	x (mongolian birga - 1800)"},
/* 11661 */ { "MONGOLIAN ROTATED BIRGA",NULL},
/* 11662 */ { "MONGOLIAN DOUBLE BIRGA WITH ORNAMENT",NULL},
/* 11663 */ { "MONGOLIAN TRIPLE BIRGA WITH ORNAMENT",NULL},
/* 11664 */ { "MONGOLIAN BIRGA WITH DOUBLE ORNAMENT",NULL},
/* 11665 */ { "MONGOLIAN ROTATED BIRGA WITH ORNAMENT",NULL},
/* 11666 */ { "MONGOLIAN ROTATED BIRGA WITH DOUBLE ORNAMENT",NULL},
/* 11667 */ { "MONGOLIAN INVERTED BIRGA",NULL},
/* 11668 */ { "MONGOLIAN INVERTED BIRGA WITH DOUBLE ORNAMENT",NULL},
/* 11669 */ { "MONGOLIAN SWIRL BIRGA",NULL},
/* 1166A */ { "MONGOLIAN SWIRL BIRGA WITH ORNAMENT",NULL},
/* 1166B */ { "MONGOLIAN SWIRL BIRGA WITH DOUBLE ORNAMENT",NULL},
/* 1166C */ { "MONGOLIAN TURNED SWIRL BIRGA WITH DOUBLE ORNAMENT",NULL},
/* 1166D */ { NULL,NULL},
/* 1166E */ { NULL,NULL},
/* 1166F */ { NULL,NULL},
/* 11670 */ { NULL,NULL},
/* 11671 */ { NULL,NULL},
/* 11672 */ { NULL,NULL},
/* 11673 */ { NULL,NULL},
/* 11674 */ { NULL,NULL},
/* 11675 */ { NULL,NULL},
/* 11676 */ { NULL,NULL},
/* 11677 */ { NULL,NULL},
/* 11678 */ { NULL,NULL},
/* 11679 */ { NULL,NULL},
/* 1167A */ { NULL,NULL},
/* 1167B */ { NULL,NULL},
/* 1167C */ { NULL,NULL},
/* 1167D */ { NULL,NULL},
/* 1167E */ { NULL,NULL},
/* 1167F */ { NULL,NULL},
/* 11680 */ { "TAKRI LETTER A",NULL},
/* 11681 */ { "TAKRI LETTER AA",NULL},
/* 11682 */ { "TAKRI LETTER I",NULL},
/* 11683 */ { "TAKRI LETTER II",NULL},
/* 11684 */ { "TAKRI LETTER U",NULL},
/* 11685 */ { "TAKRI LETTER UU",NULL},
/* 11686 */ { "TAKRI LETTER E",NULL},
/* 11687 */ { "TAKRI LETTER AI",NULL},
/* 11688 */ { "TAKRI LETTER O",NULL},
/* 11689 */ { "TAKRI LETTER AU",NULL},
/* 1168A */ { "TAKRI LETTER KA",NULL},
/* 1168B */ { "TAKRI LETTER KHA","	* also used to denote ssa"},
/* 1168C */ { "TAKRI LETTER GA",NULL},
/* 1168D */ { "TAKRI LETTER GHA",NULL},
/* 1168E */ { "TAKRI LETTER NGA",NULL},
/* 1168F */ { "TAKRI LETTER CA",NULL},
/* 11690 */ { "TAKRI LETTER CHA",NULL},
/* 11691 */ { "TAKRI LETTER JA",NULL},
/* 11692 */ { "TAKRI LETTER JHA",NULL},
/* 11693 */ { "TAKRI LETTER NYA",NULL},
/* 11694 */ { "TAKRI LETTER TTA",NULL},
/* 11695 */ { "TAKRI LETTER TTHA",NULL},
/* 11696 */ { "TAKRI LETTER DDA",NULL},
/* 11697 */ { "TAKRI LETTER DDHA",NULL},
/* 11698 */ { "TAKRI LETTER NNA",NULL},
/* 11699 */ { "TAKRI LETTER TA",NULL},
/* 1169A */ { "TAKRI LETTER THA",NULL},
/* 1169B */ { "TAKRI LETTER DA",NULL},
/* 1169C */ { "TAKRI LETTER DHA",NULL},
/* 1169D */ { "TAKRI LETTER NA",NULL},
/* 1169E */ { "TAKRI LETTER PA",NULL},
/* 1169F */ { "TAKRI LETTER PHA",NULL},
/* 116A0 */ { "TAKRI LETTER BA",NULL},
/* 116A1 */ { "TAKRI LETTER BHA",NULL},
/* 116A2 */ { "TAKRI LETTER MA",NULL},
/* 116A3 */ { "TAKRI LETTER YA",NULL},
/* 116A4 */ { "TAKRI LETTER RA",NULL},
/* 116A5 */ { "TAKRI LETTER LA",NULL},
/* 116A6 */ { "TAKRI LETTER VA",NULL},
/* 116A7 */ { "TAKRI LETTER SHA",NULL},
/* 116A8 */ { "TAKRI LETTER SA",NULL},
/* 116A9 */ { "TAKRI LETTER HA",NULL},
/* 116AA */ { "TAKRI LETTER RRA",NULL},
/* 116AB */ { "TAKRI SIGN ANUSVARA",NULL},
/* 116AC */ { "TAKRI SIGN VISARGA",NULL},
/* 116AD */ { "TAKRI VOWEL SIGN AA",NULL},
/* 116AE */ { "TAKRI VOWEL SIGN I",NULL},
/* 116AF */ { "TAKRI VOWEL SIGN II",NULL},
/* 116B0 */ { "TAKRI VOWEL SIGN U",NULL},
/* 116B1 */ { "TAKRI VOWEL SIGN UU",NULL},
/* 116B2 */ { "TAKRI VOWEL SIGN E",NULL},
/* 116B3 */ { "TAKRI VOWEL SIGN AI",NULL},
/* 116B4 */ { "TAKRI VOWEL SIGN O",NULL},
/* 116B5 */ { "TAKRI VOWEL SIGN AU",NULL},
/* 116B6 */ { "TAKRI SIGN VIRAMA",NULL},
/* 116B7 */ { "TAKRI SIGN NUKTA",NULL},
/* 116B8 */ { "TAKRI LETTER ARCHAIC KHA","	* used in earlier writings to denote kha"},
/* 116B9 */ { "TAKRI ABBREVIATION SIGN","	x (gurmukhi abbreviation sign - 0A76)\n"
	"	x (sharada abbreviation sign - 111C7)"},
/* 116BA */ { NULL,NULL},
/* 116BB */ { NULL,NULL},
/* 116BC */ { NULL,NULL},
/* 116BD */ { NULL,NULL},
/* 116BE */ { NULL,NULL},
/* 116BF */ { NULL,NULL},
/* 116C0 */ { "TAKRI DIGIT ZERO",NULL},
/* 116C1 */ { "TAKRI DIGIT ONE",NULL},
/* 116C2 */ { "TAKRI DIGIT TWO",NULL},
/* 116C3 */ { "TAKRI DIGIT THREE",NULL},
/* 116C4 */ { "TAKRI DIGIT FOUR",NULL},
/* 116C5 */ { "TAKRI DIGIT FIVE",NULL},
/* 116C6 */ { "TAKRI DIGIT SIX",NULL},
/* 116C7 */ { "TAKRI DIGIT SEVEN",NULL},
/* 116C8 */ { "TAKRI DIGIT EIGHT",NULL},
/* 116C9 */ { "TAKRI DIGIT NINE",NULL},
/* 116CA */ { NULL,NULL},
/* 116CB */ { NULL,NULL},
/* 116CC */ { NULL,NULL},
/* 116CD */ { NULL,NULL},
/* 116CE */ { NULL,NULL},
/* 116CF */ { NULL,NULL},
/* 116D0 */ { "MYANMAR PAO DIGIT ZERO",NULL},
/* 116D1 */ { "MYANMAR PAO DIGIT ONE",NULL},
/* 116D2 */ { "MYANMAR PAO DIGIT TWO",NULL},
/* 116D3 */ { "MYANMAR PAO DIGIT THREE",NULL},
/* 116D4 */ { "MYANMAR PAO DIGIT FOUR",NULL},
/* 116D5 */ { "MYANMAR PAO DIGIT FIVE",NULL},
/* 116D6 */ { "MYANMAR PAO DIGIT SIX",NULL},
/* 116D7 */ { "MYANMAR PAO DIGIT SEVEN",NULL},
/* 116D8 */ { "MYANMAR PAO DIGIT EIGHT",NULL},
/* 116D9 */ { "MYANMAR PAO DIGIT NINE",NULL},
/* 116DA */ { "MYANMAR EASTERN PWO KAREN DIGIT ZERO",NULL},
/* 116DB */ { "MYANMAR EASTERN PWO KAREN DIGIT ONE",NULL},
/* 116DC */ { "MYANMAR EASTERN PWO KAREN DIGIT TWO",NULL},
/* 116DD */ { "MYANMAR EASTERN PWO KAREN DIGIT THREE",NULL},
/* 116DE */ { "MYANMAR EASTERN PWO KAREN DIGIT FOUR",NULL},
/* 116DF */ { "MYANMAR EASTERN PWO KAREN DIGIT FIVE",NULL},
/* 116E0 */ { "MYANMAR EASTERN PWO KAREN DIGIT SIX",NULL},
/* 116E1 */ { "MYANMAR EASTERN PWO KAREN DIGIT SEVEN",NULL},
/* 116E2 */ { "MYANMAR EASTERN PWO KAREN DIGIT EIGHT",NULL},
/* 116E3 */ { "MYANMAR EASTERN PWO KAREN DIGIT NINE",NULL},
/* 116E4 */ { NULL,NULL},
/* 116E5 */ { NULL,NULL},
/* 116E6 */ { NULL,NULL},
/* 116E7 */ { NULL,NULL},
/* 116E8 */ { NULL,NULL},
/* 116E9 */ { NULL,NULL},
/* 116EA */ { NULL,NULL},
/* 116EB */ { NULL,NULL},
/* 116EC */ { NULL,NULL},
/* 116ED */ { NULL,NULL},
/* 116EE */ { NULL,NULL},
/* 116EF */ { NULL,NULL},
/* 116F0 */ { NULL,NULL},
/* 116F1 */ { NULL,NULL},
/* 116F2 */ { NULL,NULL},
/* 116F3 */ { NULL,NULL},
/* 116F4 */ { NULL,NULL},
/* 116F5 */ { NULL,NULL},
/* 116F6 */ { NULL,NULL},
/* 116F7 */ { NULL,NULL},
/* 116F8 */ { NULL,NULL},
/* 116F9 */ { NULL,NULL},
/* 116FA */ { NULL,NULL},
/* 116FB */ { NULL,NULL},
/* 116FC */ { NULL,NULL},
/* 116FD */ { NULL,NULL},
/* 116FE */ { NULL,NULL},
/* 116FF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_17[] = {
/* 11700 */ { "AHOM LETTER KA",NULL},
/* 11701 */ { "AHOM LETTER KHA",NULL},
/* 11702 */ { "AHOM LETTER NGA",NULL},
/* 11703 */ { "AHOM LETTER NA",NULL},
/* 11704 */ { "AHOM LETTER TA",NULL},
/* 11705 */ { "AHOM LETTER ALTERNATE TA",NULL},
/* 11706 */ { "AHOM LETTER PA",NULL},
/* 11707 */ { "AHOM LETTER PHA",NULL},
/* 11708 */ { "AHOM LETTER BA",NULL},
/* 11709 */ { "AHOM LETTER MA",NULL},
/* 1170A */ { "AHOM LETTER JA",NULL},
/* 1170B */ { "AHOM LETTER CHA",NULL},
/* 1170C */ { "AHOM LETTER THA",NULL},
/* 1170D */ { "AHOM LETTER RA",NULL},
/* 1170E */ { "AHOM LETTER LA",NULL},
/* 1170F */ { "AHOM LETTER SA",NULL},
/* 11710 */ { "AHOM LETTER NYA",NULL},
/* 11711 */ { "AHOM LETTER HA",NULL},
/* 11712 */ { "AHOM LETTER A",NULL},
/* 11713 */ { "AHOM LETTER DA",NULL},
/* 11714 */ { "AHOM LETTER DHA",NULL},
/* 11715 */ { "AHOM LETTER GA",NULL},
/* 11716 */ { "AHOM LETTER ALTERNATE GA",NULL},
/* 11717 */ { "AHOM LETTER GHA",NULL},
/* 11718 */ { "AHOM LETTER BHA",NULL},
/* 11719 */ { "AHOM LETTER JHA",NULL},
/* 1171A */ { "AHOM LETTER ALTERNATE BA",NULL},
/* 1171B */ { NULL,NULL},
/* 1171C */ { NULL,NULL},
/* 1171D */ { "AHOM CONSONANT SIGN MEDIAL LA",NULL},
/* 1171E */ { "AHOM CONSONANT SIGN MEDIAL RA",NULL},
/* 1171F */ { "AHOM CONSONANT SIGN MEDIAL LIGATING RA",NULL},
/* 11720 */ { "AHOM VOWEL SIGN A",NULL},
/* 11721 */ { "AHOM VOWEL SIGN AA",NULL},
/* 11722 */ { "AHOM VOWEL SIGN I",NULL},
/* 11723 */ { "AHOM VOWEL SIGN II",NULL},
/* 11724 */ { "AHOM VOWEL SIGN U",NULL},
/* 11725 */ { "AHOM VOWEL SIGN UU",NULL},
/* 11726 */ { "AHOM VOWEL SIGN E",NULL},
/* 11727 */ { "AHOM VOWEL SIGN AW",NULL},
/* 11728 */ { "AHOM VOWEL SIGN O",NULL},
/* 11729 */ { "AHOM VOWEL SIGN AI",NULL},
/* 1172A */ { "AHOM VOWEL SIGN AM",NULL},
/* 1172B */ { "AHOM SIGN KILLER",NULL},
/* 1172C */ { NULL,NULL},
/* 1172D */ { NULL,NULL},
/* 1172E */ { NULL,NULL},
/* 1172F */ { NULL,NULL},
/* 11730 */ { "AHOM DIGIT ZERO",NULL},
/* 11731 */ { "AHOM DIGIT ONE",NULL},
/* 11732 */ { "AHOM DIGIT TWO",NULL},
/* 11733 */ { "AHOM DIGIT THREE",NULL},
/* 11734 */ { "AHOM DIGIT FOUR",NULL},
/* 11735 */ { "AHOM DIGIT FIVE",NULL},
/* 11736 */ { "AHOM DIGIT SIX",NULL},
/* 11737 */ { "AHOM DIGIT SEVEN",NULL},
/* 11738 */ { "AHOM DIGIT EIGHT",NULL},
/* 11739 */ { "AHOM DIGIT NINE",NULL},
/* 1173A */ { "AHOM NUMBER TEN",NULL},
/* 1173B */ { "AHOM NUMBER TWENTY",NULL},
/* 1173C */ { "AHOM SIGN SMALL SECTION",NULL},
/* 1173D */ { "AHOM SIGN SECTION",NULL},
/* 1173E */ { "AHOM SIGN RULAI",NULL},
/* 1173F */ { "AHOM SYMBOL VI",NULL},
/* 11740 */ { "AHOM LETTER CA",NULL},
/* 11741 */ { "AHOM LETTER TTA",NULL},
/* 11742 */ { "AHOM LETTER TTHA",NULL},
/* 11743 */ { "AHOM LETTER DDA",NULL},
/* 11744 */ { "AHOM LETTER DDHA",NULL},
/* 11745 */ { "AHOM LETTER NNA",NULL},
/* 11746 */ { "AHOM LETTER LLA",NULL},
/* 11747 */ { NULL,NULL},
/* 11748 */ { NULL,NULL},
/* 11749 */ { NULL,NULL},
/* 1174A */ { NULL,NULL},
/* 1174B */ { NULL,NULL},
/* 1174C */ { NULL,NULL},
/* 1174D */ { NULL,NULL},
/* 1174E */ { NULL,NULL},
/* 1174F */ { NULL,NULL},
/* 11750 */ { NULL,NULL},
/* 11751 */ { NULL,NULL},
/* 11752 */ { NULL,NULL},
/* 11753 */ { NULL,NULL},
/* 11754 */ { NULL,NULL},
/* 11755 */ { NULL,NULL},
/* 11756 */ { NULL,NULL},
/* 11757 */ { NULL,NULL},
/* 11758 */ { NULL,NULL},
/* 11759 */ { NULL,NULL},
/* 1175A */ { NULL,NULL},
/* 1175B */ { NULL,NULL},
/* 1175C */ { NULL,NULL},
/* 1175D */ { NULL,NULL},
/* 1175E */ { NULL,NULL},
/* 1175F */ { NULL,NULL},
/* 11760 */ { NULL,NULL},
/* 11761 */ { NULL,NULL},
/* 11762 */ { NULL,NULL},
/* 11763 */ { NULL,NULL},
/* 11764 */ { NULL,NULL},
/* 11765 */ { NULL,NULL},
/* 11766 */ { NULL,NULL},
/* 11767 */ { NULL,NULL},
/* 11768 */ { NULL,NULL},
/* 11769 */ { NULL,NULL},
/* 1176A */ { NULL,NULL},
/* 1176B */ { NULL,NULL},
/* 1176C */ { NULL,NULL},
/* 1176D */ { NULL,NULL},
/* 1176E */ { NULL,NULL},
/* 1176F */ { NULL,NULL},
/* 11770 */ { NULL,NULL},
/* 11771 */ { NULL,NULL},
/* 11772 */ { NULL,NULL},
/* 11773 */ { NULL,NULL},
/* 11774 */ { NULL,NULL},
/* 11775 */ { NULL,NULL},
/* 11776 */ { NULL,NULL},
/* 11777 */ { NULL,NULL},
/* 11778 */ { NULL,NULL},
/* 11779 */ { NULL,NULL},
/* 1177A */ { NULL,NULL},
/* 1177B */ { NULL,NULL},
/* 1177C */ { NULL,NULL},
/* 1177D */ { NULL,NULL},
/* 1177E */ { NULL,NULL},
/* 1177F */ { NULL,NULL},
/* 11780 */ { NULL,NULL},
/* 11781 */ { NULL,NULL},
/* 11782 */ { NULL,NULL},
/* 11783 */ { NULL,NULL},
/* 11784 */ { NULL,NULL},
/* 11785 */ { NULL,NULL},
/* 11786 */ { NULL,NULL},
/* 11787 */ { NULL,NULL},
/* 11788 */ { NULL,NULL},
/* 11789 */ { NULL,NULL},
/* 1178A */ { NULL,NULL},
/* 1178B */ { NULL,NULL},
/* 1178C */ { NULL,NULL},
/* 1178D */ { NULL,NULL},
/* 1178E */ { NULL,NULL},
/* 1178F */ { NULL,NULL},
/* 11790 */ { NULL,NULL},
/* 11791 */ { NULL,NULL},
/* 11792 */ { NULL,NULL},
/* 11793 */ { NULL,NULL},
/* 11794 */ { NULL,NULL},
/* 11795 */ { NULL,NULL},
/* 11796 */ { NULL,NULL},
/* 11797 */ { NULL,NULL},
/* 11798 */ { NULL,NULL},
/* 11799 */ { NULL,NULL},
/* 1179A */ { NULL,NULL},
/* 1179B */ { NULL,NULL},
/* 1179C */ { NULL,NULL},
/* 1179D */ { NULL,NULL},
/* 1179E */ { NULL,NULL},
/* 1179F */ { NULL,NULL},
/* 117A0 */ { NULL,NULL},
/* 117A1 */ { NULL,NULL},
/* 117A2 */ { NULL,NULL},
/* 117A3 */ { NULL,NULL},
/* 117A4 */ { NULL,NULL},
/* 117A5 */ { NULL,NULL},
/* 117A6 */ { NULL,NULL},
/* 117A7 */ { NULL,NULL},
/* 117A8 */ { NULL,NULL},
/* 117A9 */ { NULL,NULL},
/* 117AA */ { NULL,NULL},
/* 117AB */ { NULL,NULL},
/* 117AC */ { NULL,NULL},
/* 117AD */ { NULL,NULL},
/* 117AE */ { NULL,NULL},
/* 117AF */ { NULL,NULL},
/* 117B0 */ { NULL,NULL},
/* 117B1 */ { NULL,NULL},
/* 117B2 */ { NULL,NULL},
/* 117B3 */ { NULL,NULL},
/* 117B4 */ { NULL,NULL},
/* 117B5 */ { NULL,NULL},
/* 117B6 */ { NULL,NULL},
/* 117B7 */ { NULL,NULL},
/* 117B8 */ { NULL,NULL},
/* 117B9 */ { NULL,NULL},
/* 117BA */ { NULL,NULL},
/* 117BB */ { NULL,NULL},
/* 117BC */ { NULL,NULL},
/* 117BD */ { NULL,NULL},
/* 117BE */ { NULL,NULL},
/* 117BF */ { NULL,NULL},
/* 117C0 */ { NULL,NULL},
/* 117C1 */ { NULL,NULL},
/* 117C2 */ { NULL,NULL},
/* 117C3 */ { NULL,NULL},
/* 117C4 */ { NULL,NULL},
/* 117C5 */ { NULL,NULL},
/* 117C6 */ { NULL,NULL},
/* 117C7 */ { NULL,NULL},
/* 117C8 */ { NULL,NULL},
/* 117C9 */ { NULL,NULL},
/* 117CA */ { NULL,NULL},
/* 117CB */ { NULL,NULL},
/* 117CC */ { NULL,NULL},
/* 117CD */ { NULL,NULL},
/* 117CE */ { NULL,NULL},
/* 117CF */ { NULL,NULL},
/* 117D0 */ { NULL,NULL},
/* 117D1 */ { NULL,NULL},
/* 117D2 */ { NULL,NULL},
/* 117D3 */ { NULL,NULL},
/* 117D4 */ { NULL,NULL},
/* 117D5 */ { NULL,NULL},
/* 117D6 */ { NULL,NULL},
/* 117D7 */ { NULL,NULL},
/* 117D8 */ { NULL,NULL},
/* 117D9 */ { NULL,NULL},
/* 117DA */ { NULL,NULL},
/* 117DB */ { NULL,NULL},
/* 117DC */ { NULL,NULL},
/* 117DD */ { NULL,NULL},
/* 117DE */ { NULL,NULL},
/* 117DF */ { NULL,NULL},
/* 117E0 */ { NULL,NULL},
/* 117E1 */ { NULL,NULL},
/* 117E2 */ { NULL,NULL},
/* 117E3 */ { NULL,NULL},
/* 117E4 */ { NULL,NULL},
/* 117E5 */ { NULL,NULL},
/* 117E6 */ { NULL,NULL},
/* 117E7 */ { NULL,NULL},
/* 117E8 */ { NULL,NULL},
/* 117E9 */ { NULL,NULL},
/* 117EA */ { NULL,NULL},
/* 117EB */ { NULL,NULL},
/* 117EC */ { NULL,NULL},
/* 117ED */ { NULL,NULL},
/* 117EE */ { NULL,NULL},
/* 117EF */ { NULL,NULL},
/* 117F0 */ { NULL,NULL},
/* 117F1 */ { NULL,NULL},
/* 117F2 */ { NULL,NULL},
/* 117F3 */ { NULL,NULL},
/* 117F4 */ { NULL,NULL},
/* 117F5 */ { NULL,NULL},
/* 117F6 */ { NULL,NULL},
/* 117F7 */ { NULL,NULL},
/* 117F8 */ { NULL,NULL},
/* 117F9 */ { NULL,NULL},
/* 117FA */ { NULL,NULL},
/* 117FB */ { NULL,NULL},
/* 117FC */ { NULL,NULL},
/* 117FD */ { NULL,NULL},
/* 117FE */ { NULL,NULL},
/* 117FF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_18[] = {
/* 11800 */ { "DOGRA LETTER A",NULL},
/* 11801 */ { "DOGRA LETTER AA",NULL},
/* 11802 */ { "DOGRA LETTER I",NULL},
/* 11803 */ { "DOGRA LETTER II",NULL},
/* 11804 */ { "DOGRA LETTER U",NULL},
/* 11805 */ { "DOGRA LETTER UU",NULL},
/* 11806 */ { "DOGRA LETTER E",NULL},
/* 11807 */ { "DOGRA LETTER AI",NULL},
/* 11808 */ { "DOGRA LETTER O",NULL},
/* 11809 */ { "DOGRA LETTER AU",NULL},
/* 1180A */ { "DOGRA LETTER KA",NULL},
/* 1180B */ { "DOGRA LETTER KHA",NULL},
/* 1180C */ { "DOGRA LETTER GA",NULL},
/* 1180D */ { "DOGRA LETTER GHA",NULL},
/* 1180E */ { "DOGRA LETTER NGA",NULL},
/* 1180F */ { "DOGRA LETTER CA",NULL},
/* 11810 */ { "DOGRA LETTER CHA",NULL},
/* 11811 */ { "DOGRA LETTER JA",NULL},
/* 11812 */ { "DOGRA LETTER JHA",NULL},
/* 11813 */ { "DOGRA LETTER NYA",NULL},
/* 11814 */ { "DOGRA LETTER TTA",NULL},
/* 11815 */ { "DOGRA LETTER TTHA",NULL},
/* 11816 */ { "DOGRA LETTER DDA",NULL},
/* 11817 */ { "DOGRA LETTER DDHA",NULL},
/* 11818 */ { "DOGRA LETTER NNA",NULL},
/* 11819 */ { "DOGRA LETTER TA",NULL},
/* 1181A */ { "DOGRA LETTER THA",NULL},
/* 1181B */ { "DOGRA LETTER DA",NULL},
/* 1181C */ { "DOGRA LETTER DHA",NULL},
/* 1181D */ { "DOGRA LETTER NA",NULL},
/* 1181E */ { "DOGRA LETTER PA",NULL},
/* 1181F */ { "DOGRA LETTER PHA",NULL},
/* 11820 */ { "DOGRA LETTER BA",NULL},
/* 11821 */ { "DOGRA LETTER BHA",NULL},
/* 11822 */ { "DOGRA LETTER MA",NULL},
/* 11823 */ { "DOGRA LETTER YA",NULL},
/* 11824 */ { "DOGRA LETTER RA",NULL},
/* 11825 */ { "DOGRA LETTER LA",NULL},
/* 11826 */ { "DOGRA LETTER VA",NULL},
/* 11827 */ { "DOGRA LETTER SHA",NULL},
/* 11828 */ { "DOGRA LETTER SSA",NULL},
/* 11829 */ { "DOGRA LETTER SA",NULL},
/* 1182A */ { "DOGRA LETTER HA",NULL},
/* 1182B */ { "DOGRA LETTER RRA",NULL},
/* 1182C */ { "DOGRA VOWEL SIGN AA",NULL},
/* 1182D */ { "DOGRA VOWEL SIGN I",NULL},
/* 1182E */ { "DOGRA VOWEL SIGN II",NULL},
/* 1182F */ { "DOGRA VOWEL SIGN U",NULL},
/* 11830 */ { "DOGRA VOWEL SIGN UU",NULL},
/* 11831 */ { "DOGRA VOWEL SIGN VOCALIC R",NULL},
/* 11832 */ { "DOGRA VOWEL SIGN VOCALIC RR",NULL},
/* 11833 */ { "DOGRA VOWEL SIGN E",NULL},
/* 11834 */ { "DOGRA VOWEL SIGN AI",NULL},
/* 11835 */ { "DOGRA VOWEL SIGN O",NULL},
/* 11836 */ { "DOGRA VOWEL SIGN AU",NULL},
/* 11837 */ { "DOGRA SIGN ANUSVARA",NULL},
/* 11838 */ { "DOGRA SIGN VISARGA",NULL},
/* 11839 */ { "DOGRA SIGN VIRAMA",NULL},
/* 1183A */ { "DOGRA SIGN NUKTA",NULL},
/* 1183B */ { "DOGRA ABBREVIATION SIGN",NULL},
/* 1183C */ { NULL,NULL},
/* 1183D */ { NULL,NULL},
/* 1183E */ { NULL,NULL},
/* 1183F */ { NULL,NULL},
/* 11840 */ { NULL,NULL},
/* 11841 */ { NULL,NULL},
/* 11842 */ { NULL,NULL},
/* 11843 */ { NULL,NULL},
/* 11844 */ { NULL,NULL},
/* 11845 */ { NULL,NULL},
/* 11846 */ { NULL,NULL},
/* 11847 */ { NULL,NULL},
/* 11848 */ { NULL,NULL},
/* 11849 */ { NULL,NULL},
/* 1184A */ { NULL,NULL},
/* 1184B */ { NULL,NULL},
/* 1184C */ { NULL,NULL},
/* 1184D */ { NULL,NULL},
/* 1184E */ { NULL,NULL},
/* 1184F */ { NULL,NULL},
/* 11850 */ { NULL,NULL},
/* 11851 */ { NULL,NULL},
/* 11852 */ { NULL,NULL},
/* 11853 */ { NULL,NULL},
/* 11854 */ { NULL,NULL},
/* 11855 */ { NULL,NULL},
/* 11856 */ { NULL,NULL},
/* 11857 */ { NULL,NULL},
/* 11858 */ { NULL,NULL},
/* 11859 */ { NULL,NULL},
/* 1185A */ { NULL,NULL},
/* 1185B */ { NULL,NULL},
/* 1185C */ { NULL,NULL},
/* 1185D */ { NULL,NULL},
/* 1185E */ { NULL,NULL},
/* 1185F */ { NULL,NULL},
/* 11860 */ { NULL,NULL},
/* 11861 */ { NULL,NULL},
/* 11862 */ { NULL,NULL},
/* 11863 */ { NULL,NULL},
/* 11864 */ { NULL,NULL},
/* 11865 */ { NULL,NULL},
/* 11866 */ { NULL,NULL},
/* 11867 */ { NULL,NULL},
/* 11868 */ { NULL,NULL},
/* 11869 */ { NULL,NULL},
/* 1186A */ { NULL,NULL},
/* 1186B */ { NULL,NULL},
/* 1186C */ { NULL,NULL},
/* 1186D */ { NULL,NULL},
/* 1186E */ { NULL,NULL},
/* 1186F */ { NULL,NULL},
/* 11870 */ { NULL,NULL},
/* 11871 */ { NULL,NULL},
/* 11872 */ { NULL,NULL},
/* 11873 */ { NULL,NULL},
/* 11874 */ { NULL,NULL},
/* 11875 */ { NULL,NULL},
/* 11876 */ { NULL,NULL},
/* 11877 */ { NULL,NULL},
/* 11878 */ { NULL,NULL},
/* 11879 */ { NULL,NULL},
/* 1187A */ { NULL,NULL},
/* 1187B */ { NULL,NULL},
/* 1187C */ { NULL,NULL},
/* 1187D */ { NULL,NULL},
/* 1187E */ { NULL,NULL},
/* 1187F */ { NULL,NULL},
/* 11880 */ { NULL,NULL},
/* 11881 */ { NULL,NULL},
/* 11882 */ { NULL,NULL},
/* 11883 */ { NULL,NULL},
/* 11884 */ { NULL,NULL},
/* 11885 */ { NULL,NULL},
/* 11886 */ { NULL,NULL},
/* 11887 */ { NULL,NULL},
/* 11888 */ { NULL,NULL},
/* 11889 */ { NULL,NULL},
/* 1188A */ { NULL,NULL},
/* 1188B */ { NULL,NULL},
/* 1188C */ { NULL,NULL},
/* 1188D */ { NULL,NULL},
/* 1188E */ { NULL,NULL},
/* 1188F */ { NULL,NULL},
/* 11890 */ { NULL,NULL},
/* 11891 */ { NULL,NULL},
/* 11892 */ { NULL,NULL},
/* 11893 */ { NULL,NULL},
/* 11894 */ { NULL,NULL},
/* 11895 */ { NULL,NULL},
/* 11896 */ { NULL,NULL},
/* 11897 */ { NULL,NULL},
/* 11898 */ { NULL,NULL},
/* 11899 */ { NULL,NULL},
/* 1189A */ { NULL,NULL},
/* 1189B */ { NULL,NULL},
/* 1189C */ { NULL,NULL},
/* 1189D */ { NULL,NULL},
/* 1189E */ { NULL,NULL},
/* 1189F */ { NULL,NULL},
/* 118A0 */ { "WARANG CITI CAPITAL LETTER NGAA","	* functions as an anusvara"},
/* 118A1 */ { "WARANG CITI CAPITAL LETTER A",NULL},
/* 118A2 */ { "WARANG CITI CAPITAL LETTER WI",NULL},
/* 118A3 */ { "WARANG CITI CAPITAL LETTER YU",NULL},
/* 118A4 */ { "WARANG CITI CAPITAL LETTER YA",NULL},
/* 118A5 */ { "WARANG CITI CAPITAL LETTER YO",NULL},
/* 118A6 */ { "WARANG CITI CAPITAL LETTER II",NULL},
/* 118A7 */ { "WARANG CITI CAPITAL LETTER UU",NULL},
/* 118A8 */ { "WARANG CITI CAPITAL LETTER E",NULL},
/* 118A9 */ { "WARANG CITI CAPITAL LETTER O",NULL},
/* 118AA */ { "WARANG CITI CAPITAL LETTER ANG",NULL},
/* 118AB */ { "WARANG CITI CAPITAL LETTER GA",NULL},
/* 118AC */ { "WARANG CITI CAPITAL LETTER KO",NULL},
/* 118AD */ { "WARANG CITI CAPITAL LETTER ENY",NULL},
/* 118AE */ { "WARANG CITI CAPITAL LETTER YUJ",NULL},
/* 118AF */ { "WARANG CITI CAPITAL LETTER UC",NULL},
/* 118B0 */ { "WARANG CITI CAPITAL LETTER ENN",NULL},
/* 118B1 */ { "WARANG CITI CAPITAL LETTER ODD",NULL},
/* 118B2 */ { "WARANG CITI CAPITAL LETTER TTE",NULL},
/* 118B3 */ { "WARANG CITI CAPITAL LETTER NUNG",NULL},
/* 118B4 */ { "WARANG CITI CAPITAL LETTER DA",NULL},
/* 118B5 */ { "WARANG CITI CAPITAL LETTER AT",NULL},
/* 118B6 */ { "WARANG CITI CAPITAL LETTER AM",NULL},
/* 118B7 */ { "WARANG CITI CAPITAL LETTER BU",NULL},
/* 118B8 */ { "WARANG CITI CAPITAL LETTER PU",NULL},
/* 118B9 */ { "WARANG CITI CAPITAL LETTER HIYO",NULL},
/* 118BA */ { "WARANG CITI CAPITAL LETTER HOLO",NULL},
/* 118BB */ { "WARANG CITI CAPITAL LETTER HORR",NULL},
/* 118BC */ { "WARANG CITI CAPITAL LETTER HAR",NULL},
/* 118BD */ { "WARANG CITI CAPITAL LETTER SSUU",NULL},
/* 118BE */ { "WARANG CITI CAPITAL LETTER SII",NULL},
/* 118BF */ { "WARANG CITI CAPITAL LETTER VIYO",NULL},
/* 118C0 */ { "WARANG CITI SMALL LETTER NGAA",NULL},
/* 118C1 */ { "WARANG CITI SMALL LETTER A",NULL},
/* 118C2 */ { "WARANG CITI SMALL LETTER WI",NULL},
/* 118C3 */ { "WARANG CITI SMALL LETTER YU",NULL},
/* 118C4 */ { "WARANG CITI SMALL LETTER YA",NULL},
/* 118C5 */ { "WARANG CITI SMALL LETTER YO",NULL},
/* 118C6 */ { "WARANG CITI SMALL LETTER II",NULL},
/* 118C7 */ { "WARANG CITI SMALL LETTER UU",NULL},
/* 118C8 */ { "WARANG CITI SMALL LETTER E",NULL},
/* 118C9 */ { "WARANG CITI SMALL LETTER O",NULL},
/* 118CA */ { "WARANG CITI SMALL LETTER ANG",NULL},
/* 118CB */ { "WARANG CITI SMALL LETTER GA",NULL},
/* 118CC */ { "WARANG CITI SMALL LETTER KO",NULL},
/* 118CD */ { "WARANG CITI SMALL LETTER ENY",NULL},
/* 118CE */ { "WARANG CITI SMALL LETTER YUJ",NULL},
/* 118CF */ { "WARANG CITI SMALL LETTER UC",NULL},
/* 118D0 */ { "WARANG CITI SMALL LETTER ENN",NULL},
/* 118D1 */ { "WARANG CITI SMALL LETTER ODD",NULL},
/* 118D2 */ { "WARANG CITI SMALL LETTER TTE",NULL},
/* 118D3 */ { "WARANG CITI SMALL LETTER NUNG",NULL},
/* 118D4 */ { "WARANG CITI SMALL LETTER DA",NULL},
/* 118D5 */ { "WARANG CITI SMALL LETTER AT",NULL},
/* 118D6 */ { "WARANG CITI SMALL LETTER AM",NULL},
/* 118D7 */ { "WARANG CITI SMALL LETTER BU",NULL},
/* 118D8 */ { "WARANG CITI SMALL LETTER PU",NULL},
/* 118D9 */ { "WARANG CITI SMALL LETTER HIYO",NULL},
/* 118DA */ { "WARANG CITI SMALL LETTER HOLO",NULL},
/* 118DB */ { "WARANG CITI SMALL LETTER HORR",NULL},
/* 118DC */ { "WARANG CITI SMALL LETTER HAR",NULL},
/* 118DD */ { "WARANG CITI SMALL LETTER SSUU",NULL},
/* 118DE */ { "WARANG CITI SMALL LETTER SII",NULL},
/* 118DF */ { "WARANG CITI SMALL LETTER VIYO",NULL},
/* 118E0 */ { "WARANG CITI DIGIT ZERO",NULL},
/* 118E1 */ { "WARANG CITI DIGIT ONE",NULL},
/* 118E2 */ { "WARANG CITI DIGIT TWO",NULL},
/* 118E3 */ { "WARANG CITI DIGIT THREE",NULL},
/* 118E4 */ { "WARANG CITI DIGIT FOUR",NULL},
/* 118E5 */ { "WARANG CITI DIGIT FIVE",NULL},
/* 118E6 */ { "WARANG CITI DIGIT SIX",NULL},
/* 118E7 */ { "WARANG CITI DIGIT SEVEN",NULL},
/* 118E8 */ { "WARANG CITI DIGIT EIGHT",NULL},
/* 118E9 */ { "WARANG CITI DIGIT NINE",NULL},
/* 118EA */ { "WARANG CITI NUMBER TEN",NULL},
/* 118EB */ { "WARANG CITI NUMBER TWENTY",NULL},
/* 118EC */ { "WARANG CITI NUMBER THIRTY",NULL},
/* 118ED */ { "WARANG CITI NUMBER FORTY",NULL},
/* 118EE */ { "WARANG CITI NUMBER FIFTY",NULL},
/* 118EF */ { "WARANG CITI NUMBER SIXTY",NULL},
/* 118F0 */ { "WARANG CITI NUMBER SEVENTY",NULL},
/* 118F1 */ { "WARANG CITI NUMBER EIGHTY",NULL},
/* 118F2 */ { "WARANG CITI NUMBER NINETY",NULL},
/* 118F3 */ { NULL,NULL},
/* 118F4 */ { NULL,NULL},
/* 118F5 */ { NULL,NULL},
/* 118F6 */ { NULL,NULL},
/* 118F7 */ { NULL,NULL},
/* 118F8 */ { NULL,NULL},
/* 118F9 */ { NULL,NULL},
/* 118FA */ { NULL,NULL},
/* 118FB */ { NULL,NULL},
/* 118FC */ { NULL,NULL},
/* 118FD */ { NULL,NULL},
/* 118FE */ { NULL,NULL},
/* 118FF */ { "WARANG CITI OM",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_19[] = {
/* 11900 */ { "DIVES AKURU LETTER A",NULL},
/* 11901 */ { "DIVES AKURU LETTER AA",NULL},
/* 11902 */ { "DIVES AKURU LETTER I",NULL},
/* 11903 */ { "DIVES AKURU LETTER II",NULL},
/* 11904 */ { "DIVES AKURU LETTER U",NULL},
/* 11905 */ { "DIVES AKURU LETTER UU",NULL},
/* 11906 */ { "DIVES AKURU LETTER E",NULL},
/* 11907 */ { NULL,NULL},
/* 11908 */ { NULL,NULL},
/* 11909 */ { "DIVES AKURU LETTER O",NULL},
/* 1190A */ { NULL,NULL},
/* 1190B */ { NULL,NULL},
/* 1190C */ { "DIVES AKURU LETTER KA",NULL},
/* 1190D */ { "DIVES AKURU LETTER KHA",NULL},
/* 1190E */ { "DIVES AKURU LETTER GA",NULL},
/* 1190F */ { "DIVES AKURU LETTER GHA",NULL},
/* 11910 */ { "DIVES AKURU LETTER NGA",NULL},
/* 11911 */ { "DIVES AKURU LETTER CA",NULL},
/* 11912 */ { "DIVES AKURU LETTER CHA",NULL},
/* 11913 */ { "DIVES AKURU LETTER JA",NULL},
/* 11914 */ { NULL,NULL},
/* 11915 */ { "DIVES AKURU LETTER NYA",NULL},
/* 11916 */ { "DIVES AKURU LETTER TTA",NULL},
/* 11917 */ { NULL,NULL},
/* 11918 */ { "DIVES AKURU LETTER DDA",NULL},
/* 11919 */ { "DIVES AKURU LETTER DDHA",NULL},
/* 1191A */ { "DIVES AKURU LETTER NNA",NULL},
/* 1191B */ { "DIVES AKURU LETTER TA",NULL},
/* 1191C */ { "DIVES AKURU LETTER THA",NULL},
/* 1191D */ { "DIVES AKURU LETTER DA",NULL},
/* 1191E */ { "DIVES AKURU LETTER DHA",NULL},
/* 1191F */ { "DIVES AKURU LETTER NA",NULL},
/* 11920 */ { "DIVES AKURU LETTER PA",NULL},
/* 11921 */ { "DIVES AKURU LETTER PHA",NULL},
/* 11922 */ { "DIVES AKURU LETTER BA",NULL},
/* 11923 */ { "DIVES AKURU LETTER BHA",NULL},
/* 11924 */ { "DIVES AKURU LETTER MA",NULL},
/* 11925 */ { "DIVES AKURU LETTER YA","	* also used as a vowel carrier"},
/* 11926 */ { "DIVES AKURU LETTER YYA",NULL},
/* 11927 */ { "DIVES AKURU LETTER RA",NULL},
/* 11928 */ { "DIVES AKURU LETTER LA",NULL},
/* 11929 */ { "DIVES AKURU LETTER VA",NULL},
/* 1192A */ { "DIVES AKURU LETTER SHA",NULL},
/* 1192B */ { "DIVES AKURU LETTER SSA",NULL},
/* 1192C */ { "DIVES AKURU LETTER SA",NULL},
/* 1192D */ { "DIVES AKURU LETTER HA",NULL},
/* 1192E */ { "DIVES AKURU LETTER LLA",NULL},
/* 1192F */ { "DIVES AKURU LETTER ZA",NULL},
/* 11930 */ { "DIVES AKURU VOWEL SIGN AA",NULL},
/* 11931 */ { "DIVES AKURU VOWEL SIGN I",NULL},
/* 11932 */ { "DIVES AKURU VOWEL SIGN II",NULL},
/* 11933 */ { "DIVES AKURU VOWEL SIGN U",NULL},
/* 11934 */ { "DIVES AKURU VOWEL SIGN UU",NULL},
/* 11935 */ { "DIVES AKURU VOWEL SIGN E",NULL},
/* 11936 */ { NULL,NULL},
/* 11937 */ { "DIVES AKURU VOWEL SIGN AI",NULL},
/* 11938 */ { "DIVES AKURU VOWEL SIGN O","	: 11935 11930"},
/* 11939 */ { NULL,NULL},
/* 1193A */ { NULL,NULL},
/* 1193B */ { "DIVES AKURU SIGN ANUSVARA",NULL},
/* 1193C */ { "DIVES AKURU SIGN CANDRABINDU",NULL},
/* 1193D */ { "DIVES AKURU SIGN HALANTA","	= sukun\n"
	"	* a killer, silences the inherent vowel"},
/* 1193E */ { "DIVES AKURU VIRAMA","	* used for conjunct production\n"
	"	* also used for producing a ligature of devowelized consonant and independent vowel letter"},
/* 1193F */ { "DIVES AKURU PREFIXED NASAL SIGN","	* used for cluster-initial homorganic nasal"},
/* 11940 */ { "DIVES AKURU MEDIAL YA","	* used for non-initial ya in conjuncts"},
/* 11941 */ { "DIVES AKURU INITIAL RA","	= repha\n"
	"	* used for initial ra in conjuncts"},
/* 11942 */ { "DIVES AKURU MEDIAL RA","	* used for non-initial ra in conjuncts"},
/* 11943 */ { "DIVES AKURU SIGN NUKTA","	* modern diacritic used for extending the alphabet"},
/* 11944 */ { "DIVES AKURU DOUBLE DANDA",NULL},
/* 11945 */ { "DIVES AKURU GAP FILLER",NULL},
/* 11946 */ { "DIVES AKURU END OF TEXT MARK",NULL},
/* 11947 */ { NULL,NULL},
/* 11948 */ { NULL,NULL},
/* 11949 */ { NULL,NULL},
/* 1194A */ { NULL,NULL},
/* 1194B */ { NULL,NULL},
/* 1194C */ { NULL,NULL},
/* 1194D */ { NULL,NULL},
/* 1194E */ { NULL,NULL},
/* 1194F */ { NULL,NULL},
/* 11950 */ { "DIVES AKURU DIGIT ZERO",NULL},
/* 11951 */ { "DIVES AKURU DIGIT ONE",NULL},
/* 11952 */ { "DIVES AKURU DIGIT TWO",NULL},
/* 11953 */ { "DIVES AKURU DIGIT THREE",NULL},
/* 11954 */ { "DIVES AKURU DIGIT FOUR",NULL},
/* 11955 */ { "DIVES AKURU DIGIT FIVE",NULL},
/* 11956 */ { "DIVES AKURU DIGIT SIX",NULL},
/* 11957 */ { "DIVES AKURU DIGIT SEVEN",NULL},
/* 11958 */ { "DIVES AKURU DIGIT EIGHT",NULL},
/* 11959 */ { "DIVES AKURU DIGIT NINE",NULL},
/* 1195A */ { NULL,NULL},
/* 1195B */ { NULL,NULL},
/* 1195C */ { NULL,NULL},
/* 1195D */ { NULL,NULL},
/* 1195E */ { NULL,NULL},
/* 1195F */ { NULL,NULL},
/* 11960 */ { NULL,NULL},
/* 11961 */ { NULL,NULL},
/* 11962 */ { NULL,NULL},
/* 11963 */ { NULL,NULL},
/* 11964 */ { NULL,NULL},
/* 11965 */ { NULL,NULL},
/* 11966 */ { NULL,NULL},
/* 11967 */ { NULL,NULL},
/* 11968 */ { NULL,NULL},
/* 11969 */ { NULL,NULL},
/* 1196A */ { NULL,NULL},
/* 1196B */ { NULL,NULL},
/* 1196C */ { NULL,NULL},
/* 1196D */ { NULL,NULL},
/* 1196E */ { NULL,NULL},
/* 1196F */ { NULL,NULL},
/* 11970 */ { NULL,NULL},
/* 11971 */ { NULL,NULL},
/* 11972 */ { NULL,NULL},
/* 11973 */ { NULL,NULL},
/* 11974 */ { NULL,NULL},
/* 11975 */ { NULL,NULL},
/* 11976 */ { NULL,NULL},
/* 11977 */ { NULL,NULL},
/* 11978 */ { NULL,NULL},
/* 11979 */ { NULL,NULL},
/* 1197A */ { NULL,NULL},
/* 1197B */ { NULL,NULL},
/* 1197C */ { NULL,NULL},
/* 1197D */ { NULL,NULL},
/* 1197E */ { NULL,NULL},
/* 1197F */ { NULL,NULL},
/* 11980 */ { NULL,NULL},
/* 11981 */ { NULL,NULL},
/* 11982 */ { NULL,NULL},
/* 11983 */ { NULL,NULL},
/* 11984 */ { NULL,NULL},
/* 11985 */ { NULL,NULL},
/* 11986 */ { NULL,NULL},
/* 11987 */ { NULL,NULL},
/* 11988 */ { NULL,NULL},
/* 11989 */ { NULL,NULL},
/* 1198A */ { NULL,NULL},
/* 1198B */ { NULL,NULL},
/* 1198C */ { NULL,NULL},
/* 1198D */ { NULL,NULL},
/* 1198E */ { NULL,NULL},
/* 1198F */ { NULL,NULL},
/* 11990 */ { NULL,NULL},
/* 11991 */ { NULL,NULL},
/* 11992 */ { NULL,NULL},
/* 11993 */ { NULL,NULL},
/* 11994 */ { NULL,NULL},
/* 11995 */ { NULL,NULL},
/* 11996 */ { NULL,NULL},
/* 11997 */ { NULL,NULL},
/* 11998 */ { NULL,NULL},
/* 11999 */ { NULL,NULL},
/* 1199A */ { NULL,NULL},
/* 1199B */ { NULL,NULL},
/* 1199C */ { NULL,NULL},
/* 1199D */ { NULL,NULL},
/* 1199E */ { NULL,NULL},
/* 1199F */ { NULL,NULL},
/* 119A0 */ { "NANDINAGARI LETTER A",NULL},
/* 119A1 */ { "NANDINAGARI LETTER AA",NULL},
/* 119A2 */ { "NANDINAGARI LETTER I",NULL},
/* 119A3 */ { "NANDINAGARI LETTER II",NULL},
/* 119A4 */ { "NANDINAGARI LETTER U",NULL},
/* 119A5 */ { "NANDINAGARI LETTER UU",NULL},
/* 119A6 */ { "NANDINAGARI LETTER VOCALIC R",NULL},
/* 119A7 */ { "NANDINAGARI LETTER VOCALIC RR",NULL},
/* 119A8 */ { NULL,NULL},
/* 119A9 */ { NULL,NULL},
/* 119AA */ { "NANDINAGARI LETTER E",NULL},
/* 119AB */ { "NANDINAGARI LETTER AI",NULL},
/* 119AC */ { "NANDINAGARI LETTER O",NULL},
/* 119AD */ { "NANDINAGARI LETTER AU",NULL},
/* 119AE */ { "NANDINAGARI LETTER KA",NULL},
/* 119AF */ { "NANDINAGARI LETTER KHA",NULL},
/* 119B0 */ { "NANDINAGARI LETTER GA",NULL},
/* 119B1 */ { "NANDINAGARI LETTER GHA",NULL},
/* 119B2 */ { "NANDINAGARI LETTER NGA",NULL},
/* 119B3 */ { "NANDINAGARI LETTER CA",NULL},
/* 119B4 */ { "NANDINAGARI LETTER CHA",NULL},
/* 119B5 */ { "NANDINAGARI LETTER JA",NULL},
/* 119B6 */ { "NANDINAGARI LETTER JHA",NULL},
/* 119B7 */ { "NANDINAGARI LETTER NYA",NULL},
/* 119B8 */ { "NANDINAGARI LETTER TTA",NULL},
/* 119B9 */ { "NANDINAGARI LETTER TTHA",NULL},
/* 119BA */ { "NANDINAGARI LETTER DDA",NULL},
/* 119BB */ { "NANDINAGARI LETTER DDHA",NULL},
/* 119BC */ { "NANDINAGARI LETTER NNA",NULL},
/* 119BD */ { "NANDINAGARI LETTER TA",NULL},
/* 119BE */ { "NANDINAGARI LETTER THA",NULL},
/* 119BF */ { "NANDINAGARI LETTER DA",NULL},
/* 119C0 */ { "NANDINAGARI LETTER DHA",NULL},
/* 119C1 */ { "NANDINAGARI LETTER NA",NULL},
/* 119C2 */ { "NANDINAGARI LETTER PA",NULL},
/* 119C3 */ { "NANDINAGARI LETTER PHA",NULL},
/* 119C4 */ { "NANDINAGARI LETTER BA",NULL},
/* 119C5 */ { "NANDINAGARI LETTER BHA",NULL},
/* 119C6 */ { "NANDINAGARI LETTER MA",NULL},
/* 119C7 */ { "NANDINAGARI LETTER YA",NULL},
/* 119C8 */ { "NANDINAGARI LETTER RA",NULL},
/* 119C9 */ { "NANDINAGARI LETTER LA",NULL},
/* 119CA */ { "NANDINAGARI LETTER VA",NULL},
/* 119CB */ { "NANDINAGARI LETTER SHA",NULL},
/* 119CC */ { "NANDINAGARI LETTER SSA",NULL},
/* 119CD */ { "NANDINAGARI LETTER SA",NULL},
/* 119CE */ { "NANDINAGARI LETTER HA",NULL},
/* 119CF */ { "NANDINAGARI LETTER LLA",NULL},
/* 119D0 */ { "NANDINAGARI LETTER RRA",NULL},
/* 119D1 */ { "NANDINAGARI VOWEL SIGN AA",NULL},
/* 119D2 */ { "NANDINAGARI VOWEL SIGN I",NULL},
/* 119D3 */ { "NANDINAGARI VOWEL SIGN II",NULL},
/* 119D4 */ { "NANDINAGARI VOWEL SIGN U",NULL},
/* 119D5 */ { "NANDINAGARI VOWEL SIGN UU",NULL},
/* 119D6 */ { "NANDINAGARI VOWEL SIGN VOCALIC R",NULL},
/* 119D7 */ { "NANDINAGARI VOWEL SIGN VOCALIC RR",NULL},
/* 119D8 */ { NULL,NULL},
/* 119D9 */ { NULL,NULL},
/* 119DA */ { "NANDINAGARI VOWEL SIGN E",NULL},
/* 119DB */ { "NANDINAGARI VOWEL SIGN AI",NULL},
/* 119DC */ { "NANDINAGARI VOWEL SIGN O",NULL},
/* 119DD */ { "NANDINAGARI VOWEL SIGN AU",NULL},
/* 119DE */ { "NANDINAGARI SIGN ANUSVARA",NULL},
/* 119DF */ { "NANDINAGARI SIGN VISARGA",NULL},
/* 119E0 */ { "NANDINAGARI SIGN VIRAMA",NULL},
/* 119E1 */ { "NANDINAGARI SIGN AVAGRAHA",NULL},
/* 119E2 */ { "NANDINAGARI SIGN SIDDHAM",NULL},
/* 119E3 */ { "NANDINAGARI HEADSTROKE","	* used as a spacing or filler mark"},
/* 119E4 */ { "NANDINAGARI VOWEL SIGN PRISHTHAMATRA E",NULL},
/* 119E5 */ { NULL,NULL},
/* 119E6 */ { NULL,NULL},
/* 119E7 */ { NULL,NULL},
/* 119E8 */ { NULL,NULL},
/* 119E9 */ { NULL,NULL},
/* 119EA */ { NULL,NULL},
/* 119EB */ { NULL,NULL},
/* 119EC */ { NULL,NULL},
/* 119ED */ { NULL,NULL},
/* 119EE */ { NULL,NULL},
/* 119EF */ { NULL,NULL},
/* 119F0 */ { NULL,NULL},
/* 119F1 */ { NULL,NULL},
/* 119F2 */ { NULL,NULL},
/* 119F3 */ { NULL,NULL},
/* 119F4 */ { NULL,NULL},
/* 119F5 */ { NULL,NULL},
/* 119F6 */ { NULL,NULL},
/* 119F7 */ { NULL,NULL},
/* 119F8 */ { NULL,NULL},
/* 119F9 */ { NULL,NULL},
/* 119FA */ { NULL,NULL},
/* 119FB */ { NULL,NULL},
/* 119FC */ { NULL,NULL},
/* 119FD */ { NULL,NULL},
/* 119FE */ { NULL,NULL},
/* 119FF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_1A[] = {
/* 11A00 */ { "ZANABAZAR SQUARE LETTER A","	* used for representing independent vowels in combination with vowel signs"},
/* 11A01 */ { "ZANABAZAR SQUARE VOWEL SIGN I",NULL},
/* 11A02 */ { "ZANABAZAR SQUARE VOWEL SIGN UE",NULL},
/* 11A03 */ { "ZANABAZAR SQUARE VOWEL SIGN U",NULL},
/* 11A04 */ { "ZANABAZAR SQUARE VOWEL SIGN E",NULL},
/* 11A05 */ { "ZANABAZAR SQUARE VOWEL SIGN OE",NULL},
/* 11A06 */ { "ZANABAZAR SQUARE VOWEL SIGN O",NULL},
/* 11A07 */ { "ZANABAZAR SQUARE VOWEL SIGN AI","	* also represents secondary vowel i"},
/* 11A08 */ { "ZANABAZAR SQUARE VOWEL SIGN AU","	* also represents secondary vowel u"},
/* 11A09 */ { "ZANABAZAR SQUARE VOWEL SIGN REVERSED I","	* used for Sanskrit vocalic sounds"},
/* 11A0A */ { "ZANABAZAR SQUARE VOWEL LENGTH MARK",NULL},
/* 11A0B */ { "ZANABAZAR SQUARE LETTER KA",NULL},
/* 11A0C */ { "ZANABAZAR SQUARE LETTER KHA",NULL},
/* 11A0D */ { "ZANABAZAR SQUARE LETTER GA",NULL},
/* 11A0E */ { "ZANABAZAR SQUARE LETTER GHA",NULL},
/* 11A0F */ { "ZANABAZAR SQUARE LETTER NGA",NULL},
/* 11A10 */ { "ZANABAZAR SQUARE LETTER CA",NULL},
/* 11A11 */ { "ZANABAZAR SQUARE LETTER CHA",NULL},
/* 11A12 */ { "ZANABAZAR SQUARE LETTER JA",NULL},
/* 11A13 */ { "ZANABAZAR SQUARE LETTER NYA",NULL},
/* 11A14 */ { "ZANABAZAR SQUARE LETTER TTA",NULL},
/* 11A15 */ { "ZANABAZAR SQUARE LETTER TTHA",NULL},
/* 11A16 */ { "ZANABAZAR SQUARE LETTER DDA",NULL},
/* 11A17 */ { "ZANABAZAR SQUARE LETTER DDHA",NULL},
/* 11A18 */ { "ZANABAZAR SQUARE LETTER NNA",NULL},
/* 11A19 */ { "ZANABAZAR SQUARE LETTER TA",NULL},
/* 11A1A */ { "ZANABAZAR SQUARE LETTER THA",NULL},
/* 11A1B */ { "ZANABAZAR SQUARE LETTER DA",NULL},
/* 11A1C */ { "ZANABAZAR SQUARE LETTER DHA",NULL},
/* 11A1D */ { "ZANABAZAR SQUARE LETTER NA",NULL},
/* 11A1E */ { "ZANABAZAR SQUARE LETTER PA",NULL},
/* 11A1F */ { "ZANABAZAR SQUARE LETTER PHA",NULL},
/* 11A20 */ { "ZANABAZAR SQUARE LETTER BA","	* also used instead of non-initial 11A2D in conjuncts"},
/* 11A21 */ { "ZANABAZAR SQUARE LETTER BHA",NULL},
/* 11A22 */ { "ZANABAZAR SQUARE LETTER MA",NULL},
/* 11A23 */ { "ZANABAZAR SQUARE LETTER TSA",NULL},
/* 11A24 */ { "ZANABAZAR SQUARE LETTER TSHA",NULL},
/* 11A25 */ { "ZANABAZAR SQUARE LETTER DZA",NULL},
/* 11A26 */ { "ZANABAZAR SQUARE LETTER DZHA",NULL},
/* 11A27 */ { "ZANABAZAR SQUARE LETTER ZHA",NULL},
/* 11A28 */ { "ZANABAZAR SQUARE LETTER ZA",NULL},
/* 11A29 */ { "ZANABAZAR SQUARE LETTER -A","	* Mongolian aang\n"
	"	* Tibetan a-chung\n"
	"	x (tibetan letter -a - 0F60)"},
/* 11A2A */ { "ZANABAZAR SQUARE LETTER YA",NULL},
/* 11A2B */ { "ZANABAZAR SQUARE LETTER RA",NULL},
/* 11A2C */ { "ZANABAZAR SQUARE LETTER LA",NULL},
/* 11A2D */ { "ZANABAZAR SQUARE LETTER VA",NULL},
/* 11A2E */ { "ZANABAZAR SQUARE LETTER SHA",NULL},
/* 11A2F */ { "ZANABAZAR SQUARE LETTER SSA",NULL},
/* 11A30 */ { "ZANABAZAR SQUARE LETTER SA",NULL},
/* 11A31 */ { "ZANABAZAR SQUARE LETTER HA",NULL},
/* 11A32 */ { "ZANABAZAR SQUARE LETTER KSSA",NULL},
/* 11A33 */ { "ZANABAZAR SQUARE FINAL CONSONANT MARK","	* used for marking a syllable-final consonant in Mongolian\n"
	"	* indicates a syllabic boundary in Mongolian"},
/* 11A34 */ { "ZANABAZAR SQUARE SIGN VIRAMA","	* indicates a bare consonant in Sanskrit and Tibetan\n"
	"	* not used for conjunct formation\n"
	"	x (tibetan mark halanta - 0F84)"},
/* 11A35 */ { "ZANABAZAR SQUARE SIGN CANDRABINDU","	* indicates nasalization\n"
	"	x (tibetan sign sna ldan - 0F83)\n"
	"	x (mongolian letter ali gali anusvara one - 1880)"},
/* 11A36 */ { "ZANABAZAR SQUARE SIGN CANDRABINDU WITH ORNAMENT","	* used primarily with 11A3F"},
/* 11A37 */ { "ZANABAZAR SQUARE SIGN CANDRA WITH ORNAMENT","	* used primarily with 11A3F\n"
	"	x (tibetan sign nyi zla naa da - 0F82)"},
/* 11A38 */ { "ZANABAZAR SQUARE SIGN ANUSVARA","	* indicates nasalization\n"
	"	x (tibetan sign rjes su nga ro - 0F7E)"},
/* 11A39 */ { "ZANABAZAR SQUARE SIGN VISARGA","	* indicates post-vocalic aspiration\n"
	"	x (tibetan sign rnam bcad - 0F7F)"},
/* 11A3A */ { "ZANABAZAR SQUARE CLUSTER-INITIAL LETTER RA","	* initial form of 11A2B in Tibetan conjuncts"},
/* 11A3B */ { "ZANABAZAR SQUARE CLUSTER-FINAL LETTER YA","	* final form of 11A2A in Tibetan conjuncts"},
/* 11A3C */ { "ZANABAZAR SQUARE CLUSTER-FINAL LETTER RA","	* final form of 11A2B in Tibetan conjuncts"},
/* 11A3D */ { "ZANABAZAR SQUARE CLUSTER-FINAL LETTER LA","	* final form of 11A2C in Tibetan conjuncts"},
/* 11A3E */ { "ZANABAZAR SQUARE CLUSTER-FINAL LETTER VA","	* final form of 11A2D in Tibetan conjuncts"},
/* 11A3F */ { "ZANABAZAR SQUARE INITIAL HEAD MARK","	x (tibetan mark initial brda rnying yig mgo mdun ma - 0FD3)\n"
	"	x (mongolian birga - 1800)"},
/* 11A40 */ { "ZANABAZAR SQUARE CLOSING HEAD MARK","	x (tibetan mark closing brda rnying yig mgo sgab ma - 0FD4)"},
/* 11A41 */ { "ZANABAZAR SQUARE MARK TSHEG","	x (tibetan mark intersyllabic tsheg - 0F0B)"},
/* 11A42 */ { "ZANABAZAR SQUARE MARK SHAD","	x (tibetan mark shad - 0F0D)"},
/* 11A43 */ { "ZANABAZAR SQUARE MARK DOUBLE SHAD","	x (tibetan mark nyis shad - 0F0E)"},
/* 11A44 */ { "ZANABAZAR SQUARE MARK LONG TSHEG","	x (tibetan mark gter tsheg - 0F14)"},
/* 11A45 */ { "ZANABAZAR SQUARE INITIAL DOUBLE-LINED HEAD MARK","	x (tibetan mark initial yig mgo mdun ma - 0F04)"},
/* 11A46 */ { "ZANABAZAR SQUARE CLOSING DOUBLE-LINED HEAD MARK","	x (tibetan mark closing yig mgo sgab ma - 0F05)"},
/* 11A47 */ { "ZANABAZAR SQUARE SUBJOINER","	* used for producing consonant conjuncts"},
/* 11A48 */ { NULL,NULL},
/* 11A49 */ { NULL,NULL},
/* 11A4A */ { NULL,NULL},
/* 11A4B */ { NULL,NULL},
/* 11A4C */ { NULL,NULL},
/* 11A4D */ { NULL,NULL},
/* 11A4E */ { NULL,NULL},
/* 11A4F */ { NULL,NULL},
/* 11A50 */ { "SOYOMBO LETTER A","	* used for representing independent vowels in combination with vowel signs"},
/* 11A51 */ { "SOYOMBO VOWEL SIGN I",NULL},
/* 11A52 */ { "SOYOMBO VOWEL SIGN UE",NULL},
/* 11A53 */ { "SOYOMBO VOWEL SIGN U",NULL},
/* 11A54 */ { "SOYOMBO VOWEL SIGN E",NULL},
/* 11A55 */ { "SOYOMBO VOWEL SIGN O",NULL},
/* 11A56 */ { "SOYOMBO VOWEL SIGN OE",NULL},
/* 11A57 */ { "SOYOMBO VOWEL SIGN AI",NULL},
/* 11A58 */ { "SOYOMBO VOWEL SIGN AU",NULL},
/* 11A59 */ { "SOYOMBO VOWEL SIGN VOCALIC R",NULL},
/* 11A5A */ { "SOYOMBO VOWEL SIGN VOCALIC L",NULL},
/* 11A5B */ { "SOYOMBO VOWEL LENGTH MARK",NULL},
/* 11A5C */ { "SOYOMBO LETTER KA",NULL},
/* 11A5D */ { "SOYOMBO LETTER KHA",NULL},
/* 11A5E */ { "SOYOMBO LETTER GA",NULL},
/* 11A5F */ { "SOYOMBO LETTER GHA",NULL},
/* 11A60 */ { "SOYOMBO LETTER NGA",NULL},
/* 11A61 */ { "SOYOMBO LETTER CA",NULL},
/* 11A62 */ { "SOYOMBO LETTER CHA",NULL},
/* 11A63 */ { "SOYOMBO LETTER JA",NULL},
/* 11A64 */ { "SOYOMBO LETTER JHA",NULL},
/* 11A65 */ { "SOYOMBO LETTER NYA",NULL},
/* 11A66 */ { "SOYOMBO LETTER TTA",NULL},
/* 11A67 */ { "SOYOMBO LETTER TTHA",NULL},
/* 11A68 */ { "SOYOMBO LETTER DDA",NULL},
/* 11A69 */ { "SOYOMBO LETTER DDHA",NULL},
/* 11A6A */ { "SOYOMBO LETTER NNA",NULL},
/* 11A6B */ { "SOYOMBO LETTER TA",NULL},
/* 11A6C */ { "SOYOMBO LETTER THA",NULL},
/* 11A6D */ { "SOYOMBO LETTER DA",NULL},
/* 11A6E */ { "SOYOMBO LETTER DHA",NULL},
/* 11A6F */ { "SOYOMBO LETTER NA",NULL},
/* 11A70 */ { "SOYOMBO LETTER PA",NULL},
/* 11A71 */ { "SOYOMBO LETTER PHA",NULL},
/* 11A72 */ { "SOYOMBO LETTER BA",NULL},
/* 11A73 */ { "SOYOMBO LETTER BHA",NULL},
/* 11A74 */ { "SOYOMBO LETTER MA",NULL},
/* 11A75 */ { "SOYOMBO LETTER TSA",NULL},
/* 11A76 */ { "SOYOMBO LETTER TSHA",NULL},
/* 11A77 */ { "SOYOMBO LETTER DZA",NULL},
/* 11A78 */ { "SOYOMBO LETTER ZHA",NULL},
/* 11A79 */ { "SOYOMBO LETTER ZA",NULL},
/* 11A7A */ { "SOYOMBO LETTER -A",NULL},
/* 11A7B */ { "SOYOMBO LETTER YA",NULL},
/* 11A7C */ { "SOYOMBO LETTER RA",NULL},
/* 11A7D */ { "SOYOMBO LETTER LA",NULL},
/* 11A7E */ { "SOYOMBO LETTER VA",NULL},
/* 11A7F */ { "SOYOMBO LETTER SHA",NULL},
/* 11A80 */ { "SOYOMBO LETTER SSA",NULL},
/* 11A81 */ { "SOYOMBO LETTER SA",NULL},
/* 11A82 */ { "SOYOMBO LETTER HA",NULL},
/* 11A83 */ { "SOYOMBO LETTER KSSA",NULL},
/* 11A84 */ { "SOYOMBO SIGN JIHVAMULIYA","	x (vedic sign jihvamuliya - 1CF5)"},
/* 11A85 */ { "SOYOMBO SIGN UPADHMANIYA","	x (vedic sign upadhmaniya - 1CF6)"},
/* 11A86 */ { "SOYOMBO CLUSTER-INITIAL LETTER RA",NULL},
/* 11A87 */ { "SOYOMBO CLUSTER-INITIAL LETTER LA",NULL},
/* 11A88 */ { "SOYOMBO CLUSTER-INITIAL LETTER SHA",NULL},
/* 11A89 */ { "SOYOMBO CLUSTER-INITIAL LETTER SA",NULL},
/* 11A8A */ { "SOYOMBO FINAL CONSONANT SIGN G",NULL},
/* 11A8B */ { "SOYOMBO FINAL CONSONANT SIGN K",NULL},
/* 11A8C */ { "SOYOMBO FINAL CONSONANT SIGN NG",NULL},
/* 11A8D */ { "SOYOMBO FINAL CONSONANT SIGN D",NULL},
/* 11A8E */ { "SOYOMBO FINAL CONSONANT SIGN N",NULL},
/* 11A8F */ { "SOYOMBO FINAL CONSONANT SIGN B",NULL},
/* 11A90 */ { "SOYOMBO FINAL CONSONANT SIGN M",NULL},
/* 11A91 */ { "SOYOMBO FINAL CONSONANT SIGN R",NULL},
/* 11A92 */ { "SOYOMBO FINAL CONSONANT SIGN L",NULL},
/* 11A93 */ { "SOYOMBO FINAL CONSONANT SIGN SH",NULL},
/* 11A94 */ { "SOYOMBO FINAL CONSONANT SIGN S",NULL},
/* 11A95 */ { "SOYOMBO FINAL CONSONANT SIGN -A","	* Mongolian aang\n"
	"	* Tibetan a-chung\n"
	"	x (tibetan letter -a - 0F60)"},
/* 11A96 */ { "SOYOMBO SIGN ANUSVARA",NULL},
/* 11A97 */ { "SOYOMBO SIGN VISARGA",NULL},
/* 11A98 */ { "SOYOMBO GEMINATION MARK",NULL},
/* 11A99 */ { "SOYOMBO SUBJOINER","	* used for producing consonant conjuncts"},
/* 11A9A */ { "SOYOMBO MARK TSHEG",NULL},
/* 11A9B */ { "SOYOMBO MARK SHAD",NULL},
/* 11A9C */ { "SOYOMBO MARK DOUBLE SHAD",NULL},
/* 11A9D */ { "SOYOMBO MARK PLUTA","	* indicates vowel elongation"},
/* 11A9E */ { "SOYOMBO HEAD MARK WITH MOON AND SUN AND TRIPLE FLAME","	* national symbol of Mongolia"},
/* 11A9F */ { "SOYOMBO HEAD MARK WITH MOON AND SUN AND FLAME",NULL},
/* 11AA0 */ { "SOYOMBO HEAD MARK WITH MOON AND SUN",NULL},
/* 11AA1 */ { "SOYOMBO TERMINAL MARK-1",NULL},
/* 11AA2 */ { "SOYOMBO TERMINAL MARK-2","	= cintamani, candamani"},
/* 11AA3 */ { NULL,NULL},
/* 11AA4 */ { NULL,NULL},
/* 11AA5 */ { NULL,NULL},
/* 11AA6 */ { NULL,NULL},
/* 11AA7 */ { NULL,NULL},
/* 11AA8 */ { NULL,NULL},
/* 11AA9 */ { NULL,NULL},
/* 11AAA */ { NULL,NULL},
/* 11AAB */ { NULL,NULL},
/* 11AAC */ { NULL,NULL},
/* 11AAD */ { NULL,NULL},
/* 11AAE */ { NULL,NULL},
/* 11AAF */ { NULL,NULL},
/* 11AB0 */ { "CANADIAN SYLLABICS NATTILIK HI",NULL},
/* 11AB1 */ { "CANADIAN SYLLABICS NATTILIK HII",NULL},
/* 11AB2 */ { "CANADIAN SYLLABICS NATTILIK HO","	* Nattilik (HU)"},
/* 11AB3 */ { "CANADIAN SYLLABICS NATTILIK HOO","	* Nattilik (HUU)"},
/* 11AB4 */ { "CANADIAN SYLLABICS NATTILIK HA",NULL},
/* 11AB5 */ { "CANADIAN SYLLABICS NATTILIK HAA",NULL},
/* 11AB6 */ { "CANADIAN SYLLABICS NATTILIK SHRI",NULL},
/* 11AB7 */ { "CANADIAN SYLLABICS NATTILIK SHRII",NULL},
/* 11AB8 */ { "CANADIAN SYLLABICS NATTILIK SHRO","	* Nattilik (SHRU)"},
/* 11AB9 */ { "CANADIAN SYLLABICS NATTILIK SHROO","	* Nattilik (SHRUU)"},
/* 11ABA */ { "CANADIAN SYLLABICS NATTILIK SHRA",NULL},
/* 11ABB */ { "CANADIAN SYLLABICS NATTILIK SHRAA",NULL},
/* 11ABC */ { "CANADIAN SYLLABICS SPE",NULL},
/* 11ABD */ { "CANADIAN SYLLABICS SPI",NULL},
/* 11ABE */ { "CANADIAN SYLLABICS SPO",NULL},
/* 11ABF */ { "CANADIAN SYLLABICS SPA",NULL},
/* 11AC0 */ { "PAU CIN HAU LETTER PA",NULL},
/* 11AC1 */ { "PAU CIN HAU LETTER KA",NULL},
/* 11AC2 */ { "PAU CIN HAU LETTER LA",NULL},
/* 11AC3 */ { "PAU CIN HAU LETTER MA",NULL},
/* 11AC4 */ { "PAU CIN HAU LETTER DA",NULL},
/* 11AC5 */ { "PAU CIN HAU LETTER ZA",NULL},
/* 11AC6 */ { "PAU CIN HAU LETTER VA",NULL},
/* 11AC7 */ { "PAU CIN HAU LETTER NGA",NULL},
/* 11AC8 */ { "PAU CIN HAU LETTER HA",NULL},
/* 11AC9 */ { "PAU CIN HAU LETTER GA",NULL},
/* 11ACA */ { "PAU CIN HAU LETTER KHA",NULL},
/* 11ACB */ { "PAU CIN HAU LETTER SA",NULL},
/* 11ACC */ { "PAU CIN HAU LETTER BA",NULL},
/* 11ACD */ { "PAU CIN HAU LETTER CA",NULL},
/* 11ACE */ { "PAU CIN HAU LETTER TA",NULL},
/* 11ACF */ { "PAU CIN HAU LETTER THA",NULL},
/* 11AD0 */ { "PAU CIN HAU LETTER NA",NULL},
/* 11AD1 */ { "PAU CIN HAU LETTER PHA",NULL},
/* 11AD2 */ { "PAU CIN HAU LETTER RA",NULL},
/* 11AD3 */ { "PAU CIN HAU LETTER FA",NULL},
/* 11AD4 */ { "PAU CIN HAU LETTER CHA",NULL},
/* 11AD5 */ { "PAU CIN HAU LETTER A",NULL},
/* 11AD6 */ { "PAU CIN HAU LETTER E",NULL},
/* 11AD7 */ { "PAU CIN HAU LETTER I",NULL},
/* 11AD8 */ { "PAU CIN HAU LETTER O",NULL},
/* 11AD9 */ { "PAU CIN HAU LETTER U",NULL},
/* 11ADA */ { "PAU CIN HAU LETTER UA",NULL},
/* 11ADB */ { "PAU CIN HAU LETTER IA",NULL},
/* 11ADC */ { "PAU CIN HAU LETTER FINAL P",NULL},
/* 11ADD */ { "PAU CIN HAU LETTER FINAL K",NULL},
/* 11ADE */ { "PAU CIN HAU LETTER FINAL T",NULL},
/* 11ADF */ { "PAU CIN HAU LETTER FINAL M",NULL},
/* 11AE0 */ { "PAU CIN HAU LETTER FINAL N",NULL},
/* 11AE1 */ { "PAU CIN HAU LETTER FINAL L",NULL},
/* 11AE2 */ { "PAU CIN HAU LETTER FINAL W",NULL},
/* 11AE3 */ { "PAU CIN HAU LETTER FINAL NG",NULL},
/* 11AE4 */ { "PAU CIN HAU LETTER FINAL Y",NULL},
/* 11AE5 */ { "PAU CIN HAU RISING TONE LONG",NULL},
/* 11AE6 */ { "PAU CIN HAU RISING TONE",NULL},
/* 11AE7 */ { "PAU CIN HAU SANDHI GLOTTAL STOP",NULL},
/* 11AE8 */ { "PAU CIN HAU RISING TONE LONG FINAL",NULL},
/* 11AE9 */ { "PAU CIN HAU RISING TONE FINAL",NULL},
/* 11AEA */ { "PAU CIN HAU SANDHI GLOTTAL STOP FINAL",NULL},
/* 11AEB */ { "PAU CIN HAU SANDHI TONE LONG",NULL},
/* 11AEC */ { "PAU CIN HAU SANDHI TONE",NULL},
/* 11AED */ { "PAU CIN HAU SANDHI TONE LONG FINAL",NULL},
/* 11AEE */ { "PAU CIN HAU SANDHI TONE FINAL",NULL},
/* 11AEF */ { "PAU CIN HAU MID-LEVEL TONE",NULL},
/* 11AF0 */ { "PAU CIN HAU GLOTTAL STOP VARIANT",NULL},
/* 11AF1 */ { "PAU CIN HAU MID-LEVEL TONE LONG FINAL",NULL},
/* 11AF2 */ { "PAU CIN HAU MID-LEVEL TONE FINAL",NULL},
/* 11AF3 */ { "PAU CIN HAU LOW-FALLING TONE LONG",NULL},
/* 11AF4 */ { "PAU CIN HAU LOW-FALLING TONE",NULL},
/* 11AF5 */ { "PAU CIN HAU GLOTTAL STOP",NULL},
/* 11AF6 */ { "PAU CIN HAU LOW-FALLING TONE LONG FINAL",NULL},
/* 11AF7 */ { "PAU CIN HAU LOW-FALLING TONE FINAL",NULL},
/* 11AF8 */ { "PAU CIN HAU GLOTTAL STOP FINAL",NULL},
/* 11AF9 */ { NULL,NULL},
/* 11AFA */ { NULL,NULL},
/* 11AFB */ { NULL,NULL},
/* 11AFC */ { NULL,NULL},
/* 11AFD */ { NULL,NULL},
/* 11AFE */ { NULL,NULL},
/* 11AFF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_1B[] = {
/* 11B00 */ { "DEVANAGARI HEAD MARK","	x (devanagari double danda - 0965)"},
/* 11B01 */ { "DEVANAGARI HEAD MARK WITH HEADSTROKE",NULL},
/* 11B02 */ { "DEVANAGARI SIGN BHALE",NULL},
/* 11B03 */ { "DEVANAGARI SIGN BHALE WITH HOOK",NULL},
/* 11B04 */ { "DEVANAGARI SIGN EXTENDED BHALE",NULL},
/* 11B05 */ { "DEVANAGARI SIGN EXTENDED BHALE WITH HOOK",NULL},
/* 11B06 */ { "DEVANAGARI SIGN WESTERN FIVE-LIKE BHALE",NULL},
/* 11B07 */ { "DEVANAGARI SIGN WESTERN NINE-LIKE BHALE",NULL},
/* 11B08 */ { "DEVANAGARI SIGN REVERSED NINE-LIKE BHALE",NULL},
/* 11B09 */ { "DEVANAGARI SIGN MINDU","	x (devanagari digit zero - 0966)"},
/* 11B0A */ { NULL,NULL},
/* 11B0B */ { NULL,NULL},
/* 11B0C */ { NULL,NULL},
/* 11B0D */ { NULL,NULL},
/* 11B0E */ { NULL,NULL},
/* 11B0F */ { NULL,NULL},
/* 11B10 */ { NULL,NULL},
/* 11B11 */ { NULL,NULL},
/* 11B12 */ { NULL,NULL},
/* 11B13 */ { NULL,NULL},
/* 11B14 */ { NULL,NULL},
/* 11B15 */ { NULL,NULL},
/* 11B16 */ { NULL,NULL},
/* 11B17 */ { NULL,NULL},
/* 11B18 */ { NULL,NULL},
/* 11B19 */ { NULL,NULL},
/* 11B1A */ { NULL,NULL},
/* 11B1B */ { NULL,NULL},
/* 11B1C */ { NULL,NULL},
/* 11B1D */ { NULL,NULL},
/* 11B1E */ { NULL,NULL},
/* 11B1F */ { NULL,NULL},
/* 11B20 */ { NULL,NULL},
/* 11B21 */ { NULL,NULL},
/* 11B22 */ { NULL,NULL},
/* 11B23 */ { NULL,NULL},
/* 11B24 */ { NULL,NULL},
/* 11B25 */ { NULL,NULL},
/* 11B26 */ { NULL,NULL},
/* 11B27 */ { NULL,NULL},
/* 11B28 */ { NULL,NULL},
/* 11B29 */ { NULL,NULL},
/* 11B2A */ { NULL,NULL},
/* 11B2B */ { NULL,NULL},
/* 11B2C */ { NULL,NULL},
/* 11B2D */ { NULL,NULL},
/* 11B2E */ { NULL,NULL},
/* 11B2F */ { NULL,NULL},
/* 11B30 */ { NULL,NULL},
/* 11B31 */ { NULL,NULL},
/* 11B32 */ { NULL,NULL},
/* 11B33 */ { NULL,NULL},
/* 11B34 */ { NULL,NULL},
/* 11B35 */ { NULL,NULL},
/* 11B36 */ { NULL,NULL},
/* 11B37 */ { NULL,NULL},
/* 11B38 */ { NULL,NULL},
/* 11B39 */ { NULL,NULL},
/* 11B3A */ { NULL,NULL},
/* 11B3B */ { NULL,NULL},
/* 11B3C */ { NULL,NULL},
/* 11B3D */ { NULL,NULL},
/* 11B3E */ { NULL,NULL},
/* 11B3F */ { NULL,NULL},
/* 11B40 */ { NULL,NULL},
/* 11B41 */ { NULL,NULL},
/* 11B42 */ { NULL,NULL},
/* 11B43 */ { NULL,NULL},
/* 11B44 */ { NULL,NULL},
/* 11B45 */ { NULL,NULL},
/* 11B46 */ { NULL,NULL},
/* 11B47 */ { NULL,NULL},
/* 11B48 */ { NULL,NULL},
/* 11B49 */ { NULL,NULL},
/* 11B4A */ { NULL,NULL},
/* 11B4B */ { NULL,NULL},
/* 11B4C */ { NULL,NULL},
/* 11B4D */ { NULL,NULL},
/* 11B4E */ { NULL,NULL},
/* 11B4F */ { NULL,NULL},
/* 11B50 */ { NULL,NULL},
/* 11B51 */ { NULL,NULL},
/* 11B52 */ { NULL,NULL},
/* 11B53 */ { NULL,NULL},
/* 11B54 */ { NULL,NULL},
/* 11B55 */ { NULL,NULL},
/* 11B56 */ { NULL,NULL},
/* 11B57 */ { NULL,NULL},
/* 11B58 */ { NULL,NULL},
/* 11B59 */ { NULL,NULL},
/* 11B5A */ { NULL,NULL},
/* 11B5B */ { NULL,NULL},
/* 11B5C */ { NULL,NULL},
/* 11B5D */ { NULL,NULL},
/* 11B5E */ { NULL,NULL},
/* 11B5F */ { NULL,NULL},
/* 11B60 */ { "SHARADA VOWEL SIGN OE","	x (devanagari vowel sign oe - 093A)"},
/* 11B61 */ { "SHARADA VOWEL SIGN OOE","	x (devanagari vowel sign ooe - 093B)"},
/* 11B62 */ { "SHARADA VOWEL SIGN UE","	x (devanagari vowel sign ue - 0956)"},
/* 11B63 */ { "SHARADA VOWEL SIGN UUE","	x (devanagari vowel sign uue - 0957)"},
/* 11B64 */ { "SHARADA VOWEL SIGN SHORT E","	x (devanagari vowel sign short e - 0946)"},
/* 11B65 */ { "SHARADA VOWEL SIGN SHORT O","	x (devanagari vowel sign short o - 094A)"},
/* 11B66 */ { "SHARADA VOWEL SIGN CANDRA E","	x (devanagari vowel sign candra e - 0945)"},
/* 11B67 */ { "SHARADA VOWEL SIGN CANDRA O","	x (devanagari vowel sign candra o - 0949)"},
/* 11B68 */ { NULL,NULL},
/* 11B69 */ { NULL,NULL},
/* 11B6A */ { NULL,NULL},
/* 11B6B */ { NULL,NULL},
/* 11B6C */ { NULL,NULL},
/* 11B6D */ { NULL,NULL},
/* 11B6E */ { NULL,NULL},
/* 11B6F */ { NULL,NULL},
/* 11B70 */ { NULL,NULL},
/* 11B71 */ { NULL,NULL},
/* 11B72 */ { NULL,NULL},
/* 11B73 */ { NULL,NULL},
/* 11B74 */ { NULL,NULL},
/* 11B75 */ { NULL,NULL},
/* 11B76 */ { NULL,NULL},
/* 11B77 */ { NULL,NULL},
/* 11B78 */ { NULL,NULL},
/* 11B79 */ { NULL,NULL},
/* 11B7A */ { NULL,NULL},
/* 11B7B */ { NULL,NULL},
/* 11B7C */ { NULL,NULL},
/* 11B7D */ { NULL,NULL},
/* 11B7E */ { NULL,NULL},
/* 11B7F */ { NULL,NULL},
/* 11B80 */ { NULL,NULL},
/* 11B81 */ { NULL,NULL},
/* 11B82 */ { NULL,NULL},
/* 11B83 */ { NULL,NULL},
/* 11B84 */ { NULL,NULL},
/* 11B85 */ { NULL,NULL},
/* 11B86 */ { NULL,NULL},
/* 11B87 */ { NULL,NULL},
/* 11B88 */ { NULL,NULL},
/* 11B89 */ { NULL,NULL},
/* 11B8A */ { NULL,NULL},
/* 11B8B */ { NULL,NULL},
/* 11B8C */ { NULL,NULL},
/* 11B8D */ { NULL,NULL},
/* 11B8E */ { NULL,NULL},
/* 11B8F */ { NULL,NULL},
/* 11B90 */ { NULL,NULL},
/* 11B91 */ { NULL,NULL},
/* 11B92 */ { NULL,NULL},
/* 11B93 */ { NULL,NULL},
/* 11B94 */ { NULL,NULL},
/* 11B95 */ { NULL,NULL},
/* 11B96 */ { NULL,NULL},
/* 11B97 */ { NULL,NULL},
/* 11B98 */ { NULL,NULL},
/* 11B99 */ { NULL,NULL},
/* 11B9A */ { NULL,NULL},
/* 11B9B */ { NULL,NULL},
/* 11B9C */ { NULL,NULL},
/* 11B9D */ { NULL,NULL},
/* 11B9E */ { NULL,NULL},
/* 11B9F */ { NULL,NULL},
/* 11BA0 */ { NULL,NULL},
/* 11BA1 */ { NULL,NULL},
/* 11BA2 */ { NULL,NULL},
/* 11BA3 */ { NULL,NULL},
/* 11BA4 */ { NULL,NULL},
/* 11BA5 */ { NULL,NULL},
/* 11BA6 */ { NULL,NULL},
/* 11BA7 */ { NULL,NULL},
/* 11BA8 */ { NULL,NULL},
/* 11BA9 */ { NULL,NULL},
/* 11BAA */ { NULL,NULL},
/* 11BAB */ { NULL,NULL},
/* 11BAC */ { NULL,NULL},
/* 11BAD */ { NULL,NULL},
/* 11BAE */ { NULL,NULL},
/* 11BAF */ { NULL,NULL},
/* 11BB0 */ { NULL,NULL},
/* 11BB1 */ { NULL,NULL},
/* 11BB2 */ { NULL,NULL},
/* 11BB3 */ { NULL,NULL},
/* 11BB4 */ { NULL,NULL},
/* 11BB5 */ { NULL,NULL},
/* 11BB6 */ { NULL,NULL},
/* 11BB7 */ { NULL,NULL},
/* 11BB8 */ { NULL,NULL},
/* 11BB9 */ { NULL,NULL},
/* 11BBA */ { NULL,NULL},
/* 11BBB */ { NULL,NULL},
/* 11BBC */ { NULL,NULL},
/* 11BBD */ { NULL,NULL},
/* 11BBE */ { NULL,NULL},
/* 11BBF */ { NULL,NULL},
/* 11BC0 */ { "SUNUWAR LETTER DEVI",NULL},
/* 11BC1 */ { "SUNUWAR LETTER TASLA",NULL},
/* 11BC2 */ { "SUNUWAR LETTER EKO",NULL},
/* 11BC3 */ { "SUNUWAR LETTER IMAR",NULL},
/* 11BC4 */ { "SUNUWAR LETTER REU",NULL},
/* 11BC5 */ { "SUNUWAR LETTER UTTHI",NULL},
/* 11BC6 */ { "SUNUWAR LETTER KIK",NULL},
/* 11BC7 */ { "SUNUWAR LETTER MA",NULL},
/* 11BC8 */ { "SUNUWAR LETTER APPHO",NULL},
/* 11BC9 */ { "SUNUWAR LETTER PIP",NULL},
/* 11BCA */ { "SUNUWAR LETTER GIL",NULL},
/* 11BCB */ { "SUNUWAR LETTER HAMSO",NULL},
/* 11BCC */ { "SUNUWAR LETTER CARMI",NULL},
/* 11BCD */ { "SUNUWAR LETTER NAH",NULL},
/* 11BCE */ { "SUNUWAR LETTER BUR",NULL},
/* 11BCF */ { "SUNUWAR LETTER JYAH",NULL},
/* 11BD0 */ { "SUNUWAR LETTER LOACHA",NULL},
/* 11BD1 */ { "SUNUWAR LETTER OTTHI",NULL},
/* 11BD2 */ { "SUNUWAR LETTER SHYELE",NULL},
/* 11BD3 */ { "SUNUWAR LETTER VARCA",NULL},
/* 11BD4 */ { "SUNUWAR LETTER YAT",NULL},
/* 11BD5 */ { "SUNUWAR LETTER AVA",NULL},
/* 11BD6 */ { "SUNUWAR LETTER AAL",NULL},
/* 11BD7 */ { "SUNUWAR LETTER DONGA",NULL},
/* 11BD8 */ { "SUNUWAR LETTER THARI",NULL},
/* 11BD9 */ { "SUNUWAR LETTER PHAR",NULL},
/* 11BDA */ { "SUNUWAR LETTER NGAR",NULL},
/* 11BDB */ { "SUNUWAR LETTER KHA",NULL},
/* 11BDC */ { "SUNUWAR LETTER SHYER",NULL},
/* 11BDD */ { "SUNUWAR LETTER CHELAP",NULL},
/* 11BDE */ { "SUNUWAR LETTER TENTU",NULL},
/* 11BDF */ { "SUNUWAR LETTER THELE",NULL},
/* 11BE0 */ { "SUNUWAR LETTER KLOKO",NULL},
/* 11BE1 */ { "SUNUWAR SIGN PVO",NULL},
/* 11BE2 */ { NULL,NULL},
/* 11BE3 */ { NULL,NULL},
/* 11BE4 */ { NULL,NULL},
/* 11BE5 */ { NULL,NULL},
/* 11BE6 */ { NULL,NULL},
/* 11BE7 */ { NULL,NULL},
/* 11BE8 */ { NULL,NULL},
/* 11BE9 */ { NULL,NULL},
/* 11BEA */ { NULL,NULL},
/* 11BEB */ { NULL,NULL},
/* 11BEC */ { NULL,NULL},
/* 11BED */ { NULL,NULL},
/* 11BEE */ { NULL,NULL},
/* 11BEF */ { NULL,NULL},
/* 11BF0 */ { "SUNUWAR DIGIT ZERO",NULL},
/* 11BF1 */ { "SUNUWAR DIGIT ONE",NULL},
/* 11BF2 */ { "SUNUWAR DIGIT TWO",NULL},
/* 11BF3 */ { "SUNUWAR DIGIT THREE",NULL},
/* 11BF4 */ { "SUNUWAR DIGIT FOUR",NULL},
/* 11BF5 */ { "SUNUWAR DIGIT FIVE",NULL},
/* 11BF6 */ { "SUNUWAR DIGIT SIX",NULL},
/* 11BF7 */ { "SUNUWAR DIGIT SEVEN",NULL},
/* 11BF8 */ { "SUNUWAR DIGIT EIGHT",NULL},
/* 11BF9 */ { "SUNUWAR DIGIT NINE",NULL},
/* 11BFA */ { NULL,NULL},
/* 11BFB */ { NULL,NULL},
/* 11BFC */ { NULL,NULL},
/* 11BFD */ { NULL,NULL},
/* 11BFE */ { NULL,NULL},
/* 11BFF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_1C[] = {
/* 11C00 */ { "BHAIKSUKI LETTER A",NULL},
/* 11C01 */ { "BHAIKSUKI LETTER AA",NULL},
/* 11C02 */ { "BHAIKSUKI LETTER I",NULL},
/* 11C03 */ { "BHAIKSUKI LETTER II",NULL},
/* 11C04 */ { "BHAIKSUKI LETTER U",NULL},
/* 11C05 */ { "BHAIKSUKI LETTER UU",NULL},
/* 11C06 */ { "BHAIKSUKI LETTER VOCALIC R",NULL},
/* 11C07 */ { "BHAIKSUKI LETTER VOCALIC RR",NULL},
/* 11C08 */ { "BHAIKSUKI LETTER VOCALIC L",NULL},
/* 11C09 */ { NULL,NULL},
/* 11C0A */ { "BHAIKSUKI LETTER E",NULL},
/* 11C0B */ { "BHAIKSUKI LETTER AI",NULL},
/* 11C0C */ { "BHAIKSUKI LETTER O",NULL},
/* 11C0D */ { "BHAIKSUKI LETTER AU",NULL},
/* 11C0E */ { "BHAIKSUKI LETTER KA",NULL},
/* 11C0F */ { "BHAIKSUKI LETTER KHA",NULL},
/* 11C10 */ { "BHAIKSUKI LETTER GA",NULL},
/* 11C11 */ { "BHAIKSUKI LETTER GHA",NULL},
/* 11C12 */ { "BHAIKSUKI LETTER NGA",NULL},
/* 11C13 */ { "BHAIKSUKI LETTER CA",NULL},
/* 11C14 */ { "BHAIKSUKI LETTER CHA",NULL},
/* 11C15 */ { "BHAIKSUKI LETTER JA",NULL},
/* 11C16 */ { "BHAIKSUKI LETTER JHA",NULL},
/* 11C17 */ { "BHAIKSUKI LETTER NYA",NULL},
/* 11C18 */ { "BHAIKSUKI LETTER TTA",NULL},
/* 11C19 */ { "BHAIKSUKI LETTER TTHA",NULL},
/* 11C1A */ { "BHAIKSUKI LETTER DDA",NULL},
/* 11C1B */ { "BHAIKSUKI LETTER DDHA",NULL},
/* 11C1C */ { "BHAIKSUKI LETTER NNA",NULL},
/* 11C1D */ { "BHAIKSUKI LETTER TA",NULL},
/* 11C1E */ { "BHAIKSUKI LETTER THA",NULL},
/* 11C1F */ { "BHAIKSUKI LETTER DA",NULL},
/* 11C20 */ { "BHAIKSUKI LETTER DHA",NULL},
/* 11C21 */ { "BHAIKSUKI LETTER NA",NULL},
/* 11C22 */ { "BHAIKSUKI LETTER PA",NULL},
/* 11C23 */ { "BHAIKSUKI LETTER PHA",NULL},
/* 11C24 */ { "BHAIKSUKI LETTER BA",NULL},
/* 11C25 */ { "BHAIKSUKI LETTER BHA",NULL},
/* 11C26 */ { "BHAIKSUKI LETTER MA",NULL},
/* 11C27 */ { "BHAIKSUKI LETTER YA",NULL},
/* 11C28 */ { "BHAIKSUKI LETTER RA",NULL},
/* 11C29 */ { "BHAIKSUKI LETTER LA",NULL},
/* 11C2A */ { "BHAIKSUKI LETTER VA",NULL},
/* 11C2B */ { "BHAIKSUKI LETTER SHA",NULL},
/* 11C2C */ { "BHAIKSUKI LETTER SSA",NULL},
/* 11C2D */ { "BHAIKSUKI LETTER SA",NULL},
/* 11C2E */ { "BHAIKSUKI LETTER HA",NULL},
/* 11C2F */ { "BHAIKSUKI VOWEL SIGN AA",NULL},
/* 11C30 */ { "BHAIKSUKI VOWEL SIGN I",NULL},
/* 11C31 */ { "BHAIKSUKI VOWEL SIGN II",NULL},
/* 11C32 */ { "BHAIKSUKI VOWEL SIGN U",NULL},
/* 11C33 */ { "BHAIKSUKI VOWEL SIGN UU",NULL},
/* 11C34 */ { "BHAIKSUKI VOWEL SIGN VOCALIC R",NULL},
/* 11C35 */ { "BHAIKSUKI VOWEL SIGN VOCALIC RR",NULL},
/* 11C36 */ { "BHAIKSUKI VOWEL SIGN VOCALIC L",NULL},
/* 11C37 */ { NULL,NULL},
/* 11C38 */ { "BHAIKSUKI VOWEL SIGN E",NULL},
/* 11C39 */ { "BHAIKSUKI VOWEL SIGN AI",NULL},
/* 11C3A */ { "BHAIKSUKI VOWEL SIGN O",NULL},
/* 11C3B */ { "BHAIKSUKI VOWEL SIGN AU",NULL},
/* 11C3C */ { "BHAIKSUKI SIGN CANDRABINDU",NULL},
/* 11C3D */ { "BHAIKSUKI SIGN ANUSVARA",NULL},
/* 11C3E */ { "BHAIKSUKI SIGN VISARGA",NULL},
/* 11C3F */ { "BHAIKSUKI SIGN VIRAMA",NULL},
/* 11C40 */ { "BHAIKSUKI SIGN AVAGRAHA",NULL},
/* 11C41 */ { "BHAIKSUKI DANDA",NULL},
/* 11C42 */ { "BHAIKSUKI DOUBLE DANDA",NULL},
/* 11C43 */ { "BHAIKSUKI WORD SEPARATOR",NULL},
/* 11C44 */ { "BHAIKSUKI GAP FILLER-1",NULL},
/* 11C45 */ { "BHAIKSUKI GAP FILLER-2",NULL},
/* 11C46 */ { NULL,NULL},
/* 11C47 */ { NULL,NULL},
/* 11C48 */ { NULL,NULL},
/* 11C49 */ { NULL,NULL},
/* 11C4A */ { NULL,NULL},
/* 11C4B */ { NULL,NULL},
/* 11C4C */ { NULL,NULL},
/* 11C4D */ { NULL,NULL},
/* 11C4E */ { NULL,NULL},
/* 11C4F */ { NULL,NULL},
/* 11C50 */ { "BHAIKSUKI DIGIT ZERO",NULL},
/* 11C51 */ { "BHAIKSUKI DIGIT ONE",NULL},
/* 11C52 */ { "BHAIKSUKI DIGIT TWO",NULL},
/* 11C53 */ { "BHAIKSUKI DIGIT THREE",NULL},
/* 11C54 */ { "BHAIKSUKI DIGIT FOUR",NULL},
/* 11C55 */ { "BHAIKSUKI DIGIT FIVE",NULL},
/* 11C56 */ { "BHAIKSUKI DIGIT SIX",NULL},
/* 11C57 */ { "BHAIKSUKI DIGIT SEVEN",NULL},
/* 11C58 */ { "BHAIKSUKI DIGIT EIGHT",NULL},
/* 11C59 */ { "BHAIKSUKI DIGIT NINE",NULL},
/* 11C5A */ { "BHAIKSUKI NUMBER ONE",NULL},
/* 11C5B */ { "BHAIKSUKI NUMBER TWO",NULL},
/* 11C5C */ { "BHAIKSUKI NUMBER THREE",NULL},
/* 11C5D */ { "BHAIKSUKI NUMBER FOUR",NULL},
/* 11C5E */ { "BHAIKSUKI NUMBER FIVE",NULL},
/* 11C5F */ { "BHAIKSUKI NUMBER SIX",NULL},
/* 11C60 */ { "BHAIKSUKI NUMBER SEVEN",NULL},
/* 11C61 */ { "BHAIKSUKI NUMBER EIGHT",NULL},
/* 11C62 */ { "BHAIKSUKI NUMBER NINE",NULL},
/* 11C63 */ { "BHAIKSUKI NUMBER TEN",NULL},
/* 11C64 */ { "BHAIKSUKI NUMBER TWENTY",NULL},
/* 11C65 */ { "BHAIKSUKI NUMBER THIRTY",NULL},
/* 11C66 */ { "BHAIKSUKI NUMBER FORTY",NULL},
/* 11C67 */ { "BHAIKSUKI NUMBER FIFTY",NULL},
/* 11C68 */ { "BHAIKSUKI NUMBER SIXTY",NULL},
/* 11C69 */ { "BHAIKSUKI NUMBER SEVENTY",NULL},
/* 11C6A */ { "BHAIKSUKI NUMBER EIGHTY",NULL},
/* 11C6B */ { "BHAIKSUKI NUMBER NINETY",NULL},
/* 11C6C */ { "BHAIKSUKI HUNDREDS UNIT MARK",NULL},
/* 11C6D */ { NULL,NULL},
/* 11C6E */ { NULL,NULL},
/* 11C6F */ { NULL,NULL},
/* 11C70 */ { "MARCHEN HEAD MARK","	x (left-facing svasti sign - 0FD6)"},
/* 11C71 */ { "MARCHEN MARK SHAD",NULL},
/* 11C72 */ { "MARCHEN LETTER KA",NULL},
/* 11C73 */ { "MARCHEN LETTER KHA",NULL},
/* 11C74 */ { "MARCHEN LETTER GA",NULL},
/* 11C75 */ { "MARCHEN LETTER NGA",NULL},
/* 11C76 */ { "MARCHEN LETTER CA",NULL},
/* 11C77 */ { "MARCHEN LETTER CHA",NULL},
/* 11C78 */ { "MARCHEN LETTER JA",NULL},
/* 11C79 */ { "MARCHEN LETTER NYA",NULL},
/* 11C7A */ { "MARCHEN LETTER TA",NULL},
/* 11C7B */ { "MARCHEN LETTER THA",NULL},
/* 11C7C */ { "MARCHEN LETTER DA",NULL},
/* 11C7D */ { "MARCHEN LETTER NA",NULL},
/* 11C7E */ { "MARCHEN LETTER PA",NULL},
/* 11C7F */ { "MARCHEN LETTER PHA",NULL},
/* 11C80 */ { "MARCHEN LETTER BA",NULL},
/* 11C81 */ { "MARCHEN LETTER MA",NULL},
/* 11C82 */ { "MARCHEN LETTER TSA",NULL},
/* 11C83 */ { "MARCHEN LETTER TSHA",NULL},
/* 11C84 */ { "MARCHEN LETTER DZA",NULL},
/* 11C85 */ { "MARCHEN LETTER WA",NULL},
/* 11C86 */ { "MARCHEN LETTER ZHA",NULL},
/* 11C87 */ { "MARCHEN LETTER ZA",NULL},
/* 11C88 */ { "MARCHEN LETTER -A",NULL},
/* 11C89 */ { "MARCHEN LETTER YA",NULL},
/* 11C8A */ { "MARCHEN LETTER RA",NULL},
/* 11C8B */ { "MARCHEN LETTER LA",NULL},
/* 11C8C */ { "MARCHEN LETTER SHA",NULL},
/* 11C8D */ { "MARCHEN LETTER SA",NULL},
/* 11C8E */ { "MARCHEN LETTER HA",NULL},
/* 11C8F */ { "MARCHEN LETTER A",NULL},
/* 11C90 */ { NULL,NULL},
/* 11C91 */ { NULL,NULL},
/* 11C92 */ { "MARCHEN SUBJOINED LETTER KA",NULL},
/* 11C93 */ { "MARCHEN SUBJOINED LETTER KHA",NULL},
/* 11C94 */ { "MARCHEN SUBJOINED LETTER GA",NULL},
/* 11C95 */ { "MARCHEN SUBJOINED LETTER NGA",NULL},
/* 11C96 */ { "MARCHEN SUBJOINED LETTER CA",NULL},
/* 11C97 */ { "MARCHEN SUBJOINED LETTER CHA",NULL},
/* 11C98 */ { "MARCHEN SUBJOINED LETTER JA",NULL},
/* 11C99 */ { "MARCHEN SUBJOINED LETTER NYA",NULL},
/* 11C9A */ { "MARCHEN SUBJOINED LETTER TA",NULL},
/* 11C9B */ { "MARCHEN SUBJOINED LETTER THA",NULL},
/* 11C9C */ { "MARCHEN SUBJOINED LETTER DA",NULL},
/* 11C9D */ { "MARCHEN SUBJOINED LETTER NA",NULL},
/* 11C9E */ { "MARCHEN SUBJOINED LETTER PA",NULL},
/* 11C9F */ { "MARCHEN SUBJOINED LETTER PHA",NULL},
/* 11CA0 */ { "MARCHEN SUBJOINED LETTER BA",NULL},
/* 11CA1 */ { "MARCHEN SUBJOINED LETTER MA",NULL},
/* 11CA2 */ { "MARCHEN SUBJOINED LETTER TSA",NULL},
/* 11CA3 */ { "MARCHEN SUBJOINED LETTER TSHA",NULL},
/* 11CA4 */ { "MARCHEN SUBJOINED LETTER DZA",NULL},
/* 11CA5 */ { "MARCHEN SUBJOINED LETTER WA",NULL},
/* 11CA6 */ { "MARCHEN SUBJOINED LETTER ZHA",NULL},
/* 11CA7 */ { "MARCHEN SUBJOINED LETTER ZA",NULL},
/* 11CA8 */ { NULL,NULL},
/* 11CA9 */ { "MARCHEN SUBJOINED LETTER YA",NULL},
/* 11CAA */ { "MARCHEN SUBJOINED LETTER RA",NULL},
/* 11CAB */ { "MARCHEN SUBJOINED LETTER LA",NULL},
/* 11CAC */ { "MARCHEN SUBJOINED LETTER SHA",NULL},
/* 11CAD */ { "MARCHEN SUBJOINED LETTER SA",NULL},
/* 11CAE */ { "MARCHEN SUBJOINED LETTER HA",NULL},
/* 11CAF */ { "MARCHEN SUBJOINED LETTER A",NULL},
/* 11CB0 */ { "MARCHEN VOWEL SIGN AA",NULL},
/* 11CB1 */ { "MARCHEN VOWEL SIGN I",NULL},
/* 11CB2 */ { "MARCHEN VOWEL SIGN U",NULL},
/* 11CB3 */ { "MARCHEN VOWEL SIGN E",NULL},
/* 11CB4 */ { "MARCHEN VOWEL SIGN O",NULL},
/* 11CB5 */ { "MARCHEN SIGN ANUSVARA",NULL},
/* 11CB6 */ { "MARCHEN SIGN CANDRABINDU",NULL},
/* 11CB7 */ { NULL,NULL},
/* 11CB8 */ { NULL,NULL},
/* 11CB9 */ { NULL,NULL},
/* 11CBA */ { NULL,NULL},
/* 11CBB */ { NULL,NULL},
/* 11CBC */ { NULL,NULL},
/* 11CBD */ { NULL,NULL},
/* 11CBE */ { NULL,NULL},
/* 11CBF */ { NULL,NULL},
/* 11CC0 */ { NULL,NULL},
/* 11CC1 */ { NULL,NULL},
/* 11CC2 */ { NULL,NULL},
/* 11CC3 */ { NULL,NULL},
/* 11CC4 */ { NULL,NULL},
/* 11CC5 */ { NULL,NULL},
/* 11CC6 */ { NULL,NULL},
/* 11CC7 */ { NULL,NULL},
/* 11CC8 */ { NULL,NULL},
/* 11CC9 */ { NULL,NULL},
/* 11CCA */ { NULL,NULL},
/* 11CCB */ { NULL,NULL},
/* 11CCC */ { NULL,NULL},
/* 11CCD */ { NULL,NULL},
/* 11CCE */ { NULL,NULL},
/* 11CCF */ { NULL,NULL},
/* 11CD0 */ { NULL,NULL},
/* 11CD1 */ { NULL,NULL},
/* 11CD2 */ { NULL,NULL},
/* 11CD3 */ { NULL,NULL},
/* 11CD4 */ { NULL,NULL},
/* 11CD5 */ { NULL,NULL},
/* 11CD6 */ { NULL,NULL},
/* 11CD7 */ { NULL,NULL},
/* 11CD8 */ { NULL,NULL},
/* 11CD9 */ { NULL,NULL},
/* 11CDA */ { NULL,NULL},
/* 11CDB */ { NULL,NULL},
/* 11CDC */ { NULL,NULL},
/* 11CDD */ { NULL,NULL},
/* 11CDE */ { NULL,NULL},
/* 11CDF */ { NULL,NULL},
/* 11CE0 */ { NULL,NULL},
/* 11CE1 */ { NULL,NULL},
/* 11CE2 */ { NULL,NULL},
/* 11CE3 */ { NULL,NULL},
/* 11CE4 */ { NULL,NULL},
/* 11CE5 */ { NULL,NULL},
/* 11CE6 */ { NULL,NULL},
/* 11CE7 */ { NULL,NULL},
/* 11CE8 */ { NULL,NULL},
/* 11CE9 */ { NULL,NULL},
/* 11CEA */ { NULL,NULL},
/* 11CEB */ { NULL,NULL},
/* 11CEC */ { NULL,NULL},
/* 11CED */ { NULL,NULL},
/* 11CEE */ { NULL,NULL},
/* 11CEF */ { NULL,NULL},
/* 11CF0 */ { NULL,NULL},
/* 11CF1 */ { NULL,NULL},
/* 11CF2 */ { NULL,NULL},
/* 11CF3 */ { NULL,NULL},
/* 11CF4 */ { NULL,NULL},
/* 11CF5 */ { NULL,NULL},
/* 11CF6 */ { NULL,NULL},
/* 11CF7 */ { NULL,NULL},
/* 11CF8 */ { NULL,NULL},
/* 11CF9 */ { NULL,NULL},
/* 11CFA */ { NULL,NULL},
/* 11CFB */ { NULL,NULL},
/* 11CFC */ { NULL,NULL},
/* 11CFD */ { NULL,NULL},
/* 11CFE */ { NULL,NULL},
/* 11CFF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_1D[] = {
/* 11D00 */ { "MASARAM GONDI LETTER A",NULL},
/* 11D01 */ { "MASARAM GONDI LETTER AA",NULL},
/* 11D02 */ { "MASARAM GONDI LETTER I",NULL},
/* 11D03 */ { "MASARAM GONDI LETTER II",NULL},
/* 11D04 */ { "MASARAM GONDI LETTER U",NULL},
/* 11D05 */ { "MASARAM GONDI LETTER UU",NULL},
/* 11D06 */ { "MASARAM GONDI LETTER E",NULL},
/* 11D07 */ { NULL,NULL},
/* 11D08 */ { "MASARAM GONDI LETTER AI",NULL},
/* 11D09 */ { "MASARAM GONDI LETTER O",NULL},
/* 11D0A */ { NULL,NULL},
/* 11D0B */ { "MASARAM GONDI LETTER AU",NULL},
/* 11D0C */ { "MASARAM GONDI LETTER KA",NULL},
/* 11D0D */ { "MASARAM GONDI LETTER KHA",NULL},
/* 11D0E */ { "MASARAM GONDI LETTER GA",NULL},
/* 11D0F */ { "MASARAM GONDI LETTER GHA",NULL},
/* 11D10 */ { "MASARAM GONDI LETTER NGA",NULL},
/* 11D11 */ { "MASARAM GONDI LETTER CA",NULL},
/* 11D12 */ { "MASARAM GONDI LETTER CHA",NULL},
/* 11D13 */ { "MASARAM GONDI LETTER JA",NULL},
/* 11D14 */ { "MASARAM GONDI LETTER JHA",NULL},
/* 11D15 */ { "MASARAM GONDI LETTER NYA",NULL},
/* 11D16 */ { "MASARAM GONDI LETTER TTA",NULL},
/* 11D17 */ { "MASARAM GONDI LETTER TTHA",NULL},
/* 11D18 */ { "MASARAM GONDI LETTER DDA",NULL},
/* 11D19 */ { "MASARAM GONDI LETTER DDHA",NULL},
/* 11D1A */ { "MASARAM GONDI LETTER NNA",NULL},
/* 11D1B */ { "MASARAM GONDI LETTER TA",NULL},
/* 11D1C */ { "MASARAM GONDI LETTER THA",NULL},
/* 11D1D */ { "MASARAM GONDI LETTER DA",NULL},
/* 11D1E */ { "MASARAM GONDI LETTER DHA",NULL},
/* 11D1F */ { "MASARAM GONDI LETTER NA",NULL},
/* 11D20 */ { "MASARAM GONDI LETTER PA",NULL},
/* 11D21 */ { "MASARAM GONDI LETTER PHA",NULL},
/* 11D22 */ { "MASARAM GONDI LETTER BA",NULL},
/* 11D23 */ { "MASARAM GONDI LETTER BHA",NULL},
/* 11D24 */ { "MASARAM GONDI LETTER MA",NULL},
/* 11D25 */ { "MASARAM GONDI LETTER YA",NULL},
/* 11D26 */ { "MASARAM GONDI LETTER RA",NULL},
/* 11D27 */ { "MASARAM GONDI LETTER LA",NULL},
/* 11D28 */ { "MASARAM GONDI LETTER VA",NULL},
/* 11D29 */ { "MASARAM GONDI LETTER SHA",NULL},
/* 11D2A */ { "MASARAM GONDI LETTER SSA",NULL},
/* 11D2B */ { "MASARAM GONDI LETTER SA",NULL},
/* 11D2C */ { "MASARAM GONDI LETTER HA",NULL},
/* 11D2D */ { "MASARAM GONDI LETTER LLA",NULL},
/* 11D2E */ { "MASARAM GONDI LETTER KSSA",NULL},
/* 11D2F */ { "MASARAM GONDI LETTER JNYA",NULL},
/* 11D30 */ { "MASARAM GONDI LETTER TRA",NULL},
/* 11D31 */ { "MASARAM GONDI VOWEL SIGN AA",NULL},
/* 11D32 */ { "MASARAM GONDI VOWEL SIGN I",NULL},
/* 11D33 */ { "MASARAM GONDI VOWEL SIGN II",NULL},
/* 11D34 */ { "MASARAM GONDI VOWEL SIGN U",NULL},
/* 11D35 */ { "MASARAM GONDI VOWEL SIGN UU",NULL},
/* 11D36 */ { "MASARAM GONDI VOWEL SIGN VOCALIC R",NULL},
/* 11D37 */ { NULL,NULL},
/* 11D38 */ { NULL,NULL},
/* 11D39 */ { NULL,NULL},
/* 11D3A */ { "MASARAM GONDI VOWEL SIGN E",NULL},
/* 11D3B */ { NULL,NULL},
/* 11D3C */ { "MASARAM GONDI VOWEL SIGN AI",NULL},
/* 11D3D */ { "MASARAM GONDI VOWEL SIGN O",NULL},
/* 11D3E */ { NULL,NULL},
/* 11D3F */ { "MASARAM GONDI VOWEL SIGN AU",NULL},
/* 11D40 */ { "MASARAM GONDI SIGN ANUSVARA",NULL},
/* 11D41 */ { "MASARAM GONDI SIGN VISARGA",NULL},
/* 11D42 */ { "MASARAM GONDI SIGN NUKTA",NULL},
/* 11D43 */ { "MASARAM GONDI SIGN CANDRA","	* used for transcribing foreign vowels"},
/* 11D44 */ { "MASARAM GONDI SIGN HALANTA","	* used for silencing the inherent vowel"},
/* 11D45 */ { "MASARAM GONDI VIRAMA","	* used to form conjuncts"},
/* 11D46 */ { "MASARAM GONDI REPHA","	* cluster-initial form of 11D26"},
/* 11D47 */ { "MASARAM GONDI RA-KARA","	* cluster-final form of 11D26"},
/* 11D48 */ { NULL,NULL},
/* 11D49 */ { NULL,NULL},
/* 11D4A */ { NULL,NULL},
/* 11D4B */ { NULL,NULL},
/* 11D4C */ { NULL,NULL},
/* 11D4D */ { NULL,NULL},
/* 11D4E */ { NULL,NULL},
/* 11D4F */ { NULL,NULL},
/* 11D50 */ { "MASARAM GONDI DIGIT ZERO",NULL},
/* 11D51 */ { "MASARAM GONDI DIGIT ONE",NULL},
/* 11D52 */ { "MASARAM GONDI DIGIT TWO",NULL},
/* 11D53 */ { "MASARAM GONDI DIGIT THREE",NULL},
/* 11D54 */ { "MASARAM GONDI DIGIT FOUR",NULL},
/* 11D55 */ { "MASARAM GONDI DIGIT FIVE",NULL},
/* 11D56 */ { "MASARAM GONDI DIGIT SIX",NULL},
/* 11D57 */ { "MASARAM GONDI DIGIT SEVEN",NULL},
/* 11D58 */ { "MASARAM GONDI DIGIT EIGHT",NULL},
/* 11D59 */ { "MASARAM GONDI DIGIT NINE",NULL},
/* 11D5A */ { NULL,NULL},
/* 11D5B */ { NULL,NULL},
/* 11D5C */ { NULL,NULL},
/* 11D5D */ { NULL,NULL},
/* 11D5E */ { NULL,NULL},
/* 11D5F */ { NULL,NULL},
/* 11D60 */ { "GUNJALA GONDI LETTER A",NULL},
/* 11D61 */ { "GUNJALA GONDI LETTER AA",NULL},
/* 11D62 */ { "GUNJALA GONDI LETTER I",NULL},
/* 11D63 */ { "GUNJALA GONDI LETTER II",NULL},
/* 11D64 */ { "GUNJALA GONDI LETTER U",NULL},
/* 11D65 */ { "GUNJALA GONDI LETTER UU",NULL},
/* 11D66 */ { NULL,NULL},
/* 11D67 */ { "GUNJALA GONDI LETTER EE",NULL},
/* 11D68 */ { "GUNJALA GONDI LETTER AI",NULL},
/* 11D69 */ { NULL,NULL},
/* 11D6A */ { "GUNJALA GONDI LETTER OO",NULL},
/* 11D6B */ { "GUNJALA GONDI LETTER AU",NULL},
/* 11D6C */ { "GUNJALA GONDI LETTER YA",NULL},
/* 11D6D */ { "GUNJALA GONDI LETTER VA",NULL},
/* 11D6E */ { "GUNJALA GONDI LETTER BA",NULL},
/* 11D6F */ { "GUNJALA GONDI LETTER BHA",NULL},
/* 11D70 */ { "GUNJALA GONDI LETTER MA",NULL},
/* 11D71 */ { "GUNJALA GONDI LETTER KA",NULL},
/* 11D72 */ { "GUNJALA GONDI LETTER KHA",NULL},
/* 11D73 */ { "GUNJALA GONDI LETTER TA",NULL},
/* 11D74 */ { "GUNJALA GONDI LETTER THA",NULL},
/* 11D75 */ { "GUNJALA GONDI LETTER LA",NULL},
/* 11D76 */ { "GUNJALA GONDI LETTER GA",NULL},
/* 11D77 */ { "GUNJALA GONDI LETTER GHA",NULL},
/* 11D78 */ { "GUNJALA GONDI LETTER DA",NULL},
/* 11D79 */ { "GUNJALA GONDI LETTER DHA",NULL},
/* 11D7A */ { "GUNJALA GONDI LETTER NA",NULL},
/* 11D7B */ { "GUNJALA GONDI LETTER CA",NULL},
/* 11D7C */ { "GUNJALA GONDI LETTER CHA",NULL},
/* 11D7D */ { "GUNJALA GONDI LETTER TTA",NULL},
/* 11D7E */ { "GUNJALA GONDI LETTER TTHA",NULL},
/* 11D7F */ { "GUNJALA GONDI LETTER LLA",NULL},
/* 11D80 */ { "GUNJALA GONDI LETTER JA",NULL},
/* 11D81 */ { "GUNJALA GONDI LETTER JHA",NULL},
/* 11D82 */ { "GUNJALA GONDI LETTER DDA",NULL},
/* 11D83 */ { "GUNJALA GONDI LETTER DDHA",NULL},
/* 11D84 */ { "GUNJALA GONDI LETTER NGA",NULL},
/* 11D85 */ { "GUNJALA GONDI LETTER PA",NULL},
/* 11D86 */ { "GUNJALA GONDI LETTER PHA",NULL},
/* 11D87 */ { "GUNJALA GONDI LETTER HA",NULL},
/* 11D88 */ { "GUNJALA GONDI LETTER RA",NULL},
/* 11D89 */ { "GUNJALA GONDI LETTER SA",NULL},
/* 11D8A */ { "GUNJALA GONDI VOWEL SIGN AA",NULL},
/* 11D8B */ { "GUNJALA GONDI VOWEL SIGN I",NULL},
/* 11D8C */ { "GUNJALA GONDI VOWEL SIGN II",NULL},
/* 11D8D */ { "GUNJALA GONDI VOWEL SIGN U",NULL},
/* 11D8E */ { "GUNJALA GONDI VOWEL SIGN UU",NULL},
/* 11D8F */ { NULL,NULL},
/* 11D90 */ { "GUNJALA GONDI VOWEL SIGN EE",NULL},
/* 11D91 */ { "GUNJALA GONDI VOWEL SIGN AI",NULL},
/* 11D92 */ { NULL,NULL},
/* 11D93 */ { "GUNJALA GONDI VOWEL SIGN OO",NULL},
/* 11D94 */ { "GUNJALA GONDI VOWEL SIGN AU",NULL},
/* 11D95 */ { "GUNJALA GONDI SIGN ANUSVARA",NULL},
/* 11D96 */ { "GUNJALA GONDI SIGN VISARGA",NULL},
/* 11D97 */ { "GUNJALA GONDI VIRAMA","	* used to form conjuncts"},
/* 11D98 */ { "GUNJALA GONDI OM",NULL},
/* 11D99 */ { NULL,NULL},
/* 11D9A */ { NULL,NULL},
/* 11D9B */ { NULL,NULL},
/* 11D9C */ { NULL,NULL},
/* 11D9D */ { NULL,NULL},
/* 11D9E */ { NULL,NULL},
/* 11D9F */ { NULL,NULL},
/* 11DA0 */ { "GUNJALA GONDI DIGIT ZERO",NULL},
/* 11DA1 */ { "GUNJALA GONDI DIGIT ONE",NULL},
/* 11DA2 */ { "GUNJALA GONDI DIGIT TWO",NULL},
/* 11DA3 */ { "GUNJALA GONDI DIGIT THREE",NULL},
/* 11DA4 */ { "GUNJALA GONDI DIGIT FOUR",NULL},
/* 11DA5 */ { "GUNJALA GONDI DIGIT FIVE",NULL},
/* 11DA6 */ { "GUNJALA GONDI DIGIT SIX",NULL},
/* 11DA7 */ { "GUNJALA GONDI DIGIT SEVEN",NULL},
/* 11DA8 */ { "GUNJALA GONDI DIGIT EIGHT",NULL},
/* 11DA9 */ { "GUNJALA GONDI DIGIT NINE",NULL},
/* 11DAA */ { NULL,NULL},
/* 11DAB */ { NULL,NULL},
/* 11DAC */ { NULL,NULL},
/* 11DAD */ { NULL,NULL},
/* 11DAE */ { NULL,NULL},
/* 11DAF */ { NULL,NULL},
/* 11DB0 */ { "TOLONG SIKI LETTER I",NULL},
/* 11DB1 */ { "TOLONG SIKI LETTER E",NULL},
/* 11DB2 */ { "TOLONG SIKI LETTER U",NULL},
/* 11DB3 */ { "TOLONG SIKI LETTER O",NULL},
/* 11DB4 */ { "TOLONG SIKI LETTER A",NULL},
/* 11DB5 */ { "TOLONG SIKI LETTER AA",NULL},
/* 11DB6 */ { "TOLONG SIKI LETTER P",NULL},
/* 11DB7 */ { "TOLONG SIKI LETTER PH",NULL},
/* 11DB8 */ { "TOLONG SIKI LETTER B",NULL},
/* 11DB9 */ { "TOLONG SIKI LETTER BH",NULL},
/* 11DBA */ { "TOLONG SIKI LETTER M",NULL},
/* 11DBB */ { "TOLONG SIKI LETTER T",NULL},
/* 11DBC */ { "TOLONG SIKI LETTER TH",NULL},
/* 11DBD */ { "TOLONG SIKI LETTER D",NULL},
/* 11DBE */ { "TOLONG SIKI LETTER DH",NULL},
/* 11DBF */ { "TOLONG SIKI LETTER N",NULL},
/* 11DC0 */ { "TOLONG SIKI LETTER TT",NULL},
/* 11DC1 */ { "TOLONG SIKI LETTER TTH",NULL},
/* 11DC2 */ { "TOLONG SIKI LETTER DD",NULL},
/* 11DC3 */ { "TOLONG SIKI LETTER DDH",NULL},
/* 11DC4 */ { "TOLONG SIKI LETTER NN",NULL},
/* 11DC5 */ { "TOLONG SIKI LETTER C",NULL},
/* 11DC6 */ { "TOLONG SIKI LETTER CH",NULL},
/* 11DC7 */ { "TOLONG SIKI LETTER J",NULL},
/* 11DC8 */ { "TOLONG SIKI LETTER JH",NULL},
/* 11DC9 */ { "TOLONG SIKI LETTER NY",NULL},
/* 11DCA */ { "TOLONG SIKI LETTER K",NULL},
/* 11DCB */ { "TOLONG SIKI LETTER KH",NULL},
/* 11DCC */ { "TOLONG SIKI LETTER G",NULL},
/* 11DCD */ { "TOLONG SIKI LETTER GH",NULL},
/* 11DCE */ { "TOLONG SIKI LETTER NG",NULL},
/* 11DCF */ { "TOLONG SIKI LETTER Y",NULL},
/* 11DD0 */ { "TOLONG SIKI LETTER R",NULL},
/* 11DD1 */ { "TOLONG SIKI LETTER L",NULL},
/* 11DD2 */ { "TOLONG SIKI LETTER V",NULL},
/* 11DD3 */ { "TOLONG SIKI LETTER NNY",NULL},
/* 11DD4 */ { "TOLONG SIKI LETTER S",NULL},
/* 11DD5 */ { "TOLONG SIKI LETTER H",NULL},
/* 11DD6 */ { "TOLONG SIKI LETTER X",NULL},
/* 11DD7 */ { "TOLONG SIKI LETTER RR",NULL},
/* 11DD8 */ { "TOLONG SIKI LETTER RRH",NULL},
/* 11DD9 */ { "TOLONG SIKI SIGN SELA","	= vowel length mark"},
/* 11DDA */ { "TOLONG SIKI SIGN HECAKA","	= tala\n"
	"	* represents a glottal stop"},
/* 11DDB */ { "TOLONG SIKI UNGGA",NULL},
/* 11DDC */ { NULL,NULL},
/* 11DDD */ { NULL,NULL},
/* 11DDE */ { NULL,NULL},
/* 11DDF */ { NULL,NULL},
/* 11DE0 */ { "TOLONG SIKI DIGIT ZERO",NULL},
/* 11DE1 */ { "TOLONG SIKI DIGIT ONE",NULL},
/* 11DE2 */ { "TOLONG SIKI DIGIT TWO",NULL},
/* 11DE3 */ { "TOLONG SIKI DIGIT THREE",NULL},
/* 11DE4 */ { "TOLONG SIKI DIGIT FOUR",NULL},
/* 11DE5 */ { "TOLONG SIKI DIGIT FIVE",NULL},
/* 11DE6 */ { "TOLONG SIKI DIGIT SIX",NULL},
/* 11DE7 */ { "TOLONG SIKI DIGIT SEVEN",NULL},
/* 11DE8 */ { "TOLONG SIKI DIGIT EIGHT",NULL},
/* 11DE9 */ { "TOLONG SIKI DIGIT NINE",NULL},
/* 11DEA */ { NULL,NULL},
/* 11DEB */ { NULL,NULL},
/* 11DEC */ { NULL,NULL},
/* 11DED */ { NULL,NULL},
/* 11DEE */ { NULL,NULL},
/* 11DEF */ { NULL,NULL},
/* 11DF0 */ { NULL,NULL},
/* 11DF1 */ { NULL,NULL},
/* 11DF2 */ { NULL,NULL},
/* 11DF3 */ { NULL,NULL},
/* 11DF4 */ { NULL,NULL},
/* 11DF5 */ { NULL,NULL},
/* 11DF6 */ { NULL,NULL},
/* 11DF7 */ { NULL,NULL},
/* 11DF8 */ { NULL,NULL},
/* 11DF9 */ { NULL,NULL},
/* 11DFA */ { NULL,NULL},
/* 11DFB */ { NULL,NULL},
/* 11DFC */ { NULL,NULL},
/* 11DFD */ { NULL,NULL},
/* 11DFE */ { NULL,NULL},
/* 11DFF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_1E[] = {
/* 11E00 */ { NULL,NULL},
/* 11E01 */ { NULL,NULL},
/* 11E02 */ { NULL,NULL},
/* 11E03 */ { NULL,NULL},
/* 11E04 */ { NULL,NULL},
/* 11E05 */ { NULL,NULL},
/* 11E06 */ { NULL,NULL},
/* 11E07 */ { NULL,NULL},
/* 11E08 */ { NULL,NULL},
/* 11E09 */ { NULL,NULL},
/* 11E0A */ { NULL,NULL},
/* 11E0B */ { NULL,NULL},
/* 11E0C */ { NULL,NULL},
/* 11E0D */ { NULL,NULL},
/* 11E0E */ { NULL,NULL},
/* 11E0F */ { NULL,NULL},
/* 11E10 */ { NULL,NULL},
/* 11E11 */ { NULL,NULL},
/* 11E12 */ { NULL,NULL},
/* 11E13 */ { NULL,NULL},
/* 11E14 */ { NULL,NULL},
/* 11E15 */ { NULL,NULL},
/* 11E16 */ { NULL,NULL},
/* 11E17 */ { NULL,NULL},
/* 11E18 */ { NULL,NULL},
/* 11E19 */ { NULL,NULL},
/* 11E1A */ { NULL,NULL},
/* 11E1B */ { NULL,NULL},
/* 11E1C */ { NULL,NULL},
/* 11E1D */ { NULL,NULL},
/* 11E1E */ { NULL,NULL},
/* 11E1F */ { NULL,NULL},
/* 11E20 */ { NULL,NULL},
/* 11E21 */ { NULL,NULL},
/* 11E22 */ { NULL,NULL},
/* 11E23 */ { NULL,NULL},
/* 11E24 */ { NULL,NULL},
/* 11E25 */ { NULL,NULL},
/* 11E26 */ { NULL,NULL},
/* 11E27 */ { NULL,NULL},
/* 11E28 */ { NULL,NULL},
/* 11E29 */ { NULL,NULL},
/* 11E2A */ { NULL,NULL},
/* 11E2B */ { NULL,NULL},
/* 11E2C */ { NULL,NULL},
/* 11E2D */ { NULL,NULL},
/* 11E2E */ { NULL,NULL},
/* 11E2F */ { NULL,NULL},
/* 11E30 */ { NULL,NULL},
/* 11E31 */ { NULL,NULL},
/* 11E32 */ { NULL,NULL},
/* 11E33 */ { NULL,NULL},
/* 11E34 */ { NULL,NULL},
/* 11E35 */ { NULL,NULL},
/* 11E36 */ { NULL,NULL},
/* 11E37 */ { NULL,NULL},
/* 11E38 */ { NULL,NULL},
/* 11E39 */ { NULL,NULL},
/* 11E3A */ { NULL,NULL},
/* 11E3B */ { NULL,NULL},
/* 11E3C */ { NULL,NULL},
/* 11E3D */ { NULL,NULL},
/* 11E3E */ { NULL,NULL},
/* 11E3F */ { NULL,NULL},
/* 11E40 */ { NULL,NULL},
/* 11E41 */ { NULL,NULL},
/* 11E42 */ { NULL,NULL},
/* 11E43 */ { NULL,NULL},
/* 11E44 */ { NULL,NULL},
/* 11E45 */ { NULL,NULL},
/* 11E46 */ { NULL,NULL},
/* 11E47 */ { NULL,NULL},
/* 11E48 */ { NULL,NULL},
/* 11E49 */ { NULL,NULL},
/* 11E4A */ { NULL,NULL},
/* 11E4B */ { NULL,NULL},
/* 11E4C */ { NULL,NULL},
/* 11E4D */ { NULL,NULL},
/* 11E4E */ { NULL,NULL},
/* 11E4F */ { NULL,NULL},
/* 11E50 */ { NULL,NULL},
/* 11E51 */ { NULL,NULL},
/* 11E52 */ { NULL,NULL},
/* 11E53 */ { NULL,NULL},
/* 11E54 */ { NULL,NULL},
/* 11E55 */ { NULL,NULL},
/* 11E56 */ { NULL,NULL},
/* 11E57 */ { NULL,NULL},
/* 11E58 */ { NULL,NULL},
/* 11E59 */ { NULL,NULL},
/* 11E5A */ { NULL,NULL},
/* 11E5B */ { NULL,NULL},
/* 11E5C */ { NULL,NULL},
/* 11E5D */ { NULL,NULL},
/* 11E5E */ { NULL,NULL},
/* 11E5F */ { NULL,NULL},
/* 11E60 */ { NULL,NULL},
/* 11E61 */ { NULL,NULL},
/* 11E62 */ { NULL,NULL},
/* 11E63 */ { NULL,NULL},
/* 11E64 */ { NULL,NULL},
/* 11E65 */ { NULL,NULL},
/* 11E66 */ { NULL,NULL},
/* 11E67 */ { NULL,NULL},
/* 11E68 */ { NULL,NULL},
/* 11E69 */ { NULL,NULL},
/* 11E6A */ { NULL,NULL},
/* 11E6B */ { NULL,NULL},
/* 11E6C */ { NULL,NULL},
/* 11E6D */ { NULL,NULL},
/* 11E6E */ { NULL,NULL},
/* 11E6F */ { NULL,NULL},
/* 11E70 */ { NULL,NULL},
/* 11E71 */ { NULL,NULL},
/* 11E72 */ { NULL,NULL},
/* 11E73 */ { NULL,NULL},
/* 11E74 */ { NULL,NULL},
/* 11E75 */ { NULL,NULL},
/* 11E76 */ { NULL,NULL},
/* 11E77 */ { NULL,NULL},
/* 11E78 */ { NULL,NULL},
/* 11E79 */ { NULL,NULL},
/* 11E7A */ { NULL,NULL},
/* 11E7B */ { NULL,NULL},
/* 11E7C */ { NULL,NULL},
/* 11E7D */ { NULL,NULL},
/* 11E7E */ { NULL,NULL},
/* 11E7F */ { NULL,NULL},
/* 11E80 */ { NULL,NULL},
/* 11E81 */ { NULL,NULL},
/* 11E82 */ { NULL,NULL},
/* 11E83 */ { NULL,NULL},
/* 11E84 */ { NULL,NULL},
/* 11E85 */ { NULL,NULL},
/* 11E86 */ { NULL,NULL},
/* 11E87 */ { NULL,NULL},
/* 11E88 */ { NULL,NULL},
/* 11E89 */ { NULL,NULL},
/* 11E8A */ { NULL,NULL},
/* 11E8B */ { NULL,NULL},
/* 11E8C */ { NULL,NULL},
/* 11E8D */ { NULL,NULL},
/* 11E8E */ { NULL,NULL},
/* 11E8F */ { NULL,NULL},
/* 11E90 */ { NULL,NULL},
/* 11E91 */ { NULL,NULL},
/* 11E92 */ { NULL,NULL},
/* 11E93 */ { NULL,NULL},
/* 11E94 */ { NULL,NULL},
/* 11E95 */ { NULL,NULL},
/* 11E96 */ { NULL,NULL},
/* 11E97 */ { NULL,NULL},
/* 11E98 */ { NULL,NULL},
/* 11E99 */ { NULL,NULL},
/* 11E9A */ { NULL,NULL},
/* 11E9B */ { NULL,NULL},
/* 11E9C */ { NULL,NULL},
/* 11E9D */ { NULL,NULL},
/* 11E9E */ { NULL,NULL},
/* 11E9F */ { NULL,NULL},
/* 11EA0 */ { NULL,NULL},
/* 11EA1 */ { NULL,NULL},
/* 11EA2 */ { NULL,NULL},
/* 11EA3 */ { NULL,NULL},
/* 11EA4 */ { NULL,NULL},
/* 11EA5 */ { NULL,NULL},
/* 11EA6 */ { NULL,NULL},
/* 11EA7 */ { NULL,NULL},
/* 11EA8 */ { NULL,NULL},
/* 11EA9 */ { NULL,NULL},
/* 11EAA */ { NULL,NULL},
/* 11EAB */ { NULL,NULL},
/* 11EAC */ { NULL,NULL},
/* 11EAD */ { NULL,NULL},
/* 11EAE */ { NULL,NULL},
/* 11EAF */ { NULL,NULL},
/* 11EB0 */ { NULL,NULL},
/* 11EB1 */ { NULL,NULL},
/* 11EB2 */ { NULL,NULL},
/* 11EB3 */ { NULL,NULL},
/* 11EB4 */ { NULL,NULL},
/* 11EB5 */ { NULL,NULL},
/* 11EB6 */ { NULL,NULL},
/* 11EB7 */ { NULL,NULL},
/* 11EB8 */ { NULL,NULL},
/* 11EB9 */ { NULL,NULL},
/* 11EBA */ { NULL,NULL},
/* 11EBB */ { NULL,NULL},
/* 11EBC */ { NULL,NULL},
/* 11EBD */ { NULL,NULL},
/* 11EBE */ { NULL,NULL},
/* 11EBF */ { NULL,NULL},
/* 11EC0 */ { NULL,NULL},
/* 11EC1 */ { NULL,NULL},
/* 11EC2 */ { NULL,NULL},
/* 11EC3 */ { NULL,NULL},
/* 11EC4 */ { NULL,NULL},
/* 11EC5 */ { NULL,NULL},
/* 11EC6 */ { NULL,NULL},
/* 11EC7 */ { NULL,NULL},
/* 11EC8 */ { NULL,NULL},
/* 11EC9 */ { NULL,NULL},
/* 11ECA */ { NULL,NULL},
/* 11ECB */ { NULL,NULL},
/* 11ECC */ { NULL,NULL},
/* 11ECD */ { NULL,NULL},
/* 11ECE */ { NULL,NULL},
/* 11ECF */ { NULL,NULL},
/* 11ED0 */ { NULL,NULL},
/* 11ED1 */ { NULL,NULL},
/* 11ED2 */ { NULL,NULL},
/* 11ED3 */ { NULL,NULL},
/* 11ED4 */ { NULL,NULL},
/* 11ED5 */ { NULL,NULL},
/* 11ED6 */ { NULL,NULL},
/* 11ED7 */ { NULL,NULL},
/* 11ED8 */ { NULL,NULL},
/* 11ED9 */ { NULL,NULL},
/* 11EDA */ { NULL,NULL},
/* 11EDB */ { NULL,NULL},
/* 11EDC */ { NULL,NULL},
/* 11EDD */ { NULL,NULL},
/* 11EDE */ { NULL,NULL},
/* 11EDF */ { NULL,NULL},
/* 11EE0 */ { "MAKASAR LETTER KA",NULL},
/* 11EE1 */ { "MAKASAR LETTER GA",NULL},
/* 11EE2 */ { "MAKASAR LETTER NGA",NULL},
/* 11EE3 */ { "MAKASAR LETTER PA",NULL},
/* 11EE4 */ { "MAKASAR LETTER BA",NULL},
/* 11EE5 */ { "MAKASAR LETTER MA",NULL},
/* 11EE6 */ { "MAKASAR LETTER TA",NULL},
/* 11EE7 */ { "MAKASAR LETTER DA",NULL},
/* 11EE8 */ { "MAKASAR LETTER NA",NULL},
/* 11EE9 */ { "MAKASAR LETTER CA",NULL},
/* 11EEA */ { "MAKASAR LETTER JA",NULL},
/* 11EEB */ { "MAKASAR LETTER NYA",NULL},
/* 11EEC */ { "MAKASAR LETTER YA",NULL},
/* 11EED */ { "MAKASAR LETTER RA",NULL},
/* 11EEE */ { "MAKASAR LETTER LA",NULL},
/* 11EEF */ { "MAKASAR LETTER VA",NULL},
/* 11EF0 */ { "MAKASAR LETTER SA",NULL},
/* 11EF1 */ { "MAKASAR LETTER A",NULL},
/* 11EF2 */ { "MAKASAR ANGKA",NULL},
/* 11EF3 */ { "MAKASAR VOWEL SIGN I",NULL},
/* 11EF4 */ { "MAKASAR VOWEL SIGN U",NULL},
/* 11EF5 */ { "MAKASAR VOWEL SIGN E",NULL},
/* 11EF6 */ { "MAKASAR VOWEL SIGN O",NULL},
/* 11EF7 */ { "MAKASAR PASSIMBANG",NULL},
/* 11EF8 */ { "MAKASAR END OF SECTION",NULL},
/* 11EF9 */ { NULL,NULL},
/* 11EFA */ { NULL,NULL},
/* 11EFB */ { NULL,NULL},
/* 11EFC */ { NULL,NULL},
/* 11EFD */ { NULL,NULL},
/* 11EFE */ { NULL,NULL},
/* 11EFF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_1F[] = {
/* 11F00 */ { "KAWI SIGN CANDRABINDU",NULL},
/* 11F01 */ { "KAWI SIGN ANUSVARA",NULL},
/* 11F02 */ { "KAWI SIGN REPHA","	* cluster-initial form of 11F2C\n"
	"	* also used as final r"},
/* 11F03 */ { "KAWI SIGN VISARGA",NULL},
/* 11F04 */ { "KAWI LETTER A",NULL},
/* 11F05 */ { "KAWI LETTER AA",NULL},
/* 11F06 */ { "KAWI LETTER I",NULL},
/* 11F07 */ { "KAWI LETTER II",NULL},
/* 11F08 */ { "KAWI LETTER U",NULL},
/* 11F09 */ { "KAWI LETTER UU",NULL},
/* 11F0A */ { "KAWI LETTER VOCALIC R",NULL},
/* 11F0B */ { "KAWI LETTER VOCALIC RR",NULL},
/* 11F0C */ { "KAWI LETTER VOCALIC L",NULL},
/* 11F0D */ { "KAWI LETTER VOCALIC LL",NULL},
/* 11F0E */ { "KAWI LETTER E",NULL},
/* 11F0F */ { "KAWI LETTER AI",NULL},
/* 11F10 */ { "KAWI LETTER O",NULL},
/* 11F11 */ { NULL,NULL},
/* 11F12 */ { "KAWI LETTER KA",NULL},
/* 11F13 */ { "KAWI LETTER KHA",NULL},
/* 11F14 */ { "KAWI LETTER GA",NULL},
/* 11F15 */ { "KAWI LETTER GHA",NULL},
/* 11F16 */ { "KAWI LETTER NGA",NULL},
/* 11F17 */ { "KAWI LETTER CA",NULL},
/* 11F18 */ { "KAWI LETTER CHA",NULL},
/* 11F19 */ { "KAWI LETTER JA",NULL},
/* 11F1A */ { "KAWI LETTER JHA",NULL},
/* 11F1B */ { "KAWI LETTER NYA",NULL},
/* 11F1C */ { "KAWI LETTER TTA",NULL},
/* 11F1D */ { "KAWI LETTER TTHA",NULL},
/* 11F1E */ { "KAWI LETTER DDA",NULL},
/* 11F1F */ { "KAWI LETTER DDHA",NULL},
/* 11F20 */ { "KAWI LETTER NNA",NULL},
/* 11F21 */ { "KAWI LETTER TA",NULL},
/* 11F22 */ { "KAWI LETTER THA",NULL},
/* 11F23 */ { "KAWI LETTER DA",NULL},
/* 11F24 */ { "KAWI LETTER DHA",NULL},
/* 11F25 */ { "KAWI LETTER NA",NULL},
/* 11F26 */ { "KAWI LETTER PA",NULL},
/* 11F27 */ { "KAWI LETTER PHA",NULL},
/* 11F28 */ { "KAWI LETTER BA",NULL},
/* 11F29 */ { "KAWI LETTER BHA",NULL},
/* 11F2A */ { "KAWI LETTER MA",NULL},
/* 11F2B */ { "KAWI LETTER YA",NULL},
/* 11F2C */ { "KAWI LETTER RA",NULL},
/* 11F2D */ { "KAWI LETTER LA",NULL},
/* 11F2E */ { "KAWI LETTER WA",NULL},
/* 11F2F */ { "KAWI LETTER SHA",NULL},
/* 11F30 */ { "KAWI LETTER SSA",NULL},
/* 11F31 */ { "KAWI LETTER SA",NULL},
/* 11F32 */ { "KAWI LETTER HA",NULL},
/* 11F33 */ { "KAWI LETTER JNYA",NULL},
/* 11F34 */ { "KAWI VOWEL SIGN AA",NULL},
/* 11F35 */ { "KAWI VOWEL SIGN ALTERNATE AA",NULL},
/* 11F36 */ { "KAWI VOWEL SIGN I",NULL},
/* 11F37 */ { "KAWI VOWEL SIGN II",NULL},
/* 11F38 */ { "KAWI VOWEL SIGN U",NULL},
/* 11F39 */ { "KAWI VOWEL SIGN UU",NULL},
/* 11F3A */ { "KAWI VOWEL SIGN VOCALIC R",NULL},
/* 11F3B */ { NULL,NULL},
/* 11F3C */ { NULL,NULL},
/* 11F3D */ { NULL,NULL},
/* 11F3E */ { "KAWI VOWEL SIGN E",NULL},
/* 11F3F */ { "KAWI VOWEL SIGN AI",NULL},
/* 11F40 */ { "KAWI VOWEL SIGN EU","	* represents schwa [ə]"},
/* 11F41 */ { "KAWI SIGN KILLER","	* vowel killer, always rendered visibly"},
/* 11F42 */ { "KAWI CONJOINER","	* used for producing below-base and post-base conjunct forms"},
/* 11F43 */ { "KAWI DANDA",NULL},
/* 11F44 */ { "KAWI DOUBLE DANDA",NULL},
/* 11F45 */ { "KAWI PUNCTUATION SECTION MARKER",NULL},
/* 11F46 */ { "KAWI PUNCTUATION ALTERNATE SECTION MARKER",NULL},
/* 11F47 */ { "KAWI PUNCTUATION FLOWER",NULL},
/* 11F48 */ { "KAWI PUNCTUATION SPACE FILLER",NULL},
/* 11F49 */ { "KAWI PUNCTUATION DOT",NULL},
/* 11F4A */ { "KAWI PUNCTUATION DOUBLE DOT",NULL},
/* 11F4B */ { "KAWI PUNCTUATION TRIPLE DOT",NULL},
/* 11F4C */ { "KAWI PUNCTUATION CIRCLE",NULL},
/* 11F4D */ { "KAWI PUNCTUATION FILLED CIRCLE",NULL},
/* 11F4E */ { "KAWI PUNCTUATION SPIRAL",NULL},
/* 11F4F */ { "KAWI PUNCTUATION CLOSING SPIRAL",NULL},
/* 11F50 */ { "KAWI DIGIT ZERO",NULL},
/* 11F51 */ { "KAWI DIGIT ONE",NULL},
/* 11F52 */ { "KAWI DIGIT TWO","	* also used as letter ro"},
/* 11F53 */ { "KAWI DIGIT THREE",NULL},
/* 11F54 */ { "KAWI DIGIT FOUR",NULL},
/* 11F55 */ { "KAWI DIGIT FIVE",NULL},
/* 11F56 */ { "KAWI DIGIT SIX",NULL},
/* 11F57 */ { "KAWI DIGIT SEVEN",NULL},
/* 11F58 */ { "KAWI DIGIT EIGHT",NULL},
/* 11F59 */ { "KAWI DIGIT NINE",NULL},
/* 11F5A */ { "KAWI SIGN NUKTA",NULL},
/* 11F5B */ { NULL,NULL},
/* 11F5C */ { NULL,NULL},
/* 11F5D */ { NULL,NULL},
/* 11F5E */ { NULL,NULL},
/* 11F5F */ { NULL,NULL},
/* 11F60 */ { NULL,NULL},
/* 11F61 */ { NULL,NULL},
/* 11F62 */ { NULL,NULL},
/* 11F63 */ { NULL,NULL},
/* 11F64 */ { NULL,NULL},
/* 11F65 */ { NULL,NULL},
/* 11F66 */ { NULL,NULL},
/* 11F67 */ { NULL,NULL},
/* 11F68 */ { NULL,NULL},
/* 11F69 */ { NULL,NULL},
/* 11F6A */ { NULL,NULL},
/* 11F6B */ { NULL,NULL},
/* 11F6C */ { NULL,NULL},
/* 11F6D */ { NULL,NULL},
/* 11F6E */ { NULL,NULL},
/* 11F6F */ { NULL,NULL},
/* 11F70 */ { NULL,NULL},
/* 11F71 */ { NULL,NULL},
/* 11F72 */ { NULL,NULL},
/* 11F73 */ { NULL,NULL},
/* 11F74 */ { NULL,NULL},
/* 11F75 */ { NULL,NULL},
/* 11F76 */ { NULL,NULL},
/* 11F77 */ { NULL,NULL},
/* 11F78 */ { NULL,NULL},
/* 11F79 */ { NULL,NULL},
/* 11F7A */ { NULL,NULL},
/* 11F7B */ { NULL,NULL},
/* 11F7C */ { NULL,NULL},
/* 11F7D */ { NULL,NULL},
/* 11F7E */ { NULL,NULL},
/* 11F7F */ { NULL,NULL},
/* 11F80 */ { NULL,NULL},
/* 11F81 */ { NULL,NULL},
/* 11F82 */ { NULL,NULL},
/* 11F83 */ { NULL,NULL},
/* 11F84 */ { NULL,NULL},
/* 11F85 */ { NULL,NULL},
/* 11F86 */ { NULL,NULL},
/* 11F87 */ { NULL,NULL},
/* 11F88 */ { NULL,NULL},
/* 11F89 */ { NULL,NULL},
/* 11F8A */ { NULL,NULL},
/* 11F8B */ { NULL,NULL},
/* 11F8C */ { NULL,NULL},
/* 11F8D */ { NULL,NULL},
/* 11F8E */ { NULL,NULL},
/* 11F8F */ { NULL,NULL},
/* 11F90 */ { NULL,NULL},
/* 11F91 */ { NULL,NULL},
/* 11F92 */ { NULL,NULL},
/* 11F93 */ { NULL,NULL},
/* 11F94 */ { NULL,NULL},
/* 11F95 */ { NULL,NULL},
/* 11F96 */ { NULL,NULL},
/* 11F97 */ { NULL,NULL},
/* 11F98 */ { NULL,NULL},
/* 11F99 */ { NULL,NULL},
/* 11F9A */ { NULL,NULL},
/* 11F9B */ { NULL,NULL},
/* 11F9C */ { NULL,NULL},
/* 11F9D */ { NULL,NULL},
/* 11F9E */ { NULL,NULL},
/* 11F9F */ { NULL,NULL},
/* 11FA0 */ { NULL,NULL},
/* 11FA1 */ { NULL,NULL},
/* 11FA2 */ { NULL,NULL},
/* 11FA3 */ { NULL,NULL},
/* 11FA4 */ { NULL,NULL},
/* 11FA5 */ { NULL,NULL},
/* 11FA6 */ { NULL,NULL},
/* 11FA7 */ { NULL,NULL},
/* 11FA8 */ { NULL,NULL},
/* 11FA9 */ { NULL,NULL},
/* 11FAA */ { NULL,NULL},
/* 11FAB */ { NULL,NULL},
/* 11FAC */ { NULL,NULL},
/* 11FAD */ { NULL,NULL},
/* 11FAE */ { NULL,NULL},
/* 11FAF */ { NULL,NULL},
/* 11FB0 */ { "LISU LETTER YHA","	* used for the Naxi language\n"
	"	x (turned sans-serif capital y - 2144)\n"
	"	x (lisu letter ya - A4EC)"},
/* 11FB1 */ { NULL,NULL},
/* 11FB2 */ { NULL,NULL},
/* 11FB3 */ { NULL,NULL},
/* 11FB4 */ { NULL,NULL},
/* 11FB5 */ { NULL,NULL},
/* 11FB6 */ { NULL,NULL},
/* 11FB7 */ { NULL,NULL},
/* 11FB8 */ { NULL,NULL},
/* 11FB9 */ { NULL,NULL},
/* 11FBA */ { NULL,NULL},
/* 11FBB */ { NULL,NULL},
/* 11FBC */ { NULL,NULL},
/* 11FBD */ { NULL,NULL},
/* 11FBE */ { NULL,NULL},
/* 11FBF */ { NULL,NULL},
/* 11FC0 */ { "TAMIL FRACTION ONE THREE-HUNDRED-AND-TWENTIETH","	= munthiri"},
/* 11FC1 */ { "TAMIL FRACTION ONE ONE-HUNDRED-AND-SIXTIETH","	= araikkaani"},
/* 11FC2 */ { "TAMIL FRACTION ONE EIGHTIETH","	= kaani"},
/* 11FC3 */ { "TAMIL FRACTION ONE SIXTY-FOURTH","	= kaal viisam"},
/* 11FC4 */ { "TAMIL FRACTION ONE FORTIETH","	= arai maa"},
/* 11FC5 */ { "TAMIL FRACTION ONE THIRTY-SECOND","	= arai viisam"},
/* 11FC6 */ { "TAMIL FRACTION THREE EIGHTIETHS","	= mukkaani"},
/* 11FC7 */ { "TAMIL FRACTION THREE SIXTY-FOURTHS","	= mukkaal viisam"},
/* 11FC8 */ { "TAMIL FRACTION ONE TWENTIETH","	= maa\n"
	"	x (tamil letter pa - 0BAA)"},
/* 11FC9 */ { "TAMIL FRACTION ONE SIXTEENTH-1","	= viisam/maakaani"},
/* 11FCA */ { "TAMIL FRACTION ONE SIXTEENTH-2","	= viisam/maakaani\n"
	"	* alternate representation"},
/* 11FCB */ { "TAMIL FRACTION ONE TENTH","	= irumaa"},
/* 11FCC */ { "TAMIL FRACTION ONE EIGHTH","	= araikkaal"},
/* 11FCD */ { "TAMIL FRACTION THREE TWENTIETHS","	= mummaa"},
/* 11FCE */ { "TAMIL FRACTION THREE SIXTEENTHS","	= muuviisam/mummaamukkaani"},
/* 11FCF */ { "TAMIL FRACTION ONE FIFTH","	= naangu maa"},
/* 11FD0 */ { "TAMIL FRACTION ONE QUARTER","	= kaal\n"
	"	x (tamil letter va - 0BB5)"},
/* 11FD1 */ { "TAMIL FRACTION ONE HALF-1","	= arai"},
/* 11FD2 */ { "TAMIL FRACTION ONE HALF-2","	= arai\n"
	"	* alternate representation"},
/* 11FD3 */ { "TAMIL FRACTION THREE QUARTERS","	= mukkaal"},
/* 11FD4 */ { "TAMIL FRACTION DOWNSCALING FACTOR KIIZH","	* when prefixed to a fraction, reduces its value by a factor of 1/320"},
/* 11FD5 */ { "TAMIL SIGN NEL","	* one grain of paddy"},
/* 11FD6 */ { "TAMIL SIGN CEVITU","	* equals 360 nel"},
/* 11FD7 */ { "TAMIL SIGN AAZHAAKKU","	* equals 5 cevitu"},
/* 11FD8 */ { "TAMIL SIGN UZHAKKU","	* equals 2 aazhaakku\n"
	"	* for the measure uri which equals 2 uzhakku, use the sequence 0B89 0BB0 0BBF"},
/* 11FD9 */ { "TAMIL SIGN MUUVUZHAKKU","	* equals 3 uzhakku\n"
	"	* for the measure naazhi/padi which equals 2 uri, use 0BF3\n"
	"	x (tamil day sign - 0BF3)"},
/* 11FDA */ { "TAMIL SIGN KURUNI","	= marakkaal\n"
	"	* equals 8 naazhi/padi\n"
	"	x (tamil letter nga - 0B99)"},
/* 11FDB */ { "TAMIL SIGN PATHAKKU","	* equals 2 kuruni/marakkaal"},
/* 11FDC */ { "TAMIL SIGN MUKKURUNI","	* equals 3 kuruni/marakkaal\n"
	"	* for the measure thuuni which equals 2 pathakku, use 0BA4\n"
	"	x (tamil letter ta - 0BA4)\n"
	"	* for the measure kalam which equals 3 thuuni, use 0BB3\n"
	"	x (tamil letter lla - 0BB3)"},
/* 11FDD */ { "TAMIL SIGN KAACU","	* small currency unit"},
/* 11FDE */ { "TAMIL SIGN PANAM",NULL},
/* 11FDF */ { "TAMIL SIGN PON","	* gold coin"},
/* 11FE0 */ { "TAMIL SIGN VARAAKAN","	* gold coin bearing boar insignia"},
/* 11FE1 */ { "TAMIL SIGN PAARAM","	* approximately equals 500 pounds (227 kg)"},
/* 11FE2 */ { "TAMIL SIGN KUZHI","	* equals 1 square kol, where 1 kol is approximately 11 feet (3.35 m)"},
/* 11FE3 */ { "TAMIL SIGN VELI","	= veeli\n"
	"	* equals 2000 kuzhi"},
/* 11FE4 */ { "TAMIL WET CULTIVATION SIGN","	= nansey"},
/* 11FE5 */ { "TAMIL DRY CULTIVATION SIGN","	= punsey"},
/* 11FE6 */ { "TAMIL LAND SIGN","	= nilam\n"
	"	* distinct from the rupee sign\n"
	"	x (tamil rupee sign - 0BF9)"},
/* 11FE7 */ { "TAMIL SALT PAN SIGN","	= uppalam"},
/* 11FE8 */ { "TAMIL TRADITIONAL CREDIT SIGN","	= varavu\n"
	"	x (tamil credit sign - 0BF7)"},
/* 11FE9 */ { "TAMIL TRADITIONAL NUMBER SIGN","	= enn\n"
	"	x (tamil number sign - 0BFA)"},
/* 11FEA */ { "TAMIL CURRENT SIGN","	= naalathu"},
/* 11FEB */ { "TAMIL AND ODD SIGN","	= silvaanam/sillarai"},
/* 11FEC */ { "TAMIL SPENT SIGN","	= poga"},
/* 11FED */ { "TAMIL TOTAL SIGN","	= aaga"},
/* 11FEE */ { "TAMIL IN POSSESSION SIGN","	= vasam"},
/* 11FEF */ { "TAMIL STARTING FROM SIGN","	= muthal"},
/* 11FF0 */ { "TAMIL SIGN MUTHALIYA","	= et cetera\n"
	"	* indicates items in a series"},
/* 11FF1 */ { "TAMIL SIGN VAKAIYARAA","	= et cetera\n"
	"	* indicates items of a family or kind"},
/* 11FF2 */ { NULL,NULL},
/* 11FF3 */ { NULL,NULL},
/* 11FF4 */ { NULL,NULL},
/* 11FF5 */ { NULL,NULL},
/* 11FF6 */ { NULL,NULL},
/* 11FF7 */ { NULL,NULL},
/* 11FF8 */ { NULL,NULL},
/* 11FF9 */ { NULL,NULL},
/* 11FFA */ { NULL,NULL},
/* 11FFB */ { NULL,NULL},
/* 11FFC */ { NULL,NULL},
/* 11FFD */ { NULL,NULL},
/* 11FFE */ { NULL,NULL},
/* 11FFF */ { "TAMIL PUNCTUATION END OF TEXT","	x (sinhala punctuation kunddaliya - 0DF4)"}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_20[] = {
/* 12000 */ { "CUNEIFORM SIGN A",NULL},
/* 12001 */ { "CUNEIFORM SIGN A TIMES A",NULL},
/* 12002 */ { "CUNEIFORM SIGN A TIMES BAD",NULL},
/* 12003 */ { "CUNEIFORM SIGN A TIMES GAN2 TENU",NULL},
/* 12004 */ { "CUNEIFORM SIGN A TIMES HA",NULL},
/* 12005 */ { "CUNEIFORM SIGN A TIMES IGI",NULL},
/* 12006 */ { "CUNEIFORM SIGN A TIMES LAGAR GUNU",NULL},
/* 12007 */ { "CUNEIFORM SIGN A TIMES MUSH",NULL},
/* 12008 */ { "CUNEIFORM SIGN A TIMES SAG",NULL},
/* 12009 */ { "CUNEIFORM SIGN A2",NULL},
/* 1200A */ { "CUNEIFORM SIGN AB",NULL},
/* 1200B */ { "CUNEIFORM SIGN AB TIMES ASH2",NULL},
/* 1200C */ { "CUNEIFORM SIGN AB TIMES DUN3 GUNU",NULL},
/* 1200D */ { "CUNEIFORM SIGN AB TIMES GAL",NULL},
/* 1200E */ { "CUNEIFORM SIGN AB TIMES GAN2 TENU",NULL},
/* 1200F */ { "CUNEIFORM SIGN AB TIMES HA",NULL},
/* 12010 */ { "CUNEIFORM SIGN AB TIMES IGI GUNU",NULL},
/* 12011 */ { "CUNEIFORM SIGN AB TIMES IMIN",NULL},
/* 12012 */ { "CUNEIFORM SIGN AB TIMES LAGAB",NULL},
/* 12013 */ { "CUNEIFORM SIGN AB TIMES SHESH",NULL},
/* 12014 */ { "CUNEIFORM SIGN AB TIMES U PLUS U PLUS U",NULL},
/* 12015 */ { "CUNEIFORM SIGN AB GUNU",NULL},
/* 12016 */ { "CUNEIFORM SIGN AB2",NULL},
/* 12017 */ { "CUNEIFORM SIGN AB2 TIMES BALAG",NULL},
/* 12018 */ { "CUNEIFORM SIGN AB2 TIMES GAN2 TENU",NULL},
/* 12019 */ { "CUNEIFORM SIGN AB2 TIMES ME PLUS EN",NULL},
/* 1201A */ { "CUNEIFORM SIGN AB2 TIMES SHA3",NULL},
/* 1201B */ { "CUNEIFORM SIGN AB2 TIMES TAK4",NULL},
/* 1201C */ { "CUNEIFORM SIGN AD",NULL},
/* 1201D */ { "CUNEIFORM SIGN AK",NULL},
/* 1201E */ { "CUNEIFORM SIGN AK TIMES ERIN2",NULL},
/* 1201F */ { "CUNEIFORM SIGN AK TIMES SHITA PLUS GISH",NULL},
/* 12020 */ { "CUNEIFORM SIGN AL",NULL},
/* 12021 */ { "CUNEIFORM SIGN AL TIMES AL",NULL},
/* 12022 */ { "CUNEIFORM SIGN AL TIMES DIM2",NULL},
/* 12023 */ { "CUNEIFORM SIGN AL TIMES GISH",NULL},
/* 12024 */ { "CUNEIFORM SIGN AL TIMES HA",NULL},
/* 12025 */ { "CUNEIFORM SIGN AL TIMES KAD3",NULL},
/* 12026 */ { "CUNEIFORM SIGN AL TIMES KI",NULL},
/* 12027 */ { "CUNEIFORM SIGN AL TIMES SHE",NULL},
/* 12028 */ { "CUNEIFORM SIGN AL TIMES USH",NULL},
/* 12029 */ { "CUNEIFORM SIGN ALAN",NULL},
/* 1202A */ { "CUNEIFORM SIGN ALEPH",NULL},
/* 1202B */ { "CUNEIFORM SIGN AMAR",NULL},
/* 1202C */ { "CUNEIFORM SIGN AMAR TIMES SHE",NULL},
/* 1202D */ { "CUNEIFORM SIGN AN",NULL},
/* 1202E */ { "CUNEIFORM SIGN AN OVER AN",NULL},
/* 1202F */ { "CUNEIFORM SIGN AN THREE TIMES",NULL},
/* 12030 */ { "CUNEIFORM SIGN AN PLUS NAGA OPPOSING AN PLUS NAGA",NULL},
/* 12031 */ { "CUNEIFORM SIGN AN PLUS NAGA SQUARED",NULL},
/* 12032 */ { "CUNEIFORM SIGN ANSHE",NULL},
/* 12033 */ { "CUNEIFORM SIGN APIN",NULL},
/* 12034 */ { "CUNEIFORM SIGN ARAD",NULL},
/* 12035 */ { "CUNEIFORM SIGN ARAD TIMES KUR",NULL},
/* 12036 */ { "CUNEIFORM SIGN ARKAB",NULL},
/* 12037 */ { "CUNEIFORM SIGN ASAL2",NULL},
/* 12038 */ { "CUNEIFORM SIGN ASH","	= 1 aš\n"
	"	x (cuneiform numeric sign two ash - 12400)"},
/* 12039 */ { "CUNEIFORM SIGN ASH ZIDA TENU","	= 1 aš tenû\n"
	"	= 1 diš tenû\n"
	"	= 1/2 iku\n"
	"	x (cuneiform numeric sign two ash tenu - 1244A)"},
/* 1203A */ { "CUNEIFORM SIGN ASH KABA TENU",NULL},
/* 1203B */ { "CUNEIFORM SIGN ASH OVER ASH TUG2 OVER TUG2 TUG2 OVER TUG2 PAP",NULL},
/* 1203C */ { "CUNEIFORM SIGN ASH OVER ASH OVER ASH",NULL},
/* 1203D */ { "CUNEIFORM SIGN ASH OVER ASH OVER ASH CROSSING ASH OVER ASH OVER ASH",NULL},
/* 1203E */ { "CUNEIFORM SIGN ASH2","	x (cuneiform numeric sign four ban2 variant form - 12453)"},
/* 1203F */ { "CUNEIFORM SIGN ASHGAB",NULL},
/* 12040 */ { "CUNEIFORM SIGN BA",NULL},
/* 12041 */ { "CUNEIFORM SIGN BAD",NULL},
/* 12042 */ { "CUNEIFORM SIGN BAG3",NULL},
/* 12043 */ { "CUNEIFORM SIGN BAHAR2",NULL},
/* 12044 */ { "CUNEIFORM SIGN BAL",NULL},
/* 12045 */ { "CUNEIFORM SIGN BAL OVER BAL",NULL},
/* 12046 */ { "CUNEIFORM SIGN BALAG",NULL},
/* 12047 */ { "CUNEIFORM SIGN BAR",NULL},
/* 12048 */ { "CUNEIFORM SIGN BARA2",NULL},
/* 12049 */ { "CUNEIFORM SIGN BI",NULL},
/* 1204A */ { "CUNEIFORM SIGN BI TIMES A",NULL},
/* 1204B */ { "CUNEIFORM SIGN BI TIMES GAR",NULL},
/* 1204C */ { "CUNEIFORM SIGN BI TIMES IGI GUNU",NULL},
/* 1204D */ { "CUNEIFORM SIGN BU",NULL},
/* 1204E */ { "CUNEIFORM SIGN BU OVER BU AB",NULL},
/* 1204F */ { "CUNEIFORM SIGN BU OVER BU UN",NULL},
/* 12050 */ { "CUNEIFORM SIGN BU CROSSING BU",NULL},
/* 12051 */ { "CUNEIFORM SIGN BULUG",NULL},
/* 12052 */ { "CUNEIFORM SIGN BULUG OVER BULUG",NULL},
/* 12053 */ { "CUNEIFORM SIGN BUR",NULL},
/* 12054 */ { "CUNEIFORM SIGN BUR2",NULL},
/* 12055 */ { "CUNEIFORM SIGN DA",NULL},
/* 12056 */ { "CUNEIFORM SIGN DAG",NULL},
/* 12057 */ { "CUNEIFORM SIGN DAG KISIM5 TIMES A PLUS MASH",NULL},
/* 12058 */ { "CUNEIFORM SIGN DAG KISIM5 TIMES AMAR",NULL},
/* 12059 */ { "CUNEIFORM SIGN DAG KISIM5 TIMES BALAG",NULL},
/* 1205A */ { "CUNEIFORM SIGN DAG KISIM5 TIMES BI",NULL},
/* 1205B */ { "CUNEIFORM SIGN DAG KISIM5 TIMES GA",NULL},
/* 1205C */ { "CUNEIFORM SIGN DAG KISIM5 TIMES GA PLUS MASH",NULL},
/* 1205D */ { "CUNEIFORM SIGN DAG KISIM5 TIMES GI",NULL},
/* 1205E */ { "CUNEIFORM SIGN DAG KISIM5 TIMES GIR2",NULL},
/* 1205F */ { "CUNEIFORM SIGN DAG KISIM5 TIMES GUD",NULL},
/* 12060 */ { "CUNEIFORM SIGN DAG KISIM5 TIMES HA",NULL},
/* 12061 */ { "CUNEIFORM SIGN DAG KISIM5 TIMES IR",NULL},
/* 12062 */ { "CUNEIFORM SIGN DAG KISIM5 TIMES IR PLUS LU",NULL},
/* 12063 */ { "CUNEIFORM SIGN DAG KISIM5 TIMES KAK",NULL},
/* 12064 */ { "CUNEIFORM SIGN DAG KISIM5 TIMES LA",NULL},
/* 12065 */ { "CUNEIFORM SIGN DAG KISIM5 TIMES LU",NULL},
/* 12066 */ { "CUNEIFORM SIGN DAG KISIM5 TIMES LU PLUS MASH2",NULL},
/* 12067 */ { "CUNEIFORM SIGN DAG KISIM5 TIMES LUM",NULL},
/* 12068 */ { "CUNEIFORM SIGN DAG KISIM5 TIMES NE",NULL},
/* 12069 */ { "CUNEIFORM SIGN DAG KISIM5 TIMES PAP PLUS PAP",NULL},
/* 1206A */ { "CUNEIFORM SIGN DAG KISIM5 TIMES SI",NULL},
/* 1206B */ { "CUNEIFORM SIGN DAG KISIM5 TIMES TAK4",NULL},
/* 1206C */ { "CUNEIFORM SIGN DAG KISIM5 TIMES U2 PLUS GIR2",NULL},
/* 1206D */ { "CUNEIFORM SIGN DAG KISIM5 TIMES USH",NULL},
/* 1206E */ { "CUNEIFORM SIGN DAM",NULL},
/* 1206F */ { "CUNEIFORM SIGN DAR",NULL},
/* 12070 */ { "CUNEIFORM SIGN DARA3",NULL},
/* 12071 */ { "CUNEIFORM SIGN DARA4",NULL},
/* 12072 */ { "CUNEIFORM SIGN DI",NULL},
/* 12073 */ { "CUNEIFORM SIGN DIB",NULL},
/* 12074 */ { "CUNEIFORM SIGN DIM",NULL},
/* 12075 */ { "CUNEIFORM SIGN DIM TIMES SHE",NULL},
/* 12076 */ { "CUNEIFORM SIGN DIM2",NULL},
/* 12077 */ { "CUNEIFORM SIGN DIN",NULL},
/* 12078 */ { "CUNEIFORM SIGN DIN KASKAL U GUNU DISH",NULL},
/* 12079 */ { "CUNEIFORM SIGN DISH","	= 1 diš\n"
	"	= 1 bariga\n"
	"	x (cuneiform numeric sign three dish - 12408)\n"
	"	x (cuneiform numeric sign nigidamin - 12456)\n"
	"	x (cuneiform numeric sign nigidaesh - 12457)"},
/* 1207A */ { "CUNEIFORM SIGN DU",NULL},
/* 1207B */ { "CUNEIFORM SIGN DU OVER DU",NULL},
/* 1207C */ { "CUNEIFORM SIGN DU GUNU",NULL},
/* 1207D */ { "CUNEIFORM SIGN DU SHESHIG",NULL},
/* 1207E */ { "CUNEIFORM SIGN DUB",NULL},
/* 1207F */ { "CUNEIFORM SIGN DUB TIMES ESH2",NULL},
/* 12080 */ { "CUNEIFORM SIGN DUB2",NULL},
/* 12081 */ { "CUNEIFORM SIGN DUG",NULL},
/* 12082 */ { "CUNEIFORM SIGN DUGUD",NULL},
/* 12083 */ { "CUNEIFORM SIGN DUH",NULL},
/* 12084 */ { "CUNEIFORM SIGN DUN",NULL},
/* 12085 */ { "CUNEIFORM SIGN DUN3",NULL},
/* 12086 */ { "CUNEIFORM SIGN DUN3 GUNU",NULL},
/* 12087 */ { "CUNEIFORM SIGN DUN3 GUNU GUNU",NULL},
/* 12088 */ { "CUNEIFORM SIGN DUN4",NULL},
/* 12089 */ { "CUNEIFORM SIGN DUR2",NULL},
/* 1208A */ { "CUNEIFORM SIGN E",NULL},
/* 1208B */ { "CUNEIFORM SIGN E TIMES PAP",NULL},
/* 1208C */ { "CUNEIFORM SIGN E OVER E NUN OVER NUN",NULL},
/* 1208D */ { "CUNEIFORM SIGN E2",NULL},
/* 1208E */ { "CUNEIFORM SIGN E2 TIMES A PLUS HA PLUS DA",NULL},
/* 1208F */ { "CUNEIFORM SIGN E2 TIMES GAR",NULL},
/* 12090 */ { "CUNEIFORM SIGN E2 TIMES MI",NULL},
/* 12091 */ { "CUNEIFORM SIGN E2 TIMES SAL",NULL},
/* 12092 */ { "CUNEIFORM SIGN E2 TIMES SHE",NULL},
/* 12093 */ { "CUNEIFORM SIGN E2 TIMES U",NULL},
/* 12094 */ { "CUNEIFORM SIGN EDIN",NULL},
/* 12095 */ { "CUNEIFORM SIGN EGIR",NULL},
/* 12096 */ { "CUNEIFORM SIGN EL",NULL},
/* 12097 */ { "CUNEIFORM SIGN EN",NULL},
/* 12098 */ { "CUNEIFORM SIGN EN TIMES GAN2",NULL},
/* 12099 */ { "CUNEIFORM SIGN EN TIMES GAN2 TENU",NULL},
/* 1209A */ { "CUNEIFORM SIGN EN TIMES ME",NULL},
/* 1209B */ { "CUNEIFORM SIGN EN CROSSING EN",NULL},
/* 1209C */ { "CUNEIFORM SIGN EN OPPOSING EN",NULL},
/* 1209D */ { "CUNEIFORM SIGN EN SQUARED",NULL},
/* 1209E */ { "CUNEIFORM SIGN EREN",NULL},
/* 1209F */ { "CUNEIFORM SIGN ERIN2",NULL},
/* 120A0 */ { "CUNEIFORM SIGN ESH2",NULL},
/* 120A1 */ { "CUNEIFORM SIGN EZEN",NULL},
/* 120A2 */ { "CUNEIFORM SIGN EZEN TIMES A",NULL},
/* 120A3 */ { "CUNEIFORM SIGN EZEN TIMES A PLUS LAL",NULL},
/* 120A4 */ { "CUNEIFORM SIGN EZEN TIMES A PLUS LAL TIMES LAL",NULL},
/* 120A5 */ { "CUNEIFORM SIGN EZEN TIMES AN",NULL},
/* 120A6 */ { "CUNEIFORM SIGN EZEN TIMES BAD",NULL},
/* 120A7 */ { "CUNEIFORM SIGN EZEN TIMES DUN3 GUNU",NULL},
/* 120A8 */ { "CUNEIFORM SIGN EZEN TIMES DUN3 GUNU GUNU",NULL},
/* 120A9 */ { "CUNEIFORM SIGN EZEN TIMES HA",NULL},
/* 120AA */ { "CUNEIFORM SIGN EZEN TIMES HA GUNU",NULL},
/* 120AB */ { "CUNEIFORM SIGN EZEN TIMES IGI GUNU",NULL},
/* 120AC */ { "CUNEIFORM SIGN EZEN TIMES KASKAL",NULL},
/* 120AD */ { "CUNEIFORM SIGN EZEN TIMES KASKAL SQUARED",NULL},
/* 120AE */ { "CUNEIFORM SIGN EZEN TIMES KU3",NULL},
/* 120AF */ { "CUNEIFORM SIGN EZEN TIMES LA",NULL},
/* 120B0 */ { "CUNEIFORM SIGN EZEN TIMES LAL TIMES LAL",NULL},
/* 120B1 */ { "CUNEIFORM SIGN EZEN TIMES LI",NULL},
/* 120B2 */ { "CUNEIFORM SIGN EZEN TIMES LU",NULL},
/* 120B3 */ { "CUNEIFORM SIGN EZEN TIMES U2",NULL},
/* 120B4 */ { "CUNEIFORM SIGN EZEN TIMES UD",NULL},
/* 120B5 */ { "CUNEIFORM SIGN GA",NULL},
/* 120B6 */ { "CUNEIFORM SIGN GA GUNU",NULL},
/* 120B7 */ { "CUNEIFORM SIGN GA2",NULL},
/* 120B8 */ { "CUNEIFORM SIGN GA2 TIMES A PLUS DA PLUS HA",NULL},
/* 120B9 */ { "CUNEIFORM SIGN GA2 TIMES A PLUS HA",NULL},
/* 120BA */ { "CUNEIFORM SIGN GA2 TIMES A PLUS IGI",NULL},
/* 120BB */ { "CUNEIFORM SIGN GA2 TIMES AB2 TENU PLUS TAB",NULL},
/* 120BC */ { "CUNEIFORM SIGN GA2 TIMES AN",NULL},
/* 120BD */ { "CUNEIFORM SIGN GA2 TIMES ASH",NULL},
/* 120BE */ { "CUNEIFORM SIGN GA2 TIMES ASH2 PLUS GAL",NULL},
/* 120BF */ { "CUNEIFORM SIGN GA2 TIMES BAD",NULL},
/* 120C0 */ { "CUNEIFORM SIGN GA2 TIMES BAR PLUS RA",NULL},
/* 120C1 */ { "CUNEIFORM SIGN GA2 TIMES BUR",NULL},
/* 120C2 */ { "CUNEIFORM SIGN GA2 TIMES BUR PLUS RA",NULL},
/* 120C3 */ { "CUNEIFORM SIGN GA2 TIMES DA",NULL},
/* 120C4 */ { "CUNEIFORM SIGN GA2 TIMES DI",NULL},
/* 120C5 */ { "CUNEIFORM SIGN GA2 TIMES DIM TIMES SHE",NULL},
/* 120C6 */ { "CUNEIFORM SIGN GA2 TIMES DUB",NULL},
/* 120C7 */ { "CUNEIFORM SIGN GA2 TIMES EL",NULL},
/* 120C8 */ { "CUNEIFORM SIGN GA2 TIMES EL PLUS LA",NULL},
/* 120C9 */ { "CUNEIFORM SIGN GA2 TIMES EN",NULL},
/* 120CA */ { "CUNEIFORM SIGN GA2 TIMES EN TIMES GAN2 TENU",NULL},
/* 120CB */ { "CUNEIFORM SIGN GA2 TIMES GAN2 TENU",NULL},
/* 120CC */ { "CUNEIFORM SIGN GA2 TIMES GAR",NULL},
/* 120CD */ { "CUNEIFORM SIGN GA2 TIMES GI",NULL},
/* 120CE */ { "CUNEIFORM SIGN GA2 TIMES GI4",NULL},
/* 120CF */ { "CUNEIFORM SIGN GA2 TIMES GI4 PLUS A",NULL},
/* 120D0 */ { "CUNEIFORM SIGN GA2 TIMES GIR2 PLUS SU",NULL},
/* 120D1 */ { "CUNEIFORM SIGN GA2 TIMES HA PLUS LU PLUS ESH2",NULL},
/* 120D2 */ { "CUNEIFORM SIGN GA2 TIMES HAL",NULL},
/* 120D3 */ { "CUNEIFORM SIGN GA2 TIMES HAL PLUS LA",NULL},
/* 120D4 */ { "CUNEIFORM SIGN GA2 TIMES HI PLUS LI",NULL},
/* 120D5 */ { "CUNEIFORM SIGN GA2 TIMES HUB2",NULL},
/* 120D6 */ { "CUNEIFORM SIGN GA2 TIMES IGI GUNU",NULL},
/* 120D7 */ { "CUNEIFORM SIGN GA2 TIMES ISH PLUS HU PLUS ASH",NULL},
/* 120D8 */ { "CUNEIFORM SIGN GA2 TIMES KAK",NULL},
/* 120D9 */ { "CUNEIFORM SIGN GA2 TIMES KASKAL",NULL},
/* 120DA */ { "CUNEIFORM SIGN GA2 TIMES KID",NULL},
/* 120DB */ { "CUNEIFORM SIGN GA2 TIMES KID PLUS LAL",NULL},
/* 120DC */ { "CUNEIFORM SIGN GA2 TIMES KU3 PLUS AN",NULL},
/* 120DD */ { "CUNEIFORM SIGN GA2 TIMES LA",NULL},
/* 120DE */ { "CUNEIFORM SIGN GA2 TIMES ME PLUS EN",NULL},
/* 120DF */ { "CUNEIFORM SIGN GA2 TIMES MI",NULL},
/* 120E0 */ { "CUNEIFORM SIGN GA2 TIMES NUN",NULL},
/* 120E1 */ { "CUNEIFORM SIGN GA2 TIMES NUN OVER NUN",NULL},
/* 120E2 */ { "CUNEIFORM SIGN GA2 TIMES PA",NULL},
/* 120E3 */ { "CUNEIFORM SIGN GA2 TIMES SAL",NULL},
/* 120E4 */ { "CUNEIFORM SIGN GA2 TIMES SAR",NULL},
/* 120E5 */ { "CUNEIFORM SIGN GA2 TIMES SHE",NULL},
/* 120E6 */ { "CUNEIFORM SIGN GA2 TIMES SHE PLUS TUR",NULL},
/* 120E7 */ { "CUNEIFORM SIGN GA2 TIMES SHID",NULL},
/* 120E8 */ { "CUNEIFORM SIGN GA2 TIMES SUM",NULL},
/* 120E9 */ { "CUNEIFORM SIGN GA2 TIMES TAK4",NULL},
/* 120EA */ { "CUNEIFORM SIGN GA2 TIMES U",NULL},
/* 120EB */ { "CUNEIFORM SIGN GA2 TIMES UD",NULL},
/* 120EC */ { "CUNEIFORM SIGN GA2 TIMES UD PLUS DU",NULL},
/* 120ED */ { "CUNEIFORM SIGN GA2 OVER GA2",NULL},
/* 120EE */ { "CUNEIFORM SIGN GABA",NULL},
/* 120EF */ { "CUNEIFORM SIGN GABA CROSSING GABA",NULL},
/* 120F0 */ { "CUNEIFORM SIGN GAD",NULL},
/* 120F1 */ { "CUNEIFORM SIGN GAD OVER GAD GAR OVER GAR",NULL},
/* 120F2 */ { "CUNEIFORM SIGN GAL",NULL},
/* 120F3 */ { "CUNEIFORM SIGN GAL GAD OVER GAD GAR OVER GAR",NULL},
/* 120F4 */ { "CUNEIFORM SIGN GALAM",NULL},
/* 120F5 */ { "CUNEIFORM SIGN GAM",NULL},
/* 120F6 */ { "CUNEIFORM SIGN GAN",NULL},
/* 120F7 */ { "CUNEIFORM SIGN GAN2",NULL},
/* 120F8 */ { "CUNEIFORM SIGN GAN2 TENU",NULL},
/* 120F9 */ { "CUNEIFORM SIGN GAN2 OVER GAN2",NULL},
/* 120FA */ { "CUNEIFORM SIGN GAN2 CROSSING GAN2",NULL},
/* 120FB */ { "CUNEIFORM SIGN GAR",NULL},
/* 120FC */ { "CUNEIFORM SIGN GAR3",NULL},
/* 120FD */ { "CUNEIFORM SIGN GASHAN",NULL},
/* 120FE */ { "CUNEIFORM SIGN GESHTIN",NULL},
/* 120FF */ { "CUNEIFORM SIGN GESHTIN TIMES KUR",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_21[] = {
/* 12100 */ { "CUNEIFORM SIGN GI",NULL},
/* 12101 */ { "CUNEIFORM SIGN GI TIMES E",NULL},
/* 12102 */ { "CUNEIFORM SIGN GI TIMES U",NULL},
/* 12103 */ { "CUNEIFORM SIGN GI CROSSING GI",NULL},
/* 12104 */ { "CUNEIFORM SIGN GI4",NULL},
/* 12105 */ { "CUNEIFORM SIGN GI4 OVER GI4",NULL},
/* 12106 */ { "CUNEIFORM SIGN GI4 CROSSING GI4",NULL},
/* 12107 */ { "CUNEIFORM SIGN GIDIM",NULL},
/* 12108 */ { "CUNEIFORM SIGN GIR2",NULL},
/* 12109 */ { "CUNEIFORM SIGN GIR2 GUNU",NULL},
/* 1210A */ { "CUNEIFORM SIGN GIR3",NULL},
/* 1210B */ { "CUNEIFORM SIGN GIR3 TIMES A PLUS IGI",NULL},
/* 1210C */ { "CUNEIFORM SIGN GIR3 TIMES GAN2 TENU",NULL},
/* 1210D */ { "CUNEIFORM SIGN GIR3 TIMES IGI",NULL},
/* 1210E */ { "CUNEIFORM SIGN GIR3 TIMES LU PLUS IGI",NULL},
/* 1210F */ { "CUNEIFORM SIGN GIR3 TIMES PA",NULL},
/* 12110 */ { "CUNEIFORM SIGN GISAL",NULL},
/* 12111 */ { "CUNEIFORM SIGN GISH",NULL},
/* 12112 */ { "CUNEIFORM SIGN GISH CROSSING GISH",NULL},
/* 12113 */ { "CUNEIFORM SIGN GISH TIMES BAD",NULL},
/* 12114 */ { "CUNEIFORM SIGN GISH TIMES TAK4",NULL},
/* 12115 */ { "CUNEIFORM SIGN GISH TENU",NULL},
/* 12116 */ { "CUNEIFORM SIGN GU",NULL},
/* 12117 */ { "CUNEIFORM SIGN GU CROSSING GU",NULL},
/* 12118 */ { "CUNEIFORM SIGN GU2",NULL},
/* 12119 */ { "CUNEIFORM SIGN GU2 TIMES KAK",NULL},
/* 1211A */ { "CUNEIFORM SIGN GU2 TIMES KAK TIMES IGI GUNU",NULL},
/* 1211B */ { "CUNEIFORM SIGN GU2 TIMES NUN",NULL},
/* 1211C */ { "CUNEIFORM SIGN GU2 TIMES SAL PLUS TUG2",NULL},
/* 1211D */ { "CUNEIFORM SIGN GU2 GUNU",NULL},
/* 1211E */ { "CUNEIFORM SIGN GUD",NULL},
/* 1211F */ { "CUNEIFORM SIGN GUD TIMES A PLUS KUR",NULL},
/* 12120 */ { "CUNEIFORM SIGN GUD TIMES KUR",NULL},
/* 12121 */ { "CUNEIFORM SIGN GUD OVER GUD LUGAL",NULL},
/* 12122 */ { "CUNEIFORM SIGN GUL",NULL},
/* 12123 */ { "CUNEIFORM SIGN GUM",NULL},
/* 12124 */ { "CUNEIFORM SIGN GUM TIMES SHE",NULL},
/* 12125 */ { "CUNEIFORM SIGN GUR",NULL},
/* 12126 */ { "CUNEIFORM SIGN GUR7",NULL},
/* 12127 */ { "CUNEIFORM SIGN GURUN",NULL},
/* 12128 */ { "CUNEIFORM SIGN GURUSH",NULL},
/* 12129 */ { "CUNEIFORM SIGN HA",NULL},
/* 1212A */ { "CUNEIFORM SIGN HA TENU",NULL},
/* 1212B */ { "CUNEIFORM SIGN HA GUNU",NULL},
/* 1212C */ { "CUNEIFORM SIGN HAL",NULL},
/* 1212D */ { "CUNEIFORM SIGN HI",NULL},
/* 1212E */ { "CUNEIFORM SIGN HI TIMES ASH",NULL},
/* 1212F */ { "CUNEIFORM SIGN HI TIMES ASH2",NULL},
/* 12130 */ { "CUNEIFORM SIGN HI TIMES BAD",NULL},
/* 12131 */ { "CUNEIFORM SIGN HI TIMES DISH",NULL},
/* 12132 */ { "CUNEIFORM SIGN HI TIMES GAD",NULL},
/* 12133 */ { "CUNEIFORM SIGN HI TIMES KIN",NULL},
/* 12134 */ { "CUNEIFORM SIGN HI TIMES NUN",NULL},
/* 12135 */ { "CUNEIFORM SIGN HI TIMES SHE",NULL},
/* 12136 */ { "CUNEIFORM SIGN HI TIMES U",NULL},
/* 12137 */ { "CUNEIFORM SIGN HU",NULL},
/* 12138 */ { "CUNEIFORM SIGN HUB2",NULL},
/* 12139 */ { "CUNEIFORM SIGN HUB2 TIMES AN",NULL},
/* 1213A */ { "CUNEIFORM SIGN HUB2 TIMES HAL",NULL},
/* 1213B */ { "CUNEIFORM SIGN HUB2 TIMES KASKAL",NULL},
/* 1213C */ { "CUNEIFORM SIGN HUB2 TIMES LISH",NULL},
/* 1213D */ { "CUNEIFORM SIGN HUB2 TIMES UD",NULL},
/* 1213E */ { "CUNEIFORM SIGN HUL2",NULL},
/* 1213F */ { "CUNEIFORM SIGN I",NULL},
/* 12140 */ { "CUNEIFORM SIGN I A",NULL},
/* 12141 */ { "CUNEIFORM SIGN IB",NULL},
/* 12142 */ { "CUNEIFORM SIGN IDIM",NULL},
/* 12143 */ { "CUNEIFORM SIGN IDIM OVER IDIM BUR",NULL},
/* 12144 */ { "CUNEIFORM SIGN IDIM OVER IDIM SQUARED",NULL},
/* 12145 */ { "CUNEIFORM SIGN IG",NULL},
/* 12146 */ { "CUNEIFORM SIGN IGI",NULL},
/* 12147 */ { "CUNEIFORM SIGN IGI DIB",NULL},
/* 12148 */ { "CUNEIFORM SIGN IGI RI",NULL},
/* 12149 */ { "CUNEIFORM SIGN IGI OVER IGI SHIR OVER SHIR UD OVER UD",NULL},
/* 1214A */ { "CUNEIFORM SIGN IGI GUNU",NULL},
/* 1214B */ { "CUNEIFORM SIGN IL",NULL},
/* 1214C */ { "CUNEIFORM SIGN IL TIMES GAN2 TENU",NULL},
/* 1214D */ { "CUNEIFORM SIGN IL2",NULL},
/* 1214E */ { "CUNEIFORM SIGN IM",NULL},
/* 1214F */ { "CUNEIFORM SIGN IM TIMES TAK4",NULL},
/* 12150 */ { "CUNEIFORM SIGN IM CROSSING IM",NULL},
/* 12151 */ { "CUNEIFORM SIGN IM OPPOSING IM",NULL},
/* 12152 */ { "CUNEIFORM SIGN IM SQUARED",NULL},
/* 12153 */ { "CUNEIFORM SIGN IMIN",NULL},
/* 12154 */ { "CUNEIFORM SIGN IN",NULL},
/* 12155 */ { "CUNEIFORM SIGN IR",NULL},
/* 12156 */ { "CUNEIFORM SIGN ISH",NULL},
/* 12157 */ { "CUNEIFORM SIGN KA",NULL},
/* 12158 */ { "CUNEIFORM SIGN KA TIMES A",NULL},
/* 12159 */ { "CUNEIFORM SIGN KA TIMES AD",NULL},
/* 1215A */ { "CUNEIFORM SIGN KA TIMES AD PLUS KU3",NULL},
/* 1215B */ { "CUNEIFORM SIGN KA TIMES ASH2",NULL},
/* 1215C */ { "CUNEIFORM SIGN KA TIMES BAD",NULL},
/* 1215D */ { "CUNEIFORM SIGN KA TIMES BALAG",NULL},
/* 1215E */ { "CUNEIFORM SIGN KA TIMES BAR",NULL},
/* 1215F */ { "CUNEIFORM SIGN KA TIMES BI",NULL},
/* 12160 */ { "CUNEIFORM SIGN KA TIMES ERIN2",NULL},
/* 12161 */ { "CUNEIFORM SIGN KA TIMES ESH2",NULL},
/* 12162 */ { "CUNEIFORM SIGN KA TIMES GA",NULL},
/* 12163 */ { "CUNEIFORM SIGN KA TIMES GAL",NULL},
/* 12164 */ { "CUNEIFORM SIGN KA TIMES GAN2 TENU",NULL},
/* 12165 */ { "CUNEIFORM SIGN KA TIMES GAR",NULL},
/* 12166 */ { "CUNEIFORM SIGN KA TIMES GAR PLUS SHA3 PLUS A",NULL},
/* 12167 */ { "CUNEIFORM SIGN KA TIMES GI",NULL},
/* 12168 */ { "CUNEIFORM SIGN KA TIMES GIR2",NULL},
/* 12169 */ { "CUNEIFORM SIGN KA TIMES GISH PLUS SAR",NULL},
/* 1216A */ { "CUNEIFORM SIGN KA TIMES GISH CROSSING GISH",NULL},
/* 1216B */ { "CUNEIFORM SIGN KA TIMES GU",NULL},
/* 1216C */ { "CUNEIFORM SIGN KA TIMES GUR7",NULL},
/* 1216D */ { "CUNEIFORM SIGN KA TIMES IGI",NULL},
/* 1216E */ { "CUNEIFORM SIGN KA TIMES IM",NULL},
/* 1216F */ { "CUNEIFORM SIGN KA TIMES KAK",NULL},
/* 12170 */ { "CUNEIFORM SIGN KA TIMES KI",NULL},
/* 12171 */ { "CUNEIFORM SIGN KA TIMES KID",NULL},
/* 12172 */ { "CUNEIFORM SIGN KA TIMES LI",NULL},
/* 12173 */ { "CUNEIFORM SIGN KA TIMES LU",NULL},
/* 12174 */ { "CUNEIFORM SIGN KA TIMES ME",NULL},
/* 12175 */ { "CUNEIFORM SIGN KA TIMES ME PLUS DU",NULL},
/* 12176 */ { "CUNEIFORM SIGN KA TIMES ME PLUS GI",NULL},
/* 12177 */ { "CUNEIFORM SIGN KA TIMES ME PLUS TE",NULL},
/* 12178 */ { "CUNEIFORM SIGN KA TIMES MI",NULL},
/* 12179 */ { "CUNEIFORM SIGN KA TIMES MI PLUS NUNUZ",NULL},
/* 1217A */ { "CUNEIFORM SIGN KA TIMES NE",NULL},
/* 1217B */ { "CUNEIFORM SIGN KA TIMES NUN",NULL},
/* 1217C */ { "CUNEIFORM SIGN KA TIMES PI",NULL},
/* 1217D */ { "CUNEIFORM SIGN KA TIMES RU",NULL},
/* 1217E */ { "CUNEIFORM SIGN KA TIMES SA",NULL},
/* 1217F */ { "CUNEIFORM SIGN KA TIMES SAR",NULL},
/* 12180 */ { "CUNEIFORM SIGN KA TIMES SHA",NULL},
/* 12181 */ { "CUNEIFORM SIGN KA TIMES SHE",NULL},
/* 12182 */ { "CUNEIFORM SIGN KA TIMES SHID",NULL},
/* 12183 */ { "CUNEIFORM SIGN KA TIMES SHU",NULL},
/* 12184 */ { "CUNEIFORM SIGN KA TIMES SIG",NULL},
/* 12185 */ { "CUNEIFORM SIGN KA TIMES SUHUR",NULL},
/* 12186 */ { "CUNEIFORM SIGN KA TIMES TAR",NULL},
/* 12187 */ { "CUNEIFORM SIGN KA TIMES U",NULL},
/* 12188 */ { "CUNEIFORM SIGN KA TIMES U2",NULL},
/* 12189 */ { "CUNEIFORM SIGN KA TIMES UD",NULL},
/* 1218A */ { "CUNEIFORM SIGN KA TIMES UMUM TIMES PA",NULL},
/* 1218B */ { "CUNEIFORM SIGN KA TIMES USH",NULL},
/* 1218C */ { "CUNEIFORM SIGN KA TIMES ZI",NULL},
/* 1218D */ { "CUNEIFORM SIGN KA2",NULL},
/* 1218E */ { "CUNEIFORM SIGN KA2 CROSSING KA2",NULL},
/* 1218F */ { "CUNEIFORM SIGN KAB",NULL},
/* 12190 */ { "CUNEIFORM SIGN KAD2",NULL},
/* 12191 */ { "CUNEIFORM SIGN KAD3",NULL},
/* 12192 */ { "CUNEIFORM SIGN KAD4",NULL},
/* 12193 */ { "CUNEIFORM SIGN KAD5",NULL},
/* 12194 */ { "CUNEIFORM SIGN KAD5 OVER KAD5",NULL},
/* 12195 */ { "CUNEIFORM SIGN KAK",NULL},
/* 12196 */ { "CUNEIFORM SIGN KAK TIMES IGI GUNU",NULL},
/* 12197 */ { "CUNEIFORM SIGN KAL",NULL},
/* 12198 */ { "CUNEIFORM SIGN KAL TIMES BAD",NULL},
/* 12199 */ { "CUNEIFORM SIGN KAL CROSSING KAL",NULL},
/* 1219A */ { "CUNEIFORM SIGN KAM2",NULL},
/* 1219B */ { "CUNEIFORM SIGN KAM4",NULL},
/* 1219C */ { "CUNEIFORM SIGN KASKAL",NULL},
/* 1219D */ { "CUNEIFORM SIGN KASKAL LAGAB TIMES U OVER LAGAB TIMES U",NULL},
/* 1219E */ { "CUNEIFORM SIGN KASKAL OVER KASKAL LAGAB TIMES U OVER LAGAB TIMES U",NULL},
/* 1219F */ { "CUNEIFORM SIGN KESH2",NULL},
/* 121A0 */ { "CUNEIFORM SIGN KI",NULL},
/* 121A1 */ { "CUNEIFORM SIGN KI TIMES BAD",NULL},
/* 121A2 */ { "CUNEIFORM SIGN KI TIMES U",NULL},
/* 121A3 */ { "CUNEIFORM SIGN KI TIMES UD",NULL},
/* 121A4 */ { "CUNEIFORM SIGN KID",NULL},
/* 121A5 */ { "CUNEIFORM SIGN KIN",NULL},
/* 121A6 */ { "CUNEIFORM SIGN KISAL",NULL},
/* 121A7 */ { "CUNEIFORM SIGN KISH",NULL},
/* 121A8 */ { "CUNEIFORM SIGN KISIM5",NULL},
/* 121A9 */ { "CUNEIFORM SIGN KISIM5 OVER KISIM5",NULL},
/* 121AA */ { "CUNEIFORM SIGN KU",NULL},
/* 121AB */ { "CUNEIFORM SIGN KU OVER HI TIMES ASH2 KU OVER HI TIMES ASH2",NULL},
/* 121AC */ { "CUNEIFORM SIGN KU3",NULL},
/* 121AD */ { "CUNEIFORM SIGN KU4",NULL},
/* 121AE */ { "CUNEIFORM SIGN KU4 VARIANT FORM",NULL},
/* 121AF */ { "CUNEIFORM SIGN KU7",NULL},
/* 121B0 */ { "CUNEIFORM SIGN KUL",NULL},
/* 121B1 */ { "CUNEIFORM SIGN KUL GUNU",NULL},
/* 121B2 */ { "CUNEIFORM SIGN KUN",NULL},
/* 121B3 */ { "CUNEIFORM SIGN KUR",NULL},
/* 121B4 */ { "CUNEIFORM SIGN KUR OPPOSING KUR",NULL},
/* 121B5 */ { "CUNEIFORM SIGN KUSHU2",NULL},
/* 121B6 */ { "CUNEIFORM SIGN KWU318",NULL},
/* 121B7 */ { "CUNEIFORM SIGN LA",NULL},
/* 121B8 */ { "CUNEIFORM SIGN LAGAB",NULL},
/* 121B9 */ { "CUNEIFORM SIGN LAGAB TIMES A",NULL},
/* 121BA */ { "CUNEIFORM SIGN LAGAB TIMES A PLUS DA PLUS HA",NULL},
/* 121BB */ { "CUNEIFORM SIGN LAGAB TIMES A PLUS GAR",NULL},
/* 121BC */ { "CUNEIFORM SIGN LAGAB TIMES A PLUS LAL",NULL},
/* 121BD */ { "CUNEIFORM SIGN LAGAB TIMES AL",NULL},
/* 121BE */ { "CUNEIFORM SIGN LAGAB TIMES AN",NULL},
/* 121BF */ { "CUNEIFORM SIGN LAGAB TIMES ASH ZIDA TENU",NULL},
/* 121C0 */ { "CUNEIFORM SIGN LAGAB TIMES BAD",NULL},
/* 121C1 */ { "CUNEIFORM SIGN LAGAB TIMES BI",NULL},
/* 121C2 */ { "CUNEIFORM SIGN LAGAB TIMES DAR",NULL},
/* 121C3 */ { "CUNEIFORM SIGN LAGAB TIMES EN",NULL},
/* 121C4 */ { "CUNEIFORM SIGN LAGAB TIMES GA",NULL},
/* 121C5 */ { "CUNEIFORM SIGN LAGAB TIMES GAR",NULL},
/* 121C6 */ { "CUNEIFORM SIGN LAGAB TIMES GUD",NULL},
/* 121C7 */ { "CUNEIFORM SIGN LAGAB TIMES GUD PLUS GUD",NULL},
/* 121C8 */ { "CUNEIFORM SIGN LAGAB TIMES HA",NULL},
/* 121C9 */ { "CUNEIFORM SIGN LAGAB TIMES HAL",NULL},
/* 121CA */ { "CUNEIFORM SIGN LAGAB TIMES HI TIMES NUN",NULL},
/* 121CB */ { "CUNEIFORM SIGN LAGAB TIMES IGI GUNU",NULL},
/* 121CC */ { "CUNEIFORM SIGN LAGAB TIMES IM",NULL},
/* 121CD */ { "CUNEIFORM SIGN LAGAB TIMES IM PLUS HA",NULL},
/* 121CE */ { "CUNEIFORM SIGN LAGAB TIMES IM PLUS LU",NULL},
/* 121CF */ { "CUNEIFORM SIGN LAGAB TIMES KI",NULL},
/* 121D0 */ { "CUNEIFORM SIGN LAGAB TIMES KIN",NULL},
/* 121D1 */ { "CUNEIFORM SIGN LAGAB TIMES KU3",NULL},
/* 121D2 */ { "CUNEIFORM SIGN LAGAB TIMES KUL",NULL},
/* 121D3 */ { "CUNEIFORM SIGN LAGAB TIMES KUL PLUS HI PLUS A",NULL},
/* 121D4 */ { "CUNEIFORM SIGN LAGAB TIMES LAGAB",NULL},
/* 121D5 */ { "CUNEIFORM SIGN LAGAB TIMES LISH",NULL},
/* 121D6 */ { "CUNEIFORM SIGN LAGAB TIMES LU",NULL},
/* 121D7 */ { "CUNEIFORM SIGN LAGAB TIMES LUL",NULL},
/* 121D8 */ { "CUNEIFORM SIGN LAGAB TIMES ME",NULL},
/* 121D9 */ { "CUNEIFORM SIGN LAGAB TIMES ME PLUS EN",NULL},
/* 121DA */ { "CUNEIFORM SIGN LAGAB TIMES MUSH",NULL},
/* 121DB */ { "CUNEIFORM SIGN LAGAB TIMES NE",NULL},
/* 121DC */ { "CUNEIFORM SIGN LAGAB TIMES SHE PLUS SUM",NULL},
/* 121DD */ { "CUNEIFORM SIGN LAGAB TIMES SHITA PLUS GISH PLUS ERIN2",NULL},
/* 121DE */ { "CUNEIFORM SIGN LAGAB TIMES SHITA PLUS GISH TENU",NULL},
/* 121DF */ { "CUNEIFORM SIGN LAGAB TIMES SHU2",NULL},
/* 121E0 */ { "CUNEIFORM SIGN LAGAB TIMES SHU2 PLUS SHU2",NULL},
/* 121E1 */ { "CUNEIFORM SIGN LAGAB TIMES SUM",NULL},
/* 121E2 */ { "CUNEIFORM SIGN LAGAB TIMES TAG",NULL},
/* 121E3 */ { "CUNEIFORM SIGN LAGAB TIMES TAK4",NULL},
/* 121E4 */ { "CUNEIFORM SIGN LAGAB TIMES TE PLUS A PLUS SU PLUS NA",NULL},
/* 121E5 */ { "CUNEIFORM SIGN LAGAB TIMES U",NULL},
/* 121E6 */ { "CUNEIFORM SIGN LAGAB TIMES U PLUS A",NULL},
/* 121E7 */ { "CUNEIFORM SIGN LAGAB TIMES U PLUS U PLUS U",NULL},
/* 121E8 */ { "CUNEIFORM SIGN LAGAB TIMES U2 PLUS ASH",NULL},
/* 121E9 */ { "CUNEIFORM SIGN LAGAB TIMES UD",NULL},
/* 121EA */ { "CUNEIFORM SIGN LAGAB TIMES USH",NULL},
/* 121EB */ { "CUNEIFORM SIGN LAGAB SQUARED",NULL},
/* 121EC */ { "CUNEIFORM SIGN LAGAR",NULL},
/* 121ED */ { "CUNEIFORM SIGN LAGAR TIMES SHE",NULL},
/* 121EE */ { "CUNEIFORM SIGN LAGAR TIMES SHE PLUS SUM",NULL},
/* 121EF */ { "CUNEIFORM SIGN LAGAR GUNU",NULL},
/* 121F0 */ { "CUNEIFORM SIGN LAGAR GUNU OVER LAGAR GUNU SHE",NULL},
/* 121F1 */ { "CUNEIFORM SIGN LAHSHU",NULL},
/* 121F2 */ { "CUNEIFORM SIGN LAL",NULL},
/* 121F3 */ { "CUNEIFORM SIGN LAL TIMES LAL",NULL},
/* 121F4 */ { "CUNEIFORM SIGN LAM",NULL},
/* 121F5 */ { "CUNEIFORM SIGN LAM TIMES KUR",NULL},
/* 121F6 */ { "CUNEIFORM SIGN LAM TIMES KUR PLUS RU",NULL},
/* 121F7 */ { "CUNEIFORM SIGN LI",NULL},
/* 121F8 */ { "CUNEIFORM SIGN LIL",NULL},
/* 121F9 */ { "CUNEIFORM SIGN LIMMU2",NULL},
/* 121FA */ { "CUNEIFORM SIGN LISH",NULL},
/* 121FB */ { "CUNEIFORM SIGN LU",NULL},
/* 121FC */ { "CUNEIFORM SIGN LU TIMES BAD",NULL},
/* 121FD */ { "CUNEIFORM SIGN LU2",NULL},
/* 121FE */ { "CUNEIFORM SIGN LU2 TIMES AL",NULL},
/* 121FF */ { "CUNEIFORM SIGN LU2 TIMES BAD",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_22[] = {
/* 12200 */ { "CUNEIFORM SIGN LU2 TIMES ESH2",NULL},
/* 12201 */ { "CUNEIFORM SIGN LU2 TIMES ESH2 TENU",NULL},
/* 12202 */ { "CUNEIFORM SIGN LU2 TIMES GAN2 TENU",NULL},
/* 12203 */ { "CUNEIFORM SIGN LU2 TIMES HI TIMES BAD",NULL},
/* 12204 */ { "CUNEIFORM SIGN LU2 TIMES IM",NULL},
/* 12205 */ { "CUNEIFORM SIGN LU2 TIMES KAD2",NULL},
/* 12206 */ { "CUNEIFORM SIGN LU2 TIMES KAD3",NULL},
/* 12207 */ { "CUNEIFORM SIGN LU2 TIMES KAD3 PLUS ASH",NULL},
/* 12208 */ { "CUNEIFORM SIGN LU2 TIMES KI",NULL},
/* 12209 */ { "CUNEIFORM SIGN LU2 TIMES LA PLUS ASH",NULL},
/* 1220A */ { "CUNEIFORM SIGN LU2 TIMES LAGAB",NULL},
/* 1220B */ { "CUNEIFORM SIGN LU2 TIMES ME PLUS EN",NULL},
/* 1220C */ { "CUNEIFORM SIGN LU2 TIMES NE",NULL},
/* 1220D */ { "CUNEIFORM SIGN LU2 TIMES NU",NULL},
/* 1220E */ { "CUNEIFORM SIGN LU2 TIMES SI PLUS ASH",NULL},
/* 1220F */ { "CUNEIFORM SIGN LU2 TIMES SIK2 PLUS BU",NULL},
/* 12210 */ { "CUNEIFORM SIGN LU2 TIMES TUG2",NULL},
/* 12211 */ { "CUNEIFORM SIGN LU2 TENU",NULL},
/* 12212 */ { "CUNEIFORM SIGN LU2 CROSSING LU2",NULL},
/* 12213 */ { "CUNEIFORM SIGN LU2 OPPOSING LU2",NULL},
/* 12214 */ { "CUNEIFORM SIGN LU2 SQUARED",NULL},
/* 12215 */ { "CUNEIFORM SIGN LU2 SHESHIG",NULL},
/* 12216 */ { "CUNEIFORM SIGN LU3",NULL},
/* 12217 */ { "CUNEIFORM SIGN LUGAL",NULL},
/* 12218 */ { "CUNEIFORM SIGN LUGAL OVER LUGAL",NULL},
/* 12219 */ { "CUNEIFORM SIGN LUGAL OPPOSING LUGAL",NULL},
/* 1221A */ { "CUNEIFORM SIGN LUGAL SHESHIG",NULL},
/* 1221B */ { "CUNEIFORM SIGN LUH",NULL},
/* 1221C */ { "CUNEIFORM SIGN LUL",NULL},
/* 1221D */ { "CUNEIFORM SIGN LUM",NULL},
/* 1221E */ { "CUNEIFORM SIGN LUM OVER LUM",NULL},
/* 1221F */ { "CUNEIFORM SIGN LUM OVER LUM GAR OVER GAR",NULL},
/* 12220 */ { "CUNEIFORM SIGN MA",NULL},
/* 12221 */ { "CUNEIFORM SIGN MA TIMES TAK4",NULL},
/* 12222 */ { "CUNEIFORM SIGN MA GUNU",NULL},
/* 12223 */ { "CUNEIFORM SIGN MA2",NULL},
/* 12224 */ { "CUNEIFORM SIGN MAH",NULL},
/* 12225 */ { "CUNEIFORM SIGN MAR",NULL},
/* 12226 */ { "CUNEIFORM SIGN MASH","	= 1/2 diš\n"
	"	x (cuneiform numeric sign one ban2 - 1244F)"},
/* 12227 */ { "CUNEIFORM SIGN MASH2",NULL},
/* 12228 */ { "CUNEIFORM SIGN ME",NULL},
/* 12229 */ { "CUNEIFORM SIGN MES",NULL},
/* 1222A */ { "CUNEIFORM SIGN MI",NULL},
/* 1222B */ { "CUNEIFORM SIGN MIN","	= 2 diš\n"
	"	x (cuneiform numeric sign three dish - 12408)"},
/* 1222C */ { "CUNEIFORM SIGN MU",NULL},
/* 1222D */ { "CUNEIFORM SIGN MU OVER MU",NULL},
/* 1222E */ { "CUNEIFORM SIGN MUG",NULL},
/* 1222F */ { "CUNEIFORM SIGN MUG GUNU",NULL},
/* 12230 */ { "CUNEIFORM SIGN MUNSUB",NULL},
/* 12231 */ { "CUNEIFORM SIGN MURGU2",NULL},
/* 12232 */ { "CUNEIFORM SIGN MUSH",NULL},
/* 12233 */ { "CUNEIFORM SIGN MUSH TIMES A",NULL},
/* 12234 */ { "CUNEIFORM SIGN MUSH TIMES KUR",NULL},
/* 12235 */ { "CUNEIFORM SIGN MUSH TIMES ZA",NULL},
/* 12236 */ { "CUNEIFORM SIGN MUSH OVER MUSH",NULL},
/* 12237 */ { "CUNEIFORM SIGN MUSH OVER MUSH TIMES A PLUS NA",NULL},
/* 12238 */ { "CUNEIFORM SIGN MUSH CROSSING MUSH",NULL},
/* 12239 */ { "CUNEIFORM SIGN MUSH3",NULL},
/* 1223A */ { "CUNEIFORM SIGN MUSH3 TIMES A",NULL},
/* 1223B */ { "CUNEIFORM SIGN MUSH3 TIMES A PLUS DI",NULL},
/* 1223C */ { "CUNEIFORM SIGN MUSH3 TIMES DI",NULL},
/* 1223D */ { "CUNEIFORM SIGN MUSH3 GUNU",NULL},
/* 1223E */ { "CUNEIFORM SIGN NA",NULL},
/* 1223F */ { "CUNEIFORM SIGN NA2",NULL},
/* 12240 */ { "CUNEIFORM SIGN NAGA",NULL},
/* 12241 */ { "CUNEIFORM SIGN NAGA INVERTED",NULL},
/* 12242 */ { "CUNEIFORM SIGN NAGA TIMES SHU TENU",NULL},
/* 12243 */ { "CUNEIFORM SIGN NAGA OPPOSING NAGA",NULL},
/* 12244 */ { "CUNEIFORM SIGN NAGAR",NULL},
/* 12245 */ { "CUNEIFORM SIGN NAM NUTILLU",NULL},
/* 12246 */ { "CUNEIFORM SIGN NAM",NULL},
/* 12247 */ { "CUNEIFORM SIGN NAM2",NULL},
/* 12248 */ { "CUNEIFORM SIGN NE",NULL},
/* 12249 */ { "CUNEIFORM SIGN NE TIMES A",NULL},
/* 1224A */ { "CUNEIFORM SIGN NE TIMES UD",NULL},
/* 1224B */ { "CUNEIFORM SIGN NE SHESHIG",NULL},
/* 1224C */ { "CUNEIFORM SIGN NI",NULL},
/* 1224D */ { "CUNEIFORM SIGN NI TIMES E",NULL},
/* 1224E */ { "CUNEIFORM SIGN NI2",NULL},
/* 1224F */ { "CUNEIFORM SIGN NIM",NULL},
/* 12250 */ { "CUNEIFORM SIGN NIM TIMES GAN2 TENU",NULL},
/* 12251 */ { "CUNEIFORM SIGN NIM TIMES GAR PLUS GAN2 TENU",NULL},
/* 12252 */ { "CUNEIFORM SIGN NINDA2",NULL},
/* 12253 */ { "CUNEIFORM SIGN NINDA2 TIMES AN",NULL},
/* 12254 */ { "CUNEIFORM SIGN NINDA2 TIMES ASH",NULL},
/* 12255 */ { "CUNEIFORM SIGN NINDA2 TIMES ASH PLUS ASH",NULL},
/* 12256 */ { "CUNEIFORM SIGN NINDA2 TIMES GUD",NULL},
/* 12257 */ { "CUNEIFORM SIGN NINDA2 TIMES ME PLUS GAN2 TENU",NULL},
/* 12258 */ { "CUNEIFORM SIGN NINDA2 TIMES NE",NULL},
/* 12259 */ { "CUNEIFORM SIGN NINDA2 TIMES NUN",NULL},
/* 1225A */ { "CUNEIFORM SIGN NINDA2 TIMES SHE",NULL},
/* 1225B */ { "CUNEIFORM SIGN NINDA2 TIMES SHE PLUS A AN",NULL},
/* 1225C */ { "CUNEIFORM SIGN NINDA2 TIMES SHE PLUS ASH",NULL},
/* 1225D */ { "CUNEIFORM SIGN NINDA2 TIMES SHE PLUS ASH PLUS ASH",NULL},
/* 1225E */ { "CUNEIFORM SIGN NINDA2 TIMES U2 PLUS ASH",NULL},
/* 1225F */ { "CUNEIFORM SIGN NINDA2 TIMES USH",NULL},
/* 12260 */ { "CUNEIFORM SIGN NISAG",NULL},
/* 12261 */ { "CUNEIFORM SIGN NU",NULL},
/* 12262 */ { "CUNEIFORM SIGN NU11",NULL},
/* 12263 */ { "CUNEIFORM SIGN NUN",NULL},
/* 12264 */ { "CUNEIFORM SIGN NUN LAGAR TIMES GAR",NULL},
/* 12265 */ { "CUNEIFORM SIGN NUN LAGAR TIMES MASH",NULL},
/* 12266 */ { "CUNEIFORM SIGN NUN LAGAR TIMES SAL",NULL},
/* 12267 */ { "CUNEIFORM SIGN NUN LAGAR TIMES SAL OVER NUN LAGAR TIMES SAL",NULL},
/* 12268 */ { "CUNEIFORM SIGN NUN LAGAR TIMES USH",NULL},
/* 12269 */ { "CUNEIFORM SIGN NUN TENU",NULL},
/* 1226A */ { "CUNEIFORM SIGN NUN OVER NUN",NULL},
/* 1226B */ { "CUNEIFORM SIGN NUN CROSSING NUN",NULL},
/* 1226C */ { "CUNEIFORM SIGN NUN CROSSING NUN LAGAR OVER LAGAR",NULL},
/* 1226D */ { "CUNEIFORM SIGN NUNUZ",NULL},
/* 1226E */ { "CUNEIFORM SIGN NUNUZ AB2 TIMES ASHGAB",NULL},
/* 1226F */ { "CUNEIFORM SIGN NUNUZ AB2 TIMES BI",NULL},
/* 12270 */ { "CUNEIFORM SIGN NUNUZ AB2 TIMES DUG",NULL},
/* 12271 */ { "CUNEIFORM SIGN NUNUZ AB2 TIMES GUD",NULL},
/* 12272 */ { "CUNEIFORM SIGN NUNUZ AB2 TIMES IGI GUNU",NULL},
/* 12273 */ { "CUNEIFORM SIGN NUNUZ AB2 TIMES KAD3",NULL},
/* 12274 */ { "CUNEIFORM SIGN NUNUZ AB2 TIMES LA",NULL},
/* 12275 */ { "CUNEIFORM SIGN NUNUZ AB2 TIMES NE",NULL},
/* 12276 */ { "CUNEIFORM SIGN NUNUZ AB2 TIMES SILA3",NULL},
/* 12277 */ { "CUNEIFORM SIGN NUNUZ AB2 TIMES U2",NULL},
/* 12278 */ { "CUNEIFORM SIGN NUNUZ KISIM5 TIMES BI",NULL},
/* 12279 */ { "CUNEIFORM SIGN NUNUZ KISIM5 TIMES BI U",NULL},
/* 1227A */ { "CUNEIFORM SIGN PA","	x (cuneiform numeric sign two ban2 - 12450)"},
/* 1227B */ { "CUNEIFORM SIGN PAD",NULL},
/* 1227C */ { "CUNEIFORM SIGN PAN",NULL},
/* 1227D */ { "CUNEIFORM SIGN PAP",NULL},
/* 1227E */ { "CUNEIFORM SIGN PESH2",NULL},
/* 1227F */ { "CUNEIFORM SIGN PI",NULL},
/* 12280 */ { "CUNEIFORM SIGN PI TIMES A",NULL},
/* 12281 */ { "CUNEIFORM SIGN PI TIMES AB",NULL},
/* 12282 */ { "CUNEIFORM SIGN PI TIMES BI",NULL},
/* 12283 */ { "CUNEIFORM SIGN PI TIMES BU",NULL},
/* 12284 */ { "CUNEIFORM SIGN PI TIMES E",NULL},
/* 12285 */ { "CUNEIFORM SIGN PI TIMES I",NULL},
/* 12286 */ { "CUNEIFORM SIGN PI TIMES IB",NULL},
/* 12287 */ { "CUNEIFORM SIGN PI TIMES U",NULL},
/* 12288 */ { "CUNEIFORM SIGN PI TIMES U2",NULL},
/* 12289 */ { "CUNEIFORM SIGN PI CROSSING PI",NULL},
/* 1228A */ { "CUNEIFORM SIGN PIRIG",NULL},
/* 1228B */ { "CUNEIFORM SIGN PIRIG TIMES KAL",NULL},
/* 1228C */ { "CUNEIFORM SIGN PIRIG TIMES UD",NULL},
/* 1228D */ { "CUNEIFORM SIGN PIRIG TIMES ZA",NULL},
/* 1228E */ { "CUNEIFORM SIGN PIRIG OPPOSING PIRIG",NULL},
/* 1228F */ { "CUNEIFORM SIGN RA",NULL},
/* 12290 */ { "CUNEIFORM SIGN RAB",NULL},
/* 12291 */ { "CUNEIFORM SIGN RI",NULL},
/* 12292 */ { "CUNEIFORM SIGN RU",NULL},
/* 12293 */ { "CUNEIFORM SIGN SA",NULL},
/* 12294 */ { "CUNEIFORM SIGN SAG NUTILLU",NULL},
/* 12295 */ { "CUNEIFORM SIGN SAG",NULL},
/* 12296 */ { "CUNEIFORM SIGN SAG TIMES A",NULL},
/* 12297 */ { "CUNEIFORM SIGN SAG TIMES DU",NULL},
/* 12298 */ { "CUNEIFORM SIGN SAG TIMES DUB",NULL},
/* 12299 */ { "CUNEIFORM SIGN SAG TIMES HA",NULL},
/* 1229A */ { "CUNEIFORM SIGN SAG TIMES KAK",NULL},
/* 1229B */ { "CUNEIFORM SIGN SAG TIMES KUR",NULL},
/* 1229C */ { "CUNEIFORM SIGN SAG TIMES LUM",NULL},
/* 1229D */ { "CUNEIFORM SIGN SAG TIMES MI",NULL},
/* 1229E */ { "CUNEIFORM SIGN SAG TIMES NUN",NULL},
/* 1229F */ { "CUNEIFORM SIGN SAG TIMES SAL",NULL},
/* 122A0 */ { "CUNEIFORM SIGN SAG TIMES SHID",NULL},
/* 122A1 */ { "CUNEIFORM SIGN SAG TIMES TAB",NULL},
/* 122A2 */ { "CUNEIFORM SIGN SAG TIMES U2",NULL},
/* 122A3 */ { "CUNEIFORM SIGN SAG TIMES UB",NULL},
/* 122A4 */ { "CUNEIFORM SIGN SAG TIMES UM",NULL},
/* 122A5 */ { "CUNEIFORM SIGN SAG TIMES UR",NULL},
/* 122A6 */ { "CUNEIFORM SIGN SAG TIMES USH",NULL},
/* 122A7 */ { "CUNEIFORM SIGN SAG OVER SAG",NULL},
/* 122A8 */ { "CUNEIFORM SIGN SAG GUNU",NULL},
/* 122A9 */ { "CUNEIFORM SIGN SAL",NULL},
/* 122AA */ { "CUNEIFORM SIGN SAL LAGAB TIMES ASH2",NULL},
/* 122AB */ { "CUNEIFORM SIGN SANGA2",NULL},
/* 122AC */ { "CUNEIFORM SIGN SAR",NULL},
/* 122AD */ { "CUNEIFORM SIGN SHA",NULL},
/* 122AE */ { "CUNEIFORM SIGN SHA3",NULL},
/* 122AF */ { "CUNEIFORM SIGN SHA3 TIMES A",NULL},
/* 122B0 */ { "CUNEIFORM SIGN SHA3 TIMES BAD",NULL},
/* 122B1 */ { "CUNEIFORM SIGN SHA3 TIMES GISH",NULL},
/* 122B2 */ { "CUNEIFORM SIGN SHA3 TIMES NE",NULL},
/* 122B3 */ { "CUNEIFORM SIGN SHA3 TIMES SHU2",NULL},
/* 122B4 */ { "CUNEIFORM SIGN SHA3 TIMES TUR",NULL},
/* 122B5 */ { "CUNEIFORM SIGN SHA3 TIMES U",NULL},
/* 122B6 */ { "CUNEIFORM SIGN SHA3 TIMES U PLUS A",NULL},
/* 122B7 */ { "CUNEIFORM SIGN SHA6",NULL},
/* 122B8 */ { "CUNEIFORM SIGN SHAB6",NULL},
/* 122B9 */ { "CUNEIFORM SIGN SHAR2","	= 1 šar₂\n"
	"	* same glyph as 1212D HI in all but the most archaizing texts\n"
	"	* the archaic reference glyph is formed by making a circular indentation with the end of the stylus\n"
	"	* used for logographic šar₂ and cuneiform 1 šar₂\n"
	"	x (cuneiform numeric sign two shar2 - 12423)"},
/* 122BA */ { "CUNEIFORM SIGN SHE",NULL},
/* 122BB */ { "CUNEIFORM SIGN SHE HU",NULL},
/* 122BC */ { "CUNEIFORM SIGN SHE OVER SHE GAD OVER GAD GAR OVER GAR",NULL},
/* 122BD */ { "CUNEIFORM SIGN SHE OVER SHE TAB OVER TAB GAR OVER GAR",NULL},
/* 122BE */ { "CUNEIFORM SIGN SHEG9",NULL},
/* 122BF */ { "CUNEIFORM SIGN SHEN",NULL},
/* 122C0 */ { "CUNEIFORM SIGN SHESH",NULL},
/* 122C1 */ { "CUNEIFORM SIGN SHESH2",NULL},
/* 122C2 */ { "CUNEIFORM SIGN SHESHLAM",NULL},
/* 122C3 */ { "CUNEIFORM SIGN SHID",NULL},
/* 122C4 */ { "CUNEIFORM SIGN SHID TIMES A",NULL},
/* 122C5 */ { "CUNEIFORM SIGN SHID TIMES IM",NULL},
/* 122C6 */ { "CUNEIFORM SIGN SHIM",NULL},
/* 122C7 */ { "CUNEIFORM SIGN SHIM TIMES A",NULL},
/* 122C8 */ { "CUNEIFORM SIGN SHIM TIMES BAL",NULL},
/* 122C9 */ { "CUNEIFORM SIGN SHIM TIMES BULUG",NULL},
/* 122CA */ { "CUNEIFORM SIGN SHIM TIMES DIN",NULL},
/* 122CB */ { "CUNEIFORM SIGN SHIM TIMES GAR",NULL},
/* 122CC */ { "CUNEIFORM SIGN SHIM TIMES IGI",NULL},
/* 122CD */ { "CUNEIFORM SIGN SHIM TIMES IGI GUNU",NULL},
/* 122CE */ { "CUNEIFORM SIGN SHIM TIMES KUSHU2",NULL},
/* 122CF */ { "CUNEIFORM SIGN SHIM TIMES LUL",NULL},
/* 122D0 */ { "CUNEIFORM SIGN SHIM TIMES MUG",NULL},
/* 122D1 */ { "CUNEIFORM SIGN SHIM TIMES SAL",NULL},
/* 122D2 */ { "CUNEIFORM SIGN SHINIG",NULL},
/* 122D3 */ { "CUNEIFORM SIGN SHIR",NULL},
/* 122D4 */ { "CUNEIFORM SIGN SHIR TENU","	% CUNEIFORM SIGN NU11 TENU"},
/* 122D5 */ { "CUNEIFORM SIGN SHIR OVER SHIR BUR OVER BUR","	% CUNEIFORM SIGN NU11 OVER NU11 BUR OVER BUR"},
/* 122D6 */ { "CUNEIFORM SIGN SHITA",NULL},
/* 122D7 */ { "CUNEIFORM SIGN SHU",NULL},
/* 122D8 */ { "CUNEIFORM SIGN SHU OVER INVERTED SHU",NULL},
/* 122D9 */ { "CUNEIFORM SIGN SHU2",NULL},
/* 122DA */ { "CUNEIFORM SIGN SHUBUR",NULL},
/* 122DB */ { "CUNEIFORM SIGN SI",NULL},
/* 122DC */ { "CUNEIFORM SIGN SI GUNU",NULL},
/* 122DD */ { "CUNEIFORM SIGN SIG",NULL},
/* 122DE */ { "CUNEIFORM SIGN SIG4",NULL},
/* 122DF */ { "CUNEIFORM SIGN SIG4 OVER SIG4 SHU2",NULL},
/* 122E0 */ { "CUNEIFORM SIGN SIK2",NULL},
/* 122E1 */ { "CUNEIFORM SIGN SILA3",NULL},
/* 122E2 */ { "CUNEIFORM SIGN SU",NULL},
/* 122E3 */ { "CUNEIFORM SIGN SU OVER SU",NULL},
/* 122E4 */ { "CUNEIFORM SIGN SUD",NULL},
/* 122E5 */ { "CUNEIFORM SIGN SUD2",NULL},
/* 122E6 */ { "CUNEIFORM SIGN SUHUR",NULL},
/* 122E7 */ { "CUNEIFORM SIGN SUM",NULL},
/* 122E8 */ { "CUNEIFORM SIGN SUMASH",NULL},
/* 122E9 */ { "CUNEIFORM SIGN SUR",NULL},
/* 122EA */ { "CUNEIFORM SIGN SUR9",NULL},
/* 122EB */ { "CUNEIFORM SIGN TA",NULL},
/* 122EC */ { "CUNEIFORM SIGN TA ASTERISK",NULL},
/* 122ED */ { "CUNEIFORM SIGN TA TIMES HI",NULL},
/* 122EE */ { "CUNEIFORM SIGN TA TIMES MI",NULL},
/* 122EF */ { "CUNEIFORM SIGN TA GUNU",NULL},
/* 122F0 */ { "CUNEIFORM SIGN TAB",NULL},
/* 122F1 */ { "CUNEIFORM SIGN TAB OVER TAB NI OVER NI DISH OVER DISH",NULL},
/* 122F2 */ { "CUNEIFORM SIGN TAB SQUARED",NULL},
/* 122F3 */ { "CUNEIFORM SIGN TAG",NULL},
/* 122F4 */ { "CUNEIFORM SIGN TAG TIMES BI",NULL},
/* 122F5 */ { "CUNEIFORM SIGN TAG TIMES GUD",NULL},
/* 122F6 */ { "CUNEIFORM SIGN TAG TIMES SHE",NULL},
/* 122F7 */ { "CUNEIFORM SIGN TAG TIMES SHU",NULL},
/* 122F8 */ { "CUNEIFORM SIGN TAG TIMES TUG2",NULL},
/* 122F9 */ { "CUNEIFORM SIGN TAG TIMES UD",NULL},
/* 122FA */ { "CUNEIFORM SIGN TAK4",NULL},
/* 122FB */ { "CUNEIFORM SIGN TAR",NULL},
/* 122FC */ { "CUNEIFORM SIGN TE",NULL},
/* 122FD */ { "CUNEIFORM SIGN TE GUNU",NULL},
/* 122FE */ { "CUNEIFORM SIGN TI",NULL},
/* 122FF */ { "CUNEIFORM SIGN TI TENU",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_23[] = {
/* 12300 */ { "CUNEIFORM SIGN TIL",NULL},
/* 12301 */ { "CUNEIFORM SIGN TIR",NULL},
/* 12302 */ { "CUNEIFORM SIGN TIR TIMES TAK4",NULL},
/* 12303 */ { "CUNEIFORM SIGN TIR OVER TIR",NULL},
/* 12304 */ { "CUNEIFORM SIGN TIR OVER TIR GAD OVER GAD GAR OVER GAR",NULL},
/* 12305 */ { "CUNEIFORM SIGN TU",NULL},
/* 12306 */ { "CUNEIFORM SIGN TUG2",NULL},
/* 12307 */ { "CUNEIFORM SIGN TUK",NULL},
/* 12308 */ { "CUNEIFORM SIGN TUM",NULL},
/* 12309 */ { "CUNEIFORM SIGN TUR",NULL},
/* 1230A */ { "CUNEIFORM SIGN TUR OVER TUR ZA OVER ZA",NULL},
/* 1230B */ { "CUNEIFORM SIGN U","	= 1 u\n"
	"	= 1 bur₃\n"
	"	x (cuneiform numeric sign four u - 1240F)"},
/* 1230C */ { "CUNEIFORM SIGN U GUD",NULL},
/* 1230D */ { "CUNEIFORM SIGN U U U","	= 3 u\n"
	"	= 3 bur₃\n"
	"	x (cuneiform numeric sign four u - 1240F)"},
/* 1230E */ { "CUNEIFORM SIGN U OVER U PA OVER PA GAR OVER GAR",NULL},
/* 1230F */ { "CUNEIFORM SIGN U OVER U SUR OVER SUR",NULL},
/* 12310 */ { "CUNEIFORM SIGN U OVER U U REVERSED OVER U REVERSED",NULL},
/* 12311 */ { "CUNEIFORM SIGN U2",NULL},
/* 12312 */ { "CUNEIFORM SIGN UB",NULL},
/* 12313 */ { "CUNEIFORM SIGN UD",NULL},
/* 12314 */ { "CUNEIFORM SIGN UD KUSHU2",NULL},
/* 12315 */ { "CUNEIFORM SIGN UD TIMES BAD",NULL},
/* 12316 */ { "CUNEIFORM SIGN UD TIMES MI",NULL},
/* 12317 */ { "CUNEIFORM SIGN UD TIMES U PLUS U PLUS U",NULL},
/* 12318 */ { "CUNEIFORM SIGN UD TIMES U PLUS U PLUS U GUNU",NULL},
/* 12319 */ { "CUNEIFORM SIGN UD GUNU",NULL},
/* 1231A */ { "CUNEIFORM SIGN UD SHESHIG",NULL},
/* 1231B */ { "CUNEIFORM SIGN UD SHESHIG TIMES BAD",NULL},
/* 1231C */ { "CUNEIFORM SIGN UDUG",NULL},
/* 1231D */ { "CUNEIFORM SIGN UM",NULL},
/* 1231E */ { "CUNEIFORM SIGN UM TIMES LAGAB",NULL},
/* 1231F */ { "CUNEIFORM SIGN UM TIMES ME PLUS DA",NULL},
/* 12320 */ { "CUNEIFORM SIGN UM TIMES SHA3",NULL},
/* 12321 */ { "CUNEIFORM SIGN UM TIMES U",NULL},
/* 12322 */ { "CUNEIFORM SIGN UMBIN",NULL},
/* 12323 */ { "CUNEIFORM SIGN UMUM",NULL},
/* 12324 */ { "CUNEIFORM SIGN UMUM TIMES KASKAL",NULL},
/* 12325 */ { "CUNEIFORM SIGN UMUM TIMES PA",NULL},
/* 12326 */ { "CUNEIFORM SIGN UN","	= kalam gunû\n"
	"	* the names of this and the following sign incorrectly reflect the gunû relationship between them"},
/* 12327 */ { "CUNEIFORM SIGN UN GUNU","	% CUNEIFORM SIGN KALAM"},
/* 12328 */ { "CUNEIFORM SIGN UR",NULL},
/* 12329 */ { "CUNEIFORM SIGN UR CROSSING UR",NULL},
/* 1232A */ { "CUNEIFORM SIGN UR SHESHIG",NULL},
/* 1232B */ { "CUNEIFORM SIGN UR2",NULL},
/* 1232C */ { "CUNEIFORM SIGN UR2 TIMES A PLUS HA",NULL},
/* 1232D */ { "CUNEIFORM SIGN UR2 TIMES A PLUS NA",NULL},
/* 1232E */ { "CUNEIFORM SIGN UR2 TIMES AL",NULL},
/* 1232F */ { "CUNEIFORM SIGN UR2 TIMES HA",NULL},
/* 12330 */ { "CUNEIFORM SIGN UR2 TIMES NUN",NULL},
/* 12331 */ { "CUNEIFORM SIGN UR2 TIMES U2",NULL},
/* 12332 */ { "CUNEIFORM SIGN UR2 TIMES U2 PLUS ASH",NULL},
/* 12333 */ { "CUNEIFORM SIGN UR2 TIMES U2 PLUS BI",NULL},
/* 12334 */ { "CUNEIFORM SIGN UR4",NULL},
/* 12335 */ { "CUNEIFORM SIGN URI",NULL},
/* 12336 */ { "CUNEIFORM SIGN URI3",NULL},
/* 12337 */ { "CUNEIFORM SIGN URU",NULL},
/* 12338 */ { "CUNEIFORM SIGN URU TIMES A",NULL},
/* 12339 */ { "CUNEIFORM SIGN URU TIMES ASHGAB",NULL},
/* 1233A */ { "CUNEIFORM SIGN URU TIMES BAR",NULL},
/* 1233B */ { "CUNEIFORM SIGN URU TIMES DUN",NULL},
/* 1233C */ { "CUNEIFORM SIGN URU TIMES GA",NULL},
/* 1233D */ { "CUNEIFORM SIGN URU TIMES GAL",NULL},
/* 1233E */ { "CUNEIFORM SIGN URU TIMES GAN2 TENU",NULL},
/* 1233F */ { "CUNEIFORM SIGN URU TIMES GAR",NULL},
/* 12340 */ { "CUNEIFORM SIGN URU TIMES GU",NULL},
/* 12341 */ { "CUNEIFORM SIGN URU TIMES HA",NULL},
/* 12342 */ { "CUNEIFORM SIGN URU TIMES IGI",NULL},
/* 12343 */ { "CUNEIFORM SIGN URU TIMES IM",NULL},
/* 12344 */ { "CUNEIFORM SIGN URU TIMES ISH",NULL},
/* 12345 */ { "CUNEIFORM SIGN URU TIMES KI",NULL},
/* 12346 */ { "CUNEIFORM SIGN URU TIMES LUM",NULL},
/* 12347 */ { "CUNEIFORM SIGN URU TIMES MIN",NULL},
/* 12348 */ { "CUNEIFORM SIGN URU TIMES PA",NULL},
/* 12349 */ { "CUNEIFORM SIGN URU TIMES SHE",NULL},
/* 1234A */ { "CUNEIFORM SIGN URU TIMES SIG4",NULL},
/* 1234B */ { "CUNEIFORM SIGN URU TIMES TU",NULL},
/* 1234C */ { "CUNEIFORM SIGN URU TIMES U PLUS GUD",NULL},
/* 1234D */ { "CUNEIFORM SIGN URU TIMES UD",NULL},
/* 1234E */ { "CUNEIFORM SIGN URU TIMES URUDA",NULL},
/* 1234F */ { "CUNEIFORM SIGN URUDA",NULL},
/* 12350 */ { "CUNEIFORM SIGN URUDA TIMES U",NULL},
/* 12351 */ { "CUNEIFORM SIGN USH",NULL},
/* 12352 */ { "CUNEIFORM SIGN USH TIMES A",NULL},
/* 12353 */ { "CUNEIFORM SIGN USH TIMES KU",NULL},
/* 12354 */ { "CUNEIFORM SIGN USH TIMES KUR",NULL},
/* 12355 */ { "CUNEIFORM SIGN USH TIMES TAK4",NULL},
/* 12356 */ { "CUNEIFORM SIGN USHX",NULL},
/* 12357 */ { "CUNEIFORM SIGN USH2",NULL},
/* 12358 */ { "CUNEIFORM SIGN USHUMX",NULL},
/* 12359 */ { "CUNEIFORM SIGN UTUKI",NULL},
/* 1235A */ { "CUNEIFORM SIGN UZ3",NULL},
/* 1235B */ { "CUNEIFORM SIGN UZ3 TIMES KASKAL",NULL},
/* 1235C */ { "CUNEIFORM SIGN UZU",NULL},
/* 1235D */ { "CUNEIFORM SIGN ZA","	x (cuneiform numeric sign four dish - 12409)"},
/* 1235E */ { "CUNEIFORM SIGN ZA TENU","	x (cuneiform numeric sign four ash tenu - 1244C)"},
/* 1235F */ { "CUNEIFORM SIGN ZA SQUARED TIMES KUR",NULL},
/* 12360 */ { "CUNEIFORM SIGN ZAG",NULL},
/* 12361 */ { "CUNEIFORM SIGN ZAMX",NULL},
/* 12362 */ { "CUNEIFORM SIGN ZE2",NULL},
/* 12363 */ { "CUNEIFORM SIGN ZI",NULL},
/* 12364 */ { "CUNEIFORM SIGN ZI OVER ZI",NULL},
/* 12365 */ { "CUNEIFORM SIGN ZI3",NULL},
/* 12366 */ { "CUNEIFORM SIGN ZIB",NULL},
/* 12367 */ { "CUNEIFORM SIGN ZIB KABA TENU",NULL},
/* 12368 */ { "CUNEIFORM SIGN ZIG",NULL},
/* 12369 */ { "CUNEIFORM SIGN ZIZ2",NULL},
/* 1236A */ { "CUNEIFORM SIGN ZU",NULL},
/* 1236B */ { "CUNEIFORM SIGN ZU5",NULL},
/* 1236C */ { "CUNEIFORM SIGN ZU5 TIMES A",NULL},
/* 1236D */ { "CUNEIFORM SIGN ZUBUR",NULL},
/* 1236E */ { "CUNEIFORM SIGN ZUM",NULL},
/* 1236F */ { "CUNEIFORM SIGN KAP ELAMITE",NULL},
/* 12370 */ { "CUNEIFORM SIGN AB TIMES NUN",NULL},
/* 12371 */ { "CUNEIFORM SIGN AB2 TIMES A",NULL},
/* 12372 */ { "CUNEIFORM SIGN AMAR TIMES KUG",NULL},
/* 12373 */ { "CUNEIFORM SIGN DAG KISIM5 TIMES U2 PLUS MASH",NULL},
/* 12374 */ { "CUNEIFORM SIGN DAG3",NULL},
/* 12375 */ { "CUNEIFORM SIGN DISH PLUS SHU",NULL},
/* 12376 */ { "CUNEIFORM SIGN DUB TIMES SHE",NULL},
/* 12377 */ { "CUNEIFORM SIGN EZEN TIMES GUD",NULL},
/* 12378 */ { "CUNEIFORM SIGN EZEN TIMES SHE",NULL},
/* 12379 */ { "CUNEIFORM SIGN GA2 TIMES AN PLUS KAK PLUS A",NULL},
/* 1237A */ { "CUNEIFORM SIGN GA2 TIMES ASH2",NULL},
/* 1237B */ { "CUNEIFORM SIGN GE22",NULL},
/* 1237C */ { "CUNEIFORM SIGN GIG",NULL},
/* 1237D */ { "CUNEIFORM SIGN HUSH",NULL},
/* 1237E */ { "CUNEIFORM SIGN KA TIMES ANSHE",NULL},
/* 1237F */ { "CUNEIFORM SIGN KA TIMES ASH3",NULL},
/* 12380 */ { "CUNEIFORM SIGN KA TIMES GISH",NULL},
/* 12381 */ { "CUNEIFORM SIGN KA TIMES GUD",NULL},
/* 12382 */ { "CUNEIFORM SIGN KA TIMES HI TIMES ASH2",NULL},
/* 12383 */ { "CUNEIFORM SIGN KA TIMES LUM",NULL},
/* 12384 */ { "CUNEIFORM SIGN KA TIMES PA",NULL},
/* 12385 */ { "CUNEIFORM SIGN KA TIMES SHUL",NULL},
/* 12386 */ { "CUNEIFORM SIGN KA TIMES TU",NULL},
/* 12387 */ { "CUNEIFORM SIGN KA TIMES UR2",NULL},
/* 12388 */ { "CUNEIFORM SIGN LAGAB TIMES GI",NULL},
/* 12389 */ { "CUNEIFORM SIGN LU2 SHESHIG TIMES BAD",NULL},
/* 1238A */ { "CUNEIFORM SIGN LU2 TIMES ESH2 PLUS LAL",NULL},
/* 1238B */ { "CUNEIFORM SIGN LU2 TIMES SHU",NULL},
/* 1238C */ { "CUNEIFORM SIGN MESH",NULL},
/* 1238D */ { "CUNEIFORM SIGN MUSH3 TIMES ZA",NULL},
/* 1238E */ { "CUNEIFORM SIGN NA4",NULL},
/* 1238F */ { "CUNEIFORM SIGN NIN",NULL},
/* 12390 */ { "CUNEIFORM SIGN NIN9",NULL},
/* 12391 */ { "CUNEIFORM SIGN NINDA2 TIMES BAL",NULL},
/* 12392 */ { "CUNEIFORM SIGN NINDA2 TIMES GI",NULL},
/* 12393 */ { "CUNEIFORM SIGN NU11 ROTATED NINETY DEGREES",NULL},
/* 12394 */ { "CUNEIFORM SIGN PESH2 ASTERISK",NULL},
/* 12395 */ { "CUNEIFORM SIGN PIR2",NULL},
/* 12396 */ { "CUNEIFORM SIGN SAG TIMES IGI GUNU",NULL},
/* 12397 */ { "CUNEIFORM SIGN TI2",NULL},
/* 12398 */ { "CUNEIFORM SIGN UM TIMES ME",NULL},
/* 12399 */ { "CUNEIFORM SIGN U U","	= 2 u\n"
	"	= 2 bur₃\n"
	"	x (cuneiform numeric sign four u - 1240F)"},
/* 1239A */ { NULL,NULL},
/* 1239B */ { NULL,NULL},
/* 1239C */ { NULL,NULL},
/* 1239D */ { NULL,NULL},
/* 1239E */ { NULL,NULL},
/* 1239F */ { NULL,NULL},
/* 123A0 */ { NULL,NULL},
/* 123A1 */ { NULL,NULL},
/* 123A2 */ { NULL,NULL},
/* 123A3 */ { NULL,NULL},
/* 123A4 */ { NULL,NULL},
/* 123A5 */ { NULL,NULL},
/* 123A6 */ { NULL,NULL},
/* 123A7 */ { NULL,NULL},
/* 123A8 */ { NULL,NULL},
/* 123A9 */ { NULL,NULL},
/* 123AA */ { NULL,NULL},
/* 123AB */ { NULL,NULL},
/* 123AC */ { NULL,NULL},
/* 123AD */ { NULL,NULL},
/* 123AE */ { NULL,NULL},
/* 123AF */ { NULL,NULL},
/* 123B0 */ { NULL,NULL},
/* 123B1 */ { NULL,NULL},
/* 123B2 */ { NULL,NULL},
/* 123B3 */ { NULL,NULL},
/* 123B4 */ { NULL,NULL},
/* 123B5 */ { NULL,NULL},
/* 123B6 */ { NULL,NULL},
/* 123B7 */ { NULL,NULL},
/* 123B8 */ { NULL,NULL},
/* 123B9 */ { NULL,NULL},
/* 123BA */ { NULL,NULL},
/* 123BB */ { NULL,NULL},
/* 123BC */ { NULL,NULL},
/* 123BD */ { NULL,NULL},
/* 123BE */ { NULL,NULL},
/* 123BF */ { NULL,NULL},
/* 123C0 */ { NULL,NULL},
/* 123C1 */ { NULL,NULL},
/* 123C2 */ { NULL,NULL},
/* 123C3 */ { NULL,NULL},
/* 123C4 */ { NULL,NULL},
/* 123C5 */ { NULL,NULL},
/* 123C6 */ { NULL,NULL},
/* 123C7 */ { NULL,NULL},
/* 123C8 */ { NULL,NULL},
/* 123C9 */ { NULL,NULL},
/* 123CA */ { NULL,NULL},
/* 123CB */ { NULL,NULL},
/* 123CC */ { NULL,NULL},
/* 123CD */ { NULL,NULL},
/* 123CE */ { NULL,NULL},
/* 123CF */ { NULL,NULL},
/* 123D0 */ { NULL,NULL},
/* 123D1 */ { NULL,NULL},
/* 123D2 */ { NULL,NULL},
/* 123D3 */ { NULL,NULL},
/* 123D4 */ { NULL,NULL},
/* 123D5 */ { NULL,NULL},
/* 123D6 */ { NULL,NULL},
/* 123D7 */ { NULL,NULL},
/* 123D8 */ { NULL,NULL},
/* 123D9 */ { NULL,NULL},
/* 123DA */ { NULL,NULL},
/* 123DB */ { NULL,NULL},
/* 123DC */ { NULL,NULL},
/* 123DD */ { NULL,NULL},
/* 123DE */ { NULL,NULL},
/* 123DF */ { NULL,NULL},
/* 123E0 */ { NULL,NULL},
/* 123E1 */ { NULL,NULL},
/* 123E2 */ { NULL,NULL},
/* 123E3 */ { NULL,NULL},
/* 123E4 */ { NULL,NULL},
/* 123E5 */ { NULL,NULL},
/* 123E6 */ { NULL,NULL},
/* 123E7 */ { NULL,NULL},
/* 123E8 */ { NULL,NULL},
/* 123E9 */ { NULL,NULL},
/* 123EA */ { NULL,NULL},
/* 123EB */ { NULL,NULL},
/* 123EC */ { NULL,NULL},
/* 123ED */ { NULL,NULL},
/* 123EE */ { NULL,NULL},
/* 123EF */ { NULL,NULL},
/* 123F0 */ { NULL,NULL},
/* 123F1 */ { NULL,NULL},
/* 123F2 */ { NULL,NULL},
/* 123F3 */ { NULL,NULL},
/* 123F4 */ { NULL,NULL},
/* 123F5 */ { NULL,NULL},
/* 123F6 */ { NULL,NULL},
/* 123F7 */ { NULL,NULL},
/* 123F8 */ { NULL,NULL},
/* 123F9 */ { NULL,NULL},
/* 123FA */ { NULL,NULL},
/* 123FB */ { NULL,NULL},
/* 123FC */ { NULL,NULL},
/* 123FD */ { NULL,NULL},
/* 123FE */ { NULL,NULL},
/* 123FF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_24[] = {
/* 12400 */ { "CUNEIFORM NUMERIC SIGN TWO ASH","	= 2 iku\n"
	"	x (cuneiform sign ash - 12038)"},
/* 12401 */ { "CUNEIFORM NUMERIC SIGN THREE ASH",NULL},
/* 12402 */ { "CUNEIFORM NUMERIC SIGN FOUR ASH",NULL},
/* 12403 */ { "CUNEIFORM NUMERIC SIGN FIVE ASH",NULL},
/* 12404 */ { "CUNEIFORM NUMERIC SIGN SIX ASH",NULL},
/* 12405 */ { "CUNEIFORM NUMERIC SIGN SEVEN ASH",NULL},
/* 12406 */ { "CUNEIFORM NUMERIC SIGN EIGHT ASH",NULL},
/* 12407 */ { "CUNEIFORM NUMERIC SIGN NINE ASH",NULL},
/* 12408 */ { "CUNEIFORM NUMERIC SIGN THREE DISH","	x (cuneiform sign dish - 12079)\n"
	"	x (cuneiform sign min - 1222B)"},
/* 12409 */ { "CUNEIFORM NUMERIC SIGN FOUR DISH","	= 4 bariga"},
/* 1240A */ { "CUNEIFORM NUMERIC SIGN FIVE DISH",NULL},
/* 1240B */ { "CUNEIFORM NUMERIC SIGN SIX DISH",NULL},
/* 1240C */ { "CUNEIFORM NUMERIC SIGN SEVEN DISH",NULL},
/* 1240D */ { "CUNEIFORM NUMERIC SIGN EIGHT DISH",NULL},
/* 1240E */ { "CUNEIFORM NUMERIC SIGN NINE DISH",NULL},
/* 1240F */ { "CUNEIFORM NUMERIC SIGN FOUR U","	= 4 bur₃\n"
	"	x (cuneiform sign u - 1230B)\n"
	"	x (cuneiform sign u u - 12399)\n"
	"	x (cuneiform sign u u u - 1230D)"},
/* 12410 */ { "CUNEIFORM NUMERIC SIGN FIVE U",NULL},
/* 12411 */ { "CUNEIFORM NUMERIC SIGN SIX U",NULL},
/* 12412 */ { "CUNEIFORM NUMERIC SIGN SEVEN U",NULL},
/* 12413 */ { "CUNEIFORM NUMERIC SIGN EIGHT U",NULL},
/* 12414 */ { "CUNEIFORM NUMERIC SIGN NINE U",NULL},
/* 12415 */ { "CUNEIFORM NUMERIC SIGN ONE GESH2",NULL},
/* 12416 */ { "CUNEIFORM NUMERIC SIGN TWO GESH2",NULL},
/* 12417 */ { "CUNEIFORM NUMERIC SIGN THREE GESH2",NULL},
/* 12418 */ { "CUNEIFORM NUMERIC SIGN FOUR GESH2",NULL},
/* 12419 */ { "CUNEIFORM NUMERIC SIGN FIVE GESH2",NULL},
/* 1241A */ { "CUNEIFORM NUMERIC SIGN SIX GESH2",NULL},
/* 1241B */ { "CUNEIFORM NUMERIC SIGN SEVEN GESH2",NULL},
/* 1241C */ { "CUNEIFORM NUMERIC SIGN EIGHT GESH2",NULL},
/* 1241D */ { "CUNEIFORM NUMERIC SIGN NINE GESH2",NULL},
/* 1241E */ { "CUNEIFORM NUMERIC SIGN ONE GESHU",NULL},
/* 1241F */ { "CUNEIFORM NUMERIC SIGN TWO GESHU",NULL},
/* 12420 */ { "CUNEIFORM NUMERIC SIGN THREE GESHU",NULL},
/* 12421 */ { "CUNEIFORM NUMERIC SIGN FOUR GESHU",NULL},
/* 12422 */ { "CUNEIFORM NUMERIC SIGN FIVE GESHU",NULL},
/* 12423 */ { "CUNEIFORM NUMERIC SIGN TWO SHAR2","	x (cuneiform sign shar2 - 122B9)"},
/* 12424 */ { "CUNEIFORM NUMERIC SIGN THREE SHAR2",NULL},
/* 12425 */ { "CUNEIFORM NUMERIC SIGN THREE SHAR2 VARIANT FORM",NULL},
/* 12426 */ { "CUNEIFORM NUMERIC SIGN FOUR SHAR2",NULL},
/* 12427 */ { "CUNEIFORM NUMERIC SIGN FIVE SHAR2",NULL},
/* 12428 */ { "CUNEIFORM NUMERIC SIGN SIX SHAR2",NULL},
/* 12429 */ { "CUNEIFORM NUMERIC SIGN SEVEN SHAR2",NULL},
/* 1242A */ { "CUNEIFORM NUMERIC SIGN EIGHT SHAR2",NULL},
/* 1242B */ { "CUNEIFORM NUMERIC SIGN NINE SHAR2",NULL},
/* 1242C */ { "CUNEIFORM NUMERIC SIGN ONE SHARU",NULL},
/* 1242D */ { "CUNEIFORM NUMERIC SIGN TWO SHARU",NULL},
/* 1242E */ { "CUNEIFORM NUMERIC SIGN THREE SHARU",NULL},
/* 1242F */ { "CUNEIFORM NUMERIC SIGN THREE SHARU VARIANT FORM",NULL},
/* 12430 */ { "CUNEIFORM NUMERIC SIGN FOUR SHARU",NULL},
/* 12431 */ { "CUNEIFORM NUMERIC SIGN FIVE SHARU",NULL},
/* 12432 */ { "CUNEIFORM NUMERIC SIGN SHAR2 TIMES GAL PLUS DISH",NULL},
/* 12433 */ { "CUNEIFORM NUMERIC SIGN SHAR2 TIMES GAL PLUS MIN",NULL},
/* 12434 */ { "CUNEIFORM NUMERIC SIGN ONE BURU",NULL},
/* 12435 */ { "CUNEIFORM NUMERIC SIGN TWO BURU",NULL},
/* 12436 */ { "CUNEIFORM NUMERIC SIGN THREE BURU",NULL},
/* 12437 */ { "CUNEIFORM NUMERIC SIGN THREE BURU VARIANT FORM",NULL},
/* 12438 */ { "CUNEIFORM NUMERIC SIGN FOUR BURU",NULL},
/* 12439 */ { "CUNEIFORM NUMERIC SIGN FIVE BURU",NULL},
/* 1243A */ { "CUNEIFORM NUMERIC SIGN THREE VARIANT FORM ESH16",NULL},
/* 1243B */ { "CUNEIFORM NUMERIC SIGN THREE VARIANT FORM ESH21",NULL},
/* 1243C */ { "CUNEIFORM NUMERIC SIGN FOUR VARIANT FORM LIMMU",NULL},
/* 1243D */ { "CUNEIFORM NUMERIC SIGN FOUR VARIANT FORM LIMMU4",NULL},
/* 1243E */ { "CUNEIFORM NUMERIC SIGN FOUR VARIANT FORM LIMMU A",NULL},
/* 1243F */ { "CUNEIFORM NUMERIC SIGN FOUR VARIANT FORM LIMMU B",NULL},
/* 12440 */ { "CUNEIFORM NUMERIC SIGN SIX VARIANT FORM ASH9",NULL},
/* 12441 */ { "CUNEIFORM NUMERIC SIGN SEVEN VARIANT FORM IMIN3",NULL},
/* 12442 */ { "CUNEIFORM NUMERIC SIGN SEVEN VARIANT FORM IMIN A",NULL},
/* 12443 */ { "CUNEIFORM NUMERIC SIGN SEVEN VARIANT FORM IMIN B",NULL},
/* 12444 */ { "CUNEIFORM NUMERIC SIGN EIGHT VARIANT FORM USSU",NULL},
/* 12445 */ { "CUNEIFORM NUMERIC SIGN EIGHT VARIANT FORM USSU3",NULL},
/* 12446 */ { "CUNEIFORM NUMERIC SIGN NINE VARIANT FORM ILIMMU",NULL},
/* 12447 */ { "CUNEIFORM NUMERIC SIGN NINE VARIANT FORM ILIMMU3",NULL},
/* 12448 */ { "CUNEIFORM NUMERIC SIGN NINE VARIANT FORM ILIMMU4",NULL},
/* 12449 */ { "CUNEIFORM NUMERIC SIGN NINE VARIANT FORM ILIMMU A",NULL},
/* 1244A */ { "CUNEIFORM NUMERIC SIGN TWO ASH TENU","	= 2 diš tenû\n"
	"	x (cuneiform sign ash zida tenu - 12039)"},
/* 1244B */ { "CUNEIFORM NUMERIC SIGN THREE ASH TENU",NULL},
/* 1244C */ { "CUNEIFORM NUMERIC SIGN FOUR ASH TENU",NULL},
/* 1244D */ { "CUNEIFORM NUMERIC SIGN FIVE ASH TENU",NULL},
/* 1244E */ { "CUNEIFORM NUMERIC SIGN SIX ASH TENU",NULL},
/* 1244F */ { "CUNEIFORM NUMERIC SIGN ONE BAN2","	* 12226 should be used for 1/2 diš\n"
	"	x (cuneiform sign mash - 12226)"},
/* 12450 */ { "CUNEIFORM NUMERIC SIGN TWO BAN2",NULL},
/* 12451 */ { "CUNEIFORM NUMERIC SIGN THREE BAN2",NULL},
/* 12452 */ { "CUNEIFORM NUMERIC SIGN FOUR BAN2",NULL},
/* 12453 */ { "CUNEIFORM NUMERIC SIGN FOUR BAN2 VARIANT FORM",NULL},
/* 12454 */ { "CUNEIFORM NUMERIC SIGN FIVE BAN2",NULL},
/* 12455 */ { "CUNEIFORM NUMERIC SIGN FIVE BAN2 VARIANT FORM",NULL},
/* 12456 */ { "CUNEIFORM NUMERIC SIGN NIGIDAMIN","	= 2 bariga\n"
	"	x (cuneiform sign dish - 12079)"},
/* 12457 */ { "CUNEIFORM NUMERIC SIGN NIGIDAESH","	= 3 bariga"},
/* 12458 */ { "CUNEIFORM NUMERIC SIGN ONE ESHE3",NULL},
/* 12459 */ { "CUNEIFORM NUMERIC SIGN TWO ESHE3",NULL},
/* 1245A */ { "CUNEIFORM NUMERIC SIGN ONE THIRD DISH",NULL},
/* 1245B */ { "CUNEIFORM NUMERIC SIGN TWO THIRDS DISH",NULL},
/* 1245C */ { "CUNEIFORM NUMERIC SIGN FIVE SIXTHS DISH",NULL},
/* 1245D */ { "CUNEIFORM NUMERIC SIGN ONE THIRD VARIANT FORM A","	= 1/3 aš curved\n"
	"	= 1/3 diš curved"},
/* 1245E */ { "CUNEIFORM NUMERIC SIGN TWO THIRDS VARIANT FORM A","	= 2/3 aš curved\n"
	"	= 2/3 diš curved"},
/* 1245F */ { "CUNEIFORM NUMERIC SIGN ONE EIGHTH ASH","	= 1/8 iku"},
/* 12460 */ { "CUNEIFORM NUMERIC SIGN ONE QUARTER ASH","	= 1/4 iku"},
/* 12461 */ { "CUNEIFORM NUMERIC SIGN OLD ASSYRIAN ONE SIXTH",NULL},
/* 12462 */ { "CUNEIFORM NUMERIC SIGN OLD ASSYRIAN ONE QUARTER",NULL},
/* 12463 */ { "CUNEIFORM NUMERIC SIGN ONE QUARTER GUR","	= 1 bariga variant form"},
/* 12464 */ { "CUNEIFORM NUMERIC SIGN ONE HALF GUR","	= 2 bariga variant form\n"
	"	* the sequence 12464 12463 is used for 3/4 gur"},
/* 12465 */ { "CUNEIFORM NUMERIC SIGN ELAMITE ONE THIRD",NULL},
/* 12466 */ { "CUNEIFORM NUMERIC SIGN ELAMITE TWO THIRDS",NULL},
/* 12467 */ { "CUNEIFORM NUMERIC SIGN ELAMITE FORTY",NULL},
/* 12468 */ { "CUNEIFORM NUMERIC SIGN ELAMITE FIFTY",NULL},
/* 12469 */ { "CUNEIFORM NUMERIC SIGN FOUR U VARIANT FORM",NULL},
/* 1246A */ { "CUNEIFORM NUMERIC SIGN FIVE U VARIANT FORM",NULL},
/* 1246B */ { "CUNEIFORM NUMERIC SIGN SIX U VARIANT FORM",NULL},
/* 1246C */ { "CUNEIFORM NUMERIC SIGN SEVEN U VARIANT FORM",NULL},
/* 1246D */ { "CUNEIFORM NUMERIC SIGN EIGHT U VARIANT FORM",NULL},
/* 1246E */ { "CUNEIFORM NUMERIC SIGN NINE U VARIANT FORM",NULL},
/* 1246F */ { NULL,NULL},
/* 12470 */ { "CUNEIFORM PUNCTUATION SIGN OLD ASSYRIAN WORD DIVIDER","	x (ugaritic word divider - 1039F)\n"
	"	x (old persian word divider - 103D0)"},
/* 12471 */ { "CUNEIFORM PUNCTUATION SIGN VERTICAL COLON",NULL},
/* 12472 */ { "CUNEIFORM PUNCTUATION SIGN DIAGONAL COLON",NULL},
/* 12473 */ { "CUNEIFORM PUNCTUATION SIGN DIAGONAL TRICOLON",NULL},
/* 12474 */ { "CUNEIFORM PUNCTUATION SIGN DIAGONAL QUADCOLON",NULL},
/* 12475 */ { NULL,NULL},
/* 12476 */ { NULL,NULL},
/* 12477 */ { NULL,NULL},
/* 12478 */ { NULL,NULL},
/* 12479 */ { NULL,NULL},
/* 1247A */ { NULL,NULL},
/* 1247B */ { NULL,NULL},
/* 1247C */ { NULL,NULL},
/* 1247D */ { NULL,NULL},
/* 1247E */ { NULL,NULL},
/* 1247F */ { NULL,NULL},
/* 12480 */ { "CUNEIFORM SIGN AB TIMES NUN TENU",NULL},
/* 12481 */ { "CUNEIFORM SIGN AB TIMES SHU2",NULL},
/* 12482 */ { "CUNEIFORM SIGN AD TIMES ESH2",NULL},
/* 12483 */ { "CUNEIFORM SIGN BAD TIMES DISH TENU",NULL},
/* 12484 */ { "CUNEIFORM SIGN BAHAR2 TIMES AB2",NULL},
/* 12485 */ { "CUNEIFORM SIGN BAHAR2 TIMES NI",NULL},
/* 12486 */ { "CUNEIFORM SIGN BAHAR2 TIMES ZA",NULL},
/* 12487 */ { "CUNEIFORM SIGN BU OVER BU TIMES NA2",NULL},
/* 12488 */ { "CUNEIFORM SIGN DA TIMES TAK4",NULL},
/* 12489 */ { "CUNEIFORM SIGN DAG TIMES KUR",NULL},
/* 1248A */ { "CUNEIFORM SIGN DIM TIMES IGI",NULL},
/* 1248B */ { "CUNEIFORM SIGN DIM TIMES U U U",NULL},
/* 1248C */ { "CUNEIFORM SIGN DIM2 TIMES UD",NULL},
/* 1248D */ { "CUNEIFORM SIGN DUG TIMES ANSHE",NULL},
/* 1248E */ { "CUNEIFORM SIGN DUG TIMES ASH",NULL},
/* 1248F */ { "CUNEIFORM SIGN DUG TIMES ASH AT LEFT",NULL},
/* 12490 */ { "CUNEIFORM SIGN DUG TIMES DIN",NULL},
/* 12491 */ { "CUNEIFORM SIGN DUG TIMES DUN",NULL},
/* 12492 */ { "CUNEIFORM SIGN DUG TIMES ERIN2",NULL},
/* 12493 */ { "CUNEIFORM SIGN DUG TIMES GA",NULL},
/* 12494 */ { "CUNEIFORM SIGN DUG TIMES GI",NULL},
/* 12495 */ { "CUNEIFORM SIGN DUG TIMES GIR2 GUNU",NULL},
/* 12496 */ { "CUNEIFORM SIGN DUG TIMES GISH",NULL},
/* 12497 */ { "CUNEIFORM SIGN DUG TIMES HA",NULL},
/* 12498 */ { "CUNEIFORM SIGN DUG TIMES HI",NULL},
/* 12499 */ { "CUNEIFORM SIGN DUG TIMES IGI GUNU",NULL},
/* 1249A */ { "CUNEIFORM SIGN DUG TIMES KASKAL",NULL},
/* 1249B */ { "CUNEIFORM SIGN DUG TIMES KUR",NULL},
/* 1249C */ { "CUNEIFORM SIGN DUG TIMES KUSHU2",NULL},
/* 1249D */ { "CUNEIFORM SIGN DUG TIMES KUSHU2 PLUS KASKAL",NULL},
/* 1249E */ { "CUNEIFORM SIGN DUG TIMES LAK-020",NULL},
/* 1249F */ { "CUNEIFORM SIGN DUG TIMES LAM",NULL},
/* 124A0 */ { "CUNEIFORM SIGN DUG TIMES LAM TIMES KUR",NULL},
/* 124A1 */ { "CUNEIFORM SIGN DUG TIMES LUH PLUS GISH",NULL},
/* 124A2 */ { "CUNEIFORM SIGN DUG TIMES MASH",NULL},
/* 124A3 */ { "CUNEIFORM SIGN DUG TIMES MES",NULL},
/* 124A4 */ { "CUNEIFORM SIGN DUG TIMES MI",NULL},
/* 124A5 */ { "CUNEIFORM SIGN DUG TIMES NI",NULL},
/* 124A6 */ { "CUNEIFORM SIGN DUG TIMES PI",NULL},
/* 124A7 */ { "CUNEIFORM SIGN DUG TIMES SHE",NULL},
/* 124A8 */ { "CUNEIFORM SIGN DUG TIMES SI GUNU",NULL},
/* 124A9 */ { "CUNEIFORM SIGN E2 TIMES KUR",NULL},
/* 124AA */ { "CUNEIFORM SIGN E2 TIMES PAP",NULL},
/* 124AB */ { "CUNEIFORM SIGN ERIN2 X",NULL},
/* 124AC */ { "CUNEIFORM SIGN ESH2 CROSSING ESH2",NULL},
/* 124AD */ { "CUNEIFORM SIGN EZEN SHESHIG TIMES ASH",NULL},
/* 124AE */ { "CUNEIFORM SIGN EZEN SHESHIG TIMES HI",NULL},
/* 124AF */ { "CUNEIFORM SIGN EZEN SHESHIG TIMES IGI GUNU",NULL},
/* 124B0 */ { "CUNEIFORM SIGN EZEN SHESHIG TIMES LA",NULL},
/* 124B1 */ { "CUNEIFORM SIGN EZEN SHESHIG TIMES LAL",NULL},
/* 124B2 */ { "CUNEIFORM SIGN EZEN SHESHIG TIMES ME",NULL},
/* 124B3 */ { "CUNEIFORM SIGN EZEN SHESHIG TIMES MES",NULL},
/* 124B4 */ { "CUNEIFORM SIGN EZEN SHESHIG TIMES SU",NULL},
/* 124B5 */ { "CUNEIFORM SIGN EZEN TIMES SU",NULL},
/* 124B6 */ { "CUNEIFORM SIGN GA2 TIMES BAHAR2",NULL},
/* 124B7 */ { "CUNEIFORM SIGN GA2 TIMES DIM GUNU",NULL},
/* 124B8 */ { "CUNEIFORM SIGN GA2 TIMES DUG TIMES IGI GUNU",NULL},
/* 124B9 */ { "CUNEIFORM SIGN GA2 TIMES DUG TIMES KASKAL",NULL},
/* 124BA */ { "CUNEIFORM SIGN GA2 TIMES EREN",NULL},
/* 124BB */ { "CUNEIFORM SIGN GA2 TIMES GA",NULL},
/* 124BC */ { "CUNEIFORM SIGN GA2 TIMES GAR PLUS DI",NULL},
/* 124BD */ { "CUNEIFORM SIGN GA2 TIMES GAR PLUS NE",NULL},
/* 124BE */ { "CUNEIFORM SIGN GA2 TIMES HA PLUS A",NULL},
/* 124BF */ { "CUNEIFORM SIGN GA2 TIMES KUSHU2 PLUS KASKAL",NULL},
/* 124C0 */ { "CUNEIFORM SIGN GA2 TIMES LAM",NULL},
/* 124C1 */ { "CUNEIFORM SIGN GA2 TIMES LAM TIMES KUR",NULL},
/* 124C2 */ { "CUNEIFORM SIGN GA2 TIMES LUH",NULL},
/* 124C3 */ { "CUNEIFORM SIGN GA2 TIMES MUSH",NULL},
/* 124C4 */ { "CUNEIFORM SIGN GA2 TIMES NE",NULL},
/* 124C5 */ { "CUNEIFORM SIGN GA2 TIMES NE PLUS E2",NULL},
/* 124C6 */ { "CUNEIFORM SIGN GA2 TIMES NE PLUS GI",NULL},
/* 124C7 */ { "CUNEIFORM SIGN GA2 TIMES SHIM",NULL},
/* 124C8 */ { "CUNEIFORM SIGN GA2 TIMES ZIZ2",NULL},
/* 124C9 */ { "CUNEIFORM SIGN GABA ROTATED NINETY DEGREES",NULL},
/* 124CA */ { "CUNEIFORM SIGN GESHTIN TIMES U",NULL},
/* 124CB */ { "CUNEIFORM SIGN GISH TIMES GISH CROSSING GISH",NULL},
/* 124CC */ { "CUNEIFORM SIGN GU2 TIMES IGI GUNU",NULL},
/* 124CD */ { "CUNEIFORM SIGN GUD PLUS GISH TIMES TAK4",NULL},
/* 124CE */ { "CUNEIFORM SIGN HA TENU GUNU",NULL},
/* 124CF */ { "CUNEIFORM SIGN HI TIMES ASH OVER HI TIMES ASH",NULL},
/* 124D0 */ { "CUNEIFORM SIGN KA TIMES BU",NULL},
/* 124D1 */ { "CUNEIFORM SIGN KA TIMES KA",NULL},
/* 124D2 */ { "CUNEIFORM SIGN KA TIMES U U U",NULL},
/* 124D3 */ { "CUNEIFORM SIGN KA TIMES UR",NULL},
/* 124D4 */ { "CUNEIFORM SIGN LAGAB TIMES ZU OVER ZU",NULL},
/* 124D5 */ { "CUNEIFORM SIGN LAK-003",NULL},
/* 124D6 */ { "CUNEIFORM SIGN LAK-021",NULL},
/* 124D7 */ { "CUNEIFORM SIGN LAK-025",NULL},
/* 124D8 */ { "CUNEIFORM SIGN LAK-030",NULL},
/* 124D9 */ { "CUNEIFORM SIGN LAK-050",NULL},
/* 124DA */ { "CUNEIFORM SIGN LAK-051",NULL},
/* 124DB */ { "CUNEIFORM SIGN LAK-062",NULL},
/* 124DC */ { "CUNEIFORM SIGN LAK-079 OVER LAK-079 GUNU",NULL},
/* 124DD */ { "CUNEIFORM SIGN LAK-080",NULL},
/* 124DE */ { "CUNEIFORM SIGN LAK-081 OVER LAK-081",NULL},
/* 124DF */ { "CUNEIFORM SIGN LAK-092",NULL},
/* 124E0 */ { "CUNEIFORM SIGN LAK-130",NULL},
/* 124E1 */ { "CUNEIFORM SIGN LAK-142",NULL},
/* 124E2 */ { "CUNEIFORM SIGN LAK-210",NULL},
/* 124E3 */ { "CUNEIFORM SIGN LAK-219",NULL},
/* 124E4 */ { "CUNEIFORM SIGN LAK-220",NULL},
/* 124E5 */ { "CUNEIFORM SIGN LAK-225",NULL},
/* 124E6 */ { "CUNEIFORM SIGN LAK-228",NULL},
/* 124E7 */ { "CUNEIFORM SIGN LAK-238",NULL},
/* 124E8 */ { "CUNEIFORM SIGN LAK-265",NULL},
/* 124E9 */ { "CUNEIFORM SIGN LAK-266",NULL},
/* 124EA */ { "CUNEIFORM SIGN LAK-343",NULL},
/* 124EB */ { "CUNEIFORM SIGN LAK-347",NULL},
/* 124EC */ { "CUNEIFORM SIGN LAK-348",NULL},
/* 124ED */ { "CUNEIFORM SIGN LAK-383",NULL},
/* 124EE */ { "CUNEIFORM SIGN LAK-384",NULL},
/* 124EF */ { "CUNEIFORM SIGN LAK-390",NULL},
/* 124F0 */ { "CUNEIFORM SIGN LAK-441",NULL},
/* 124F1 */ { "CUNEIFORM SIGN LAK-449",NULL},
/* 124F2 */ { "CUNEIFORM SIGN LAK-449 TIMES GU",NULL},
/* 124F3 */ { "CUNEIFORM SIGN LAK-449 TIMES IGI",NULL},
/* 124F4 */ { "CUNEIFORM SIGN LAK-449 TIMES PAP PLUS LU3",NULL},
/* 124F5 */ { "CUNEIFORM SIGN LAK-449 TIMES PAP PLUS PAP PLUS LU3",NULL},
/* 124F6 */ { "CUNEIFORM SIGN LAK-449 TIMES U2 PLUS BA",NULL},
/* 124F7 */ { "CUNEIFORM SIGN LAK-450",NULL},
/* 124F8 */ { "CUNEIFORM SIGN LAK-457",NULL},
/* 124F9 */ { "CUNEIFORM SIGN LAK-470",NULL},
/* 124FA */ { "CUNEIFORM SIGN LAK-483",NULL},
/* 124FB */ { "CUNEIFORM SIGN LAK-490",NULL},
/* 124FC */ { "CUNEIFORM SIGN LAK-492",NULL},
/* 124FD */ { "CUNEIFORM SIGN LAK-493",NULL},
/* 124FE */ { "CUNEIFORM SIGN LAK-495",NULL},
/* 124FF */ { "CUNEIFORM SIGN LAK-550",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_25[] = {
/* 12500 */ { "CUNEIFORM SIGN LAK-608",NULL},
/* 12501 */ { "CUNEIFORM SIGN LAK-617",NULL},
/* 12502 */ { "CUNEIFORM SIGN LAK-617 TIMES ASH",NULL},
/* 12503 */ { "CUNEIFORM SIGN LAK-617 TIMES BAD",NULL},
/* 12504 */ { "CUNEIFORM SIGN LAK-617 TIMES DUN3 GUNU GUNU",NULL},
/* 12505 */ { "CUNEIFORM SIGN LAK-617 TIMES KU3",NULL},
/* 12506 */ { "CUNEIFORM SIGN LAK-617 TIMES LA",NULL},
/* 12507 */ { "CUNEIFORM SIGN LAK-617 TIMES TAR",NULL},
/* 12508 */ { "CUNEIFORM SIGN LAK-617 TIMES TE",NULL},
/* 12509 */ { "CUNEIFORM SIGN LAK-617 TIMES U2",NULL},
/* 1250A */ { "CUNEIFORM SIGN LAK-617 TIMES UD",NULL},
/* 1250B */ { "CUNEIFORM SIGN LAK-617 TIMES URUDA",NULL},
/* 1250C */ { "CUNEIFORM SIGN LAK-636",NULL},
/* 1250D */ { "CUNEIFORM SIGN LAK-648",NULL},
/* 1250E */ { "CUNEIFORM SIGN LAK-648 TIMES DUB",NULL},
/* 1250F */ { "CUNEIFORM SIGN LAK-648 TIMES GA",NULL},
/* 12510 */ { "CUNEIFORM SIGN LAK-648 TIMES IGI",NULL},
/* 12511 */ { "CUNEIFORM SIGN LAK-648 TIMES IGI GUNU",NULL},
/* 12512 */ { "CUNEIFORM SIGN LAK-648 TIMES NI",NULL},
/* 12513 */ { "CUNEIFORM SIGN LAK-648 TIMES PAP PLUS PAP PLUS LU3",NULL},
/* 12514 */ { "CUNEIFORM SIGN LAK-648 TIMES SHESH PLUS KI",NULL},
/* 12515 */ { "CUNEIFORM SIGN LAK-648 TIMES UD",NULL},
/* 12516 */ { "CUNEIFORM SIGN LAK-648 TIMES URUDA",NULL},
/* 12517 */ { "CUNEIFORM SIGN LAK-724",NULL},
/* 12518 */ { "CUNEIFORM SIGN LAK-749",NULL},
/* 12519 */ { "CUNEIFORM SIGN LU2 GUNU TIMES ASH",NULL},
/* 1251A */ { "CUNEIFORM SIGN LU2 TIMES DISH",NULL},
/* 1251B */ { "CUNEIFORM SIGN LU2 TIMES HAL",NULL},
/* 1251C */ { "CUNEIFORM SIGN LU2 TIMES PAP",NULL},
/* 1251D */ { "CUNEIFORM SIGN LU2 TIMES PAP PLUS PAP PLUS LU3",NULL},
/* 1251E */ { "CUNEIFORM SIGN LU2 TIMES TAK4",NULL},
/* 1251F */ { "CUNEIFORM SIGN MI PLUS ZA7",NULL},
/* 12520 */ { "CUNEIFORM SIGN MUSH OVER MUSH TIMES GA",NULL},
/* 12521 */ { "CUNEIFORM SIGN MUSH OVER MUSH TIMES KAK",NULL},
/* 12522 */ { "CUNEIFORM SIGN NINDA2 TIMES DIM GUNU",NULL},
/* 12523 */ { "CUNEIFORM SIGN NINDA2 TIMES GISH",NULL},
/* 12524 */ { "CUNEIFORM SIGN NINDA2 TIMES GUL",NULL},
/* 12525 */ { "CUNEIFORM SIGN NINDA2 TIMES HI",NULL},
/* 12526 */ { "CUNEIFORM SIGN NINDA2 TIMES KESH2",NULL},
/* 12527 */ { "CUNEIFORM SIGN NINDA2 TIMES LAK-050",NULL},
/* 12528 */ { "CUNEIFORM SIGN NINDA2 TIMES MASH",NULL},
/* 12529 */ { "CUNEIFORM SIGN NINDA2 TIMES PAP PLUS PAP",NULL},
/* 1252A */ { "CUNEIFORM SIGN NINDA2 TIMES U",NULL},
/* 1252B */ { "CUNEIFORM SIGN NINDA2 TIMES U PLUS U",NULL},
/* 1252C */ { "CUNEIFORM SIGN NINDA2 TIMES URUDA",NULL},
/* 1252D */ { "CUNEIFORM SIGN SAG GUNU TIMES HA",NULL},
/* 1252E */ { "CUNEIFORM SIGN SAG TIMES EN",NULL},
/* 1252F */ { "CUNEIFORM SIGN SAG TIMES SHE AT LEFT",NULL},
/* 12530 */ { "CUNEIFORM SIGN SAG TIMES TAK4",NULL},
/* 12531 */ { "CUNEIFORM SIGN SHA6 TENU",NULL},
/* 12532 */ { "CUNEIFORM SIGN SHE OVER SHE",NULL},
/* 12533 */ { "CUNEIFORM SIGN SHE PLUS HUB2",NULL},
/* 12534 */ { "CUNEIFORM SIGN SHE PLUS NAM2",NULL},
/* 12535 */ { "CUNEIFORM SIGN SHE PLUS SAR",NULL},
/* 12536 */ { "CUNEIFORM SIGN SHU2 PLUS DUG TIMES NI",NULL},
/* 12537 */ { "CUNEIFORM SIGN SHU2 PLUS E2 TIMES AN",NULL},
/* 12538 */ { "CUNEIFORM SIGN SI TIMES TAK4",NULL},
/* 12539 */ { "CUNEIFORM SIGN TAK4 PLUS SAG",NULL},
/* 1253A */ { "CUNEIFORM SIGN TUM TIMES GAN2 TENU",NULL},
/* 1253B */ { "CUNEIFORM SIGN TUM TIMES THREE DISH",NULL},
/* 1253C */ { "CUNEIFORM SIGN UR2 INVERTED",NULL},
/* 1253D */ { "CUNEIFORM SIGN UR2 TIMES UD",NULL},
/* 1253E */ { "CUNEIFORM SIGN URU TIMES DARA3",NULL},
/* 1253F */ { "CUNEIFORM SIGN URU TIMES LAK-668",NULL},
/* 12540 */ { "CUNEIFORM SIGN URU TIMES LU3",NULL},
/* 12541 */ { "CUNEIFORM SIGN ZA7",NULL},
/* 12542 */ { "CUNEIFORM SIGN ZU OVER ZU PLUS SAR",NULL},
/* 12543 */ { "CUNEIFORM SIGN ZU5 TIMES THREE DISH TENU",NULL},
/* 12544 */ { NULL,NULL},
/* 12545 */ { NULL,NULL},
/* 12546 */ { NULL,NULL},
/* 12547 */ { NULL,NULL},
/* 12548 */ { NULL,NULL},
/* 12549 */ { NULL,NULL},
/* 1254A */ { NULL,NULL},
/* 1254B */ { NULL,NULL},
/* 1254C */ { NULL,NULL},
/* 1254D */ { NULL,NULL},
/* 1254E */ { NULL,NULL},
/* 1254F */ { NULL,NULL},
/* 12550 */ { NULL,NULL},
/* 12551 */ { NULL,NULL},
/* 12552 */ { NULL,NULL},
/* 12553 */ { NULL,NULL},
/* 12554 */ { NULL,NULL},
/* 12555 */ { NULL,NULL},
/* 12556 */ { NULL,NULL},
/* 12557 */ { NULL,NULL},
/* 12558 */ { NULL,NULL},
/* 12559 */ { NULL,NULL},
/* 1255A */ { NULL,NULL},
/* 1255B */ { NULL,NULL},
/* 1255C */ { NULL,NULL},
/* 1255D */ { NULL,NULL},
/* 1255E */ { NULL,NULL},
/* 1255F */ { NULL,NULL},
/* 12560 */ { NULL,NULL},
/* 12561 */ { NULL,NULL},
/* 12562 */ { NULL,NULL},
/* 12563 */ { NULL,NULL},
/* 12564 */ { NULL,NULL},
/* 12565 */ { NULL,NULL},
/* 12566 */ { NULL,NULL},
/* 12567 */ { NULL,NULL},
/* 12568 */ { NULL,NULL},
/* 12569 */ { NULL,NULL},
/* 1256A */ { NULL,NULL},
/* 1256B */ { NULL,NULL},
/* 1256C */ { NULL,NULL},
/* 1256D */ { NULL,NULL},
/* 1256E */ { NULL,NULL},
/* 1256F */ { NULL,NULL},
/* 12570 */ { NULL,NULL},
/* 12571 */ { NULL,NULL},
/* 12572 */ { NULL,NULL},
/* 12573 */ { NULL,NULL},
/* 12574 */ { NULL,NULL},
/* 12575 */ { NULL,NULL},
/* 12576 */ { NULL,NULL},
/* 12577 */ { NULL,NULL},
/* 12578 */ { NULL,NULL},
/* 12579 */ { NULL,NULL},
/* 1257A */ { NULL,NULL},
/* 1257B */ { NULL,NULL},
/* 1257C */ { NULL,NULL},
/* 1257D */ { NULL,NULL},
/* 1257E */ { NULL,NULL},
/* 1257F */ { NULL,NULL},
/* 12580 */ { NULL,NULL},
/* 12581 */ { NULL,NULL},
/* 12582 */ { NULL,NULL},
/* 12583 */ { NULL,NULL},
/* 12584 */ { NULL,NULL},
/* 12585 */ { NULL,NULL},
/* 12586 */ { NULL,NULL},
/* 12587 */ { NULL,NULL},
/* 12588 */ { NULL,NULL},
/* 12589 */ { NULL,NULL},
/* 1258A */ { NULL,NULL},
/* 1258B */ { NULL,NULL},
/* 1258C */ { NULL,NULL},
/* 1258D */ { NULL,NULL},
/* 1258E */ { NULL,NULL},
/* 1258F */ { NULL,NULL},
/* 12590 */ { NULL,NULL},
/* 12591 */ { NULL,NULL},
/* 12592 */ { NULL,NULL},
/* 12593 */ { NULL,NULL},
/* 12594 */ { NULL,NULL},
/* 12595 */ { NULL,NULL},
/* 12596 */ { NULL,NULL},
/* 12597 */ { NULL,NULL},
/* 12598 */ { NULL,NULL},
/* 12599 */ { NULL,NULL},
/* 1259A */ { NULL,NULL},
/* 1259B */ { NULL,NULL},
/* 1259C */ { NULL,NULL},
/* 1259D */ { NULL,NULL},
/* 1259E */ { NULL,NULL},
/* 1259F */ { NULL,NULL},
/* 125A0 */ { NULL,NULL},
/* 125A1 */ { NULL,NULL},
/* 125A2 */ { NULL,NULL},
/* 125A3 */ { NULL,NULL},
/* 125A4 */ { NULL,NULL},
/* 125A5 */ { NULL,NULL},
/* 125A6 */ { NULL,NULL},
/* 125A7 */ { NULL,NULL},
/* 125A8 */ { NULL,NULL},
/* 125A9 */ { NULL,NULL},
/* 125AA */ { NULL,NULL},
/* 125AB */ { NULL,NULL},
/* 125AC */ { NULL,NULL},
/* 125AD */ { NULL,NULL},
/* 125AE */ { NULL,NULL},
/* 125AF */ { NULL,NULL},
/* 125B0 */ { NULL,NULL},
/* 125B1 */ { NULL,NULL},
/* 125B2 */ { NULL,NULL},
/* 125B3 */ { NULL,NULL},
/* 125B4 */ { NULL,NULL},
/* 125B5 */ { NULL,NULL},
/* 125B6 */ { NULL,NULL},
/* 125B7 */ { NULL,NULL},
/* 125B8 */ { NULL,NULL},
/* 125B9 */ { NULL,NULL},
/* 125BA */ { NULL,NULL},
/* 125BB */ { NULL,NULL},
/* 125BC */ { NULL,NULL},
/* 125BD */ { NULL,NULL},
/* 125BE */ { NULL,NULL},
/* 125BF */ { NULL,NULL},
/* 125C0 */ { NULL,NULL},
/* 125C1 */ { NULL,NULL},
/* 125C2 */ { NULL,NULL},
/* 125C3 */ { NULL,NULL},
/* 125C4 */ { NULL,NULL},
/* 125C5 */ { NULL,NULL},
/* 125C6 */ { NULL,NULL},
/* 125C7 */ { NULL,NULL},
/* 125C8 */ { NULL,NULL},
/* 125C9 */ { NULL,NULL},
/* 125CA */ { NULL,NULL},
/* 125CB */ { NULL,NULL},
/* 125CC */ { NULL,NULL},
/* 125CD */ { NULL,NULL},
/* 125CE */ { NULL,NULL},
/* 125CF */ { NULL,NULL},
/* 125D0 */ { NULL,NULL},
/* 125D1 */ { NULL,NULL},
/* 125D2 */ { NULL,NULL},
/* 125D3 */ { NULL,NULL},
/* 125D4 */ { NULL,NULL},
/* 125D5 */ { NULL,NULL},
/* 125D6 */ { NULL,NULL},
/* 125D7 */ { NULL,NULL},
/* 125D8 */ { NULL,NULL},
/* 125D9 */ { NULL,NULL},
/* 125DA */ { NULL,NULL},
/* 125DB */ { NULL,NULL},
/* 125DC */ { NULL,NULL},
/* 125DD */ { NULL,NULL},
/* 125DE */ { NULL,NULL},
/* 125DF */ { NULL,NULL},
/* 125E0 */ { NULL,NULL},
/* 125E1 */ { NULL,NULL},
/* 125E2 */ { NULL,NULL},
/* 125E3 */ { NULL,NULL},
/* 125E4 */ { NULL,NULL},
/* 125E5 */ { NULL,NULL},
/* 125E6 */ { NULL,NULL},
/* 125E7 */ { NULL,NULL},
/* 125E8 */ { NULL,NULL},
/* 125E9 */ { NULL,NULL},
/* 125EA */ { NULL,NULL},
/* 125EB */ { NULL,NULL},
/* 125EC */ { NULL,NULL},
/* 125ED */ { NULL,NULL},
/* 125EE */ { NULL,NULL},
/* 125EF */ { NULL,NULL},
/* 125F0 */ { NULL,NULL},
/* 125F1 */ { NULL,NULL},
/* 125F2 */ { NULL,NULL},
/* 125F3 */ { NULL,NULL},
/* 125F4 */ { NULL,NULL},
/* 125F5 */ { NULL,NULL},
/* 125F6 */ { NULL,NULL},
/* 125F7 */ { NULL,NULL},
/* 125F8 */ { NULL,NULL},
/* 125F9 */ { NULL,NULL},
/* 125FA */ { NULL,NULL},
/* 125FB */ { NULL,NULL},
/* 125FC */ { NULL,NULL},
/* 125FD */ { NULL,NULL},
/* 125FE */ { NULL,NULL},
/* 125FF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_2F[] = {
/* 12F00 */ { NULL,NULL},
/* 12F01 */ { NULL,NULL},
/* 12F02 */ { NULL,NULL},
/* 12F03 */ { NULL,NULL},
/* 12F04 */ { NULL,NULL},
/* 12F05 */ { NULL,NULL},
/* 12F06 */ { NULL,NULL},
/* 12F07 */ { NULL,NULL},
/* 12F08 */ { NULL,NULL},
/* 12F09 */ { NULL,NULL},
/* 12F0A */ { NULL,NULL},
/* 12F0B */ { NULL,NULL},
/* 12F0C */ { NULL,NULL},
/* 12F0D */ { NULL,NULL},
/* 12F0E */ { NULL,NULL},
/* 12F0F */ { NULL,NULL},
/* 12F10 */ { NULL,NULL},
/* 12F11 */ { NULL,NULL},
/* 12F12 */ { NULL,NULL},
/* 12F13 */ { NULL,NULL},
/* 12F14 */ { NULL,NULL},
/* 12F15 */ { NULL,NULL},
/* 12F16 */ { NULL,NULL},
/* 12F17 */ { NULL,NULL},
/* 12F18 */ { NULL,NULL},
/* 12F19 */ { NULL,NULL},
/* 12F1A */ { NULL,NULL},
/* 12F1B */ { NULL,NULL},
/* 12F1C */ { NULL,NULL},
/* 12F1D */ { NULL,NULL},
/* 12F1E */ { NULL,NULL},
/* 12F1F */ { NULL,NULL},
/* 12F20 */ { NULL,NULL},
/* 12F21 */ { NULL,NULL},
/* 12F22 */ { NULL,NULL},
/* 12F23 */ { NULL,NULL},
/* 12F24 */ { NULL,NULL},
/* 12F25 */ { NULL,NULL},
/* 12F26 */ { NULL,NULL},
/* 12F27 */ { NULL,NULL},
/* 12F28 */ { NULL,NULL},
/* 12F29 */ { NULL,NULL},
/* 12F2A */ { NULL,NULL},
/* 12F2B */ { NULL,NULL},
/* 12F2C */ { NULL,NULL},
/* 12F2D */ { NULL,NULL},
/* 12F2E */ { NULL,NULL},
/* 12F2F */ { NULL,NULL},
/* 12F30 */ { NULL,NULL},
/* 12F31 */ { NULL,NULL},
/* 12F32 */ { NULL,NULL},
/* 12F33 */ { NULL,NULL},
/* 12F34 */ { NULL,NULL},
/* 12F35 */ { NULL,NULL},
/* 12F36 */ { NULL,NULL},
/* 12F37 */ { NULL,NULL},
/* 12F38 */ { NULL,NULL},
/* 12F39 */ { NULL,NULL},
/* 12F3A */ { NULL,NULL},
/* 12F3B */ { NULL,NULL},
/* 12F3C */ { NULL,NULL},
/* 12F3D */ { NULL,NULL},
/* 12F3E */ { NULL,NULL},
/* 12F3F */ { NULL,NULL},
/* 12F40 */ { NULL,NULL},
/* 12F41 */ { NULL,NULL},
/* 12F42 */ { NULL,NULL},
/* 12F43 */ { NULL,NULL},
/* 12F44 */ { NULL,NULL},
/* 12F45 */ { NULL,NULL},
/* 12F46 */ { NULL,NULL},
/* 12F47 */ { NULL,NULL},
/* 12F48 */ { NULL,NULL},
/* 12F49 */ { NULL,NULL},
/* 12F4A */ { NULL,NULL},
/* 12F4B */ { NULL,NULL},
/* 12F4C */ { NULL,NULL},
/* 12F4D */ { NULL,NULL},
/* 12F4E */ { NULL,NULL},
/* 12F4F */ { NULL,NULL},
/* 12F50 */ { NULL,NULL},
/* 12F51 */ { NULL,NULL},
/* 12F52 */ { NULL,NULL},
/* 12F53 */ { NULL,NULL},
/* 12F54 */ { NULL,NULL},
/* 12F55 */ { NULL,NULL},
/* 12F56 */ { NULL,NULL},
/* 12F57 */ { NULL,NULL},
/* 12F58 */ { NULL,NULL},
/* 12F59 */ { NULL,NULL},
/* 12F5A */ { NULL,NULL},
/* 12F5B */ { NULL,NULL},
/* 12F5C */ { NULL,NULL},
/* 12F5D */ { NULL,NULL},
/* 12F5E */ { NULL,NULL},
/* 12F5F */ { NULL,NULL},
/* 12F60 */ { NULL,NULL},
/* 12F61 */ { NULL,NULL},
/* 12F62 */ { NULL,NULL},
/* 12F63 */ { NULL,NULL},
/* 12F64 */ { NULL,NULL},
/* 12F65 */ { NULL,NULL},
/* 12F66 */ { NULL,NULL},
/* 12F67 */ { NULL,NULL},
/* 12F68 */ { NULL,NULL},
/* 12F69 */ { NULL,NULL},
/* 12F6A */ { NULL,NULL},
/* 12F6B */ { NULL,NULL},
/* 12F6C */ { NULL,NULL},
/* 12F6D */ { NULL,NULL},
/* 12F6E */ { NULL,NULL},
/* 12F6F */ { NULL,NULL},
/* 12F70 */ { NULL,NULL},
/* 12F71 */ { NULL,NULL},
/* 12F72 */ { NULL,NULL},
/* 12F73 */ { NULL,NULL},
/* 12F74 */ { NULL,NULL},
/* 12F75 */ { NULL,NULL},
/* 12F76 */ { NULL,NULL},
/* 12F77 */ { NULL,NULL},
/* 12F78 */ { NULL,NULL},
/* 12F79 */ { NULL,NULL},
/* 12F7A */ { NULL,NULL},
/* 12F7B */ { NULL,NULL},
/* 12F7C */ { NULL,NULL},
/* 12F7D */ { NULL,NULL},
/* 12F7E */ { NULL,NULL},
/* 12F7F */ { NULL,NULL},
/* 12F80 */ { NULL,NULL},
/* 12F81 */ { NULL,NULL},
/* 12F82 */ { NULL,NULL},
/* 12F83 */ { NULL,NULL},
/* 12F84 */ { NULL,NULL},
/* 12F85 */ { NULL,NULL},
/* 12F86 */ { NULL,NULL},
/* 12F87 */ { NULL,NULL},
/* 12F88 */ { NULL,NULL},
/* 12F89 */ { NULL,NULL},
/* 12F8A */ { NULL,NULL},
/* 12F8B */ { NULL,NULL},
/* 12F8C */ { NULL,NULL},
/* 12F8D */ { NULL,NULL},
/* 12F8E */ { NULL,NULL},
/* 12F8F */ { NULL,NULL},
/* 12F90 */ { "CYPRO-MINOAN SIGN CM001",NULL},
/* 12F91 */ { "CYPRO-MINOAN SIGN CM002",NULL},
/* 12F92 */ { "CYPRO-MINOAN SIGN CM004",NULL},
/* 12F93 */ { "CYPRO-MINOAN SIGN CM005",NULL},
/* 12F94 */ { "CYPRO-MINOAN SIGN CM006",NULL},
/* 12F95 */ { "CYPRO-MINOAN SIGN CM007",NULL},
/* 12F96 */ { "CYPRO-MINOAN SIGN CM008",NULL},
/* 12F97 */ { "CYPRO-MINOAN SIGN CM009",NULL},
/* 12F98 */ { "CYPRO-MINOAN SIGN CM010",NULL},
/* 12F99 */ { "CYPRO-MINOAN SIGN CM011",NULL},
/* 12F9A */ { "CYPRO-MINOAN SIGN CM012",NULL},
/* 12F9B */ { "CYPRO-MINOAN SIGN CM012B",NULL},
/* 12F9C */ { "CYPRO-MINOAN SIGN CM013",NULL},
/* 12F9D */ { "CYPRO-MINOAN SIGN CM015",NULL},
/* 12F9E */ { "CYPRO-MINOAN SIGN CM017",NULL},
/* 12F9F */ { "CYPRO-MINOAN SIGN CM019",NULL},
/* 12FA0 */ { "CYPRO-MINOAN SIGN CM021",NULL},
/* 12FA1 */ { "CYPRO-MINOAN SIGN CM023",NULL},
/* 12FA2 */ { "CYPRO-MINOAN SIGN CM024",NULL},
/* 12FA3 */ { "CYPRO-MINOAN SIGN CM025",NULL},
/* 12FA4 */ { "CYPRO-MINOAN SIGN CM026",NULL},
/* 12FA5 */ { "CYPRO-MINOAN SIGN CM027",NULL},
/* 12FA6 */ { "CYPRO-MINOAN SIGN CM028",NULL},
/* 12FA7 */ { "CYPRO-MINOAN SIGN CM029",NULL},
/* 12FA8 */ { "CYPRO-MINOAN SIGN CM030",NULL},
/* 12FA9 */ { "CYPRO-MINOAN SIGN CM033",NULL},
/* 12FAA */ { "CYPRO-MINOAN SIGN CM034",NULL},
/* 12FAB */ { "CYPRO-MINOAN SIGN CM035",NULL},
/* 12FAC */ { "CYPRO-MINOAN SIGN CM036",NULL},
/* 12FAD */ { "CYPRO-MINOAN SIGN CM037",NULL},
/* 12FAE */ { "CYPRO-MINOAN SIGN CM038",NULL},
/* 12FAF */ { "CYPRO-MINOAN SIGN CM039",NULL},
/* 12FB0 */ { "CYPRO-MINOAN SIGN CM040",NULL},
/* 12FB1 */ { "CYPRO-MINOAN SIGN CM041",NULL},
/* 12FB2 */ { "CYPRO-MINOAN SIGN CM044",NULL},
/* 12FB3 */ { "CYPRO-MINOAN SIGN CM046",NULL},
/* 12FB4 */ { "CYPRO-MINOAN SIGN CM047",NULL},
/* 12FB5 */ { "CYPRO-MINOAN SIGN CM049",NULL},
/* 12FB6 */ { "CYPRO-MINOAN SIGN CM050",NULL},
/* 12FB7 */ { "CYPRO-MINOAN SIGN CM051",NULL},
/* 12FB8 */ { "CYPRO-MINOAN SIGN CM052",NULL},
/* 12FB9 */ { "CYPRO-MINOAN SIGN CM053",NULL},
/* 12FBA */ { "CYPRO-MINOAN SIGN CM054",NULL},
/* 12FBB */ { "CYPRO-MINOAN SIGN CM055",NULL},
/* 12FBC */ { "CYPRO-MINOAN SIGN CM056",NULL},
/* 12FBD */ { "CYPRO-MINOAN SIGN CM058",NULL},
/* 12FBE */ { "CYPRO-MINOAN SIGN CM059",NULL},
/* 12FBF */ { "CYPRO-MINOAN SIGN CM060",NULL},
/* 12FC0 */ { "CYPRO-MINOAN SIGN CM061",NULL},
/* 12FC1 */ { "CYPRO-MINOAN SIGN CM062",NULL},
/* 12FC2 */ { "CYPRO-MINOAN SIGN CM063",NULL},
/* 12FC3 */ { "CYPRO-MINOAN SIGN CM064",NULL},
/* 12FC4 */ { "CYPRO-MINOAN SIGN CM066",NULL},
/* 12FC5 */ { "CYPRO-MINOAN SIGN CM067",NULL},
/* 12FC6 */ { "CYPRO-MINOAN SIGN CM068",NULL},
/* 12FC7 */ { "CYPRO-MINOAN SIGN CM069",NULL},
/* 12FC8 */ { "CYPRO-MINOAN SIGN CM070",NULL},
/* 12FC9 */ { "CYPRO-MINOAN SIGN CM071",NULL},
/* 12FCA */ { "CYPRO-MINOAN SIGN CM072",NULL},
/* 12FCB */ { "CYPRO-MINOAN SIGN CM073",NULL},
/* 12FCC */ { "CYPRO-MINOAN SIGN CM074",NULL},
/* 12FCD */ { "CYPRO-MINOAN SIGN CM075",NULL},
/* 12FCE */ { "CYPRO-MINOAN SIGN CM075B",NULL},
/* 12FCF */ { "CYPRO-MINOAN SIGN CM076",NULL},
/* 12FD0 */ { "CYPRO-MINOAN SIGN CM078",NULL},
/* 12FD1 */ { "CYPRO-MINOAN SIGN CM079",NULL},
/* 12FD2 */ { "CYPRO-MINOAN SIGN CM080",NULL},
/* 12FD3 */ { "CYPRO-MINOAN SIGN CM081",NULL},
/* 12FD4 */ { "CYPRO-MINOAN SIGN CM082",NULL},
/* 12FD5 */ { "CYPRO-MINOAN SIGN CM083",NULL},
/* 12FD6 */ { "CYPRO-MINOAN SIGN CM084",NULL},
/* 12FD7 */ { "CYPRO-MINOAN SIGN CM085",NULL},
/* 12FD8 */ { "CYPRO-MINOAN SIGN CM086",NULL},
/* 12FD9 */ { "CYPRO-MINOAN SIGN CM087",NULL},
/* 12FDA */ { "CYPRO-MINOAN SIGN CM088",NULL},
/* 12FDB */ { "CYPRO-MINOAN SIGN CM089",NULL},
/* 12FDC */ { "CYPRO-MINOAN SIGN CM090",NULL},
/* 12FDD */ { "CYPRO-MINOAN SIGN CM091",NULL},
/* 12FDE */ { "CYPRO-MINOAN SIGN CM092",NULL},
/* 12FDF */ { "CYPRO-MINOAN SIGN CM094",NULL},
/* 12FE0 */ { "CYPRO-MINOAN SIGN CM095",NULL},
/* 12FE1 */ { "CYPRO-MINOAN SIGN CM096",NULL},
/* 12FE2 */ { "CYPRO-MINOAN SIGN CM097",NULL},
/* 12FE3 */ { "CYPRO-MINOAN SIGN CM098",NULL},
/* 12FE4 */ { "CYPRO-MINOAN SIGN CM099",NULL},
/* 12FE5 */ { "CYPRO-MINOAN SIGN CM100",NULL},
/* 12FE6 */ { "CYPRO-MINOAN SIGN CM101",NULL},
/* 12FE7 */ { "CYPRO-MINOAN SIGN CM102",NULL},
/* 12FE8 */ { "CYPRO-MINOAN SIGN CM103",NULL},
/* 12FE9 */ { "CYPRO-MINOAN SIGN CM104",NULL},
/* 12FEA */ { "CYPRO-MINOAN SIGN CM105",NULL},
/* 12FEB */ { "CYPRO-MINOAN SIGN CM107",NULL},
/* 12FEC */ { "CYPRO-MINOAN SIGN CM108",NULL},
/* 12FED */ { "CYPRO-MINOAN SIGN CM109",NULL},
/* 12FEE */ { "CYPRO-MINOAN SIGN CM110",NULL},
/* 12FEF */ { "CYPRO-MINOAN SIGN CM112",NULL},
/* 12FF0 */ { "CYPRO-MINOAN SIGN CM114",NULL},
/* 12FF1 */ { "CYPRO-MINOAN SIGN CM301",NULL},
/* 12FF2 */ { "CYPRO-MINOAN SIGN CM302",NULL},
/* 12FF3 */ { NULL,NULL},
/* 12FF4 */ { NULL,NULL},
/* 12FF5 */ { NULL,NULL},
/* 12FF6 */ { NULL,NULL},
/* 12FF7 */ { NULL,NULL},
/* 12FF8 */ { NULL,NULL},
/* 12FF9 */ { NULL,NULL},
/* 12FFA */ { NULL,NULL},
/* 12FFB */ { NULL,NULL},
/* 12FFC */ { NULL,NULL},
/* 12FFD */ { NULL,NULL},
/* 12FFE */ { NULL,NULL},
/* 12FFF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_30[] = {
/* 13000 */ { "EGYPTIAN HIEROGLYPH A001","	* classifier human being"},
/* 13001 */ { "EGYPTIAN HIEROGLYPH A002","	* classifier eating/drinking/speech/ silence/thoughts/feelings"},
/* 13002 */ { "EGYPTIAN HIEROGLYPH A003","	* classifier sitting : ḥmsꞽ"},
/* 13003 */ { "EGYPTIAN HIEROGLYPH A004","	* classifier supplication/hiding/rejection"},
/* 13004 */ { "EGYPTIAN HIEROGLYPH A005",NULL},
/* 13005 */ { "EGYPTIAN HIEROGLYPH A005A","	* logogram (to hide) : ꞽmn"},
/* 13006 */ { "EGYPTIAN HIEROGLYPH A006","	* logogram (pure, clean) : wꜥb"},
/* 13007 */ { "EGYPTIAN HIEROGLYPH A006A","	* classifier to libate : sṯ"},
/* 13008 */ { "EGYPTIAN HIEROGLYPH A006B",NULL},
/* 13009 */ { "EGYPTIAN HIEROGLYPH A007","	* classifier sitting/weak/faint"},
/* 1300A */ { "EGYPTIAN HIEROGLYPH A008","	* classifier joy/veneration"},
/* 1300B */ { "EGYPTIAN HIEROGLYPH A009","	* classifier to lift, to carry : fꜣꞽ"},
/* 1300C */ { "EGYPTIAN HIEROGLYPH A010","	* classifier sailing/rowing : sḳdꞽ"},
/* 1300D */ { "EGYPTIAN HIEROGLYPH A011","	* phonemogram : ḫnms"},
/* 1300E */ { "EGYPTIAN HIEROGLYPH A012","	* logogram (army) : mšꜥ"},
/* 1300F */ { "EGYPTIAN HIEROGLYPH A013","	* classifier rebel/enemy "},
/* 13010 */ { "EGYPTIAN HIEROGLYPH A014","	* classifier rebel, opponent : rḳ"},
/* 13011 */ { "EGYPTIAN HIEROGLYPH A014A","	* classifier death : mt"},
/* 13012 */ { "EGYPTIAN HIEROGLYPH A015","	* logogram (to fall) : ḫr\n"
	"	~ 13012 FE03 rotated approximately 30 degrees"},
/* 13013 */ { "EGYPTIAN HIEROGLYPH A016","	* classifier bowing"},
/* 13014 */ { "EGYPTIAN HIEROGLYPH A017","	* classifier youth/child"},
/* 13015 */ { "EGYPTIAN HIEROGLYPH A017A","	* classifier youth/child"},
/* 13016 */ { "EGYPTIAN HIEROGLYPH A018","	* classifier child (royal)"},
/* 13017 */ { "EGYPTIAN HIEROGLYPH A019","	* logogram (old, old age) : ꞽꜣw"},
/* 13018 */ { "EGYPTIAN HIEROGLYPH A020","	* logogram (elder) : smsw"},
/* 13019 */ { "EGYPTIAN HIEROGLYPH A021",NULL},
/* 1301A */ { "EGYPTIAN HIEROGLYPH A022","	* classifier statue"},
/* 1301B */ { "EGYPTIAN HIEROGLYPH A023","	* classifier sovereign : ꞽt.y"},
/* 1301C */ { "EGYPTIAN HIEROGLYPH A024","	* classifier force/effort"},
/* 1301D */ { "EGYPTIAN HIEROGLYPH A025","	* classifier force/effort"},
/* 1301E */ { "EGYPTIAN HIEROGLYPH A026","	* logogram (vocative interjection) : ꞽ"},
/* 1301F */ { "EGYPTIAN HIEROGLYPH A027","	* phonemogram/classifier messenger : ꞽn"},
/* 13020 */ { "EGYPTIAN HIEROGLYPH A028","	* logogram (to be high) : ḳꜣꞽ"},
/* 13021 */ { "EGYPTIAN HIEROGLYPH A029","	* classifier upside-down : sḫd"},
/* 13022 */ { "EGYPTIAN HIEROGLYPH A030","	* classifier adoration"},
/* 13023 */ { "EGYPTIAN HIEROGLYPH A031","	* classifier turning away"},
/* 13024 */ { "EGYPTIAN HIEROGLYPH A032","	* classifier dancing : ḫbꞽ"},
/* 13025 */ { "EGYPTIAN HIEROGLYPH A032A",NULL},
/* 13026 */ { "EGYPTIAN HIEROGLYPH A033","	* classifier wandering/displaced : rw"},
/* 13027 */ { "EGYPTIAN HIEROGLYPH A034","	* logogram (to pound, to build) : ḫwsꞽ"},
/* 13028 */ { "EGYPTIAN HIEROGLYPH A035","	* logogram (to build) : ḳd"},
/* 13029 */ { "EGYPTIAN HIEROGLYPH A036","	* logogram (brewer) : ꜥf.ty"},
/* 1302A */ { "EGYPTIAN HIEROGLYPH A037","	* logogram (brewer) : ꜥf.ty"},
/* 1302B */ { "EGYPTIAN HIEROGLYPH A038","	* logogram (Cusae) : ḳꞽs"},
/* 1302C */ { "EGYPTIAN HIEROGLYPH A039","	* logogram (Cusae) : ḳꞽs"},
/* 1302D */ { "EGYPTIAN HIEROGLYPH A040","	* classifier divinity"},
/* 1302E */ { "EGYPTIAN HIEROGLYPH A040A","	* classifier divinity"},
/* 1302F */ { "EGYPTIAN HIEROGLYPH A041","	* logogram (first person singular) : ꞽ"},
/* 13030 */ { "EGYPTIAN HIEROGLYPH A042","	* classifier king : n(y)-sw.t"},
/* 13031 */ { "EGYPTIAN HIEROGLYPH A042A","	* logogram (first person singular) : ꞽ"},
/* 13032 */ { "EGYPTIAN HIEROGLYPH A043","	* classifier king"},
/* 13033 */ { "EGYPTIAN HIEROGLYPH A043A","	* logogram (king of Upper Egypt) : n.y-sw.t"},
/* 13034 */ { "EGYPTIAN HIEROGLYPH A044","	* classifier king : n.y-sw.t"},
/* 13035 */ { "EGYPTIAN HIEROGLYPH A045","	* classifier king : bꞽ.ty"},
/* 13036 */ { "EGYPTIAN HIEROGLYPH A045A","	* classifier king : n.y-sw.t"},
/* 13037 */ { "EGYPTIAN HIEROGLYPH A046","	* classifier king : bꞽ.tyw"},
/* 13038 */ { "EGYPTIAN HIEROGLYPH A047","	* logogram (to guard) : sꜣw"},
/* 13039 */ { "EGYPTIAN HIEROGLYPH A048","	* logogram (relating to, belonging to) : ꞽr.y"},
/* 1303A */ { "EGYPTIAN HIEROGLYPH A049","	* classifier foreigner"},
/* 1303B */ { "EGYPTIAN HIEROGLYPH A050","	* logogram (to be noble) : špsꞽ"},
/* 1303C */ { "EGYPTIAN HIEROGLYPH A051","	* logogram (to be noble) : šps"},
/* 1303D */ { "EGYPTIAN HIEROGLYPH A052","	* classifier name (deceased person)"},
/* 1303E */ { "EGYPTIAN HIEROGLYPH A053","	* classifier image/statue/likeness"},
/* 1303F */ { "EGYPTIAN HIEROGLYPH A054","	* classifier body/corpse/death"},
/* 13040 */ { "EGYPTIAN HIEROGLYPH A055","	* logogram (to sleep/to spend the night) : sḏr"},
/* 13041 */ { "EGYPTIAN HIEROGLYPH A056","	* classifier enemy : ḫft.y"},
/* 13042 */ { "EGYPTIAN HIEROGLYPH A057","	* logogram (an offering that the king gives) : ḥtp-dꞽ-n.y-sw.t"},
/* 13043 */ { "EGYPTIAN HIEROGLYPH A058","	* classifier hacking : ḫbs"},
/* 13044 */ { "EGYPTIAN HIEROGLYPH A059","	* classifier driving away : sḥrꞽ"},
/* 13045 */ { "EGYPTIAN HIEROGLYPH A060","	* logogram (to sprinkle, to scatter) : stꞽ"},
/* 13046 */ { "EGYPTIAN HIEROGLYPH A061","	* logogram (to turn back) : ꜥnn"},
/* 13047 */ { "EGYPTIAN HIEROGLYPH A062","	* logogram (great one, chief) : wr"},
/* 13048 */ { "EGYPTIAN HIEROGLYPH A063",NULL},
/* 13049 */ { "EGYPTIAN HIEROGLYPH A064","	* classifier to lift, to carry : fꜣꞽ"},
/* 1304A */ { "EGYPTIAN HIEROGLYPH A065","	* logogram (the one who belongs to the god) : ꞽr.y-nṯr"},
/* 1304B */ { "EGYPTIAN HIEROGLYPH A066","	* logogram (the musician/Ihy) : ꞽḥy"},
/* 1304C */ { "EGYPTIAN HIEROGLYPH A067","	* classifier personal name"},
/* 1304D */ { "EGYPTIAN HIEROGLYPH A068","	* logogram (messenger) : wpw.ty"},
/* 1304E */ { "EGYPTIAN HIEROGLYPH A069","	* classifier occupation/relationship"},
/* 1304F */ { "EGYPTIAN HIEROGLYPH A070","	* logogram (million, many) : ḥḥ"},
/* 13050 */ { "EGYPTIAN HIEROGLYPH B001","	* classifier female"},
/* 13051 */ { "EGYPTIAN HIEROGLYPH B002","	* classifier pregnant : ꞽwr"},
/* 13052 */ { "EGYPTIAN HIEROGLYPH B003","	* classifier birth : msꞽ"},
/* 13053 */ { "EGYPTIAN HIEROGLYPH B004","	* classifier birth : msꞽ"},
/* 13054 */ { "EGYPTIAN HIEROGLYPH B005","	* classifier nursing, rearing : rnn"},
/* 13055 */ { "EGYPTIAN HIEROGLYPH B005A","	* logogram weaver or nurse : ? | mnḫ.t"},
/* 13056 */ { "EGYPTIAN HIEROGLYPH B006","	* classifier nursing, rearing : rnn"},
/* 13057 */ { "EGYPTIAN HIEROGLYPH B007","	* classifier female royalty"},
/* 13058 */ { "EGYPTIAN HIEROGLYPH B008","	* classifier human being (together with A1) : ḥr.w-nb"},
/* 13059 */ { "EGYPTIAN HIEROGLYPH B009","	* logogram (the musician) : ꞽḥ.yt"},
/* 1305A */ { "EGYPTIAN HIEROGLYPH C001","	* logogram (Re) : rꜥ"},
/* 1305B */ { "EGYPTIAN HIEROGLYPH C002","	* logogram (Re) : rꜥ"},
/* 1305C */ { "EGYPTIAN HIEROGLYPH C002A","	* logogram (Re) : rꜥ"},
/* 1305D */ { "EGYPTIAN HIEROGLYPH C002B","	* mirrored version of 1305C"},
/* 1305E */ { "EGYPTIAN HIEROGLYPH C002C","	* mirrored version of 1305B"},
/* 1305F */ { "EGYPTIAN HIEROGLYPH C003","	* logogram (Thot) : ḏhwty"},
/* 13060 */ { "EGYPTIAN HIEROGLYPH C004","	* classifier Khnum : ẖnm.w"},
/* 13061 */ { "EGYPTIAN HIEROGLYPH C005","	* logogram/phonemogram (who joins with life) : ẖnm.t-ꜥnḫ"},
/* 13062 */ { "EGYPTIAN HIEROGLYPH C006","	* classifier Anubis/Wepwawet (divinity)"},
/* 13063 */ { "EGYPTIAN HIEROGLYPH C007","	* logogram (Seth) : stš/stẖ"},
/* 13064 */ { "EGYPTIAN HIEROGLYPH C008","	* classifier Min : gb.tyw"},
/* 13065 */ { "EGYPTIAN HIEROGLYPH C009","	* logogram (Hathor) : ḥw.t-ḥr"},
/* 13066 */ { "EGYPTIAN HIEROGLYPH C010","	* logogram (Maat) : mꜣꜥ.t"},
/* 13067 */ { "EGYPTIAN HIEROGLYPH C010A","	* logogram (Maat) : mꜣꜥ.t"},
/* 13068 */ { "EGYPTIAN HIEROGLYPH C011","	* logogram (million, many) : ḥḥ"},
/* 13069 */ { "EGYPTIAN HIEROGLYPH C012","	* logogram (Amon) : ꞽmn"},
/* 1306A */ { "EGYPTIAN HIEROGLYPH C013","	* mirrored version of 13069"},
/* 1306B */ { "EGYPTIAN HIEROGLYPH C014","	* logogram (Amon is his strength (sꜣ-rꜥ name Ramses VI)) : ꞽmn-ḥr-ḫpš=f"},
/* 1306C */ { "EGYPTIAN HIEROGLYPH C015","	* mirrored version of 1306B"},
/* 1306D */ { "EGYPTIAN HIEROGLYPH C016","	* logogram (Atum) : ꞽtmw"},
/* 1306E */ { "EGYPTIAN HIEROGLYPH C017","	* classifier Montu (divinity)"},
/* 1306F */ { "EGYPTIAN HIEROGLYPH C018","	* classifier Tatenen : tꜣ-ṯnn"},
/* 13070 */ { "EGYPTIAN HIEROGLYPH C019","	* classifier Ptah : ptḥ"},
/* 13071 */ { "EGYPTIAN HIEROGLYPH C020","	* logogram (Ptah) : ptḥ"},
/* 13072 */ { "EGYPTIAN HIEROGLYPH C021","	* phonemogram : bs"},
/* 13073 */ { "EGYPTIAN HIEROGLYPH C022","	* classifier moon : ꞽꜥḥ"},
/* 13074 */ { "EGYPTIAN HIEROGLYPH C023","	* logogram (Sekhmet) : sḫm.t"},
/* 13075 */ { "EGYPTIAN HIEROGLYPH C024","	* logogram (Neith) : n.t"},
/* 13076 */ { "EGYPTIAN HIEROGLYPH D001","	* logogram (head) : tp"},
/* 13077 */ { "EGYPTIAN HIEROGLYPH D002","	* phonemogram : ḥr"},
/* 13078 */ { "EGYPTIAN HIEROGLYPH D003","	* classifier hair"},
/* 13079 */ { "EGYPTIAN HIEROGLYPH D004","	* phonemogram : ꞽr"},
/* 1307A */ { "EGYPTIAN HIEROGLYPH D005","	* classifier eye related actions : dgꞽ"},
/* 1307B */ { "EGYPTIAN HIEROGLYPH D006","	* classifier eye related actions : dgꞽ"},
/* 1307C */ { "EGYPTIAN HIEROGLYPH D007","	* phonemogram : ꜥntyw"},
/* 1307D */ { "EGYPTIAN HIEROGLYPH D008","	* phonemogram : ꜥn"},
/* 1307E */ { "EGYPTIAN HIEROGLYPH D008A","	* phonemogram : ꜥn"},
/* 1307F */ { "EGYPTIAN HIEROGLYPH D009","	* logogram (to weep) : rmꞽ"},
/* 13080 */ { "EGYPTIAN HIEROGLYPH D010","	* logogram (udjat eye) : wḏꜣ.t"},
/* 13081 */ { "EGYPTIAN HIEROGLYPH D011","	* logogram 1/2"},
/* 13082 */ { "EGYPTIAN HIEROGLYPH D012","	* not to be confused with 131F3 or 133F8\n"
	"	* 1/4\n"
	"	* classifier pupil : ḏfḏ"},
/* 13083 */ { "EGYPTIAN HIEROGLYPH D013","	* 1/8\n"
	"	* classifier eyebrow : ꞽnḥ"},
/* 13084 */ { "EGYPTIAN HIEROGLYPH D014","	* logogram 1/16"},
/* 13085 */ { "EGYPTIAN HIEROGLYPH D015","	* logogram 1/32"},
/* 13086 */ { "EGYPTIAN HIEROGLYPH D016","	* logogram 1/64"},
/* 13087 */ { "EGYPTIAN HIEROGLYPH D017","	* logogram (figure, image) : tꞽ.t"},
/* 13088 */ { "EGYPTIAN HIEROGLYPH D018","	* logogram (ear) : msḏr"},
/* 13089 */ { "EGYPTIAN HIEROGLYPH D019","	* classifier nose : šr.t"},
/* 1308A */ { "EGYPTIAN HIEROGLYPH D020","	* classifier nose : fnḏ"},
/* 1308B */ { "EGYPTIAN HIEROGLYPH D021","	* mouth\n"
	"	* not to be confused with 133AB\n"
	"	* phonemogram : r"},
/* 1308C */ { "EGYPTIAN HIEROGLYPH D022","	* logogram (2/3) : r.wy"},
/* 1308D */ { "EGYPTIAN HIEROGLYPH D023","	* logogram (3/4) : ḫmt-r.w"},
/* 1308E */ { "EGYPTIAN HIEROGLYPH D024","	* classifier lip, border, edge : sp.t"},
/* 1308F */ { "EGYPTIAN HIEROGLYPH D025","	* logogram (lips) : sp.ty"},
/* 13090 */ { "EGYPTIAN HIEROGLYPH D026","	* classifier blood : snf"},
/* 13091 */ { "EGYPTIAN HIEROGLYPH D027","	* classifier breast : mnḏ\n"
	"	~ 13091 FE00 rotated 90 degrees"},
/* 13092 */ { "EGYPTIAN HIEROGLYPH D027A","	* variant of 13091"},
/* 13093 */ { "EGYPTIAN HIEROGLYPH D028","	* logogram (spirit, essence) : kꜣ\n"
	"	~ 13093 FE01 rotated 180 degrees"},
/* 13094 */ { "EGYPTIAN HIEROGLYPH D029","	* logogram (spirit, essence) : kꜣ"},
/* 13095 */ { "EGYPTIAN HIEROGLYPH D030","	* classifier Nehebkau : nḥb-kꜣ.w"},
/* 13096 */ { "EGYPTIAN HIEROGLYPH D031","	* logogram (mortuary priest) : ḥm-kꜣ"},
/* 13097 */ { "EGYPTIAN HIEROGLYPH D031A","	* logogram (mortuary priest) : ḥm-kꜣ"},
/* 13098 */ { "EGYPTIAN HIEROGLYPH D032","	* classifier enveloping, embracing, uniting"},
/* 13099 */ { "EGYPTIAN HIEROGLYPH D033","	* phonemogram : ẖn"},
/* 1309A */ { "EGYPTIAN HIEROGLYPH D034","	* logogram (to fight) : ꜥḥꜣ"},
/* 1309B */ { "EGYPTIAN HIEROGLYPH D034A","	* logogram (to fight) : ꜥḥꜣ"},
/* 1309C */ { "EGYPTIAN HIEROGLYPH D035","	* logogram (negative particle) : n"},
/* 1309D */ { "EGYPTIAN HIEROGLYPH D036","	* transliterated as A725\n"
	"	x (hebrew letter ayin - 05E2)\n"
	"	x (arabic letter ain - 0639)\n"
	"	* phonemogram : ꜥ"},
/* 1309E */ { "EGYPTIAN HIEROGLYPH D037","	* phonemogram : ḏꞽ > dꞽ"},
/* 1309F */ { "EGYPTIAN HIEROGLYPH D038","	* phonemogram : m"},
/* 130A0 */ { "EGYPTIAN HIEROGLYPH D039","	* logogram (to offer, to present) : ḥnk"},
/* 130A1 */ { "EGYPTIAN HIEROGLYPH D040","	* classifier force, effort"},
/* 130A2 */ { "EGYPTIAN HIEROGLYPH D041","	* classifier arm related movements or actions"},
/* 130A3 */ { "EGYPTIAN HIEROGLYPH D042","	* logogram (cubit) : mḥ"},
/* 130A4 */ { "EGYPTIAN HIEROGLYPH D043","	* logogram (to protect) : ḫwꞽ"},
/* 130A5 */ { "EGYPTIAN HIEROGLYPH D044","	* classifier governing/controlling : ḫrp"},
/* 130A6 */ { "EGYPTIAN HIEROGLYPH D045","	* logogram (to make holy) : ḏsr"},
/* 130A7 */ { "EGYPTIAN HIEROGLYPH D046","	* phonemogram : d"},
/* 130A8 */ { "EGYPTIAN HIEROGLYPH D046A","	* logogram (scent, perfume, dew) : ꞽd.t"},
/* 130A9 */ { "EGYPTIAN HIEROGLYPH D047","	* classifier hand : ḏr.t"},
/* 130AA */ { "EGYPTIAN HIEROGLYPH D048","	* logogram (palm) : šsp"},
/* 130AB */ { "EGYPTIAN HIEROGLYPH D048A","	* phono-repeater : ḥnt"},
/* 130AC */ { "EGYPTIAN HIEROGLYPH D049","	* classifier grasping/holding : ꜣmm"},
/* 130AD */ { "EGYPTIAN HIEROGLYPH D050","	* not to be confused with 130B7\n"
	"	* 10000\n"
	"	* logogram (finger) : ḏbꜥ"},
/* 130AE */ { "EGYPTIAN HIEROGLYPH D050A","	* \\20000"},
/* 130AF */ { "EGYPTIAN HIEROGLYPH D050B","	* \\30000"},
/* 130B0 */ { "EGYPTIAN HIEROGLYPH D050C","	* \\40000"},
/* 130B1 */ { "EGYPTIAN HIEROGLYPH D050D","	* \\50000"},
/* 130B2 */ { "EGYPTIAN HIEROGLYPH D050E","	* \\60000"},
/* 130B3 */ { "EGYPTIAN HIEROGLYPH D050F","	* \\70000"},
/* 130B4 */ { "EGYPTIAN HIEROGLYPH D050G","	* \\80000"},
/* 130B5 */ { "EGYPTIAN HIEROGLYPH D050H","	* \\90000"},
/* 130B6 */ { "EGYPTIAN HIEROGLYPH D050I","	* \\50000"},
/* 130B7 */ { "EGYPTIAN HIEROGLYPH D051","	* not to be confused with 130AD\n"
	"	* classifier taking : ṯꜣꞽ"},
/* 130B8 */ { "EGYPTIAN HIEROGLYPH D052","	* phonemogram : bꜣḥ\n"
	"	~ 130B8 FE03 rotated approximately 25 degrees"},
/* 130B9 */ { "EGYPTIAN HIEROGLYPH D052A","	* phonemogram : sšm"},
/* 130BA */ { "EGYPTIAN HIEROGLYPH D053","	* phonemogram : bꜣḥ\n"
	"	~ 130BA FE03 rotated approximately 25 degrees"},
/* 130BB */ { "EGYPTIAN HIEROGLYPH D054","	* classifier movement"},
/* 130BC */ { "EGYPTIAN HIEROGLYPH D054A","	* logogram (to come) : ꞽwꞽ"},
/* 130BD */ { "EGYPTIAN HIEROGLYPH D055","	* classifier reverse movement"},
/* 130BE */ { "EGYPTIAN HIEROGLYPH D056","	* classifier leg/foot : rd"},
/* 130BF */ { "EGYPTIAN HIEROGLYPH D057","	* classifier damage, injury : nkn"},
/* 130C0 */ { "EGYPTIAN HIEROGLYPH D058","	* phonemogram : b"},
/* 130C1 */ { "EGYPTIAN HIEROGLYPH D059","	* phonemogram : ꜥb"},
/* 130C2 */ { "EGYPTIAN HIEROGLYPH D060","	* logogram (to be pure, to be clean) : wꜥb"},
/* 130C3 */ { "EGYPTIAN HIEROGLYPH D061","	* phono-repeater : sꜣḥ"},
/* 130C4 */ { "EGYPTIAN HIEROGLYPH D062","	* phonemogram : sꜣḥ"},
/* 130C5 */ { "EGYPTIAN HIEROGLYPH D063","	* phonemogram : sꜣḥ"},
/* 130C6 */ { "EGYPTIAN HIEROGLYPH D064","	* logogram (hand) : ḏr.t"},
/* 130C7 */ { "EGYPTIAN HIEROGLYPH D065","	* logogram (child, son, lad) : šrꞽ"},
/* 130C8 */ { "EGYPTIAN HIEROGLYPH D066","	* classifier to engrave : wdꞽ"},
/* 130C9 */ { "EGYPTIAN HIEROGLYPH D067","	* 1 heqat measure\n"
	"	* not to be confused with 13212"},
/* 130CA */ { "EGYPTIAN HIEROGLYPH D067A","	* 2 heqat measures"},
/* 130CB */ { "EGYPTIAN HIEROGLYPH D067B","	* 3 heqat measures"},
/* 130CC */ { "EGYPTIAN HIEROGLYPH D067C","	* 4 heqat measures"},
/* 130CD */ { "EGYPTIAN HIEROGLYPH D067D","	* 5 heqat measures"},
/* 130CE */ { "EGYPTIAN HIEROGLYPH D067E","	* 6 heqat measures"},
/* 130CF */ { "EGYPTIAN HIEROGLYPH D067F","	* 7 heqat measures"},
/* 130D0 */ { "EGYPTIAN HIEROGLYPH D067G","	* 8 heqat measures"},
/* 130D1 */ { "EGYPTIAN HIEROGLYPH D067H","	* 9 heqat measures"},
/* 130D2 */ { "EGYPTIAN HIEROGLYPH E001","	* not to be confused with 130FD\n"
	"	* logogram (bull) : kꜣ"},
/* 130D3 */ { "EGYPTIAN HIEROGLYPH E002","	* classifier rage/aggression : smꜣ"},
/* 130D4 */ { "EGYPTIAN HIEROGLYPH E003","	* classifier calf : bḥs"},
/* 130D5 */ { "EGYPTIAN HIEROGLYPH E004","	* classifier cow divinity : mḥ.yt"},
/* 130D6 */ { "EGYPTIAN HIEROGLYPH E005","	* classifier concern : ꜣms"},
/* 130D7 */ { "EGYPTIAN HIEROGLYPH E006","	* logogram (span (of horses)/horse) : ḥtr"},
/* 130D8 */ { "EGYPTIAN HIEROGLYPH E007","	* classifier donkey/ass : ꜥꜣ"},
/* 130D9 */ { "EGYPTIAN HIEROGLYPH E008","	* logogram (kid) : ꞽb"},
/* 130DA */ { "EGYPTIAN HIEROGLYPH E008A","	* phono-repeater : ꞽb"},
/* 130DB */ { "EGYPTIAN HIEROGLYPH E009","	* phonemogram : ꞽw"},
/* 130DC */ { "EGYPTIAN HIEROGLYPH E009A","	* classifier cow (cow of the sky) : ꞽh.t"},
/* 130DD */ { "EGYPTIAN HIEROGLYPH E010","	* classifier ram : bꜣ"},
/* 130DE */ { "EGYPTIAN HIEROGLYPH E011","	* phonemogram : bꜣ"},
/* 130DF */ { "EGYPTIAN HIEROGLYPH E012","	* classifier pig : ꞽpḥ"},
/* 130E0 */ { "EGYPTIAN HIEROGLYPH E013","	* phonemogram : mꞽ"},
/* 130E1 */ { "EGYPTIAN HIEROGLYPH E014","	* classifier dog/hound : ṯsm"},
/* 130E2 */ { "EGYPTIAN HIEROGLYPH E015","	* logogram (Anubis) : ꞽnp.w"},
/* 130E3 */ { "EGYPTIAN HIEROGLYPH E016","	* logogram (privy to the secrets) : ḥr.y-sštꜣ"},
/* 130E4 */ { "EGYPTIAN HIEROGLYPH E016A","	* classifier Anubis : ꞽnp.w"},
/* 130E5 */ { "EGYPTIAN HIEROGLYPH E017","	* phonemogram : sꜣb"},
/* 130E6 */ { "EGYPTIAN HIEROGLYPH E017A","	* phonemogram : sṯꜣ"},
/* 130E7 */ { "EGYPTIAN HIEROGLYPH E018","	* logogram (Wepwawet) : wp-wꜣ.wt"},
/* 130E8 */ { "EGYPTIAN HIEROGLYPH E019","	* classifier Wepwawet : wp-wꜣ.wt"},
/* 130E9 */ { "EGYPTIAN HIEROGLYPH E020","	* logogram (Seth) : stš/stẖ"},
/* 130EA */ { "EGYPTIAN HIEROGLYPH E020A",NULL},
/* 130EB */ { "EGYPTIAN HIEROGLYPH E021","	* logogram (Seth) : stš/stẖ"},
/* 130EC */ { "EGYPTIAN HIEROGLYPH E022","	* classifier (lion) : mꜣꞽ"},
/* 130ED */ { "EGYPTIAN HIEROGLYPH E023","	* phonemogram : rw"},
/* 130EE */ { "EGYPTIAN HIEROGLYPH E024","	* classifier leopard : ꜣby"},
/* 130EF */ { "EGYPTIAN HIEROGLYPH E025","	* classifier hippopotamus : ḫꜣb"},
/* 130F0 */ { "EGYPTIAN HIEROGLYPH E026","	* classifier elephant : ꜣbw"},
/* 130F1 */ { "EGYPTIAN HIEROGLYPH E027","	* classifier to fortell : sr"},
/* 130F2 */ { "EGYPTIAN HIEROGLYPH E028","	* classifier oryx : mꜣ-ḥḏ"},
/* 130F3 */ { "EGYPTIAN HIEROGLYPH E028A","	* logogram (Oryx nome, 16th nome of Upper Egypt) : mꜣ-ḥḏ"},
/* 130F4 */ { "EGYPTIAN HIEROGLYPH E029","	* classifier gazelle : gḥs"},
/* 130F5 */ { "EGYPTIAN HIEROGLYPH E030","	* classifier ibex : n(ꞽ)ꜣw"},
/* 130F6 */ { "EGYPTIAN HIEROGLYPH E031","	* logogram (rank, diginity) : sꜥḥ"},
/* 130F7 */ { "EGYPTIAN HIEROGLYPH E032","	* classifier rage, fury : ḳnd"},
/* 130F8 */ { "EGYPTIAN HIEROGLYPH E033","	* classifier monkey : gf"},
/* 130F9 */ { "EGYPTIAN HIEROGLYPH E034","	* phonemogram : wn"},
/* 130FA */ { "EGYPTIAN HIEROGLYPH E034A","	* variant of 130F9"},
/* 130FB */ { "EGYPTIAN HIEROGLYPH E036","	* logogram (Thot) : ḏḥwty"},
/* 130FC */ { "EGYPTIAN HIEROGLYPH E037","	* logogram (symbol of the cycle of time) : wnšb"},
/* 130FD */ { "EGYPTIAN HIEROGLYPH E038","	* cow\n"
	"	* not to be confused with 130D2"},
/* 130FE */ { "EGYPTIAN HIEROGLYPH F001","	* classifier bull, ox, cattle : kꜣ"},
/* 130FF */ { "EGYPTIAN HIEROGLYPH F001A","	* phonemogram : ḫnt"}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_31[] = {
/* 13100 */ { "EGYPTIAN HIEROGLYPH F002","	* classifier rage/aggression : ḏnd"},
/* 13101 */ { "EGYPTIAN HIEROGLYPH F003","	* phonemogram : ꜣt"},
/* 13102 */ { "EGYPTIAN HIEROGLYPH F004","	* logogram (beginning, front) : ḥꜣ.t"},
/* 13103 */ { "EGYPTIAN HIEROGLYPH F005","	* phonemogram : šsꜣ"},
/* 13104 */ { "EGYPTIAN HIEROGLYPH F006","	* phonemogram : šsꜣ"},
/* 13105 */ { "EGYPTIAN HIEROGLYPH F007","	* classifier worth, dignity, renown : šfšf.yt"},
/* 13106 */ { "EGYPTIAN HIEROGLYPH F008","	* logogram (worth, dignity, renown) : šf.yt"},
/* 13107 */ { "EGYPTIAN HIEROGLYPH F009","	* logogram (strength) : pḥ.ty"},
/* 13108 */ { "EGYPTIAN HIEROGLYPH F010","	* classifier throat associated action : sꜥm"},
/* 13109 */ { "EGYPTIAN HIEROGLYPH F011","	* classifier throat associated action : ꜥm"},
/* 1310A */ { "EGYPTIAN HIEROGLYPH F012","	* phonemogram : wsr"},
/* 1310B */ { "EGYPTIAN HIEROGLYPH F013","	* phonemogram : wp"},
/* 1310C */ { "EGYPTIAN HIEROGLYPH F013A","	* variant of 1310B"},
/* 1310D */ { "EGYPTIAN HIEROGLYPH F014","	* logogram (New Year's Day) : wp-rnp.t"},
/* 1310E */ { "EGYPTIAN HIEROGLYPH F015","	* logogram (New Year's Day) : wp-rnp.t"},
/* 1310F */ { "EGYPTIAN HIEROGLYPH F016","	* logogram (horn) : ꜥb\n"
	"	~ 1310F FE00 rotated 90 degrees\n"
	"	~ 1310F FE03 rotated approximately 30 degrees"},
/* 13110 */ { "EGYPTIAN HIEROGLYPH F017","	* logogram purification : ꜥb.w"},
/* 13111 */ { "EGYPTIAN HIEROGLYPH F018","	* phonemogram : ḥ"},
/* 13112 */ { "EGYPTIAN HIEROGLYPH F019","	* classifier jaw : ꜥr"},
/* 13113 */ { "EGYPTIAN HIEROGLYPH F020","	* logogram (tongue) : ns"},
/* 13114 */ { "EGYPTIAN HIEROGLYPH F021","	* logogram (ear) : msḏr"},
/* 13115 */ { "EGYPTIAN HIEROGLYPH F021A","	* from hieratic\n"
	"	* logogram to hear, to listen"},
/* 13116 */ { "EGYPTIAN HIEROGLYPH F022","	* phonemogram : pḥ"},
/* 13117 */ { "EGYPTIAN HIEROGLYPH F023","	* classifier foreleg/arm : ḫpš\n"
	"	~ 13117 FE02 rotated 270 degrees"},
/* 13118 */ { "EGYPTIAN HIEROGLYPH F024","	* mirrored version of 13117\n"
	"	* classifier foreleg/arm : ḫpš"},
/* 13119 */ { "EGYPTIAN HIEROGLYPH F025","	* phonemogram : wḥm"},
/* 1311A */ { "EGYPTIAN HIEROGLYPH F026","	* phonemogram : ẖn"},
/* 1311B */ { "EGYPTIAN HIEROGLYPH F027","	* classifier animal : ṯsm"},
/* 1311C */ { "EGYPTIAN HIEROGLYPH F028","	* logogram (dappled, many-coloured) : sꜣb\n"
	"	~ 1311C FE00 rotated 90 degrees"},
/* 1311D */ { "EGYPTIAN HIEROGLYPH F029","	* phonemogram : st"},
/* 1311E */ { "EGYPTIAN HIEROGLYPH F030","	* phonemogram : šd"},
/* 1311F */ { "EGYPTIAN HIEROGLYPH F031","	* phonemogram : ms"},
/* 13120 */ { "EGYPTIAN HIEROGLYPH F031A","	* cursive variant of 1311F\n"
	"	* phonemogram : ms"},
/* 13121 */ { "EGYPTIAN HIEROGLYPH F032","	* transliterated as 1E96\n"
	"	* logogram (belly, body) : ẖ.t\n"
	"	~ 13121 FE00 rotated 90 degrees"},
/* 13122 */ { "EGYPTIAN HIEROGLYPH F033","	* phonemogram : sd"},
/* 13123 */ { "EGYPTIAN HIEROGLYPH F034","	* logogram (heart, mind, wish) : ꞽb"},
/* 13124 */ { "EGYPTIAN HIEROGLYPH F035","	* phonemogram : nfr"},
/* 13125 */ { "EGYPTIAN HIEROGLYPH F036","	* phonemogram : smꜣ"},
/* 13126 */ { "EGYPTIAN HIEROGLYPH F037","	* classifier spine, vertebrae : ꞽꜣ.t"},
/* 13127 */ { "EGYPTIAN HIEROGLYPH F037A","	* logogram (to cut) : šꜥd\n"
	"	~ 13127 FE00 rotated 90 degrees"},
/* 13128 */ { "EGYPTIAN HIEROGLYPH F038","	* classifier back, backbone : psḏ"},
/* 13129 */ { "EGYPTIAN HIEROGLYPH F038A",NULL},
/* 1312A */ { "EGYPTIAN HIEROGLYPH F039","	* phonemogram : ꞽmꜣḫ"},
/* 1312B */ { "EGYPTIAN HIEROGLYPH F040","	* logogram (to be long, to stretch out) : ꜣwꞽ"},
/* 1312C */ { "EGYPTIAN HIEROGLYPH F041","	* classifier slaughter/evil : šꜥ.t"},
/* 1312D */ { "EGYPTIAN HIEROGLYPH F042","	* classifier rib : spr"},
/* 1312E */ { "EGYPTIAN HIEROGLYPH F043","	* classifier ribs (meat of ribs) : spḥ.t"},
/* 1312F */ { "EGYPTIAN HIEROGLYPH F044","	* phono-repeater : ꞽwꜥ\n"
	"	~ 1312F FE03 rotated approximately 40 degrees [but not yet vertical]\n"
	"	~ 1312F FE06 rotated approximately 325 degrees [horizontal]"},
/* 13130 */ { "EGYPTIAN HIEROGLYPH F045","	* logogram (uterus, womb) : ꞽd.t"},
/* 13131 */ { "EGYPTIAN HIEROGLYPH F045A","	* phonemogram : m"},
/* 13132 */ { "EGYPTIAN HIEROGLYPH F046","	* logogram (to go round, to turn round) : pẖr\n"
	"	~ 13132 FE01 rotated 180 degrees"},
/* 13133 */ { "EGYPTIAN HIEROGLYPH F046A","	* rotated version of 13132\n"
	"	* logogram (to go round, to turn round) : pẖr"},
/* 13134 */ { "EGYPTIAN HIEROGLYPH F047","	* mirrored version of 13132\n"
	"	* classifier winding, intestine : ḳ(ꜣ)b"},
/* 13135 */ { "EGYPTIAN HIEROGLYPH F047A","	* mirrored version of 13133\n"
	"	* logogram (to go round, to turn round) : pẖr"},
/* 13136 */ { "EGYPTIAN HIEROGLYPH F048","	* logogram (to go round, to turn round) : pẖr"},
/* 13137 */ { "EGYPTIAN HIEROGLYPH F049","	* mirrored version of 13136\n"
	"	* phono-repeater : wḏb"},
/* 13138 */ { "EGYPTIAN HIEROGLYPH F050","	* phonemogram : spẖr"},
/* 13139 */ { "EGYPTIAN HIEROGLYPH F051","	* phonemogram : f\n"
	"	~ 13139 FE00 rotated 90 degrees\n"
	"	~ 13139 FE01 rotated 180 degrees\n"
	"	~ 13139 FE02 rotated 270 degrees\n"
	"	~ 13139 FE03 rotated approximately 45 degrees [vertical]\n"
	"	~ 13139 FE04 rotated approximately 135 degrees [horizontal]\n"
	"	~ 13139 FE05 rotated approximately 225 degrees [vertical]\n"
	"	~ 13139 FE06 rotated approximately 315 degrees [horizontal]"},
/* 1313A */ { "EGYPTIAN HIEROGLYPH F051A","	* classifier part of a body : ḥꜥ.w"},
/* 1313B */ { "EGYPTIAN HIEROGLYPH F051B","	* variant of 1313A\n"
	"	* logogram (limbs, body) : ḥꜥ.w"},
/* 1313C */ { "EGYPTIAN HIEROGLYPH F051C","	* rotated version of 13139"},
/* 1313D */ { "EGYPTIAN HIEROGLYPH F052","	* classifier excrement : ḥs"},
/* 1313E */ { "EGYPTIAN HIEROGLYPH F053","	* phonemogram : mdw"},
/* 1313F */ { "EGYPTIAN HIEROGLYPH G001","	* Egyptian vulture, Egyptological alef\n"
	"	* not to be confused with 13142\n"
	"	* transliterated as A723\n"
	"	x (hebrew letter alef - 05D0)\n"
	"	x (arabic letter alef with hamza above - 0623)\n"
	"	* phonemogram : ꜣ"},
/* 13140 */ { "EGYPTIAN HIEROGLYPH G002","	* phonemogram : ꜣꜣ"},
/* 13141 */ { "EGYPTIAN HIEROGLYPH G003","	* phonemogram : mꜣ"},
/* 13142 */ { "EGYPTIAN HIEROGLYPH G004","	* not to be confused with 1313F\n"
	"	* phonemogram : tyw"},
/* 13143 */ { "EGYPTIAN HIEROGLYPH G005","	* logogram (Horus) : ḥr"},
/* 13144 */ { "EGYPTIAN HIEROGLYPH G006","	* classifier falcon : bꞽk"},
/* 13145 */ { "EGYPTIAN HIEROGLYPH G006A","	* logogram (lord) : nb"},
/* 13146 */ { "EGYPTIAN HIEROGLYPH G007","	* classifier divine beings/divine things"},
/* 13147 */ { "EGYPTIAN HIEROGLYPH G007A","	* logogram (Nemty (divinity)) : nmty"},
/* 13148 */ { "EGYPTIAN HIEROGLYPH G007B","	* logogram nmty (Nemty (divinity))"},
/* 13149 */ { "EGYPTIAN HIEROGLYPH G008","	* logogram (golden Horus) : ḥr-nbw"},
/* 1314A */ { "EGYPTIAN HIEROGLYPH G009","	* logogram (Re-Hor (usually in rꜥ-ḥr-ꜣḫ.ty) : rꜥ-ḥr"},
/* 1314B */ { "EGYPTIAN HIEROGLYPH G010","	* classifier bark of Sokar : ḥnw"},
/* 1314C */ { "EGYPTIAN HIEROGLYPH G011","	* classifier cult image : ꜥẖm"},
/* 1314D */ { "EGYPTIAN HIEROGLYPH G011A",NULL},
/* 1314E */ { "EGYPTIAN HIEROGLYPH G012","	* classifier cult image : ꜥẖm"},
/* 1314F */ { "EGYPTIAN HIEROGLYPH G013","	* classifier falcon divinity : spd(.w)"},
/* 13150 */ { "EGYPTIAN HIEROGLYPH G014","	* logogram (mother) : mw.t"},
/* 13151 */ { "EGYPTIAN HIEROGLYPH G015","	* logogram (mother) : mw.t"},
/* 13152 */ { "EGYPTIAN HIEROGLYPH G016","	* logogram (the two ladies (i.e. Nekhbet and Wadjet) : nb.ty"},
/* 13153 */ { "EGYPTIAN HIEROGLYPH G017","	* phonemogram : m"},
/* 13154 */ { "EGYPTIAN HIEROGLYPH G018","	* phonemogram : mm"},
/* 13155 */ { "EGYPTIAN HIEROGLYPH G019",NULL},
/* 13156 */ { "EGYPTIAN HIEROGLYPH G020","	* phonemogram : m-ꜥ"},
/* 13157 */ { "EGYPTIAN HIEROGLYPH G020A","	* phonemogram : mr (ꞽm.y-r)"},
/* 13158 */ { "EGYPTIAN HIEROGLYPH G021","	* phonemogram : nḥ"},
/* 13159 */ { "EGYPTIAN HIEROGLYPH G022","	* phonemogram : ḏb"},
/* 1315A */ { "EGYPTIAN HIEROGLYPH G023","	* logogram (common folk, subjects, people) : rḫ.yt"},
/* 1315B */ { "EGYPTIAN HIEROGLYPH G024","	* logogram (common folk, subjects, people) : rḫ.yt"},
/* 1315C */ { "EGYPTIAN HIEROGLYPH G025","	* phonemogram : ꜣḫ"},
/* 1315D */ { "EGYPTIAN HIEROGLYPH G026","	* logogram (Thot) : ḏḥwty"},
/* 1315E */ { "EGYPTIAN HIEROGLYPH G026A","	* classifier ibis : hb"},
/* 1315F */ { "EGYPTIAN HIEROGLYPH G027","	* logogram (to be red) : dšr"},
/* 13160 */ { "EGYPTIAN HIEROGLYPH G028","	* phonemogram : gm"},
/* 13161 */ { "EGYPTIAN HIEROGLYPH G029","	* phonemogram : bꜣ"},
/* 13162 */ { "EGYPTIAN HIEROGLYPH G030","	* logogram (souls) : bꜣ.w"},
/* 13163 */ { "EGYPTIAN HIEROGLYPH G031","	* classifier heron : bnw"},
/* 13164 */ { "EGYPTIAN HIEROGLYPH G032","	* logogram (to inundate) : bꜥḥ"},
/* 13165 */ { "EGYPTIAN HIEROGLYPH G033","	* phonemogram : sdꜣ"},
/* 13166 */ { "EGYPTIAN HIEROGLYPH G034","	* classifier ostrich : nꞽw"},
/* 13167 */ { "EGYPTIAN HIEROGLYPH G035","	* phonemogram : ꜥḳ"},
/* 13168 */ { "EGYPTIAN HIEROGLYPH G036","	* phonemogram : wr"},
/* 13169 */ { "EGYPTIAN HIEROGLYPH G036A","	* variant of 13168"},
/* 1316A */ { "EGYPTIAN HIEROGLYPH G037","	* classifier negative, bad : ꞽsf.t"},
/* 1316B */ { "EGYPTIAN HIEROGLYPH G037A","	* variant of 1316A"},
/* 1316C */ { "EGYPTIAN HIEROGLYPH G038","	* goose\n"
	"	* phonemogram : gb"},
/* 1316D */ { "EGYPTIAN HIEROGLYPH G039","	* duck\n"
	"	* logogram (son) : sꜣ "},
/* 1316E */ { "EGYPTIAN HIEROGLYPH G040","	* phonemogram : pꜣ"},
/* 1316F */ { "EGYPTIAN HIEROGLYPH G041","	* phonemogram : ḫn"},
/* 13170 */ { "EGYPTIAN HIEROGLYPH G042","	* phonemogram : ḏfꜣ"},
/* 13171 */ { "EGYPTIAN HIEROGLYPH G043","	* phonemogram : w"},
/* 13172 */ { "EGYPTIAN HIEROGLYPH G043A","	* phonemogram : tw"},
/* 13173 */ { "EGYPTIAN HIEROGLYPH G044","	* phonemogram : ww"},
/* 13174 */ { "EGYPTIAN HIEROGLYPH G045","	* phonemogram : wꜥ"},
/* 13175 */ { "EGYPTIAN HIEROGLYPH G045A","	* phonemogram : dꞽw"},
/* 13176 */ { "EGYPTIAN HIEROGLYPH G046","	* phonemogram : mꜣw"},
/* 13177 */ { "EGYPTIAN HIEROGLYPH G047","	* phonemogram : ṯꜣ"},
/* 13178 */ { "EGYPTIAN HIEROGLYPH G048","	* classifier nest : šš"},
/* 13179 */ { "EGYPTIAN HIEROGLYPH G049",NULL},
/* 1317A */ { "EGYPTIAN HIEROGLYPH G050","	* phonemogram : rḫ.ty"},
/* 1317B */ { "EGYPTIAN HIEROGLYPH G051","	* classifier catching fish : ḥꜣm"},
/* 1317C */ { "EGYPTIAN HIEROGLYPH G052","	* classifier feeding, eating : snm"},
/* 1317D */ { "EGYPTIAN HIEROGLYPH G053","	* logogram (soul) : bꜣ"},
/* 1317E */ { "EGYPTIAN HIEROGLYPH G054","	* phonemogram : snḏ"},
/* 1317F */ { "EGYPTIAN HIEROGLYPH H001","	* logogram (bird, fowl) : ꜣpd"},
/* 13180 */ { "EGYPTIAN HIEROGLYPH H002","	* phono-repeater : wšm"},
/* 13181 */ { "EGYPTIAN HIEROGLYPH H003","	* phonemogram : pꜣḳ"},
/* 13182 */ { "EGYPTIAN HIEROGLYPH H004","	* classifier people : rmṯ"},
/* 13183 */ { "EGYPTIAN HIEROGLYPH H005","	* classifier wing : ḏnḥ\n"
	"	~ 13183 FE02 rotated 270 degrees"},
/* 13184 */ { "EGYPTIAN HIEROGLYPH H006","	* phonemogram : šw\n"
	"	~ 13184 FE03 rotated approximately 25 degrees\n"
	"	~ 13184 FE06 rotated approximately 335 degrees"},
/* 13185 */ { "EGYPTIAN HIEROGLYPH H006A","	* from hieratic\n"
	"	* phonemogram : šw"},
/* 13186 */ { "EGYPTIAN HIEROGLYPH H007","	* classifier claw : ꞽꜣf.t"},
/* 13187 */ { "EGYPTIAN HIEROGLYPH H008","	* logogram (son) : sꜣ\n"
	"	~ 13187 FE01 rotated 180 degrees"},
/* 13188 */ { "EGYPTIAN HIEROGLYPH I001","	* phonemogram : ꜥšꜣ"},
/* 13189 */ { "EGYPTIAN HIEROGLYPH I002","	* classifier turtle : štw"},
/* 1318A */ { "EGYPTIAN HIEROGLYPH I003","	* classifier aggression : ꜣd"},
/* 1318B */ { "EGYPTIAN HIEROGLYPH I004","	* classifier Sobek : sbk"},
/* 1318C */ { "EGYPTIAN HIEROGLYPH I005","	* logogram (to gather) : sꜣḳ"},
/* 1318D */ { "EGYPTIAN HIEROGLYPH I005A","	* classifier Sobek : sbk"},
/* 1318E */ { "EGYPTIAN HIEROGLYPH I006","	* phonemogram : km"},
/* 1318F */ { "EGYPTIAN HIEROGLYPH I007","	* classifier divinity : ḥḳ.t"},
/* 13190 */ { "EGYPTIAN HIEROGLYPH I008","	* logogram (one hundred thousand) : ḥfn"},
/* 13191 */ { "EGYPTIAN HIEROGLYPH I009","	* phonemogram : f"},
/* 13192 */ { "EGYPTIAN HIEROGLYPH I009A","	* logogram (to go forth) : prꞽ"},
/* 13193 */ { "EGYPTIAN HIEROGLYPH I010","	* transliterated as 1E0F\n"
	"	* phonemogram : ḏ"},
/* 13194 */ { "EGYPTIAN HIEROGLYPH I010A","	* phonemogram : ḏfꜣ"},
/* 13195 */ { "EGYPTIAN HIEROGLYPH I011","	* phonemogram : ḏḏ"},
/* 13196 */ { "EGYPTIAN HIEROGLYPH I011A","	* logogram (eternity) : ḏ.t"},
/* 13197 */ { "EGYPTIAN HIEROGLYPH I012","	* classifier female divinity : nbw.t"},
/* 13198 */ { "EGYPTIAN HIEROGLYPH I013","	* classifier female divinity (Wadjet) : wꜣḏ.t"},
/* 13199 */ { "EGYPTIAN HIEROGLYPH I014","	* classifier coiling, winding : ḳꜣb"},
/* 1319A */ { "EGYPTIAN HIEROGLYPH I015","	* classifier snake/uraeus : ꞽꜥr.t"},
/* 1319B */ { "EGYPTIAN HIEROGLYPH K001","	* phonemogram : ꞽn"},
/* 1319C */ { "EGYPTIAN HIEROGLYPH K002","	* phono-repeater : bw\n"
	"	~ 1319C FE03 rotated approximately 45 degrees"},
/* 1319D */ { "EGYPTIAN HIEROGLYPH K003","	* logogram (fish) : rm\n"
	"	~ 1319D FE03 rotated approximately 30 degrees"},
/* 1319E */ { "EGYPTIAN HIEROGLYPH K004","	* phonemogram : ẖꜣ"},
/* 1319F */ { "EGYPTIAN HIEROGLYPH K005","	* phono-repeater : bs\n"
	"	~ 1319F FE03 rotated approximately 30 degrees"},
/* 131A0 */ { "EGYPTIAN HIEROGLYPH K006","	* logogram (scale) : nšm.t\n"
	"	~ 131A0 FE00 rotated 90 degrees\n"
	"	~ 131A0 FE02 rotated 270 degrees"},
/* 131A1 */ { "EGYPTIAN HIEROGLYPH K007","	* classifier rage, anger : špt"},
/* 131A2 */ { "EGYPTIAN HIEROGLYPH K008","	* classifier catfish : nꜥr"},
/* 131A3 */ { "EGYPTIAN HIEROGLYPH L001","	* logogram (to become) : ḫpr"},
/* 131A4 */ { "EGYPTIAN HIEROGLYPH L002","	* logogram (king of Lower Egypt) : bꞽ.ty"},
/* 131A5 */ { "EGYPTIAN HIEROGLYPH L002A","	* logogram (king of Upper Egypt and Lower Egypt) : n(.y)-sw.t-bꞽ.ty"},
/* 131A6 */ { "EGYPTIAN HIEROGLYPH L003","	x (egyptian hieroglyph-13DEE - 13DEE)"},
/* 131A7 */ { "EGYPTIAN HIEROGLYPH L004","	* classifier locust : snḥm"},
/* 131A8 */ { "EGYPTIAN HIEROGLYPH L005","	* classifier centipede : spꜣ"},
/* 131A9 */ { "EGYPTIAN HIEROGLYPH L006","	* phonemogram : ḫꜣ"},
/* 131AA */ { "EGYPTIAN HIEROGLYPH L006A","	* mirrored version of 131A9"},
/* 131AB */ { "EGYPTIAN HIEROGLYPH L007","	* classifier scorpion : srḳ.t"},
/* 131AC */ { "EGYPTIAN HIEROGLYPH L008","	* logogram/phonemogram (type of beetle) : ꜥnḫ"},
/* 131AD */ { "EGYPTIAN HIEROGLYPH M001","	* classifier tree, product of a tree : ꜥš"},
/* 131AE */ { "EGYPTIAN HIEROGLYPH M001A","	* classifier product of a tree : hbny"},
/* 131AF */ { "EGYPTIAN HIEROGLYPH M001B","	* phonemogram : ꞽm=f"},
/* 131B0 */ { "EGYPTIAN HIEROGLYPH M002","	* phonemogram : ḥn"},
/* 131B1 */ { "EGYPTIAN HIEROGLYPH M003","	* phonemogram : ḫt\n"
	"	~ 131B1 FE00 rotated 90 degrees\n"
	"	~ 131B1 FE01 rotated 180 degrees\n"
	"	~ 131B1 FE03 rotated approximately 45 degrees"},
/* 131B2 */ { "EGYPTIAN HIEROGLYPH M003A","	* phonemogram : m-ḫt"},
/* 131B3 */ { "EGYPTIAN HIEROGLYPH M004","	* logogram (year) : rnp.t"},
/* 131B4 */ { "EGYPTIAN HIEROGLYPH M005","	* logogram (time/season) : tr"},
/* 131B5 */ { "EGYPTIAN HIEROGLYPH M006","	* logogram (time/season) : tr"},
/* 131B6 */ { "EGYPTIAN HIEROGLYPH M007","	* classifier youth, vigour, fresh : rnp"},
/* 131B7 */ { "EGYPTIAN HIEROGLYPH M008","	* phonemogram : šꜣ"},
/* 131B8 */ { "EGYPTIAN HIEROGLYPH M009","	* classifier lotus flower : sšn\n"
	"	~ 131B8 FE00 rotated 90 degrees"},
/* 131B9 */ { "EGYPTIAN HIEROGLYPH M010","	* classifier lotus bud : nḥb.t\n"
	"	~ 131B9 FE00 rotated 90 degrees"},
/* 131BA */ { "EGYPTIAN HIEROGLYPH M010A","	* classifier offering : wdn\n"
	"	~ 131BA FE02 rotated 270 degrees"},
/* 131BB */ { "EGYPTIAN HIEROGLYPH M011","	* logogram (to offer) : wdn"},
/* 131BC */ { "EGYPTIAN HIEROGLYPH M012","	* 1000\n"
	"	* phonemogram : ḫꜣ"},
/* 131BD */ { "EGYPTIAN HIEROGLYPH M012A","	* \\2000"},
/* 131BE */ { "EGYPTIAN HIEROGLYPH M012B","	* \\3000"},
/* 131BF */ { "EGYPTIAN HIEROGLYPH M012C","	* \\4000"},
/* 131C0 */ { "EGYPTIAN HIEROGLYPH M012D","	* \\5000"},
/* 131C1 */ { "EGYPTIAN HIEROGLYPH M012E","	* \\6000"},
/* 131C2 */ { "EGYPTIAN HIEROGLYPH M012F","	* \\7000"},
/* 131C3 */ { "EGYPTIAN HIEROGLYPH M012G","	* \\8000"},
/* 131C4 */ { "EGYPTIAN HIEROGLYPH M012H","	* \\9000"},
/* 131C5 */ { "EGYPTIAN HIEROGLYPH M013","	* phonemogram : wꜣḏ"},
/* 131C6 */ { "EGYPTIAN HIEROGLYPH M014","	* phonemogram : wꜣḏ"},
/* 131C7 */ { "EGYPTIAN HIEROGLYPH M015","	* logogram (Lower Egypt) : mḥ.w"},
/* 131C8 */ { "EGYPTIAN HIEROGLYPH M015A","	* logogram (Lower Egypt) : mḥ.w"},
/* 131C9 */ { "EGYPTIAN HIEROGLYPH M016","	* phonemogram : ḥꜣ"},
/* 131CA */ { "EGYPTIAN HIEROGLYPH M016A","	* logogram (Lower Egypt) : mḥ.w"},
/* 131CB */ { "EGYPTIAN HIEROGLYPH M017","	* egyptological yod\n"
	"	* transliterated as A7BD\n"
	"	x (hebrew letter yod - 05D9)\n"
	"	x (arabic letter yeh - 064A)\n"
	"	* phonemogram : ꞽ\n"
	"	~ 131CB FE00 rotated 90 degrees"},
/* 131CC */ { "EGYPTIAN HIEROGLYPH M017A","	x (egyptian hieroglyph z004 - 133ED)\n"
	"	* phonemogram : y"},
/* 131CD */ { "EGYPTIAN HIEROGLYPH M018","	* phonemogram/logogram (to come) : ꞽy(ꞽ)"},
/* 131CE */ { "EGYPTIAN HIEROGLYPH M019","	* phonemogram : ꜥꜣb"},
/* 131CF */ { "EGYPTIAN HIEROGLYPH M020","	* logogram (marshland, country) : sḫ.t"},
/* 131D0 */ { "EGYPTIAN HIEROGLYPH M021","	* logogram (herb, plant) : sm"},
/* 131D1 */ { "EGYPTIAN HIEROGLYPH M022","	* classifier \"bud, lotus bud\"\n"
	"	* phonemogram : nḫb"},
/* 131D2 */ { "EGYPTIAN HIEROGLYPH M022A","	* phonemogram : nn"},
/* 131D3 */ { "EGYPTIAN HIEROGLYPH M023","	* logogram (king of Upper Egypt) : n(.y)-sw.t"},
/* 131D4 */ { "EGYPTIAN HIEROGLYPH M024","	* phonemogram : rsw/rsy"},
/* 131D5 */ { "EGYPTIAN HIEROGLYPH M024A","	* logogram (land) : tꜣ"},
/* 131D6 */ { "EGYPTIAN HIEROGLYPH M025","	* logogram (Upper Egypt) : šmꜥ.w"},
/* 131D7 */ { "EGYPTIAN HIEROGLYPH M026","	* logogram (Upper Egypt) : šmꜥ.w"},
/* 131D8 */ { "EGYPTIAN HIEROGLYPH M027","	* logogram (Upper Egypt) : šmꜥ.w"},
/* 131D9 */ { "EGYPTIAN HIEROGLYPH M028","	* logogram (the 10 of Upper Egypt) : mḏ-šmꜥ.w"},
/* 131DA */ { "EGYPTIAN HIEROGLYPH M028A","	* logogram (Upper Egypt) : šmꜥ.w"},
/* 131DB */ { "EGYPTIAN HIEROGLYPH M029","	* logogram (to be sweet) : nḏm\n"
	"	~ 131DB FE03 rotated approximately 20 degrees\n"
	"	~ 131DB FE06 rotated approximately 340 degrees"},
/* 131DC */ { "EGYPTIAN HIEROGLYPH M030","	* logogram (to be sweet) : bnr/bnꞽ"},
/* 131DD */ { "EGYPTIAN HIEROGLYPH M031","	* classifier growing : srd"},
/* 131DE */ { "EGYPTIAN HIEROGLYPH M031A","	* classifier growing : srd"},
/* 131DF */ { "EGYPTIAN HIEROGLYPH M032","	* classifier growing : rd"},
/* 131E0 */ { "EGYPTIAN HIEROGLYPH M033","	* logogram (grain, barley, corn) : ꞽt\n"
	"	~ 131E0 FE00 rotated 90 degrees [= 270 degrees]"},
/* 131E1 */ { "EGYPTIAN HIEROGLYPH M033A","	* variant of 131E0\n"
	"	* classifier grain, barley, corn : ꞽt"},
/* 131E2 */ { "EGYPTIAN HIEROGLYPH M033B","	* variant of 131E0\n"
	"	* classifier grain, barley, corn : tbtb"},
/* 131E3 */ { "EGYPTIAN HIEROGLYPH M034","	* logogram (emmer) : bd.t"},
/* 131E4 */ { "EGYPTIAN HIEROGLYPH M035","	* classifier heap, quantity : ꜥḥꜥ"},
/* 131E5 */ { "EGYPTIAN HIEROGLYPH M036","	* phonemogram : ḏr"},
/* 131E6 */ { "EGYPTIAN HIEROGLYPH M037","	* older variant of 131E5\n"
	"	* phonemogram : ḏr"},
/* 131E7 */ { "EGYPTIAN HIEROGLYPH M038","	* classifier flax : ḥmꜥ"},
/* 131E8 */ { "EGYPTIAN HIEROGLYPH M039","	* classifier granular product : snṯr"},
/* 131E9 */ { "EGYPTIAN HIEROGLYPH M040","	* not to be confused with 132A7 or 1342A\n"
	"	* phonemogram : ꞽs"},
/* 131EA */ { "EGYPTIAN HIEROGLYPH M040A","	* phonemogram : ꞽs"},
/* 131EB */ { "EGYPTIAN HIEROGLYPH M041","	* classifier wood/timber : ꜥš"},
/* 131EC */ { "EGYPTIAN HIEROGLYPH M042","	* phonemogram : wn"},
/* 131ED */ { "EGYPTIAN HIEROGLYPH M043","	* logogram (wine) : ꞽrp"},
/* 131EE */ { "EGYPTIAN HIEROGLYPH M044","	* thorn\n"
	"	* not to be confused with 133DA\n"
	"	* phonemogram : spd\n"
	"	~ 131EE FE01 rotated 180 degrees\n"
	"	~ 131EE FE02 rotated 270 degrees\n"
	"	~ 131EE FE06 rotated approximately 330 degrees"},
/* 131EF */ { "EGYPTIAN HIEROGLYPH N001","	* logogram (sky) : p.t"},
/* 131F0 */ { "EGYPTIAN HIEROGLYPH N002","	* classifier night : grḥ"},
/* 131F1 */ { "EGYPTIAN HIEROGLYPH N003","	* older variant of 131F0\n"
	"	* classifier night : grḥ"},
/* 131F2 */ { "EGYPTIAN HIEROGLYPH N004","	* classifier storm : sšn"},
/* 131F3 */ { "EGYPTIAN HIEROGLYPH N005","	* not to be confused with 13082 or 133F8\n"
	"	* logogram (the sun, Re) : rꜥ"},
/* 131F4 */ { "EGYPTIAN HIEROGLYPH N006","	* logogram (the sun, Re) : rꜥ"},
/* 131F5 */ { "EGYPTIAN HIEROGLYPH N007","	* logogram (course (of the day), daily requirements) : ẖr.t-hrw"},
/* 131F6 */ { "EGYPTIAN HIEROGLYPH N008","	* classifier light, shining, rising : psḏ"},
/* 131F7 */ { "EGYPTIAN HIEROGLYPH N009","	* variant of 131F8\n"
	"	* phonemogram : psḏ"},
/* 131F8 */ { "EGYPTIAN HIEROGLYPH N010","	* variant of 131F7\n"
	"	* phonemogram : psḏ\n"
	"	~ 131F8 FE01 rotated 180 degrees"},
/* 131F9 */ { "EGYPTIAN HIEROGLYPH N011","	* logogram (month) : ꜣbd\n"
	"	~ 131F9 FE00 rotated 90 degrees\n"
	"	~ 131F9 FE01 rotated 180 degrees"},
/* 131FA */ { "EGYPTIAN HIEROGLYPH N012","	* classifier moon : ꞽꜥḥ\n"
	"	~ 131FA FE00 rotated 90 degrees\n"
	"	~ 131FA FE01 rotated 180 degrees"},
/* 131FB */ { "EGYPTIAN HIEROGLYPH N013","	* logogram (half-month (festival)) : smd.t"},
/* 131FC */ { "EGYPTIAN HIEROGLYPH N014","	* logogram (star) : sbꜣ"},
/* 131FD */ { "EGYPTIAN HIEROGLYPH N015","	* classifier (netherworld) : dwꜣ.t"},
/* 131FE */ { "EGYPTIAN HIEROGLYPH N016","	* logogram (land) : tꜣ"},
/* 131FF */ { "EGYPTIAN HIEROGLYPH N017","	* variant of 131FE\n"
	"	* logogram (land) : tꜣ"}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_32[] = {
/* 13200 */ { "EGYPTIAN HIEROGLYPH N018","	* not to be confused with 132F0, 133D4, or 133F3\n"
	"	* logogram (island) : ꞽw"},
/* 13201 */ { "EGYPTIAN HIEROGLYPH N018A","	* phonemogram : ꞽmn"},
/* 13202 */ { "EGYPTIAN HIEROGLYPH N018B",NULL},
/* 13203 */ { "EGYPTIAN HIEROGLYPH N019","	* logogram (horizon-dweller) : ꜣḫ.ty"},
/* 13204 */ { "EGYPTIAN HIEROGLYPH N020","	* classifier riverbank : wḏb"},
/* 13205 */ { "EGYPTIAN HIEROGLYPH N021","	* logogram (riverbank) : ꞽdb\n"
	"	~ 13205 FE03 rotated approximately 30 degrees [but not yet vertical]\n"
	"	~ 13205 FE06 rotated approximately 330 degrees [horizontal]"},
/* 13206 */ { "EGYPTIAN HIEROGLYPH N022","	* logogram (riverbank) : ꞽdb"},
/* 13207 */ { "EGYPTIAN HIEROGLYPH N023","	* classifier geographical location : dmꞽ"},
/* 13208 */ { "EGYPTIAN HIEROGLYPH N024","	* logogram (nome, district) : spꜣ.t"},
/* 13209 */ { "EGYPTIAN HIEROGLYPH N025","	* classifier foreign land, desert : ḫꜣs.t"},
/* 1320A */ { "EGYPTIAN HIEROGLYPH N025A","	* variant of 13209"},
/* 1320B */ { "EGYPTIAN HIEROGLYPH N026","	* phonemogram : ḏw"},
/* 1320C */ { "EGYPTIAN HIEROGLYPH N027","	* logogram (horizon) : ꜣḫ.t"},
/* 1320D */ { "EGYPTIAN HIEROGLYPH N028","	* phonemogram : ḫꜥ"},
/* 1320E */ { "EGYPTIAN HIEROGLYPH N029","	* hill\n"
	"	* not to be confused with 133D8\n"
	"	* transliterated as q or as 1E33\n"
	"	x (hebrew letter qof - 05E7)\n"
	"	x (arabic letter qaf - 0642)\n"
	"	* phonemogram : ḳ"},
/* 1320F */ { "EGYPTIAN HIEROGLYPH N030","	* logogram hill, mound : ꞽꜣ.t"},
/* 13210 */ { "EGYPTIAN HIEROGLYPH N031","	* logogram (road) : wꜣ.t"},
/* 13211 */ { "EGYPTIAN HIEROGLYPH N032","	* classifier clay : sꞽn"},
/* 13212 */ { "EGYPTIAN HIEROGLYPH N033","	* not to be confused with 130C9\n"
	"	* classifier medicaments, incense, oil : snṯr"},
/* 13213 */ { "EGYPTIAN HIEROGLYPH N033A","	* not to be confused with 133E7\n"
	"	* classifier medicaments, incense, oil : ꜥn.tyw"},
/* 13214 */ { "EGYPTIAN HIEROGLYPH N034","	* classifier metal objects : ꞽḳḥ.w"},
/* 13215 */ { "EGYPTIAN HIEROGLYPH N034A","	* variant of 13214\n"
	"	* logogram (metal) : bꞽꜣ"},
/* 13216 */ { "EGYPTIAN HIEROGLYPH N035","	* phonemogram : n\n"
	"	~ 13216 FE02 rotated 270 degrees"},
/* 13217 */ { "EGYPTIAN HIEROGLYPH N035A","	* logogram (water) : mw"},
/* 13218 */ { "EGYPTIAN HIEROGLYPH N036","	* phonemogram : mr"},
/* 13219 */ { "EGYPTIAN HIEROGLYPH N037","	* lake\n"
	"	* transliterated as 0161\n"
	"	* not to be confused with 1328C\n"
	"	* phonemogram : š"},
/* 1321A */ { "EGYPTIAN HIEROGLYPH N037A","	* variant of 13219\n"
	"	* phonemogram : š"},
/* 1321B */ { "EGYPTIAN HIEROGLYPH N038","	* variant of 13219\n"
	"	* phonemogram : š"},
/* 1321C */ { "EGYPTIAN HIEROGLYPH N039","	* variant of 13219\n"
	"	* phonemogram : š"},
/* 1321D */ { "EGYPTIAN HIEROGLYPH N040","	* logogram (to go) : šm"},
/* 1321E */ { "EGYPTIAN HIEROGLYPH N041","	* phonemogram : ḥm"},
/* 1321F */ { "EGYPTIAN HIEROGLYPH N042","	* variant of 1321E\n"
	"	* phonemogram : ḥm"},
/* 13220 */ { "EGYPTIAN HIEROGLYPH NL001","	* logogram (Memphis (the white wall; first nome of Lower Egypt)) : ꞽnb-ḥḏ"},
/* 13221 */ { "EGYPTIAN HIEROGLYPH NL002","	* logogram (2nd nome of Lower Egypt) : ḫm/ḫpš/ꞽwꜥ"},
/* 13222 */ { "EGYPTIAN HIEROGLYPH NL003","	* logogram (West, 3rd nome of Lower Egypt) : ꞽmn.tt"},
/* 13223 */ { "EGYPTIAN HIEROGLYPH NL004","	* logogram (Neith-South, 4th nome of Lower Egypt) : n.t-rs.yt"},
/* 13224 */ { "EGYPTIAN HIEROGLYPH NL005","	* logogram (Neith-North, 5th nome of Lower Egypt) : n.t-mḥ.yt"},
/* 13225 */ { "EGYPTIAN HIEROGLYPH NL005A","	* logogram (Neith-North, 5th nome of Lower Egypt) : n.t-mḥ.yt"},
/* 13226 */ { "EGYPTIAN HIEROGLYPH NL006","	* logogram (6th nome of Lower Egypt) : ḫꜣsw.w"},
/* 13227 */ { "EGYPTIAN HIEROGLYPH NL007","	* logogram (7th nome of Lower Egypt) : wꜥ-m-ḥww-ꞽmn.ty"},
/* 13228 */ { "EGYPTIAN HIEROGLYPH NL008","	* logogram (8th nome of Lower Egypt) : wꜥ-m-ḥww-ꞽꜣb.ty"},
/* 13229 */ { "EGYPTIAN HIEROGLYPH NL009","	* logogram (9th nome of Lower Egypt) : ꜥnḏ.ty "},
/* 1322A */ { "EGYPTIAN HIEROGLYPH NL010","	* logogram (10th nome of Lower Egypt) : km-wr"},
/* 1322B */ { "EGYPTIAN HIEROGLYPH NL011","	* logogram (11th nome of Lower Egypt) : ḥsbw"},
/* 1322C */ { "EGYPTIAN HIEROGLYPH NL012","	* logogram (12th nome of Lower Egypt) : ṯb-nṯr"},
/* 1322D */ { "EGYPTIAN HIEROGLYPH NL013","	* logogram (13th nome of Lower Egypt) : ḥḳꜣ-ꜥnḏ.w"},
/* 1322E */ { "EGYPTIAN HIEROGLYPH NL014","	* logogram (14th nome of Upper Egypt) : ḫnt.y-ꞽꜣb.ty"},
/* 1322F */ { "EGYPTIAN HIEROGLYPH NL015","	* logogram (Thot nome, 15th nome of Lower Egypt) : ḏhwty"},
/* 13230 */ { "EGYPTIAN HIEROGLYPH NL016","	* logogram (First-of-fishes nome (16th nome of Lower Egypt)) : ḥꜣ.t-mḥ.yt"},
/* 13231 */ { "EGYPTIAN HIEROGLYPH NL017","	* logogram (Behdet, 17th nome of Lower Egypt) : bḥd.t"},
/* 13232 */ { "EGYPTIAN HIEROGLYPH NL017A","	* logogram (17th nome of Lower Egypt (Diospolis)) : smꜣ-bḥd.t"},
/* 13233 */ { "EGYPTIAN HIEROGLYPH NL018",NULL},
/* 13234 */ { "EGYPTIAN HIEROGLYPH NL019",NULL},
/* 13235 */ { "EGYPTIAN HIEROGLYPH NL020",NULL},
/* 13236 */ { "EGYPTIAN HIEROGLYPH NU001","	* logogram (Nubia, 1st nome of Upper Egypt) : tꜣ-sty"},
/* 13237 */ { "EGYPTIAN HIEROGLYPH NU002","	* logogram (Throne of Horus (Edfu, 2nd nome of Upper Egypt)) : wṯs-ḥr"},
/* 13238 */ { "EGYPTIAN HIEROGLYPH NU003","	* logogram (3rd nome of Upper Egypt) : nḫn"},
/* 13239 */ { "EGYPTIAN HIEROGLYPH NU004","	* logogram (Thebes) : wꜣs.t"},
/* 1323A */ { "EGYPTIAN HIEROGLYPH NU005","	* logogram (The two gods, 5th nome of Upper Egypt) : nṯr.wy"},
/* 1323B */ { "EGYPTIAN HIEROGLYPH NU006","	* logogram (Iqer, 6th nome of Upper Egypt) : ꞽḳr"},
/* 1323C */ { "EGYPTIAN HIEROGLYPH NU007","	* logogram (Bat (7th nome of Upper Egypt)) : bꜣ.t"},
/* 1323D */ { "EGYPTIAN HIEROGLYPH NU008","	* logogram (8th nome of Upper Egypt) : tꜣ-wr"},
/* 1323E */ { "EGYPTIAN HIEROGLYPH NU009","	* logogram (9th nome of Upper Egypt) : mnw"},
/* 1323F */ { "EGYPTIAN HIEROGLYPH NU010","	* logogram (Wadjet, 10th nome of Upper Egypt) : wꜣḏ.t"},
/* 13240 */ { "EGYPTIAN HIEROGLYPH NU010A","	* logogram (Wadjet, 10th nome of Upper Egypt) : wꜣḏ.t"},
/* 13241 */ { "EGYPTIAN HIEROGLYPH NU011","	* logogram (11th nome of Upper Egypt) : šꜣ/stẖ/stš"},
/* 13242 */ { "EGYPTIAN HIEROGLYPH NU011A","	* logogram (11th nome of Upper Egypt (commonly under stẖ/stš/šꜣ) : ḥw-n.t"},
/* 13243 */ { "EGYPTIAN HIEROGLYPH NU012","	* logogram (12th nome of Upper Egypt) : ꜣtf.t"},
/* 13244 */ { "EGYPTIAN HIEROGLYPH NU013","	* logogram (13th nome of Upper Egypt) : nḏf.t-ḫnt.t"},
/* 13245 */ { "EGYPTIAN HIEROGLYPH NU014","	* logogram (14th nome of Upper Egypt) : nḏf.t-pḥ.t"},
/* 13246 */ { "EGYPTIAN HIEROGLYPH NU015","	* logogram (Hermopolis magna, 15th nome of Upper Egypt) : wnw.t"},
/* 13247 */ { "EGYPTIAN HIEROGLYPH NU016","	* logogram (Oryx nome, 16th nome of Upper Egypt) : mꜣ-ḥḏ"},
/* 13248 */ { "EGYPTIAN HIEROGLYPH NU017","	* logogram (Anubis nome (17th nome of Upper Egypt)) : ꞽnpw.t"},
/* 13249 */ { "EGYPTIAN HIEROGLYPH NU018","	* logogram (18th nome of Upper Egypt (known as nmty as well)) : dwn-ꜥn.wy"},
/* 1324A */ { "EGYPTIAN HIEROGLYPH NU018A",NULL},
/* 1324B */ { "EGYPTIAN HIEROGLYPH NU019","	* logogram (place of Igai, 19th nome of Upper Egypt) : bw-ꞽgꜣꞽ"},
/* 1324C */ { "EGYPTIAN HIEROGLYPH NU020","	* logogram (20th nome of Upper Egypt) : nꜥr.t-ḫnt.t"},
/* 1324D */ { "EGYPTIAN HIEROGLYPH NU021","	* logogram (21th nome of Upper Egypt) : nꜥr.t-ph.t"},
/* 1324E */ { "EGYPTIAN HIEROGLYPH NU022","	* logogram (22th nome of Upper Egypt) : mdnꞽ.t"},
/* 1324F */ { "EGYPTIAN HIEROGLYPH NU022A","	* logogram (22th nome of Upper Egypt) : mdnꞽ.t"},
/* 13250 */ { "EGYPTIAN HIEROGLYPH O001","	* logogram (house, domain) : pr"},
/* 13251 */ { "EGYPTIAN HIEROGLYPH O001A","	* logogram (scriptorum, school (house of life)) : pr-ꜥnḫ"},
/* 13252 */ { "EGYPTIAN HIEROGLYPH O002","	* logogram (treasury) : pr-ḥḏ"},
/* 13253 */ { "EGYPTIAN HIEROGLYPH O003","	* logogram (invocation offering) : pr.t-ḫrw"},
/* 13254 */ { "EGYPTIAN HIEROGLYPH O004","	x (hebrew letter he - 05D4)\n"
	"	x (arabic letter heh - 0647)\n"
	"	* phonemogram : h"},
/* 13255 */ { "EGYPTIAN HIEROGLYPH O005","	* phonemogram : nm"},
/* 13256 */ { "EGYPTIAN HIEROGLYPH O005A","	* mirrored version of 13255"},
/* 13257 */ { "EGYPTIAN HIEROGLYPH O006","	* logogram (temple, mansion, estate) : ḥw.t\n"
	"	~ 13257 FE01 rotated 180 degrees"},
/* 13258 */ { "EGYPTIAN HIEROGLYPH O006A","	* beginning of hwt or serekh enclosure\n"
	"	x (egyptian hieroglyph o033a - 13282)"},
/* 13259 */ { "EGYPTIAN HIEROGLYPH O006B","	* beginning of low hwt enclosure"},
/* 1325A */ { "EGYPTIAN HIEROGLYPH O006C","	* beginning of high hwt enclosure"},
/* 1325B */ { "EGYPTIAN HIEROGLYPH O006D","	* end of high hwt enclosure"},
/* 1325C */ { "EGYPTIAN HIEROGLYPH O006E","	* end of low hwt enclosure"},
/* 1325D */ { "EGYPTIAN HIEROGLYPH O006F","	* end of hwt enclosure"},
/* 1325E */ { "EGYPTIAN HIEROGLYPH O007","	* logogram (temple, mansion, estate) : ḥw.t"},
/* 1325F */ { "EGYPTIAN HIEROGLYPH O008","	* logogram (the great domain, temple) : ḥw.t-ꜥꜣ.t"},
/* 13260 */ { "EGYPTIAN HIEROGLYPH O009","	* logogram (Nephthys (divinity)) : nb.t-ḥw.t"},
/* 13261 */ { "EGYPTIAN HIEROGLYPH O010","	* logogram (Hathor (divinity)) : ḥw.t-ḥr"},
/* 13262 */ { "EGYPTIAN HIEROGLYPH O010A","	* logogram (mansion of life) : ḥw.t-ꜥnḫ"},
/* 13263 */ { "EGYPTIAN HIEROGLYPH O010B",NULL},
/* 13264 */ { "EGYPTIAN HIEROGLYPH O010C",NULL},
/* 13265 */ { "EGYPTIAN HIEROGLYPH O011","	* logogram (palace) : ꜥḥ"},
/* 13266 */ { "EGYPTIAN HIEROGLYPH O012","	* logogram (palace) : ꜥḥ"},
/* 13267 */ { "EGYPTIAN HIEROGLYPH O013","	* classifier enfolding, enclosing, walling in : sbḫ"},
/* 13268 */ { "EGYPTIAN HIEROGLYPH O014","	* classifier gateway : sbḫ.t"},
/* 13269 */ { "EGYPTIAN HIEROGLYPH O015","	* logogram (court) : wsḫ.t"},
/* 1326A */ { "EGYPTIAN HIEROGLYPH O016","	* logogram (portal, portico) : sbḫ.t"},
/* 1326B */ { "EGYPTIAN HIEROGLYPH O017","	* phonemogram : tꜣ"},
/* 1326C */ { "EGYPTIAN HIEROGLYPH O018","	* classifier shrine, chapel : kꜣr"},
/* 1326D */ { "EGYPTIAN HIEROGLYPH O019","	* classifier shrine : pr-wr"},
/* 1326E */ { "EGYPTIAN HIEROGLYPH O019A","	* logogram (shrine, row of shrines) : ꞽtr.t"},
/* 1326F */ { "EGYPTIAN HIEROGLYPH O020","	* classifier sanctuary, shrine : ꞽtr.ty"},
/* 13270 */ { "EGYPTIAN HIEROGLYPH O020A","	* variant of 1326F"},
/* 13271 */ { "EGYPTIAN HIEROGLYPH O021","	* logogram (pavilion, hall, booth) : sḥ"},
/* 13272 */ { "EGYPTIAN HIEROGLYPH O022","	* classifier booth : sḥ"},
/* 13273 */ { "EGYPTIAN HIEROGLYPH O023","	* logogram (jubilee, sed-festival) : ḥb-sd"},
/* 13274 */ { "EGYPTIAN HIEROGLYPH O024","	* classifier pyramid, tomb : mr"},
/* 13275 */ { "EGYPTIAN HIEROGLYPH O024A","	* classifier solar temple : sḫ.t-rꜥ"},
/* 13276 */ { "EGYPTIAN HIEROGLYPH O025","	* classifier obelisk : tḫn"},
/* 13277 */ { "EGYPTIAN HIEROGLYPH O025A","	* classifier solar temple : nḫn-rꜥ"},
/* 13278 */ { "EGYPTIAN HIEROGLYPH O026","	* classifier stela : wḏ"},
/* 13279 */ { "EGYPTIAN HIEROGLYPH O027","	* classifier hall, office : ḫꜣ"},
/* 1327A */ { "EGYPTIAN HIEROGLYPH O028","	* phonemogram : ꞽwn"},
/* 1327B */ { "EGYPTIAN HIEROGLYPH O029","	* phonemogram : ꜥꜣ\n"
	"	~ 1327B FE00 rotated 90 degrees\n"
	"	~ 1327B FE02 rotated 270 degrees"},
/* 1327C */ { "EGYPTIAN HIEROGLYPH O029A","	* rotated version of 1327B\n"
	"	* phonemogram : ꜥꜣ"},
/* 1327D */ { "EGYPTIAN HIEROGLYPH O030","	* not to be confused with 13361\n"
	"	* logogram (pole, support) : sḫn.t"},
/* 1327E */ { "EGYPTIAN HIEROGLYPH O030A",NULL},
/* 1327F */ { "EGYPTIAN HIEROGLYPH O031","	* logogram (gate) : ꜥꜣ\n"
	"	~ 1327F FE00 rotated 90 degrees\n"
	"	~ 1327F FE01 rotated 180 degrees"},
/* 13280 */ { "EGYPTIAN HIEROGLYPH O032","	* classifier doorway : sbꜣ"},
/* 13281 */ { "EGYPTIAN HIEROGLYPH O033","	* classifier palace façade : srḫ"},
/* 13282 */ { "EGYPTIAN HIEROGLYPH O033A","	* end of serekh enclosure\n"
	"	x (egyptian hieroglyph o006a - 13258)"},
/* 13283 */ { "EGYPTIAN HIEROGLYPH O034","	x (egyptian hieroglyph s029 - 132F4)\n"
	"	* phonemogram : s"},
/* 13284 */ { "EGYPTIAN HIEROGLYPH O035","	* phonemogram : ꞽs"},
/* 13285 */ { "EGYPTIAN HIEROGLYPH O036","	* logogram (wall) : ꞽnb\n"
	"	~ 13285 FE00 rotated 90 degrees"},
/* 13286 */ { "EGYPTIAN HIEROGLYPH O036A","	* beginning of fortified wall cartouche"},
/* 13287 */ { "EGYPTIAN HIEROGLYPH O036B","	* end of fortified wall cartouche"},
/* 13288 */ { "EGYPTIAN HIEROGLYPH O036C","	* beginning of fortified wall enclosure"},
/* 13289 */ { "EGYPTIAN HIEROGLYPH O036D","	* end of fortified wall enclosure"},
/* 1328A */ { "EGYPTIAN HIEROGLYPH O037","	* classifier overthrow, demolish : whn"},
/* 1328B */ { "EGYPTIAN HIEROGLYPH O038","	* classifier passage : ꜥrr.yt\n"
	"	~ 1328B FE01 rotated 180 degrees"},
/* 1328C */ { "EGYPTIAN HIEROGLYPH O039","	* not to be confused with 13219\n"
	"	* classifier stone, brick, pebble : mꜣṯ\n"
	"	~ 1328C FE00 rotated 90 degrees"},
/* 1328D */ { "EGYPTIAN HIEROGLYPH O040","	* logogram stairway : rwd"},
/* 1328E */ { "EGYPTIAN HIEROGLYPH O041","	* classifier ascending, being high : ḳꜣ.y"},
/* 1328F */ { "EGYPTIAN HIEROGLYPH O042","	* phonemogram : šsp"},
/* 13290 */ { "EGYPTIAN HIEROGLYPH O043","	* older variant of 1328F\n"
	"	* phonemogram : šsp"},
/* 13291 */ { "EGYPTIAN HIEROGLYPH O044","	* logogram (office, rank, function) : ꞽꜣw.t"},
/* 13292 */ { "EGYPTIAN HIEROGLYPH O045","	* logogram (harim, inner chamber) : ꞽp.t"},
/* 13293 */ { "EGYPTIAN HIEROGLYPH O046","	* logogram (harim, inner chamber) : ꞽp.t"},
/* 13294 */ { "EGYPTIAN HIEROGLYPH O047","	* logogram (Hierakonpolis) : nḫn"},
/* 13295 */ { "EGYPTIAN HIEROGLYPH O048","	* logogram (time, occasion) : sp"},
/* 13296 */ { "EGYPTIAN HIEROGLYPH O049","	* logogram (city, village) : nꞽw.t\n"
	"	~ 13296 FE03 rotated 45 degrees [= 135, 225, 315 degrees]"},
/* 13297 */ { "EGYPTIAN HIEROGLYPH O050","	* classifier treshing floor : sp.t"},
/* 13298 */ { "EGYPTIAN HIEROGLYPH O050A","	* mirrored version of 13299"},
/* 13299 */ { "EGYPTIAN HIEROGLYPH O050B","	* phono-repeater/classifier (time, occasion) : sp"},
/* 1329A */ { "EGYPTIAN HIEROGLYPH O051","	* logogram (granary) : šnw.t"},
/* 1329B */ { "EGYPTIAN HIEROGLYPH P001","	* classifier movement : ḫnt"},
/* 1329C */ { "EGYPTIAN HIEROGLYPH P001A","	* classifier to upset, to overturn : pnꜥ"},
/* 1329D */ { "EGYPTIAN HIEROGLYPH P002",NULL},
/* 1329E */ { "EGYPTIAN HIEROGLYPH P003","	* classifier bark/boat : (m)skt.t"},
/* 1329F */ { "EGYPTIAN HIEROGLYPH P003A","	* mirrored variant of 1329E"},
/* 132A0 */ { "EGYPTIAN HIEROGLYPH P004","	* logogram (to loosen, to explain) : wḥꜥ"},
/* 132A1 */ { "EGYPTIAN HIEROGLYPH P005","	* logogram (wind, breath, air) : ṯꜣw"},
/* 132A2 */ { "EGYPTIAN HIEROGLYPH P006","	* phonemogram : ꜥḥꜥ"},
/* 132A3 */ { "EGYPTIAN HIEROGLYPH P007","	* phonemogram : ꜥḥꜥ"},
/* 132A4 */ { "EGYPTIAN HIEROGLYPH P008","	* phonemogram : ḫrw\n"
	"	~ 132A4 FE01 rotated 180 degrees\n"
	"	~ 132A4 FE02 rotated 270 degrees\n"
	"	~ 132A4 FE06 rotated approximately 315 degrees"},
/* 132A5 */ { "EGYPTIAN HIEROGLYPH P009","	* phonemogram : ḫrw=f(y)"},
/* 132A6 */ { "EGYPTIAN HIEROGLYPH P010","	* logogram (steering oar) : ḥmw"},
/* 132A7 */ { "EGYPTIAN HIEROGLYPH P011","	* not to be confused with 131E9 or 1342A\n"
	"	* classifier mooring post : mnꞽ.t"},
/* 132A8 */ { "EGYPTIAN HIEROGLYPH Q001","	* logogram (seat, throne, place) : s.t"},
/* 132A9 */ { "EGYPTIAN HIEROGLYPH Q002","	* phonemogram : ws"},
/* 132AA */ { "EGYPTIAN HIEROGLYPH Q003","	* phonemogram : p\n"
	"	~ 132AA FE00 rotated 90 degrees"},
/* 132AB */ { "EGYPTIAN HIEROGLYPH Q004","	* classifier headrest : wrs"},
/* 132AC */ { "EGYPTIAN HIEROGLYPH Q005","	* classifier box : hn(w)"},
/* 132AD */ { "EGYPTIAN HIEROGLYPH Q006","	* classifier coffin : ḳrs.w"},
/* 132AE */ { "EGYPTIAN HIEROGLYPH Q007","	* classifier fire, flame, heat : sḏ.t"},
/* 132AF */ { "EGYPTIAN HIEROGLYPH R001","	* classifier altar : ḫꜣ(w).t"},
/* 132B0 */ { "EGYPTIAN HIEROGLYPH R002","	* logogram (altar) : ḫꜣw.t"},
/* 132B1 */ { "EGYPTIAN HIEROGLYPH R002A","	* logogram (altar) : ḫꜣw.t"},
/* 132B2 */ { "EGYPTIAN HIEROGLYPH R003","	* classifier festival : ḥ(ꜣ)b"},
/* 132B3 */ { "EGYPTIAN HIEROGLYPH R003A","	* classifier offering table/jar-stand : ḫnt"},
/* 132B4 */ { "EGYPTIAN HIEROGLYPH R003B",NULL},
/* 132B5 */ { "EGYPTIAN HIEROGLYPH R004","	* logogram (offering) : ḥtp"},
/* 132B6 */ { "EGYPTIAN HIEROGLYPH R005","	* classifier fumigation/censing : kꜣp"},
/* 132B7 */ { "EGYPTIAN HIEROGLYPH R006","	* logogram (to fumigate, to cense) : kꜣp"},
/* 132B8 */ { "EGYPTIAN HIEROGLYPH R007","	* logogram (incense) : snṯr"},
/* 132B9 */ { "EGYPTIAN HIEROGLYPH R008","	* logogram (god) : nṯr"},
/* 132BA */ { "EGYPTIAN HIEROGLYPH R009","	* classifier natron : ḥsmn"},
/* 132BB */ { "EGYPTIAN HIEROGLYPH R010","	* logogram (necropolis) : ẖr.t-nṯr"},
/* 132BC */ { "EGYPTIAN HIEROGLYPH R010A","	* logogram (necropolis) : ẖr.t-nṯr"},
/* 132BD */ { "EGYPTIAN HIEROGLYPH R011","	* phonemogram : ḏd"},
/* 132BE */ { "EGYPTIAN HIEROGLYPH R012","	* classifier standard : ꞽꜣ.t"},
/* 132BF */ { "EGYPTIAN HIEROGLYPH R013","	* logogram (west, right side) : ꞽmn.t"},
/* 132C0 */ { "EGYPTIAN HIEROGLYPH R014","	* logogram (west) : ꞽmn.t"},
/* 132C1 */ { "EGYPTIAN HIEROGLYPH R015","	* phonemogram : ꜣb"},
/* 132C2 */ { "EGYPTIAN HIEROGLYPH R016","	* classifier fray, battle : sk.w"},
/* 132C3 */ { "EGYPTIAN HIEROGLYPH R016A","	* logogram (Nefertem) : nfr-tm"},
/* 132C4 */ { "EGYPTIAN HIEROGLYPH R017","	* logogram (8th nome of Upper Egypt) : tꜣ-wr"},
/* 132C5 */ { "EGYPTIAN HIEROGLYPH R018","	* logogram (8th nome of Upper Egypt) : tꜣ-wr"},
/* 132C6 */ { "EGYPTIAN HIEROGLYPH R019","	* logogram (Thebes) : wꜣs.t"},
/* 132C7 */ { "EGYPTIAN HIEROGLYPH R020","	* logogram (Seshat (divinity)) : sšꜣ.t"},
/* 132C8 */ { "EGYPTIAN HIEROGLYPH R021","	* logogram (Seshat (divinity)) : sšꜣ.t"},
/* 132C9 */ { "EGYPTIAN HIEROGLYPH R022","	* logogram (Letopolis) : ḫm"},
/* 132CA */ { "EGYPTIAN HIEROGLYPH R023","	* logogram (Min (divinity)) : mnw"},
/* 132CB */ { "EGYPTIAN HIEROGLYPH R024","	* logogram (Neith (divinity)) : n.t\n"
	"	~ 132CB FE00 rotated 90 degrees"},
/* 132CC */ { "EGYPTIAN HIEROGLYPH R025","	* logogram (Neith (divinity)) : n.t"},
/* 132CD */ { "EGYPTIAN HIEROGLYPH R026","	* phonemogram : smꜣ"},
/* 132CE */ { "EGYPTIAN HIEROGLYPH R027","	* logogram (Neith (divinity)) : n.t"},
/* 132CF */ { "EGYPTIAN HIEROGLYPH R028","	* logogram (Bat (7th nome of Upper Egypt)) : bꜣ.t"},
/* 132D0 */ { "EGYPTIAN HIEROGLYPH R029","	* logogram (shrine, row of shrines) : ꞽtr.t"},
/* 132D1 */ { "EGYPTIAN HIEROGLYPH S001","	* phonemogram : ḥḏ"},
/* 132D2 */ { "EGYPTIAN HIEROGLYPH S002","	* classifier crown : wrr.t"},
/* 132D3 */ { "EGYPTIAN HIEROGLYPH S002A","	* logogram (Upper Egypt) : šmꜥ.w"},
/* 132D4 */ { "EGYPTIAN HIEROGLYPH S003","	* phonemogram : n"},
/* 132D5 */ { "EGYPTIAN HIEROGLYPH S004","	* classifier crown : n.t"},
/* 132D6 */ { "EGYPTIAN HIEROGLYPH S005","	* classifier double crown : sḫm.ty"},
/* 132D7 */ { "EGYPTIAN HIEROGLYPH S006","	* classifier double crown : sḫm.ty"},
/* 132D8 */ { "EGYPTIAN HIEROGLYPH S006A","	* logogram (Lower Egypt) : mḥ.w"},
/* 132D9 */ { "EGYPTIAN HIEROGLYPH S007","	* classifier crown : ḫprš"},
/* 132DA */ { "EGYPTIAN HIEROGLYPH S008","	* logogram (Atef crown) : ꜣtf"},
/* 132DB */ { "EGYPTIAN HIEROGLYPH S009","	* logogram (double plumes/two feather crown) : šw.ty"},
/* 132DC */ { "EGYPTIAN HIEROGLYPH S010","	* logogram (strip of cloth, fillet) : mḏḥ\n"
	"	~ 132DC FE00 rotated 90 degrees"},
/* 132DD */ { "EGYPTIAN HIEROGLYPH S011","	* logogram (necklace, collar) : wsḫ"},
/* 132DE */ { "EGYPTIAN HIEROGLYPH S012","	* logogram (gold) : nbw"},
/* 132DF */ { "EGYPTIAN HIEROGLYPH S013","	* phonemogram : nb"},
/* 132E0 */ { "EGYPTIAN HIEROGLYPH S014","	* logogram (silver) : ḥḏ"},
/* 132E1 */ { "EGYPTIAN HIEROGLYPH S014A","	* logogram (white gold, fine gold, electrum) : ḏꜥm"},
/* 132E2 */ { "EGYPTIAN HIEROGLYPH S014B",NULL},
/* 132E3 */ { "EGYPTIAN HIEROGLYPH S015","	* logogram (faience, glass) : ṯḥn.t"},
/* 132E4 */ { "EGYPTIAN HIEROGLYPH S016","	* logogram (faience, glass) : ṯḥn.t"},
/* 132E5 */ { "EGYPTIAN HIEROGLYPH S017","	* logogram (faience, glass) : ṯḥn.t"},
/* 132E6 */ { "EGYPTIAN HIEROGLYPH S017A","	* phonemogram : šsm"},
/* 132E7 */ { "EGYPTIAN HIEROGLYPH S018","	* classifier necklace : mnꞽ.t\n"
	"	~ 132E7 FE00 rotated 90 degrees\n"
	"	~ 132E7 FE02 rotated 270 degrees"},
/* 132E8 */ { "EGYPTIAN HIEROGLYPH S019","	* logogram (sealbearer) : ḫtm.w/y"},
/* 132E9 */ { "EGYPTIAN HIEROGLYPH S020","	* logogram (seal, lock, sealing) : ḫtm\n"
	"	~ 132E9 FE02 rotated 270 degrees\n"
	"	~ 132E9 FE06 rotated approximately 300 degrees"},
/* 132EA */ { "EGYPTIAN HIEROGLYPH S021","	* logogram (necklace, collar) : wsḫ"},
/* 132EB */ { "EGYPTIAN HIEROGLYPH S022","	* phonemogram : sṯ"},
/* 132EC */ { "EGYPTIAN HIEROGLYPH S023","	* logogram (to unite, to assemble) : dmḏ"},
/* 132ED */ { "EGYPTIAN HIEROGLYPH S024","	* classifier to tie, to bind : ṯs"},
/* 132EE */ { "EGYPTIAN HIEROGLYPH S025","	* classifier garment, mantle, kilt : mꜣs.t"},
/* 132EF */ { "EGYPTIAN HIEROGLYPH S026","	* classifier kilt, royal apron : šnḏ.wt"},
/* 132F0 */ { "EGYPTIAN HIEROGLYPH S026A","	* not to be confused with 13200, 133D4, or 133F3\n"
	"	* logogram (loincloth, garment) : dꜣꞽ.w"},
/* 132F1 */ { "EGYPTIAN HIEROGLYPH S026B","	* variant of 132F0"},
/* 132F2 */ { "EGYPTIAN HIEROGLYPH S027","	* logogram (clothing) : mnḫ.t"},
/* 132F3 */ { "EGYPTIAN HIEROGLYPH S028","	* classifier clothing : ḥbs"},
/* 132F4 */ { "EGYPTIAN HIEROGLYPH S029","	x (egyptian hieroglyph o034 - 13283)\n"
	"	* phonemogram : s"},
/* 132F5 */ { "EGYPTIAN HIEROGLYPH S030","	* phonemogram : sf"},
/* 132F6 */ { "EGYPTIAN HIEROGLYPH S031","	* phonemogram : smꜣ"},
/* 132F7 */ { "EGYPTIAN HIEROGLYPH S032","	* phonemogram : sꞽꜣ"},
/* 132F8 */ { "EGYPTIAN HIEROGLYPH S033","	* classifier sandal : ṯbw.t\n"
	"	~ 132F8 FE02 rotated 270 degrees"},
/* 132F9 */ { "EGYPTIAN HIEROGLYPH S034","	* logogram (life) : ꜥnḫ"},
/* 132FA */ { "EGYPTIAN HIEROGLYPH S035","	* classifier shadow, shade : mnḳb"},
/* 132FB */ { "EGYPTIAN HIEROGLYPH S035A","	* variant of 132FA"},
/* 132FC */ { "EGYPTIAN HIEROGLYPH S036","	* older variant of 132FA\n"
	"	* logogram (shadow, shade) : šw.t"},
/* 132FD */ { "EGYPTIAN HIEROGLYPH S037","	* logogram (fan) : ḫw\n"
	"	~ 132FD FE02 rotated 270 degrees"},
/* 132FE */ { "EGYPTIAN HIEROGLYPH S038","	* phonemogram : ḥḳꜣ"},
/* 132FF */ { "EGYPTIAN HIEROGLYPH S039","	* logogram (shepherd's crook) : ꜥw.t"}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_33[] = {
/* 13300 */ { "EGYPTIAN HIEROGLYPH S040","	* phonemogram : wꜣs"},
/* 13301 */ { "EGYPTIAN HIEROGLYPH S041","	* classifier sceptre : ḏꜥm"},
/* 13302 */ { "EGYPTIAN HIEROGLYPH S042","	* phonemogram : sḫm\n"
	"	~ 13302 FE02 rotated 270 degrees"},
/* 13303 */ { "EGYPTIAN HIEROGLYPH S043","	* phonemogram : md(w)\n"
	"	~ 13303 FE02 rotated 270 degrees"},
/* 13304 */ { "EGYPTIAN HIEROGLYPH S044","	* classifier staff, sceptre : ꜣsm"},
/* 13305 */ { "EGYPTIAN HIEROGLYPH S045","	* logogram (flagellum) : nḫꜣḫꜣ"},
/* 13306 */ { "EGYPTIAN HIEROGLYPH S046","	* phonemogram : k"},
/* 13307 */ { "EGYPTIAN HIEROGLYPH T001","	* phonemogram : mn\n"
	"	~ 13307 FE00 rotated 90 degrees"},
/* 13308 */ { "EGYPTIAN HIEROGLYPH T002","	* classifier striking, hitting : sḳr\n"
	"	~ 13308 FE01 rotated 180 degrees"},
/* 13309 */ { "EGYPTIAN HIEROGLYPH T003","	* phonemogram : ḥḏ"},
/* 1330A */ { "EGYPTIAN HIEROGLYPH T003A","	* phonemogram : ḥḏw"},
/* 1330B */ { "EGYPTIAN HIEROGLYPH T004","	* phonemogram : ḥḏ"},
/* 1330C */ { "EGYPTIAN HIEROGLYPH T005","	* phonemogram : ḥḏ"},
/* 1330D */ { "EGYPTIAN HIEROGLYPH T006","	* phonemogram : ḥḏḏ"},
/* 1330E */ { "EGYPTIAN HIEROGLYPH T007","	* logogram (carpenter, shipwright) : mḏḥ.w"},
/* 1330F */ { "EGYPTIAN HIEROGLYPH T007A","	* classifier axe, battle-axe : ꞽḳḥ.w"},
/* 13310 */ { "EGYPTIAN HIEROGLYPH T008","	* older variant of 13311\n"
	"	* phonemogram : tp\n"
	"	~ 13310 FE02 rotated 270 degrees"},
/* 13311 */ { "EGYPTIAN HIEROGLYPH T008A","	* phonemogram : tp\n"
	"	~ 13311 FE02 rotated 270 degrees"},
/* 13312 */ { "EGYPTIAN HIEROGLYPH T009","	* classifier bow, weapon : pḏ.t\n"
	"	~ 13312 FE01 rotated 180 degrees\n"
	"	~ 13312 FE02 rotated 270 degrees"},
/* 13313 */ { "EGYPTIAN HIEROGLYPH T009A","	* older variant of 13312\n"
	"	* phonemogram : pḏ\n"
	"	~ 13313 FE01 rotated 180 degrees\n"
	"	~ 13313 FE02 rotated 270 degrees"},
/* 13314 */ { "EGYPTIAN HIEROGLYPH T010","	* logogram (bow) : pḏ.t\n"
	"	~ 13314 FE01 rotated 180 degrees\n"
	"	~ 13314 FE02 rotated 270 degrees"},
/* 13315 */ { "EGYPTIAN HIEROGLYPH T011","	* phonemogram : swn"},
/* 13316 */ { "EGYPTIAN HIEROGLYPH T011A",NULL},
/* 13317 */ { "EGYPTIAN HIEROGLYPH T012","	* phonemogram : rwḏ"},
/* 13318 */ { "EGYPTIAN HIEROGLYPH T013","	* phono-repeater : rs"},
/* 13319 */ { "EGYPTIAN HIEROGLYPH T014","	* phono-repeater : ḳmꜣ"},
/* 1331A */ { "EGYPTIAN HIEROGLYPH T015","	* older variant of 13319\n"
	"	* phonemogram : ṯḥn"},
/* 1331B */ { "EGYPTIAN HIEROGLYPH T016","	* classifier curved blade, scimitar : ḫpš\n"
	"	~ 1331B FE00 rotated 90 degrees\n"
	"	~ 1331B FE01 rotated 180 degrees"},
/* 1331C */ { "EGYPTIAN HIEROGLYPH T016A","	* classifier strong arm, power, strength : ḫpš\n"
	"	~ 1331C FE02 rotated 270 degrees"},
/* 1331D */ { "EGYPTIAN HIEROGLYPH T017","	* logogram (chariot) : wrr.t"},
/* 1331E */ { "EGYPTIAN HIEROGLYPH T018","	* logogram (follower, retainer) : šms.w"},
/* 1331F */ { "EGYPTIAN HIEROGLYPH T019","	* classifier bone : ꜣbw"},
/* 13320 */ { "EGYPTIAN HIEROGLYPH T020","	* older variant of 1331F\n"
	"	* classifier harpoon : ḳs"},
/* 13321 */ { "EGYPTIAN HIEROGLYPH T021","	* logogram (one, sole) : wꜥ\n"
	"	~ 13321 FE01 rotated 180 degrees\n"
	"	~ 13321 FE02 rotated 270 degrees"},
/* 13322 */ { "EGYPTIAN HIEROGLYPH T022","	* phonemogram : sn\n"
	"	~ 13322 FE00 rotated 90 degrees\n"
	"	~ 13322 FE01 rotated 180 degrees"},
/* 13323 */ { "EGYPTIAN HIEROGLYPH T023","	* more recent variant of 13322\n"
	"	* phonemogram : sn"},
/* 13324 */ { "EGYPTIAN HIEROGLYPH T024","	* classifier catching, netting : ꞽ.ꜥḥ"},
/* 13325 */ { "EGYPTIAN HIEROGLYPH T025","	* phonemogram : ḏbꜣ"},
/* 13326 */ { "EGYPTIAN HIEROGLYPH T026","	* classifier catching, netting : ꞽbṯ"},
/* 13327 */ { "EGYPTIAN HIEROGLYPH T027","	* older variant of 13326\n"
	"	* classifier weaving, woven material : sḫt"},
/* 13328 */ { "EGYPTIAN HIEROGLYPH T028","	* phonemogram : ẖr"},
/* 13329 */ { "EGYPTIAN HIEROGLYPH T029","	* logogram (place of slaughter)"},
/* 1332A */ { "EGYPTIAN HIEROGLYPH T030","	* classifier cutting, slaughter : ds"},
/* 1332B */ { "EGYPTIAN HIEROGLYPH T031","	* phonemogram : sšm\n"
	"	~ 1332B FE06 rotated approximately 340 degrees [horizontal]"},
/* 1332C */ { "EGYPTIAN HIEROGLYPH T032","	* phonemogram : sšm"},
/* 1332D */ { "EGYPTIAN HIEROGLYPH T032A","	* phonemogram : sšm"},
/* 1332E */ { "EGYPTIAN HIEROGLYPH T033","	* older variant of 13326\n"
	"	* logogram (butcher) : sšm"},
/* 1332F */ { "EGYPTIAN HIEROGLYPH T033A",NULL},
/* 13330 */ { "EGYPTIAN HIEROGLYPH T034","	* classifier knife : nm"},
/* 13331 */ { "EGYPTIAN HIEROGLYPH T035","	* variant of 13330\n"
	"	* logogram (knife) : nm\n"
	"	~ 13331 FE01 rotated 180 degrees\n"
	"	~ 13331 FE02 rotated 270 degrees"},
/* 13332 */ { "EGYPTIAN HIEROGLYPH T036","	* classifier shield : ꞽkm"},
/* 13333 */ { "EGYPTIAN HIEROGLYPH U001","	* phonemogram : mꜣ"},
/* 13334 */ { "EGYPTIAN HIEROGLYPH U002","	* stylistic variant of 13333\n"
	"	* phonemogram : mꜣ"},
/* 13335 */ { "EGYPTIAN HIEROGLYPH U003","	* phonemogram (in mꜣꜣ, to see) : mꜣ"},
/* 13336 */ { "EGYPTIAN HIEROGLYPH U004","	* phonemogram : mꜣꜥ"},
/* 13337 */ { "EGYPTIAN HIEROGLYPH U005","	* stylistic variant of 13336\n"
	"	* phonemogram : mꜣꜥ"},
/* 13338 */ { "EGYPTIAN HIEROGLYPH U006","	* phonemogram : mr\n"
	"	~ 13338 FE03 rotated approximately 30 degrees\n"
	"	~ 13338 FE06 rotated approximately 320 degrees [horizontal]"},
/* 13339 */ { "EGYPTIAN HIEROGLYPH U006A","	* rotated version of 13338"},
/* 1333A */ { "EGYPTIAN HIEROGLYPH U006B","	* mirrored version of 13339"},
/* 1333B */ { "EGYPTIAN HIEROGLYPH U007","	* rotated version of 13338\n"
	"	* phonemogram : mr"},
/* 1333C */ { "EGYPTIAN HIEROGLYPH U008","	* phonemogram : ḥn\n"
	"	~ 1333C FE00 rotated 90 degrees"},
/* 1333D */ { "EGYPTIAN HIEROGLYPH U009","	* classifier grain/barley : sšr"},
/* 1333E */ { "EGYPTIAN HIEROGLYPH U010","	* logogram (harvest, crop) : šm.w"},
/* 1333F */ { "EGYPTIAN HIEROGLYPH U011","	* logogram (bushel (a corn measure, 10 hin)) : ḥḳꜣ.t"},
/* 13340 */ { "EGYPTIAN HIEROGLYPH U012","	* logogram (bushel (a corn measure, 10 hin)) : ḥḳꜣ.t"},
/* 13341 */ { "EGYPTIAN HIEROGLYPH U013","	* classifier plough/plowed material : skꜣ"},
/* 13342 */ { "EGYPTIAN HIEROGLYPH U014","	* phono-repeater : šnꜥ"},
/* 13343 */ { "EGYPTIAN HIEROGLYPH U015","	* phonemogram : tm"},
/* 13344 */ { "EGYPTIAN HIEROGLYPH U016","	* phonemogram : bꞽꜣ"},
/* 13345 */ { "EGYPTIAN HIEROGLYPH U017","	* phonemogram : grg"},
/* 13346 */ { "EGYPTIAN HIEROGLYPH U018","	* variant of 13345\n"
	"	* logogram (to found, to establish, to hunt, to lay (a trap)) : grg"},
/* 13347 */ { "EGYPTIAN HIEROGLYPH U019","	* phonemogram : nw"},
/* 13348 */ { "EGYPTIAN HIEROGLYPH U020","	* older variant of 13347\n"
	"	* phonemogram : nw"},
/* 13349 */ { "EGYPTIAN HIEROGLYPH U021","	* phonemogram : stp"},
/* 1334A */ { "EGYPTIAN HIEROGLYPH U022","	* phono-repeater : mnḫ\n"
	"	~ 1334A FE02 rotated 270 degrees"},
/* 1334B */ { "EGYPTIAN HIEROGLYPH U023","	* phonemogram : ꜣb/mr"},
/* 1334C */ { "EGYPTIAN HIEROGLYPH U023A","	* stylistic variant of 1334B\n"
	"	* phonemogram : mr"},
/* 1334D */ { "EGYPTIAN HIEROGLYPH U024","	* logogram (craftsman) : ḥmw.w"},
/* 1334E */ { "EGYPTIAN HIEROGLYPH U025","	* older variant of 1334D\n"
	"	* logogram (craft) : ḥmw.t"},
/* 1334F */ { "EGYPTIAN HIEROGLYPH U026","	* logogram (to open) : wbꜣ"},
/* 13350 */ { "EGYPTIAN HIEROGLYPH U027","	* older variant of 1334F\n"
	"	* classifier to open : wbꜣ"},
/* 13351 */ { "EGYPTIAN HIEROGLYPH U028","	* phonemogram : ḏꜣ"},
/* 13352 */ { "EGYPTIAN HIEROGLYPH U029","	* older variant of 13351\n"
	"	* phonemogram : ḏꜣ"},
/* 13353 */ { "EGYPTIAN HIEROGLYPH U029A","	* phonemogram : wḏꜣ"},
/* 13354 */ { "EGYPTIAN HIEROGLYPH U030","	* phonemogram : tꜣ"},
/* 13355 */ { "EGYPTIAN HIEROGLYPH U031","	* classifier to restrain : rtḥ"},
/* 13356 */ { "EGYPTIAN HIEROGLYPH U032","	* logogram (to pound, to crush) : sḥm"},
/* 13357 */ { "EGYPTIAN HIEROGLYPH U032A","	* phono-repeater : smn"},
/* 13358 */ { "EGYPTIAN HIEROGLYPH U033","	* phonemogram : tꞽ"},
/* 13359 */ { "EGYPTIAN HIEROGLYPH U034","	* phonemogram : ḫsf"},
/* 1335A */ { "EGYPTIAN HIEROGLYPH U035","	* phonemogram : ḫsf"},
/* 1335B */ { "EGYPTIAN HIEROGLYPH U036","	* phonemogram : ḥm"},
/* 1335C */ { "EGYPTIAN HIEROGLYPH U037","	* logogram (razor) : mẖꜥḳ.t"},
/* 1335D */ { "EGYPTIAN HIEROGLYPH U038","	* logogram (balance) : mḫꜣ.t"},
/* 1335E */ { "EGYPTIAN HIEROGLYPH U039","	* classifier balance, scale : mḫꜣ.t"},
/* 1335F */ { "EGYPTIAN HIEROGLYPH U040","	* cursive variant of 1335E\n"
	"	* phonemogram : rs"},
/* 13360 */ { "EGYPTIAN HIEROGLYPH U041","	* classifier plummet : tḫ"},
/* 13361 */ { "EGYPTIAN HIEROGLYPH U042","	* not to be confused with 1327D\n"
	"	* logogram (staff) : ms.t\n"
	"	~ 13361 FE02 rotated 270 degrees"},
/* 13362 */ { "EGYPTIAN HIEROGLYPH V001","	* classifier \"cord, rope\"\n"
	"	* not to be confused with 133F2\n"
	"	* logogram (100) : šn.t"},
/* 13363 */ { "EGYPTIAN HIEROGLYPH V001A","	* 200"},
/* 13364 */ { "EGYPTIAN HIEROGLYPH V001B","	* 300"},
/* 13365 */ { "EGYPTIAN HIEROGLYPH V001C","	* 400"},
/* 13366 */ { "EGYPTIAN HIEROGLYPH V001D","	* 500"},
/* 13367 */ { "EGYPTIAN HIEROGLYPH V001E","	* 600"},
/* 13368 */ { "EGYPTIAN HIEROGLYPH V001F","	* 700"},
/* 13369 */ { "EGYPTIAN HIEROGLYPH V001G","	* 800"},
/* 1336A */ { "EGYPTIAN HIEROGLYPH V001H","	* 900"},
/* 1336B */ { "EGYPTIAN HIEROGLYPH V001I","	* 500"},
/* 1336C */ { "EGYPTIAN HIEROGLYPH V002","	* logogram (to drag, to pull, to draw) : sṯꜣ"},
/* 1336D */ { "EGYPTIAN HIEROGLYPH V002A","	* phonemogram : stꜣ/sṯꜣ"},
/* 1336E */ { "EGYPTIAN HIEROGLYPH V003","	* phonemogram : sṯꜣ.w"},
/* 1336F */ { "EGYPTIAN HIEROGLYPH V004","	* phonemogram : wꜣ"},
/* 13370 */ { "EGYPTIAN HIEROGLYPH V005","	* logogram (foundation) : snṯ\n"
	"	~ 13370 FE06 rotated approximately 320 degrees"},
/* 13371 */ { "EGYPTIAN HIEROGLYPH V006","	* phonemogram : šs\n"
	"	~ 13371 FE06 rotated approximately 315 degrees"},
/* 13372 */ { "EGYPTIAN HIEROGLYPH V007","	* phonemogram : šn"},
/* 13373 */ { "EGYPTIAN HIEROGLYPH V007A","	* classifier cloth : ꞽꜣḳs\n"
	"	~ 13373 FE02 rotated 270 degrees"},
/* 13374 */ { "EGYPTIAN HIEROGLYPH V007B","	* phonemogram : šn"},
/* 13375 */ { "EGYPTIAN HIEROGLYPH V008","	* phonemogram : šn"},
/* 13376 */ { "EGYPTIAN HIEROGLYPH V009","	* logogram (to surround, to encircle) : šnꞽ"},
/* 13377 */ { "EGYPTIAN HIEROGLYPH V010","	* logogram (name) : rn\n"
	"	~ 13377 FE00 rotated 90 degrees"},
/* 13378 */ { "EGYPTIAN HIEROGLYPH V011","	x (egyptian hieroglyph v011d - 1342F)\n"
	"	* classifier half, part, portion : psš\n"
	"	~ 13378 FE00 rotated 90 degrees"},
/* 13379 */ { "EGYPTIAN HIEROGLYPH V011A","	* beginning of cartouche"},
/* 1337A */ { "EGYPTIAN HIEROGLYPH V011B","	* end of cartouche"},
/* 1337B */ { "EGYPTIAN HIEROGLYPH V011C","	* end of knotless cartouche"},
/* 1337C */ { "EGYPTIAN HIEROGLYPH V012","	* classifier papyrus/book/document : šꜥ.t"},
/* 1337D */ { "EGYPTIAN HIEROGLYPH V012A","	* phonemogram : dḳr\n"
	"	~ 1337D FE02 rotated 270 degrees"},
/* 1337E */ { "EGYPTIAN HIEROGLYPH V012B","	* classifier papyrus/book/document : wḏ.w-nṯr.w"},
/* 1337F */ { "EGYPTIAN HIEROGLYPH V013","	* transliterated as 1E6F\n"
	"	* phonemogram : ṯ"},
/* 13380 */ { "EGYPTIAN HIEROGLYPH V014","	* variant of 1337F\n"
	"	* phonemogram : ṯ"},
/* 13381 */ { "EGYPTIAN HIEROGLYPH V015","	* phonemogram : ꞽṯ(ꞽ)"},
/* 13382 */ { "EGYPTIAN HIEROGLYPH V016","	* phonemogram : sꜣ"},
/* 13383 */ { "EGYPTIAN HIEROGLYPH V017","	* logogram (protection) : sꜣ"},
/* 13384 */ { "EGYPTIAN HIEROGLYPH V018","	* older variant of 13383\n"
	"	* logogram (protection) : sꜣ"},
/* 13385 */ { "EGYPTIAN HIEROGLYPH V019","	* logogram (stable) : mḏ.t\n"
	"	~ 13385 FE02 rotated 270 degrees"},
/* 13386 */ { "EGYPTIAN HIEROGLYPH V020","	* not to be confused with 133AD\n"
	"	* logogram (10) : mḏ"},
/* 13387 */ { "EGYPTIAN HIEROGLYPH V020A","	* not to be confused with 133AE\n"
	"	* 20"},
/* 13388 */ { "EGYPTIAN HIEROGLYPH V020B","	* 30"},
/* 13389 */ { "EGYPTIAN HIEROGLYPH V020C","	* 40"},
/* 1338A */ { "EGYPTIAN HIEROGLYPH V020D","	* 50"},
/* 1338B */ { "EGYPTIAN HIEROGLYPH V020E","	* 60"},
/* 1338C */ { "EGYPTIAN HIEROGLYPH V020F","	* 70"},
/* 1338D */ { "EGYPTIAN HIEROGLYPH V020G","	* 80"},
/* 1338E */ { "EGYPTIAN HIEROGLYPH V020H","	* 90"},
/* 1338F */ { "EGYPTIAN HIEROGLYPH V020I","	* variant of 13387\n"
	"	* 20"},
/* 13390 */ { "EGYPTIAN HIEROGLYPH V020J","	* variant of 13388\n"
	"	* 30"},
/* 13391 */ { "EGYPTIAN HIEROGLYPH V020K","	* variant of 13389\n"
	"	* 40"},
/* 13392 */ { "EGYPTIAN HIEROGLYPH V020L","	* variant of 1338A\n"
	"	* 50"},
/* 13393 */ { "EGYPTIAN HIEROGLYPH V021","	* logogram (stable) : mḏ.t"},
/* 13394 */ { "EGYPTIAN HIEROGLYPH V022","	* phonemogram : mḥ"},
/* 13395 */ { "EGYPTIAN HIEROGLYPH V023","	* older variant of 13394\n"
	"	* phonemogram : mḥ"},
/* 13396 */ { "EGYPTIAN HIEROGLYPH V023A","	* phonemogram : mḥ"},
/* 13397 */ { "EGYPTIAN HIEROGLYPH V024","	* phonemogram : wḏ > wd"},
/* 13398 */ { "EGYPTIAN HIEROGLYPH V025","	* more recent variant of 13397\n"
	"	* phonemogram : wḏ > wd"},
/* 13399 */ { "EGYPTIAN HIEROGLYPH V026","	* phonemogram : ꜥnḏ\n"
	"	~ 13399 FE00 rotated 90 degrees"},
/* 1339A */ { "EGYPTIAN HIEROGLYPH V027","	* older variant of 13399\n"
	"	* phonemogram : ꜥnḏ\n"
	"	~ 1339A FE00 rotated 90 degrees"},
/* 1339B */ { "EGYPTIAN HIEROGLYPH V028","	* transliterated as 1E25\n"
	"	x (arabic letter hah - 062D)\n"
	"	* phonemogram : ḥ"},
/* 1339C */ { "EGYPTIAN HIEROGLYPH V028A","	* phonemogram : ḥꜥ"},
/* 1339D */ { "EGYPTIAN HIEROGLYPH V029","	* phonemogram : wꜣḥ"},
/* 1339E */ { "EGYPTIAN HIEROGLYPH V029A","	* phonemogram : sk"},
/* 1339F */ { "EGYPTIAN HIEROGLYPH V030","	* phonemogram : nb"},
/* 133A0 */ { "EGYPTIAN HIEROGLYPH V030A","	* variant of 1339F"},
/* 133A1 */ { "EGYPTIAN HIEROGLYPH V031","	x (hebrew letter kaf - 05DB)\n"
	"	x (arabic letter kaf - 0643)\n"
	"	* phonemogram : k"},
/* 133A2 */ { "EGYPTIAN HIEROGLYPH V031A","	* mirrored version of 133A1\n"
	"	* phonemogram : k"},
/* 133A3 */ { "EGYPTIAN HIEROGLYPH V032","	* phonemogram : msn"},
/* 133A4 */ { "EGYPTIAN HIEROGLYPH V033","	* classifier linen : sšr"},
/* 133A5 */ { "EGYPTIAN HIEROGLYPH V033A","	* classifier sack, bundle : ḳꜣr"},
/* 133A6 */ { "EGYPTIAN HIEROGLYPH V034","	* more recent variant of 133A4\n"
	"	* classifier (perfume) : st"},
/* 133A7 */ { "EGYPTIAN HIEROGLYPH V035","	* logogram (linen) : sšr"},
/* 133A8 */ { "EGYPTIAN HIEROGLYPH V036","	* phonemogram : ḥn"},
/* 133A9 */ { "EGYPTIAN HIEROGLYPH V037","	* phono-repeater : ꞽdr"},
/* 133AA */ { "EGYPTIAN HIEROGLYPH V037A","	* phonemogram : ꞽd"},
/* 133AB */ { "EGYPTIAN HIEROGLYPH V038","	* not to be confused with 1308B\n"
	"	* classifier to bandage, to wrap : wt"},
/* 133AC */ { "EGYPTIAN HIEROGLYPH V039","	* logogram (Tit-amulet) : tꞽ.t"},
/* 133AD */ { "EGYPTIAN HIEROGLYPH V040","	* not to be confused with 13386\n"
	"	* 10"},
/* 133AE */ { "EGYPTIAN HIEROGLYPH V040A","	* not to be confused with 13387\n"
	"	* 20"},
/* 133AF */ { "EGYPTIAN HIEROGLYPH W001","	* classifier oil, unguent : mrḥ.t\n"
	"	~ 133AF FE02 rotated 270 degrees"},
/* 133B0 */ { "EGYPTIAN HIEROGLYPH W002","	* phonemogram : bꜣs\n"
	"	~ 133B0 FE02 rotated 270 degrees"},
/* 133B1 */ { "EGYPTIAN HIEROGLYPH W003","	* logogram (festival) : ḥ(ꜣ)b"},
/* 133B2 */ { "EGYPTIAN HIEROGLYPH W003A","	* variant of 133B1"},
/* 133B3 */ { "EGYPTIAN HIEROGLYPH W004","	* logogram (festival) : h(ꜣ)b"},
/* 133B4 */ { "EGYPTIAN HIEROGLYPH W005","	* logogram (lector priest) : ẖr.y-ḥ(ꜣ)b.t"},
/* 133B5 */ { "EGYPTIAN HIEROGLYPH W006","	* classifier cauldron : ḥw.t"},
/* 133B6 */ { "EGYPTIAN HIEROGLYPH W007","	* classifier granite : mꜣṯ"},
/* 133B7 */ { "EGYPTIAN HIEROGLYPH W008","	* phono-repeater : ꜣb"},
/* 133B8 */ { "EGYPTIAN HIEROGLYPH W009","	* phonemogram : ẖnm"},
/* 133B9 */ { "EGYPTIAN HIEROGLYPH W009A","	* mirrored version of 133B8"},
/* 133BA */ { "EGYPTIAN HIEROGLYPH W010","	* phonemogram : ꜥ"},
/* 133BB */ { "EGYPTIAN HIEROGLYPH W010A","	* phonemogram : bꜣ"},
/* 133BC */ { "EGYPTIAN HIEROGLYPH W011","	* phonemogram : g"},
/* 133BD */ { "EGYPTIAN HIEROGLYPH W012","	* older variant of 133BC\n"
	"	* phonemogram : g"},
/* 133BE */ { "EGYPTIAN HIEROGLYPH W013","	* classifier red (earthenware) vessel : dšr.t"},
/* 133BF */ { "EGYPTIAN HIEROGLYPH W014","	* phonemogram : ḥs\n"
	"	~ 133BF FE02 rotated 270 degrees"},
/* 133C0 */ { "EGYPTIAN HIEROGLYPH W014A",NULL},
/* 133C1 */ { "EGYPTIAN HIEROGLYPH W015","	* logogram (to be cool, to cool) : ḳbḥ"},
/* 133C2 */ { "EGYPTIAN HIEROGLYPH W016","	* classifier libation water : ḳbḥ"},
/* 133C3 */ { "EGYPTIAN HIEROGLYPH W017","	* phonemogram : ḫnt"},
/* 133C4 */ { "EGYPTIAN HIEROGLYPH W017A","	* cursive variant of 133C3\n"
	"	* phonemogram : ḫnt"},
/* 133C5 */ { "EGYPTIAN HIEROGLYPH W018","	* older variant of 133C3\n"
	"	* phonemogram : ḫnt"},
/* 133C6 */ { "EGYPTIAN HIEROGLYPH W018A","	* cursive variant of 133C5"},
/* 133C7 */ { "EGYPTIAN HIEROGLYPH W019","	* phonemogram : mꞽ"},
/* 133C8 */ { "EGYPTIAN HIEROGLYPH W020","	* classifier milk : ꞽrṯ.t"},
/* 133C9 */ { "EGYPTIAN HIEROGLYPH W021","	* classifier wine : ꞽrp"},
/* 133CA */ { "EGYPTIAN HIEROGLYPH W022","	* logogram (beer) : ḥnḳ.t"},
/* 133CB */ { "EGYPTIAN HIEROGLYPH W023","	* logogram (beer) : ḥnḳ.t"},
/* 133CC */ { "EGYPTIAN HIEROGLYPH W024","	* phonemogram : nw"},
/* 133CD */ { "EGYPTIAN HIEROGLYPH W024A","	* monogram 'nw(n)' or 'nww'"},
/* 133CE */ { "EGYPTIAN HIEROGLYPH W025","	* phonemogram : ꞽn(ꞽ)"},
/* 133CF */ { "EGYPTIAN HIEROGLYPH X001","	* phonemogram : t"},
/* 133D0 */ { "EGYPTIAN HIEROGLYPH X002","	* logogram (bread) : t"},
/* 133D1 */ { "EGYPTIAN HIEROGLYPH X003","	* variant of 133D0\n"
	"	* classifier bread/food"},
/* 133D2 */ { "EGYPTIAN HIEROGLYPH X004","	* classifier festival"},
/* 133D3 */ { "EGYPTIAN HIEROGLYPH X004A","	* variant of 133D2\n"
	"	* phonemogram : t\n"
	"	~ 133D3 FE00 rotated 90 degrees"},
/* 133D4 */ { "EGYPTIAN HIEROGLYPH X004B","	* variant of 133D2\n"
	"	* not to be confused with 13200, 132F0, or 133F3\n"
	"	* classifier bread, festival; Phonemogram t; Logogram t (bread); Phono-repeater: sn, fḳꜣ : t | sn, fḳꜣ"},
/* 133D5 */ { "EGYPTIAN HIEROGLYPH X005","	* hieratic\n"
	"	* variant of 133D4\n"
	"	* phono-repeater : sn"},
/* 133D6 */ { "EGYPTIAN HIEROGLYPH X006","	* classifier offering, cake, loaf : t-ꜣsr"},
/* 133D7 */ { "EGYPTIAN HIEROGLYPH X006A","	* variant of 133D6"},
/* 133D8 */ { "EGYPTIAN HIEROGLYPH X007","	* not to be confused with 1320E\n"
	"	* classifier food : gs"},
/* 133D9 */ { "EGYPTIAN HIEROGLYPH X008","	* phonemogram : ḏꞽ > dꞽ"},
/* 133DA */ { "EGYPTIAN HIEROGLYPH X008A","	* variant of 133D9\n"
	"	* not to be confused with 131EE\n"
	"	* classifier bread : t-ḥḏ"},
/* 133DB */ { "EGYPTIAN HIEROGLYPH Y001","	* classifier abstract words : sspd.w\n"
	"	~ 133DB FE02 rotated 270 degrees"},
/* 133DC */ { "EGYPTIAN HIEROGLYPH Y001A","	* rotated version of 133DB\n"
	"	* logogram (papyrus scroll, book) : mḏꜣ.t"},
/* 133DD */ { "EGYPTIAN HIEROGLYPH Y002","	* older variant of 133DB\n"
	"	* classifier writing, things written : mdw\n"
	"	~ 133DD FE02 rotated 270 degrees"},
/* 133DE */ { "EGYPTIAN HIEROGLYPH Y003","	* logogram (scribe) : sš"},
/* 133DF */ { "EGYPTIAN HIEROGLYPH Y004","	* mirrored version of 133DE\n"
	"	* logogram (scribe) : sš"},
/* 133E0 */ { "EGYPTIAN HIEROGLYPH Y005","	* phonemogram : mn"},
/* 133E1 */ { "EGYPTIAN HIEROGLYPH Y006","	* classifier game, gamepiece : sn.t"},
/* 133E2 */ { "EGYPTIAN HIEROGLYPH Y007","	* classifier harp : bn.t"},
/* 133E3 */ { "EGYPTIAN HIEROGLYPH Y008","	* classifier sistrum : sḫm"},
/* 133E4 */ { "EGYPTIAN HIEROGLYPH Z001","	* not to be confused with 133FA\n"
	"	* classifier semogram\n"
	"	~ 133E4 FE00 rotated 90 degrees [= 270 degrees]"},
/* 133E5 */ { "EGYPTIAN HIEROGLYPH Z002","	* not to be confused with 133FC\n"
	"	* classifier plural\n"
	"	~ 133E5 FE00 rotated 90 degrees [= 270 degrees]"},
/* 133E6 */ { "EGYPTIAN HIEROGLYPH Z002A","	* stylistic variant of 133E5"},
/* 133E7 */ { "EGYPTIAN HIEROGLYPH Z002B","	* not to be confused with 13213\n"
	"	~ 133E7 FE00 rotated 90 degrees [= 270 degrees]"},
/* 133E8 */ { "EGYPTIAN HIEROGLYPH Z002C","	* variant of 133E6\n"
	"	* classifier plural\n"
	"	~ 133E8 FE01 rotated 180 degrees"},
/* 133E9 */ { "EGYPTIAN HIEROGLYPH Z002D","	* rotated version of 133E8\n"
	"	* classifier plural"},
/* 133EA */ { "EGYPTIAN HIEROGLYPH Z003","	* variant of 133E5\n"
	"	* classifier plural"},
/* 133EB */ { "EGYPTIAN HIEROGLYPH Z003A","	* rotated version of 133E5\n"
	"	* classifier plural"},
/* 133EC */ { "EGYPTIAN HIEROGLYPH Z003B","	* rotated version of 133E7"},
/* 133ED */ { "EGYPTIAN HIEROGLYPH Z004","	* classifier 'dual'\n"
	"	x (egyptian hieroglyph m017a - 131CC)\n"
	"	* phonemogram : y"},
/* 133EE */ { "EGYPTIAN HIEROGLYPH Z004A","	* not to be confused with 133FB\n"
	"	* logogram (two) : sn.w\n"
	"	~ 133EE FE00 rotated 90 degrees [= 270 degrees]"},
/* 133EF */ { "EGYPTIAN HIEROGLYPH Z005","	* substitute for dangerous signs"},
/* 133F0 */ { "EGYPTIAN HIEROGLYPH Z005A","	* variant of 133EF\n"
	"	* classifier divinity (replacing G7)"},
/* 133F1 */ { "EGYPTIAN HIEROGLYPH Z006","	* classifier death : ḫp.t"},
/* 133F2 */ { "EGYPTIAN HIEROGLYPH Z007","	* not to be confused with 13362\n"
	"	* phonemogram : w\n"
	"	~ 133F2 FE00 rotated 90 degrees"},
/* 133F3 */ { "EGYPTIAN HIEROGLYPH Z008","	* not to be confused with 13200, 132F0, or 133D4\n"
	"	* classifier round, oval : šn(.w)"},
/* 133F4 */ { "EGYPTIAN HIEROGLYPH Z009","	* classifier divide : psš"},
/* 133F5 */ { "EGYPTIAN HIEROGLYPH Z010","	* older variant of 133F4\n"
	"	* classifier break : ḥbs\n"
	"	~ 133F5 FE00 rotated 90 degrees"},
/* 133F6 */ { "EGYPTIAN HIEROGLYPH Z011","	* phonemogram : ꞽm\n"
	"	~ 133F6 FE00 rotated 90 degrees"},
/* 133F7 */ { "EGYPTIAN HIEROGLYPH Z012","	* hieratic\n"
	"	* phonemogram : ḥw"},
/* 133F8 */ { "EGYPTIAN HIEROGLYPH Z013","	* circle, unmarked round sign\n"
	"	* not to be confused with 13082 or 131F3"},
/* 133F9 */ { "EGYPTIAN HIEROGLYPH Z014","	* hieratic\n"
	"	* classifier semogram"},
/* 133FA */ { "EGYPTIAN HIEROGLYPH Z015","	* not to be confused with 133E4\n"
	"	* logogram (one, sole) : wꜥ"},
/* 133FB */ { "EGYPTIAN HIEROGLYPH Z015A","	* not to be confused with 133EE\n"
	"	* logogram (two) : sn.w"},
/* 133FC */ { "EGYPTIAN HIEROGLYPH Z015B","	* not to be confused with 133E5\n"
	"	x (egyptian hieroglyph z003 - 133EA)\n"
	"	* logogram (three) : ḫmt"},
/* 133FD */ { "EGYPTIAN HIEROGLYPH Z015C","	* logogram (four) : fd(.w)"},
/* 133FE */ { "EGYPTIAN HIEROGLYPH Z015D","	* logogram (five) : dꞽw"},
/* 133FF */ { "EGYPTIAN HIEROGLYPH Z015E","	* logogram (six) : sꞽs"}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_34[] = {
/* 13400 */ { "EGYPTIAN HIEROGLYPH Z015F","	* logogram (seven) : sfḫ"},
/* 13401 */ { "EGYPTIAN HIEROGLYPH Z015G","	* logogram (eight) : ḫmn"},
/* 13402 */ { "EGYPTIAN HIEROGLYPH Z015H","	* logogram (nine) : psḏ"},
/* 13403 */ { "EGYPTIAN HIEROGLYPH Z015I","	* variant of 133FE\n"
	"	* logogram (five) : dꞽw"},
/* 13404 */ { "EGYPTIAN HIEROGLYPH Z016","	* logogram (one, sole) : wꜥ"},
/* 13405 */ { "EGYPTIAN HIEROGLYPH Z016A","	* logogram (two) : sn.w"},
/* 13406 */ { "EGYPTIAN HIEROGLYPH Z016B","	* logogram (three) : ḫmt"},
/* 13407 */ { "EGYPTIAN HIEROGLYPH Z016C","	* logogram (four) : fd(.w)"},
/* 13408 */ { "EGYPTIAN HIEROGLYPH Z016D","	* logogram (five) : dꞽw"},
/* 13409 */ { "EGYPTIAN HIEROGLYPH Z016E","	* logogram (six) : sꞽs"},
/* 1340A */ { "EGYPTIAN HIEROGLYPH Z016F","	* logogram (seven) : sfḫ"},
/* 1340B */ { "EGYPTIAN HIEROGLYPH Z016G","	* logogram ḫmn (eight)/Logogram ḫmnw (Hermopolis) : ḫmn & ḫmnw"},
/* 1340C */ { "EGYPTIAN HIEROGLYPH Z016H","	* logogram (nine) : psḏ"},
/* 1340D */ { "EGYPTIAN HIEROGLYPH AA001","	* transliterated as 1E2B\n"
	"	x (arabic letter khah - 062E)\n"
	"	* phonemogram : ḫ\n"
	"	~ 1340D FE04 rotated approximately 135 degrees [= 315 degrees]"},
/* 1340E */ { "EGYPTIAN HIEROGLYPH AA002","	* classifier bad/evil : nḥꜣ"},
/* 1340F */ { "EGYPTIAN HIEROGLYPH AA003","	* classifier efflux, smell (i.e., excrement) : ḥs"},
/* 13410 */ { "EGYPTIAN HIEROGLYPH AA004","	* phonemogram : bꜣ"},
/* 13411 */ { "EGYPTIAN HIEROGLYPH AA005","	* classifier oar : ḥpt"},
/* 13412 */ { "EGYPTIAN HIEROGLYPH AA006","	* phono-repeater : ṯmꜣ"},
/* 13413 */ { "EGYPTIAN HIEROGLYPH AA007","	* classifier to present : sḳ(r)"},
/* 13414 */ { "EGYPTIAN HIEROGLYPH AA007A","	* mirrored version of 13413\n"
	"	* classifier to present : sḳ(r)"},
/* 13415 */ { "EGYPTIAN HIEROGLYPH AA007B",NULL},
/* 13416 */ { "EGYPTIAN HIEROGLYPH AA008","	* logogram (nome, district) : spꜣ.t\n"
	"	~ 13416 FE00 rotated 90 degrees"},
/* 13417 */ { "EGYPTIAN HIEROGLYPH AA009","	* classifier suffering : wḫd"},
/* 13418 */ { "EGYPTIAN HIEROGLYPH AA010","	* classifier writing : drf"},
/* 13419 */ { "EGYPTIAN HIEROGLYPH AA011","	* phonemogram : mꜣꜥ\n"
	"	~ 13419 FE00 rotated 90 degrees\n"
	"	~ 13419 FE01 rotated 180 degrees\n"
	"	~ 13419 FE02 rotated 270 degrees\n"
	"	~ 13419 FE03 rotated approximately 15 degrees\n"
	"	~ 13419 FE06 rotated approximately 345 degrees"},
/* 1341A */ { "EGYPTIAN HIEROGLYPH AA012","	* older variant of 13419\n"
	"	* phonemogram : mꜣꜥ\n"
	"	~ 1341A FE00 rotated 90 degrees"},
/* 1341B */ { "EGYPTIAN HIEROGLYPH AA013","	* phonemogram : gs"},
/* 1341C */ { "EGYPTIAN HIEROGLYPH AA014","	* older variant of 1341B\n"
	"	* logogram (side, half) : gs"},
/* 1341D */ { "EGYPTIAN HIEROGLYPH AA015","	* phonemogram : m"},
/* 1341E */ { "EGYPTIAN HIEROGLYPH AA016","	* variant of 1341D\n"
	"	* logogram (side, half) : gs"},
/* 1341F */ { "EGYPTIAN HIEROGLYPH AA017","	* phonemogram : sꜣ"},
/* 13420 */ { "EGYPTIAN HIEROGLYPH AA018","	* more recent variant of 1341F\n"
	"	* phonemogram : s"},
/* 13421 */ { "EGYPTIAN HIEROGLYPH AA019","	* classifier shrine, chapel"},
/* 13422 */ { "EGYPTIAN HIEROGLYPH AA020","	* phonemogram : ꜥpr"},
/* 13423 */ { "EGYPTIAN HIEROGLYPH AA021","	* logogram (to judge, to separate) : wḏꜥ\n"
	"	~ 13423 FE00 rotated 90 degrees"},
/* 13424 */ { "EGYPTIAN HIEROGLYPH AA022","	* logogram (to judge, to separate) : wḏꜥ"},
/* 13425 */ { "EGYPTIAN HIEROGLYPH AA023","	* logogram (to press, to cling (to)) : mḏd"},
/* 13426 */ { "EGYPTIAN HIEROGLYPH AA024","	* older variant of 13425\n"
	"	* logogram (to press, to cling (to)) : mḏd"},
/* 13427 */ { "EGYPTIAN HIEROGLYPH AA025","	* phonemogram : smꜣ"},
/* 13428 */ { "EGYPTIAN HIEROGLYPH AA026","	* phonemogram : sbꞽ"},
/* 13429 */ { "EGYPTIAN HIEROGLYPH AA027","	* phonemogram : nḏ"},
/* 1342A */ { "EGYPTIAN HIEROGLYPH AA028","	* not to be confused with 131E9 and 132A7\n"
	"	* phonemogram : ḳd"},
/* 1342B */ { "EGYPTIAN HIEROGLYPH AA029","	* older variant of 1342A\n"
	"	* phonemogram : ḳd"},
/* 1342C */ { "EGYPTIAN HIEROGLYPH AA030","	* logogram (ornament) : ẖkr\n"
	"	~ 1342C FE02 rotated 270 degrees"},
/* 1342D */ { "EGYPTIAN HIEROGLYPH AA031","	* older variant of 1342C\n"
	"	* logogram (ornament) : ẖkr"},
/* 1342E */ { "EGYPTIAN HIEROGLYPH AA032","	* logogram (Nubia) : sty\n"
	"	~ 1342E FE02 rotated 270 degrees"},
/* 1342F */ { "EGYPTIAN HIEROGLYPH V011D","	* knotted beginning of cartouche\n"
	"	* not to be confused with 13378"},
/* 13430 */ { "EGYPTIAN HIEROGLYPH VERTICAL JOINER","	= sign separator: subordination (Manuel de Codage)"},
/* 13431 */ { "EGYPTIAN HIEROGLYPH HORIZONTAL JOINER","	= sign separator: juxtaposition (Manuel de Codage)"},
/* 13432 */ { "EGYPTIAN HIEROGLYPH INSERT AT TOP START",NULL},
/* 13433 */ { "EGYPTIAN HIEROGLYPH INSERT AT BOTTOM START",NULL},
/* 13434 */ { "EGYPTIAN HIEROGLYPH INSERT AT TOP END",NULL},
/* 13435 */ { "EGYPTIAN HIEROGLYPH INSERT AT BOTTOM END",NULL},
/* 13436 */ { "EGYPTIAN HIEROGLYPH OVERLAY MIDDLE",NULL},
/* 13437 */ { "EGYPTIAN HIEROGLYPH BEGIN SEGMENT",NULL},
/* 13438 */ { "EGYPTIAN HIEROGLYPH END SEGMENT",NULL},
/* 13439 */ { "EGYPTIAN HIEROGLYPH INSERT AT MIDDLE",NULL},
/* 1343A */ { "EGYPTIAN HIEROGLYPH INSERT AT TOP",NULL},
/* 1343B */ { "EGYPTIAN HIEROGLYPH INSERT AT BOTTOM",NULL},
/* 1343C */ { "EGYPTIAN HIEROGLYPH BEGIN ENCLOSURE",NULL},
/* 1343D */ { "EGYPTIAN HIEROGLYPH END ENCLOSURE",NULL},
/* 1343E */ { "EGYPTIAN HIEROGLYPH BEGIN WALLED ENCLOSURE",NULL},
/* 1343F */ { "EGYPTIAN HIEROGLYPH END WALLED ENCLOSURE",NULL},
/* 13440 */ { "EGYPTIAN HIEROGLYPH MIRROR HORIZONTALLY",NULL},
/* 13441 */ { "EGYPTIAN HIEROGLYPH FULL BLANK",NULL},
/* 13442 */ { "EGYPTIAN HIEROGLYPH HALF BLANK",NULL},
/* 13443 */ { "EGYPTIAN HIEROGLYPH LOST SIGN","	~ 13443 FE00 expanded "},
/* 13444 */ { "EGYPTIAN HIEROGLYPH HALF LOST SIGN","	~ 13444 FE00 expanded "},
/* 13445 */ { "EGYPTIAN HIEROGLYPH TALL LOST SIGN","	~ 13445 FE00 expanded "},
/* 13446 */ { "EGYPTIAN HIEROGLYPH WIDE LOST SIGN","	~ 13446 FE00 expanded "},
/* 13447 */ { "EGYPTIAN HIEROGLYPH MODIFIER DAMAGED AT TOP START",NULL},
/* 13448 */ { "EGYPTIAN HIEROGLYPH MODIFIER DAMAGED AT BOTTOM START",NULL},
/* 13449 */ { "EGYPTIAN HIEROGLYPH MODIFIER DAMAGED AT START",NULL},
/* 1344A */ { "EGYPTIAN HIEROGLYPH MODIFIER DAMAGED AT TOP END",NULL},
/* 1344B */ { "EGYPTIAN HIEROGLYPH MODIFIER DAMAGED AT TOP",NULL},
/* 1344C */ { "EGYPTIAN HIEROGLYPH MODIFIER DAMAGED AT BOTTOM START AND TOP END",NULL},
/* 1344D */ { "EGYPTIAN HIEROGLYPH MODIFIER DAMAGED AT START AND TOP",NULL},
/* 1344E */ { "EGYPTIAN HIEROGLYPH MODIFIER DAMAGED AT BOTTOM END",NULL},
/* 1344F */ { "EGYPTIAN HIEROGLYPH MODIFIER DAMAGED AT TOP START AND BOTTOM END",NULL},
/* 13450 */ { "EGYPTIAN HIEROGLYPH MODIFIER DAMAGED AT BOTTOM",NULL},
/* 13451 */ { "EGYPTIAN HIEROGLYPH MODIFIER DAMAGED AT START AND BOTTOM",NULL},
/* 13452 */ { "EGYPTIAN HIEROGLYPH MODIFIER DAMAGED AT END",NULL},
/* 13453 */ { "EGYPTIAN HIEROGLYPH MODIFIER DAMAGED AT TOP AND END",NULL},
/* 13454 */ { "EGYPTIAN HIEROGLYPH MODIFIER DAMAGED AT BOTTOM AND END",NULL},
/* 13455 */ { "EGYPTIAN HIEROGLYPH MODIFIER DAMAGED",NULL},
/* 13456 */ { NULL,NULL},
/* 13457 */ { NULL,NULL},
/* 13458 */ { NULL,NULL},
/* 13459 */ { NULL,NULL},
/* 1345A */ { NULL,NULL},
/* 1345B */ { NULL,NULL},
/* 1345C */ { NULL,NULL},
/* 1345D */ { NULL,NULL},
/* 1345E */ { NULL,NULL},
/* 1345F */ { NULL,NULL},
/* 13460 */ { "EGYPTIAN HIEROGLYPH-13460","	* classifier human being"},
/* 13461 */ { "EGYPTIAN HIEROGLYPH-13461","	* classifier human being : rmn.w"},
/* 13462 */ { "EGYPTIAN HIEROGLYPH-13462","	* logogram (first person singular) : ꞽ"},
/* 13463 */ { "EGYPTIAN HIEROGLYPH-13463","	* classifier human being : wnn.yw"},
/* 13464 */ { "EGYPTIAN HIEROGLYPH-13464","	* classifier court, entourage : šny.t"},
/* 13465 */ { "EGYPTIAN HIEROGLYPH-13465","	* classifier occupation/relationship (fisherman or brewer) : ḏbḥ(.w) | dbḥ"},
/* 13466 */ { "EGYPTIAN HIEROGLYPH-13466","	* classifier to conspire, to brood : wꜣ"},
/* 13467 */ { "EGYPTIAN HIEROGLYPH-13467","	* classifier personal name"},
/* 13468 */ { "EGYPTIAN HIEROGLYPH-13468","	* logogram (enemies) : ḫft.yw"},
/* 13469 */ { "EGYPTIAN HIEROGLYPH-13469","	* classifier human being (poor man) : šwꜣ.w "},
/* 1346A */ { "EGYPTIAN HIEROGLYPH-1346A","	* classifier human being : ḥnmm.t?"},
/* 1346B */ { "EGYPTIAN HIEROGLYPH-1346B","	* logogram (vocative interjection) : ꞽ "},
/* 1346C */ { "EGYPTIAN HIEROGLYPH-1346C","	* logogram (first person singular) : ꞽ"},
/* 1346D */ { "EGYPTIAN HIEROGLYPH-1346D","	* classifier sitting : ḥ(m)sꞽ"},
/* 1346E */ { "EGYPTIAN HIEROGLYPH-1346E",NULL},
/* 1346F */ { "EGYPTIAN HIEROGLYPH-1346F","	* classifier eating/drinking/speech/ silence/thoughts feelings"},
/* 13470 */ { "EGYPTIAN HIEROGLYPH-13470","	* classifier speech/sound : ṯḥḥ.wt"},
/* 13471 */ { "EGYPTIAN HIEROGLYPH-13471","	* classifier speech/silence : dbḥ"},
/* 13472 */ { "EGYPTIAN HIEROGLYPH-13472","	* classifier acclaim, speaking : nhm"},
/* 13473 */ { "EGYPTIAN HIEROGLYPH-13473","	* classifier speech/silence : ḏd"},
/* 13474 */ { "EGYPTIAN HIEROGLYPH-13474","	* classifier sitting/weak/faint"},
/* 13475 */ { "EGYPTIAN HIEROGLYPH-13475",NULL},
/* 13476 */ { "EGYPTIAN HIEROGLYPH-13476","	* logogram (praise, worship) : dwꜣ"},
/* 13477 */ { "EGYPTIAN HIEROGLYPH-13477","	* classifier adoration : ꞽꜣw.t"},
/* 13478 */ { "EGYPTIAN HIEROGLYPH-13478","	* classifier supplication/hiding/rejection"},
/* 13479 */ { "EGYPTIAN HIEROGLYPH-13479","	* classifier harpooner/priest : msn.ty"},
/* 1347A */ { "EGYPTIAN HIEROGLYPH-1347A","	* classifier reverence : ḥfꜣ"},
/* 1347B */ { "EGYPTIAN HIEROGLYPH-1347B","	* classifier enemies : twꜣ.w"},
/* 1347C */ { "EGYPTIAN HIEROGLYPH-1347C","	* classifier prisoner : sḳr-ꜥnḫ"},
/* 1347D */ { "EGYPTIAN HIEROGLYPH-1347D","	* classifier human being/personal name"},
/* 1347E */ { "EGYPTIAN HIEROGLYPH-1347E","	* classifier joy : hnw"},
/* 1347F */ { "EGYPTIAN HIEROGLYPH-1347F","	* logogram (joy) : hnw"},
/* 13480 */ { "EGYPTIAN HIEROGLYPH-13480","	* classifier making music : ḫnw"},
/* 13481 */ { "EGYPTIAN HIEROGLYPH-13481","	* classifier joy : hnw"},
/* 13482 */ { "EGYPTIAN HIEROGLYPH-13482","	* classifier joy : hnw"},
/* 13483 */ { "EGYPTIAN HIEROGLYPH-13483","	* classifier human being"},
/* 13484 */ { "EGYPTIAN HIEROGLYPH-13484","	* classifier human being : ꞽt"},
/* 13485 */ { "EGYPTIAN HIEROGLYPH-13485","	* logogram (musician) : ḥs.w"},
/* 13486 */ { "EGYPTIAN HIEROGLYPH-13486","	* classifier bald : ꞽꜣs"},
/* 13487 */ { "EGYPTIAN HIEROGLYPH-13487","	* classifier music : ꞽḥy"},
/* 13488 */ { "EGYPTIAN HIEROGLYPH-13488",NULL},
/* 13489 */ { "EGYPTIAN HIEROGLYPH-13489","	* classifier to totter : mss"},
/* 1348A */ { "EGYPTIAN HIEROGLYPH-1348A","	* classifier foreigner (Nubian) : nḥs.y"},
/* 1348B */ { "EGYPTIAN HIEROGLYPH-1348B","	* logogram (to fraternize) : snsn"},
/* 1348C */ { "EGYPTIAN HIEROGLYPH-1348C","	* logogram (to fraternize) : snsn "},
/* 1348D */ { "EGYPTIAN HIEROGLYPH-1348D","	* classifier deserter/wanderer : tš"},
/* 1348E */ { "EGYPTIAN HIEROGLYPH-1348E","	* classifier to wrestle : ḳmꜣ"},
/* 1348F */ { "EGYPTIAN HIEROGLYPH-1348F","	* classifier to defecate : fgn"},
/* 13490 */ { "EGYPTIAN HIEROGLYPH-13490","	* classifier to be short : ḥwꜥ"},
/* 13491 */ { "EGYPTIAN HIEROGLYPH-13491","	* logogram (to pour, to drain) : stꞽ"},
/* 13492 */ { "EGYPTIAN HIEROGLYPH-13492","	* classifier (the cold one) : ḥs.w"},
/* 13493 */ { "EGYPTIAN HIEROGLYPH-13493","	* phonemogram : ꞽn"},
/* 13494 */ { "EGYPTIAN HIEROGLYPH-13494","	* classifier old man : kḥkḥ"},
/* 13495 */ { "EGYPTIAN HIEROGLYPH-13495",NULL},
/* 13496 */ { "EGYPTIAN HIEROGLYPH-13496","	* classifier hair related : ꞽꜣs"},
/* 13497 */ { "EGYPTIAN HIEROGLYPH-13497",NULL},
/* 13498 */ { "EGYPTIAN HIEROGLYPH-13498","	* phonemogram : ꜥnt"},
/* 13499 */ { "EGYPTIAN HIEROGLYPH-13499","	* logogram (myrrh) : ꜥnt.yw"},
/* 1349A */ { "EGYPTIAN HIEROGLYPH-1349A","	* classifier official, noble : sr"},
/* 1349B */ { "EGYPTIAN HIEROGLYPH-1349B","	* classifier vocative interjection : ꞽ"},
/* 1349C */ { "EGYPTIAN HIEROGLYPH-1349C","	* logogram (to bend) : ḳꜥḥ"},
/* 1349D */ { "EGYPTIAN HIEROGLYPH-1349D","	* classifier attacker : tkk"},
/* 1349E */ { "EGYPTIAN HIEROGLYPH-1349E","	* classifier lifting/carrying : ṯsꞽ"},
/* 1349F */ { "EGYPTIAN HIEROGLYPH-1349F",NULL},
/* 134A0 */ { "EGYPTIAN HIEROGLYPH-134A0",NULL},
/* 134A1 */ { "EGYPTIAN HIEROGLYPH-134A1","	* classifier bowing : ksw"},
/* 134A2 */ { "EGYPTIAN HIEROGLYPH-134A2","	* logogram (sem-priest)? : sm"},
/* 134A3 */ { "EGYPTIAN HIEROGLYPH-134A3","	* classifier bald : ꞽꜣs"},
/* 134A4 */ { "EGYPTIAN HIEROGLYPH-134A4","	* classifier bald : ꞽꜣs"},
/* 134A5 */ { "EGYPTIAN HIEROGLYPH-134A5","	* classifier adoration : ꞽꜣw"},
/* 134A6 */ { "EGYPTIAN HIEROGLYPH-134A6",NULL},
/* 134A7 */ { "EGYPTIAN HIEROGLYPH-134A7","	* classifier leaping, bounding : špw"},
/* 134A8 */ { "EGYPTIAN HIEROGLYPH-134A8","	* classifier bowing : ksw"},
/* 134A9 */ { "EGYPTIAN HIEROGLYPH-134A9",NULL},
/* 134AA */ { "EGYPTIAN HIEROGLYPH-134AA","	* classifier bowing : ḫꜣb"},
/* 134AB */ { "EGYPTIAN HIEROGLYPH-134AB","	* logogram (kissing the land) : sn-tꜣ"},
/* 134AC */ { "EGYPTIAN HIEROGLYPH-134AC","	* classifier to twist : sps"},
/* 134AD */ { "EGYPTIAN HIEROGLYPH-134AD","	* phonemogram : ḳꞽs"},
/* 134AE */ { "EGYPTIAN HIEROGLYPH-134AE",NULL},
/* 134AF */ { "EGYPTIAN HIEROGLYPH-134AF","	* logogram (bowing down) : ḫꜣb/ksw "},
/* 134B0 */ { "EGYPTIAN HIEROGLYPH-134B0","	* classifier falling : sḫr"},
/* 134B1 */ { "EGYPTIAN HIEROGLYPH-134B1","	* logogram (to overthrow, to cast down) : sḫr"},
/* 134B2 */ { "EGYPTIAN HIEROGLYPH-134B2","	* classifier enemy : mmty"},
/* 134B3 */ { "EGYPTIAN HIEROGLYPH-134B3","	* classifier bowing/lowering to the ground"},
/* 134B4 */ { "EGYPTIAN HIEROGLYPH-134B4",NULL},
/* 134B5 */ { "EGYPTIAN HIEROGLYPH-134B5","	* logogram (kissing the land) : sn-tꜣ"},
/* 134B6 */ { "EGYPTIAN HIEROGLYPH-134B6","	* logogram (kissing the land) : sn-tꜣ"},
/* 134B7 */ { "EGYPTIAN HIEROGLYPH-134B7",NULL},
/* 134B8 */ { "EGYPTIAN HIEROGLYPH-134B8","	* classifier bowing, lowering to the ground : ksꞽ"},
/* 134B9 */ { "EGYPTIAN HIEROGLYPH-134B9","	* classifier corpse : ẖꜣ.t"},
/* 134BA */ { "EGYPTIAN HIEROGLYPH-134BA","	* classifier to overthrow : hdb"},
/* 134BB */ { "EGYPTIAN HIEROGLYPH-134BB","	* classifier corpse"},
/* 134BC */ { "EGYPTIAN HIEROGLYPH-134BC","	* classifier to sleep/to awaken : sḏr, sṯs"},
/* 134BD */ { "EGYPTIAN HIEROGLYPH-134BD","	* classifier lying on one side : sḏr"},
/* 134BE */ { "EGYPTIAN HIEROGLYPH-134BE",NULL},
/* 134BF */ { "EGYPTIAN HIEROGLYPH-134BF","	* classifier swimming : mḥꞽ"},
/* 134C0 */ { "EGYPTIAN HIEROGLYPH-134C0","	* phonemogram : nb"},
/* 134C1 */ { "EGYPTIAN HIEROGLYPH-134C1","	* classifier swimming : nbꞽ"},
/* 134C2 */ { "EGYPTIAN HIEROGLYPH-134C2",NULL},
/* 134C3 */ { "EGYPTIAN HIEROGLYPH-134C3","	* phonemogram : nb"},
/* 134C4 */ { "EGYPTIAN HIEROGLYPH-134C4","	* phonemogram : nb"},
/* 134C5 */ { "EGYPTIAN HIEROGLYPH-134C5","	* classifier swimming : nbꞽ"},
/* 134C6 */ { "EGYPTIAN HIEROGLYPH-134C6","	* logogram (official, noble) : sr"},
/* 134C7 */ { "EGYPTIAN HIEROGLYPH-134C7","	* logogram (9th nome of Lower Egypt) : ꜥnḏ.ty"},
/* 134C8 */ { "EGYPTIAN HIEROGLYPH-134C8","	* classifier statue : twt"},
/* 134C9 */ { "EGYPTIAN HIEROGLYPH-134C9","	* logogram (elder) : wr"},
/* 134CA */ { "EGYPTIAN HIEROGLYPH-134CA","	* logogram (elder (in ḥr-wr, Haroeris)) : wr"},
/* 134CB */ { "EGYPTIAN HIEROGLYPH-134CB","	* classifier sovereign : ꞽt.y"},
/* 134CC */ { "EGYPTIAN HIEROGLYPH-134CC",NULL},
/* 134CD */ { "EGYPTIAN HIEROGLYPH-134CD","	* classifier wisdom : sbḳ"},
/* 134CE */ { "EGYPTIAN HIEROGLYPH-134CE","	* logogram (elder of the court) : sms.w-hꜣy.t"},
/* 134CF */ { "EGYPTIAN HIEROGLYPH-134CF","	* classifier statue : twt"},
/* 134D0 */ { "EGYPTIAN HIEROGLYPH-134D0","	* classifier to cut down"},
/* 134D1 */ { "EGYPTIAN HIEROGLYPH-134D1","	* logogram (great) : wr"},
/* 134D2 */ { "EGYPTIAN HIEROGLYPH-134D2","	* logogram (great one, chief) : wr"},
/* 134D3 */ { "EGYPTIAN HIEROGLYPH-134D3","	* logogram (great one, chief) : wr"},
/* 134D4 */ { "EGYPTIAN HIEROGLYPH-134D4","	* logogram (great) : wr"},
/* 134D5 */ { "EGYPTIAN HIEROGLYPH-134D5",NULL},
/* 134D6 */ { "EGYPTIAN HIEROGLYPH-134D6","	* logogram (great one, chief) : wr"},
/* 134D7 */ { "EGYPTIAN HIEROGLYPH-134D7","	* classifier noble : sr"},
/* 134D8 */ { "EGYPTIAN HIEROGLYPH-134D8","	* classifier Orion : sꜣḥ"},
/* 134D9 */ { "EGYPTIAN HIEROGLYPH-134D9","	* logogram (son/child of) : sꜣ"},
/* 134DA */ { "EGYPTIAN HIEROGLYPH-134DA","	* classifier lector priest : ẖr.y-ḥb.t ḥr.y-tp"},
/* 134DB */ { "EGYPTIAN HIEROGLYPH-134DB","	* logogram (humankind, patricians) : pꜥ.t"},
/* 134DC */ { "EGYPTIAN HIEROGLYPH-134DC","	* logogram (humankind, patricians) : pꜥ.t"},
/* 134DD */ { "EGYPTIAN HIEROGLYPH-134DD","	* logogram (to drink) : swr"},
/* 134DE */ { "EGYPTIAN HIEROGLYPH-134DE","	* classifier swallowing : sꜥm"},
/* 134DF */ { "EGYPTIAN HIEROGLYPH-134DF","	* logogram (to drink) : swr"},
/* 134E0 */ { "EGYPTIAN HIEROGLYPH-134E0","	* classifier drinking : swr"},
/* 134E1 */ { "EGYPTIAN HIEROGLYPH-134E1","	* classifier lifting/carrying : fꜣꞽ"},
/* 134E2 */ { "EGYPTIAN HIEROGLYPH-134E2","	* classifier lifting/carrying : fꜣꞽ"},
/* 134E3 */ { "EGYPTIAN HIEROGLYPH-134E3","	* classifier lifting/carrying : fꜣꞽ"},
/* 134E4 */ { "EGYPTIAN HIEROGLYPH-134E4","	* pictogram kneeling making offering"},
/* 134E5 */ { "EGYPTIAN HIEROGLYPH-134E5","	* classifier work : kꜣ.t"},
/* 134E6 */ { "EGYPTIAN HIEROGLYPH-134E6","	* classifier work : kꜣ.t"},
/* 134E7 */ { "EGYPTIAN HIEROGLYPH-134E7","	* phonemogram : f"},
/* 134E8 */ { "EGYPTIAN HIEROGLYPH-134E8","	* classifier work : kꜣ.t"},
/* 134E9 */ { "EGYPTIAN HIEROGLYPH-134E9","	* classifier work : kꜣ.t"},
/* 134EA */ { "EGYPTIAN HIEROGLYPH-134EA","	* logogram (to lift, to carry) : fꜣꞽ"},
/* 134EB */ { "EGYPTIAN HIEROGLYPH-134EB","	* logogram (to lift, to carry) : fꜣꞽ"},
/* 134EC */ { "EGYPTIAN HIEROGLYPH-134EC","	* logogram (to lift the arm) : fꜣꞽ-ꜥ"},
/* 134ED */ { "EGYPTIAN HIEROGLYPH-134ED","	* logogram (Heh (divinity)) : ḥḥ"},
/* 134EE */ { "EGYPTIAN HIEROGLYPH-134EE","	* logogram (to suppport, to raise) : twꜣ"},
/* 134EF */ { "EGYPTIAN HIEROGLYPH-134EF","	* classifier to hold up, to support (in the title ꜥḫ-p.t) : ꜥḫ"},
/* 134F0 */ { "EGYPTIAN HIEROGLYPH-134F0","	* classifier vocative interjection"},
/* 134F1 */ { "EGYPTIAN HIEROGLYPH-134F1","	* phonemogram (in snm.t, the island Biga) : snm"},
/* 134F2 */ { "EGYPTIAN HIEROGLYPH-134F2","	* phonemogram : ꞽwn"},
/* 134F3 */ { "EGYPTIAN HIEROGLYPH-134F3","	* phonemogram/logogram (his heart) : ꞽb=f"},
/* 134F4 */ { "EGYPTIAN HIEROGLYPH-134F4","	* classifier people : rḫ.yt"},
/* 134F5 */ { "EGYPTIAN HIEROGLYPH-134F5",NULL},
/* 134F6 */ { "EGYPTIAN HIEROGLYPH-134F6","	* logogram (farmer/gardener) : ꞽb(w)"},
/* 134F7 */ { "EGYPTIAN HIEROGLYPH-134F7","	* phonemogram (from fꜣꞽ ḥr) : ḥr=f"},
/* 134F8 */ { "EGYPTIAN HIEROGLYPH-134F8","	* classifier reaping : šꜥ"},
/* 134F9 */ { "EGYPTIAN HIEROGLYPH-134F9","	* classifier lector priest : ẖr.y-ḥb.t"},
/* 134FA */ { "EGYPTIAN HIEROGLYPH-134FA","	* phonemogram : nn"},
/* 134FB */ { "EGYPTIAN HIEROGLYPH-134FB","	* logogram (his name) : rn=f"},
/* 134FC */ { "EGYPTIAN HIEROGLYPH-134FC","	* phonemogram : f"},
/* 134FD */ { "EGYPTIAN HIEROGLYPH-134FD","	* logogram (to lift, to carry) : fꜣꞽ"},
/* 134FE */ { "EGYPTIAN HIEROGLYPH-134FE","	* classifier to lift, to carry : fꜣꞽ"},
/* 134FF */ { "EGYPTIAN HIEROGLYPH-134FF","	* logogram (work) : kꜣ.t"}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_35[] = {
/* 13500 */ { "EGYPTIAN HIEROGLYPH-13500","	* phonemogram : f"},
/* 13501 */ { "EGYPTIAN HIEROGLYPH-13501","	* logogram (to raise up offerings) : fꜣꞽ-(ꞽ)ḫ.t"},
/* 13502 */ { "EGYPTIAN HIEROGLYPH-13502","	* logogram (to raise up offerings) : fꜣꞽ-(ꞽ)ḫ.t"},
/* 13503 */ { "EGYPTIAN HIEROGLYPH-13503",NULL},
/* 13504 */ { "EGYPTIAN HIEROGLYPH-13504","	* logogram (to suppport/to raise the sky) : twꜣ-p.t"},
/* 13505 */ { "EGYPTIAN HIEROGLYPH-13505","	* phonemogram : f"},
/* 13506 */ { "EGYPTIAN HIEROGLYPH-13506",NULL},
/* 13507 */ { "EGYPTIAN HIEROGLYPH-13507","	* phonemogram : f"},
/* 13508 */ { "EGYPTIAN HIEROGLYPH-13508","	* phonemogram : f"},
/* 13509 */ { "EGYPTIAN HIEROGLYPH-13509",NULL},
/* 1350A */ { "EGYPTIAN HIEROGLYPH-1350A","	* classifier offering : ḫnp"},
/* 1350B */ { "EGYPTIAN HIEROGLYPH-1350B","	* logogram (to bring) : ꞽnꞽ"},
/* 1350C */ { "EGYPTIAN HIEROGLYPH-1350C","	* logogram (to bring) : ꞽnꞽ"},
/* 1350D */ { "EGYPTIAN HIEROGLYPH-1350D","	* classifier force/effort : nḏr/smꜣ"},
/* 1350E */ { "EGYPTIAN HIEROGLYPH-1350E","	* classifier force/effort : nḫt"},
/* 1350F */ { "EGYPTIAN HIEROGLYPH-1350F","	* classifier death : mt"},
/* 13510 */ { "EGYPTIAN HIEROGLYPH-13510","	* logogram (pure, clean) : wꜥb"},
/* 13511 */ { "EGYPTIAN HIEROGLYPH-13511","	* logogram (pure, clean) : wꜥb"},
/* 13512 */ { "EGYPTIAN HIEROGLYPH-13512","	* logogram (pure, clean) : wꜥb"},
/* 13513 */ { "EGYPTIAN HIEROGLYPH-13513","	* logogram (wab-priest) : wꜥb"},
/* 13514 */ { "EGYPTIAN HIEROGLYPH-13514","	* logogram (wab-priest) : wꜥb"},
/* 13515 */ { "EGYPTIAN HIEROGLYPH-13515",NULL},
/* 13516 */ { "EGYPTIAN HIEROGLYPH-13516","	* classifier to libate : sṯ"},
/* 13517 */ { "EGYPTIAN HIEROGLYPH-13517","	* logogram (pure, clean) : wꜥb"},
/* 13518 */ { "EGYPTIAN HIEROGLYPH-13518","	* logogram (pure, clean) : wꜥb"},
/* 13519 */ { "EGYPTIAN HIEROGLYPH-13519","	* logogram (to be pure, to be clean) : wꜥb"},
/* 1351A */ { "EGYPTIAN HIEROGLYPH-1351A","	* logogram (pure, clean) : wꜥb"},
/* 1351B */ { "EGYPTIAN HIEROGLYPH-1351B",NULL},
/* 1351C */ { "EGYPTIAN HIEROGLYPH-1351C","	* logogram (wab-priest) : wꜥb"},
/* 1351D */ { "EGYPTIAN HIEROGLYPH-1351D","	* logogram (pure, clean) : wꜥb"},
/* 1351E */ { "EGYPTIAN HIEROGLYPH-1351E","	* logogram (pure, clean) : wꜥb"},
/* 1351F */ { "EGYPTIAN HIEROGLYPH-1351F","	* classifier pouring : stꞽ"},
/* 13520 */ { "EGYPTIAN HIEROGLYPH-13520","	* classifier pouring : stꞽ"},
/* 13521 */ { "EGYPTIAN HIEROGLYPH-13521",NULL},
/* 13522 */ { "EGYPTIAN HIEROGLYPH-13522","	* logogram (to pour) : stꞽ"},
/* 13523 */ { "EGYPTIAN HIEROGLYPH-13523","	* logogram (to libate)? : ḳbḥ"},
/* 13524 */ { "EGYPTIAN HIEROGLYPH-13524","	* classifier greeting : nꞽnꞽ"},
/* 13525 */ { "EGYPTIAN HIEROGLYPH-13525","	* classifier to sprinkle, to scatter : ntš"},
/* 13526 */ { "EGYPTIAN HIEROGLYPH-13526","	* logogram (to sprinkle, to scatter) : stꞽ"},
/* 13527 */ { "EGYPTIAN HIEROGLYPH-13527","	* logogram (to hide) : ꞽmn"},
/* 13528 */ { "EGYPTIAN HIEROGLYPH-13528","	* classifier hiding/hidden : ꞽmn"},
/* 13529 */ { "EGYPTIAN HIEROGLYPH-13529","	* classifier hiding/hidden : ꞽmn"},
/* 1352A */ { "EGYPTIAN HIEROGLYPH-1352A","	* logogram (to hide) : ꞽmn"},
/* 1352B */ { "EGYPTIAN HIEROGLYPH-1352B","	* classifier melting/casting : nb"},
/* 1352C */ { "EGYPTIAN HIEROGLYPH-1352C","	* logogram (overseer of the deserts) : ꞽm.y-r-s.t"},
/* 1352D */ { "EGYPTIAN HIEROGLYPH-1352D","	* classifier grinding : nḏ"},
/* 1352E */ { "EGYPTIAN HIEROGLYPH-1352E","	* classifier grinding : nḏ"},
/* 1352F */ { "EGYPTIAN HIEROGLYPH-1352F","	* classifier (to measure) : ḫꜣꞽ"},
/* 13530 */ { "EGYPTIAN HIEROGLYPH-13530","	* classifier reaping/harvesting : ꜣsḫ"},
/* 13531 */ { "EGYPTIAN HIEROGLYPH-13531","	* logogram (to drive in the mooring post) : ḥwꞽ-mnꞽ.t"},
/* 13532 */ { "EGYPTIAN HIEROGLYPH-13532",NULL},
/* 13533 */ { "EGYPTIAN HIEROGLYPH-13533","	* logogram (to pound, to build) : ḫwsꞽ"},
/* 13534 */ { "EGYPTIAN HIEROGLYPH-13534","	* logogram (to pound, to build) : ḫwsꞽ"},
/* 13535 */ { "EGYPTIAN HIEROGLYPH-13535","	* logogram (to build) : ḳd"},
/* 13536 */ { "EGYPTIAN HIEROGLYPH-13536","	* logogram (to build) : ḳd"},
/* 13537 */ { "EGYPTIAN HIEROGLYPH-13537","	* classifier building/constructing : sꞽp"},
/* 13538 */ { "EGYPTIAN HIEROGLYPH-13538","	* classifier building/constructing : ẖnm"},
/* 13539 */ { "EGYPTIAN HIEROGLYPH-13539","	* classifier building/constructing : sps"},
/* 1353A */ { "EGYPTIAN HIEROGLYPH-1353A","	* logogram (to create, to shape) : nḥp"},
/* 1353B */ { "EGYPTIAN HIEROGLYPH-1353B","	* classifier to create, to shape : nḥp"},
/* 1353C */ { "EGYPTIAN HIEROGLYPH-1353C","	* classifier to create : ḳd"},
/* 1353D */ { "EGYPTIAN HIEROGLYPH-1353D","	* classifier to create : ḳd"},
/* 1353E */ { "EGYPTIAN HIEROGLYPH-1353E","	* logogram (to sieve, to press) : ꜥtḫ"},
/* 1353F */ { "EGYPTIAN HIEROGLYPH-1353F","	* logogram (brewer) : ꜥf.ty"},
/* 13540 */ { "EGYPTIAN HIEROGLYPH-13540","	* classifier pot-stand/sideboard : ḫnt"},
/* 13541 */ { "EGYPTIAN HIEROGLYPH-13541","	* classifier to punt/pole (a boat) : wdꞽ"},
/* 13542 */ { "EGYPTIAN HIEROGLYPH-13542","	* uncertain, classifier?"},
/* 13543 */ { "EGYPTIAN HIEROGLYPH-13543","	* logogram (builders) : ḳd.w"},
/* 13544 */ { "EGYPTIAN HIEROGLYPH-13544",NULL},
/* 13545 */ { "EGYPTIAN HIEROGLYPH-13545",NULL},
/* 13546 */ { "EGYPTIAN HIEROGLYPH-13546","	* uncertain (in sꜣ.w (domain), and in an offering list after ḥnḳ.t)"},
/* 13547 */ { "EGYPTIAN HIEROGLYPH-13547","	* classifier to open (a scroll) : pg(ꜣ)"},
/* 13548 */ { "EGYPTIAN HIEROGLYPH-13548","	* logogram (scribe) : sš"},
/* 13549 */ { "EGYPTIAN HIEROGLYPH-13549","	* classifier occupation : bꜣk"},
/* 1354A */ { "EGYPTIAN HIEROGLYPH-1354A",NULL},
/* 1354B */ { "EGYPTIAN HIEROGLYPH-1354B","	* logogram (to strike) : ḥwꞽ"},
/* 1354C */ { "EGYPTIAN HIEROGLYPH-1354C","	* logogram (to bend down) : wꜥf"},
/* 1354D */ { "EGYPTIAN HIEROGLYPH-1354D","	* logogram (slaughtered oryx) : mꜣ-ḥḏ sfṯ"},
/* 1354E */ { "EGYPTIAN HIEROGLYPH-1354E","	* logogram (to guard) : sꜣw"},
/* 1354F */ { "EGYPTIAN HIEROGLYPH-1354F","	* logogram (herdsman) : mnꞽ.w"},
/* 13550 */ { "EGYPTIAN HIEROGLYPH-13550","	* classifier herdsman : nr"},
/* 13551 */ { "EGYPTIAN HIEROGLYPH-13551","	* classifier foreigner (Asiatic) : ꜥꜣm"},
/* 13552 */ { "EGYPTIAN HIEROGLYPH-13552","	* logogram (relating to, belonging to) : ꞽr.y"},
/* 13553 */ { "EGYPTIAN HIEROGLYPH-13553","	* logogram (to guard) : sꜣw"},
/* 13554 */ { "EGYPTIAN HIEROGLYPH-13554","	* logogram (foreigner) : rwty"},
/* 13555 */ { "EGYPTIAN HIEROGLYPH-13555","	* logogram (to guard) : sꜣw"},
/* 13556 */ { "EGYPTIAN HIEROGLYPH-13556","	* logogram (to guard) : sꜣw"},
/* 13557 */ { "EGYPTIAN HIEROGLYPH-13557","	* logogram (to guard) : sꜣw"},
/* 13558 */ { "EGYPTIAN HIEROGLYPH-13558","	* logogram (to guard) : sꜣw"},
/* 13559 */ { "EGYPTIAN HIEROGLYPH-13559","	* logogram (to guard) : sꜣw"},
/* 1355A */ { "EGYPTIAN HIEROGLYPH-1355A","	* logogram (to guard) : sꜣw"},
/* 1355B */ { "EGYPTIAN HIEROGLYPH-1355B","	* logogram (to guard) : sꜣw"},
/* 1355C */ { "EGYPTIAN HIEROGLYPH-1355C","	* logogram (relating to, belonging to) : ꞽr.y"},
/* 1355D */ { "EGYPTIAN HIEROGLYPH-1355D","	* classifier foreigner"},
/* 1355E */ { "EGYPTIAN HIEROGLYPH-1355E","	* classifier enslave : bꜣk"},
/* 1355F */ { "EGYPTIAN HIEROGLYPH-1355F","	* uncertain"},
/* 13560 */ { "EGYPTIAN HIEROGLYPH-13560","	* classifier bow-people, nomads : ꞽwn.tyw"},
/* 13561 */ { "EGYPTIAN HIEROGLYPH-13561","	* classifier bow-people, nomads : ꞽwn.tyw"},
/* 13562 */ { "EGYPTIAN HIEROGLYPH-13562","	* classifier foreigner : fnḫ.w"},
/* 13563 */ { "EGYPTIAN HIEROGLYPH-13563","	* classifier wandering/displaced : šmꜣ.y"},
/* 13564 */ { "EGYPTIAN HIEROGLYPH-13564","	* logogram (herdsman) : mnꞽ.w"},
/* 13565 */ { "EGYPTIAN HIEROGLYPH-13565","	* logogram (herdsman) : mnꞽ.w"},
/* 13566 */ { "EGYPTIAN HIEROGLYPH-13566","	* logogram (wanderer, displaced) : šmꜣ.y"},
/* 13567 */ { "EGYPTIAN HIEROGLYPH-13567","	* logogram (prospector) : smn.ty"},
/* 13568 */ { "EGYPTIAN HIEROGLYPH-13568","	* logogram (herdsman) : mnꞽ.w"},
/* 13569 */ { "EGYPTIAN HIEROGLYPH-13569","	* logogram (herdsman) : mnꞽ.w"},
/* 1356A */ { "EGYPTIAN HIEROGLYPH-1356A",NULL},
/* 1356B */ { "EGYPTIAN HIEROGLYPH-1356B","	* logogram (elder) : smsw"},
/* 1356C */ { "EGYPTIAN HIEROGLYPH-1356C","	* classifier elder : smsw"},
/* 1356D */ { "EGYPTIAN HIEROGLYPH-1356D",NULL},
/* 1356E */ { "EGYPTIAN HIEROGLYPH-1356E","	* logogram (to protect) : ḥmꜣg"},
/* 1356F */ { "EGYPTIAN HIEROGLYPH-1356F","	* logogram (to erect) : sꜥḥꜥ"},
/* 13570 */ { "EGYPTIAN HIEROGLYPH-13570","	* logogram (to erect the djed pillar) : sꜥḥꜥ-ḏd"},
/* 13571 */ { "EGYPTIAN HIEROGLYPH-13571","	* classifier erecting the djed pillar (group classifier for sꜥḥꜥ-ḏd-ꞽn-ꞽr.yw-ḫt-n(y)-sw.t) : sꜥḥꜥ-ḏd-ꞽn-ꞽr.yw-ḫt-n(y)-sw.t"},
/* 13572 */ { "EGYPTIAN HIEROGLYPH-13572","	* classifier erecting : sꜥḥꜥ"},
/* 13573 */ { "EGYPTIAN HIEROGLYPH-13573","	* logogram (elder) : smsw"},
/* 13574 */ { "EGYPTIAN HIEROGLYPH-13574","	* logogram (to be old) : sms"},
/* 13575 */ { "EGYPTIAN HIEROGLYPH-13575","	* logogram (myrrh) : ꜥnt.yw"},
/* 13576 */ { "EGYPTIAN HIEROGLYPH-13576","	* classifier divinity : ꞽwn-mw.t=f"},
/* 13577 */ { "EGYPTIAN HIEROGLYPH-13577","	* logogram (sem-priest) : sm"},
/* 13578 */ { "EGYPTIAN HIEROGLYPH-13578","	* logogram (to be strong) : nḫt"},
/* 13579 */ { "EGYPTIAN HIEROGLYPH-13579","	* logogram (Onuris) : ꞽn-ḥr.t"},
/* 1357A */ { "EGYPTIAN HIEROGLYPH-1357A","	* logogram (Onuris) : ꞽn-ḥr.t"},
/* 1357B */ { "EGYPTIAN HIEROGLYPH-1357B",NULL},
/* 1357C */ { "EGYPTIAN HIEROGLYPH-1357C","	* logogram (prospector) : smn.ty"},
/* 1357D */ { "EGYPTIAN HIEROGLYPH-1357D",NULL},
/* 1357E */ { "EGYPTIAN HIEROGLYPH-1357E","	* logogram (the one who opens the two doors of the sky) : wn-ꜥꜣ.wy-(n.w)-p.t"},
/* 1357F */ { "EGYPTIAN HIEROGLYPH-1357F","	* logogram (gatekeeper) : ꞽr.y-ꜥꜣ"},
/* 13580 */ { "EGYPTIAN HIEROGLYPH-13580","	* phonemogram : m kꜣ"},
/* 13581 */ { "EGYPTIAN HIEROGLYPH-13581",NULL},
/* 13582 */ { "EGYPTIAN HIEROGLYPH-13582","	* logogram (to protect) : mkꞽ"},
/* 13583 */ { "EGYPTIAN HIEROGLYPH-13583","	* logogram (to raise the sail) : fꜣꞽ-ṯꜣw"},
/* 13584 */ { "EGYPTIAN HIEROGLYPH-13584","	* classifier presenting : sfsf"},
/* 13585 */ { "EGYPTIAN HIEROGLYPH-13585","	* logogram (to bring) : ꞽnꞽ"},
/* 13586 */ { "EGYPTIAN HIEROGLYPH-13586","	* logogram (lord of the two lands) : nb-tꜣ.wy"},
/* 13587 */ { "EGYPTIAN HIEROGLYPH-13587","	* classifier to spread : p(s)š"},
/* 13588 */ { "EGYPTIAN HIEROGLYPH-13588","	* phono-repeater : fd"},
/* 13589 */ { "EGYPTIAN HIEROGLYPH-13589","	* classifier to uproot : fdꞽ"},
/* 1358A */ { "EGYPTIAN HIEROGLYPH-1358A","	* phonemogram : ḫꜣ"},
/* 1358B */ { "EGYPTIAN HIEROGLYPH-1358B","	* phonemogram : ḫꜣ-dꞽ.t"},
/* 1358C */ { "EGYPTIAN HIEROGLYPH-1358C","	* phonemogram : ḫꜣ-dꞽ.t"},
/* 1358D */ { "EGYPTIAN HIEROGLYPH-1358D","	* logogram (to illuminate) : nms"},
/* 1358E */ { "EGYPTIAN HIEROGLYPH-1358E","	* logogram (army) : mšꜥ"},
/* 1358F */ { "EGYPTIAN HIEROGLYPH-1358F","	* classifier angry one : dndn.ty"},
/* 13590 */ { "EGYPTIAN HIEROGLYPH-13590","	* logogram (messenger/killer) : hb.y"},
/* 13591 */ { "EGYPTIAN HIEROGLYPH-13591","	* classifier driving away : sḥrꞽ"},
/* 13592 */ { "EGYPTIAN HIEROGLYPH-13592","	* classifier slayer : ḫꜣbb"},
/* 13593 */ { "EGYPTIAN HIEROGLYPH-13593","	* classifier (harpooner) : ꞽꜣwty"},
/* 13594 */ { "EGYPTIAN HIEROGLYPH-13594","	* classifier driving away : sḥrꞽ"},
/* 13595 */ { "EGYPTIAN HIEROGLYPH-13595","	* classifier dancing : ꞽbꜣ"},
/* 13596 */ { "EGYPTIAN HIEROGLYPH-13596","	* logogram (to be strong) : nḫt"},
/* 13597 */ { "EGYPTIAN HIEROGLYPH-13597","	* classifier battle : mnꜥ"},
/* 13598 */ { "EGYPTIAN HIEROGLYPH-13598","	* classifier ?"},
/* 13599 */ { "EGYPTIAN HIEROGLYPH-13599","	* logogram (to be strong) : nḫt"},
/* 1359A */ { "EGYPTIAN HIEROGLYPH-1359A",NULL},
/* 1359B */ { "EGYPTIAN HIEROGLYPH-1359B",NULL},
/* 1359C */ { "EGYPTIAN HIEROGLYPH-1359C","	* classifier army : mšꜥ"},
/* 1359D */ { "EGYPTIAN HIEROGLYPH-1359D","	* classifier foreigner : šrdn"},
/* 1359E */ { "EGYPTIAN HIEROGLYPH-1359E","	* classifier hiding/hidden : ꞽmn"},
/* 1359F */ { "EGYPTIAN HIEROGLYPH-1359F","	* classifier hiding/hidden : ꞽmn"},
/* 135A0 */ { "EGYPTIAN HIEROGLYPH-135A0",NULL},
/* 135A1 */ { "EGYPTIAN HIEROGLYPH-135A1","	* classifier runner (foreign) : pḥrr"},
/* 135A2 */ { "EGYPTIAN HIEROGLYPH-135A2","	* classifier army (semitic loanword) : ḏbꞽ"},
/* 135A3 */ { "EGYPTIAN HIEROGLYPH-135A3",NULL},
/* 135A4 */ { "EGYPTIAN HIEROGLYPH-135A4","	* classifier to trample : tꞽtꞽ"},
/* 135A5 */ { "EGYPTIAN HIEROGLYPH-135A5","	* logogram (army) : mšꜥ"},
/* 135A6 */ { "EGYPTIAN HIEROGLYPH-135A6","	* classifier soldiery : mnf.yt"},
/* 135A7 */ { "EGYPTIAN HIEROGLYPH-135A7","	* logogram (army) : mšꜥ"},
/* 135A8 */ { "EGYPTIAN HIEROGLYPH-135A8","	* logogram (army)? : mšꜥ"},
/* 135A9 */ { "EGYPTIAN HIEROGLYPH-135A9","	* logogram (army)? : mšꜥ"},
/* 135AA */ { "EGYPTIAN HIEROGLYPH-135AA","	* logogram (army) : mšꜥ"},
/* 135AB */ { "EGYPTIAN HIEROGLYPH-135AB","	* logogram (1st nome of Upper Egypt) : tꜣ-sṯy"},
/* 135AC */ { "EGYPTIAN HIEROGLYPH-135AC","	* logogram (army) : mšꜥ"},
/* 135AD */ { "EGYPTIAN HIEROGLYPH-135AD","	* logogram (army)? : mšꜥ"},
/* 135AE */ { "EGYPTIAN HIEROGLYPH-135AE",NULL},
/* 135AF */ { "EGYPTIAN HIEROGLYPH-135AF","	* classifier rebel/enemy "},
/* 135B0 */ { "EGYPTIAN HIEROGLYPH-135B0","	* classifier rebel : ẖꜥk-ꞽb"},
/* 135B1 */ { "EGYPTIAN HIEROGLYPH-135B1","	* classifier enemy?"},
/* 135B2 */ { "EGYPTIAN HIEROGLYPH-135B2","	* classifier enemy : snn.t"},
/* 135B3 */ { "EGYPTIAN HIEROGLYPH-135B3","	* classifier enemy : twꜣ.t"},
/* 135B4 */ { "EGYPTIAN HIEROGLYPH-135B4","	* classifier rebel : sbꞽ"},
/* 135B5 */ { "EGYPTIAN HIEROGLYPH-135B5","	* logogram (chiefs) : wr "},
/* 135B6 */ { "EGYPTIAN HIEROGLYPH-135B6","	* classifier Syrian : ḫr.y"},
/* 135B7 */ { "EGYPTIAN HIEROGLYPH-135B7","	* classifier enemy/rebel (Xerxes) : ḫšryš "},
/* 135B8 */ { "EGYPTIAN HIEROGLYPH-135B8","	* classifier evil one : nbḏ"},
/* 135B9 */ { "EGYPTIAN HIEROGLYPH-135B9","	* classifier enemy/rebel (Xerxes) : ḫšryš"},
/* 135BA */ { "EGYPTIAN HIEROGLYPH-135BA","	* classifier rebel : sbꞽ"},
/* 135BB */ { "EGYPTIAN HIEROGLYPH-135BB","	* classifier enemy : ṯs.tyw"},
/* 135BC */ { "EGYPTIAN HIEROGLYPH-135BC","	* logogram (rebel) : sbꞽ"},
/* 135BD */ { "EGYPTIAN HIEROGLYPH-135BD",NULL},
/* 135BE */ { "EGYPTIAN HIEROGLYPH-135BE","	* logogram (rebel) : sbꞽ"},
/* 135BF */ { "EGYPTIAN HIEROGLYPH-135BF","	* logogram (rebel) : sbꞽ"},
/* 135C0 */ { "EGYPTIAN HIEROGLYPH-135C0",NULL},
/* 135C1 */ { "EGYPTIAN HIEROGLYPH-135C1","	* classifier rebel : sbꞽ"},
/* 135C2 */ { "EGYPTIAN HIEROGLYPH-135C2","	* classifier enemy : bdš"},
/* 135C3 */ { "EGYPTIAN HIEROGLYPH-135C3","	* classifier rebel, enemy : ẖꜣk-ꞽb"},
/* 135C4 */ { "EGYPTIAN HIEROGLYPH-135C4","	* classifier enemy : bdš"},
/* 135C5 */ { "EGYPTIAN HIEROGLYPH-135C5","	* classifier rebel : bṯn"},
/* 135C6 */ { "EGYPTIAN HIEROGLYPH-135C6","	* classifier rebel : sbꞽ"},
/* 135C7 */ { "EGYPTIAN HIEROGLYPH-135C7","	* classifier rebel, enemy : ẖꜣk-ꞽb"},
/* 135C8 */ { "EGYPTIAN HIEROGLYPH-135C8","	* classifier foes, hostile forces : kꞽ.wy"},
/* 135C9 */ { "EGYPTIAN HIEROGLYPH-135C9","	* classifier enemy : šnṯ"},
/* 135CA */ { "EGYPTIAN HIEROGLYPH-135CA","	* classifier foreigners (as enemies) : ḫꜣs.t"},
/* 135CB */ { "EGYPTIAN HIEROGLYPH-135CB","	* classifier rebel : sbꞽ"},
/* 135CC */ { "EGYPTIAN HIEROGLYPH-135CC","	* classifier rebel : sbꞽ"},
/* 135CD */ { "EGYPTIAN HIEROGLYPH-135CD","	* logogram enemy : ḫft.y"},
/* 135CE */ { "EGYPTIAN HIEROGLYPH-135CE",NULL},
/* 135CF */ { "EGYPTIAN HIEROGLYPH-135CF","	* logogram (rebel) : sbꞽ"},
/* 135D0 */ { "EGYPTIAN HIEROGLYPH-135D0","	* logogram enemy/rebel : ḫft.y/sbꞽ"},
/* 135D1 */ { "EGYPTIAN HIEROGLYPH-135D1",NULL},
/* 135D2 */ { "EGYPTIAN HIEROGLYPH-135D2",NULL},
/* 135D3 */ { "EGYPTIAN HIEROGLYPH-135D3","	* classifier enemy : ḫr.y"},
/* 135D4 */ { "EGYPTIAN HIEROGLYPH-135D4","	* classifier bow-people, nomads : ꞽwn.tyw"},
/* 135D5 */ { "EGYPTIAN HIEROGLYPH-135D5","	* logogram (prisoner) : sḳr-ꜥnḫ"},
/* 135D6 */ { "EGYPTIAN HIEROGLYPH-135D6",NULL},
/* 135D7 */ { "EGYPTIAN HIEROGLYPH-135D7","	* logogram (foreigner) : ḫꜣs.ty "},
/* 135D8 */ { "EGYPTIAN HIEROGLYPH-135D8","	* classifier to drive away : msn(ḥ)"},
/* 135D9 */ { "EGYPTIAN HIEROGLYPH-135D9","	* logogram (to bend down, to subdue) : wꜥf"},
/* 135DA */ { "EGYPTIAN HIEROGLYPH-135DA","	* classifier foreigner : mry"},
/* 135DB */ { "EGYPTIAN HIEROGLYPH-135DB",NULL},
/* 135DC */ { "EGYPTIAN HIEROGLYPH-135DC","	* classifier foreign people : ḫꜣs.wt nb.wt"},
/* 135DD */ { "EGYPTIAN HIEROGLYPH-135DD","	* classifier weak, downcast : bdš.w"},
/* 135DE */ { "EGYPTIAN HIEROGLYPH-135DE","	* classifier dancing : ḥpg"},
/* 135DF */ { "EGYPTIAN HIEROGLYPH-135DF","	* classifier joy, jubilation : hnw"},
/* 135E0 */ { "EGYPTIAN HIEROGLYPH-135E0","	* classifier dancing : ꞽbꜣ"},
/* 135E1 */ { "EGYPTIAN HIEROGLYPH-135E1","	* classifier dance : ꞽbꜣ"},
/* 135E2 */ { "EGYPTIAN HIEROGLYPH-135E2","	* classifier dance : ꞽbꜣ"},
/* 135E3 */ { "EGYPTIAN HIEROGLYPH-135E3","	* classifier youthful soldier : mgꜣ"},
/* 135E4 */ { "EGYPTIAN HIEROGLYPH-135E4","	* classifier fear/veneration : hꜣ-snḏ"},
/* 135E5 */ { "EGYPTIAN HIEROGLYPH-135E5","	* classifier dancing : ḫbꞽ"},
/* 135E6 */ { "EGYPTIAN HIEROGLYPH-135E6","	* classifier dancing : ḫbꞽ"},
/* 135E7 */ { "EGYPTIAN HIEROGLYPH-135E7","	* classifier dancing : ḫbꞽ"},
/* 135E8 */ { "EGYPTIAN HIEROGLYPH-135E8","	* classifier dancing : ḫbꞽ"},
/* 135E9 */ { "EGYPTIAN HIEROGLYPH-135E9","	* classifier fear/veneration : hꜣ-snḏ"},
/* 135EA */ { "EGYPTIAN HIEROGLYPH-135EA",NULL},
/* 135EB */ { "EGYPTIAN HIEROGLYPH-135EB","	* logogram (the great god) : nṯr-ꜥꜣ"},
/* 135EC */ { "EGYPTIAN HIEROGLYPH-135EC",NULL},
/* 135ED */ { "EGYPTIAN HIEROGLYPH-135ED","	* logogram (to make music) : ꞽḥy"},
/* 135EE */ { "EGYPTIAN HIEROGLYPH-135EE","	* logogram (the great god) : nṯr-ꜥꜣ"},
/* 135EF */ { "EGYPTIAN HIEROGLYPH-135EF","	* logogram (the king of Lower Egypt) : bꞽ.ty"},
/* 135F0 */ { "EGYPTIAN HIEROGLYPH-135F0","	* classifier divinity : ꞽḥy"},
/* 135F1 */ { "EGYPTIAN HIEROGLYPH-135F1","	* logogram (Ihy (divinity)) : ꞽḥy"},
/* 135F2 */ { "EGYPTIAN HIEROGLYPH-135F2","	* logogram (the musician) : ꞽḥy"},
/* 135F3 */ { "EGYPTIAN HIEROGLYPH-135F3","	* logogram (the great god) : nṯr-ꜥꜣ"},
/* 135F4 */ { "EGYPTIAN HIEROGLYPH-135F4","	* logogram (king of Upper Egypt) : n(y)-sw.t"},
/* 135F5 */ { "EGYPTIAN HIEROGLYPH-135F5","	* logogram (the great god) : nṯr-ꜥꜣ"},
/* 135F6 */ { "EGYPTIAN HIEROGLYPH-135F6","	* logogram (the great god) : nṯr-ꜥꜣ"},
/* 135F7 */ { "EGYPTIAN HIEROGLYPH-135F7","	* logogram (Ihy (divinity)) : ꞽḥy"},
/* 135F8 */ { "EGYPTIAN HIEROGLYPH-135F8","	* logogram (Harsomtus) : ḥr-smꜣ-tꜣ.wy"},
/* 135F9 */ { "EGYPTIAN HIEROGLYPH-135F9","	* logogram (Harsomtus) : ḥr-smꜣ-tꜣ.wy "},
/* 135FA */ { "EGYPTIAN HIEROGLYPH-135FA","	* logogram (Harsomtus) : ḥr-smꜣ-tꜣ.wy "},
/* 135FB */ { "EGYPTIAN HIEROGLYPH-135FB","	* logogram (to sing) : ḥsꞽ "},
/* 135FC */ { "EGYPTIAN HIEROGLYPH-135FC","	* phonemogram : ḥsꞽ"},
/* 135FD */ { "EGYPTIAN HIEROGLYPH-135FD","	* classifier musician : ḫnw"},
/* 135FE */ { "EGYPTIAN HIEROGLYPH-135FE","	* classifier playing music : sbꜣ"},
/* 135FF */ { "EGYPTIAN HIEROGLYPH-135FF","	* classifier drum : mḳmḳ"}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_36[] = {
/* 13600 */ { "EGYPTIAN HIEROGLYPH-13600","	* classifier striking a drum : sr"},
/* 13601 */ { "EGYPTIAN HIEROGLYPH-13601","	* logogram (musician/percussionist) : ḫn.w"},
/* 13602 */ { "EGYPTIAN HIEROGLYPH-13602","	* classifier beating, striking : dbdb"},
/* 13603 */ { "EGYPTIAN HIEROGLYPH-13603","	* classifier lute player : ṯnf"},
/* 13604 */ { "EGYPTIAN HIEROGLYPH-13604","	* logogram (Cusae) : ḳꞽs"},
/* 13605 */ { "EGYPTIAN HIEROGLYPH-13605","	* classifier hunter, scout : nw"},
/* 13606 */ { "EGYPTIAN HIEROGLYPH-13606","	* classifier hunter, scout : nw"},
/* 13607 */ { "EGYPTIAN HIEROGLYPH-13607","	* logogram (to be strong, valiant) : ḳnꞽ"},
/* 13608 */ { "EGYPTIAN HIEROGLYPH-13608","	* logogram (the good beginning) : tp-nfr"},
/* 13609 */ { "EGYPTIAN HIEROGLYPH-13609","	* logogram (Cusae) : ḳꞽs"},
/* 1360A */ { "EGYPTIAN HIEROGLYPH-1360A","	* logogram (to be strong, valiant) : ḳnꞽ"},
/* 1360B */ { "EGYPTIAN HIEROGLYPH-1360B","	* logogram (to be strong, valiant) : ḳnꞽ"},
/* 1360C */ { "EGYPTIAN HIEROGLYPH-1360C","	* classifier chariot : wrr.yt"},
/* 1360D */ { "EGYPTIAN HIEROGLYPH-1360D","	* logogram (triomphator) : dwn.ty"},
/* 1360E */ { "EGYPTIAN HIEROGLYPH-1360E",NULL},
/* 1360F */ { "EGYPTIAN HIEROGLYPH-1360F","	* logogram (butchery, animals for sacrifice) : ḫr.yt"},
/* 13610 */ { "EGYPTIAN HIEROGLYPH-13610","	* pictogram ((with) a plough, (with) a yoke of oxen, (as) the first of men) : (m) ḥb (m) ḥtr (m) tp n rmṯ"},
/* 13611 */ { "EGYPTIAN HIEROGLYPH-13611","	* logogram (part of the sꜣ-rꜥ nb ḫꜥ.w construction) : sꜣ-rꜥ-nb"},
/* 13612 */ { "EGYPTIAN HIEROGLYPH-13612","	* phonemogram/logogram (part of the sꜣ-rꜥ nb ḫꜥ.w construction) : sꜣ nb"},
/* 13613 */ { "EGYPTIAN HIEROGLYPH-13613","	* classifier? : wnty"},
/* 13614 */ { "EGYPTIAN HIEROGLYPH-13614","	* phonemogram aromatic resin (styrax?) : nnyb"},
/* 13615 */ { "EGYPTIAN HIEROGLYPH-13615","	* phonemogram (lapis-lazuli) : ḫsbḏ"},
/* 13616 */ { "EGYPTIAN HIEROGLYPH-13616","	* logogram (triomphator) : dwn.ty"},
/* 13617 */ { "EGYPTIAN HIEROGLYPH-13617","	* phonemogram (lapis-lazuli) : ḫsbḏ"},
/* 13618 */ { "EGYPTIAN HIEROGLYPH-13618","	* logogram (to go around) : pẖr"},
/* 13619 */ { "EGYPTIAN HIEROGLYPH-13619","	* classifier hunter, scout : nw"},
/* 1361A */ { "EGYPTIAN HIEROGLYPH-1361A","	* classifier priest : ꞽwn-mw.t=f"},
/* 1361B */ { "EGYPTIAN HIEROGLYPH-1361B","	* phonemogram : wḥꜥ"},
/* 1361C */ { "EGYPTIAN HIEROGLYPH-1361C",NULL},
/* 1361D */ { "EGYPTIAN HIEROGLYPH-1361D","	* classifier youth/child : ḫy"},
/* 1361E */ { "EGYPTIAN HIEROGLYPH-1361E","	* classifier to sit, to be comfortable : snḏm"},
/* 1361F */ { "EGYPTIAN HIEROGLYPH-1361F","	* phonemogram : msdm"},
/* 13620 */ { "EGYPTIAN HIEROGLYPH-13620","	* classifier musician : ḫnw"},
/* 13621 */ { "EGYPTIAN HIEROGLYPH-13621","	* classifier child, youth, young man : ḥwn.w"},
/* 13622 */ { "EGYPTIAN HIEROGLYPH-13622","	* logogram (weaned child) : wḏḥ"},
/* 13623 */ { "EGYPTIAN HIEROGLYPH-13623","	* phonemogram : ꜥb"},
/* 13624 */ { "EGYPTIAN HIEROGLYPH-13624",NULL},
/* 13625 */ { "EGYPTIAN HIEROGLYPH-13625","	* logogram (son of Re) : sꜣ-rꜥ"},
/* 13626 */ { "EGYPTIAN HIEROGLYPH-13626","	* logogram (son of Re) : sꜣ-rꜥ"},
/* 13627 */ { "EGYPTIAN HIEROGLYPH-13627","	* phonemogram : r + ḫ"},
/* 13628 */ { "EGYPTIAN HIEROGLYPH-13628","	* classifier child : nḫn.w"},
/* 13629 */ { "EGYPTIAN HIEROGLYPH-13629","	* classifier child : wḏḥ"},
/* 1362A */ { "EGYPTIAN HIEROGLYPH-1362A","	* phonemogram : m"},
/* 1362B */ { "EGYPTIAN HIEROGLYPH-1362B",NULL},
/* 1362C */ { "EGYPTIAN HIEROGLYPH-1362C","	* phonemogram : ḫft-ḥr"},
/* 1362D */ { "EGYPTIAN HIEROGLYPH-1362D","	* phonemogram : ḫft-ḥr"},
/* 1362E */ { "EGYPTIAN HIEROGLYPH-1362E","	* classifier protector : ḫw.y"},
/* 1362F */ { "EGYPTIAN HIEROGLYPH-1362F","	* phonemogram : ꜥš"},
/* 13630 */ { "EGYPTIAN HIEROGLYPH-13630","	* phonemogram : ḫꜥ"},
/* 13631 */ { "EGYPTIAN HIEROGLYPH-13631",NULL},
/* 13632 */ { "EGYPTIAN HIEROGLYPH-13632","	* classifier Orion : sꜣḥ"},
/* 13633 */ { "EGYPTIAN HIEROGLYPH-13633","	* classifier child divinity : ḥkꜣ"},
/* 13634 */ { "EGYPTIAN HIEROGLYPH-13634","	* classifier child : sfy"},
/* 13635 */ { "EGYPTIAN HIEROGLYPH-13635",NULL},
/* 13636 */ { "EGYPTIAN HIEROGLYPH-13636","	* logogram (son/child of) : sꜣ"},
/* 13637 */ { "EGYPTIAN HIEROGLYPH-13637","	* logogram (crowns, appearances) : ḫꜥ.w"},
/* 13638 */ { "EGYPTIAN HIEROGLYPH-13638","	* logogram (son/child of) : sꜣ"},
/* 13639 */ { "EGYPTIAN HIEROGLYPH-13639","	* classifier child : sf(y)"},
/* 1363A */ { "EGYPTIAN HIEROGLYPH-1363A",NULL},
/* 1363B */ { "EGYPTIAN HIEROGLYPH-1363B","	* phonemogram : ḫn"},
/* 1363C */ { "EGYPTIAN HIEROGLYPH-1363C","	* classifier expelling, spitting : nš"},
/* 1363D */ { "EGYPTIAN HIEROGLYPH-1363D","	* logogram (dwarf, pigmy) : dng"},
/* 1363E */ { "EGYPTIAN HIEROGLYPH-1363E","	* classifier revered person"},
/* 1363F */ { "EGYPTIAN HIEROGLYPH-1363F","	* classifier revered person"},
/* 13640 */ { "EGYPTIAN HIEROGLYPH-13640","	* classifier revered person : ꞽt"},
/* 13641 */ { "EGYPTIAN HIEROGLYPH-13641","	* logogram (to be noble) : šps"},
/* 13642 */ { "EGYPTIAN HIEROGLYPH-13642","	* logogram (the noble speech) : mdw-šps"},
/* 13643 */ { "EGYPTIAN HIEROGLYPH-13643","	* classifier revered person"},
/* 13644 */ { "EGYPTIAN HIEROGLYPH-13644","	* logogram/phonemogram (costly offerings) : šps.w"},
/* 13645 */ { "EGYPTIAN HIEROGLYPH-13645","	* logogram (noble, splendid) : šps"},
/* 13646 */ { "EGYPTIAN HIEROGLYPH-13646","	* logogram (to be noble) : špsꞽ"},
/* 13647 */ { "EGYPTIAN HIEROGLYPH-13647","	* classifier divinity : ꞽtmw"},
/* 13648 */ { "EGYPTIAN HIEROGLYPH-13648","	* classifier to abide, to occupy : ḥmsꞽ"},
/* 13649 */ { "EGYPTIAN HIEROGLYPH-13649",NULL},
/* 1364A */ { "EGYPTIAN HIEROGLYPH-1364A","	* logogram (to be noble) : špsꞽ"},
/* 1364B */ { "EGYPTIAN HIEROGLYPH-1364B",NULL},
/* 1364C */ { "EGYPTIAN HIEROGLYPH-1364C","	* classifier noble : sꜥḥ"},
/* 1364D */ { "EGYPTIAN HIEROGLYPH-1364D","	* logogram/phonemogram (costly offerings) : šps.w"},
/* 1364E */ { "EGYPTIAN HIEROGLYPH-1364E","	* logogram (to be noble) : špsꞽ"},
/* 1364F */ { "EGYPTIAN HIEROGLYPH-1364F",NULL},
/* 13650 */ { "EGYPTIAN HIEROGLYPH-13650","	* classifier revered person"},
/* 13651 */ { "EGYPTIAN HIEROGLYPH-13651","	* logogram (Harsomtus) : ḥr-smꜣ-tꜣ.wy"},
/* 13652 */ { "EGYPTIAN HIEROGLYPH-13652","	* classifier divinity"},
/* 13653 */ { "EGYPTIAN HIEROGLYPH-13653",NULL},
/* 13654 */ { "EGYPTIAN HIEROGLYPH-13654","	* classifier divinity : mr.ty"},
/* 13655 */ { "EGYPTIAN HIEROGLYPH-13655","	* classifier divinity"},
/* 13656 */ { "EGYPTIAN HIEROGLYPH-13656","	* classifier king : n(y)-sw.t"},
/* 13657 */ { "EGYPTIAN HIEROGLYPH-13657","	* classifier king : n(y)-sw.t"},
/* 13658 */ { "EGYPTIAN HIEROGLYPH-13658",NULL},
/* 13659 */ { "EGYPTIAN HIEROGLYPH-13659","	* logogram (first person singular) : ꞽ"},
/* 1365A */ { "EGYPTIAN HIEROGLYPH-1365A",NULL},
/* 1365B */ { "EGYPTIAN HIEROGLYPH-1365B","	* classifier divinity : ꞽtmw"},
/* 1365C */ { "EGYPTIAN HIEROGLYPH-1365C","	* logogram (first person singular) : ꞽ"},
/* 1365D */ { "EGYPTIAN HIEROGLYPH-1365D","	* logogram (first person singular) : ꞽ"},
/* 1365E */ { "EGYPTIAN HIEROGLYPH-1365E","	* logogram (powerful one) : sḫm"},
/* 1365F */ { "EGYPTIAN HIEROGLYPH-1365F","	* logogram (majesty) : ḥm"},
/* 13660 */ { "EGYPTIAN HIEROGLYPH-13660","	* logogram (king) : n.y-sw.t"},
/* 13661 */ { "EGYPTIAN HIEROGLYPH-13661","	* logogram (Khepri) : ḫprꞽ"},
/* 13662 */ { "EGYPTIAN HIEROGLYPH-13662","	* logogram (to rule) : ḥḳꜣ"},
/* 13663 */ { "EGYPTIAN HIEROGLYPH-13663","	* logogram (ruler of the 9th nome of Lower Egypt) : ḥḳꜣ-ꜥnḏ.ty"},
/* 13664 */ { "EGYPTIAN HIEROGLYPH-13664","	* logogram (ruler) : ḥḳꜣ"},
/* 13665 */ { "EGYPTIAN HIEROGLYPH-13665","	* classifier statue : ẖn.ty"},
/* 13666 */ { "EGYPTIAN HIEROGLYPH-13666","	* logogram (sovereign) : ꞽt.y"},
/* 13667 */ { "EGYPTIAN HIEROGLYPH-13667","	* logogram (noble, splendid) : šps"},
/* 13668 */ { "EGYPTIAN HIEROGLYPH-13668","	* classifier sovereign : ꞽt.y"},
/* 13669 */ { "EGYPTIAN HIEROGLYPH-13669","	* logogram (sovereign) : ꞽt.y"},
/* 1366A */ { "EGYPTIAN HIEROGLYPH-1366A",NULL},
/* 1366B */ { "EGYPTIAN HIEROGLYPH-1366B",NULL},
/* 1366C */ { "EGYPTIAN HIEROGLYPH-1366C","	* classifier personal name"},
/* 1366D */ { "EGYPTIAN HIEROGLYPH-1366D","	* classifier statue : ꞽrw"},
/* 1366E */ { "EGYPTIAN HIEROGLYPH-1366E","	* classifier praying, worshipping : smnḥ"},
/* 1366F */ { "EGYPTIAN HIEROGLYPH-1366F","	* classifier king : n.y-sw.t"},
/* 13670 */ { "EGYPTIAN HIEROGLYPH-13670","	* classifier divinity : kꜣ-ḥtp"},
/* 13671 */ { "EGYPTIAN HIEROGLYPH-13671","	* classifier king : n.y-sw.t"},
/* 13672 */ { "EGYPTIAN HIEROGLYPH-13672","	* classifier divinity : ḫnt.y-ꞽmn.tyw"},
/* 13673 */ { "EGYPTIAN HIEROGLYPH-13673","	* classifier king : n.y-sw.t"},
/* 13674 */ { "EGYPTIAN HIEROGLYPH-13674","	* classifier king : n.y-sw.t"},
/* 13675 */ { "EGYPTIAN HIEROGLYPH-13675","	* classifier divinity : nṯr"},
/* 13676 */ { "EGYPTIAN HIEROGLYPH-13676","	* logogram (king of Upper Egypt) : n.y-sw.t"},
/* 13677 */ { "EGYPTIAN HIEROGLYPH-13677","	* classifier king : n.y-sw.t"},
/* 13678 */ { "EGYPTIAN HIEROGLYPH-13678","	* classifier king : n.y-sw.t"},
/* 13679 */ { "EGYPTIAN HIEROGLYPH-13679","	* classifier divinity : ḫnt.y-ꞽmn.tyw"},
/* 1367A */ { "EGYPTIAN HIEROGLYPH-1367A","	* logogram (king of Upper Egypt) : n.y-sw.t"},
/* 1367B */ { "EGYPTIAN HIEROGLYPH-1367B","	* logogram (king of Upper Egypt) : n.y-sw.t"},
/* 1367C */ { "EGYPTIAN HIEROGLYPH-1367C","	* logogram (king of Upper Egypt) : n.y-sw.t"},
/* 1367D */ { "EGYPTIAN HIEROGLYPH-1367D","	* logogram (majesty) : ḥm"},
/* 1367E */ { "EGYPTIAN HIEROGLYPH-1367E","	* logogram (he of Heliopolis) : ꞽwn.y"},
/* 1367F */ { "EGYPTIAN HIEROGLYPH-1367F","	* logogram (the white crown) : ḥḏ.t"},
/* 13680 */ { "EGYPTIAN HIEROGLYPH-13680","	* classifier divinity : wsꞽr"},
/* 13681 */ { "EGYPTIAN HIEROGLYPH-13681","	* classifier Osiris : wsꞽr"},
/* 13682 */ { "EGYPTIAN HIEROGLYPH-13682","	* classifier king : n.y-sw.t"},
/* 13683 */ { "EGYPTIAN HIEROGLYPH-13683",NULL},
/* 13684 */ { "EGYPTIAN HIEROGLYPH-13684","	* logogram (king of Upper Egypt) : n.y-sw.t"},
/* 13685 */ { "EGYPTIAN HIEROGLYPH-13685","	* logogram (king of Upper Egypt) : n.y-sw.t"},
/* 13686 */ { "EGYPTIAN HIEROGLYPH-13686","	* logogram (king of Upper Egypt and land, when occurring together with king of Lower Egypt forms n(.y)-sw.t-bꞽ.ty nb tꜣ.wy) : n(.y)-sw.t & tꜣ"},
/* 13687 */ { "EGYPTIAN HIEROGLYPH-13687","	* logogram (king of Upper Egypt and land when occurring together with red crown wearing variant forms n(.y)-sw.t-bꞽ.ty nb tꜣ.wy) : n(.y)-sw.t & tꜣ"},
/* 13688 */ { "EGYPTIAN HIEROGLYPH-13688","	* logogram (king of Upper Egypt) : n(.y)-sw.t"},
/* 13689 */ { "EGYPTIAN HIEROGLYPH-13689","	* logogram (Osiris) : wsꞽr"},
/* 1368A */ { "EGYPTIAN HIEROGLYPH-1368A","	* logogram (king of Lower Egypt) : bꞽ.ty"},
/* 1368B */ { "EGYPTIAN HIEROGLYPH-1368B","	* logogram (king of Lower Egypt) : bꞽ.ty"},
/* 1368C */ { "EGYPTIAN HIEROGLYPH-1368C","	* logogram (king of Lower Egypt) : bꞽ.ty"},
/* 1368D */ { "EGYPTIAN HIEROGLYPH-1368D","	* logogram (king of Lower Egypt) : bꞽ.ty"},
/* 1368E */ { "EGYPTIAN HIEROGLYPH-1368E","	* logogram (king of Lower Egypt) : bꞽ.ty"},
/* 1368F */ { "EGYPTIAN HIEROGLYPH-1368F","	* classifier king : n(y)-sw.t"},
/* 13690 */ { "EGYPTIAN HIEROGLYPH-13690","	* logogram (king of Lower Egypt) : bꞽ.ty"},
/* 13691 */ { "EGYPTIAN HIEROGLYPH-13691","	* classifier sovereign : ꞽt.y"},
/* 13692 */ { "EGYPTIAN HIEROGLYPH-13692","	* classifier king : n.y-sw.t"},
/* 13693 */ { "EGYPTIAN HIEROGLYPH-13693","	* logogram (king of Lower Egypt and land, when occurring together with king of Upper Egypt forms n(.y)-sw.t-bꞽ.ty nb tꜣ.wy) : bꞽ.ty tꜣ"},
/* 13694 */ { "EGYPTIAN HIEROGLYPH-13694","	* logogram (king of Lower Egypt and land, when occurring together with a white crown variant forms n(.y)-sw.t-bꞽ.ty nb tꜣ.wy) : bꞽ.ty tꜣ"},
/* 13695 */ { "EGYPTIAN HIEROGLYPH-13695","	* logogram (king of Upper Egypt) : n(.y)-sw.t"},
/* 13696 */ { "EGYPTIAN HIEROGLYPH-13696","	* logogram (to run) : pḥrr"},
/* 13697 */ { "EGYPTIAN HIEROGLYPH-13697","	* logogram (an offering that the king gives) : ḥtp-dꞽ-n.y-sw.t"},
/* 13698 */ { "EGYPTIAN HIEROGLYPH-13698","	* phonemogram : ṯ"},
/* 13699 */ { "EGYPTIAN HIEROGLYPH-13699","	* logogram (Atum) : ꞽtmw"},
/* 1369A */ { "EGYPTIAN HIEROGLYPH-1369A","	* logogram (first person singular) : ꞽ"},
/* 1369B */ { "EGYPTIAN HIEROGLYPH-1369B","	* logogram (king of Upper and Lower Egypt) : n(y)-sw.t-bꞽ.ty"},
/* 1369C */ { "EGYPTIAN HIEROGLYPH-1369C","	* classifier king/divinity : pꜣ-nṯr-mnḫ"},
/* 1369D */ { "EGYPTIAN HIEROGLYPH-1369D","	* classifier king/divinity : pꜣ-nṯr-mnḫ"},
/* 1369E */ { "EGYPTIAN HIEROGLYPH-1369E","	* logogram (Atum) : ꞽtmw"},
/* 1369F */ { "EGYPTIAN HIEROGLYPH-1369F","	* classifier divinity : ꞽtmw"},
/* 136A0 */ { "EGYPTIAN HIEROGLYPH-136A0","	* logogram (Atum) : ꞽtmw"},
/* 136A1 */ { "EGYPTIAN HIEROGLYPH-136A1","	* classifier sovereign : ꞽt.y"},
/* 136A2 */ { "EGYPTIAN HIEROGLYPH-136A2","	* logogram (king of Upper and Lower Egypt) : n(y)-sw.t-bꞽ.ty"},
/* 136A3 */ { "EGYPTIAN HIEROGLYPH-136A3",NULL},
/* 136A4 */ { "EGYPTIAN HIEROGLYPH-136A4","	* pictogram prostrate offering a vase of myrrh"},
/* 136A5 */ { "EGYPTIAN HIEROGLYPH-136A5","	* logogram (sovereign) : ꞽt.y"},
/* 136A6 */ { "EGYPTIAN HIEROGLYPH-136A6","	* classifier sovereign : ꞽt.y"},
/* 136A7 */ { "EGYPTIAN HIEROGLYPH-136A7","	* classifier sovereign : ꞽt.y"},
/* 136A8 */ { "EGYPTIAN HIEROGLYPH-136A8",NULL},
/* 136A9 */ { "EGYPTIAN HIEROGLYPH-136A9","	* logogram (sovereign) : ꞽt.y"},
/* 136AA */ { "EGYPTIAN HIEROGLYPH-136AA","	* logogram (sovereign) : ꞽt.y"},
/* 136AB */ { "EGYPTIAN HIEROGLYPH-136AB",NULL},
/* 136AC */ { "EGYPTIAN HIEROGLYPH-136AC","	* logogram/phonemogram (in ꜥnḏ.ty (Busiris)) : ꜥnḏ"},
/* 136AD */ { "EGYPTIAN HIEROGLYPH-136AD","	* logogram (9th nome of Lower Egypt) : ꜥnḏ.ty"},
/* 136AE */ { "EGYPTIAN HIEROGLYPH-136AE","	* classifier majesty (specifically referring to Shu) : ḥm"},
/* 136AF */ { "EGYPTIAN HIEROGLYPH-136AF","	* classifier divinity (Geb) : gbb"},
/* 136B0 */ { "EGYPTIAN HIEROGLYPH-136B0",NULL},
/* 136B1 */ { "EGYPTIAN HIEROGLYPH-136B1","	* classifier name (deceased person)"},
/* 136B2 */ { "EGYPTIAN HIEROGLYPH-136B2","	* classifier name (deceased person)"},
/* 136B3 */ { "EGYPTIAN HIEROGLYPH-136B3",NULL},
/* 136B4 */ { "EGYPTIAN HIEROGLYPH-136B4","	* classifier name (deceased person)"},
/* 136B5 */ { "EGYPTIAN HIEROGLYPH-136B5","	* classifier divinity : wsꞽr"},
/* 136B6 */ { "EGYPTIAN HIEROGLYPH-136B6","	* classifier divinity : ḫnt.y-ꞽmn.tyw"},
/* 136B7 */ { "EGYPTIAN HIEROGLYPH-136B7","	* classifier creation/form : ꞽr.w"},
/* 136B8 */ { "EGYPTIAN HIEROGLYPH-136B8","	* classifier to sleep/to spend the night : sḏr"},
/* 136B9 */ { "EGYPTIAN HIEROGLYPH-136B9","	* classifier statue : ẖn.ty"},
/* 136BA */ { "EGYPTIAN HIEROGLYPH-136BA",NULL},
/* 136BB */ { "EGYPTIAN HIEROGLYPH-136BB","	* classifier statue : twt"},
/* 136BC */ { "EGYPTIAN HIEROGLYPH-136BC",NULL},
/* 136BD */ { "EGYPTIAN HIEROGLYPH-136BD","	* logogram (statue) : mnw"},
/* 136BE */ { "EGYPTIAN HIEROGLYPH-136BE","	* classifier statue : mnw"},
/* 136BF */ { "EGYPTIAN HIEROGLYPH-136BF","	* classifier carrying chair : wr-ꜥ"},
/* 136C0 */ { "EGYPTIAN HIEROGLYPH-136C0","	* classifier divinity : ꜥḳ.t-m-rw.ty"},
/* 136C1 */ { "EGYPTIAN HIEROGLYPH-136C1","	* classifier statue : smn"},
/* 136C2 */ { "EGYPTIAN HIEROGLYPH-136C2","	* logogram (monument)? : mn.w"},
/* 136C3 */ { "EGYPTIAN HIEROGLYPH-136C3",NULL},
/* 136C4 */ { "EGYPTIAN HIEROGLYPH-136C4","	* classifier to awake : nhsꞽ"},
/* 136C5 */ { "EGYPTIAN HIEROGLYPH-136C5","	* classifier to sleep : sḏr"},
/* 136C6 */ { "EGYPTIAN HIEROGLYPH-136C6","	* classifier : ẖꜣ.t"},
/* 136C7 */ { "EGYPTIAN HIEROGLYPH-136C7","	* classifier corpse : ẖꜣ.t"},
/* 136C8 */ { "EGYPTIAN HIEROGLYPH-136C8","	* classifier to sleep : sḏr"},
/* 136C9 */ { "EGYPTIAN HIEROGLYPH-136C9","	* classifier (ointment vessel in the shape of the king) : snn"},
/* 136CA */ { "EGYPTIAN HIEROGLYPH-136CA","	* classifier wine : ꞽrp"},
/* 136CB */ { "EGYPTIAN HIEROGLYPH-136CB","	* logogram (to venerate) : dwꜣ"},
/* 136CC */ { "EGYPTIAN HIEROGLYPH-136CC","	* phonemogram/logogram (million/many) : ḥḥ"},
/* 136CD */ { "EGYPTIAN HIEROGLYPH-136CD","	* phonemogram : š"},
/* 136CE */ { "EGYPTIAN HIEROGLYPH-136CE",NULL},
/* 136CF */ { "EGYPTIAN HIEROGLYPH-136CF","	* logogram (to love) : mrꞽ"},
/* 136D0 */ { "EGYPTIAN HIEROGLYPH-136D0","	* logogram (his townsman) : nꞽw.ty=f"},
/* 136D1 */ { "EGYPTIAN HIEROGLYPH-136D1","	* classifier playing : ḥꜥb"},
/* 136D2 */ { "EGYPTIAN HIEROGLYPH-136D2","	* classifier playing : ḥꜥb"},
/* 136D3 */ { "EGYPTIAN HIEROGLYPH-136D3","	* logogram (gods) : nṯr.w"},
/* 136D4 */ { "EGYPTIAN HIEROGLYPH-136D4","	* phonemogram : ṯ"},
/* 136D5 */ { "EGYPTIAN HIEROGLYPH-136D5","	* logogram (majesty) : ḥm.t"},
/* 136D6 */ { "EGYPTIAN HIEROGLYPH-136D6","	* logogram (feminine first person singular) : ꞽ"},
/* 136D7 */ { "EGYPTIAN HIEROGLYPH-136D7","	* classifier divinity : n.t"},
/* 136D8 */ { "EGYPTIAN HIEROGLYPH-136D8",NULL},
/* 136D9 */ { "EGYPTIAN HIEROGLYPH-136D9","	* classifier divinity : tfn.t"},
/* 136DA */ { "EGYPTIAN HIEROGLYPH-136DA","	* phonemogram : ṯ"},
/* 136DB */ { "EGYPTIAN HIEROGLYPH-136DB","	* classifier divinity : ẖrsk.t"},
/* 136DC */ { "EGYPTIAN HIEROGLYPH-136DC","	* classifier ruler : ḥḳꜣ.t"},
/* 136DD */ { "EGYPTIAN HIEROGLYPH-136DD",NULL},
/* 136DE */ { "EGYPTIAN HIEROGLYPH-136DE","	* logogram (mistress) : ḥnw.t"},
/* 136DF */ { "EGYPTIAN HIEROGLYPH-136DF","	* classifier personal name : ꜥnḫ=s-n-ꜣs.t"},
/* 136E0 */ { "EGYPTIAN HIEROGLYPH-136E0","	* classifier personal name : ḥr-ꜥnḫ"},
/* 136E1 */ { "EGYPTIAN HIEROGLYPH-136E1","	* phonemogram : n(w)ꞽ"},
/* 136E2 */ { "EGYPTIAN HIEROGLYPH-136E2","	* logogram (Maat) : mꜣꜥ.t"},
/* 136E3 */ { "EGYPTIAN HIEROGLYPH-136E3","	* phonemogram (in ḥw.t-ꞽr.yw (hall of records/scriptorium)) : ꞽr.y"},
/* 136E4 */ { "EGYPTIAN HIEROGLYPH-136E4","	* classifier enemy : ḫft.ywt"},
/* 136E5 */ { "EGYPTIAN HIEROGLYPH-136E5","	* logogram (first person singular) : ꞽ"},
/* 136E6 */ { "EGYPTIAN HIEROGLYPH-136E6","	* classifier youth : nḫḫ"},
/* 136E7 */ { "EGYPTIAN HIEROGLYPH-136E7","	* phonemogram : ṯ"},
/* 136E8 */ { "EGYPTIAN HIEROGLYPH-136E8","	* classifier divinity : ꞽmn.t"},
/* 136E9 */ { "EGYPTIAN HIEROGLYPH-136E9","	* classifier ruler : ḥḳꜣ.t"},
/* 136EA */ { "EGYPTIAN HIEROGLYPH-136EA","	* logogram (mistress) : ḥnw.t"},
/* 136EB */ { "EGYPTIAN HIEROGLYPH-136EB","	* classifier divinity : srḳ.t"},
/* 136EC */ { "EGYPTIAN HIEROGLYPH-136EC",NULL},
/* 136ED */ { "EGYPTIAN HIEROGLYPH-136ED","	* phonemogram : f"},
/* 136EE */ { "EGYPTIAN HIEROGLYPH-136EE","	* classifier woman : ḥm.t"},
/* 136EF */ { "EGYPTIAN HIEROGLYPH-136EF","	* classifier divinity (title of šntꜣyt) : ḳꜣ.t-bꜣ.w"},
/* 136F0 */ { "EGYPTIAN HIEROGLYPH-136F0","	* classifier relationship : ꜣb.wt"},
/* 136F1 */ { "EGYPTIAN HIEROGLYPH-136F1",NULL},
/* 136F2 */ { "EGYPTIAN HIEROGLYPH-136F2","	* phonemogram : ṯ"},
/* 136F3 */ { "EGYPTIAN HIEROGLYPH-136F3","	* classifier name (deceased person)"},
/* 136F4 */ { "EGYPTIAN HIEROGLYPH-136F4","	* spindle/spinning tool"},
/* 136F5 */ { "EGYPTIAN HIEROGLYPH-136F5",NULL},
/* 136F6 */ { "EGYPTIAN HIEROGLYPH-136F6","	* classifier barren woman : snb.t"},
/* 136F7 */ { "EGYPTIAN HIEROGLYPH-136F7","	* classifier to mourn : ḥꜣꞽ"},
/* 136F8 */ { "EGYPTIAN HIEROGLYPH-136F8","	* phonemogram (to form mr.ty (the two eyes)) : mrt"},
/* 136F9 */ { "EGYPTIAN HIEROGLYPH-136F9","	* classifier to welcome : nyny"},
/* 136FA */ { "EGYPTIAN HIEROGLYPH-136FA","	* classifier to praise : dwꜣ"},
/* 136FB */ { "EGYPTIAN HIEROGLYPH-136FB","	* classifier (mourner) : ḥꜣ.t"},
/* 136FC */ { "EGYPTIAN HIEROGLYPH-136FC","	* classifier divinity : wrr.t"},
/* 136FD */ { "EGYPTIAN HIEROGLYPH-136FD",NULL},
/* 136FE */ { "EGYPTIAN HIEROGLYPH-136FE","	* classifier fortune : rnn.t"},
/* 136FF */ { "EGYPTIAN HIEROGLYPH-136FF","	* classifier to clap & phonemogram : dḫn & s"}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_37[] = {
/* 13700 */ { "EGYPTIAN HIEROGLYPH-13700","	* logogram (to be noble) : šps"},
/* 13701 */ { "EGYPTIAN HIEROGLYPH-13701","	* logogram (to be noble) : šps"},
/* 13702 */ { "EGYPTIAN HIEROGLYPH-13702","	* logogram (to be noble) : šps"},
/* 13703 */ { "EGYPTIAN HIEROGLYPH-13703","	* logogram (noblewoman) : šps.t"},
/* 13704 */ { "EGYPTIAN HIEROGLYPH-13704","	* logogram (noblewoman) : šps.t"},
/* 13705 */ { "EGYPTIAN HIEROGLYPH-13705","	* logogram (noblewoman) : šps.t"},
/* 13706 */ { "EGYPTIAN HIEROGLYPH-13706","	* classifier name female royalty : ḫnt-kꜣ.w=s"},
/* 13707 */ { "EGYPTIAN HIEROGLYPH-13707",NULL},
/* 13708 */ { "EGYPTIAN HIEROGLYPH-13708","	* classifier personal name : ḥtp-ḥr=s"},
/* 13709 */ { "EGYPTIAN HIEROGLYPH-13709","	* classifier personal name"},
/* 1370A */ { "EGYPTIAN HIEROGLYPH-1370A","	* logogram (to be noble) : šps"},
/* 1370B */ { "EGYPTIAN HIEROGLYPH-1370B",NULL},
/* 1370C */ { "EGYPTIAN HIEROGLYPH-1370C","	* logogram (to be noble) : šps"},
/* 1370D */ { "EGYPTIAN HIEROGLYPH-1370D","	* classifier resting : snḏm"},
/* 1370E */ { "EGYPTIAN HIEROGLYPH-1370E","	* classifier youth : rnpꞽ"},
/* 1370F */ { "EGYPTIAN HIEROGLYPH-1370F","	* classifier name"},
/* 13710 */ { "EGYPTIAN HIEROGLYPH-13710","	* classifier to welcome : nyny"},
/* 13711 */ { "EGYPTIAN HIEROGLYPH-13711","	* classifier to welcome : nyny"},
/* 13712 */ { "EGYPTIAN HIEROGLYPH-13712",NULL},
/* 13713 */ { "EGYPTIAN HIEROGLYPH-13713","	* classifier mourners : ḥ(ꜣ)y.t"},
/* 13714 */ { "EGYPTIAN HIEROGLYPH-13714","	* classifier (screamers, mourners) : sgb.wt"},
/* 13715 */ { "EGYPTIAN HIEROGLYPH-13715","	* classifier divinity : ꜣs.t"},
/* 13716 */ { "EGYPTIAN HIEROGLYPH-13716","	* classifier relationship : ḫnms.t"},
/* 13717 */ { "EGYPTIAN HIEROGLYPH-13717","	* classifier to raise/to support : ḫy"},
/* 13718 */ { "EGYPTIAN HIEROGLYPH-13718","	* classifier singing : šmꜥ"},
/* 13719 */ { "EGYPTIAN HIEROGLYPH-13719","	* phonemogram : sw"},
/* 1371A */ { "EGYPTIAN HIEROGLYPH-1371A","	* logogram (to rule) : ḥḳꜣ"},
/* 1371B */ { "EGYPTIAN HIEROGLYPH-1371B","	* phonemogram : nḏ"},
/* 1371C */ { "EGYPTIAN HIEROGLYPH-1371C","	* classifier mourner : ḥꜣy.t"},
/* 1371D */ { "EGYPTIAN HIEROGLYPH-1371D",NULL},
/* 1371E */ { "EGYPTIAN HIEROGLYPH-1371E","	* logogram (noblewoman) : sr.t"},
/* 1371F */ { "EGYPTIAN HIEROGLYPH-1371F","	* logogram (sovereign) : ꞽt.yt"},
/* 13720 */ { "EGYPTIAN HIEROGLYPH-13720","	* phonemogram : w"},
/* 13721 */ { "EGYPTIAN HIEROGLYPH-13721","	* logogram (to be old, old age) : ꞽꜣwꞽ"},
/* 13722 */ { "EGYPTIAN HIEROGLYPH-13722","	* logogram (noble lady) : rpy.t"},
/* 13723 */ { "EGYPTIAN HIEROGLYPH-13723","	* logogram (sovereign) : ꞽt.yt"},
/* 13724 */ { "EGYPTIAN HIEROGLYPH-13724","	* phonemogram (cryptography) : t/r"},
/* 13725 */ { "EGYPTIAN HIEROGLYPH-13725","	* classifier mourner : ḥꜣy.t"},
/* 13726 */ { "EGYPTIAN HIEROGLYPH-13726","	* classifier? : šꜣ.tw"},
/* 13727 */ { "EGYPTIAN HIEROGLYPH-13727","	* classifier danceress : ꞽhb.t"},
/* 13728 */ { "EGYPTIAN HIEROGLYPH-13728","	* classifier nursing, rearing : ꜣṯ"},
/* 13729 */ { "EGYPTIAN HIEROGLYPH-13729","	* classifier : ꜥtꜣ"},
/* 1372A */ { "EGYPTIAN HIEROGLYPH-1372A",NULL},
/* 1372B */ { "EGYPTIAN HIEROGLYPH-1372B","	* classifier royal sister : sn.t"},
/* 1372C */ { "EGYPTIAN HIEROGLYPH-1372C","	* classifier royal personal name : nfr-nfr.w-ꞽtn-nfr.ty-ꞽyꞽ.tꞽ"},
/* 1372D */ { "EGYPTIAN HIEROGLYPH-1372D",NULL},
/* 1372E */ { "EGYPTIAN HIEROGLYPH-1372E",NULL},
/* 1372F */ { "EGYPTIAN HIEROGLYPH-1372F","	* logogram (king of Upper Egypt) : n.y-sw.t"},
/* 13730 */ { "EGYPTIAN HIEROGLYPH-13730","	* phonemogram : b"},
/* 13731 */ { "EGYPTIAN HIEROGLYPH-13731",NULL},
/* 13732 */ { "EGYPTIAN HIEROGLYPH-13732","	* logogram (rejoicing) : nhm"},
/* 13733 */ { "EGYPTIAN HIEROGLYPH-13733","	* classifier (to rejoice) : nhm"},
/* 13734 */ { "EGYPTIAN HIEROGLYPH-13734","	* classifier jubilation : sꜣ-tꜣ"},
/* 13735 */ { "EGYPTIAN HIEROGLYPH-13735","	* classifier sistrum player : sḫm.y(t)"},
/* 13736 */ { "EGYPTIAN HIEROGLYPH-13736","	* classifier female rhythm maker : dḫn.t"},
/* 13737 */ { "EGYPTIAN HIEROGLYPH-13737","	* classifier birth : msꞽ"},
/* 13738 */ { "EGYPTIAN HIEROGLYPH-13738","	* classifier nurse : ꜣṯ.(y)t"},
/* 13739 */ { "EGYPTIAN HIEROGLYPH-13739","	* logogram (to birth, to bring forth) : msꞽ"},
/* 1373A */ { "EGYPTIAN HIEROGLYPH-1373A","	* classifier birth : msꞽ"},
/* 1373B */ { "EGYPTIAN HIEROGLYPH-1373B","	* classifier birth : msꞽ"},
/* 1373C */ { "EGYPTIAN HIEROGLYPH-1373C","	* classifier birth : msꞽ"},
/* 1373D */ { "EGYPTIAN HIEROGLYPH-1373D","	* classifier nurse : ḫnm.t"},
/* 1373E */ { "EGYPTIAN HIEROGLYPH-1373E",NULL},
/* 1373F */ { "EGYPTIAN HIEROGLYPH-1373F","	* logogram (nurse) : ḫnm.t"},
/* 13740 */ { "EGYPTIAN HIEROGLYPH-13740","	* logogram (nurse) : ḫnm.t"},
/* 13741 */ { "EGYPTIAN HIEROGLYPH-13741",NULL},
/* 13742 */ { "EGYPTIAN HIEROGLYPH-13742","	* classifier nursing, rearing : rnn"},
/* 13743 */ { "EGYPTIAN HIEROGLYPH-13743","	* classifier nursing, rearing : rnn"},
/* 13744 */ { "EGYPTIAN HIEROGLYPH-13744","	* classifier (dancer/acrobat) : ḫb.t"},
/* 13745 */ { "EGYPTIAN HIEROGLYPH-13745","	* phonemogram : nḏ"},
/* 13746 */ { "EGYPTIAN HIEROGLYPH-13746",NULL},
/* 13747 */ { "EGYPTIAN HIEROGLYPH-13747","	* classifier moving back and forth : wnwn"},
/* 13748 */ { "EGYPTIAN HIEROGLYPH-13748","	* phonemogram (cryptography) : st.y-m"},
/* 13749 */ { "EGYPTIAN HIEROGLYPH-13749","	* logogram (in combination with \\C268B) : rꜥ-nb"},
/* 1374A */ { "EGYPTIAN HIEROGLYPH-1374A","	* classifier moon : ꞽꜥḥ"},
/* 1374B */ { "EGYPTIAN HIEROGLYPH-1374B","	* classifier moon/light (together with Re, representing the sun and the moon as the two lights) : ḥꜣy.ty"},
/* 1374C */ { "EGYPTIAN HIEROGLYPH-1374C",NULL},
/* 1374D */ { "EGYPTIAN HIEROGLYPH-1374D","	* logogram (Geb) : gbb"},
/* 1374E */ { "EGYPTIAN HIEROGLYPH-1374E","	* logogram (Geb) : gbb"},
/* 1374F */ { "EGYPTIAN HIEROGLYPH-1374F","	* logogram (the earthmaker (divinity)) : ꞽr-tꜣ"},
/* 13750 */ { "EGYPTIAN HIEROGLYPH-13750",NULL},
/* 13751 */ { "EGYPTIAN HIEROGLYPH-13751","	* logogram (the utterance, divinity) : ḥw"},
/* 13752 */ { "EGYPTIAN HIEROGLYPH-13752","	* logogram (the utterance, divinity) : ḥw"},
/* 13753 */ { "EGYPTIAN HIEROGLYPH-13753","	* logogram (perception/knowledge (divinity)) : sꞽꜣ"},
/* 13754 */ { "EGYPTIAN HIEROGLYPH-13754","	* logogram (perception/knowledge (divinity)) : sꞽꜣ"},
/* 13755 */ { "EGYPTIAN HIEROGLYPH-13755",NULL},
/* 13756 */ { "EGYPTIAN HIEROGLYPH-13756",NULL},
/* 13757 */ { "EGYPTIAN HIEROGLYPH-13757",NULL},
/* 13758 */ { "EGYPTIAN HIEROGLYPH-13758","	* logogram (first person singular, for Harsomtus) : ꞽ"},
/* 13759 */ { "EGYPTIAN HIEROGLYPH-13759","	* classifier Khepri (divinity)"},
/* 1375A */ { "EGYPTIAN HIEROGLYPH-1375A","	* logogram (spirit) : kꜣ"},
/* 1375B */ { "EGYPTIAN HIEROGLYPH-1375B","	* logogram (god) : nṯr"},
/* 1375C */ { "EGYPTIAN HIEROGLYPH-1375C","	* classifier divinity (Chay) : šꜣy"},
/* 1375D */ { "EGYPTIAN HIEROGLYPH-1375D","	* classifier divinity : tꜣ-ṯnn"},
/* 1375E */ { "EGYPTIAN HIEROGLYPH-1375E",NULL},
/* 1375F */ { "EGYPTIAN HIEROGLYPH-1375F","	* classifier divinity : pḏ.ty"},
/* 13760 */ { "EGYPTIAN HIEROGLYPH-13760","	* classifier divinity (Nekhbet)"},
/* 13761 */ { "EGYPTIAN HIEROGLYPH-13761","	* logogram (Khepri) : ḫprꞽ"},
/* 13762 */ { "EGYPTIAN HIEROGLYPH-13762","	* classifier Khepri (divinity)"},
/* 13763 */ { "EGYPTIAN HIEROGLYPH-13763","	* logogram (Amon) : ꞽmn"},
/* 13764 */ { "EGYPTIAN HIEROGLYPH-13764","	* classifier divinity : ꞽn-ḥr-šw"},
/* 13765 */ { "EGYPTIAN HIEROGLYPH-13765","	* logogram (Maat and Amon) : mꜣꜥ.t & ꞽmn "},
/* 13766 */ { "EGYPTIAN HIEROGLYPH-13766","	* logogram (Amon) : ꞽmn"},
/* 13767 */ { "EGYPTIAN HIEROGLYPH-13767","	* logogram (Amon) : ꞽmn"},
/* 13768 */ { "EGYPTIAN HIEROGLYPH-13768","	* logogram (living image of Amon) : sḫm-ꜥnḫ-n-ꞽmn"},
/* 13769 */ { "EGYPTIAN HIEROGLYPH-13769","	* logogram divinity : ꞽr-ṯꜥw"},
/* 1376A */ { "EGYPTIAN HIEROGLYPH-1376A",NULL},
/* 1376B */ { "EGYPTIAN HIEROGLYPH-1376B",NULL},
/* 1376C */ { "EGYPTIAN HIEROGLYPH-1376C","	* classifier nursing, rearing : rnn"},
/* 1376D */ { "EGYPTIAN HIEROGLYPH-1376D","	* logogram (Amon) : ꞽmn"},
/* 1376E */ { "EGYPTIAN HIEROGLYPH-1376E","	* classifier Wepwawet (divinity)"},
/* 1376F */ { "EGYPTIAN HIEROGLYPH-1376F",NULL},
/* 13770 */ { "EGYPTIAN HIEROGLYPH-13770","	* classifier divinity : ḏsr-m-pr=f-m-sbḫ.t-ꜣḫ.t"},
/* 13771 */ { "EGYPTIAN HIEROGLYPH-13771","	* phonemogram : n"},
/* 13772 */ { "EGYPTIAN HIEROGLYPH-13772","	* classifier jubilation : hnw"},
/* 13773 */ { "EGYPTIAN HIEROGLYPH-13773","	* logogram (to drive away) : sḥrꞽ"},
/* 13774 */ { "EGYPTIAN HIEROGLYPH-13774","	* logogram (to drive away) : sḥrꞽ"},
/* 13775 */ { "EGYPTIAN HIEROGLYPH-13775",NULL},
/* 13776 */ { "EGYPTIAN HIEROGLYPH-13776","	* logogram (to drive away) : sḥrꞽ"},
/* 13777 */ { "EGYPTIAN HIEROGLYPH-13777","	* logogram (to drive away) : sḥrꞽ "},
/* 13778 */ { "EGYPTIAN HIEROGLYPH-13778","	* classifier driving away : sḥrꞽ"},
/* 13779 */ { "EGYPTIAN HIEROGLYPH-13779","	* logogram (Duamutef) : dwꜣ-mw.t=f"},
/* 1377A */ { "EGYPTIAN HIEROGLYPH-1377A","	* logogram (to be strong) : wsr"},
/* 1377B */ { "EGYPTIAN HIEROGLYPH-1377B","	* logogram (sovereign) : ꞽt.yt"},
/* 1377C */ { "EGYPTIAN HIEROGLYPH-1377C","	* logogram (Anubis) : ꞽnpw"},
/* 1377D */ { "EGYPTIAN HIEROGLYPH-1377D","	* classifier messenger : wpw.ty"},
/* 1377E */ { "EGYPTIAN HIEROGLYPH-1377E","	* logogram (messenger) : wpw.ty"},
/* 1377F */ { "EGYPTIAN HIEROGLYPH-1377F","	* logogram (to drive away) : sḥrꞽ"},
/* 13780 */ { "EGYPTIAN HIEROGLYPH-13780","	* logogram (to drive away) : sḥrꞽ"},
/* 13781 */ { "EGYPTIAN HIEROGLYPH-13781",NULL},
/* 13782 */ { "EGYPTIAN HIEROGLYPH-13782",NULL},
/* 13783 */ { "EGYPTIAN HIEROGLYPH-13783",NULL},
/* 13784 */ { "EGYPTIAN HIEROGLYPH-13784","	* logogram (to drive away) : sḥrꞽ"},
/* 13785 */ { "EGYPTIAN HIEROGLYPH-13785","	* logogram : šmꜣ.y"},
/* 13786 */ { "EGYPTIAN HIEROGLYPH-13786","	* classifier : nb.w-nr.w"},
/* 13787 */ { "EGYPTIAN HIEROGLYPH-13787",NULL},
/* 13788 */ { "EGYPTIAN HIEROGLYPH-13788","	* logogram (decease deamon) : šmꜣ.y"},
/* 13789 */ { "EGYPTIAN HIEROGLYPH-13789","	* logogram (decease deamon) : šmꜣ.y"},
/* 1378A */ { "EGYPTIAN HIEROGLYPH-1378A","	* logogram (decease deamon) : šmꜣ.yt"},
/* 1378B */ { "EGYPTIAN HIEROGLYPH-1378B","	* logogram (to drive away) : sḥrꞽ"},
/* 1378C */ { "EGYPTIAN HIEROGLYPH-1378C","	* logogram (burial) : ḳrs.t"},
/* 1378D */ { "EGYPTIAN HIEROGLYPH-1378D","	* classifier protector : (nḏ.t(y)t)"},
/* 1378E */ { "EGYPTIAN HIEROGLYPH-1378E",NULL},
/* 1378F */ { "EGYPTIAN HIEROGLYPH-1378F","	* classifier divinity (Apis) : ḥp"},
/* 13790 */ { "EGYPTIAN HIEROGLYPH-13790","	* classifier protector : mnw-n(y)-sw.t-m-nḫ.t=f"},
/* 13791 */ { "EGYPTIAN HIEROGLYPH-13791","	* phonemogram : wp"},
/* 13792 */ { "EGYPTIAN HIEROGLYPH-13792",NULL},
/* 13793 */ { "EGYPTIAN HIEROGLYPH-13793","	* phonemogram : w"},
/* 13794 */ { "EGYPTIAN HIEROGLYPH-13794","	* logogram (Shu) : šw"},
/* 13795 */ { "EGYPTIAN HIEROGLYPH-13795","	* logogram (son/child of) : sꜣ"},
/* 13796 */ { "EGYPTIAN HIEROGLYPH-13796","	* logogram (Horus) : ḥr"},
/* 13797 */ { "EGYPTIAN HIEROGLYPH-13797","	* classifier joy : hnw"},
/* 13798 */ { "EGYPTIAN HIEROGLYPH-13798","	* classifier falcon divinity : bḥd.ty"},
/* 13799 */ { "EGYPTIAN HIEROGLYPH-13799","	* classifier divinity : snw"},
/* 1379A */ { "EGYPTIAN HIEROGLYPH-1379A","	* logogram (majesty) : ḥm"},
/* 1379B */ { "EGYPTIAN HIEROGLYPH-1379B","	* phonemogram/logogram : sḫm"},
/* 1379C */ { "EGYPTIAN HIEROGLYPH-1379C","	* classifier divinity : sꜣḳ-ḥꜥ.w"},
/* 1379D */ { "EGYPTIAN HIEROGLYPH-1379D","	* logogram (Re) : rꜥ"},
/* 1379E */ { "EGYPTIAN HIEROGLYPH-1379E","	* logogram (Re) : rꜥ"},
/* 1379F */ { "EGYPTIAN HIEROGLYPH-1379F","	* logogram (Re) : rꜥ"},
/* 137A0 */ { "EGYPTIAN HIEROGLYPH-137A0","	* logogram (day) : hrw"},
/* 137A1 */ { "EGYPTIAN HIEROGLYPH-137A1","	* logogram (Re) : rꜥ"},
/* 137A2 */ { "EGYPTIAN HIEROGLYPH-137A2","	* logogram (Re) : rꜥ "},
/* 137A3 */ { "EGYPTIAN HIEROGLYPH-137A3",NULL},
/* 137A4 */ { "EGYPTIAN HIEROGLYPH-137A4","	* logogram (Re) : rꜥ"},
/* 137A5 */ { "EGYPTIAN HIEROGLYPH-137A5","	* logogram (Re and image) : rꜥ & sḫm"},
/* 137A6 */ { "EGYPTIAN HIEROGLYPH-137A6","	* logogram (Re and image) : rꜥ & sḫm"},
/* 137A7 */ { "EGYPTIAN HIEROGLYPH-137A7","	* logogram (the eye of Re) : ꞽr.t-rꜥ"},
/* 137A8 */ { "EGYPTIAN HIEROGLYPH-137A8","	* logogram (of Re) : n rꜥ"},
/* 137A9 */ { "EGYPTIAN HIEROGLYPH-137A9","	* logogram (son of Re) : sꜣ-rꜥ"},
/* 137AA */ { "EGYPTIAN HIEROGLYPH-137AA","	* classifier statue/likeness : sšm(.w)"},
/* 137AB */ { "EGYPTIAN HIEROGLYPH-137AB","	* classifier divinity : ꜥꜣ-mꜣꜥ-ḫrw"},
/* 137AC */ { "EGYPTIAN HIEROGLYPH-137AC","	* logogram (to live) : ꜥnḫ"},
/* 137AD */ { "EGYPTIAN HIEROGLYPH-137AD","	* logogram (eye of Horus) : ꞽr.t-ḥr "},
/* 137AE */ { "EGYPTIAN HIEROGLYPH-137AE","	* phonemogram/logogram (lord) : nb"},
/* 137AF */ { "EGYPTIAN HIEROGLYPH-137AF","	* logogram (majesty) : ḥm"},
/* 137B0 */ { "EGYPTIAN HIEROGLYPH-137B0","	* logogram (spirit) : kꜣ"},
/* 137B1 */ { "EGYPTIAN HIEROGLYPH-137B1","	* logogram (power, strength) : ḫpš"},
/* 137B2 */ { "EGYPTIAN HIEROGLYPH-137B2","	* phonemogram/logogram : sḫm"},
/* 137B3 */ { "EGYPTIAN HIEROGLYPH-137B3","	* logogram (god) : nṯr"},
/* 137B4 */ { "EGYPTIAN HIEROGLYPH-137B4","	* logogram (beloved of Horus) : mr.y-ḥr"},
/* 137B5 */ { "EGYPTIAN HIEROGLYPH-137B5","	* classifier Sokar (divinity)"},
/* 137B6 */ { "EGYPTIAN HIEROGLYPH-137B6","	* classifier Sokar (divinity)"},
/* 137B7 */ { "EGYPTIAN HIEROGLYPH-137B7",NULL},
/* 137B8 */ { "EGYPTIAN HIEROGLYPH-137B8","	* classifier Montu (divinity)"},
/* 137B9 */ { "EGYPTIAN HIEROGLYPH-137B9","	* classifier divinity : mr.ty"},
/* 137BA */ { "EGYPTIAN HIEROGLYPH-137BA","	* logogram (first person singular) : ꞽ"},
/* 137BB */ { "EGYPTIAN HIEROGLYPH-137BB",NULL},
/* 137BC */ { "EGYPTIAN HIEROGLYPH-137BC","	* logogram (Khonsu) : ḫnsw"},
/* 137BD */ { "EGYPTIAN HIEROGLYPH-137BD","	* classifier Khonsu (divinity)"},
/* 137BE */ { "EGYPTIAN HIEROGLYPH-137BE",NULL},
/* 137BF */ { "EGYPTIAN HIEROGLYPH-137BF","	* logogram (the one of the horizon) : ꜣḫ.ty"},
/* 137C0 */ { "EGYPTIAN HIEROGLYPH-137C0",NULL},
/* 137C1 */ { "EGYPTIAN HIEROGLYPH-137C1","	* logogram (god) : nṯr"},
/* 137C2 */ { "EGYPTIAN HIEROGLYPH-137C2","	* logogram (in the ꜥnḫ-nṯr-nfr construction) : ꜥnḫ-nṯr"},
/* 137C3 */ { "EGYPTIAN HIEROGLYPH-137C3","	* logogram (god and goddess) : nṯr nṯr.t"},
/* 137C4 */ { "EGYPTIAN HIEROGLYPH-137C4","	* logogram (god) : nṯr"},
/* 137C5 */ { "EGYPTIAN HIEROGLYPH-137C5","	* logogram (Re) : rꜥ"},
/* 137C6 */ { "EGYPTIAN HIEROGLYPH-137C6","	* logogram (the one of the horizon) : ꜣḫ.ty"},
/* 137C7 */ { "EGYPTIAN HIEROGLYPH-137C7","	* logogram (Horus, Behedety) : ḥr-bḥd.ty"},
/* 137C8 */ { "EGYPTIAN HIEROGLYPH-137C8","	* logogram (Horus) : ḥr"},
/* 137C9 */ { "EGYPTIAN HIEROGLYPH-137C9","	* logogram (Horus, protector of his father, Behedety, the many-coloured of plumage, giving life) : ḥr-nḏ-ꞽt=f-bḥd.ty-sꜣb-šw.t-dꞽ-ꜥnḫ"},
/* 137CA */ { "EGYPTIAN HIEROGLYPH-137CA",NULL},
/* 137CB */ { "EGYPTIAN HIEROGLYPH-137CB","	* logogram (god) : nṯr"},
/* 137CC */ { "EGYPTIAN HIEROGLYPH-137CC","	* logogram (the one of the horizon) : ꜣḫ.ty"},
/* 137CD */ { "EGYPTIAN HIEROGLYPH-137CD","	* logogram (Re) : rꜥ"},
/* 137CE */ { "EGYPTIAN HIEROGLYPH-137CE","	* logogram (Horus of the east) : ḥr-ꞽꜣb.ty"},
/* 137CF */ { "EGYPTIAN HIEROGLYPH-137CF",NULL},
/* 137D0 */ { "EGYPTIAN HIEROGLYPH-137D0","	* logogram (strength, power) : pḥ.ty"},
/* 137D1 */ { "EGYPTIAN HIEROGLYPH-137D1","	* logogram (eternity) : nḥḥ"},
/* 137D2 */ { "EGYPTIAN HIEROGLYPH-137D2","	* logogram nHH (eternity)"},
/* 137D3 */ { "EGYPTIAN HIEROGLYPH-137D3","	* logogram (eternity) : nḥḥ"},
/* 137D4 */ { "EGYPTIAN HIEROGLYPH-137D4","	* logogram (eternity) : nḥḥ"},
/* 137D5 */ { "EGYPTIAN HIEROGLYPH-137D5","	* logogram (the sole one, unique) : wꜥ.ty"},
/* 137D6 */ { "EGYPTIAN HIEROGLYPH-137D6","	* classifier divinity : ꞽn-ḥr.t"},
/* 137D7 */ { "EGYPTIAN HIEROGLYPH-137D7","	* logogram (lord of the two lands, when used in connection with a Seth-headed figure) : nb-tꜣ.wy"},
/* 137D8 */ { "EGYPTIAN HIEROGLYPH-137D8","	* classifier harpooner : ꞽ(ꜣ)w.ty"},
/* 137D9 */ { "EGYPTIAN HIEROGLYPH-137D9",NULL},
/* 137DA */ { "EGYPTIAN HIEROGLYPH-137DA","	* logogram (valour, strength) : ḳn.t"},
/* 137DB */ { "EGYPTIAN HIEROGLYPH-137DB","	* logogram (valour, strength) : ḳn.t"},
/* 137DC */ { "EGYPTIAN HIEROGLYPH-137DC","	* logogram (Qebehsenuef) : ḳbḥ-sn.w=f"},
/* 137DD */ { "EGYPTIAN HIEROGLYPH-137DD",NULL},
/* 137DE */ { "EGYPTIAN HIEROGLYPH-137DE","	* phonemogram : ḥr"},
/* 137DF */ { "EGYPTIAN HIEROGLYPH-137DF","	* logogram (Wenty) : wnty"},
/* 137E0 */ { "EGYPTIAN HIEROGLYPH-137E0","	* logogram (Wenty) : wnty"},
/* 137E1 */ { "EGYPTIAN HIEROGLYPH-137E1",NULL},
/* 137E2 */ { "EGYPTIAN HIEROGLYPH-137E2","	* logogram (Wenty) : wnty"},
/* 137E3 */ { "EGYPTIAN HIEROGLYPH-137E3","	* classifier divinity : wnty"},
/* 137E4 */ { "EGYPTIAN HIEROGLYPH-137E4","	* classifier harpooner : (ꞽ)ꜣ(w).ty"},
/* 137E5 */ { "EGYPTIAN HIEROGLYPH-137E5","	* logogram (harpooner) or Logogram (Wenty) : ꞽꜣw.ty | wnty"},
/* 137E6 */ { "EGYPTIAN HIEROGLYPH-137E6","	* logogram (Wenty) : wnty"},
/* 137E7 */ { "EGYPTIAN HIEROGLYPH-137E7","	* classifier divinity (Geb) : gbb"},
/* 137E8 */ { "EGYPTIAN HIEROGLYPH-137E8","	* logogram (million, many) : ḥḥ"},
/* 137E9 */ { "EGYPTIAN HIEROGLYPH-137E9","	* logogram (million, many) : ḥḥ"},
/* 137EA */ { "EGYPTIAN HIEROGLYPH-137EA","	* logogram (million, many) : ḥḥ"},
/* 137EB */ { "EGYPTIAN HIEROGLYPH-137EB","	* logogram (million, many) : ḥḥ"},
/* 137EC */ { "EGYPTIAN HIEROGLYPH-137EC","	* logogram (million, many) : ḥḥ"},
/* 137ED */ { "EGYPTIAN HIEROGLYPH-137ED","	* logogram (millions of years) : ḥḥ (n) ꜥnḫ"},
/* 137EE */ { "EGYPTIAN HIEROGLYPH-137EE","	* logogram (million, many) : ḥḥ"},
/* 137EF */ { "EGYPTIAN HIEROGLYPH-137EF","	* logogram (million, many) : ḥḥ"},
/* 137F0 */ { "EGYPTIAN HIEROGLYPH-137F0","	* logogram (eternity) : ḥḥ"},
/* 137F1 */ { "EGYPTIAN HIEROGLYPH-137F1",NULL},
/* 137F2 */ { "EGYPTIAN HIEROGLYPH-137F2","	* logogram (million, many) : ḥḥ"},
/* 137F3 */ { "EGYPTIAN HIEROGLYPH-137F3","	* logogram (all eternity) : ḥḥ nb"},
/* 137F4 */ { "EGYPTIAN HIEROGLYPH-137F4",NULL},
/* 137F5 */ { "EGYPTIAN HIEROGLYPH-137F5","	* logogram (million, many) : ḥḥ"},
/* 137F6 */ { "EGYPTIAN HIEROGLYPH-137F6","	* logogram (million, many) : ḥḥ"},
/* 137F7 */ { "EGYPTIAN HIEROGLYPH-137F7","	* logogram Heh (million, many) : ḥḥ"},
/* 137F8 */ { "EGYPTIAN HIEROGLYPH-137F8","	* logogram (million, many) : ḥḥ"},
/* 137F9 */ { "EGYPTIAN HIEROGLYPH-137F9","	* phonemogram : ḥ"},
/* 137FA */ { "EGYPTIAN HIEROGLYPH-137FA","	* logogram (million, many) : ḥḥ"},
/* 137FB */ { "EGYPTIAN HIEROGLYPH-137FB",NULL},
/* 137FC */ { "EGYPTIAN HIEROGLYPH-137FC","	* logogram (million, many) : ḥḥ"},
/* 137FD */ { "EGYPTIAN HIEROGLYPH-137FD","	* logogram (million, many) : ḥḥ"},
/* 137FE */ { "EGYPTIAN HIEROGLYPH-137FE","	* logogram (million, many) : ḥḥ"},
/* 137FF */ { "EGYPTIAN HIEROGLYPH-137FF","	* logogram (million, many) : ḥḥ"}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_38[] = {
/* 13800 */ { "EGYPTIAN HIEROGLYPH-13800","	* logogram (million, many) : ḥḥ"},
/* 13801 */ { "EGYPTIAN HIEROGLYPH-13801","	* logogram (million, many) : ḥḥ"},
/* 13802 */ { "EGYPTIAN HIEROGLYPH-13802","	* logogram (million, many) : ḥḥ"},
/* 13803 */ { "EGYPTIAN HIEROGLYPH-13803","	* logogram (million, many) : ḥḥ"},
/* 13804 */ { "EGYPTIAN HIEROGLYPH-13804","	* classifier to wean : wḏḥ"},
/* 13805 */ { "EGYPTIAN HIEROGLYPH-13805","	* classifier to wean : wḏḥ"},
/* 13806 */ { "EGYPTIAN HIEROGLYPH-13806","	* logogram (Atum) : ꞽtmw"},
/* 13807 */ { "EGYPTIAN HIEROGLYPH-13807",NULL},
/* 13808 */ { "EGYPTIAN HIEROGLYPH-13808","	* classifier child : sḏ.ty"},
/* 13809 */ { "EGYPTIAN HIEROGLYPH-13809","	* logogram (first person singular) : ꞽ"},
/* 1380A */ { "EGYPTIAN HIEROGLYPH-1380A","	* logogram (Horus the child) : ḥr-pꜣ-ẖrd"},
/* 1380B */ { "EGYPTIAN HIEROGLYPH-1380B","	* classifier creator : ḫnm.w"},
/* 1380C */ { "EGYPTIAN HIEROGLYPH-1380C","	* logogram (Khnum) : ẖnm.w"},
/* 1380D */ { "EGYPTIAN HIEROGLYPH-1380D","	* logogram (Khnum) : ẖnm.w"},
/* 1380E */ { "EGYPTIAN HIEROGLYPH-1380E","	* phonemogram : ẖnm"},
/* 1380F */ { "EGYPTIAN HIEROGLYPH-1380F","	* logogram (Khnum) : ẖnm.w"},
/* 13810 */ { "EGYPTIAN HIEROGLYPH-13810","	* logogram (Khnum) : ẖnm.w"},
/* 13811 */ { "EGYPTIAN HIEROGLYPH-13811","	* logogram (Khnum) : ẖnm.w"},
/* 13812 */ { "EGYPTIAN HIEROGLYPH-13812","	* classifier Khnum : ẖnm.w"},
/* 13813 */ { "EGYPTIAN HIEROGLYPH-13813","	* classifier Khnum : ẖnm.w"},
/* 13814 */ { "EGYPTIAN HIEROGLYPH-13814",NULL},
/* 13815 */ { "EGYPTIAN HIEROGLYPH-13815","	* logogram (Khnum) : ẖnm.w"},
/* 13816 */ { "EGYPTIAN HIEROGLYPH-13816","	* logogram (creator) : nḥp"},
/* 13817 */ { "EGYPTIAN HIEROGLYPH-13817","	* logogram (creator) : nḥp"},
/* 13818 */ { "EGYPTIAN HIEROGLYPH-13818","	* logogram (to build, to create) : ḳd"},
/* 13819 */ { "EGYPTIAN HIEROGLYPH-13819","	* logogram (to create, to form) : nḥp"},
/* 1381A */ { "EGYPTIAN HIEROGLYPH-1381A","	* logogram (to build) : ẖnm"},
/* 1381B */ { "EGYPTIAN HIEROGLYPH-1381B","	* phonemogram : r"},
/* 1381C */ { "EGYPTIAN HIEROGLYPH-1381C",NULL},
/* 1381D */ { "EGYPTIAN HIEROGLYPH-1381D","	* logogram (messenger) : wpw.ty"},
/* 1381E */ { "EGYPTIAN HIEROGLYPH-1381E","	* logogram (Min) : mnw"},
/* 1381F */ { "EGYPTIAN HIEROGLYPH-1381F",NULL},
/* 13820 */ { "EGYPTIAN HIEROGLYPH-13820","	* classifier divinity : kꜣ-mw.t=f"},
/* 13821 */ { "EGYPTIAN HIEROGLYPH-13821",NULL},
/* 13822 */ { "EGYPTIAN HIEROGLYPH-13822",NULL},
/* 13823 */ { "EGYPTIAN HIEROGLYPH-13823",NULL},
/* 13824 */ { "EGYPTIAN HIEROGLYPH-13824","	* logogram (the flood) : hꜥpy"},
/* 13825 */ { "EGYPTIAN HIEROGLYPH-13825","	* logogram (the flood) : hꜥpy"},
/* 13826 */ { "EGYPTIAN HIEROGLYPH-13826","	* logogram (the Nile/the flood) : hꜥpy "},
/* 13827 */ { "EGYPTIAN HIEROGLYPH-13827","	* logogram (the Nile/the flood) : hꜥpy"},
/* 13828 */ { "EGYPTIAN HIEROGLYPH-13828",NULL},
/* 13829 */ { "EGYPTIAN HIEROGLYPH-13829","	* logogram (the Nile/the flood) : hꜥpy"},
/* 1382A */ { "EGYPTIAN HIEROGLYPH-1382A",NULL},
/* 1382B */ { "EGYPTIAN HIEROGLYPH-1382B","	* logogram (Onuris) : ꞽn-ḥr.t"},
/* 1382C */ { "EGYPTIAN HIEROGLYPH-1382C",NULL},
/* 1382D */ { "EGYPTIAN HIEROGLYPH-1382D","	* logogram (Onuris) : ꞽn-ḥr.t"},
/* 1382E */ { "EGYPTIAN HIEROGLYPH-1382E","	* logogram (Orion) : sꜣḥ"},
/* 1382F */ { "EGYPTIAN HIEROGLYPH-1382F","	* logogram (Orion) : sꜣḥ"},
/* 13830 */ { "EGYPTIAN HIEROGLYPH-13830","	* classifier Osiris : wsꞽr"},
/* 13831 */ { "EGYPTIAN HIEROGLYPH-13831","	* logogram (Osiris) : wsꞽr"},
/* 13832 */ { "EGYPTIAN HIEROGLYPH-13832",NULL},
/* 13833 */ { "EGYPTIAN HIEROGLYPH-13833","	* logogram (one who belongs to Seth) : stẖ.y"},
/* 13834 */ { "EGYPTIAN HIEROGLYPH-13834",NULL},
/* 13835 */ { "EGYPTIAN HIEROGLYPH-13835","	* classifier Osiris"},
/* 13836 */ { "EGYPTIAN HIEROGLYPH-13836","	* classifier Osiris : wsꞽr"},
/* 13837 */ { "EGYPTIAN HIEROGLYPH-13837","	* classifier Osiris : ḫnt.y-ꞽmn.tyw"},
/* 13838 */ { "EGYPTIAN HIEROGLYPH-13838","	* logogram (Osiris) : wsꞽr"},
/* 13839 */ { "EGYPTIAN HIEROGLYPH-13839","	* logogram (Ptah) : ptḥ"},
/* 1383A */ { "EGYPTIAN HIEROGLYPH-1383A","	* classifier Ptah : ptḥ"},
/* 1383B */ { "EGYPTIAN HIEROGLYPH-1383B","	* logogram (Ptah) : ptḥ"},
/* 1383C */ { "EGYPTIAN HIEROGLYPH-1383C","	* classifier divinity (Imhotep)"},
/* 1383D */ { "EGYPTIAN HIEROGLYPH-1383D","	* logogram (Ptah) : ptḥ"},
/* 1383E */ { "EGYPTIAN HIEROGLYPH-1383E","	* logogram (divine, godly) : nṯr.y"},
/* 1383F */ { "EGYPTIAN HIEROGLYPH-1383F","	* logogram (Ptah) : ptḥ"},
/* 13840 */ { "EGYPTIAN HIEROGLYPH-13840","	* logogram (divine, godly) : nṯr.y"},
/* 13841 */ { "EGYPTIAN HIEROGLYPH-13841","	* logogram (Ptah) : ptḥ"},
/* 13842 */ { "EGYPTIAN HIEROGLYPH-13842","	* classifier divinity : nfr-ḥr"},
/* 13843 */ { "EGYPTIAN HIEROGLYPH-13843","	* logogram (Re) : rꜥ"},
/* 13844 */ { "EGYPTIAN HIEROGLYPH-13844","	* classifier king of Upper Egypt : n(.y)-sw.t"},
/* 13845 */ { "EGYPTIAN HIEROGLYPH-13845","	* logogram (Re) : rꜥ"},
/* 13846 */ { "EGYPTIAN HIEROGLYPH-13846","	* logogram (Khepri) : ḫprꞽ"},
/* 13847 */ { "EGYPTIAN HIEROGLYPH-13847","	* logogram (powerful one) : sḫm"},
/* 13848 */ { "EGYPTIAN HIEROGLYPH-13848",NULL},
/* 13849 */ { "EGYPTIAN HIEROGLYPH-13849","	* logogram (one who belongs to Seth) : stẖ.y"},
/* 1384A */ { "EGYPTIAN HIEROGLYPH-1384A","	* logogram (one who belongs to Seth) : stẖ.y"},
/* 1384B */ { "EGYPTIAN HIEROGLYPH-1384B","	* classifier misery, pain : ꜣh/ꞽh"},
/* 1384C */ { "EGYPTIAN HIEROGLYPH-1384C",NULL},
/* 1384D */ { "EGYPTIAN HIEROGLYPH-1384D",NULL},
/* 1384E */ { "EGYPTIAN HIEROGLYPH-1384E","	* classifier vile one : ẖs-ḳd"},
/* 1384F */ { "EGYPTIAN HIEROGLYPH-1384F","	* classifier evil one : nbḏ"},
/* 13850 */ { "EGYPTIAN HIEROGLYPH-13850","	* classifier creation, form : ꞽr.w"},
/* 13851 */ { "EGYPTIAN HIEROGLYPH-13851","	* logogram (Sobek) : sbk"},
/* 13852 */ { "EGYPTIAN HIEROGLYPH-13852","	* classifier crocodile divinity : sbk-šmꜥ-nfr"},
/* 13853 */ { "EGYPTIAN HIEROGLYPH-13853","	* phonemogram (first person for sbk-šmꜥ-nfr) : ꞽ "},
/* 13854 */ { "EGYPTIAN HIEROGLYPH-13854",NULL},
/* 13855 */ { "EGYPTIAN HIEROGLYPH-13855","	* logogram (the one who watches her mansions) : rs.t-ḥw.wt=s"},
/* 13856 */ { "EGYPTIAN HIEROGLYPH-13856","	* logogram (Sopdu) : spd.w"},
/* 13857 */ { "EGYPTIAN HIEROGLYPH-13857","	* classifier guardian : ḥry-sḫ.t"},
/* 13858 */ { "EGYPTIAN HIEROGLYPH-13858","	* classifier guardian : ḫsf-sby.w"},
/* 13859 */ { "EGYPTIAN HIEROGLYPH-13859","	* classifier baboon divinity (i.e. Thot) : n.y-mꜣꜥ.t"},
/* 1385A */ { "EGYPTIAN HIEROGLYPH-1385A","	* logogram (Hapy) : ḥp.y"},
/* 1385B */ { "EGYPTIAN HIEROGLYPH-1385B","	* logogram (Tatenen) : tꜣ-ṯnn"},
/* 1385C */ { "EGYPTIAN HIEROGLYPH-1385C","	* logogram (Tatenen) : tꜣ-ṯnn"},
/* 1385D */ { "EGYPTIAN HIEROGLYPH-1385D","	* phonemogram : ṯn.tꞽ"},
/* 1385E */ { "EGYPTIAN HIEROGLYPH-1385E","	* classifier Tatenen : tꜣ-ṯnn"},
/* 1385F */ { "EGYPTIAN HIEROGLYPH-1385F","	* logogram (Tatenen) : tꜣ-ṯnn"},
/* 13860 */ { "EGYPTIAN HIEROGLYPH-13860","	* logogram (Tatenen) : tꜣ-ṯnn"},
/* 13861 */ { "EGYPTIAN HIEROGLYPH-13861","	* phonemogram : ṯn(w)"},
/* 13862 */ { "EGYPTIAN HIEROGLYPH-13862","	* phonemogram : sw"},
/* 13863 */ { "EGYPTIAN HIEROGLYPH-13863","	* logogram (Tatenen) : tꜣ-ṯnn"},
/* 13864 */ { "EGYPTIAN HIEROGLYPH-13864","	* logogram (Thot) : ḏhwty"},
/* 13865 */ { "EGYPTIAN HIEROGLYPH-13865","	* phonemogram : ḥr.y-ꞽb"},
/* 13866 */ { "EGYPTIAN HIEROGLYPH-13866","	* classifier Thoth : ꞽpy"},
/* 13867 */ { "EGYPTIAN HIEROGLYPH-13867",NULL},
/* 13868 */ { "EGYPTIAN HIEROGLYPH-13868","	* classifier moon : ꞽꜥḥ"},
/* 13869 */ { "EGYPTIAN HIEROGLYPH-13869",NULL},
/* 1386A */ { "EGYPTIAN HIEROGLYPH-1386A","	* classifier divinity : ḥkꜣ.w"},
/* 1386B */ { "EGYPTIAN HIEROGLYPH-1386B","	* phonemogram : ḥr.y-ꞽb"},
/* 1386C */ { "EGYPTIAN HIEROGLYPH-1386C","	* phonemogram : ḥr.y-ꞽb"},
/* 1386D */ { "EGYPTIAN HIEROGLYPH-1386D","	* logogram/phonemogram (to be great) : wr"},
/* 1386E */ { "EGYPTIAN HIEROGLYPH-1386E",NULL},
/* 1386F */ { "EGYPTIAN HIEROGLYPH-1386F","	* logogram (Thot) : ḏhwty"},
/* 13870 */ { "EGYPTIAN HIEROGLYPH-13870",NULL},
/* 13871 */ { "EGYPTIAN HIEROGLYPH-13871","	* logogram (son of Re) : sꜣ-rꜥ"},
/* 13872 */ { "EGYPTIAN HIEROGLYPH-13872","	* classifier earth-god : ꜣkr"},
/* 13873 */ { "EGYPTIAN HIEROGLYPH-13873","	* logogram (eternity) : nḥḥ"},
/* 13874 */ { "EGYPTIAN HIEROGLYPH-13874","	* phonemogram : dwꜣ.t"},
/* 13875 */ { "EGYPTIAN HIEROGLYPH-13875","	* phonemogram : ḥnꜥ"},
/* 13876 */ { "EGYPTIAN HIEROGLYPH-13876","	* classifier Anubis : ꜥnḳ.t"},
/* 13877 */ { "EGYPTIAN HIEROGLYPH-13877","	* classifier Anubis : ꜥnḳ.t"},
/* 13878 */ { "EGYPTIAN HIEROGLYPH-13878","	* classifier Renenutet : rnn.(w)ṯ(t)"},
/* 13879 */ { "EGYPTIAN HIEROGLYPH-13879",NULL},
/* 1387A */ { "EGYPTIAN HIEROGLYPH-1387A","	* classifier (in ḥs-nb=s) : ḥs"},
/* 1387B */ { "EGYPTIAN HIEROGLYPH-1387B","	* logogram (Keket) : kk.t"},
/* 1387C */ { "EGYPTIAN HIEROGLYPH-1387C","	* classifier divinity?"},
/* 1387D */ { "EGYPTIAN HIEROGLYPH-1387D","	* classifier Hathor : ḥw.t-ḥr"},
/* 1387E */ { "EGYPTIAN HIEROGLYPH-1387E","	* logogram (Isis) : ꜣs.t"},
/* 1387F */ { "EGYPTIAN HIEROGLYPH-1387F","	* classifier female divinity (usually associated with Hathor)"},
/* 13880 */ { "EGYPTIAN HIEROGLYPH-13880","	* logogram : nb"},
/* 13881 */ { "EGYPTIAN HIEROGLYPH-13881","	* logogram (powerful one) : sḫm.t"},
/* 13882 */ { "EGYPTIAN HIEROGLYPH-13882","	* logogram (majesty) : ḥm.t"},
/* 13883 */ { "EGYPTIAN HIEROGLYPH-13883","	* logogram/phonemogram (lord/lady) : nb"},
/* 13884 */ { "EGYPTIAN HIEROGLYPH-13884","	* logogram/phonemogram (lady) : nb.t "},
/* 13885 */ { "EGYPTIAN HIEROGLYPH-13885","	* logogram (life) : ꜥnḫ"},
/* 13886 */ { "EGYPTIAN HIEROGLYPH-13886","	* logogram/phonemogram (effective/splendid) : mnḫ"},
/* 13887 */ { "EGYPTIAN HIEROGLYPH-13887",NULL},
/* 13888 */ { "EGYPTIAN HIEROGLYPH-13888","	* logogram (mistress of the sistrum) : nb.t-sšš.t"},
/* 13889 */ { "EGYPTIAN HIEROGLYPH-13889","	* logogram (mistress of the sistrum) : nb.t-sšš.t"},
/* 1388A */ { "EGYPTIAN HIEROGLYPH-1388A","	* logogram (majesty) : ḥm.t"},
/* 1388B */ { "EGYPTIAN HIEROGLYPH-1388B","	* classifier divinity : ḥwt-ḥr"},
/* 1388C */ { "EGYPTIAN HIEROGLYPH-1388C","	* logogram (rejoicing) : nhm "},
/* 1388D */ { "EGYPTIAN HIEROGLYPH-1388D","	* logogram (rejoicing) : nhm"},
/* 1388E */ { "EGYPTIAN HIEROGLYPH-1388E","	* classifier to nurse : ꜣṯꞽ"},
/* 1388F */ { "EGYPTIAN HIEROGLYPH-1388F","	* logogram (to nurse, to rear (from rnn)) : rr"},
/* 13890 */ { "EGYPTIAN HIEROGLYPH-13890","	* logogram (Hathor) : ḥw.t-ḥr"},
/* 13891 */ { "EGYPTIAN HIEROGLYPH-13891","	* logogram (gold) : nbw"},
/* 13892 */ { "EGYPTIAN HIEROGLYPH-13892","	* logogram (ruler) : ḥḳꜣ.t"},
/* 13893 */ { "EGYPTIAN HIEROGLYPH-13893","	* logogram (the heavens/sky) : p.t"},
/* 13894 */ { "EGYPTIAN HIEROGLYPH-13894","	* classifier Hathor : ḥw.t-ḥr"},
/* 13895 */ { "EGYPTIAN HIEROGLYPH-13895","	* logogram (Hathor) : ḥw.t-ḥr"},
/* 13896 */ { "EGYPTIAN HIEROGLYPH-13896","	* logogram (Isis) : ꜣs.t"},
/* 13897 */ { "EGYPTIAN HIEROGLYPH-13897","	* logogram (Isis) : ꜣs.t"},
/* 13898 */ { "EGYPTIAN HIEROGLYPH-13898",NULL},
/* 13899 */ { "EGYPTIAN HIEROGLYPH-13899","	* logogram (Isis) : ꜣs.t"},
/* 1389A */ { "EGYPTIAN HIEROGLYPH-1389A",NULL},
/* 1389B */ { "EGYPTIAN HIEROGLYPH-1389B","	* classifier divinity : ꞽp.t-wr.t"},
/* 1389C */ { "EGYPTIAN HIEROGLYPH-1389C","	* logogram (Hathor) : ḥw.t-ḥr"},
/* 1389D */ { "EGYPTIAN HIEROGLYPH-1389D","	* logogram (Isis) : ꜣs.t"},
/* 1389E */ { "EGYPTIAN HIEROGLYPH-1389E","	* classifier Isis : ꜣs.t"},
/* 1389F */ { "EGYPTIAN HIEROGLYPH-1389F","	* logogram (Isis) : ꜣs.t"},
/* 138A0 */ { "EGYPTIAN HIEROGLYPH-138A0","	* classifier divinity : ḥḳꜣ.t"},
/* 138A1 */ { "EGYPTIAN HIEROGLYPH-138A1","	* classifier mourner : ḥꜣy.t"},
/* 138A2 */ { "EGYPTIAN HIEROGLYPH-138A2",NULL},
/* 138A3 */ { "EGYPTIAN HIEROGLYPH-138A3",NULL},
/* 138A4 */ { "EGYPTIAN HIEROGLYPH-138A4",NULL},
/* 138A5 */ { "EGYPTIAN HIEROGLYPH-138A5","	* logogram (Isis) : ꜣs.t"},
/* 138A6 */ { "EGYPTIAN HIEROGLYPH-138A6","	* logogram (Isis) : ꜣs.t"},
/* 138A7 */ { "EGYPTIAN HIEROGLYPH-138A7","	* logogram (the widow) : šntꜣy.t"},
/* 138A8 */ { "EGYPTIAN HIEROGLYPH-138A8","	* logogram (Isis) : ꜣs.t"},
/* 138A9 */ { "EGYPTIAN HIEROGLYPH-138A9","	* logogram (lord) : nb"},
/* 138AA */ { "EGYPTIAN HIEROGLYPH-138AA","	* logogram (to protect) : ḫwꞽ"},
/* 138AB */ { "EGYPTIAN HIEROGLYPH-138AB","	* logogram (to protect) : ḫwꞽ"},
/* 138AC */ { "EGYPTIAN HIEROGLYPH-138AC","	* phonemogram : snṯ-ꞽnbw"},
/* 138AD */ { "EGYPTIAN HIEROGLYPH-138AD","	* logogram/phonemogram (lady) : nb.t"},
/* 138AE */ { "EGYPTIAN HIEROGLYPH-138AE","	* classifier leonid divinity (female) : sḫm.t/bꜣs.tt"},
/* 138AF */ { "EGYPTIAN HIEROGLYPH-138AF","	* logogram (Sekhmet) : sḫm.t"},
/* 138B0 */ { "EGYPTIAN HIEROGLYPH-138B0","	* classifier leonid divinity (female) : sḫm.t"},
/* 138B1 */ { "EGYPTIAN HIEROGLYPH-138B1",NULL},
/* 138B2 */ { "EGYPTIAN HIEROGLYPH-138B2","	* classifier leonid divinity (male) : ḥḏ-ḥtp"},
/* 138B3 */ { "EGYPTIAN HIEROGLYPH-138B3",NULL},
/* 138B4 */ { "EGYPTIAN HIEROGLYPH-138B4","	* classifier leonid divinity (male) : ḫns-mꜣꜥ.t; bꜥḥ-ꞽb"},
/* 138B5 */ { "EGYPTIAN HIEROGLYPH-138B5",NULL},
/* 138B6 */ { "EGYPTIAN HIEROGLYPH-138B6","	* classifier leonid divinity (female) : bꜣs.tt"},
/* 138B7 */ { "EGYPTIAN HIEROGLYPH-138B7","	* classifier leonid divinity (female) : sḫm.t"},
/* 138B8 */ { "EGYPTIAN HIEROGLYPH-138B8","	* logogram (city, village) : nꞽw.t"},
/* 138B9 */ { "EGYPTIAN HIEROGLYPH-138B9","	* logogram (Sekhmet) : sḫm.t"},
/* 138BA */ { "EGYPTIAN HIEROGLYPH-138BA","	* classifier leonid divinity (female) : sḫm.t"},
/* 138BB */ { "EGYPTIAN HIEROGLYPH-138BB","	* classifier leonid divinity (female) : mnḥy.t"},
/* 138BC */ { "EGYPTIAN HIEROGLYPH-138BC",NULL},
/* 138BD */ { "EGYPTIAN HIEROGLYPH-138BD",NULL},
/* 138BE */ { "EGYPTIAN HIEROGLYPH-138BE","	* logogram (she who is on the throne/stairs (Bastet)) : ḥr.yt-ḫnd.w"},
/* 138BF */ { "EGYPTIAN HIEROGLYPH-138BF","	* logogram (to be hidden) : štꜣ"},
/* 138C0 */ { "EGYPTIAN HIEROGLYPH-138C0","	* classifier hidden : štꜣ"},
/* 138C1 */ { "EGYPTIAN HIEROGLYPH-138C1","	* logogram (to be hidden) : štꜣ"},
/* 138C2 */ { "EGYPTIAN HIEROGLYPH-138C2","	* classifier divinity? : mꜣ-ꜥnḫ"},
/* 138C3 */ { "EGYPTIAN HIEROGLYPH-138C3","	* classifier leonid divinity (female) : sḫm.t"},
/* 138C4 */ { "EGYPTIAN HIEROGLYPH-138C4","	* classifier leonid divinity (female) : bꜣs.tt"},
/* 138C5 */ { "EGYPTIAN HIEROGLYPH-138C5","	* logogram (vocative interjection) : ꞽ"},
/* 138C6 */ { "EGYPTIAN HIEROGLYPH-138C6","	* logogram (daughter of Re) : sꜣ.t-rꜥ"},
/* 138C7 */ { "EGYPTIAN HIEROGLYPH-138C7","	* phonemogram : šms"},
/* 138C8 */ { "EGYPTIAN HIEROGLYPH-138C8","	* logogram (Maat) : mꜣꜥ.t"},
/* 138C9 */ { "EGYPTIAN HIEROGLYPH-138C9","	* logogram (ruler of truth/Maat) : ḥḳꜣ-mꜣꜥ.t"},
/* 138CA */ { "EGYPTIAN HIEROGLYPH-138CA","	* logogram (truth) : mꜣꜥ"},
/* 138CB */ { "EGYPTIAN HIEROGLYPH-138CB","	* logogram (in name Ramses IV) : wsr-mꜣꜥ.t"},
/* 138CC */ { "EGYPTIAN HIEROGLYPH-138CC","	* classifier woman : rw.t-"},
/* 138CD */ { "EGYPTIAN HIEROGLYPH-138CD","	* logogram (Maat) : mꜣꜥ.t"},
/* 138CE */ { "EGYPTIAN HIEROGLYPH-138CE","	* classifier divinity : mꜣꜥ.t"},
/* 138CF */ { "EGYPTIAN HIEROGLYPH-138CF","	* classifier truth : mꜥꜣ.t"},
/* 138D0 */ { "EGYPTIAN HIEROGLYPH-138D0","	* logogram/phonemogram (whom truth/Maat loves) : mr(.y)-mꜣꜥ.t"},
/* 138D1 */ { "EGYPTIAN HIEROGLYPH-138D1","	* logogram (Maat) : mꜣꜥ.t"},
/* 138D2 */ { "EGYPTIAN HIEROGLYPH-138D2","	* logogram (in name Ramses II) : wsr-mꜣꜥ.t"},
/* 138D3 */ { "EGYPTIAN HIEROGLYPH-138D3","	* logogram (in name Ramses II) : wsr-mꜣꜥ.t"},
/* 138D4 */ { "EGYPTIAN HIEROGLYPH-138D4","	* logogram (in name Ramses II) : wsr-mꜣꜥ.t"},
/* 138D5 */ { "EGYPTIAN HIEROGLYPH-138D5","	* logogram (gate which gives truth) : rw.t-dꞽ(.t)-mꜣꜥ.t"},
/* 138D6 */ { "EGYPTIAN HIEROGLYPH-138D6","	* logogram (to be hidden) : štꜣ"},
/* 138D7 */ { "EGYPTIAN HIEROGLYPH-138D7","	* logogram (Meret) : mr.t"},
/* 138D8 */ { "EGYPTIAN HIEROGLYPH-138D8","	* classifier divinity : mr.t"},
/* 138D9 */ { "EGYPTIAN HIEROGLYPH-138D9","	* classifier divinity : mr.t"},
/* 138DA */ { "EGYPTIAN HIEROGLYPH-138DA","	* classifier divinity/musician : nb.tyw"},
/* 138DB */ { "EGYPTIAN HIEROGLYPH-138DB",NULL},
/* 138DC */ { "EGYPTIAN HIEROGLYPH-138DC","	* logogram (Meret) : mr.t"},
/* 138DD */ { "EGYPTIAN HIEROGLYPH-138DD","	* classifier divinity : mr.ty"},
/* 138DE */ { "EGYPTIAN HIEROGLYPH-138DE","	* logogram (Mut) : mw.t"},
/* 138DF */ { "EGYPTIAN HIEROGLYPH-138DF","	* logogram (together with \\C98 and \\C43A, representing the triad of Dendera) : ꞽwn.t "},
/* 138E0 */ { "EGYPTIAN HIEROGLYPH-138E0","	* classifier majesty : ḥm"},
/* 138E1 */ { "EGYPTIAN HIEROGLYPH-138E1","	* logogram (Mut) : mw.t"},
/* 138E2 */ { "EGYPTIAN HIEROGLYPH-138E2","	* logogram (Hathor) : ḥw.t-ḥr"},
/* 138E3 */ { "EGYPTIAN HIEROGLYPH-138E3","	* logogram (Hathor, giving life) : ḥw.t-ḥr-dꞽ-ꜥnḫ"},
/* 138E4 */ { "EGYPTIAN HIEROGLYPH-138E4","	* logogram (Hathor) : ḥw.t-ḥr"},
/* 138E5 */ { "EGYPTIAN HIEROGLYPH-138E5","	* phonemogram : n"},
/* 138E6 */ { "EGYPTIAN HIEROGLYPH-138E6","	* classifier divinity : dp.(y)t"},
/* 138E7 */ { "EGYPTIAN HIEROGLYPH-138E7","	* phonemogram : n"},
/* 138E8 */ { "EGYPTIAN HIEROGLYPH-138E8","	* logogram (Neith) : n.t"},
/* 138E9 */ { "EGYPTIAN HIEROGLYPH-138E9","	* logogram (Neith) : n.t"},
/* 138EA */ { "EGYPTIAN HIEROGLYPH-138EA","	* (cryptography) Phonemogram : wn"},
/* 138EB */ { "EGYPTIAN HIEROGLYPH-138EB","	* phonemogram : n(.t)"},
/* 138EC */ { "EGYPTIAN HIEROGLYPH-138EC","	* logogram (king of Lower Egypt) : bꞽ.ty"},
/* 138ED */ { "EGYPTIAN HIEROGLYPH-138ED","	* phonemogram : nt"},
/* 138EE */ { "EGYPTIAN HIEROGLYPH-138EE","	* classifier divinity (Neith) : n.t"},
/* 138EF */ { "EGYPTIAN HIEROGLYPH-138EF","	* phonemogram : wnn"},
/* 138F0 */ { "EGYPTIAN HIEROGLYPH-138F0","	* logogram (Dendera) : ꞽꜣ.t-dꞽ"},
/* 138F1 */ { "EGYPTIAN HIEROGLYPH-138F1","	* logogram (Nephthys) : nb.t-ḥw.t"},
/* 138F2 */ { "EGYPTIAN HIEROGLYPH-138F2","	* classifier sister (together with Isis) : sn.ty"},
/* 138F3 */ { "EGYPTIAN HIEROGLYPH-138F3","	* classifier mourner : ḥꜣy.t"},
/* 138F4 */ { "EGYPTIAN HIEROGLYPH-138F4","	* logogram (Nephthys) : nb.t-ḥw.t"},
/* 138F5 */ { "EGYPTIAN HIEROGLYPH-138F5","	* logogram (the heavens/sky) : p.t"},
/* 138F6 */ { "EGYPTIAN HIEROGLYPH-138F6","	* logogram (the heavens/sky) : p.t"},
/* 138F7 */ { "EGYPTIAN HIEROGLYPH-138F7","	* phonemogram : n"},
/* 138F8 */ { "EGYPTIAN HIEROGLYPH-138F8","	* logogram (the heavens/sky) : p.t"},
/* 138F9 */ { "EGYPTIAN HIEROGLYPH-138F9","	* logogram (hour) : wnw.t "},
/* 138FA */ { "EGYPTIAN HIEROGLYPH-138FA","	* logogram (city, village) : nꞽw.t"},
/* 138FB */ { "EGYPTIAN HIEROGLYPH-138FB","	* logogram (city, village) : nꞽw.t"},
/* 138FC */ { "EGYPTIAN HIEROGLYPH-138FC","	* logogram (the sky) : gb.t"},
/* 138FD */ { "EGYPTIAN HIEROGLYPH-138FD","	* logogram (the heavens/sky) : p.t"},
/* 138FE */ { "EGYPTIAN HIEROGLYPH-138FE","	* logogram/phonemogram (to shine) : psḏ"},
/* 138FF */ { "EGYPTIAN HIEROGLYPH-138FF","	* classifier divinity (Sothis) : spd.t"}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_39[] = {
/* 13900 */ { "EGYPTIAN HIEROGLYPH-13900","	* logogram (Seshat) : sšꜣ.t"},
/* 13901 */ { "EGYPTIAN HIEROGLYPH-13901",NULL},
/* 13902 */ { "EGYPTIAN HIEROGLYPH-13902","	* logogram (Seshat) : sšꜣ.t"},
/* 13903 */ { "EGYPTIAN HIEROGLYPH-13903","	* logogram (Seshat) : sšꜣ.t"},
/* 13904 */ { "EGYPTIAN HIEROGLYPH-13904","	* logogram (stretching the rope) : pḏ-šsr"},
/* 13905 */ { "EGYPTIAN HIEROGLYPH-13905","	* phonemogram : sbꜣ"},
/* 13906 */ { "EGYPTIAN HIEROGLYPH-13906",NULL},
/* 13907 */ { "EGYPTIAN HIEROGLYPH-13907","	* classifier bovid divinity : ḥsꜣ.t"},
/* 13908 */ { "EGYPTIAN HIEROGLYPH-13908","	* logogram/phonemogram (lord) : nb"},
/* 13909 */ { "EGYPTIAN HIEROGLYPH-13909","	* logogram (the throne (Edfu)) : wṯs.t"},
/* 1390A */ { "EGYPTIAN HIEROGLYPH-1390A","	* logogram (sovereign) : ꞽt.yt"},
/* 1390B */ { "EGYPTIAN HIEROGLYPH-1390B","	* logogram (sovereign) : ꞽt.yt"},
/* 1390C */ { "EGYPTIAN HIEROGLYPH-1390C","	* logogram (sovereign) : ꞽt.yt"},
/* 1390D */ { "EGYPTIAN HIEROGLYPH-1390D","	* logogram (ruler) : ḥḳꜣ.t"},
/* 1390E */ { "EGYPTIAN HIEROGLYPH-1390E","	* logogram (sovereign) : ꞽt.yt"},
/* 1390F */ { "EGYPTIAN HIEROGLYPH-1390F","	* logogram (ruler) : ḥḳꜣ.t"},
/* 13910 */ { "EGYPTIAN HIEROGLYPH-13910","	* phonemogram : wn"},
/* 13911 */ { "EGYPTIAN HIEROGLYPH-13911","	* phonemogram : wn"},
/* 13912 */ { "EGYPTIAN HIEROGLYPH-13912","	* phonemogram : wn"},
/* 13913 */ { "EGYPTIAN HIEROGLYPH-13913","	* phonemogram : wn"},
/* 13914 */ { "EGYPTIAN HIEROGLYPH-13914","	* phonemogram : wn"},
/* 13915 */ { "EGYPTIAN HIEROGLYPH-13915","	* classifier divinity : ꜥnṯ"},
/* 13916 */ { "EGYPTIAN HIEROGLYPH-13916","	* logogram : ḥꜣ.t-mḥ.yt"},
/* 13917 */ { "EGYPTIAN HIEROGLYPH-13917","	* classifier divinity : ḥꜣ.t-mḥ.yt"},
/* 13918 */ { "EGYPTIAN HIEROGLYPH-13918","	* classifier Hekat : ḥḳ.t"},
/* 13919 */ { "EGYPTIAN HIEROGLYPH-13919","	* logogram (Keku) : kk.w"},
/* 1391A */ { "EGYPTIAN HIEROGLYPH-1391A","	* logogram (the west) : ꞽmn.t"},
/* 1391B */ { "EGYPTIAN HIEROGLYPH-1391B","	* logogram (Serqet) : srḳ.t"},
/* 1391C */ { "EGYPTIAN HIEROGLYPH-1391C","	* logogram (Thebes) : wꜣs.t"},
/* 1391D */ { "EGYPTIAN HIEROGLYPH-1391D","	* phonemogram : r"},
/* 1391E */ { "EGYPTIAN HIEROGLYPH-1391E","	* logogram (moon)? : ꞽꜥḥ"},
/* 1391F */ { "EGYPTIAN HIEROGLYPH-1391F","	* classifier (Sekhet, goddess of the marshlands) : sḫ.t"},
/* 13920 */ { "EGYPTIAN HIEROGLYPH-13920","	* classifier divinity : ḏd.t"},
/* 13921 */ { "EGYPTIAN HIEROGLYPH-13921","	* classifier divinity : wr.t-šꜥ.t"},
/* 13922 */ { "EGYPTIAN HIEROGLYPH-13922","	* logogram (perception/knowledge) : sꞽꜣ.t"},
/* 13923 */ { "EGYPTIAN HIEROGLYPH-13923","	* logogram (morning) : dwꜣ.w"},
/* 13924 */ { "EGYPTIAN HIEROGLYPH-13924",NULL},
/* 13925 */ { "EGYPTIAN HIEROGLYPH-13925","	* logogram (morning) : dwꜣ.w"},
/* 13926 */ { "EGYPTIAN HIEROGLYPH-13926","	* logogram (morning) : dwꜣ.w"},
/* 13927 */ { "EGYPTIAN HIEROGLYPH-13927","	* logogram (morning) : dwꜣ.w"},
/* 13928 */ { "EGYPTIAN HIEROGLYPH-13928","	* logogram (morning) : dwꜣ.w"},
/* 13929 */ { "EGYPTIAN HIEROGLYPH-13929","	* logogram (the two of the horizon) : ꜣḫty.ty"},
/* 1392A */ { "EGYPTIAN HIEROGLYPH-1392A","	* logogram (the (four) supports) : sḫn.wt"},
/* 1392B */ { "EGYPTIAN HIEROGLYPH-1392B","	* logogram (Hathor) : ḥw.t-ḥr"},
/* 1392C */ { "EGYPTIAN HIEROGLYPH-1392C","	* logogram (Hathor) : ḥw.t-ḥr"},
/* 1392D */ { "EGYPTIAN HIEROGLYPH-1392D","	* classifier female : mnꞽ.t"},
/* 1392E */ { "EGYPTIAN HIEROGLYPH-1392E","	* logogram (head) : tp"},
/* 1392F */ { "EGYPTIAN HIEROGLYPH-1392F","	* classifier to laugh : nṯḥṯḥ"},
/* 13930 */ { "EGYPTIAN HIEROGLYPH-13930","	* classifier spit : ꞽsd"},
/* 13931 */ { "EGYPTIAN HIEROGLYPH-13931","	* classifier birthplace : msḫn.t"},
/* 13932 */ { "EGYPTIAN HIEROGLYPH-13932","	* logogram (Hathor) : ḥw.t-ḥr"},
/* 13933 */ { "EGYPTIAN HIEROGLYPH-13933","	* classifier staff"},
/* 13934 */ { "EGYPTIAN HIEROGLYPH-13934","	* phonemogram : ḥr.y-tp"},
/* 13935 */ { "EGYPTIAN HIEROGLYPH-13935","	* logogram (face) : ḥr"},
/* 13936 */ { "EGYPTIAN HIEROGLYPH-13936","	* logogram (face) : ḥr"},
/* 13937 */ { "EGYPTIAN HIEROGLYPH-13937","	* classifier human being : tm.yw"},
/* 13938 */ { "EGYPTIAN HIEROGLYPH-13938","	* classifier occupation : sr"},
/* 13939 */ { "EGYPTIAN HIEROGLYPH-13939","	* classifier calling : nꞽs"},
/* 1393A */ { "EGYPTIAN HIEROGLYPH-1393A","	* classifier calling : ḏsw"},
/* 1393B */ { "EGYPTIAN HIEROGLYPH-1393B",NULL},
/* 1393C */ { "EGYPTIAN HIEROGLYPH-1393C",NULL},
/* 1393D */ { "EGYPTIAN HIEROGLYPH-1393D","	* classifier eating : wnm"},
/* 1393E */ { "EGYPTIAN HIEROGLYPH-1393E","	* classifier child : ḫrd/nḫn"},
/* 1393F */ { "EGYPTIAN HIEROGLYPH-1393F","	* classifier child/small one : ḥwn"},
/* 13940 */ { "EGYPTIAN HIEROGLYPH-13940","	* classifier nursing : mnꜥ"},
/* 13941 */ { "EGYPTIAN HIEROGLYPH-13941","	* classifier dwarf/pigmy : dng"},
/* 13942 */ { "EGYPTIAN HIEROGLYPH-13942","	* classifier (to bow, to attack) : ꞽkꞽ"},
/* 13943 */ { "EGYPTIAN HIEROGLYPH-13943","	* classifier to fall : sḫr"},
/* 13944 */ { "EGYPTIAN HIEROGLYPH-13944","	* classifier to call : nꞽs"},
/* 13945 */ { "EGYPTIAN HIEROGLYPH-13945","	* classifier to rejoice : hnꞽ"},
/* 13946 */ { "EGYPTIAN HIEROGLYPH-13946","	* classifier turning around : nꜥw"},
/* 13947 */ { "EGYPTIAN HIEROGLYPH-13947",NULL},
/* 13948 */ { "EGYPTIAN HIEROGLYPH-13948","	* classifier to rejoice : ḥꜥꞽ"},
/* 13949 */ { "EGYPTIAN HIEROGLYPH-13949","	* logogram (Heh, divinity) : ḥḥ"},
/* 1394A */ { "EGYPTIAN HIEROGLYPH-1394A","	* classifier upside-down : sḫdḫd"},
/* 1394B */ { "EGYPTIAN HIEROGLYPH-1394B","	* classifier to swim : mḥꞽ"},
/* 1394C */ { "EGYPTIAN HIEROGLYPH-1394C",NULL},
/* 1394D */ { "EGYPTIAN HIEROGLYPH-1394D","	* classifier swimming : nbꞽ"},
/* 1394E */ { "EGYPTIAN HIEROGLYPH-1394E",NULL},
/* 1394F */ { "EGYPTIAN HIEROGLYPH-1394F","	* logogram (to be great) : wr"},
/* 13950 */ { "EGYPTIAN HIEROGLYPH-13950","	* classifier herald : ḥww.ty"},
/* 13951 */ { "EGYPTIAN HIEROGLYPH-13951","	* classifier to carry away, to take : ḫn(f)"},
/* 13952 */ { "EGYPTIAN HIEROGLYPH-13952","	* classifier herald : ḥww.ty"},
/* 13953 */ { "EGYPTIAN HIEROGLYPH-13953",NULL},
/* 13954 */ { "EGYPTIAN HIEROGLYPH-13954","	* classifier elder/official : sr"},
/* 13955 */ { "EGYPTIAN HIEROGLYPH-13955","	* classifier Orion : sꜣḥ"},
/* 13956 */ { "EGYPTIAN HIEROGLYPH-13956","	* classifier to spit, to spew : bšꞽ"},
/* 13957 */ { "EGYPTIAN HIEROGLYPH-13957","	* classifier to lift, to carry : fꜣꞽ"},
/* 13958 */ { "EGYPTIAN HIEROGLYPH-13958","	* classifier to drive away : ḫsr"},
/* 13959 */ { "EGYPTIAN HIEROGLYPH-13959","	* classifier to oppose, to rebel : ḫsbꞽ"},
/* 1395A */ { "EGYPTIAN HIEROGLYPH-1395A","	* classifier to extend : sꜣwꞽ"},
/* 1395B */ { "EGYPTIAN HIEROGLYPH-1395B","	* classifier to scatter : sṯꞽ"},
/* 1395C */ { "EGYPTIAN HIEROGLYPH-1395C",NULL},
/* 1395D */ { "EGYPTIAN HIEROGLYPH-1395D","	* classifier dancing : rw.t"},
/* 1395E */ { "EGYPTIAN HIEROGLYPH-1395E","	* classifier guarding, protecting : sꜣw"},
/* 1395F */ { "EGYPTIAN HIEROGLYPH-1395F","	* classifier drinking : swr"},
/* 13960 */ { "EGYPTIAN HIEROGLYPH-13960","	* classifier to uproot : fdꞽ"},
/* 13961 */ { "EGYPTIAN HIEROGLYPH-13961",NULL},
/* 13962 */ { "EGYPTIAN HIEROGLYPH-13962","	* classifier to churn up : ꜥḏ"},
/* 13963 */ { "EGYPTIAN HIEROGLYPH-13963","	* classifier breaking/destroying : sḏ dšr.t"},
/* 13964 */ { "EGYPTIAN HIEROGLYPH-13964","	* classifier to expel, to drive of : rwꞽ"},
/* 13965 */ { "EGYPTIAN HIEROGLYPH-13965","	* classifier potter : ḳd.w"},
/* 13966 */ { "EGYPTIAN HIEROGLYPH-13966","	* classifier to climb, to fly : ḥfdꞽ"},
/* 13967 */ { "EGYPTIAN HIEROGLYPH-13967","	* classifier (to melt, to cast) : nbꞽ"},
/* 13968 */ { "EGYPTIAN HIEROGLYPH-13968",NULL},
/* 13969 */ { "EGYPTIAN HIEROGLYPH-13969","	* classifier to drive away : ḫs(r)"},
/* 1396A */ { "EGYPTIAN HIEROGLYPH-1396A","	* logogram (lifetime) : ꜥḥꜥ.w"},
/* 1396B */ { "EGYPTIAN HIEROGLYPH-1396B","	* logogram (evil one) : nbḏ"},
/* 1396C */ { "EGYPTIAN HIEROGLYPH-1396C",NULL},
/* 1396D */ { "EGYPTIAN HIEROGLYPH-1396D","	* logogram (evil one) : nbḏ"},
/* 1396E */ { "EGYPTIAN HIEROGLYPH-1396E","	* classifier tresses : nꜣb.t"},
/* 1396F */ { "EGYPTIAN HIEROGLYPH-1396F","	* classifier tresses : nꜣb.t"},
/* 13970 */ { "EGYPTIAN HIEROGLYPH-13970","	* logogram (head covering (braid of hair?)) : (ꞽ)ꜣr.t"},
/* 13971 */ { "EGYPTIAN HIEROGLYPH-13971","	* classifier scalp, temple : smꜣ"},
/* 13972 */ { "EGYPTIAN HIEROGLYPH-13972","	* classifier hairlock : ḥnsk.t"},
/* 13973 */ { "EGYPTIAN HIEROGLYPH-13973","	* logogram (to see) : mꜥꜥ"},
/* 13974 */ { "EGYPTIAN HIEROGLYPH-13974","	* classifier eye-paint : smd.t"},
/* 13975 */ { "EGYPTIAN HIEROGLYPH-13975","	* phonemogram : ꞽrꞽ-ẖr"},
/* 13976 */ { "EGYPTIAN HIEROGLYPH-13976","	* classifier eye related actions : dgꞽ"},
/* 13977 */ { "EGYPTIAN HIEROGLYPH-13977","	* classifier eye related actions : dgꞽ"},
/* 13978 */ { "EGYPTIAN HIEROGLYPH-13978","	* classifier eye related actions : ḫf"},
/* 13979 */ { "EGYPTIAN HIEROGLYPH-13979","	* classifier eye related actions : ptr"},
/* 1397A */ { "EGYPTIAN HIEROGLYPH-1397A","	* logogram (to see, to behold) : ptr"},
/* 1397B */ { "EGYPTIAN HIEROGLYPH-1397B","	* phonemogram : mꜣ"},
/* 1397C */ { "EGYPTIAN HIEROGLYPH-1397C","	* classifier sleep : ḳd"},
/* 1397D */ { "EGYPTIAN HIEROGLYPH-1397D","	* phonemogram : ꜥntyw"},
/* 1397E */ { "EGYPTIAN HIEROGLYPH-1397E","	* classifier adornment/beauty"},
/* 1397F */ { "EGYPTIAN HIEROGLYPH-1397F","	* classifier (to sleep) : ḳdd"},
/* 13980 */ { "EGYPTIAN HIEROGLYPH-13980","	* classifier eye related actions : ptr"},
/* 13981 */ { "EGYPTIAN HIEROGLYPH-13981",NULL},
/* 13982 */ { "EGYPTIAN HIEROGLYPH-13982","	* phonemogram : ꜥn"},
/* 13983 */ { "EGYPTIAN HIEROGLYPH-13983",NULL},
/* 13984 */ { "EGYPTIAN HIEROGLYPH-13984","	* phonemogram : ꜥn"},
/* 13985 */ { "EGYPTIAN HIEROGLYPH-13985","	* logogram (to wake) : rs"},
/* 13986 */ { "EGYPTIAN HIEROGLYPH-13986","	* logogram (to weep) : rmꞽ"},
/* 13987 */ { "EGYPTIAN HIEROGLYPH-13987","	* classifier weeping/crying : rmꞽ"},
/* 13988 */ { "EGYPTIAN HIEROGLYPH-13988","	* phonemogram : rm"},
/* 13989 */ { "EGYPTIAN HIEROGLYPH-13989","	* logogram (to weep) : rmꞽ"},
/* 1398A */ { "EGYPTIAN HIEROGLYPH-1398A","	* classifier weeping/crying : rmꞽ"},
/* 1398B */ { "EGYPTIAN HIEROGLYPH-1398B","	* classifier eye related actions : dgꞽ"},
/* 1398C */ { "EGYPTIAN HIEROGLYPH-1398C","	* logogram (the \"\"dazzling-eye\"\" (Egypt)) : bꜣḳ.t"},
/* 1398D */ { "EGYPTIAN HIEROGLYPH-1398D","	* logogram (eye) : ꞽr.t"},
/* 1398E */ { "EGYPTIAN HIEROGLYPH-1398E","	* logogram (the eye of Re) : ꞽr.t-rꜥ"},
/* 1398F */ { "EGYPTIAN HIEROGLYPH-1398F","	* logogram (to see) : mꜣꜣ"},
/* 13990 */ { "EGYPTIAN HIEROGLYPH-13990","	* classifier backside : mḥꜣ"},
/* 13991 */ { "EGYPTIAN HIEROGLYPH-13991","	* classifier nose : šr.t"},
/* 13992 */ { "EGYPTIAN HIEROGLYPH-13992","	* classifier to suckle : snḳ"},
/* 13993 */ { "EGYPTIAN HIEROGLYPH-13993",NULL},
/* 13994 */ { "EGYPTIAN HIEROGLYPH-13994","	* logogram 1/3"},
/* 13995 */ { "EGYPTIAN HIEROGLYPH-13995","	* logogram (2/3) : r.wy"},
/* 13996 */ { "EGYPTIAN HIEROGLYPH-13996","	* interpretant : r"},
/* 13997 */ { "EGYPTIAN HIEROGLYPH-13997","	* logogram (lip, border, edge) : sp.t"},
/* 13998 */ { "EGYPTIAN HIEROGLYPH-13998","	* logogram (lips) : sp.ty"},
/* 13999 */ { "EGYPTIAN HIEROGLYPH-13999","	* classifier spit : ꞽšš"},
/* 1399A */ { "EGYPTIAN HIEROGLYPH-1399A","	* logogram (breakfast (washing the mouth)) : ꞽꜥ.w-r"},
/* 1399B */ { "EGYPTIAN HIEROGLYPH-1399B","	* classifier spit : nš/nẖ"},
/* 1399C */ { "EGYPTIAN HIEROGLYPH-1399C","	* phonemogram : p"},
/* 1399D */ { "EGYPTIAN HIEROGLYPH-1399D","	* phonemogram : p"},
/* 1399E */ { "EGYPTIAN HIEROGLYPH-1399E","	* classifier beard or Classifier hair : ḫꜣbs | ḥnsk.t"},
/* 1399F */ { "EGYPTIAN HIEROGLYPH-1399F","	* logogram (to sit) : ḥmsꞽ"},
/* 139A0 */ { "EGYPTIAN HIEROGLYPH-139A0","	* logogram (spirit, essence) : kꜣ"},
/* 139A1 */ { "EGYPTIAN HIEROGLYPH-139A1",NULL},
/* 139A2 */ { "EGYPTIAN HIEROGLYPH-139A2","	* logogram (spirit, essence) : kꜣ"},
/* 139A3 */ { "EGYPTIAN HIEROGLYPH-139A3","	* logogram (royal spirit/essence) : kꜣ-n(.y)-sw.t"},
/* 139A4 */ { "EGYPTIAN HIEROGLYPH-139A4","	* logogram (food, provisions) : kꜣ"},
/* 139A5 */ { "EGYPTIAN HIEROGLYPH-139A5","	* logogram (food, provisions) : kꜣ"},
/* 139A6 */ { "EGYPTIAN HIEROGLYPH-139A6","	* logogram (negative relative adjective) : ꞽw.ty"},
/* 139A7 */ { "EGYPTIAN HIEROGLYPH-139A7","	* phonemogram : ḫm"},
/* 139A8 */ { "EGYPTIAN HIEROGLYPH-139A8",NULL},
/* 139A9 */ { "EGYPTIAN HIEROGLYPH-139A9","	* phono-repeater : ḫm"},
/* 139AA */ { "EGYPTIAN HIEROGLYPH-139AA","	* phono-repeater (kidney) : sḫn"},
/* 139AB */ { "EGYPTIAN HIEROGLYPH-139AB","	* classifier to embrace : ḥpt"},
/* 139AC */ { "EGYPTIAN HIEROGLYPH-139AC","	* logogram (to embrace) : ḥpt"},
/* 139AD */ { "EGYPTIAN HIEROGLYPH-139AD","	* classifier (in ẖꜣm-(ꞽ)ḫ.t) : ẖꜥm"},
/* 139AE */ { "EGYPTIAN HIEROGLYPH-139AE","	* logogram (mortuary priest) : ḥm-kꜣ"},
/* 139AF */ { "EGYPTIAN HIEROGLYPH-139AF",NULL},
/* 139B0 */ { "EGYPTIAN HIEROGLYPH-139B0","	* logogram (to row, to convey by water) : ẖnꞽ"},
/* 139B1 */ { "EGYPTIAN HIEROGLYPH-139B1","	* classifier movement by boat : sḳdꞽ"},
/* 139B2 */ { "EGYPTIAN HIEROGLYPH-139B2","	* logogram (to row, to convey by water) : ẖnꞽ"},
/* 139B3 */ { "EGYPTIAN HIEROGLYPH-139B3","	* phonemogram : ẖn"},
/* 139B4 */ { "EGYPTIAN HIEROGLYPH-139B4","	* classifier grasping the oar : ḫmꜥ.w-ḥmw"},
/* 139B5 */ { "EGYPTIAN HIEROGLYPH-139B5","	* phonemogram : ẖn"},
/* 139B6 */ { "EGYPTIAN HIEROGLYPH-139B6","	* phonemogram : ẖn"},
/* 139B7 */ { "EGYPTIAN HIEROGLYPH-139B7","	* logogram (to fight) : ꜥḥꜣ"},
/* 139B8 */ { "EGYPTIAN HIEROGLYPH-139B8","	* logogram (to fight) : ꜥḥꜣ"},
/* 139B9 */ { "EGYPTIAN HIEROGLYPH-139B9","	* logogram (to fight) : ꜥḥꜣ"},
/* 139BA */ { "EGYPTIAN HIEROGLYPH-139BA","	* logogram (to fight) : ꜥḥꜣ"},
/* 139BB */ { "EGYPTIAN HIEROGLYPH-139BB",NULL},
/* 139BC */ { "EGYPTIAN HIEROGLYPH-139BC","	* logogram (to fight) (in ꜥḥꜣ.t (fighter (female)) : ꜥḥꜣ"},
/* 139BD */ { "EGYPTIAN HIEROGLYPH-139BD",NULL},
/* 139BE */ { "EGYPTIAN HIEROGLYPH-139BE","	* logogram (to fight) (in ꜥḥꜣ.t (fighter (female)) : ꜥḥꜣ"},
/* 139BF */ { "EGYPTIAN HIEROGLYPH-139BF","	* logogram (to fight) : ꜥḥꜣ"},
/* 139C0 */ { "EGYPTIAN HIEROGLYPH-139C0","	* logogram (to fight) : ꜥḥꜣ"},
/* 139C1 */ { "EGYPTIAN HIEROGLYPH-139C1","	* logogram (to fight) : ꜥḥꜣ"},
/* 139C2 */ { "EGYPTIAN HIEROGLYPH-139C2","	* logogram (negative particle) : n"},
/* 139C3 */ { "EGYPTIAN HIEROGLYPH-139C3","	* classifier arm related movements or actions : rmn"},
/* 139C4 */ { "EGYPTIAN HIEROGLYPH-139C4","	* logogram (arm, hand) : ꜥ"},
/* 139C5 */ { "EGYPTIAN HIEROGLYPH-139C5","	* phonemogram : dd"},
/* 139C6 */ { "EGYPTIAN HIEROGLYPH-139C6","	* phonemogram : m"},
/* 139C7 */ { "EGYPTIAN HIEROGLYPH-139C7","	* classifier supporting/carrying : rmn"},
/* 139C8 */ { "EGYPTIAN HIEROGLYPH-139C8","	* classifier enveloping : ꜥtḫ"},
/* 139C9 */ { "EGYPTIAN HIEROGLYPH-139C9","	* logogram (arm, shoulder) : rmn"},
/* 139CA */ { "EGYPTIAN HIEROGLYPH-139CA","	* classifier shoulder/arm : rmn"},
/* 139CB */ { "EGYPTIAN HIEROGLYPH-139CB","	* logogram (to offer, to present) or Phonemogram : ḥnk | (r)dꞽ"},
/* 139CC */ { "EGYPTIAN HIEROGLYPH-139CC","	* phonemogram : mk"},
/* 139CD */ { "EGYPTIAN HIEROGLYPH-139CD","	* logogram (to receive) : šsp"},
/* 139CE */ { "EGYPTIAN HIEROGLYPH-139CE","	* logogram (course (of the day); daily requirements) : ẖr.t-hrw"},
/* 139CF */ { "EGYPTIAN HIEROGLYPH-139CF","	* logogram (course (of the day); daily requirements) : ẖr.t-hrw"},
/* 139D0 */ { "EGYPTIAN HIEROGLYPH-139D0","	* classifier strength, power : wsr"},
/* 139D1 */ { "EGYPTIAN HIEROGLYPH-139D1","	* logogram (offering Maat) : ḥnk-mꜣꜥ.t"},
/* 139D2 */ { "EGYPTIAN HIEROGLYPH-139D2",NULL},
/* 139D3 */ { "EGYPTIAN HIEROGLYPH-139D3","	* classifier force, effort : dndn, ḏsr"},
/* 139D4 */ { "EGYPTIAN HIEROGLYPH-139D4",NULL},
/* 139D5 */ { "EGYPTIAN HIEROGLYPH-139D5","	* logogram (to wash) : ꞽꜥꞽ"},
/* 139D6 */ { "EGYPTIAN HIEROGLYPH-139D6","	* logogram (to wash) : ꞽꜥꞽ"},
/* 139D7 */ { "EGYPTIAN HIEROGLYPH-139D7","	* logogram (to wash) : ꞽꜥꞽ"},
/* 139D8 */ { "EGYPTIAN HIEROGLYPH-139D8",NULL},
/* 139D9 */ { "EGYPTIAN HIEROGLYPH-139D9",NULL},
/* 139DA */ { "EGYPTIAN HIEROGLYPH-139DA","	* phonemogram : ḫꜣ"},
/* 139DB */ { "EGYPTIAN HIEROGLYPH-139DB","	* classifier washing : ꞽꜥꞽ"},
/* 139DC */ { "EGYPTIAN HIEROGLYPH-139DC","	* logogram (to wash) : ꞽꜥꞽ"},
/* 139DD */ { "EGYPTIAN HIEROGLYPH-139DD","	* classifier stretching out : hn"},
/* 139DE */ { "EGYPTIAN HIEROGLYPH-139DE","	* classifier negative action : ḫb"},
/* 139DF */ { "EGYPTIAN HIEROGLYPH-139DF","	* classifier to rejoice : nḥrḥr"},
/* 139E0 */ { "EGYPTIAN HIEROGLYPH-139E0","	* classifier to call : nꞽs"},
/* 139E1 */ { "EGYPTIAN HIEROGLYPH-139E1","	* logogram (to protect) : ḫwꞽ"},
/* 139E2 */ { "EGYPTIAN HIEROGLYPH-139E2","	* logogram (to make holy) : ḏsr"},
/* 139E3 */ { "EGYPTIAN HIEROGLYPH-139E3",NULL},
/* 139E4 */ { "EGYPTIAN HIEROGLYPH-139E4",NULL},
/* 139E5 */ { "EGYPTIAN HIEROGLYPH-139E5",NULL},
/* 139E6 */ { "EGYPTIAN HIEROGLYPH-139E6","	* classifier to govern/to control : ḫrp"},
/* 139E7 */ { "EGYPTIAN HIEROGLYPH-139E7","	* classifier messenger : ḥw(w).t(y)"},
/* 139E8 */ { "EGYPTIAN HIEROGLYPH-139E8","	* logogram (to make holy, to be holy, to be splendid) : ḏsr"},
/* 139E9 */ { "EGYPTIAN HIEROGLYPH-139E9","	* phonemogram : dꞽ"},
/* 139EA */ { "EGYPTIAN HIEROGLYPH-139EA","	* classifier netherworld : dwꜣ.t"},
/* 139EB */ { "EGYPTIAN HIEROGLYPH-139EB","	* phonemogram : ḏsr"},
/* 139EC */ { "EGYPTIAN HIEROGLYPH-139EC","	* classifier to write, to inscribe : spẖr"},
/* 139ED */ { "EGYPTIAN HIEROGLYPH-139ED","	* logogram (to write, to inscribe) : spẖr"},
/* 139EE */ { "EGYPTIAN HIEROGLYPH-139EE","	* classifier to destroy, to overthrow : ḫmꞽ"},
/* 139EF */ { "EGYPTIAN HIEROGLYPH-139EF","	* classifier elder/official : sr"},
/* 139F0 */ { "EGYPTIAN HIEROGLYPH-139F0","	* classifier adoration : dwꜣ"},
/* 139F1 */ { "EGYPTIAN HIEROGLYPH-139F1","	* logogram (to make holy) : ḏsr"},
/* 139F2 */ { "EGYPTIAN HIEROGLYPH-139F2","	* logogram (to make holy/to be sacred) : ḏsr"},
/* 139F3 */ { "EGYPTIAN HIEROGLYPH-139F3","	* phonemogram : ḏsr"},
/* 139F4 */ { "EGYPTIAN HIEROGLYPH-139F4","	* logogram (to repel) : ḫsr"},
/* 139F5 */ { "EGYPTIAN HIEROGLYPH-139F5","	* logogram (to make holy/to be sacred) : ḏsr"},
/* 139F6 */ { "EGYPTIAN HIEROGLYPH-139F6","	* classifier fighting : ẖnn.w"},
/* 139F7 */ { "EGYPTIAN HIEROGLYPH-139F7","	* phonemogram : d"},
/* 139F8 */ { "EGYPTIAN HIEROGLYPH-139F8","	* logogram (scent, perfume, dew) : ꞽd.t"},
/* 139F9 */ { "EGYPTIAN HIEROGLYPH-139F9","	* phonemogram : wd"},
/* 139FA */ { "EGYPTIAN HIEROGLYPH-139FA","	* phonemogram : šp"},
/* 139FB */ { "EGYPTIAN HIEROGLYPH-139FB","	* logogram (scent, perfume, dew) : ꞽd.t"},
/* 139FC */ { "EGYPTIAN HIEROGLYPH-139FC","	* classifier cut of hand : kp"},
/* 139FD */ { "EGYPTIAN HIEROGLYPH-139FD","	* ?"},
/* 139FE */ { "EGYPTIAN HIEROGLYPH-139FE","	* phonemogram : ḥnt"},
/* 139FF */ { "EGYPTIAN HIEROGLYPH-139FF","	* phono-repeater : ḥnt"}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_3A[] = {
/* 13A00 */ { "EGYPTIAN HIEROGLYPH-13A00","	* classifier : ḥmꜣg"},
/* 13A01 */ { "EGYPTIAN HIEROGLYPH-13A01","	* classifier to hold fast/to seize : nḏrꞽ"},
/* 13A02 */ { "EGYPTIAN HIEROGLYPH-13A02","	* logogram (to seize, to grasp) : ḫfꜥ"},
/* 13A03 */ { "EGYPTIAN HIEROGLYPH-13A03","	* classifier to squeeze, to enclose, to tie up : ꜥrf"},
/* 13A04 */ { "EGYPTIAN HIEROGLYPH-13A04","	* classifier : ḥmꜣg"},
/* 13A05 */ { "EGYPTIAN HIEROGLYPH-13A05","	* phono-repeater : fꜥg"},
/* 13A06 */ { "EGYPTIAN HIEROGLYPH-13A06","	* logogram (Prosopopite nome) : mtr"},
/* 13A07 */ { "EGYPTIAN HIEROGLYPH-13A07","	* classifier copulating : nk"},
/* 13A08 */ { "EGYPTIAN HIEROGLYPH-13A08","	* phonemogram : bꜣḥ"},
/* 13A09 */ { "EGYPTIAN HIEROGLYPH-13A09","	* classifier copulation : nk"},
/* 13A0A */ { "EGYPTIAN HIEROGLYPH-13A0A","	* logogram (the two testicles) : ꞽs.wy"},
/* 13A0B */ { "EGYPTIAN HIEROGLYPH-13A0B","	* classifier testicles : ẖr.wy"},
/* 13A0C */ { "EGYPTIAN HIEROGLYPH-13A0C","	* classifier testicles : ẖr.wy"},
/* 13A0D */ { "EGYPTIAN HIEROGLYPH-13A0D","	* logogram/Phonemogram (cow) : ꞽd.t"},
/* 13A0E */ { "EGYPTIAN HIEROGLYPH-13A0E",NULL},
/* 13A0F */ { "EGYPTIAN HIEROGLYPH-13A0F","	* phonemogram : ḥm"},
/* 13A10 */ { "EGYPTIAN HIEROGLYPH-13A10","	* phonemogram : wr"},
/* 13A11 */ { "EGYPTIAN HIEROGLYPH-13A11","	* phonemogram : wr(.t)"},
/* 13A12 */ { "EGYPTIAN HIEROGLYPH-13A12","	* classifier to run : bṯ"},
/* 13A13 */ { "EGYPTIAN HIEROGLYPH-13A13","	* classifier to fall : ḫr"},
/* 13A14 */ { "EGYPTIAN HIEROGLYPH-13A14","	* classifier turning back : šnꜥ"},
/* 13A15 */ { "EGYPTIAN HIEROGLYPH-13A15","	* classifier to spread : pšš"},
/* 13A16 */ { "EGYPTIAN HIEROGLYPH-13A16","	* classifier to be upside-down : sḫd"},
/* 13A17 */ { "EGYPTIAN HIEROGLYPH-13A17","	* interpretant r and classifier movement : prꞽ"},
/* 13A18 */ { "EGYPTIAN HIEROGLYPH-13A18","	* phonemogram (dental) and classifier movement : t & sḳdꞽ"},
/* 13A19 */ { "EGYPTIAN HIEROGLYPH-13A19","	* phonemogram : wꜥr"},
/* 13A1A */ { "EGYPTIAN HIEROGLYPH-13A1A","	* logogram (to transgress) : thꞽ"},
/* 13A1B */ { "EGYPTIAN HIEROGLYPH-13A1B","	* classifier to disappear : snk"},
/* 13A1C */ { "EGYPTIAN HIEROGLYPH-13A1C","	* logogram (transgression) : th"},
/* 13A1D */ { "EGYPTIAN HIEROGLYPH-13A1D","	* logogram (to be pure, to be clean) : wꜥb"},
/* 13A1E */ { "EGYPTIAN HIEROGLYPH-13A1E","	* logogram (to be pure, to be clean) : wꜥb"},
/* 13A1F */ { "EGYPTIAN HIEROGLYPH-13A1F","	* logogram (to be pure, to be clean) : wꜥb"},
/* 13A20 */ { "EGYPTIAN HIEROGLYPH-13A20","	* phonemogram : ꜣb"},
/* 13A21 */ { "EGYPTIAN HIEROGLYPH-13A21","	* phonemogram : sꜣḥ"},
/* 13A22 */ { "EGYPTIAN HIEROGLYPH-13A22","	* phonemogram (Orion) : sꜣḥ"},
/* 13A23 */ { "EGYPTIAN HIEROGLYPH-13A23","	* phonemogram : sꜣḥ"},
/* 13A24 */ { "EGYPTIAN HIEROGLYPH-13A24","	* phonemogram : sꜣḥ"},
/* 13A25 */ { "EGYPTIAN HIEROGLYPH-13A25",NULL},
/* 13A26 */ { "EGYPTIAN HIEROGLYPH-13A26","	* phonemogram : sꜣḥ"},
/* 13A27 */ { "EGYPTIAN HIEROGLYPH-13A27","	* phonemogram : gn"},
/* 13A28 */ { "EGYPTIAN HIEROGLYPH-13A28","	* phonemogram : gn"},
/* 13A29 */ { "EGYPTIAN HIEROGLYPH-13A29","	* logogram (Orion) : sꜣḥ"},
/* 13A2A */ { "EGYPTIAN HIEROGLYPH-13A2A","	* phonemogram : sꜣḥ"},
/* 13A2B */ { "EGYPTIAN HIEROGLYPH-13A2B","	* phonemogram/logogram (annals) : gn.wt"},
/* 13A2C */ { "EGYPTIAN HIEROGLYPH-13A2C",NULL},
/* 13A2D */ { "EGYPTIAN HIEROGLYPH-13A2D","	* phonemogram : sꜣḥ"},
/* 13A2E */ { "EGYPTIAN HIEROGLYPH-13A2E",NULL},
/* 13A2F */ { "EGYPTIAN HIEROGLYPH-13A2F","	* phonemogram : sꜣḥ"},
/* 13A30 */ { "EGYPTIAN HIEROGLYPH-13A30",NULL},
/* 13A31 */ { "EGYPTIAN HIEROGLYPH-13A31",NULL},
/* 13A32 */ { "EGYPTIAN HIEROGLYPH-13A32","	* classifier throat : nḥb.t"},
/* 13A33 */ { "EGYPTIAN HIEROGLYPH-13A33","	* classifier cheeks/eyebrows : mnḏ.ty"},
/* 13A34 */ { "EGYPTIAN HIEROGLYPH-13A34","	* classifier throat : nḥb.t"},
/* 13A35 */ { "EGYPTIAN HIEROGLYPH-13A35","	* classifier pupil : ꞽm"},
/* 13A36 */ { "EGYPTIAN HIEROGLYPH-13A36","	* classifier taking/carrying : šdꞽ"},
/* 13A37 */ { "EGYPTIAN HIEROGLYPH-13A37","	* classifier violent one : mds"},
/* 13A38 */ { "EGYPTIAN HIEROGLYPH-13A38","	* classifier enemy : ẖꜣ.tyw"},
/* 13A39 */ { "EGYPTIAN HIEROGLYPH-13A39","	* classifier rage, anger : nšn"},
/* 13A3A */ { "EGYPTIAN HIEROGLYPH-13A3A",NULL},
/* 13A3B */ { "EGYPTIAN HIEROGLYPH-13A3B","	* logogram (Seth) : stš/stẖ"},
/* 13A3C */ { "EGYPTIAN HIEROGLYPH-13A3C","	* classifier Seth : nhs"},
/* 13A3D */ { "EGYPTIAN HIEROGLYPH-13A3D","	* classifier fighting : bꜥr"},
/* 13A3E */ { "EGYPTIAN HIEROGLYPH-13A3E","	* logogram (Seth) : stš/stẖ"},
/* 13A3F */ { "EGYPTIAN HIEROGLYPH-13A3F","	* classifier Seth : stš"},
/* 13A40 */ { "EGYPTIAN HIEROGLYPH-13A40","	* classifier Seth : nhs"},
/* 13A41 */ { "EGYPTIAN HIEROGLYPH-13A41","	* logogram (Seth) : stš/stẖ"},
/* 13A42 */ { "EGYPTIAN HIEROGLYPH-13A42","	* classifier Seth : nhs"},
/* 13A43 */ { "EGYPTIAN HIEROGLYPH-13A43","	* classifier Seth : stš"},
/* 13A44 */ { "EGYPTIAN HIEROGLYPH-13A44","	* logogram (11th nome of Upper Egypt) : šꜣ/stẖ/stš"},
/* 13A45 */ { "EGYPTIAN HIEROGLYPH-13A45","	* classifier Seth : nhs"},
/* 13A46 */ { "EGYPTIAN HIEROGLYPH-13A46",NULL},
/* 13A47 */ { "EGYPTIAN HIEROGLYPH-13A47","	* logogram (Seth) : stš/stẖ"},
/* 13A48 */ { "EGYPTIAN HIEROGLYPH-13A48",NULL},
/* 13A49 */ { "EGYPTIAN HIEROGLYPH-13A49","	* logogram (Seth) : stš/stẖ"},
/* 13A4A */ { "EGYPTIAN HIEROGLYPH-13A4A",NULL},
/* 13A4B */ { "EGYPTIAN HIEROGLYPH-13A4B",NULL},
/* 13A4C */ { "EGYPTIAN HIEROGLYPH-13A4C","	* logogram (Seth) : stš/stẖ"},
/* 13A4D */ { "EGYPTIAN HIEROGLYPH-13A4D",NULL},
/* 13A4E */ { "EGYPTIAN HIEROGLYPH-13A4E","	* logogram/Phonemogram (lord, in nb.ty, the two lords Horus and Seth) : nb"},
/* 13A4F */ { "EGYPTIAN HIEROGLYPH-13A4F","	* logogram/Phonemogram (lord, in nb.wy, the two lords Horus and Seth) : nb"},
/* 13A50 */ { "EGYPTIAN HIEROGLYPH-13A50","	* logogram (Seth) : stš/stẖ"},
/* 13A51 */ { "EGYPTIAN HIEROGLYPH-13A51",NULL},
/* 13A52 */ { "EGYPTIAN HIEROGLYPH-13A52",NULL},
/* 13A53 */ { "EGYPTIAN HIEROGLYPH-13A53",NULL},
/* 13A54 */ { "EGYPTIAN HIEROGLYPH-13A54","	* logogram (Seth) : stš/stẖ"},
/* 13A55 */ { "EGYPTIAN HIEROGLYPH-13A55","	* classifier storm : ḳr.y"},
/* 13A56 */ { "EGYPTIAN HIEROGLYPH-13A56","	* classifier storm : sšn"},
/* 13A57 */ { "EGYPTIAN HIEROGLYPH-13A57","	* logogram/Phonemogram (lord, in nb.wy, the two lords Horus and Seth) : nb"},
/* 13A58 */ { "EGYPTIAN HIEROGLYPH-13A58","	* classifier storm, storm cloud : ḳrr"},
/* 13A59 */ { "EGYPTIAN HIEROGLYPH-13A59","	* classifier storm, storm cloud : ḳrr"},
/* 13A5A */ { "EGYPTIAN HIEROGLYPH-13A5A","	* logogram/Phonemogram (Hebenu, capital of the 16th nome of Upper Egypt) : ḥbn.w"},
/* 13A5B */ { "EGYPTIAN HIEROGLYPH-13A5B","	* logogram (Oryx nome, 16th nome of Upper Egypt) : mꜣ-ḥḏ"},
/* 13A5C */ { "EGYPTIAN HIEROGLYPH-13A5C","	* logogram (Oryx nome, 16th nome of Upper Egypt) : mꜣ-ḥḏ"},
/* 13A5D */ { "EGYPTIAN HIEROGLYPH-13A5D","	* logogram (Oryx nome, 16th nome of Upper Egypt) : mꜣ-ḥḏ"},
/* 13A5E */ { "EGYPTIAN HIEROGLYPH-13A5E","	* classifier oryx : mꜣ-ḥḏ"},
/* 13A5F */ { "EGYPTIAN HIEROGLYPH-13A5F","	* phonemogram : ꞽw"},
/* 13A60 */ { "EGYPTIAN HIEROGLYPH-13A60","	* phonemogram : ꞽw"},
/* 13A61 */ { "EGYPTIAN HIEROGLYPH-13A61",NULL},
/* 13A62 */ { "EGYPTIAN HIEROGLYPH-13A62","	* classifier (Oryx) : mꜣ-ḥḏ"},
/* 13A63 */ { "EGYPTIAN HIEROGLYPH-13A63","	* classifier roarer : hmhm.t(y)"},
/* 13A64 */ { "EGYPTIAN HIEROGLYPH-13A64","	* logogram (herd, flock) : ꜥw.t"},
/* 13A65 */ { "EGYPTIAN HIEROGLYPH-13A65","	* classifier noble/dignity/rank : sꜥḥ"},
/* 13A66 */ { "EGYPTIAN HIEROGLYPH-13A66","	* logogram (gazelle) : gḥs"},
/* 13A67 */ { "EGYPTIAN HIEROGLYPH-13A67","	* phonemogram : s"},
/* 13A68 */ { "EGYPTIAN HIEROGLYPH-13A68","	* logogram (rams) : bꜣ.w"},
/* 13A69 */ { "EGYPTIAN HIEROGLYPH-13A69","	* logogram (son of Re) : sꜣ-rꜥ"},
/* 13A6A */ { "EGYPTIAN HIEROGLYPH-13A6A","	* logogram (he of Edfu) : bḥd.ty"},
/* 13A6B */ { "EGYPTIAN HIEROGLYPH-13A6B","	* phonemogram (in bꜣ-n-rꜥ-mr.y-ꞽmn) : bꜣ"},
/* 13A6C */ { "EGYPTIAN HIEROGLYPH-13A6C","	* phonemogram : sḥḏ"},
/* 13A6D */ { "EGYPTIAN HIEROGLYPH-13A6D","	* phonemogram : nb"},
/* 13A6E */ { "EGYPTIAN HIEROGLYPH-13A6E","	* logogram (to the north of) : mḥ"},
/* 13A6F */ { "EGYPTIAN HIEROGLYPH-13A6F",NULL},
/* 13A70 */ { "EGYPTIAN HIEROGLYPH-13A70","	* classifier ram divinity : bt"},
/* 13A71 */ { "EGYPTIAN HIEROGLYPH-13A71","	* phonemogram : bꜣ"},
/* 13A72 */ { "EGYPTIAN HIEROGLYPH-13A72","	* phonemogram : nb"},
/* 13A73 */ { "EGYPTIAN HIEROGLYPH-13A73",NULL},
/* 13A74 */ { "EGYPTIAN HIEROGLYPH-13A74","	* ?"},
/* 13A75 */ { "EGYPTIAN HIEROGLYPH-13A75","	* phonemogram : ꜣms"},
/* 13A76 */ { "EGYPTIAN HIEROGLYPH-13A76","	* phonemogram : š"},
/* 13A77 */ { "EGYPTIAN HIEROGLYPH-13A77","	* phonemogram : šsr"},
/* 13A78 */ { "EGYPTIAN HIEROGLYPH-13A78","	* logogram/Phonemogram (to make glad, to be glad) : ꜣms-ꞽb"},
/* 13A79 */ { "EGYPTIAN HIEROGLYPH-13A79",NULL},
/* 13A7A */ { "EGYPTIAN HIEROGLYPH-13A7A","	* phonemogram : ꞽw"},
/* 13A7B */ { "EGYPTIAN HIEROGLYPH-13A7B","	* phonemogram : ꞽw"},
/* 13A7C */ { "EGYPTIAN HIEROGLYPH-13A7C","	* classifier jackal : wnš.w"},
/* 13A7D */ { "EGYPTIAN HIEROGLYPH-13A7D","	* phonemogram/logogram (those that conduct) : sb.yw"},
/* 13A7E */ { "EGYPTIAN HIEROGLYPH-13A7E","	* phonemogram : ꞽmn.t"},
/* 13A7F */ { "EGYPTIAN HIEROGLYPH-13A7F","	* phonemogram/logogram (many-coloured of plumage) : sꜣb-šw.t"},
/* 13A80 */ { "EGYPTIAN HIEROGLYPH-13A80","	* logogram (jackal of Upper Egypt) : sꜣb šmꜥ.w"},
/* 13A81 */ { "EGYPTIAN HIEROGLYPH-13A81","	* logogram (Wepwawet of Upper Egypt) : wp-wꜣ.wt-šmꜥ.w"},
/* 13A82 */ { "EGYPTIAN HIEROGLYPH-13A82",NULL},
/* 13A83 */ { "EGYPTIAN HIEROGLYPH-13A83","	* phonemogram : sṯꜣ"},
/* 13A84 */ { "EGYPTIAN HIEROGLYPH-13A84","	* logogram (Wepwawet)? : wp-wꜣ.wt"},
/* 13A85 */ { "EGYPTIAN HIEROGLYPH-13A85","	* logogram (those who conduct the bark of Re) : sb.yw-wꞽꜣ-n-rꜥ"},
/* 13A86 */ { "EGYPTIAN HIEROGLYPH-13A86","	* phonemogram : ṯsm"},
/* 13A87 */ { "EGYPTIAN HIEROGLYPH-13A87","	* logogram ((secret) image (of a god)) : sštꜣ"},
/* 13A88 */ { "EGYPTIAN HIEROGLYPH-13A88","	* logogram (to make secret) : sštꜣ"},
/* 13A89 */ { "EGYPTIAN HIEROGLYPH-13A89","	* logogram (the primary (secret) image (of a god)) : sštꜣ-tp(.y)"},
/* 13A8A */ { "EGYPTIAN HIEROGLYPH-13A8A","	* logogram ((secret) image (of a god)) : sštꜣ"},
/* 13A8B */ { "EGYPTIAN HIEROGLYPH-13A8B","	* classifier divinity : ꞽnp.w"},
/* 13A8C */ { "EGYPTIAN HIEROGLYPH-13A8C","	* logogram (Anubis) : ꞽnp.w"},
/* 13A8D */ { "EGYPTIAN HIEROGLYPH-13A8D","	* logogram (Anubis) : ꞽnp.w"},
/* 13A8E */ { "EGYPTIAN HIEROGLYPH-13A8E","	* logogram (Anubis) : ꞽnp.w"},
/* 13A8F */ { "EGYPTIAN HIEROGLYPH-13A8F","	* classifier canine divinity : wp-wꜣ.wt"},
/* 13A90 */ { "EGYPTIAN HIEROGLYPH-13A90",NULL},
/* 13A91 */ { "EGYPTIAN HIEROGLYPH-13A91","	* classifier canine divinity : wp-wꜣ.wt"},
/* 13A92 */ { "EGYPTIAN HIEROGLYPH-13A92","	* classifier canine divinity : wp-wꜣ.wt"},
/* 13A93 */ { "EGYPTIAN HIEROGLYPH-13A93","	* classifier canine divinity : wp-wꜣ.wt"},
/* 13A94 */ { "EGYPTIAN HIEROGLYPH-13A94","	* logogram (Anubis nome (17th nome of Upper Egypt)) : ꞽnpw.t"},
/* 13A95 */ { "EGYPTIAN HIEROGLYPH-13A95","	* logogram (Anubis nome (17th nome of Upper Egypt)) : ꞽnpw.t"},
/* 13A96 */ { "EGYPTIAN HIEROGLYPH-13A96",NULL},
/* 13A97 */ { "EGYPTIAN HIEROGLYPH-13A97","	* logogram (privy to the secrets) : ḥr.y-sštꜣ"},
/* 13A98 */ { "EGYPTIAN HIEROGLYPH-13A98","	* logogram (Anubis) : ꞽnp.w"},
/* 13A99 */ { "EGYPTIAN HIEROGLYPH-13A99","	* logogram (cat) : mꞽw.t"},
/* 13A9A */ { "EGYPTIAN HIEROGLYPH-13A9A","	* logogram (like Re) : mꞽ-rꜥ"},
/* 13A9B */ { "EGYPTIAN HIEROGLYPH-13A9B","	* phonemogram : ḫft-ḥr"},
/* 13A9C */ { "EGYPTIAN HIEROGLYPH-13A9C","	* logogram (given life like Re) : dꞽ-ꜥnḫ-mꞽ-rꜥ "},
/* 13A9D */ { "EGYPTIAN HIEROGLYPH-13A9D",NULL},
/* 13A9E */ { "EGYPTIAN HIEROGLYPH-13A9E","	* logogram (young lioness) : ḥwn.t"},
/* 13A9F */ { "EGYPTIAN HIEROGLYPH-13A9F","	* phonemogram : ḫft-ḥr"},
/* 13AA0 */ { "EGYPTIAN HIEROGLYPH-13AA0","	* phonemogram : ḫft-ḥr"},
/* 13AA1 */ { "EGYPTIAN HIEROGLYPH-13AA1","	* phonemogram : ḫft-ḥr"},
/* 13AA2 */ { "EGYPTIAN HIEROGLYPH-13AA2","	* phonemogram : m"},
/* 13AA3 */ { "EGYPTIAN HIEROGLYPH-13AA3",NULL},
/* 13AA4 */ { "EGYPTIAN HIEROGLYPH-13AA4","	* phonemogram : m rw.t(y)"},
/* 13AA5 */ { "EGYPTIAN HIEROGLYPH-13AA5","	* classifier horse : smsm (=ssm.t)"},
/* 13AA6 */ { "EGYPTIAN HIEROGLYPH-13AA6","	* classifier horse : ssm.t"},
/* 13AA7 */ { "EGYPTIAN HIEROGLYPH-13AA7","	* logogram (span (of horses)/horse) : ḥtr"},
/* 13AA8 */ { "EGYPTIAN HIEROGLYPH-13AA8","	* logogram (span (of horses)/horse) : ḥtr"},
/* 13AA9 */ { "EGYPTIAN HIEROGLYPH-13AA9",NULL},
/* 13AAA */ { "EGYPTIAN HIEROGLYPH-13AAA","	* classifier cattle : ꜥw.t"},
/* 13AAB */ { "EGYPTIAN HIEROGLYPH-13AAB","	* logogram (rank, diginity) : sꜥḥ"},
/* 13AAC */ { "EGYPTIAN HIEROGLYPH-13AAC",NULL},
/* 13AAD */ { "EGYPTIAN HIEROGLYPH-13AAD",NULL},
/* 13AAE */ { "EGYPTIAN HIEROGLYPH-13AAE","	* classifier griffin : ꜥḫḫ"},
/* 13AAF */ { "EGYPTIAN HIEROGLYPH-13AAF","	* logogram (griffin) : ꜥḫḫ"},
/* 13AB0 */ { "EGYPTIAN HIEROGLYPH-13AB0","	* logogram (triomphator) : dwn.ty"},
/* 13AB1 */ { "EGYPTIAN HIEROGLYPH-13AB1","	* classifier hippopotamus goddess : ḥḏ.t"},
/* 13AB2 */ { "EGYPTIAN HIEROGLYPH-13AB2",NULL},
/* 13AB3 */ { "EGYPTIAN HIEROGLYPH-13AB3","	* classifier hippopotamus : ḫꜣb"},
/* 13AB4 */ { "EGYPTIAN HIEROGLYPH-13AB4","	* classifier animal in water : ꞽm.yw-mw"},
/* 13AB5 */ { "EGYPTIAN HIEROGLYPH-13AB5","	* logogram/phonemogram (Ipet) : ꞽp.t"},
/* 13AB6 */ { "EGYPTIAN HIEROGLYPH-13AB6","	* phonemogram/logogram (in ꞽp.t-sw.t) : ꞽp.t"},
/* 13AB7 */ { "EGYPTIAN HIEROGLYPH-13AB7","	* logogram/Phonemogram (great one (female)) : wr.t"},
/* 13AB8 */ { "EGYPTIAN HIEROGLYPH-13AB8","	* logogram/Phonemogram (great one (female)) : wr.t "},
/* 13AB9 */ { "EGYPTIAN HIEROGLYPH-13AB9","	* logogram (to rejoice) : bnhm"},
/* 13ABA */ { "EGYPTIAN HIEROGLYPH-13ABA","	* logogram (first person singular, referring to Nut) : ꞽ"},
/* 13ABB */ { "EGYPTIAN HIEROGLYPH-13ABB","	* classifier jackal : wnš.w"},
/* 13ABC */ { "EGYPTIAN HIEROGLYPH-13ABC",NULL},
/* 13ABD */ { "EGYPTIAN HIEROGLYPH-13ABD","	* phonemogram : wn"},
/* 13ABE */ { "EGYPTIAN HIEROGLYPH-13ABE","	* phonemogram : wn"},
/* 13ABF */ { "EGYPTIAN HIEROGLYPH-13ABF","	* logogram (Hermopolis magna, 15th nome of Upper Egypt) : wnw.t "},
/* 13AC0 */ { "EGYPTIAN HIEROGLYPH-13AC0",NULL},
/* 13AC1 */ { "EGYPTIAN HIEROGLYPH-13AC1","	* logogram (lord of the two lands) : nb tꜣ.wy"},
/* 13AC2 */ { "EGYPTIAN HIEROGLYPH-13AC2","	* classifier (lion) : mꜣꞽ"},
/* 13AC3 */ { "EGYPTIAN HIEROGLYPH-13AC3","	* logogram (lion) : mꜣꞽ/rw/pḥ.tꞽ"},
/* 13AC4 */ { "EGYPTIAN HIEROGLYPH-13AC4","	* phonemogram : rw"},
/* 13AC5 */ { "EGYPTIAN HIEROGLYPH-13AC5","	* classifier divinity (lioness) : mḥ(.y)t"},
/* 13AC6 */ { "EGYPTIAN HIEROGLYPH-13AC6",NULL},
/* 13AC7 */ { "EGYPTIAN HIEROGLYPH-13AC7","	* logogram (throne dais) : ṯnṯꜣ.t"},
/* 13AC8 */ { "EGYPTIAN HIEROGLYPH-13AC8","	* logogram (lion) : mꜣꞽ"},
/* 13AC9 */ { "EGYPTIAN HIEROGLYPH-13AC9",NULL},
/* 13ACA */ { "EGYPTIAN HIEROGLYPH-13ACA","	* logogram (living lion) : mꜣꞽ-ꜥnḫ"},
/* 13ACB */ { "EGYPTIAN HIEROGLYPH-13ACB","	* logogram (living lion) : mꜣꞽ-ꜥnḫ"},
/* 13ACC */ { "EGYPTIAN HIEROGLYPH-13ACC","	* phonemogram : mds"},
/* 13ACD */ { "EGYPTIAN HIEROGLYPH-13ACD","	* phonemogram : ḥsꜣ-šnꜥ"},
/* 13ACE */ { "EGYPTIAN HIEROGLYPH-13ACE","	* phonemogram : pẖr"},
/* 13ACF */ { "EGYPTIAN HIEROGLYPH-13ACF","	* logogram (to present) : šms"},
/* 13AD0 */ { "EGYPTIAN HIEROGLYPH-13AD0","	* logogram/phonemogram (king of Upper Egypt and Lower Egypt, lord) : n(.y)-sw.t-bꞽ.ty nb"},
/* 13AD1 */ { "EGYPTIAN HIEROGLYPH-13AD1","	* logogram (in the construction sꜣ-rꜥ nb ḫꜥ.w) : rꜥ + nb"},
/* 13AD2 */ { "EGYPTIAN HIEROGLYPH-13AD2","	* logogram (Mehyt, divinity) : mḥ.yt"},
/* 13AD3 */ { "EGYPTIAN HIEROGLYPH-13AD3","	* logogram (Pachet) : pꜣḫ.t"},
/* 13AD4 */ { "EGYPTIAN HIEROGLYPH-13AD4","	* phonemogram tf and phonemogram r : tf & r"},
/* 13AD5 */ { "EGYPTIAN HIEROGLYPH-13AD5","	* phonemogram : n"},
/* 13AD6 */ { "EGYPTIAN HIEROGLYPH-13AD6","	* classifier divinity : twtw"},
/* 13AD7 */ { "EGYPTIAN HIEROGLYPH-13AD7","	* logogram (to give, to place) : rdꞽ"},
/* 13AD8 */ { "EGYPTIAN HIEROGLYPH-13AD8","	* phonemogram : ḏsr"},
/* 13AD9 */ { "EGYPTIAN HIEROGLYPH-13AD9","	* phonemogram : ršw"},
/* 13ADA */ { "EGYPTIAN HIEROGLYPH-13ADA","	* phonemogram (in ꜣwtwkrtr) : kr"},
/* 13ADB */ { "EGYPTIAN HIEROGLYPH-13ADB","	* logogram (Re) : rꜥ"},
/* 13ADC */ { "EGYPTIAN HIEROGLYPH-13ADC",NULL},
/* 13ADD */ { "EGYPTIAN HIEROGLYPH-13ADD","	* logogram (Matit, goddess of 12th nome of Upper Egypt) : mꜣt.yt"},
/* 13ADE */ { "EGYPTIAN HIEROGLYPH-13ADE","	* logogram (door bolt) : ḥkn"},
/* 13ADF */ { "EGYPTIAN HIEROGLYPH-13ADF","	* logogram (every day) : rꜥ-nb"},
/* 13AE0 */ { "EGYPTIAN HIEROGLYPH-13AE0","	* logogram (Pachet) : pꜣḫ.t"},
/* 13AE1 */ { "EGYPTIAN HIEROGLYPH-13AE1","	* phonemogram : nb-ḫpš"},
/* 13AE2 */ { "EGYPTIAN HIEROGLYPH-13AE2","	* phonemogram : rdꞽ"},
/* 13AE3 */ { "EGYPTIAN HIEROGLYPH-13AE3","	* logogram (to make holy) : ḏsr"},
/* 13AE4 */ { "EGYPTIAN HIEROGLYPH-13AE4","	* classifier aggressive like a lion : tkn"},
/* 13AE5 */ { "EGYPTIAN HIEROGLYPH-13AE5","	* classifier leopard : ꜣby"},
/* 13AE6 */ { "EGYPTIAN HIEROGLYPH-13AE6","	* phonemogram/logogram (rage, anger) : ḳnd"},
/* 13AE7 */ { "EGYPTIAN HIEROGLYPH-13AE7","	* logogram (Tefrer, geographical location) : tfrr"},
/* 13AE8 */ { "EGYPTIAN HIEROGLYPH-13AE8","	* classifier monkey (divinity) : wpt"},
/* 13AE9 */ { "EGYPTIAN HIEROGLYPH-13AE9","	* logogram (Thot) : ḏḥwty"},
/* 13AEA */ { "EGYPTIAN HIEROGLYPH-13AEA","	* logogram (king (of Upper Egypt)) : n(.y)-sw.t"},
/* 13AEB */ { "EGYPTIAN HIEROGLYPH-13AEB","	* phonemogram : bsꜣ"},
/* 13AEC */ { "EGYPTIAN HIEROGLYPH-13AEC","	* phonemogram : bsꜣ"},
/* 13AED */ { "EGYPTIAN HIEROGLYPH-13AED","	* logogram (scribe) : sš"},
/* 13AEE */ { "EGYPTIAN HIEROGLYPH-13AEE","	* logogram (to write, to inscribe) : spẖr"},
/* 13AEF */ { "EGYPTIAN HIEROGLYPH-13AEF","	* logogram (New Year's Day) : wp-rnp.t"},
/* 13AF0 */ { "EGYPTIAN HIEROGLYPH-13AF0","	* logogram (to speak words, to recite) : ḏd-mdw"},
/* 13AF1 */ { "EGYPTIAN HIEROGLYPH-13AF1","	* logogram (recitation by) : ḏd-mdw-ꞽn"},
/* 13AF2 */ { "EGYPTIAN HIEROGLYPH-13AF2",NULL},
/* 13AF3 */ { "EGYPTIAN HIEROGLYPH-13AF3",NULL},
/* 13AF4 */ { "EGYPTIAN HIEROGLYPH-13AF4","	* phonemogram : sꜣ=f"},
/* 13AF5 */ { "EGYPTIAN HIEROGLYPH-13AF5","	* phonemogram : n-sꜣ"},
/* 13AF6 */ { "EGYPTIAN HIEROGLYPH-13AF6",NULL},
/* 13AF7 */ { "EGYPTIAN HIEROGLYPH-13AF7","	* classifier ritual object : šb.t"},
/* 13AF8 */ { "EGYPTIAN HIEROGLYPH-13AF8","	* logogram (symbol of the cycle of time) : wnšb"},
/* 13AF9 */ { "EGYPTIAN HIEROGLYPH-13AF9","	* logogram (symbol of the cycle of time) : wnšb"},
/* 13AFA */ { "EGYPTIAN HIEROGLYPH-13AFA","	* phonemogram : ꞽn"},
/* 13AFB */ { "EGYPTIAN HIEROGLYPH-13AFB","	* phonemogram : ꞽn"},
/* 13AFC */ { "EGYPTIAN HIEROGLYPH-13AFC",NULL},
/* 13AFD */ { "EGYPTIAN HIEROGLYPH-13AFD",NULL},
/* 13AFE */ { "EGYPTIAN HIEROGLYPH-13AFE","	* logogram (lady of writing) : nb.t-sš"},
/* 13AFF */ { "EGYPTIAN HIEROGLYPH-13AFF","	* phonemogram : t"}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_3B[] = {
/* 13B00 */ { "EGYPTIAN HIEROGLYPH-13B00","	* logogram (to be good) : nfr"},
/* 13B01 */ { "EGYPTIAN HIEROGLYPH-13B01","	* logogram (to be good) : nfr"},
/* 13B02 */ { "EGYPTIAN HIEROGLYPH-13B02","	* classifier baboon : bꜣ.w-ꞽꜣb.tyw"},
/* 13B03 */ { "EGYPTIAN HIEROGLYPH-13B03","	* phonemogram : nfr"},
/* 13B04 */ { "EGYPTIAN HIEROGLYPH-13B04",NULL},
/* 13B05 */ { "EGYPTIAN HIEROGLYPH-13B05","	* classifier monkey : ꞽwf"},
/* 13B06 */ { "EGYPTIAN HIEROGLYPH-13B06",NULL},
/* 13B07 */ { "EGYPTIAN HIEROGLYPH-13B07","	* logogram/phonemogram (beautiful of face) : nfr(.t)-ḥr"},
/* 13B08 */ { "EGYPTIAN HIEROGLYPH-13B08","	* logogram (good year) : rnp.t-nfr.t"},
/* 13B09 */ { "EGYPTIAN HIEROGLYPH-13B09",NULL},
/* 13B0A */ { "EGYPTIAN HIEROGLYPH-13B0A","	* logogram (New Year's Day) : wp-rnp.t"},
/* 13B0B */ { "EGYPTIAN HIEROGLYPH-13B0B","	* phonemogram : nfr"},
/* 13B0C */ { "EGYPTIAN HIEROGLYPH-13B0C","	* phonemogram : nfr.w"},
/* 13B0D */ { "EGYPTIAN HIEROGLYPH-13B0D","	* phonemogram : nfr.w"},
/* 13B0E */ { "EGYPTIAN HIEROGLYPH-13B0E","	* phonemogram : nfr"},
/* 13B0F */ { "EGYPTIAN HIEROGLYPH-13B0F","	* logogram/phonemogram (the beautiful lotus flower) : nḫb nfr"},
/* 13B10 */ { "EGYPTIAN HIEROGLYPH-13B10",NULL},
/* 13B11 */ { "EGYPTIAN HIEROGLYPH-13B11","	* phonemogram : ḏd + s + r"},
/* 13B12 */ { "EGYPTIAN HIEROGLYPH-13B12","	* logogram (to adorn) or Logogram (to be friendly) : sẖkr | ꞽmꜣ"},
/* 13B13 */ { "EGYPTIAN HIEROGLYPH-13B13","	* ?"},
/* 13B14 */ { "EGYPTIAN HIEROGLYPH-13B14","	* classifier mouse : pnw"},
/* 13B15 */ { "EGYPTIAN HIEROGLYPH-13B15","	* logogram (lord) : nb"},
/* 13B16 */ { "EGYPTIAN HIEROGLYPH-13B16","	* logogram (lord) : nb"},
/* 13B17 */ { "EGYPTIAN HIEROGLYPH-13B17","	* logogram rꜥ and nb (in sꜣ-rꜥ nb ḫꜥ.w) : rꜥ nb"},
/* 13B18 */ { "EGYPTIAN HIEROGLYPH-13B18","	* logogram (king of Upper Egypt and Lower Egypt, lord) : n(.y)-sw.t-bꞽ.ty-nb"},
/* 13B19 */ { "EGYPTIAN HIEROGLYPH-13B19","	* logogram (lord of the two lands) : nb-tꜣ.wy"},
/* 13B1A */ { "EGYPTIAN HIEROGLYPH-13B1A","	* logogram (living image) : šsp-ꜥnḫ"},
/* 13B1B */ { "EGYPTIAN HIEROGLYPH-13B1B","	* logogram (living image) : šsp-ꜥnḫ"},
/* 13B1C */ { "EGYPTIAN HIEROGLYPH-13B1C","	* logogram (the sole/unique lord) : nb-wꜥ"},
/* 13B1D */ { "EGYPTIAN HIEROGLYPH-13B1D","	* logogram (the sole/unique lord) : nb-wꜥ"},
/* 13B1E */ { "EGYPTIAN HIEROGLYPH-13B1E","	* logogram (lord) : nb"},
/* 13B1F */ { "EGYPTIAN HIEROGLYPH-13B1F",NULL},
/* 13B20 */ { "EGYPTIAN HIEROGLYPH-13B20","	* phonemogram : m"},
/* 13B21 */ { "EGYPTIAN HIEROGLYPH-13B21","	* logogram (lord) : nb"},
/* 13B22 */ { "EGYPTIAN HIEROGLYPH-13B22","	* logogram (presenting myrrh) : šms ꜥntyw"},
/* 13B23 */ { "EGYPTIAN HIEROGLYPH-13B23","	* logogram (image, referring to the king) : šsp"},
/* 13B24 */ { "EGYPTIAN HIEROGLYPH-13B24",NULL},
/* 13B25 */ { "EGYPTIAN HIEROGLYPH-13B25","	* logogram (image) : šsp"},
/* 13B26 */ { "EGYPTIAN HIEROGLYPH-13B26","	* logogram (lord) : nb"},
/* 13B27 */ { "EGYPTIAN HIEROGLYPH-13B27","	* classifier divinity Aker : ꜣkr"},
/* 13B28 */ { "EGYPTIAN HIEROGLYPH-13B28","	* classifier divinity Aker : ꜣkr"},
/* 13B29 */ { "EGYPTIAN HIEROGLYPH-13B29",NULL},
/* 13B2A */ { "EGYPTIAN HIEROGLYPH-13B2A",NULL},
/* 13B2B */ { "EGYPTIAN HIEROGLYPH-13B2B","	* classifier Hapy : ḥp"},
/* 13B2C */ { "EGYPTIAN HIEROGLYPH-13B2C","	* phonemogram : nfr"},
/* 13B2D */ { "EGYPTIAN HIEROGLYPH-13B2D","	* logogram (yoke of oxen) : ḥtr"},
/* 13B2E */ { "EGYPTIAN HIEROGLYPH-13B2E","	* phonemogram : n-nb"},
/* 13B2F */ { "EGYPTIAN HIEROGLYPH-13B2F","	* classifier bull (specifically in kꜣ-ḥḏ (the (sacred) white bull) : kꜣ"},
/* 13B30 */ { "EGYPTIAN HIEROGLYPH-13B30","	* classifier bovid (steer, ox, cattle, male animal) : ꞽwꜣ"},
/* 13B31 */ { "EGYPTIAN HIEROGLYPH-13B31","	* classifier glad, pleased : ꜣms"},
/* 13B32 */ { "EGYPTIAN HIEROGLYPH-13B32","	* classifier bovid (steer, ox, cattle, male animal) : ꞽwꜣ"},
/* 13B33 */ { "EGYPTIAN HIEROGLYPH-13B33","	* logogram (cow) : ꞽḥ.t"},
/* 13B34 */ { "EGYPTIAN HIEROGLYPH-13B34","	* logogram (bull) : kꜣ"},
/* 13B35 */ { "EGYPTIAN HIEROGLYPH-13B35","	* logogram (sacrificial steer) : smꜣ"},
/* 13B36 */ { "EGYPTIAN HIEROGLYPH-13B36","	* logogram (sacrificial steer) : smꜣ"},
/* 13B37 */ { "EGYPTIAN HIEROGLYPH-13B37","	* classifier (Seth) : tbh"},
/* 13B38 */ { "EGYPTIAN HIEROGLYPH-13B38","	* logogram (sacrificial steer) : smꜣ"},
/* 13B39 */ { "EGYPTIAN HIEROGLYPH-13B39","	* classifier (to fall) : ḫr"},
/* 13B3A */ { "EGYPTIAN HIEROGLYPH-13B3A",NULL},
/* 13B3B */ { "EGYPTIAN HIEROGLYPH-13B3B","	* classifier slaughter? : sꞽd-tꜣ"},
/* 13B3C */ { "EGYPTIAN HIEROGLYPH-13B3C","	* classifier prepare to attack : ṯwn"},
/* 13B3D */ { "EGYPTIAN HIEROGLYPH-13B3D",NULL},
/* 13B3E */ { "EGYPTIAN HIEROGLYPH-13B3E","	* logogram (11th nome of Lower Egypt) : ḥsbw"},
/* 13B3F */ { "EGYPTIAN HIEROGLYPH-13B3F","	* logogram (6th nome of Lower Egypt) : ḫꜣsw.w"},
/* 13B40 */ { "EGYPTIAN HIEROGLYPH-13B40","	* logogram (6th nome of Lower Egypt) : ḫꜣsw.w"},
/* 13B41 */ { "EGYPTIAN HIEROGLYPH-13B41","	* logogram (Cynopolis nome) : sꜣkꜣ"},
/* 13B42 */ { "EGYPTIAN HIEROGLYPH-13B42","	* logogram (12th nome of Lower Egypt) : ṯb-nṯr"},
/* 13B43 */ { "EGYPTIAN HIEROGLYPH-13B43","	* classifier divinity : nsr-msr"},
/* 13B44 */ { "EGYPTIAN HIEROGLYPH-13B44","	* phonemogram (in ꜣms-ꞽb (to rejoice)) : ꜣms"},
/* 13B45 */ { "EGYPTIAN HIEROGLYPH-13B45","	* phonemogram : bꜣẖ"},
/* 13B46 */ { "EGYPTIAN HIEROGLYPH-13B46","	* classifier cow divinity : ḥs(ꜣ).t"},
/* 13B47 */ { "EGYPTIAN HIEROGLYPH-13B47","	* phonemogram (in ꜣms-ꞽb) : ꜣms"},
/* 13B48 */ { "EGYPTIAN HIEROGLYPH-13B48","	* phonemogram : wbn"},
/* 13B49 */ { "EGYPTIAN HIEROGLYPH-13B49","	* logogram (lady) : nb.t"},
/* 13B4A */ { "EGYPTIAN HIEROGLYPH-13B4A","	* logogram (Re and lord (in sꜣ-rꜥ nb ḫꜥ.w)) : rꜥ nb"},
/* 13B4B */ { "EGYPTIAN HIEROGLYPH-13B4B",NULL},
/* 13B4C */ { "EGYPTIAN HIEROGLYPH-13B4C","	* logogram (cattle) : wnḏw"},
/* 13B4D */ { "EGYPTIAN HIEROGLYPH-13B4D","	* logogram (king of Upper Egypt and Lower Egypt, lord) : n(.y)-sw.t bꞽ.ty nb"},
/* 13B4E */ { "EGYPTIAN HIEROGLYPH-13B4E","	* classifier cow divinity : ḥs(ꜣ).t"},
/* 13B4F */ { "EGYPTIAN HIEROGLYPH-13B4F","	* logogram (Re and lord (in sꜣ-rꜥ nb ḫꜥ.w)) : rꜥ nb"},
/* 13B50 */ { "EGYPTIAN HIEROGLYPH-13B50","	* classifier cow divinity : ꞽh.t"},
/* 13B51 */ { "EGYPTIAN HIEROGLYPH-13B51","	* classifier cow divinity : ḥs(ꜣ).t"},
/* 13B52 */ { "EGYPTIAN HIEROGLYPH-13B52",NULL},
/* 13B53 */ { "EGYPTIAN HIEROGLYPH-13B53","	* phonemogram (in km-wr) : wr"},
/* 13B54 */ { "EGYPTIAN HIEROGLYPH-13B54","	* logogram (10th nome of Lower Egypt) : km-wr"},
/* 13B55 */ { "EGYPTIAN HIEROGLYPH-13B55",NULL},
/* 13B56 */ { "EGYPTIAN HIEROGLYPH-13B56","	* logogram (12th nome of Lower Egypt) : ṯb-nṯr"},
/* 13B57 */ { "EGYPTIAN HIEROGLYPH-13B57","	* classifier (bull) : kꜣ"},
/* 13B58 */ { "EGYPTIAN HIEROGLYPH-13B58","	* logogram (bull, beef) : kꜥ/ꞽḥ"},
/* 13B59 */ { "EGYPTIAN HIEROGLYPH-13B59","	* classifier divinity (Ash-spitter) : ꜣš-ssf"},
/* 13B5A */ { "EGYPTIAN HIEROGLYPH-13B5A","	* classifier Ammet : ꜥmm.t"},
/* 13B5B */ { "EGYPTIAN HIEROGLYPH-13B5B","	* classifier rhinoceros : šḳb"},
/* 13B5C */ { "EGYPTIAN HIEROGLYPH-13B5C","	* phonemogram : hrw"},
/* 13B5D */ { "EGYPTIAN HIEROGLYPH-13B5D","	* phonemogram : sš"},
/* 13B5E */ { "EGYPTIAN HIEROGLYPH-13B5E",NULL},
/* 13B5F */ { "EGYPTIAN HIEROGLYPH-13B5F","	* phonemogram : hrw"},
/* 13B60 */ { "EGYPTIAN HIEROGLYPH-13B60","	* logogram (worth, dignity, renown) : šf.yt"},
/* 13B61 */ { "EGYPTIAN HIEROGLYPH-13B61","	* classifier ram : rhny"},
/* 13B62 */ { "EGYPTIAN HIEROGLYPH-13B62","	* classifier worth, dignity, renown : šf.yt"},
/* 13B63 */ { "EGYPTIAN HIEROGLYPH-13B63","	* classifier worth, dignity, renown : šf.y"},
/* 13B64 */ { "EGYPTIAN HIEROGLYPH-13B64","	* logogram (worth, dignity, renown) : šf.yt"},
/* 13B65 */ { "EGYPTIAN HIEROGLYPH-13B65","	* classifier (Atef crown) : ꜣtf"},
/* 13B66 */ { "EGYPTIAN HIEROGLYPH-13B66","	* logogram (worth, dignity, renown) : šf.yt"},
/* 13B67 */ { "EGYPTIAN HIEROGLYPH-13B67","	* logogram (worth, dignity, renown) : šf.yt"},
/* 13B68 */ { "EGYPTIAN HIEROGLYPH-13B68","	* classifier worth, dignity, renown : šf.yt"},
/* 13B69 */ { "EGYPTIAN HIEROGLYPH-13B69","	* logogram (the eight primordial gods) : ẖnmwy"},
/* 13B6A */ { "EGYPTIAN HIEROGLYPH-13B6A","	* logogram (bull) : kꜣ"},
/* 13B6B */ { "EGYPTIAN HIEROGLYPH-13B6B","	* phonemogram : smꜣ"},
/* 13B6C */ { "EGYPTIAN HIEROGLYPH-13B6C","	* classifier rage/aggression : ḏnd"},
/* 13B6D */ { "EGYPTIAN HIEROGLYPH-13B6D","	* phonemogram : šsmw"},
/* 13B6E */ { "EGYPTIAN HIEROGLYPH-13B6E","	* logogram (bull) : kꜣ"},
/* 13B6F */ { "EGYPTIAN HIEROGLYPH-13B6F","	* classifier : ḫtn"},
/* 13B70 */ { "EGYPTIAN HIEROGLYPH-13B70","	* classifier Ursa Major constellation : msḫt.yw"},
/* 13B71 */ { "EGYPTIAN HIEROGLYPH-13B71","	* logogram (bull) : kꜣ"},
/* 13B72 */ { "EGYPTIAN HIEROGLYPH-13B72","	* classifier nose : fnḏ"},
/* 13B73 */ { "EGYPTIAN HIEROGLYPH-13B73","	* classifier kissing : sn"},
/* 13B74 */ { "EGYPTIAN HIEROGLYPH-13B74","	* classifier double doors : ḫns"},
/* 13B75 */ { "EGYPTIAN HIEROGLYPH-13B75","	* logogram (double doors) : ḫns"},
/* 13B76 */ { "EGYPTIAN HIEROGLYPH-13B76","	* phonemogram : stꜣ"},
/* 13B77 */ { "EGYPTIAN HIEROGLYPH-13B77","	* phonemogram : stꜣ"},
/* 13B78 */ { "EGYPTIAN HIEROGLYPH-13B78","	* phonemogram : stꜣ"},
/* 13B79 */ { "EGYPTIAN HIEROGLYPH-13B79","	* phonemogram : stꜣ"},
/* 13B7A */ { "EGYPTIAN HIEROGLYPH-13B7A",NULL},
/* 13B7B */ { "EGYPTIAN HIEROGLYPH-13B7B","	* phonemogram : stꜣ"},
/* 13B7C */ { "EGYPTIAN HIEROGLYPH-13B7C","	* phonemogram : stꜣ"},
/* 13B7D */ { "EGYPTIAN HIEROGLYPH-13B7D","	* logogram (jackal) : sꜣb"},
/* 13B7E */ { "EGYPTIAN HIEROGLYPH-13B7E",NULL},
/* 13B7F */ { "EGYPTIAN HIEROGLYPH-13B7F","	* logogram (Ennead) : psḏ.t"},
/* 13B80 */ { "EGYPTIAN HIEROGLYPH-13B80",NULL},
/* 13B81 */ { "EGYPTIAN HIEROGLYPH-13B81","	* phonemogram : wsr"},
/* 13B82 */ { "EGYPTIAN HIEROGLYPH-13B82","	* logogram (throat) : ḥt.yt"},
/* 13B83 */ { "EGYPTIAN HIEROGLYPH-13B83","	* logogram (throat) : ḥt.yt"},
/* 13B84 */ { "EGYPTIAN HIEROGLYPH-13B84",NULL},
/* 13B85 */ { "EGYPTIAN HIEROGLYPH-13B85","	* phonemogram : wsr"},
/* 13B86 */ { "EGYPTIAN HIEROGLYPH-13B86","	* phonemogram : wsr"},
/* 13B87 */ { "EGYPTIAN HIEROGLYPH-13B87","	* logogram (gazelle) : gḥs"},
/* 13B88 */ { "EGYPTIAN HIEROGLYPH-13B88","	* phonemogram : šsr"},
/* 13B89 */ { "EGYPTIAN HIEROGLYPH-13B89","	* phonemogram : šsm"},
/* 13B8A */ { "EGYPTIAN HIEROGLYPH-13B8A","	* logogram (antilope) : mꜣ"},
/* 13B8B */ { "EGYPTIAN HIEROGLYPH-13B8B","	* phonemogram : šsr"},
/* 13B8C */ { "EGYPTIAN HIEROGLYPH-13B8C","	* logogram (ibex) : n(ꞽ)ꜣw"},
/* 13B8D */ { "EGYPTIAN HIEROGLYPH-13B8D",NULL},
/* 13B8E */ { "EGYPTIAN HIEROGLYPH-13B8E","	* phonemogram : dn"},
/* 13B8F */ { "EGYPTIAN HIEROGLYPH-13B8F","	* phonemogram : ꜣt"},
/* 13B90 */ { "EGYPTIAN HIEROGLYPH-13B90","	* phonemogram : pꜣḫt"},
/* 13B91 */ { "EGYPTIAN HIEROGLYPH-13B91","	* logogram (to distinguish) and (beginning, front) : ṯnꞽ ḥꜣ.t"},
/* 13B92 */ { "EGYPTIAN HIEROGLYPH-13B92","	* logogram (beginning, front) : ḥꜣ.t"},
/* 13B93 */ { "EGYPTIAN HIEROGLYPH-13B93","	* classifier Haker festival : hꜣkr"},
/* 13B94 */ { "EGYPTIAN HIEROGLYPH-13B94","	* logogram (Khonsu) : ḫnsw"},
/* 13B95 */ { "EGYPTIAN HIEROGLYPH-13B95","	* classifier strength : ꜣ.t"},
/* 13B96 */ { "EGYPTIAN HIEROGLYPH-13B96",NULL},
/* 13B97 */ { "EGYPTIAN HIEROGLYPH-13B97","	* phonemogram : ḫntš"},
/* 13B98 */ { "EGYPTIAN HIEROGLYPH-13B98","	* phonemogram : ḫntš"},
/* 13B99 */ { "EGYPTIAN HIEROGLYPH-13B99",NULL},
/* 13B9A */ { "EGYPTIAN HIEROGLYPH-13B9A","	* phonemogram : ḫntš"},
/* 13B9B */ { "EGYPTIAN HIEROGLYPH-13B9B","	* phonemogram : ḫntš"},
/* 13B9C */ { "EGYPTIAN HIEROGLYPH-13B9C","	* phonemogram : ḫntš"},
/* 13B9D */ { "EGYPTIAN HIEROGLYPH-13B9D","	* phonemogram : ḫntš"},
/* 13B9E */ { "EGYPTIAN HIEROGLYPH-13B9E",NULL},
/* 13B9F */ { "EGYPTIAN HIEROGLYPH-13B9F","	* phonemogram : ḫntš"},
/* 13BA0 */ { "EGYPTIAN HIEROGLYPH-13BA0","	* phono-repeater : ḫntš"},
/* 13BA1 */ { "EGYPTIAN HIEROGLYPH-13BA1","	* phonemogram : ꜣbw"},
/* 13BA2 */ { "EGYPTIAN HIEROGLYPH-13BA2","	* classifier hyena : ḥṯ.t"},
/* 13BA3 */ { "EGYPTIAN HIEROGLYPH-13BA3","	* logogram (rage) : nšn"},
/* 13BA4 */ { "EGYPTIAN HIEROGLYPH-13BA4","	* logogram (New Year's Day) : wp-rnp.t"},
/* 13BA5 */ { "EGYPTIAN HIEROGLYPH-13BA5","	* logogram (New Year's Day) : wp-rnp.t"},
/* 13BA6 */ { "EGYPTIAN HIEROGLYPH-13BA6","	* phonemogram (commonly in wp-rnp.t) : wp"},
/* 13BA7 */ { "EGYPTIAN HIEROGLYPH-13BA7",NULL},
/* 13BA8 */ { "EGYPTIAN HIEROGLYPH-13BA8",NULL},
/* 13BA9 */ { "EGYPTIAN HIEROGLYPH-13BA9","	* logogram (the one who awakes whole) : rs-wḏꜣ"},
/* 13BAA */ { "EGYPTIAN HIEROGLYPH-13BAA","	* phonemogram : dmḏ"},
/* 13BAB */ { "EGYPTIAN HIEROGLYPH-13BAB","	* phonemogram : dmḏ"},
/* 13BAC */ { "EGYPTIAN HIEROGLYPH-13BAC",NULL},
/* 13BAD */ { "EGYPTIAN HIEROGLYPH-13BAD",NULL},
/* 13BAE */ { "EGYPTIAN HIEROGLYPH-13BAE","	* logogram (to be true) : mꜣꜥ"},
/* 13BAF */ { "EGYPTIAN HIEROGLYPH-13BAF",NULL},
/* 13BB0 */ { "EGYPTIAN HIEROGLYPH-13BB0",NULL},
/* 13BB1 */ { "EGYPTIAN HIEROGLYPH-13BB1",NULL},
/* 13BB2 */ { "EGYPTIAN HIEROGLYPH-13BB2","	* classifier jaw : ꜥr"},
/* 13BB3 */ { "EGYPTIAN HIEROGLYPH-13BB3","	* phonemogram : ns"},
/* 13BB4 */ { "EGYPTIAN HIEROGLYPH-13BB4","	* phonemogram : ns"},
/* 13BB5 */ { "EGYPTIAN HIEROGLYPH-13BB5","	* phonemogram : ns"},
/* 13BB6 */ { "EGYPTIAN HIEROGLYPH-13BB6","	* logogram to hear, to listen"},
/* 13BB7 */ { "EGYPTIAN HIEROGLYPH-13BB7","	* logogram (magic) : ḥkꜣ.w"},
/* 13BB8 */ { "EGYPTIAN HIEROGLYPH-13BB8","	* phonemogram : sḳr"},
/* 13BB9 */ { "EGYPTIAN HIEROGLYPH-13BB9","	* classifier thigh : mn.t"},
/* 13BBA */ { "EGYPTIAN HIEROGLYPH-13BBA",NULL},
/* 13BBB */ { "EGYPTIAN HIEROGLYPH-13BBB",NULL},
/* 13BBC */ { "EGYPTIAN HIEROGLYPH-13BBC","	* phonemogram : sḳr"},
/* 13BBD */ { "EGYPTIAN HIEROGLYPH-13BBD","	* logogram (to repeat) : wḥm"},
/* 13BBE */ { "EGYPTIAN HIEROGLYPH-13BBE","	* phonemogram : nm"},
/* 13BBF */ { "EGYPTIAN HIEROGLYPH-13BBF","	* phonemogram : nm"},
/* 13BC0 */ { "EGYPTIAN HIEROGLYPH-13BC0","	* phonemogram : kꜣp (gb)"},
/* 13BC1 */ { "EGYPTIAN HIEROGLYPH-13BC1",NULL},
/* 13BC2 */ { "EGYPTIAN HIEROGLYPH-13BC2","	* phonemogram : kꜣp"},
/* 13BC3 */ { "EGYPTIAN HIEROGLYPH-13BC3","	* phonemogram : kꜣp"},
/* 13BC4 */ { "EGYPTIAN HIEROGLYPH-13BC4","	* logogram (Letopolis) : ḫm"},
/* 13BC5 */ { "EGYPTIAN HIEROGLYPH-13BC5","	* phonemogram : bḫ"},
/* 13BC6 */ { "EGYPTIAN HIEROGLYPH-13BC6","	* phonemogram : bḫn"},
/* 13BC7 */ { "EGYPTIAN HIEROGLYPH-13BC7","	* classifier animal : pꜣ-mꞽw"},
/* 13BC8 */ { "EGYPTIAN HIEROGLYPH-13BC8","	* phonemogram : m"},
/* 13BC9 */ { "EGYPTIAN HIEROGLYPH-13BC9","	* classifier animal : ꜥw.t"},
/* 13BCA */ { "EGYPTIAN HIEROGLYPH-13BCA","	* classifier leopard skin : bꜣ"},
/* 13BCB */ { "EGYPTIAN HIEROGLYPH-13BCB","	* classifier hoof : ꜥꜣg.t"},
/* 13BCC */ { "EGYPTIAN HIEROGLYPH-13BCC","	* phonemogram : st"},
/* 13BCD */ { "EGYPTIAN HIEROGLYPH-13BCD","	* phonemogram : st"},
/* 13BCE */ { "EGYPTIAN HIEROGLYPH-13BCE","	* phonemogram : wt"},
/* 13BCF */ { "EGYPTIAN HIEROGLYPH-13BCF","	* phonemogram : ḫnt"},
/* 13BD0 */ { "EGYPTIAN HIEROGLYPH-13BD0","	* phonemogram : šd"},
/* 13BD1 */ { "EGYPTIAN HIEROGLYPH-13BD1","	* phonemogram : šd"},
/* 13BD2 */ { "EGYPTIAN HIEROGLYPH-13BD2","	* logogram (skin, water skin) : šd.w"},
/* 13BD3 */ { "EGYPTIAN HIEROGLYPH-13BD3","	* phonemogram : ms"},
/* 13BD4 */ { "EGYPTIAN HIEROGLYPH-13BD4","	* classifier back/end : pḥ.wy"},
/* 13BD5 */ { "EGYPTIAN HIEROGLYPH-13BD5","	* phonemogram : ẖr"},
/* 13BD6 */ { "EGYPTIAN HIEROGLYPH-13BD6","	* phono-repeater : sd"},
/* 13BD7 */ { "EGYPTIAN HIEROGLYPH-13BD7","	* phonemogram : ꜣbw"},
/* 13BD8 */ { "EGYPTIAN HIEROGLYPH-13BD8","	* phonemogram : mꜣ"},
/* 13BD9 */ { "EGYPTIAN HIEROGLYPH-13BD9",NULL},
/* 13BDA */ { "EGYPTIAN HIEROGLYPH-13BDA","	* phonemogram : mꜣṯ"},
/* 13BDB */ { "EGYPTIAN HIEROGLYPH-13BDB","	* phonemogram : ꜣbw"},
/* 13BDC */ { "EGYPTIAN HIEROGLYPH-13BDC","	* phonemogram : mꜣṯ"},
/* 13BDD */ { "EGYPTIAN HIEROGLYPH-13BDD","	* phonemogram : nfr"},
/* 13BDE */ { "EGYPTIAN HIEROGLYPH-13BDE","	* phonemogram : nfr"},
/* 13BDF */ { "EGYPTIAN HIEROGLYPH-13BDF","	* phonemogram : smꜣ"},
/* 13BE0 */ { "EGYPTIAN HIEROGLYPH-13BE0","	* phonemogram : smꜣ"},
/* 13BE1 */ { "EGYPTIAN HIEROGLYPH-13BE1","	* phonemogram : smꜣ"},
/* 13BE2 */ { "EGYPTIAN HIEROGLYPH-13BE2","	* logogram (who unites the two lands) : smꜣ-tꜣ.wy"},
/* 13BE3 */ { "EGYPTIAN HIEROGLYPH-13BE3","	* classifier (backbone) : psḏ"},
/* 13BE4 */ { "EGYPTIAN HIEROGLYPH-13BE4","	* classifier back, backbone : psḏ"},
/* 13BE5 */ { "EGYPTIAN HIEROGLYPH-13BE5","	* classifier back, backbone : psḏ"},
/* 13BE6 */ { "EGYPTIAN HIEROGLYPH-13BE6","	* classifier cutting/slaughter : ꜥḏy.t"},
/* 13BE7 */ { "EGYPTIAN HIEROGLYPH-13BE7","	* phono-repeater : mḥ"},
/* 13BE8 */ { "EGYPTIAN HIEROGLYPH-13BE8","	* classifier cutting : šꜥd\n"
	"	~ 13BE8 FE00 rotated 90 degrees [= 270 degrees]"},
/* 13BE9 */ { "EGYPTIAN HIEROGLYPH-13BE9","	* classifier shreds, pieces : spꞽ\n"
	"	~ 13BE9 FE00 rotated 90 degrees [= 270 degrees]"},
/* 13BEA */ { "EGYPTIAN HIEROGLYPH-13BEA","	* phono-repeater : mḥ\n"
	"	~ 13BEA FE00 rotated 90 degrees [= 270 degrees]"},
/* 13BEB */ { "EGYPTIAN HIEROGLYPH-13BEB","	* phonemogram : tꜣy"},
/* 13BEC */ { "EGYPTIAN HIEROGLYPH-13BEC","	* phonemogram : ꞽmꜣḫ"},
/* 13BED */ { "EGYPTIAN HIEROGLYPH-13BED",NULL},
/* 13BEE */ { "EGYPTIAN HIEROGLYPH-13BEE","	* logogram (to be long, to stretch out) : ꜣwꞽ"},
/* 13BEF */ { "EGYPTIAN HIEROGLYPH-13BEF","	* logogram (to be long, to stretch out) : ꜣwꞽ"},
/* 13BF0 */ { "EGYPTIAN HIEROGLYPH-13BF0","	* classifier rib (offering) : spr"},
/* 13BF1 */ { "EGYPTIAN HIEROGLYPH-13BF1","	* logogram (slaughter, evil) : šꜥ.t"},
/* 13BF2 */ { "EGYPTIAN HIEROGLYPH-13BF2","	* logogram (slaughter, evil) : šꜥ.t"},
/* 13BF3 */ { "EGYPTIAN HIEROGLYPH-13BF3","	* classifier rib (offering) : spr"},
/* 13BF4 */ { "EGYPTIAN HIEROGLYPH-13BF4",NULL},
/* 13BF5 */ { "EGYPTIAN HIEROGLYPH-13BF5","	* logogram (to bring, present, offer, go) : ms"},
/* 13BF6 */ { "EGYPTIAN HIEROGLYPH-13BF6","	* phonemogram and classifier movement (in thm (to tread, to penetrate)) : m"},
/* 13BF7 */ { "EGYPTIAN HIEROGLYPH-13BF7","	* phono-repeater : ꞽwꜥ"},
/* 13BF8 */ { "EGYPTIAN HIEROGLYPH-13BF8","	* classifier meat : mḏ-nfr"},
/* 13BF9 */ { "EGYPTIAN HIEROGLYPH-13BF9",NULL},
/* 13BFA */ { "EGYPTIAN HIEROGLYPH-13BFA","	* classifier offering meat : sḫn"},
/* 13BFB */ { "EGYPTIAN HIEROGLYPH-13BFB","	* phonemogram : ꞽ(w)n"},
/* 13BFC */ { "EGYPTIAN HIEROGLYPH-13BFC","	* logogram (limb) : ꜥ.t"},
/* 13BFD */ { "EGYPTIAN HIEROGLYPH-13BFD","	* phonemogram : dbn"},
/* 13BFE */ { "EGYPTIAN HIEROGLYPH-13BFE","	* phonemogram (in m-pẖr) : pẖr"},
/* 13BFF */ { "EGYPTIAN HIEROGLYPH-13BFF","	* logogram (to go round, to turn round) : pẖr"}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_3C[] = {
/* 13C00 */ { "EGYPTIAN HIEROGLYPH-13C00","	* logogram (to go round, to turn round) : pẖr"},
/* 13C01 */ { "EGYPTIAN HIEROGLYPH-13C01","	* classifier scent : stꞽ"},
/* 13C02 */ { "EGYPTIAN HIEROGLYPH-13C02","	* classifier scent : stꞽ"},
/* 13C03 */ { "EGYPTIAN HIEROGLYPH-13C03","	* phonemogram : ḫ"},
/* 13C04 */ { "EGYPTIAN HIEROGLYPH-13C04","	* phonemogram or Classifier enemy : ḫ | ḫfty"},
/* 13C05 */ { "EGYPTIAN HIEROGLYPH-13C05","	* classifier liver : mꞽs.t"},
/* 13C06 */ { "EGYPTIAN HIEROGLYPH-13C06",NULL},
/* 13C07 */ { "EGYPTIAN HIEROGLYPH-13C07","	* classifier (talons or fangs) : wḫꜣ.w"},
/* 13C08 */ { "EGYPTIAN HIEROGLYPH-13C08","	* classifier spine : bḳs.w"},
/* 13C09 */ { "EGYPTIAN HIEROGLYPH-13C09","	* phonemogram : tmꜣ"},
/* 13C0A */ { "EGYPTIAN HIEROGLYPH-13C0A","	* phonemogram : tm"},
/* 13C0B */ { "EGYPTIAN HIEROGLYPH-13C0B","	* logogram (ostrich) : nꞽw"},
/* 13C0C */ { "EGYPTIAN HIEROGLYPH-13C0C",NULL},
/* 13C0D */ { "EGYPTIAN HIEROGLYPH-13C0D",NULL},
/* 13C0E */ { "EGYPTIAN HIEROGLYPH-13C0E","	* logogram (to tremble) : sdꜣ"},
/* 13C0F */ { "EGYPTIAN HIEROGLYPH-13C0F","	* classifier to tremble : sd(ꜣ)d(ꜣ)"},
/* 13C10 */ { "EGYPTIAN HIEROGLYPH-13C10","	* phonemogram (like in ḫsbd lapis-lazuli) : b"},
/* 13C11 */ { "EGYPTIAN HIEROGLYPH-13C11","	* logogram (soul) : bꜣ"},
/* 13C12 */ { "EGYPTIAN HIEROGLYPH-13C12",NULL},
/* 13C13 */ { "EGYPTIAN HIEROGLYPH-13C13","	* phono-repeater : ḥtm"},
/* 13C14 */ { "EGYPTIAN HIEROGLYPH-13C14","	* phonemogram : ḫntš"},
/* 13C15 */ { "EGYPTIAN HIEROGLYPH-13C15","	* logogram (Sepa) : spꜣ"},
/* 13C16 */ { "EGYPTIAN HIEROGLYPH-13C16","	* phonemogram : pꜣ(.yw)"},
/* 13C17 */ { "EGYPTIAN HIEROGLYPH-13C17","	* logogram (to tremble) : sdꜣ(dꜣ)"},
/* 13C18 */ { "EGYPTIAN HIEROGLYPH-13C18","	* phonemogram : pꜣ"},
/* 13C19 */ { "EGYPTIAN HIEROGLYPH-13C19","	* logogram (to destroy) : ḥtm"},
/* 13C1A */ { "EGYPTIAN HIEROGLYPH-13C1A","	* classifier : ḥtm"},
/* 13C1B */ { "EGYPTIAN HIEROGLYPH-13C1B","	* phonemogram : ḫn"},
/* 13C1C */ { "EGYPTIAN HIEROGLYPH-13C1C","	* phonemogram : ḫntš"},
/* 13C1D */ { "EGYPTIAN HIEROGLYPH-13C1D","	* phonemogram : ḫntš"},
/* 13C1E */ { "EGYPTIAN HIEROGLYPH-13C1E",NULL},
/* 13C1F */ { "EGYPTIAN HIEROGLYPH-13C1F","	* phonemogram : ḥtr"},
/* 13C20 */ { "EGYPTIAN HIEROGLYPH-13C20","	* phonemogram : ḥtr"},
/* 13C21 */ { "EGYPTIAN HIEROGLYPH-13C21","	* phonemogram : ḳmꜣ"},
/* 13C22 */ { "EGYPTIAN HIEROGLYPH-13C22","	* phonemogram : ḳmꜣ"},
/* 13C23 */ { "EGYPTIAN HIEROGLYPH-13C23","	* phonemogram : ḳmꜣ"},
/* 13C24 */ { "EGYPTIAN HIEROGLYPH-13C24",NULL},
/* 13C25 */ { "EGYPTIAN HIEROGLYPH-13C25","	* phonemogram : ḏfꜣ"},
/* 13C26 */ { "EGYPTIAN HIEROGLYPH-13C26",NULL},
/* 13C27 */ { "EGYPTIAN HIEROGLYPH-13C27","	* phonemogram : smn"},
/* 13C28 */ { "EGYPTIAN HIEROGLYPH-13C28","	* phono-repeater : ḥtm"},
/* 13C29 */ { "EGYPTIAN HIEROGLYPH-13C29","	* phonemogram : ḏb"},
/* 13C2A */ { "EGYPTIAN HIEROGLYPH-13C2A","	* classifier lying, sleeping, spending the night : sḏr"},
/* 13C2B */ { "EGYPTIAN HIEROGLYPH-13C2B","	* phonemogram : gm"},
/* 13C2C */ { "EGYPTIAN HIEROGLYPH-13C2C",NULL},
/* 13C2D */ { "EGYPTIAN HIEROGLYPH-13C2D","	* phonemogram : m"},
/* 13C2E */ { "EGYPTIAN HIEROGLYPH-13C2E","	* phonemogram : mr (ꞽm.y-r)"},
/* 13C2F */ { "EGYPTIAN HIEROGLYPH-13C2F","	* phonemogram : mr (ꞽm.y-r)"},
/* 13C30 */ { "EGYPTIAN HIEROGLYPH-13C30","	* phonemogram/phono-repeater : ꞽb"},
/* 13C31 */ { "EGYPTIAN HIEROGLYPH-13C31","	* phonemogram : ꜥḳ"},
/* 13C32 */ { "EGYPTIAN HIEROGLYPH-13C32",NULL},
/* 13C33 */ { "EGYPTIAN HIEROGLYPH-13C33","	* phonemogram : gm"},
/* 13C34 */ { "EGYPTIAN HIEROGLYPH-13C34","	* phonemogram : bꜣ"},
/* 13C35 */ { "EGYPTIAN HIEROGLYPH-13C35",NULL},
/* 13C36 */ { "EGYPTIAN HIEROGLYPH-13C36","	* phonemogram : b"},
/* 13C37 */ { "EGYPTIAN HIEROGLYPH-13C37","	* logogram (soul) : bꜣ"},
/* 13C38 */ { "EGYPTIAN HIEROGLYPH-13C38","	* logogram (soul) : bꜣ"},
/* 13C39 */ { "EGYPTIAN HIEROGLYPH-13C39",NULL},
/* 13C3A */ { "EGYPTIAN HIEROGLYPH-13C3A","	* logogram (might, power) : bꜣ.w"},
/* 13C3B */ { "EGYPTIAN HIEROGLYPH-13C3B",NULL},
/* 13C3C */ { "EGYPTIAN HIEROGLYPH-13C3C","	* logogram (to hack up, to open up (the earth)) : bꜣ"},
/* 13C3D */ { "EGYPTIAN HIEROGLYPH-13C3D",NULL},
/* 13C3E */ { "EGYPTIAN HIEROGLYPH-13C3E",NULL},
/* 13C3F */ { "EGYPTIAN HIEROGLYPH-13C3F",NULL},
/* 13C40 */ { "EGYPTIAN HIEROGLYPH-13C40","	* phonemogram : ty"},
/* 13C41 */ { "EGYPTIAN HIEROGLYPH-13C41",NULL},
/* 13C42 */ { "EGYPTIAN HIEROGLYPH-13C42",NULL},
/* 13C43 */ { "EGYPTIAN HIEROGLYPH-13C43","	* phonemogram : yt"},
/* 13C44 */ { "EGYPTIAN HIEROGLYPH-13C44",NULL},
/* 13C45 */ { "EGYPTIAN HIEROGLYPH-13C45","	* phonemogram : ḥꜣm"},
/* 13C46 */ { "EGYPTIAN HIEROGLYPH-13C46","	* phonemogram : gm"},
/* 13C47 */ { "EGYPTIAN HIEROGLYPH-13C47","	* classifier bird offering : nšn"},
/* 13C48 */ { "EGYPTIAN HIEROGLYPH-13C48","	* classifier destroy, to destroy (in this case specifically in ḥtm.yt, place of execution) : ḥtm"},
/* 13C49 */ { "EGYPTIAN HIEROGLYPH-13C49","	* logogram (bird, fowl) : ꜣpd"},
/* 13C4A */ { "EGYPTIAN HIEROGLYPH-13C4A","	* phonemogram : b"},
/* 13C4B */ { "EGYPTIAN HIEROGLYPH-13C4B","	* logogram (might, power) : bꜣ.w"},
/* 13C4C */ { "EGYPTIAN HIEROGLYPH-13C4C","	* logogram/phonemogram (in ḥw.t-bꜣ.w (room in the Esna temple)) : bꜣ.w"},
/* 13C4D */ { "EGYPTIAN HIEROGLYPH-13C4D","	* phonemogram : ꜣḫ"},
/* 13C4E */ { "EGYPTIAN HIEROGLYPH-13C4E","	* logogram (god) : nṯr"},
/* 13C4F */ { "EGYPTIAN HIEROGLYPH-13C4F","	* logogram (god) : nṯr"},
/* 13C50 */ { "EGYPTIAN HIEROGLYPH-13C50","	* logogram (god) : nṯr"},
/* 13C51 */ { "EGYPTIAN HIEROGLYPH-13C51","	* logogram (to inundate) : bꜥḥ"},
/* 13C52 */ { "EGYPTIAN HIEROGLYPH-13C52","	* logogram (soul) : bꜣ"},
/* 13C53 */ { "EGYPTIAN HIEROGLYPH-13C53",NULL},
/* 13C54 */ { "EGYPTIAN HIEROGLYPH-13C54","	* logogram (to inundate) : bꜥḥ"},
/* 13C55 */ { "EGYPTIAN HIEROGLYPH-13C55","	* logogram (to inundate) : bꜥḥ"},
/* 13C56 */ { "EGYPTIAN HIEROGLYPH-13C56","	* logogram (inundation) : bꜥḥ"},
/* 13C57 */ { "EGYPTIAN HIEROGLYPH-13C57","	* logogram (god) : nṯr"},
/* 13C58 */ { "EGYPTIAN HIEROGLYPH-13C58","	* phonemogram : b"},
/* 13C59 */ { "EGYPTIAN HIEROGLYPH-13C59","	* classifier heron : bnw"},
/* 13C5A */ { "EGYPTIAN HIEROGLYPH-13C5A","	* phonemogram : tꜣ"},
/* 13C5B */ { "EGYPTIAN HIEROGLYPH-13C5B","	* phonemogram : ꜣḫw"},
/* 13C5C */ { "EGYPTIAN HIEROGLYPH-13C5C","	* logogram (god) : nṯr"},
/* 13C5D */ { "EGYPTIAN HIEROGLYPH-13C5D","	* logogram (Thot) : ḏḥwty"},
/* 13C5E */ { "EGYPTIAN HIEROGLYPH-13C5E","	* logogram (to be excellent) : ꞽḳr"},
/* 13C5F */ { "EGYPTIAN HIEROGLYPH-13C5F","	* logogram (Thot) : ḏḥwty"},
/* 13C60 */ { "EGYPTIAN HIEROGLYPH-13C60","	* logogram (god) : nṯr"},
/* 13C61 */ { "EGYPTIAN HIEROGLYPH-13C61",NULL},
/* 13C62 */ { "EGYPTIAN HIEROGLYPH-13C62","	* logogram (Thot) : ḏḥwty"},
/* 13C63 */ { "EGYPTIAN HIEROGLYPH-13C63","	* logogram (Thot) : ḏḥwty"},
/* 13C64 */ { "EGYPTIAN HIEROGLYPH-13C64","	* logogram (god) : nṯr"},
/* 13C65 */ { "EGYPTIAN HIEROGLYPH-13C65","	* logogram (Thot) : ḏḥwty"},
/* 13C66 */ { "EGYPTIAN HIEROGLYPH-13C66","	* phonemogram : ṯꜣ"},
/* 13C67 */ { "EGYPTIAN HIEROGLYPH-13C67","	* logogram (god) : nṯr"},
/* 13C68 */ { "EGYPTIAN HIEROGLYPH-13C68","	* logogram (god) : nṯr"},
/* 13C69 */ { "EGYPTIAN HIEROGLYPH-13C69","	* classifier Thot : nb ḫmnw"},
/* 13C6A */ { "EGYPTIAN HIEROGLYPH-13C6A","	* logogram (god) : nṯr"},
/* 13C6B */ { "EGYPTIAN HIEROGLYPH-13C6B",NULL},
/* 13C6C */ { "EGYPTIAN HIEROGLYPH-13C6C","	* logogram (Horus) : ḥr"},
/* 13C6D */ { "EGYPTIAN HIEROGLYPH-13C6D","	* logogram (Re-Hor (usually in rꜥ-ḥr-ꜣḫ.ty) : rꜥ-ḥr"},
/* 13C6E */ { "EGYPTIAN HIEROGLYPH-13C6E","	* logogram (Re-Hor (usually in rꜥ-ḥr-ꜣḫ.ty) : rꜥ-ḥr"},
/* 13C6F */ { "EGYPTIAN HIEROGLYPH-13C6F","	* logogram (Re-Hor (usually in rꜥ-ḥr-ꜣḫ.ty) : rꜥ-ḥr"},
/* 13C70 */ { "EGYPTIAN HIEROGLYPH-13C70","	* logogram (Horus) : ḥr"},
/* 13C71 */ { "EGYPTIAN HIEROGLYPH-13C71","	* logogram (Horus) : ḥr"},
/* 13C72 */ { "EGYPTIAN HIEROGLYPH-13C72","	* logogram (Horus) : ḥr"},
/* 13C73 */ { "EGYPTIAN HIEROGLYPH-13C73","	* classifier king : n(.y)-sw.t"},
/* 13C74 */ { "EGYPTIAN HIEROGLYPH-13C74","	* phonemogram : pn"},
/* 13C75 */ { "EGYPTIAN HIEROGLYPH-13C75","	* phonemogram : pn"},
/* 13C76 */ { "EGYPTIAN HIEROGLYPH-13C76","	* classifier divinity : ꞽmt.t"},
/* 13C77 */ { "EGYPTIAN HIEROGLYPH-13C77","	* logogram (Sopdu (divinity)) : spd.w"},
/* 13C78 */ { "EGYPTIAN HIEROGLYPH-13C78","	* logogram (the female Horus) : ḥr.t"},
/* 13C79 */ { "EGYPTIAN HIEROGLYPH-13C79","	* logogram (Horus) : ḥr"},
/* 13C7A */ { "EGYPTIAN HIEROGLYPH-13C7A","	* logogram (the female falcon) : bꞽk.t"},
/* 13C7B */ { "EGYPTIAN HIEROGLYPH-13C7B","	* logogram (goddess) : nṯr.t"},
/* 13C7C */ { "EGYPTIAN HIEROGLYPH-13C7C","	* logogram (god) : nṯr"},
/* 13C7D */ { "EGYPTIAN HIEROGLYPH-13C7D","	* logogram (high quality (red) linen) : ꞽdmꞽ"},
/* 13C7E */ { "EGYPTIAN HIEROGLYPH-13C7E",NULL},
/* 13C7F */ { "EGYPTIAN HIEROGLYPH-13C7F","	* logogram (west) : ꞽmn.t"},
/* 13C80 */ { "EGYPTIAN HIEROGLYPH-13C80","	* logogram (West, 3rd nome of Lower Egypt) : ꞽmn.tt"},
/* 13C81 */ { "EGYPTIAN HIEROGLYPH-13C81","	* logogram (high quality (red) linen) : ꞽdmꞽ"},
/* 13C82 */ { "EGYPTIAN HIEROGLYPH-13C82","	* classifier divine beings/divine things"},
/* 13C83 */ { "EGYPTIAN HIEROGLYPH-13C83","	* logogram (goddess) : nṯr.t"},
/* 13C84 */ { "EGYPTIAN HIEROGLYPH-13C84","	* logogram (goddess) : nṯr.t"},
/* 13C85 */ { "EGYPTIAN HIEROGLYPH-13C85","	* classifier divinity (Min) : mnw"},
/* 13C86 */ { "EGYPTIAN HIEROGLYPH-13C86","	* logogram (may he live, the god) : ꜥnḫ-nṯr"},
/* 13C87 */ { "EGYPTIAN HIEROGLYPH-13C87","	* logogram (majesty) : ḥm"},
/* 13C88 */ { "EGYPTIAN HIEROGLYPH-13C88","	* logogram (majesty) : ḥm"},
/* 13C89 */ { "EGYPTIAN HIEROGLYPH-13C89",NULL},
/* 13C8A */ { "EGYPTIAN HIEROGLYPH-13C8A","	* logogram (Harsomtus) : ḥr-smꜣ-tꜣ.wy"},
/* 13C8B */ { "EGYPTIAN HIEROGLYPH-13C8B","	* logogram (Harsomtus) : ḥr-smꜣ-tꜣ.wy"},
/* 13C8C */ { "EGYPTIAN HIEROGLYPH-13C8C","	* logogram (The two gods, 5th nome of Upper Egypt) : nṯr.wy"},
/* 13C8D */ { "EGYPTIAN HIEROGLYPH-13C8D","	* logogram (Throne of Horus (Edfu)) : wṯs-ḥr"},
/* 13C8E */ { "EGYPTIAN HIEROGLYPH-13C8E","	* logogram (Throne of Horus (Edfu)) : wṯs-ḥr"},
/* 13C8F */ { "EGYPTIAN HIEROGLYPH-13C8F","	* logogram (Throne of Horus (Edfu)) : wṯs-ḥr"},
/* 13C90 */ { "EGYPTIAN HIEROGLYPH-13C90","	* logogram (Throne of Horus (Edfu, 2nd nome of Upper Egypt)) : wṯs-ḥr"},
/* 13C91 */ { "EGYPTIAN HIEROGLYPH-13C91","	* logogram (Horus who is on the palace façade) : ḥr-ḥr.y-srḫ"},
/* 13C92 */ { "EGYPTIAN HIEROGLYPH-13C92","	* logogram/phonemogram (Horus, who endures on the palace façade) : ḥr mn (ḥr) srḫ"},
/* 13C93 */ { "EGYPTIAN HIEROGLYPH-13C93","	* classifier the one who is on the palace façade : ḥr.y-srḫ"},
/* 13C94 */ { "EGYPTIAN HIEROGLYPH-13C94","	* logogram (the living falcon who is on the palace façade) : bꞽk ꜥnḫ ḥr.y srḫ"},
/* 13C95 */ { "EGYPTIAN HIEROGLYPH-13C95","	* logogram (throne, palace façade) : srḫ"},
/* 13C96 */ { "EGYPTIAN HIEROGLYPH-13C96","	* logogram (west, right side) : ꞽmn.t"},
/* 13C97 */ { "EGYPTIAN HIEROGLYPH-13C97","	* logogram (west, right side) : ꞽmn.t"},
/* 13C98 */ { "EGYPTIAN HIEROGLYPH-13C98","	* logogram (necropolis) : ẖr.t-nṯr"},
/* 13C99 */ { "EGYPTIAN HIEROGLYPH-13C99","	* logogram (necropolis) : ẖr.t-nṯr"},
/* 13C9A */ { "EGYPTIAN HIEROGLYPH-13C9A",NULL},
/* 13C9B */ { "EGYPTIAN HIEROGLYPH-13C9B","	* logogram (Nemty (divinity)) : nmty"},
/* 13C9C */ { "EGYPTIAN HIEROGLYPH-13C9C","	* logogram (Nemty (divinity)) : nmty"},
/* 13C9D */ { "EGYPTIAN HIEROGLYPH-13C9D","	* logogram (lord) : nb"},
/* 13C9E */ { "EGYPTIAN HIEROGLYPH-13C9E","	* logogram (lord) : nb"},
/* 13C9F */ { "EGYPTIAN HIEROGLYPH-13C9F","	* logogram (lord) : nb"},
/* 13CA0 */ { "EGYPTIAN HIEROGLYPH-13CA0","	* classifier (Sokar) : skr"},
/* 13CA1 */ { "EGYPTIAN HIEROGLYPH-13CA1","	* phonemogram : p & nst"},
/* 13CA2 */ { "EGYPTIAN HIEROGLYPH-13CA2","	* logogram : ẖr.t-nṯr"},
/* 13CA3 */ { "EGYPTIAN HIEROGLYPH-13CA3","	* logogram (sanctuary of Sokar) : šṯy.t"},
/* 13CA4 */ { "EGYPTIAN HIEROGLYPH-13CA4","	* logogram (lord) : nb"},
/* 13CA5 */ { "EGYPTIAN HIEROGLYPH-13CA5","	* logogram (in bꞽk-n-nbw.t, falcon of the golden ones) : bꞽk & nbw"},
/* 13CA6 */ { "EGYPTIAN HIEROGLYPH-13CA6","	* logogram (golden Horus) : ḥr-nbw"},
/* 13CA7 */ { "EGYPTIAN HIEROGLYPH-13CA7","	* logogram (Nemty (divinity)) : nmty"},
/* 13CA8 */ { "EGYPTIAN HIEROGLYPH-13CA8",NULL},
/* 13CA9 */ { "EGYPTIAN HIEROGLYPH-13CA9",NULL},
/* 13CAA */ { "EGYPTIAN HIEROGLYPH-13CAA","	* classifier high quality (red) linen : (ꞽ)dmꞽ"},
/* 13CAB */ { "EGYPTIAN HIEROGLYPH-13CAB","	* logogram (high quality (red) linen) : ꞽdmꞽ"},
/* 13CAC */ { "EGYPTIAN HIEROGLYPH-13CAC","	* logogram (high quality (red) linen) : ꞽdmꞽ"},
/* 13CAD */ { "EGYPTIAN HIEROGLYPH-13CAD","	* logogram (the one who spreads out his wings ((Dewen-anwy) divinity)) : dwn-ꜥn.wy"},
/* 13CAE */ { "EGYPTIAN HIEROGLYPH-13CAE",NULL},
/* 13CAF */ { "EGYPTIAN HIEROGLYPH-13CAF","	* phonemogram : ṯꜣ"},
/* 13CB0 */ { "EGYPTIAN HIEROGLYPH-13CB0","	* phonemogram and classifier throne (in ṯnṯꜣ.t) : ṯꜣ"},
/* 13CB1 */ { "EGYPTIAN HIEROGLYPH-13CB1",NULL},
/* 13CB2 */ { "EGYPTIAN HIEROGLYPH-13CB2","	* logogram (many-coloured of plumage) : sꜣb-šw.t"},
/* 13CB3 */ { "EGYPTIAN HIEROGLYPH-13CB3","	* logogram (many-coloured of plumage) : sꜣb-šw.t"},
/* 13CB4 */ { "EGYPTIAN HIEROGLYPH-13CB4","	* logogram (many-coloured of plumage) : sꜣb-šw.t"},
/* 13CB5 */ { "EGYPTIAN HIEROGLYPH-13CB5","	* logogram (many-coloured of plumage) : sꜣb-šw.t"},
/* 13CB6 */ { "EGYPTIAN HIEROGLYPH-13CB6","	* logogram (many-coloured of plumage, who goes forth in/from the horizon) : sꜣb-šw.t-pr-m-ꜣḫ.t"},
/* 13CB7 */ { "EGYPTIAN HIEROGLYPH-13CB7","	* logogram (many-coloured of plumage, who goes forth in/from the horizon) : sꜣb-šw.t-pr-m-ꜣḫ.t"},
/* 13CB8 */ { "EGYPTIAN HIEROGLYPH-13CB8","	* logogram (many-coloured of plumage, who goes forth in/from the horizon) : sꜣb-šw.t-pr-m-ꜣḫ.t"},
/* 13CB9 */ { "EGYPTIAN HIEROGLYPH-13CB9",NULL},
/* 13CBA */ { "EGYPTIAN HIEROGLYPH-13CBA","	* logogram (to protect) : ḫwꞽ"},
/* 13CBB */ { "EGYPTIAN HIEROGLYPH-13CBB",NULL},
/* 13CBC */ { "EGYPTIAN HIEROGLYPH-13CBC","	* logogram (the one who spreads out his wings ((Dewen-anwy) divinity)) : dwn-ꜥn.wy"},
/* 13CBD */ { "EGYPTIAN HIEROGLYPH-13CBD",NULL},
/* 13CBE */ { "EGYPTIAN HIEROGLYPH-13CBE","	* logogram (to protect) : mkꞽ/ḫwꞽ"},
/* 13CBF */ { "EGYPTIAN HIEROGLYPH-13CBF","	* classifier falcon : b(ꞽ)k.t"},
/* 13CC0 */ { "EGYPTIAN HIEROGLYPH-13CC0","	* classifier falcon/bird of prey : gmḥs"},
/* 13CC1 */ { "EGYPTIAN HIEROGLYPH-13CC1","	* logogram (god) : nṯr"},
/* 13CC2 */ { "EGYPTIAN HIEROGLYPH-13CC2","	* logogram (god) : nṯr"},
/* 13CC3 */ { "EGYPTIAN HIEROGLYPH-13CC3","	* logogram (Horus) : ḥr"},
/* 13CC4 */ { "EGYPTIAN HIEROGLYPH-13CC4","	* classifier cult image : ꜥẖm"},
/* 13CC5 */ { "EGYPTIAN HIEROGLYPH-13CC5","	* logogram (Horus) : ḥr"},
/* 13CC6 */ { "EGYPTIAN HIEROGLYPH-13CC6","	* logogram (Haroeris) : ḥr-wr"},
/* 13CC7 */ { "EGYPTIAN HIEROGLYPH-13CC7","	* logogram (Haroeris) : ḥr-wr"},
/* 13CC8 */ { "EGYPTIAN HIEROGLYPH-13CC8","	* logogram (Haroeris) : ḥr-wr"},
/* 13CC9 */ { "EGYPTIAN HIEROGLYPH-13CC9","	* logogram (Sopdu (divinity)) : spd.w"},
/* 13CCA */ { "EGYPTIAN HIEROGLYPH-13CCA","	* classifier cult image : ꜥẖm"},
/* 13CCB */ { "EGYPTIAN HIEROGLYPH-13CCB",NULL},
/* 13CCC */ { "EGYPTIAN HIEROGLYPH-13CCC","	* logogram : sḏr"},
/* 13CCD */ { "EGYPTIAN HIEROGLYPH-13CCD",NULL},
/* 13CCE */ { "EGYPTIAN HIEROGLYPH-13CCE",NULL},
/* 13CCF */ { "EGYPTIAN HIEROGLYPH-13CCF","	* classifier (some type of bird) or (Dedwen, divinity) : bn | ddwn"},
/* 13CD0 */ { "EGYPTIAN HIEROGLYPH-13CD0","	* phonemogram : wr"},
/* 13CD1 */ { "EGYPTIAN HIEROGLYPH-13CD1","	* classifier negative, bad : ꞽw.ty"},
/* 13CD2 */ { "EGYPTIAN HIEROGLYPH-13CD2",NULL},
/* 13CD3 */ { "EGYPTIAN HIEROGLYPH-13CD3","	* phonemogram : ḏb"},
/* 13CD4 */ { "EGYPTIAN HIEROGLYPH-13CD4","	* logogram (brick, sheet, ingot) : ḏb.t"},
/* 13CD5 */ { "EGYPTIAN HIEROGLYPH-13CD5","	* logogram (soul) : bꜣ"},
/* 13CD6 */ { "EGYPTIAN HIEROGLYPH-13CD6","	* logogram (soul) : bꜣ"},
/* 13CD7 */ { "EGYPTIAN HIEROGLYPH-13CD7",NULL},
/* 13CD8 */ { "EGYPTIAN HIEROGLYPH-13CD8",NULL},
/* 13CD9 */ { "EGYPTIAN HIEROGLYPH-13CD9","	* phonemogram : b"},
/* 13CDA */ { "EGYPTIAN HIEROGLYPH-13CDA","	* logogram (He of Edfu) : bḥd.ty"},
/* 13CDB */ { "EGYPTIAN HIEROGLYPH-13CDB",NULL},
/* 13CDC */ { "EGYPTIAN HIEROGLYPH-13CDC","	* logogram (the female falcon) : bꞽk.t"},
/* 13CDD */ { "EGYPTIAN HIEROGLYPH-13CDD","	* logogram (goddess) : nṯr.t"},
/* 13CDE */ { "EGYPTIAN HIEROGLYPH-13CDE","	* logogram (soul) : bꜣ"},
/* 13CDF */ { "EGYPTIAN HIEROGLYPH-13CDF",NULL},
/* 13CE0 */ { "EGYPTIAN HIEROGLYPH-13CE0","	* classifier descendant : ḫr(.y)"},
/* 13CE1 */ { "EGYPTIAN HIEROGLYPH-13CE1","	* phonemogram : ṯꜣ"},
/* 13CE2 */ { "EGYPTIAN HIEROGLYPH-13CE2","	* logogram (water fowl) : rꜣ"},
/* 13CE3 */ { "EGYPTIAN HIEROGLYPH-13CE3","	* classifier nest : sš"},
/* 13CE4 */ { "EGYPTIAN HIEROGLYPH-13CE4",NULL},
/* 13CE5 */ { "EGYPTIAN HIEROGLYPH-13CE5","	* classifier nest : sš"},
/* 13CE6 */ { "EGYPTIAN HIEROGLYPH-13CE6","	* phonemogram : rḫt"},
/* 13CE7 */ { "EGYPTIAN HIEROGLYPH-13CE7","	* phonemogram : rḫt"},
/* 13CE8 */ { "EGYPTIAN HIEROGLYPH-13CE8",NULL},
/* 13CE9 */ { "EGYPTIAN HIEROGLYPH-13CE9","	* phonemogram : mḥ"},
/* 13CEA */ { "EGYPTIAN HIEROGLYPH-13CEA","	* phonemogram : mḥ"},
/* 13CEB */ { "EGYPTIAN HIEROGLYPH-13CEB","	* logogram (nest) : sš"},
/* 13CEC */ { "EGYPTIAN HIEROGLYPH-13CEC","	* phonemogram : mḥ"},
/* 13CED */ { "EGYPTIAN HIEROGLYPH-13CED","	* logogram (bird-pool, nest) : sš"},
/* 13CEE */ { "EGYPTIAN HIEROGLYPH-13CEE","	* logogram (nest) : sš"},
/* 13CEF */ { "EGYPTIAN HIEROGLYPH-13CEF","	* logogram (bird-pool, nest, marshland) : sš"},
/* 13CF0 */ { "EGYPTIAN HIEROGLYPH-13CF0","	* classifier pelican : ḥn.t"},
/* 13CF1 */ { "EGYPTIAN HIEROGLYPH-13CF1","	* phonemogram : nḥ"},
/* 13CF2 */ { "EGYPTIAN HIEROGLYPH-13CF2","	* phonemogram : nḥ"},
/* 13CF3 */ { "EGYPTIAN HIEROGLYPH-13CF3","	* phonemogram : nḥ"},
/* 13CF4 */ { "EGYPTIAN HIEROGLYPH-13CF4","	* phonemogram : nḥ"},
/* 13CF5 */ { "EGYPTIAN HIEROGLYPH-13CF5","	* phonemogram : ty"},
/* 13CF6 */ { "EGYPTIAN HIEROGLYPH-13CF6","	* phonemogram : ty"},
/* 13CF7 */ { "EGYPTIAN HIEROGLYPH-13CF7","	* logogram (common folk, subjects, people) : rḫ.yt"},
/* 13CF8 */ { "EGYPTIAN HIEROGLYPH-13CF8","	* logogram (common folk, subjects, people) : rḫ.yt"},
/* 13CF9 */ { "EGYPTIAN HIEROGLYPH-13CF9","	* phonemogram/Logogram (who everyone knows) : rḫ.t-ḥr-nb"},
/* 13CFA */ { "EGYPTIAN HIEROGLYPH-13CFA","	* logogram (common folk, subjects, people) : rḫ.yt"},
/* 13CFB */ { "EGYPTIAN HIEROGLYPH-13CFB","	* logogram (common folk, subjects, people) : rḫ.yt"},
/* 13CFC */ { "EGYPTIAN HIEROGLYPH-13CFC","	* phonemogram : tyw"},
/* 13CFD */ { "EGYPTIAN HIEROGLYPH-13CFD",NULL},
/* 13CFE */ { "EGYPTIAN HIEROGLYPH-13CFE","	* phonemogram : ty"},
/* 13CFF */ { "EGYPTIAN HIEROGLYPH-13CFF",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_3D[] = {
/* 13D00 */ { "EGYPTIAN HIEROGLYPH-13D00","	* phonemogram : nt"},
/* 13D01 */ { "EGYPTIAN HIEROGLYPH-13D01",NULL},
/* 13D02 */ { "EGYPTIAN HIEROGLYPH-13D02","	* logogram (goddess) : nṯr.t"},
/* 13D03 */ { "EGYPTIAN HIEROGLYPH-13D03","	* logogram (Nekhbet (divinity)) : nḫb.t"},
/* 13D04 */ { "EGYPTIAN HIEROGLYPH-13D04","	* classifier divinity (Nekhbet) : nḫb.t"},
/* 13D05 */ { "EGYPTIAN HIEROGLYPH-13D05","	* logogram (Mut (divinity)) : mw.t"},
/* 13D06 */ { "EGYPTIAN HIEROGLYPH-13D06","	* classifier uraeus : wr.t"},
/* 13D07 */ { "EGYPTIAN HIEROGLYPH-13D07","	* logogram (lady (in nb.ty)) : nb.t"},
/* 13D08 */ { "EGYPTIAN HIEROGLYPH-13D08","	* logogram (new year festival) : wp-rnp.t"},
/* 13D09 */ { "EGYPTIAN HIEROGLYPH-13D09","	* logogram/phonemogram (to protect) : mkꞽ"},
/* 13D0A */ { "EGYPTIAN HIEROGLYPH-13D0A","	* logogram/phonemogram (to protect) : mkꞽ"},
/* 13D0B */ { "EGYPTIAN HIEROGLYPH-13D0B","	* logogram/phonemogram (to protect) : mkꞽ"},
/* 13D0C */ { "EGYPTIAN HIEROGLYPH-13D0C",NULL},
/* 13D0D */ { "EGYPTIAN HIEROGLYPH-13D0D",NULL},
/* 13D0E */ { "EGYPTIAN HIEROGLYPH-13D0E","	* phonemogram : ꜣ"},
/* 13D0F */ { "EGYPTIAN HIEROGLYPH-13D0F","	* logogram (mother of the god, lady of) : mw.t-nṯr-nb"},
/* 13D10 */ { "EGYPTIAN HIEROGLYPH-13D10","	* logogram (staff) : mdw"},
/* 13D11 */ { "EGYPTIAN HIEROGLYPH-13D11","	* classifier staff : mdw"},
/* 13D12 */ { "EGYPTIAN HIEROGLYPH-13D12","	* classifier staff"},
/* 13D13 */ { "EGYPTIAN HIEROGLYPH-13D13","	* classifier staff : mdw"},
/* 13D14 */ { "EGYPTIAN HIEROGLYPH-13D14","	* phonemogram : mdw"},
/* 13D15 */ { "EGYPTIAN HIEROGLYPH-13D15","	* logogram (staff) : mdw"},
/* 13D16 */ { "EGYPTIAN HIEROGLYPH-13D16","	* phonemogram/logogram (end) : nfr.(y)t"},
/* 13D17 */ { "EGYPTIAN HIEROGLYPH-13D17","	* logogram (to see) : mꜣꜣ"},
/* 13D18 */ { "EGYPTIAN HIEROGLYPH-13D18","	* phono-repeater : ꞽmꜣḫ"},
/* 13D19 */ { "EGYPTIAN HIEROGLYPH-13D19","	* logogram (to speak, to say) : ḏd"},
/* 13D1A */ { "EGYPTIAN HIEROGLYPH-13D1A","	* classifier common crane : ḏꜣ(.t)"},
/* 13D1B */ { "EGYPTIAN HIEROGLYPH-13D1B","	* logogram (to speak, to say) : ḏd"},
/* 13D1C */ { "EGYPTIAN HIEROGLYPH-13D1C","	* phonemogram : pg"},
/* 13D1D */ { "EGYPTIAN HIEROGLYPH-13D1D","	* phonemogram : ꜣḫ"},
/* 13D1E */ { "EGYPTIAN HIEROGLYPH-13D1E","	* phonemogram/logogram (spirits) : ꜣḫ"},
/* 13D1F */ { "EGYPTIAN HIEROGLYPH-13D1F","	* phono-repeater : nr"},
/* 13D20 */ { "EGYPTIAN HIEROGLYPH-13D20",NULL},
/* 13D21 */ { "EGYPTIAN HIEROGLYPH-13D21",NULL},
/* 13D22 */ { "EGYPTIAN HIEROGLYPH-13D22",NULL},
/* 13D23 */ { "EGYPTIAN HIEROGLYPH-13D23","	* phonemogram : šps"},
/* 13D24 */ { "EGYPTIAN HIEROGLYPH-13D24","	* phonemogram : tꜣš"},
/* 13D25 */ { "EGYPTIAN HIEROGLYPH-13D25","	* classifier double feather : šw.ty"},
/* 13D26 */ { "EGYPTIAN HIEROGLYPH-13D26","	* phonemogram : r"},
/* 13D27 */ { "EGYPTIAN HIEROGLYPH-13D27",NULL},
/* 13D28 */ { "EGYPTIAN HIEROGLYPH-13D28","	* logogram (claw, talon) : ꜥn.t"},
/* 13D29 */ { "EGYPTIAN HIEROGLYPH-13D29","	* logogram (one who is within an egg) : ꞽm.yw-swḥ.t"},
/* 13D2A */ { "EGYPTIAN HIEROGLYPH-13D2A","	* logogram (Duau (divinity)) : dwꜣw"},
/* 13D2B */ { "EGYPTIAN HIEROGLYPH-13D2B","	* phonemogram : m"},
/* 13D2C */ { "EGYPTIAN HIEROGLYPH-13D2C","	* phonemogram : w"},
/* 13D2D */ { "EGYPTIAN HIEROGLYPH-13D2D","	* phonemogram : ꜣ"},
/* 13D2E */ { "EGYPTIAN HIEROGLYPH-13D2E","	* phonemogram : gb"},
/* 13D2F */ { "EGYPTIAN HIEROGLYPH-13D2F","	* logogram (Nehebkau (divinity)) : nḥb-kꜣ.w"},
/* 13D30 */ { "EGYPTIAN HIEROGLYPH-13D30","	* classifier hardun lizard : ḏnf"},
/* 13D31 */ { "EGYPTIAN HIEROGLYPH-13D31","	* classifier evil : ḏwḏw"},
/* 13D32 */ { "EGYPTIAN HIEROGLYPH-13D32","	* classifier Nun : nꞽw"},
/* 13D33 */ { "EGYPTIAN HIEROGLYPH-13D33","	* logogram (Sobek (divinity)) : sbk"},
/* 13D34 */ { "EGYPTIAN HIEROGLYPH-13D34","	* logogram (Iqer, 6th nome of Upper Egypt) : ꞽḳr"},
/* 13D35 */ { "EGYPTIAN HIEROGLYPH-13D35","	* classifier divinity (Sobek) : sbk"},
/* 13D36 */ { "EGYPTIAN HIEROGLYPH-13D36","	* logogram (Iqer, 6th nome of Upper Egypt) : ꞽḳr"},
/* 13D37 */ { "EGYPTIAN HIEROGLYPH-13D37","	* logogram (Medinet Habu) : ṯꜣm.t"},
/* 13D38 */ { "EGYPTIAN HIEROGLYPH-13D38","	* logogram (Iqer, 6th nome of Upper Egypt) : ꞽḳr"},
/* 13D39 */ { "EGYPTIAN HIEROGLYPH-13D39","	* classifier water animal : ꞽm.yw-mw"},
/* 13D3A */ { "EGYPTIAN HIEROGLYPH-13D3A","	* classifier enemy in crocodile form : ḫꜥw"},
/* 13D3B */ { "EGYPTIAN HIEROGLYPH-13D3B","	* logogram (crocodile) : ꜥfꜥ"},
/* 13D3C */ { "EGYPTIAN HIEROGLYPH-13D3C","	* classifier enemy in crocodile form : ḥnt.y"},
/* 13D3D */ { "EGYPTIAN HIEROGLYPH-13D3D","	* classifier enemy in crocodile form : mg(ꜣ)"},
/* 13D3E */ { "EGYPTIAN HIEROGLYPH-13D3E","	* classifier crocodile : ḥnt.y"},
/* 13D3F */ { "EGYPTIAN HIEROGLYPH-13D3F","	* logogram (crocodile) : mg(ꜣ)"},
/* 13D40 */ { "EGYPTIAN HIEROGLYPH-13D40","	* logogram (Sobek (divinity)) : sbk"},
/* 13D41 */ { "EGYPTIAN HIEROGLYPH-13D41","	* logogram (to gather) : sꜣḳ"},
/* 13D42 */ { "EGYPTIAN HIEROGLYPH-13D42","	* logogram (Sobek (divinity)) : sbk"},
/* 13D43 */ { "EGYPTIAN HIEROGLYPH-13D43","	* logogram (Sobek-Re (divinity)) : sbk-rꜥ"},
/* 13D44 */ { "EGYPTIAN HIEROGLYPH-13D44","	* logogram (sovereign) : ꞽty"},
/* 13D45 */ { "EGYPTIAN HIEROGLYPH-13D45","	* logogram (Sobek (divinity)) : sbk"},
/* 13D46 */ { "EGYPTIAN HIEROGLYPH-13D46","	* phonemogram : f"},
/* 13D47 */ { "EGYPTIAN HIEROGLYPH-13D47","	* ?"},
/* 13D48 */ { "EGYPTIAN HIEROGLYPH-13D48","	* logogram (Sobek-Re (divinity)) : sbk-rꜥ"},
/* 13D49 */ { "EGYPTIAN HIEROGLYPH-13D49","	* classifier the two crocodiles : sbk.wy"},
/* 13D4A */ { "EGYPTIAN HIEROGLYPH-13D4A","	* logogram (moment of attack) : ꜣ.t"},
/* 13D4B */ { "EGYPTIAN HIEROGLYPH-13D4B","	* logogram (Egypt) : km.t"},
/* 13D4C */ { "EGYPTIAN HIEROGLYPH-13D4C","	* phonemogram : km"},
/* 13D4D */ { "EGYPTIAN HIEROGLYPH-13D4D","	* phonemogram : km"},
/* 13D4E */ { "EGYPTIAN HIEROGLYPH-13D4E","	* phonemogram : km"},
/* 13D4F */ { "EGYPTIAN HIEROGLYPH-13D4F",NULL},
/* 13D50 */ { "EGYPTIAN HIEROGLYPH-13D50",NULL},
/* 13D51 */ { "EGYPTIAN HIEROGLYPH-13D51","	* logogram Hfn (one hundred thousand)"},
/* 13D52 */ { "EGYPTIAN HIEROGLYPH-13D52","	* logogram (Heqet (divinity)) : ḥḳ.t"},
/* 13D53 */ { "EGYPTIAN HIEROGLYPH-13D53","	* logogram (one hundred thousand) : ḥfn"},
/* 13D54 */ { "EGYPTIAN HIEROGLYPH-13D54","	* classifier snake : ꜥḥꜥ"},
/* 13D55 */ { "EGYPTIAN HIEROGLYPH-13D55","	* logogram (to enter) : ꜥḳ"},
/* 13D56 */ { "EGYPTIAN HIEROGLYPH-13D56","	* logogram (to enter) : ꜥḳ"},
/* 13D57 */ { "EGYPTIAN HIEROGLYPH-13D57","	* logogram (to go forth) : prꞽ"},
/* 13D58 */ { "EGYPTIAN HIEROGLYPH-13D58","	* logogram (to go forth) : prꞽ"},
/* 13D59 */ { "EGYPTIAN HIEROGLYPH-13D59","	* classifier snake : ꜥḥꜥ"},
/* 13D5A */ { "EGYPTIAN HIEROGLYPH-13D5A","	* logogram (lifetime) : ꜥḥꜥ.w"},
/* 13D5B */ { "EGYPTIAN HIEROGLYPH-13D5B","	* phonemogram : ꞽnḏ"},
/* 13D5C */ { "EGYPTIAN HIEROGLYPH-13D5C","	* phonemogram : nf"},
/* 13D5D */ { "EGYPTIAN HIEROGLYPH-13D5D","	* phonemogram : f"},
/* 13D5E */ { "EGYPTIAN HIEROGLYPH-13D5E","	* logogram (father) : ꞽt"},
/* 13D5F */ { "EGYPTIAN HIEROGLYPH-13D5F","	* phonemogram : py"},
/* 13D60 */ { "EGYPTIAN HIEROGLYPH-13D60",NULL},
/* 13D61 */ { "EGYPTIAN HIEROGLYPH-13D61","	* phonemogram/logogram (his name) : rn=f"},
/* 13D62 */ { "EGYPTIAN HIEROGLYPH-13D62","	* logogram (to go forth) : prꞽ"},
/* 13D63 */ { "EGYPTIAN HIEROGLYPH-13D63","	* phonemogram : ꞽnḏ"},
/* 13D64 */ { "EGYPTIAN HIEROGLYPH-13D64","	* logogram (to go forth) : prꞽ"},
/* 13D65 */ { "EGYPTIAN HIEROGLYPH-13D65","	* logogram (divinity) : wr-ḥkꜣ.w"},
/* 13D66 */ { "EGYPTIAN HIEROGLYPH-13D66",NULL},
/* 13D67 */ { "EGYPTIAN HIEROGLYPH-13D67","	* phonemogram/logogram (eternity) : ḏ.t"},
/* 13D68 */ { "EGYPTIAN HIEROGLYPH-13D68","	* logogram (eternity) : ḏ.t"},
/* 13D69 */ { "EGYPTIAN HIEROGLYPH-13D69","	* classifier divinity : ḳbḥ.wt"},
/* 13D6A */ { "EGYPTIAN HIEROGLYPH-13D6A","	* logogram/phonemogram (boundry, cliff) : ṯn.w"},
/* 13D6B */ { "EGYPTIAN HIEROGLYPH-13D6B","	* logogram (boundry, cliff) : ṯn.w"},
/* 13D6C */ { "EGYPTIAN HIEROGLYPH-13D6C","	* classifier divinity : ḳbḥ.wt"},
/* 13D6D */ { "EGYPTIAN HIEROGLYPH-13D6D","	* logogram (the two mountain ranges of the Nile valley) : ṯn.wy"},
/* 13D6E */ { "EGYPTIAN HIEROGLYPH-13D6E","	* logogram (the two mountain ranges of the Nile valley) : ṯn.wy"},
/* 13D6F */ { "EGYPTIAN HIEROGLYPH-13D6F","	* logogram (eternity) : ḏ.t"},
/* 13D70 */ { "EGYPTIAN HIEROGLYPH-13D70","	* phonemogram : nt"},
/* 13D71 */ { "EGYPTIAN HIEROGLYPH-13D71","	* phonemogram : mḏ"},
/* 13D72 */ { "EGYPTIAN HIEROGLYPH-13D72","	* phonemogram (in ḥḏ-tꜣ, dawn, daybreak) : ḥḏ"},
/* 13D73 */ { "EGYPTIAN HIEROGLYPH-13D73","	* logogram (cavern) : ḳr.t"},
/* 13D74 */ { "EGYPTIAN HIEROGLYPH-13D74","	* logogram (cavern) : ḳr.t"},
/* 13D75 */ { "EGYPTIAN HIEROGLYPH-13D75","	* logogram (cavern) : ḳr.t"},
/* 13D76 */ { "EGYPTIAN HIEROGLYPH-13D76","	* logogram (cavern) : ḳr.t"},
/* 13D77 */ { "EGYPTIAN HIEROGLYPH-13D77","	* logogram (cavern) : ḳr.t"},
/* 13D78 */ { "EGYPTIAN HIEROGLYPH-13D78","	* logogram (the two holes, the two caverns) : ḳr.ty"},
/* 13D79 */ { "EGYPTIAN HIEROGLYPH-13D79","	* classifier female divinity"},
/* 13D7A */ { "EGYPTIAN HIEROGLYPH-13D7A","	* logogram (lady (in nb.ty)) : nb.t"},
/* 13D7B */ { "EGYPTIAN HIEROGLYPH-13D7B","	* logogram (fire, flame) : nsr.t"},
/* 13D7C */ { "EGYPTIAN HIEROGLYPH-13D7C","	* logogram (fire, flame) : nsr.t"},
/* 13D7D */ { "EGYPTIAN HIEROGLYPH-13D7D","	* classifier the two udjat eyes : wḏꜣ.ty"},
/* 13D7E */ { "EGYPTIAN HIEROGLYPH-13D7E","	* logogram (goddesses) : nṯr.wt"},
/* 13D7F */ { "EGYPTIAN HIEROGLYPH-13D7F","	* classifier Ennead : psḏ.t"},
/* 13D80 */ { "EGYPTIAN HIEROGLYPH-13D80",NULL},
/* 13D81 */ { "EGYPTIAN HIEROGLYPH-13D81",NULL},
/* 13D82 */ { "EGYPTIAN HIEROGLYPH-13D82","	* logogram (goddess) : nṯr.t"},
/* 13D83 */ { "EGYPTIAN HIEROGLYPH-13D83","	* logogram (goddess) : nṯr.t"},
/* 13D84 */ { "EGYPTIAN HIEROGLYPH-13D84","	* logogram (goddess) : nṯr.t"},
/* 13D85 */ { "EGYPTIAN HIEROGLYPH-13D85",NULL},
/* 13D86 */ { "EGYPTIAN HIEROGLYPH-13D86",NULL},
/* 13D87 */ { "EGYPTIAN HIEROGLYPH-13D87","	* logogram (goddesses) : nṯr.wt"},
/* 13D88 */ { "EGYPTIAN HIEROGLYPH-13D88","	* classifier uraeus snake : wꜣḏ.t"},
/* 13D89 */ { "EGYPTIAN HIEROGLYPH-13D89","	* logogram (lady (in nb.ty)) : nb.t"},
/* 13D8A */ { "EGYPTIAN HIEROGLYPH-13D8A","	* phonemogram : n"},
/* 13D8B */ { "EGYPTIAN HIEROGLYPH-13D8B","	* logogram (lady (in nb.ty)) : nb.t"},
/* 13D8C */ { "EGYPTIAN HIEROGLYPH-13D8C","	* classifier the two uraeus snakes : wꜣḏ.ty"},
/* 13D8D */ { "EGYPTIAN HIEROGLYPH-13D8D","	* logogram (Hathor) : ḥw.t-ḥr"},
/* 13D8E */ { "EGYPTIAN HIEROGLYPH-13D8E","	* logogram (goddess) : nṯr.t"},
/* 13D8F */ { "EGYPTIAN HIEROGLYPH-13D8F","	* logogram (Renenutet) : rnn.wtt"},
/* 13D90 */ { "EGYPTIAN HIEROGLYPH-13D90","	* phonemogram/logogram (to encircle with) : mḥn"},
/* 13D91 */ { "EGYPTIAN HIEROGLYPH-13D91","	* classifier snake, uraeus : ꞽꜥr.ty"},
/* 13D92 */ { "EGYPTIAN HIEROGLYPH-13D92","	* logogram (Wadjet (divinity) : wꜣḏ.t"},
/* 13D93 */ { "EGYPTIAN HIEROGLYPH-13D93","	* logogram (lady (in nb.ty)) : nb.t"},
/* 13D94 */ { "EGYPTIAN HIEROGLYPH-13D94","	* classifier uraeus : wr.t"},
/* 13D95 */ { "EGYPTIAN HIEROGLYPH-13D95","	* logogram (lady (in nb.ty)) : nb.t"},
/* 13D96 */ { "EGYPTIAN HIEROGLYPH-13D96","	* logogram (Renenutet) : rnn.wtt"},
/* 13D97 */ { "EGYPTIAN HIEROGLYPH-13D97","	* logogram (uraeus) : mḥn.t"},
/* 13D98 */ { "EGYPTIAN HIEROGLYPH-13D98","	* classifier coil (of a snake) : mḥn"},
/* 13D99 */ { "EGYPTIAN HIEROGLYPH-13D99","	* logogram (uraeus) : mḥn.t"},
/* 13D9A */ { "EGYPTIAN HIEROGLYPH-13D9A","	* logogram (uraeus) : mḥn.t"},
/* 13D9B */ { "EGYPTIAN HIEROGLYPH-13D9B","	* logogram (uraeus) : mḥn.t"},
/* 13D9C */ { "EGYPTIAN HIEROGLYPH-13D9C",NULL},
/* 13D9D */ { "EGYPTIAN HIEROGLYPH-13D9D","	* logogram (uraeus) : mḥn.t"},
/* 13D9E */ { "EGYPTIAN HIEROGLYPH-13D9E",NULL},
/* 13D9F */ { "EGYPTIAN HIEROGLYPH-13D9F",NULL},
/* 13DA0 */ { "EGYPTIAN HIEROGLYPH-13DA0","	* logogram (lady of Dendera) : nb.t ꞽwn.t"},
/* 13DA1 */ { "EGYPTIAN HIEROGLYPH-13DA1","	* logogram (lady of Dendera) : nb.t ꞽwn.t"},
/* 13DA2 */ { "EGYPTIAN HIEROGLYPH-13DA2","	* phonemogram/logogram (to not know) : n rḫ"},
/* 13DA3 */ { "EGYPTIAN HIEROGLYPH-13DA3","	* phonemogram/logogram (to not know) : n rḫ"},
/* 13DA4 */ { "EGYPTIAN HIEROGLYPH-13DA4","	* phono-repeater : n rḫ"},
/* 13DA5 */ { "EGYPTIAN HIEROGLYPH-13DA5","	* phonemogram/logogram (to not know) : n rḫ"},
/* 13DA6 */ { "EGYPTIAN HIEROGLYPH-13DA6",NULL},
/* 13DA7 */ { "EGYPTIAN HIEROGLYPH-13DA7","	* logogram (Renenutet) : rnn.wtt"},
/* 13DA8 */ { "EGYPTIAN HIEROGLYPH-13DA8","	* phonemogram : (ꞽ)ḫr"},
/* 13DA9 */ { "EGYPTIAN HIEROGLYPH-13DA9","	* phonemogram : n"},
/* 13DAA */ { "EGYPTIAN HIEROGLYPH-13DAA","	* logogram (the two caverns) : ḳr.ty"},
/* 13DAB */ { "EGYPTIAN HIEROGLYPH-13DAB","	* classifier snake"},
/* 13DAC */ { "EGYPTIAN HIEROGLYPH-13DAC",NULL},
/* 13DAD */ { "EGYPTIAN HIEROGLYPH-13DAD","	* classifier snake"},
/* 13DAE */ { "EGYPTIAN HIEROGLYPH-13DAE","	* phonemogram : f"},
/* 13DAF */ { "EGYPTIAN HIEROGLYPH-13DAF","	* classifier snake, serpent : nḥꜣ-ḥr"},
/* 13DB0 */ { "EGYPTIAN HIEROGLYPH-13DB0",NULL},
/* 13DB1 */ { "EGYPTIAN HIEROGLYPH-13DB1","	* phonemogram : f"},
/* 13DB2 */ { "EGYPTIAN HIEROGLYPH-13DB2","	* phonemogram : f"},
/* 13DB3 */ { "EGYPTIAN HIEROGLYPH-13DB3","	* phonemogram n and logogram bꜣ (soul) : n & bꜣ"},
/* 13DB4 */ { "EGYPTIAN HIEROGLYPH-13DB4","	* classifier snake : ꜥꜣpp"},
/* 13DB5 */ { "EGYPTIAN HIEROGLYPH-13DB5",NULL},
/* 13DB6 */ { "EGYPTIAN HIEROGLYPH-13DB6","	* phonemogram : ꜥ"},
/* 13DB7 */ { "EGYPTIAN HIEROGLYPH-13DB7","	* logogram (Shai (divinity)) : šꜣw"},
/* 13DB8 */ { "EGYPTIAN HIEROGLYPH-13DB8","	* classifier snake, serpent : ḥfꜣw"},
/* 13DB9 */ { "EGYPTIAN HIEROGLYPH-13DB9","	* classifier snake, serpent : pẖr-ḥr"},
/* 13DBA */ { "EGYPTIAN HIEROGLYPH-13DBA",NULL},
/* 13DBB */ { "EGYPTIAN HIEROGLYPH-13DBB","	* classifier snake : ꜥꜣpp"},
/* 13DBC */ { "EGYPTIAN HIEROGLYPH-13DBC","	* classifier snake : ḥf(ꜣ).t"},
/* 13DBD */ { "EGYPTIAN HIEROGLYPH-13DBD","	* classifier snake/enemy : bṯw"},
/* 13DBE */ { "EGYPTIAN HIEROGLYPH-13DBE","	* classifier snake/enemy (Apophis) : ꜥꜣpp"},
/* 13DBF */ { "EGYPTIAN HIEROGLYPH-13DBF","	* classifier snake/enemy (Apophis) : ꜥꜣpp"},
/* 13DC0 */ { "EGYPTIAN HIEROGLYPH-13DC0","	* classifier snake : ḏw-ḳd"},
/* 13DC1 */ { "EGYPTIAN HIEROGLYPH-13DC1","	* classifier snake/enemy (Apophis) : ꜥꜣpp"},
/* 13DC2 */ { "EGYPTIAN HIEROGLYPH-13DC2",NULL},
/* 13DC3 */ { "EGYPTIAN HIEROGLYPH-13DC3","	* classifier snake/enemy (Apophis) : ꜥ(ꜣ)pp"},
/* 13DC4 */ { "EGYPTIAN HIEROGLYPH-13DC4","	* classifier snake/divinity : km-ꜣ.t=f"},
/* 13DC5 */ { "EGYPTIAN HIEROGLYPH-13DC5",NULL},
/* 13DC6 */ { "EGYPTIAN HIEROGLYPH-13DC6",NULL},
/* 13DC7 */ { "EGYPTIAN HIEROGLYPH-13DC7",NULL},
/* 13DC8 */ { "EGYPTIAN HIEROGLYPH-13DC8",NULL},
/* 13DC9 */ { "EGYPTIAN HIEROGLYPH-13DC9",NULL},
/* 13DCA */ { "EGYPTIAN HIEROGLYPH-13DCA","	* logogram (the north wind) : mḥy.t"},
/* 13DCB */ { "EGYPTIAN HIEROGLYPH-13DCB","	* phonemogram rr and classifier geographical location : rr"},
/* 13DCC */ { "EGYPTIAN HIEROGLYPH-13DCC","	* logogram (fish) : rm"},
/* 13DCD */ { "EGYPTIAN HIEROGLYPH-13DCD","	* phonemogram : ẖꜣ"},
/* 13DCE */ { "EGYPTIAN HIEROGLYPH-13DCE","	* logogram (canal of the Two Fishes (in the second nome of Upper Egypt)) : ꜥꜣḏ.wy"},
/* 13DCF */ { "EGYPTIAN HIEROGLYPH-13DCF","	* phonemogram : ꞽn"},
/* 13DD0 */ { "EGYPTIAN HIEROGLYPH-13DD0","	* phonemogram/logogram (Shenes (geographical location)) : Šns"},
/* 13DD1 */ { "EGYPTIAN HIEROGLYPH-13DD1","	* logogram (Re) : rꜥ"},
/* 13DD2 */ { "EGYPTIAN HIEROGLYPH-13DD2","	* phonemogram : rꜥ"},
/* 13DD3 */ { "EGYPTIAN HIEROGLYPH-13DD3","	* phonemogram : ẖꜣ"},
/* 13DD4 */ { "EGYPTIAN HIEROGLYPH-13DD4","	* logogram (First-of-fishes nome (16th nome of Lower Egypt)) : ḥꜣ.t-mḥ.yt"},
/* 13DD5 */ { "EGYPTIAN HIEROGLYPH-13DD5","	* phonemogram : ẖꜣ"},
/* 13DD6 */ { "EGYPTIAN HIEROGLYPH-13DD6","	* logogram/phonemogram (to flood out, to emerge) : bsꞽ"},
/* 13DD7 */ { "EGYPTIAN HIEROGLYPH-13DD7","	* logogram/phonemogram (to flood out, to emerge) : bsꞽ"},
/* 13DD8 */ { "EGYPTIAN HIEROGLYPH-13DD8","	* logogram/phonemogram (to flood out, to emerge) : bsꞽ"},
/* 13DD9 */ { "EGYPTIAN HIEROGLYPH-13DD9","	* logogram/phonemogram (to flood out, to emerge) : bsꞽ"},
/* 13DDA */ { "EGYPTIAN HIEROGLYPH-13DDA","	* phonemogram : s"},
/* 13DDB */ { "EGYPTIAN HIEROGLYPH-13DDB",NULL},
/* 13DDC */ { "EGYPTIAN HIEROGLYPH-13DDC","	* logogram (anger, discontent) : špt"},
/* 13DDD */ { "EGYPTIAN HIEROGLYPH-13DDD","	* logogram (to be angry) : špt"},
/* 13DDE */ { "EGYPTIAN HIEROGLYPH-13DDE",NULL},
/* 13DDF */ { "EGYPTIAN HIEROGLYPH-13DDF","	* logogram (to be angry) : špt"},
/* 13DE0 */ { "EGYPTIAN HIEROGLYPH-13DE0",NULL},
/* 13DE1 */ { "EGYPTIAN HIEROGLYPH-13DE1","	* logogram (to become) : ḫpr"},
/* 13DE2 */ { "EGYPTIAN HIEROGLYPH-13DE2","	* logogram/Phonemogram (life to) : ꜥnḫ-n"},
/* 13DE3 */ { "EGYPTIAN HIEROGLYPH-13DE3","	* logogram (to illuminate) : sḥḏ"},
/* 13DE4 */ { "EGYPTIAN HIEROGLYPH-13DE4","	* classifier winged scarab : ꜥpy"},
/* 13DE5 */ { "EGYPTIAN HIEROGLYPH-13DE5","	* logogram (to go forth) : prꞽ"},
/* 13DE6 */ { "EGYPTIAN HIEROGLYPH-13DE6","	* logogram (to go forth) : prꞽ"},
/* 13DE7 */ { "EGYPTIAN HIEROGLYPH-13DE7","	* logogram (to go forth) : prꞽ"},
/* 13DE8 */ { "EGYPTIAN HIEROGLYPH-13DE8",NULL},
/* 13DE9 */ { "EGYPTIAN HIEROGLYPH-13DE9","	* logogram (who goes forth from the horizon) : pr-m-ꜣḫ.t"},
/* 13DEA */ { "EGYPTIAN HIEROGLYPH-13DEA","	* logogram (the winged scarab) : ꜥpy"},
/* 13DEB */ { "EGYPTIAN HIEROGLYPH-13DEB","	* logogram (scarab (amulet)) : ḫprr"},
/* 13DEC */ { "EGYPTIAN HIEROGLYPH-13DEC","	* phonemogram : nt"},
/* 13DED */ { "EGYPTIAN HIEROGLYPH-13DED","	* logogram (beginning) : ḥꜣ.t"},
/* 13DEE */ { "EGYPTIAN HIEROGLYPH-13DEE","	x (egyptian hieroglyph l003 - 131A6)\n"
	"	* classifier fly/insect : ꜥff"},
/* 13DEF */ { "EGYPTIAN HIEROGLYPH-13DEF","	* classifier wasp : tkk.t"},
/* 13DF0 */ { "EGYPTIAN HIEROGLYPH-13DF0","	* phonemogram : r"},
/* 13DF1 */ { "EGYPTIAN HIEROGLYPH-13DF1","	* logogram (mantis) : ḳd.t"},
/* 13DF2 */ { "EGYPTIAN HIEROGLYPH-13DF2","	* classifier scorpion : srḳ.t"},
/* 13DF3 */ { "EGYPTIAN HIEROGLYPH-13DF3",NULL},
/* 13DF4 */ { "EGYPTIAN HIEROGLYPH-13DF4","	* classifier Serket/Selkis : srḳ.t"},
/* 13DF5 */ { "EGYPTIAN HIEROGLYPH-13DF5","	* logogram (Serket/Selkis (divinity)) : srḳ.t"},
/* 13DF6 */ { "EGYPTIAN HIEROGLYPH-13DF6","	* logogram (Serket/Selkis (divinity)) : srḳ.t"},
/* 13DF7 */ { "EGYPTIAN HIEROGLYPH-13DF7","	* classifier tiny insect : ꜥpšꜣy.t"},
/* 13DF8 */ { "EGYPTIAN HIEROGLYPH-13DF8","	* classifier to open : sꜣš"},
/* 13DF9 */ { "EGYPTIAN HIEROGLYPH-13DF9","	* classifier beetle : ꜥnḫ"},
/* 13DFA */ { "EGYPTIAN HIEROGLYPH-13DFA","	* phonemogram : ꞽmꜣ"},
/* 13DFB */ { "EGYPTIAN HIEROGLYPH-13DFB","	* logogram (sycamore) : nh.t"},
/* 13DFC */ { "EGYPTIAN HIEROGLYPH-13DFC",NULL},
/* 13DFD */ { "EGYPTIAN HIEROGLYPH-13DFD","	* logogram (rain (divinity)) : ḥw.t"},
/* 13DFE */ { "EGYPTIAN HIEROGLYPH-13DFE","	* logogram (Neith, 4th and 5th nomes of Lower Egypt) : n.t"},
/* 13DFF */ { "EGYPTIAN HIEROGLYPH-13DFF","	* logogram (14th nome of Upper Egypt) : nḏf.t-pḥ.t"}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_3E[] = {
/* 13E00 */ { "EGYPTIAN HIEROGLYPH-13E00","	* logogram (20th and 21st nomes of Upper Egypt) : nꜥr.t"},
/* 13E01 */ { "EGYPTIAN HIEROGLYPH-13E01","	* logogram (20th and 21st nomes of Upper Egypt) : nꜥr.t"},
/* 13E02 */ { "EGYPTIAN HIEROGLYPH-13E02","	* logogram (13th nome of Upper Egypt) : nḏf.t-ḫnt.t"},
/* 13E03 */ { "EGYPTIAN HIEROGLYPH-13E03","	* classifier tamarisk wood : ꞽsr.t"},
/* 13E04 */ { "EGYPTIAN HIEROGLYPH-13E04",NULL},
/* 13E05 */ { "EGYPTIAN HIEROGLYPH-13E05","	* phono-repeater : bꜣḳ"},
/* 13E06 */ { "EGYPTIAN HIEROGLYPH-13E06","	* classifier wood : mr.t"},
/* 13E07 */ { "EGYPTIAN HIEROGLYPH-13E07","	* classifier wood : ꜥš"},
/* 13E08 */ { "EGYPTIAN HIEROGLYPH-13E08","	* classifier costly wood : s(s)ḏ(m)"},
/* 13E09 */ { "EGYPTIAN HIEROGLYPH-13E09","	* classifier doum palm : mꜣmꜣ"},
/* 13E0A */ { "EGYPTIAN HIEROGLYPH-13E0A","	* classifier doum palm : mꜣmꜣ"},
/* 13E0B */ { "EGYPTIAN HIEROGLYPH-13E0B","	* logogram (true of voice) : mꜣꜥ-ḫrw"},
/* 13E0C */ { "EGYPTIAN HIEROGLYPH-13E0C",NULL},
/* 13E0D */ { "EGYPTIAN HIEROGLYPH-13E0D","	* logogram (to be justified) : mꜣꜥ-ḫrw"},
/* 13E0E */ { "EGYPTIAN HIEROGLYPH-13E0E",NULL},
/* 13E0F */ { "EGYPTIAN HIEROGLYPH-13E0F","	* phono-repeater : ḏꜥ"},
/* 13E10 */ { "EGYPTIAN HIEROGLYPH-13E10","	* phonemogram : ḫr"},
/* 13E11 */ { "EGYPTIAN HIEROGLYPH-13E11","	* phonemogram : ḫt"},
/* 13E12 */ { "EGYPTIAN HIEROGLYPH-13E12",NULL},
/* 13E13 */ { "EGYPTIAN HIEROGLYPH-13E13","	* phonemogram : ḫt"},
/* 13E14 */ { "EGYPTIAN HIEROGLYPH-13E14","	* classifier plant : twr"},
/* 13E15 */ { "EGYPTIAN HIEROGLYPH-13E15","	* classifier oil : sfṯ/ḥꜣ.tt-ꜥš"},
/* 13E16 */ { "EGYPTIAN HIEROGLYPH-13E16","	* classifier plant? : ꞽw.t"},
/* 13E17 */ { "EGYPTIAN HIEROGLYPH-13E17","	* classifier plant : twn"},
/* 13E18 */ { "EGYPTIAN HIEROGLYPH-13E18",NULL},
/* 13E19 */ { "EGYPTIAN HIEROGLYPH-13E19","	* logogram (year) : rnp.t"},
/* 13E1A */ { "EGYPTIAN HIEROGLYPH-13E1A","	* logogram (year) : rnp.t"},
/* 13E1B */ { "EGYPTIAN HIEROGLYPH-13E1B","	* logogram (year) : rnp.t"},
/* 13E1C */ { "EGYPTIAN HIEROGLYPH-13E1C","	* phono-repeater : tr"},
/* 13E1D */ { "EGYPTIAN HIEROGLYPH-13E1D","	* logogram (year) : rnp.t"},
/* 13E1E */ { "EGYPTIAN HIEROGLYPH-13E1E","	* logogram (year) : rnp.t"},
/* 13E1F */ { "EGYPTIAN HIEROGLYPH-13E1F","	* logogram (time/season) : tr"},
/* 13E20 */ { "EGYPTIAN HIEROGLYPH-13E20","	* logogram (to be young, to rejuvenate) : rnpꞽ"},
/* 13E21 */ { "EGYPTIAN HIEROGLYPH-13E21","	* logogram (to be young, to rejuvenate) : rnpꞽ"},
/* 13E22 */ { "EGYPTIAN HIEROGLYPH-13E22","	* classifier/phono-repeater : tr"},
/* 13E23 */ { "EGYPTIAN HIEROGLYPH-13E23","	* logogram (time/season) : tr"},
/* 13E24 */ { "EGYPTIAN HIEROGLYPH-13E24",NULL},
/* 13E25 */ { "EGYPTIAN HIEROGLYPH-13E25",NULL},
/* 13E26 */ { "EGYPTIAN HIEROGLYPH-13E26","	* logogram (year) : rnp.t"},
/* 13E27 */ { "EGYPTIAN HIEROGLYPH-13E27","	* logogram (to be young, to rejuvenate) : rnpꞽ"},
/* 13E28 */ { "EGYPTIAN HIEROGLYPH-13E28",NULL},
/* 13E29 */ { "EGYPTIAN HIEROGLYPH-13E29",NULL},
/* 13E2A */ { "EGYPTIAN HIEROGLYPH-13E2A","	* ?"},
/* 13E2B */ { "EGYPTIAN HIEROGLYPH-13E2B",NULL},
/* 13E2C */ { "EGYPTIAN HIEROGLYPH-13E2C",NULL},
/* 13E2D */ { "EGYPTIAN HIEROGLYPH-13E2D","	* phonemogram : šꜣ"},
/* 13E2E */ { "EGYPTIAN HIEROGLYPH-13E2E","	* phonemogram : šꜣ"},
/* 13E2F */ { "EGYPTIAN HIEROGLYPH-13E2F","	* logogram (marsh, meadow) : šꜣ"},
/* 13E30 */ { "EGYPTIAN HIEROGLYPH-13E30","	* classifier flower : ms"},
/* 13E31 */ { "EGYPTIAN HIEROGLYPH-13E31","	* phonemogram : šꜣ"},
/* 13E32 */ { "EGYPTIAN HIEROGLYPH-13E32","	* phonemogram : šꜣ"},
/* 13E33 */ { "EGYPTIAN HIEROGLYPH-13E33","	* phonemogram : ḫ"},
/* 13E34 */ { "EGYPTIAN HIEROGLYPH-13E34","	* phonemogram : šꜣ"},
/* 13E35 */ { "EGYPTIAN HIEROGLYPH-13E35","	* phonemogram : šꜣ"},
/* 13E36 */ { "EGYPTIAN HIEROGLYPH-13E36","	* phonemogram : š"},
/* 13E37 */ { "EGYPTIAN HIEROGLYPH-13E37",NULL},
/* 13E38 */ { "EGYPTIAN HIEROGLYPH-13E38","	* ?"},
/* 13E39 */ { "EGYPTIAN HIEROGLYPH-13E39","	* classifier offering : wdn"},
/* 13E3A */ { "EGYPTIAN HIEROGLYPH-13E3A","	* classifier lettuce : ꜥb(w)"},
/* 13E3B */ { "EGYPTIAN HIEROGLYPH-13E3B",NULL},
/* 13E3C */ { "EGYPTIAN HIEROGLYPH-13E3C","	* classifier growing : srd"},
/* 13E3D */ { "EGYPTIAN HIEROGLYPH-13E3D",NULL},
/* 13E3E */ { "EGYPTIAN HIEROGLYPH-13E3E",NULL},
/* 13E3F */ { "EGYPTIAN HIEROGLYPH-13E3F","	* logogram (to be good) : nfr"},
/* 13E40 */ { "EGYPTIAN HIEROGLYPH-13E40","	* classifier flower : nḥb.t"},
/* 13E41 */ { "EGYPTIAN HIEROGLYPH-13E41","	* classifier plants/flowers : ḫꜣ.w"},
/* 13E42 */ { "EGYPTIAN HIEROGLYPH-13E42","	* classifier joy : ꜣw-ꞽb"},
/* 13E43 */ { "EGYPTIAN HIEROGLYPH-13E43","	* classifier plant/phono-repeater : hdn"},
/* 13E44 */ { "EGYPTIAN HIEROGLYPH-13E44","	* classifier joy : rš(.w)"},
/* 13E45 */ { "EGYPTIAN HIEROGLYPH-13E45","	* classifier joy : ꜣw-ꞽb"},
/* 13E46 */ { "EGYPTIAN HIEROGLYPH-13E46",NULL},
/* 13E47 */ { "EGYPTIAN HIEROGLYPH-13E47","	* classifier joy : rš(.w)"},
/* 13E48 */ { "EGYPTIAN HIEROGLYPH-13E48","	* classifier flower : ḥrr(.t)"},
/* 13E49 */ { "EGYPTIAN HIEROGLYPH-13E49",NULL},
/* 13E4A */ { "EGYPTIAN HIEROGLYPH-13E4A","	* classifier flower : ḥrr(.t)"},
/* 13E4B */ { "EGYPTIAN HIEROGLYPH-13E4B","	* logogram (flower) : sbtt"},
/* 13E4C */ { "EGYPTIAN HIEROGLYPH-13E4C","	* classifier flower : ḥrr(.t)"},
/* 13E4D */ { "EGYPTIAN HIEROGLYPH-13E4D","	* logogram (Wennefer, title of Osiris) : wnn-nfr"},
/* 13E4E */ { "EGYPTIAN HIEROGLYPH-13E4E","	* classifier plants, vegetables : sm.w"},
/* 13E4F */ { "EGYPTIAN HIEROGLYPH-13E4F","	* logogram (lotus) : nḫb"},
/* 13E50 */ { "EGYPTIAN HIEROGLYPH-13E50",NULL},
/* 13E51 */ { "EGYPTIAN HIEROGLYPH-13E51","	* logogram (lotus) : nḫb"},
/* 13E52 */ { "EGYPTIAN HIEROGLYPH-13E52","	* classifier reed/rush : ꞽꜣr"},
/* 13E53 */ { "EGYPTIAN HIEROGLYPH-13E53","	* classifier reed/rush : ꞽꜣr"},
/* 13E54 */ { "EGYPTIAN HIEROGLYPH-13E54","	* classifier floral offering : ms(w)"},
/* 13E55 */ { "EGYPTIAN HIEROGLYPH-13E55","	* classifier floral offering : ms(w)"},
/* 13E56 */ { "EGYPTIAN HIEROGLYPH-13E56",NULL},
/* 13E57 */ { "EGYPTIAN HIEROGLYPH-13E57",NULL},
/* 13E58 */ { "EGYPTIAN HIEROGLYPH-13E58","	* phonemogram : ḥn"},
/* 13E59 */ { "EGYPTIAN HIEROGLYPH-13E59","	* logogram (to offer) : wdn"},
/* 13E5A */ { "EGYPTIAN HIEROGLYPH-13E5A","	* logogram (to offer) : wdn"},
/* 13E5B */ { "EGYPTIAN HIEROGLYPH-13E5B","	* phonemogram : nfr"},
/* 13E5C */ { "EGYPTIAN HIEROGLYPH-13E5C","	* phonemogram : ḫꜣ"},
/* 13E5D */ { "EGYPTIAN HIEROGLYPH-13E5D","	* phonemogram ḫꜣ? (in the verb ḫꜣḫꜣ, to winnow, to scatter) : ḫꜣ"},
/* 13E5E */ { "EGYPTIAN HIEROGLYPH-13E5E","	* phonemogram : ḫ"},
/* 13E5F */ { "EGYPTIAN HIEROGLYPH-13E5F","	* phonemogram : ḫꜣ"},
/* 13E60 */ { "EGYPTIAN HIEROGLYPH-13E60","	* logogram (\\1000) : ḫꜣ"},
/* 13E61 */ { "EGYPTIAN HIEROGLYPH-13E61","	* phonemogram : šn"},
/* 13E62 */ { "EGYPTIAN HIEROGLYPH-13E62","	* logogram (\\1000) : ḫꜣ"},
/* 13E63 */ { "EGYPTIAN HIEROGLYPH-13E63","	* classifier lotus leaf : sp(ꜣ).t"},
/* 13E64 */ { "EGYPTIAN HIEROGLYPH-13E64","	* phonemogram : ḫꜣ"},
/* 13E65 */ { "EGYPTIAN HIEROGLYPH-13E65","	* \\4000"},
/* 13E66 */ { "EGYPTIAN HIEROGLYPH-13E66","	* phonemogram : wꜣḏ"},
/* 13E67 */ { "EGYPTIAN HIEROGLYPH-13E67","	* phonemogram : wꜣḏ"},
/* 13E68 */ { "EGYPTIAN HIEROGLYPH-13E68",NULL},
/* 13E69 */ { "EGYPTIAN HIEROGLYPH-13E69",NULL},
/* 13E6A */ { "EGYPTIAN HIEROGLYPH-13E6A","	* logogram (Lower Egypt) : mḥ.w"},
/* 13E6B */ { "EGYPTIAN HIEROGLYPH-13E6B","	* phonemogram : ḥs"},
/* 13E6C */ { "EGYPTIAN HIEROGLYPH-13E6C","	* logogram (uraeus) : wꜣḏ.t"},
/* 13E6D */ { "EGYPTIAN HIEROGLYPH-13E6D","	* logogram (uraeus) : wꜣḏ.t"},
/* 13E6E */ { "EGYPTIAN HIEROGLYPH-13E6E","	* logogram (uraeus) : wꜣḏ.t"},
/* 13E6F */ { "EGYPTIAN HIEROGLYPH-13E6F","	* logogram (to gleam, to be bright, to dazzle) : ṯḥn"},
/* 13E70 */ { "EGYPTIAN HIEROGLYPH-13E70","	* logogram (Upper Egypt) : šmꜥ.w"},
/* 13E71 */ { "EGYPTIAN HIEROGLYPH-13E71",NULL},
/* 13E72 */ { "EGYPTIAN HIEROGLYPH-13E72",NULL},
/* 13E73 */ { "EGYPTIAN HIEROGLYPH-13E73","	* phonemogram : ḥꜣ"},
/* 13E74 */ { "EGYPTIAN HIEROGLYPH-13E74","	* classifier marsh/swamp : mḥ.t"},
/* 13E75 */ { "EGYPTIAN HIEROGLYPH-13E75","	* logogram (Lower Egypt) : mḥ.w"},
/* 13E76 */ { "EGYPTIAN HIEROGLYPH-13E76","	* phonemogram : ꜣḫ"},
/* 13E77 */ { "EGYPTIAN HIEROGLYPH-13E77","	* logogram (Lower Egypt) : tꜣ-mḥ.w"},
/* 13E78 */ { "EGYPTIAN HIEROGLYPH-13E78","	* logogram (Upper Egypt) : šmꜥ.w"},
/* 13E79 */ { "EGYPTIAN HIEROGLYPH-13E79","	* phonemogram : ḥꜣ"},
/* 13E7A */ { "EGYPTIAN HIEROGLYPH-13E7A","	* radicogram (grain of Lower Egypt) : mḥ.w"},
/* 13E7B */ { "EGYPTIAN HIEROGLYPH-13E7B","	* logogram (Upper Egypt) : šmꜥ.w"},
/* 13E7C */ { "EGYPTIAN HIEROGLYPH-13E7C","	* logogram (Upper Egypt) : šmꜥ.w"},
/* 13E7D */ { "EGYPTIAN HIEROGLYPH-13E7D","	* logogram (Upper Egypt) : šmꜥ.w"},
/* 13E7E */ { "EGYPTIAN HIEROGLYPH-13E7E","	* logogram (Upper Egypt) : šmꜥ.w"},
/* 13E7F */ { "EGYPTIAN HIEROGLYPH-13E7F",NULL},
/* 13E80 */ { "EGYPTIAN HIEROGLYPH-13E80","	* phonemogram : ḥꜣ"},
/* 13E81 */ { "EGYPTIAN HIEROGLYPH-13E81","	* classifier plants : rnp.wt"},
/* 13E82 */ { "EGYPTIAN HIEROGLYPH-13E82","	* logogram (Lower Egypt) : mḥ.w"},
/* 13E83 */ { "EGYPTIAN HIEROGLYPH-13E83","	* classifier floral offering : ms(w)"},
/* 13E84 */ { "EGYPTIAN HIEROGLYPH-13E84","	* phonemogram : ꞽ"},
/* 13E85 */ { "EGYPTIAN HIEROGLYPH-13E85","	* phonemogram : ꞽ"},
/* 13E86 */ { "EGYPTIAN HIEROGLYPH-13E86","	* phonemogram : ꜥꜣb"},
/* 13E87 */ { "EGYPTIAN HIEROGLYPH-13E87","	* logogram offering : ꜥꜣb.t"},
/* 13E88 */ { "EGYPTIAN HIEROGLYPH-13E88","	* logogram offering : ꜥꜣb.t"},
/* 13E89 */ { "EGYPTIAN HIEROGLYPH-13E89","	* logogram offering : ꜥꜣb.t"},
/* 13E8A */ { "EGYPTIAN HIEROGLYPH-13E8A","	* logogram (marshland, country) : sḫ.t"},
/* 13E8B */ { "EGYPTIAN HIEROGLYPH-13E8B","	* classifier reeds/rushes : ꞽꜣr.w"},
/* 13E8C */ { "EGYPTIAN HIEROGLYPH-13E8C","	* phonemogram : n/rs.y"},
/* 13E8D */ { "EGYPTIAN HIEROGLYPH-13E8D",NULL},
/* 13E8E */ { "EGYPTIAN HIEROGLYPH-13E8E","	* phonemogram : nḫb"},
/* 13E8F */ { "EGYPTIAN HIEROGLYPH-13E8F","	* phonemogram : rsw/rsy"},
/* 13E90 */ { "EGYPTIAN HIEROGLYPH-13E90","	* logogram (Upper Egypt) : šmꜥ.w"},
/* 13E91 */ { "EGYPTIAN HIEROGLYPH-13E91","	* phonemogram : šmꜥ"},
/* 13E92 */ { "EGYPTIAN HIEROGLYPH-13E92","	* logogram (Upper Egypt) : šmꜥ.w"},
/* 13E93 */ { "EGYPTIAN HIEROGLYPH-13E93","	* phonemogram : rsw/rsy"},
/* 13E94 */ { "EGYPTIAN HIEROGLYPH-13E94",NULL},
/* 13E95 */ { "EGYPTIAN HIEROGLYPH-13E95","	* logogram (Upper Egypt) : šmꜥ.w"},
/* 13E96 */ { "EGYPTIAN HIEROGLYPH-13E96","	* logogram (custodian of the property of the king) : ꞽr.y-(ꞽ)ḫ.t-n(.y)-sw.t"},
/* 13E97 */ { "EGYPTIAN HIEROGLYPH-13E97","	* classifier plants : sr{r}.wy"},
/* 13E98 */ { "EGYPTIAN HIEROGLYPH-13E98","	* logogram (Upper Egypt) : šmꜥ.w"},
/* 13E99 */ { "EGYPTIAN HIEROGLYPH-13E99","	* phonemogram : nḫb"},
/* 13E9A */ { "EGYPTIAN HIEROGLYPH-13E9A","	* logogram (king of Upper Egypt) : n(.y)-sw.t"},
/* 13E9B */ { "EGYPTIAN HIEROGLYPH-13E9B","	* phonemogram : šmꜥ"},
/* 13E9C */ { "EGYPTIAN HIEROGLYPH-13E9C",NULL},
/* 13E9D */ { "EGYPTIAN HIEROGLYPH-13E9D","	* logogram (to follow, to accompany) : šms"},
/* 13E9E */ { "EGYPTIAN HIEROGLYPH-13E9E","	* classifier braided lock of hair : ḥnsk.t"},
/* 13E9F */ { "EGYPTIAN HIEROGLYPH-13E9F","	* classifier succesful, fortunate : mꜥr"},
/* 13EA0 */ { "EGYPTIAN HIEROGLYPH-13EA0","	* logogram (succesful, fortunate) : mꜥr"},
/* 13EA1 */ { "EGYPTIAN HIEROGLYPH-13EA1","	* logogram (to be sweet) : bnr/bnꞽ"},
/* 13EA2 */ { "EGYPTIAN HIEROGLYPH-13EA2","	* logogram (to be sweet) : bnr/bnꞽ"},
/* 13EA3 */ { "EGYPTIAN HIEROGLYPH-13EA3","	* classifier plants : rd"},
/* 13EA4 */ { "EGYPTIAN HIEROGLYPH-13EA4",NULL},
/* 13EA5 */ { "EGYPTIAN HIEROGLYPH-13EA5","	* classifier grain, barley, corn : sw.t"},
/* 13EA6 */ { "EGYPTIAN HIEROGLYPH-13EA6","	* logogram (emmer) : bd.t"},
/* 13EA7 */ { "EGYPTIAN HIEROGLYPH-13EA7",NULL},
/* 13EA8 */ { "EGYPTIAN HIEROGLYPH-13EA8","	* phonemogram : ḏr"},
/* 13EA9 */ { "EGYPTIAN HIEROGLYPH-13EA9","	* phonemogram : ḏr"},
/* 13EAA */ { "EGYPTIAN HIEROGLYPH-13EAA","	* classifier tying, binding : dmꜣ"},
/* 13EAB */ { "EGYPTIAN HIEROGLYPH-13EAB","	* phonemogram : ḏr"},
/* 13EAC */ { "EGYPTIAN HIEROGLYPH-13EAC","	* phonemogram : ḏr"},
/* 13EAD */ { "EGYPTIAN HIEROGLYPH-13EAD",NULL},
/* 13EAE */ { "EGYPTIAN HIEROGLYPH-13EAE",NULL},
/* 13EAF */ { "EGYPTIAN HIEROGLYPH-13EAF","	* phonemogram : ḏr"},
/* 13EB0 */ { "EGYPTIAN HIEROGLYPH-13EB0","	* classifier tying, binding : dmꜣ"},
/* 13EB1 */ { "EGYPTIAN HIEROGLYPH-13EB1","	* classifier vegetable, fruit, plant : rnp.wt"},
/* 13EB2 */ { "EGYPTIAN HIEROGLYPH-13EB2","	* logogram ((a vessel) with faience) : ṯḥn.t"},
/* 13EB3 */ { "EGYPTIAN HIEROGLYPH-13EB3","	* phonemogram : ꞽs"},
/* 13EB4 */ { "EGYPTIAN HIEROGLYPH-13EB4","	* phonemogram : ꞽs"},
/* 13EB5 */ { "EGYPTIAN HIEROGLYPH-13EB5","	* phonemogram : ꞽs"},
/* 13EB6 */ { "EGYPTIAN HIEROGLYPH-13EB6",NULL},
/* 13EB7 */ { "EGYPTIAN HIEROGLYPH-13EB7","	* logogram (gardiner, vinter) : kꜣn.y"},
/* 13EB8 */ { "EGYPTIAN HIEROGLYPH-13EB8","	* classifier wine : ꞽrp"},
/* 13EB9 */ { "EGYPTIAN HIEROGLYPH-13EB9","	* classifier fig : dꜣb"},
/* 13EBA */ { "EGYPTIAN HIEROGLYPH-13EBA","	* classifier Min (mnw) or logogram ꜥbw (lettuce) : mnw | ꜥbw"},
/* 13EBB */ { "EGYPTIAN HIEROGLYPH-13EBB","	* classifier unions : ḥḏ(.w)"},
/* 13EBC */ { "EGYPTIAN HIEROGLYPH-13EBC","	* classifier plants : sm"},
/* 13EBD */ { "EGYPTIAN HIEROGLYPH-13EBD",NULL},
/* 13EBE */ { "EGYPTIAN HIEROGLYPH-13EBE","	* classifier lettuce : ꜥb.w"},
/* 13EBF */ { "EGYPTIAN HIEROGLYPH-13EBF",NULL},
/* 13EC0 */ { "EGYPTIAN HIEROGLYPH-13EC0","	* logogram (fig) : dꜣb"},
/* 13EC1 */ { "EGYPTIAN HIEROGLYPH-13EC1",NULL},
/* 13EC2 */ { "EGYPTIAN HIEROGLYPH-13EC2","	* classifier lower sky : nn.t"},
/* 13EC3 */ { "EGYPTIAN HIEROGLYPH-13EC3","	* logogram (granary) : šnw.t"},
/* 13EC4 */ { "EGYPTIAN HIEROGLYPH-13EC4","	* classifier affliction : nḳm.t"},
/* 13EC5 */ { "EGYPTIAN HIEROGLYPH-13EC5","	* classifier cavern : tpḥ.t"},
/* 13EC6 */ { "EGYPTIAN HIEROGLYPH-13EC6","	* logogram (primeval waters) : nw.w"},
/* 13EC7 */ { "EGYPTIAN HIEROGLYPH-13EC7","	* classifier dark/darkness : snk"},
/* 13EC8 */ { "EGYPTIAN HIEROGLYPH-13EC8","	* classifier darkness (in divinity Keket (kk.t)) : kk.t"},
/* 13EC9 */ { "EGYPTIAN HIEROGLYPH-13EC9","	* classifier darkness : wḫ"},
/* 13ECA */ { "EGYPTIAN HIEROGLYPH-13ECA","	* classifier darkness : wḫꜣ"},
/* 13ECB */ { "EGYPTIAN HIEROGLYPH-13ECB","	* logogram (night) : grḥ"},
/* 13ECC */ { "EGYPTIAN HIEROGLYPH-13ECC","	* classifier night : grḥ"},
/* 13ECD */ { "EGYPTIAN HIEROGLYPH-13ECD","	* phonemogram : ḥr.y"},
/* 13ECE */ { "EGYPTIAN HIEROGLYPH-13ECE","	* classifier dawn : ꜥnḏ"},
/* 13ECF */ { "EGYPTIAN HIEROGLYPH-13ECF","	* logogram (dew, scent, rain) : ꞽꜣd.t"},
/* 13ED0 */ { "EGYPTIAN HIEROGLYPH-13ED0","	* classifier cloud/storm/moisture/rain : ꞽgp"},
/* 13ED1 */ { "EGYPTIAN HIEROGLYPH-13ED1","	* classifier cloudiness : ḥꜣty"},
/* 13ED2 */ { "EGYPTIAN HIEROGLYPH-13ED2","	* classifier time : nḥḥ"},
/* 13ED3 */ { "EGYPTIAN HIEROGLYPH-13ED3","	* classifier divinity : ḥr"},
/* 13ED4 */ { "EGYPTIAN HIEROGLYPH-13ED4","	* logogram (king of Upper Egypt and Lower Egypt) : n(.y)-sw.t-bꞽ.ty"},
/* 13ED5 */ { "EGYPTIAN HIEROGLYPH-13ED5","	* logogram (king of Upper Egypt and Lower Egypt) : n(.y)-sw.t-bꞽ.ty"},
/* 13ED6 */ { "EGYPTIAN HIEROGLYPH-13ED6","	* logogram (king of Upper Egypt and Lower Egypt) : n(.y)-sw.t-bꞽ.ty"},
/* 13ED7 */ { "EGYPTIAN HIEROGLYPH-13ED7","	* logogram (king of Upper Egypt and Lower Egypt) : n(.y)-sw.t-bꞽ.ty"},
/* 13ED8 */ { "EGYPTIAN HIEROGLYPH-13ED8","	* logogram (king of Upper Egypt and Lower Egypt) : n(.y)-sw.t-bꞽ.ty"},
/* 13ED9 */ { "EGYPTIAN HIEROGLYPH-13ED9","	* logogram (king of Upper Egypt and Lower Egypt) : n(.y)-sw.t-bꞽ.ty"},
/* 13EDA */ { "EGYPTIAN HIEROGLYPH-13EDA","	* logogram (king of Upper Egypt and Lower Egypt) : n(.y)-sw.t-bꞽ.ty"},
/* 13EDB */ { "EGYPTIAN HIEROGLYPH-13EDB","	* classifier to scatter light, to illuminate : wpš"},
/* 13EDC */ { "EGYPTIAN HIEROGLYPH-13EDC",NULL},
/* 13EDD */ { "EGYPTIAN HIEROGLYPH-13EDD","	* classifier to scatter light, to illuminate : wpš"},
/* 13EDE */ { "EGYPTIAN HIEROGLYPH-13EDE","	* classifier light, shining, rising : ꞽꜣḫ.w"},
/* 13EDF */ { "EGYPTIAN HIEROGLYPH-13EDF","	* classifier light, shining, rising : ḥḏḏ.wt"},
/* 13EE0 */ { "EGYPTIAN HIEROGLYPH-13EE0","	* classifier sunfolk : ḥnmm.t"},
/* 13EE1 */ { "EGYPTIAN HIEROGLYPH-13EE1","	* classifier to shine : wbn"},
/* 13EE2 */ { "EGYPTIAN HIEROGLYPH-13EE2","	* classifier light, shining, rising : sḥḏ"},
/* 13EE3 */ { "EGYPTIAN HIEROGLYPH-13EE3","	* classifier to scatter light, to illuminate : wpš"},
/* 13EE4 */ { "EGYPTIAN HIEROGLYPH-13EE4","	* classifier solar period : rnp.t"},
/* 13EE5 */ { "EGYPTIAN HIEROGLYPH-13EE5",NULL},
/* 13EE6 */ { "EGYPTIAN HIEROGLYPH-13EE6","	* classifier solar period : dwꜣw"},
/* 13EE7 */ { "EGYPTIAN HIEROGLYPH-13EE7","	* classifier to spread out : ḥdy"},
/* 13EE8 */ { "EGYPTIAN HIEROGLYPH-13EE8","	* logogram (the winged scarab or sun disk) : ꜥpy"},
/* 13EE9 */ { "EGYPTIAN HIEROGLYPH-13EE9","	* classifier Horus of Edfu : bḥd.ty"},
/* 13EEA */ { "EGYPTIAN HIEROGLYPH-13EEA","	* logogram (to go forth) : prꞽ"},
/* 13EEB */ { "EGYPTIAN HIEROGLYPH-13EEB","	* classifier divinity : ḏḥwty"},
/* 13EEC */ { "EGYPTIAN HIEROGLYPH-13EEC","	* classifier divinity : ḏḥwty"},
/* 13EED */ { "EGYPTIAN HIEROGLYPH-13EED","	* logogram (king of Upper Egypt and Lower Egypt) : n(.y)-sw.t-bꞽ.ty"},
/* 13EEE */ { "EGYPTIAN HIEROGLYPH-13EEE","	* logogram (king of Upper Egypt and Lower Egypt) : n(.y)-sw.t-bꞽ.ty"},
/* 13EEF */ { "EGYPTIAN HIEROGLYPH-13EEF","	* logogram (to rise, to shine) : wbn"},
/* 13EF0 */ { "EGYPTIAN HIEROGLYPH-13EF0","	* classifier winged sun disk : ꜥpy"},
/* 13EF1 */ { "EGYPTIAN HIEROGLYPH-13EF1","	* logogram (to rise, to shine) : wbn"},
/* 13EF2 */ { "EGYPTIAN HIEROGLYPH-13EF2","	* logogram (to rise, to shine) : wbn"},
/* 13EF3 */ { "EGYPTIAN HIEROGLYPH-13EF3","	* logogram (in rꜥ-nb) : ꞽꜥḥ"},
/* 13EF4 */ { "EGYPTIAN HIEROGLYPH-13EF4",NULL},
/* 13EF5 */ { "EGYPTIAN HIEROGLYPH-13EF5","	* logogram (half-month (festival)) : smd.t"},
/* 13EF6 */ { "EGYPTIAN HIEROGLYPH-13EF6","	* logogram (month) : ꜣbd"},
/* 13EF7 */ { "EGYPTIAN HIEROGLYPH-13EF7",NULL},
/* 13EF8 */ { "EGYPTIAN HIEROGLYPH-13EF8","	* logogram (to gleam, to be bright, to dazzle) : ṯḥn"},
/* 13EF9 */ { "EGYPTIAN HIEROGLYPH-13EF9","	* logogram (Upper Egypt) : tꜣ-šmꜥ.w"},
/* 13EFA */ { "EGYPTIAN HIEROGLYPH-13EFA","	* logogram (Lower Egypt) : tꜣ-mḥ.w"},
/* 13EFB */ { "EGYPTIAN HIEROGLYPH-13EFB","	* logogram (land) : tꜣ"},
/* 13EFC */ { "EGYPTIAN HIEROGLYPH-13EFC","	* logogram (land) : tꜣ"},
/* 13EFD */ { "EGYPTIAN HIEROGLYPH-13EFD","	* logogram (land) : tꜣ"},
/* 13EFE */ { "EGYPTIAN HIEROGLYPH-13EFE","	* logogram (land) : tꜣ"},
/* 13EFF */ { "EGYPTIAN HIEROGLYPH-13EFF","	* logogram (land) : tꜣ"}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_3F[] = {
/* 13F00 */ { "EGYPTIAN HIEROGLYPH-13F00","	* logogram (Dendera) : ꞽꜣ.t-dꞽ"},
/* 13F01 */ { "EGYPTIAN HIEROGLYPH-13F01","	* classifier great water/basin : wrr"},
/* 13F02 */ { "EGYPTIAN HIEROGLYPH-13F02","	* classifier geographical location : tꜣ"},
/* 13F03 */ { "EGYPTIAN HIEROGLYPH-13F03","	* classifier garden : ḥsp"},
/* 13F04 */ { "EGYPTIAN HIEROGLYPH-13F04","	* logogram (nome, district) : spꜣ.t"},
/* 13F05 */ { "EGYPTIAN HIEROGLYPH-13F05","	* logogram (nome, district) : spꜣ.t"},
/* 13F06 */ { "EGYPTIAN HIEROGLYPH-13F06","	* logogram (nome, district) : spꜣ.t"},
/* 13F07 */ { "EGYPTIAN HIEROGLYPH-13F07",NULL},
/* 13F08 */ { "EGYPTIAN HIEROGLYPH-13F08","	* logogram (9th nome of Lower Egypt) : wꜥ-m-ḥww"},
/* 13F09 */ { "EGYPTIAN HIEROGLYPH-13F09",NULL},
/* 13F0A */ { "EGYPTIAN HIEROGLYPH-13F0A","	* classifier garden : ḥsp"},
/* 13F0B */ { "EGYPTIAN HIEROGLYPH-13F0B",NULL},
/* 13F0C */ { "EGYPTIAN HIEROGLYPH-13F0C","	* logogram (Prosopite Nome) : mtr"},
/* 13F0D */ { "EGYPTIAN HIEROGLYPH-13F0D","	* logogram (9th nome of Lower Egypt) : ꜥnḏ.ty"},
/* 13F0E */ { "EGYPTIAN HIEROGLYPH-13F0E","	* logogram (20th and 21st nomes of Upper Egypt) : nꜥr.t"},
/* 13F0F */ { "EGYPTIAN HIEROGLYPH-13F0F","	* logogram (14th nome of Upper Egypt) : nḏf.t-pḥ.t"},
/* 13F10 */ { "EGYPTIAN HIEROGLYPH-13F10","	* logogram (21th nome of Upper Egypt) : nꜥr.t-pḥ.t"},
/* 13F11 */ { "EGYPTIAN HIEROGLYPH-13F11","	* logogram (14th nome of Upper Egypt) : nḏf.t-pḥ.t"},
/* 13F12 */ { "EGYPTIAN HIEROGLYPH-13F12","	* logogram (14th nome of Upper Egypt) : ḫnt.y-ꞽꜣb.ty"},
/* 13F13 */ { "EGYPTIAN HIEROGLYPH-13F13","	* logogram (18th nome of Lower Egypt) : ꞽm.ty-ḫnt.y"},
/* 13F14 */ { "EGYPTIAN HIEROGLYPH-13F14","	* logogram (12th nome of Upper Egypt) : ꜣtf.t"},
/* 13F15 */ { "EGYPTIAN HIEROGLYPH-13F15","	* logogram (Ha (divinity)) : ḥꜣ"},
/* 13F16 */ { "EGYPTIAN HIEROGLYPH-13F16","	* logogram (foreign land/desert) : ḫꜣs.t"},
/* 13F17 */ { "EGYPTIAN HIEROGLYPH-13F17","	* classifier location : ty"},
/* 13F18 */ { "EGYPTIAN HIEROGLYPH-13F18","	* logogram (place of life (i.e., the west)) : ꜥnḫ.t"},
/* 13F19 */ { "EGYPTIAN HIEROGLYPH-13F19","	* logogram (place of life (i.e., the west)) : ꜥnḫ.t"},
/* 13F1A */ { "EGYPTIAN HIEROGLYPH-13F1A","	* classifier foreign land : sṯ.t"},
/* 13F1B */ { "EGYPTIAN HIEROGLYPH-13F1B","	* logogram (the evil one) : ḏw-ḳd"},
/* 13F1C */ { "EGYPTIAN HIEROGLYPH-13F1C","	* logogram (12th nome of Upper Egypt) : ꜣtf.t"},
/* 13F1D */ { "EGYPTIAN HIEROGLYPH-13F1D","	* logogram (12th nome of Upper Egypt) : ꜣtf.t"},
/* 13F1E */ { "EGYPTIAN HIEROGLYPH-13F1E","	* logogram (Ha (divinity)) : ḥꜣ"},
/* 13F1F */ { "EGYPTIAN HIEROGLYPH-13F1F","	* classifier medicaments, incense, oil : snṯr\n"
	"	~ 13F1F FE01 rotated 180 degrees"},
/* 13F20 */ { "EGYPTIAN HIEROGLYPH-13F20","	* logogram (eternity) : nḥḥ"},
/* 13F21 */ { "EGYPTIAN HIEROGLYPH-13F21","	* logogram (place of execution/slaughter) : ḫb.t/nm.t"},
/* 13F22 */ { "EGYPTIAN HIEROGLYPH-13F22",NULL},
/* 13F23 */ { "EGYPTIAN HIEROGLYPH-13F23","	* logogram (eternity) : nḥḥ"},
/* 13F24 */ { "EGYPTIAN HIEROGLYPH-13F24","	* logogram (to appear, to be shining) : ḫꜥꞽ"},
/* 13F25 */ { "EGYPTIAN HIEROGLYPH-13F25","	* logogram hill, mound : ꞽꜣ.t"},
/* 13F26 */ { "EGYPTIAN HIEROGLYPH-13F26","	* logogram hill, mound : ꞽꜣ.t"},
/* 13F27 */ { "EGYPTIAN HIEROGLYPH-13F27",NULL},
/* 13F28 */ { "EGYPTIAN HIEROGLYPH-13F28","	* logogram (Dendera) : ꞽꜣ.t-dꞽ"},
/* 13F29 */ { "EGYPTIAN HIEROGLYPH-13F29","	* phonemogram : ḥr"},
/* 13F2A */ { "EGYPTIAN HIEROGLYPH-13F2A","	* classifier entirely, quite, at all : rsꞽ"},
/* 13F2B */ { "EGYPTIAN HIEROGLYPH-13F2B",NULL},
/* 13F2C */ { "EGYPTIAN HIEROGLYPH-13F2C","	* classifier window : wsy"},
/* 13F2D */ { "EGYPTIAN HIEROGLYPH-13F2D","	* logogram (road) : wꜣ.t"},
/* 13F2E */ { "EGYPTIAN HIEROGLYPH-13F2E","	* classifier road, path : wꜣ.t"},
/* 13F2F */ { "EGYPTIAN HIEROGLYPH-13F2F","	* logogram (time) : hꜣw"},
/* 13F30 */ { "EGYPTIAN HIEROGLYPH-13F30","	* classifier decay, rot : ꜥwꜣ"},
/* 13F31 */ { "EGYPTIAN HIEROGLYPH-13F31","	* phonemogram : n"},
/* 13F32 */ { "EGYPTIAN HIEROGLYPH-13F32","	* logogram (island (in ꞽw-ḏsḏs (El-Bahriya oasis))) : ꞽw"},
/* 13F33 */ { "EGYPTIAN HIEROGLYPH-13F33","	* logogram (Dendera) : ꞽꜣ.t-dꞽ"},
/* 13F34 */ { "EGYPTIAN HIEROGLYPH-13F34","	* phonemogram : m"},
/* 13F35 */ { "EGYPTIAN HIEROGLYPH-13F35",NULL},
/* 13F36 */ { "EGYPTIAN HIEROGLYPH-13F36","	* classifier time : ꜥḥꜥ.w"},
/* 13F37 */ { "EGYPTIAN HIEROGLYPH-13F37","	* classifier bank (river, fortress) : ꞽḫm.t"},
/* 13F38 */ { "EGYPTIAN HIEROGLYPH-13F38","	* classifier waters, rivers, lakes : mr-n-ḫꜣ"},
/* 13F39 */ { "EGYPTIAN HIEROGLYPH-13F39","	* classifier to dam, to revet : ḏnꞽ"},
/* 13F3A */ { "EGYPTIAN HIEROGLYPH-13F3A","	* logogram (to wade) : rhnꞽ"},
/* 13F3B */ { "EGYPTIAN HIEROGLYPH-13F3B","	* phonemogram : s-m"},
/* 13F3C */ { "EGYPTIAN HIEROGLYPH-13F3C","	* phonemogram : š"},
/* 13F3D */ { "EGYPTIAN HIEROGLYPH-13F3D",NULL},
/* 13F3E */ { "EGYPTIAN HIEROGLYPH-13F3E","	* phonemogram : š"},
/* 13F3F */ { "EGYPTIAN HIEROGLYPH-13F3F","	* logogram (Hierakonpolis) : nḫn"},
/* 13F40 */ { "EGYPTIAN HIEROGLYPH-13F40","	* logogram (island) : ꞽw"},
/* 13F41 */ { "EGYPTIAN HIEROGLYPH-13F41","	* logogram (to go) : šm"},
/* 13F42 */ { "EGYPTIAN HIEROGLYPH-13F42",NULL},
/* 13F43 */ { "EGYPTIAN HIEROGLYPH-13F43","	* logogram (Dendera) : ꞽꜣ.t-dꞽ"},
/* 13F44 */ { "EGYPTIAN HIEROGLYPH-13F44","	* phonemogram : ḥm"},
/* 13F45 */ { "EGYPTIAN HIEROGLYPH-13F45","	* phonemogram : ḥm"},
/* 13F46 */ { "EGYPTIAN HIEROGLYPH-13F46","	* logogram (copper) : ḥmt"},
/* 13F47 */ { "EGYPTIAN HIEROGLYPH-13F47","	* classifier metal : bꞽꜣ"},
/* 13F48 */ { "EGYPTIAN HIEROGLYPH-13F48","	* phonemogram : mry"},
/* 13F49 */ { "EGYPTIAN HIEROGLYPH-13F49",NULL},
/* 13F4A */ { "EGYPTIAN HIEROGLYPH-13F4A","	* classifier (lightning bolt) : ḥnb.w"},
/* 13F4B */ { "EGYPTIAN HIEROGLYPH-13F4B",NULL},
/* 13F4C */ { "EGYPTIAN HIEROGLYPH-13F4C","	* classifier two tombs : ꞽs.wy"},
/* 13F4D */ { "EGYPTIAN HIEROGLYPH-13F4D","	* logogram (invocation offering) : pr.t-ḫrw"},
/* 13F4E */ { "EGYPTIAN HIEROGLYPH-13F4E",NULL},
/* 13F4F */ { "EGYPTIAN HIEROGLYPH-13F4F","	* logogram (temple) : gs-pr"},
/* 13F50 */ { "EGYPTIAN HIEROGLYPH-13F50","	* logogram (temple) : gs.w-pr.w "},
/* 13F51 */ { "EGYPTIAN HIEROGLYPH-13F51","	* logogram (temple) : gs.w-pr.w"},
/* 13F52 */ { "EGYPTIAN HIEROGLYPH-13F52","	* logogram (houses, domains) : pr.w"},
/* 13F53 */ { "EGYPTIAN HIEROGLYPH-13F53","	* logogram (court) : wsḫ.t"},
/* 13F54 */ { "EGYPTIAN HIEROGLYPH-13F54","	* classifier place, building : s.t"},
/* 13F55 */ { "EGYPTIAN HIEROGLYPH-13F55",NULL},
/* 13F56 */ { "EGYPTIAN HIEROGLYPH-13F56","	* logogram (temple, mansion, estate) : ḥw.t"},
/* 13F57 */ { "EGYPTIAN HIEROGLYPH-13F57","	* logogram (temples, mansions, estates) : ḥw.wt"},
/* 13F58 */ { "EGYPTIAN HIEROGLYPH-13F58",NULL},
/* 13F59 */ { "EGYPTIAN HIEROGLYPH-13F59","	* logogram (temple, mansion, estate) : ḥw.t"},
/* 13F5A */ { "EGYPTIAN HIEROGLYPH-13F5A",NULL},
/* 13F5B */ { "EGYPTIAN HIEROGLYPH-13F5B","	* logogram (temples, mansions, estates) : ḥw.wt"},
/* 13F5C */ { "EGYPTIAN HIEROGLYPH-13F5C","	* logogram (temples, mansions, estates) : ḥw.wt"},
/* 13F5D */ { "EGYPTIAN HIEROGLYPH-13F5D","	* logogram (Hathor, lady (of)) : ḥw.t-ḥr-nb.t"},
/* 13F5E */ { "EGYPTIAN HIEROGLYPH-13F5E",NULL},
/* 13F5F */ { "EGYPTIAN HIEROGLYPH-13F5F",NULL},
/* 13F60 */ { "EGYPTIAN HIEROGLYPH-13F60","	* logogram (Nephthys (divinity)) : nb.t-ḥw.t"},
/* 13F61 */ { "EGYPTIAN HIEROGLYPH-13F61","	* logogram (Nephthys (divinity)) : nb.t-ḥw.t"},
/* 13F62 */ { "EGYPTIAN HIEROGLYPH-13F62","	* logogram (palace) : ꜥḥ"},
/* 13F63 */ { "EGYPTIAN HIEROGLYPH-13F63","	* logogram (palace) : ꜥḥ"},
/* 13F64 */ { "EGYPTIAN HIEROGLYPH-13F64",NULL},
/* 13F65 */ { "EGYPTIAN HIEROGLYPH-13F65","	* classifier palace : ꜥḥ"},
/* 13F66 */ { "EGYPTIAN HIEROGLYPH-13F66",NULL},
/* 13F67 */ { "EGYPTIAN HIEROGLYPH-13F67","	* logogram (palace) : ꜥḥ"},
/* 13F68 */ { "EGYPTIAN HIEROGLYPH-13F68",NULL},
/* 13F69 */ { "EGYPTIAN HIEROGLYPH-13F69","	* classifier divine : nṯrꞽ"},
/* 13F6A */ { "EGYPTIAN HIEROGLYPH-13F6A","	* phonemogram : wsḫ"},
/* 13F6B */ { "EGYPTIAN HIEROGLYPH-13F6B","	* phonemogram : wsḫ"},
/* 13F6C */ { "EGYPTIAN HIEROGLYPH-13F6C","	* phonemogram : wsḫ"},
/* 13F6D */ { "EGYPTIAN HIEROGLYPH-13F6D","	* phonemogram : wsḫ"},
/* 13F6E */ { "EGYPTIAN HIEROGLYPH-13F6E","	* logogram (court of offerings) : wsḫ.t-ḥtp"},
/* 13F6F */ { "EGYPTIAN HIEROGLYPH-13F6F",NULL},
/* 13F70 */ { "EGYPTIAN HIEROGLYPH-13F70",NULL},
/* 13F71 */ { "EGYPTIAN HIEROGLYPH-13F71",NULL},
/* 13F72 */ { "EGYPTIAN HIEROGLYPH-13F72","	* logogram (wall) : ꞽnb\n"
	"	~ 13F72 FE00 rotated 90 degrees [= 270 degrees]"},
/* 13F73 */ { "EGYPTIAN HIEROGLYPH-13F73","	* classifier overthrow, demolish : snb"},
/* 13F74 */ { "EGYPTIAN HIEROGLYPH-13F74","	* classifier overthrow, demolish : sšn"},
/* 13F75 */ { "EGYPTIAN HIEROGLYPH-13F75","	* classifier geographical location : km-wr"},
/* 13F76 */ { "EGYPTIAN HIEROGLYPH-13F76","	* classifier geographical location (Elephantine) : ꜣbw"},
/* 13F77 */ { "EGYPTIAN HIEROGLYPH-13F77",NULL},
/* 13F78 */ { "EGYPTIAN HIEROGLYPH-13F78","	* classifier wall : sbty"},
/* 13F79 */ { "EGYPTIAN HIEROGLYPH-13F79","	* logogram i(Memphis (the white wall)) : nb-ḥḏ"},
/* 13F7A */ { "EGYPTIAN HIEROGLYPH-13F7A",NULL},
/* 13F7B */ { "EGYPTIAN HIEROGLYPH-13F7B","	* logogram (serekh (palace) façade) : srḫ"},
/* 13F7C */ { "EGYPTIAN HIEROGLYPH-13F7C","	* classifier palace façade : srḫ"},
/* 13F7D */ { "EGYPTIAN HIEROGLYPH-13F7D",NULL},
/* 13F7E */ { "EGYPTIAN HIEROGLYPH-13F7E",NULL},
/* 13F7F */ { "EGYPTIAN HIEROGLYPH-13F7F","	* classifier palace façade : srḫ"},
/* 13F80 */ { "EGYPTIAN HIEROGLYPH-13F80","	* logogram (serekh (palace) façade) : srḫ"},
/* 13F81 */ { "EGYPTIAN HIEROGLYPH-13F81","	* logogram (serekh (palace) façade) : srḫ"},
/* 13F82 */ { "EGYPTIAN HIEROGLYPH-13F82","	* logogram (chapel) : ḥḏ"},
/* 13F83 */ { "EGYPTIAN HIEROGLYPH-13F83","	* logogram (chapel) : ḥḏ"},
/* 13F84 */ { "EGYPTIAN HIEROGLYPH-13F84","	* logogram (serekh (palace) façade) : srḫ"},
/* 13F85 */ { "EGYPTIAN HIEROGLYPH-13F85","	* logogram (serekh (palace) façade) : srḫ"},
/* 13F86 */ { "EGYPTIAN HIEROGLYPH-13F86","	* logogram (serekh (palace) façade) : srḫ"},
/* 13F87 */ { "EGYPTIAN HIEROGLYPH-13F87","	* logogram (serekh (palace) façade) : srḫ"},
/* 13F88 */ { "EGYPTIAN HIEROGLYPH-13F88","	* classifier pylon/gateway : bḫny"},
/* 13F89 */ { "EGYPTIAN HIEROGLYPH-13F89",NULL},
/* 13F8A */ { "EGYPTIAN HIEROGLYPH-13F8A","	* logogram (sanctuary of Upper Egypt) : pr-wr"},
/* 13F8B */ { "EGYPTIAN HIEROGLYPH-13F8B","	* classifier doorway/gateway : mꜣh.t"},
/* 13F8C */ { "EGYPTIAN HIEROGLYPH-13F8C","	* logogram : ḥw.t"},
/* 13F8D */ { "EGYPTIAN HIEROGLYPH-13F8D","	* logogram (chapel) : kꜣr"},
/* 13F8E */ { "EGYPTIAN HIEROGLYPH-13F8E","	* logogram (chapel)"},
/* 13F8F */ { "EGYPTIAN HIEROGLYPH-13F8F","	* phonemogram (in r-rw.t (outside)) : rw.t"},
/* 13F90 */ { "EGYPTIAN HIEROGLYPH-13F90","	* logogram (palace) : ꜥḥ"},
/* 13F91 */ { "EGYPTIAN HIEROGLYPH-13F91","	* logogram (portal, portico) : sbḫ.t"},
/* 13F92 */ { "EGYPTIAN HIEROGLYPH-13F92","	* classifier doorway : sbꜣ"},
/* 13F93 */ { "EGYPTIAN HIEROGLYPH-13F93","	* phonemogram (in r-rw.t (outside)) : rw.t"},
/* 13F94 */ { "EGYPTIAN HIEROGLYPH-13F94","	* logogram (doorway) : sbꜣ"},
/* 13F95 */ { "EGYPTIAN HIEROGLYPH-13F95","	* classifier portal, portico : sbḫ.t"},
/* 13F96 */ { "EGYPTIAN HIEROGLYPH-13F96","	* classifier tomb : ꞽs"},
/* 13F97 */ { "EGYPTIAN HIEROGLYPH-13F97",NULL},
/* 13F98 */ { "EGYPTIAN HIEROGLYPH-13F98","	* classifier portal, portico : sbḫ.t"},
/* 13F99 */ { "EGYPTIAN HIEROGLYPH-13F99","	* logogram (main gate of a temple) : tꜣy.t"},
/* 13F9A */ { "EGYPTIAN HIEROGLYPH-13F9A","	* classifier curtain : tꜣy.ty"},
/* 13F9B */ { "EGYPTIAN HIEROGLYPH-13F9B",NULL},
/* 13F9C */ { "EGYPTIAN HIEROGLYPH-13F9C","	* classifier funerary chapel, cenotaph : mꜥḥꜥ.t"},
/* 13F9D */ { "EGYPTIAN HIEROGLYPH-13F9D","	* classifier chapel : ḥḏ"},
/* 13F9E */ { "EGYPTIAN HIEROGLYPH-13F9E","	* logogram (sanctuary of Upper Egypt) : pr-wr"},
/* 13F9F */ { "EGYPTIAN HIEROGLYPH-13F9F","	* logogram (to be divine) : nṯrꞽ"},
/* 13FA0 */ { "EGYPTIAN HIEROGLYPH-13FA0",NULL},
/* 13FA1 */ { "EGYPTIAN HIEROGLYPH-13FA1","	* classifier shrine : pr-wr"},
/* 13FA2 */ { "EGYPTIAN HIEROGLYPH-13FA2","	* logogram (sanctuary of Upper Egypt) : pr-wr"},
/* 13FA3 */ { "EGYPTIAN HIEROGLYPH-13FA3","	* logogram (sanctuary of Upper Egypt) : pr-wr"},
/* 13FA4 */ { "EGYPTIAN HIEROGLYPH-13FA4",NULL},
/* 13FA5 */ { "EGYPTIAN HIEROGLYPH-13FA5","	* classifier shrine : ḥḏ-šps"},
/* 13FA6 */ { "EGYPTIAN HIEROGLYPH-13FA6","	* classifier shrine : pr-wr"},
/* 13FA7 */ { "EGYPTIAN HIEROGLYPH-13FA7","	* classifier chapel (associated with Min) : sḥn"},
/* 13FA8 */ { "EGYPTIAN HIEROGLYPH-13FA8","	* logogram (Ennead) : psḏ.t"},
/* 13FA9 */ { "EGYPTIAN HIEROGLYPH-13FA9","	* classifier shrine : s.t=f-wr.t"},
/* 13FAA */ { "EGYPTIAN HIEROGLYPH-13FAA",NULL},
/* 13FAB */ { "EGYPTIAN HIEROGLYPH-13FAB","	* logogram (sanctuary of Sokar) : šṯy.t"},
/* 13FAC */ { "EGYPTIAN HIEROGLYPH-13FAC","	* classifier sanctuary, shrine : pr-nsr"},
/* 13FAD */ { "EGYPTIAN HIEROGLYPH-13FAD","	* logogram (shrine, row of shrines) : ꞽtr.t"},
/* 13FAE */ { "EGYPTIAN HIEROGLYPH-13FAE","	* logogram (Dendera) : ꞽwn.t"},
/* 13FAF */ { "EGYPTIAN HIEROGLYPH-13FAF",NULL},
/* 13FB0 */ { "EGYPTIAN HIEROGLYPH-13FB0",NULL},
/* 13FB1 */ { "EGYPTIAN HIEROGLYPH-13FB1","	* logogram (sanctuary of Upper Egypt) : pr-wr"},
/* 13FB2 */ { "EGYPTIAN HIEROGLYPH-13FB2",NULL},
/* 13FB3 */ { "EGYPTIAN HIEROGLYPH-13FB3","	* logogram (portal, portico) : hꜣy,t"},
/* 13FB4 */ { "EGYPTIAN HIEROGLYPH-13FB4","	* logogram (ceiling, heaven) : hꜣy.t"},
/* 13FB5 */ { "EGYPTIAN HIEROGLYPH-13FB5","	* logogram (portal, portico) : hꜣy,t"},
/* 13FB6 */ { "EGYPTIAN HIEROGLYPH-13FB6","	* ?Logogram (shrine?) : sḥ"},
/* 13FB7 */ { "EGYPTIAN HIEROGLYPH-13FB7","	* logogram (pavilion, hall, booth) : sḥ"},
/* 13FB8 */ { "EGYPTIAN HIEROGLYPH-13FB8","	* logogram (to tie on, to don) : ꜥrḳ"},
/* 13FB9 */ { "EGYPTIAN HIEROGLYPH-13FB9",NULL},
/* 13FBA */ { "EGYPTIAN HIEROGLYPH-13FBA",NULL},
/* 13FBB */ { "EGYPTIAN HIEROGLYPH-13FBB","	* logogram (divine booth) : sḥ-nṯr"},
/* 13FBC */ { "EGYPTIAN HIEROGLYPH-13FBC","	* logogram (booth) : sḥ"},
/* 13FBD */ { "EGYPTIAN HIEROGLYPH-13FBD","	* phonemogram : ꜥrḳ"},
/* 13FBE */ { "EGYPTIAN HIEROGLYPH-13FBE","	* phonemogram (in ꜥrḳ-wr) : ꜥrḳ"},
/* 13FBF */ { "EGYPTIAN HIEROGLYPH-13FBF","	* phonemogram : ꜥrḳ"},
/* 13FC0 */ { "EGYPTIAN HIEROGLYPH-13FC0","	* logogram (jubilee, sed-festival) : ḥb-sd"},
/* 13FC1 */ { "EGYPTIAN HIEROGLYPH-13FC1","	* classifier throne dais : ṯnṯꜣ.t"},
/* 13FC2 */ { "EGYPTIAN HIEROGLYPH-13FC2",NULL},
/* 13FC3 */ { "EGYPTIAN HIEROGLYPH-13FC3","	* logogram (jubilee, sed-festival) : ḥb-sd"},
/* 13FC4 */ { "EGYPTIAN HIEROGLYPH-13FC4","	* logogram (four) : (ꞽ)fd.w"},
/* 13FC5 */ { "EGYPTIAN HIEROGLYPH-13FC5","	* logogram (jubilee, sed-festival) : ḥb-sd"},
/* 13FC6 */ { "EGYPTIAN HIEROGLYPH-13FC6","	* logogram (jubilee, sed-festival) : ḥb-sd"},
/* 13FC7 */ { "EGYPTIAN HIEROGLYPH-13FC7",NULL},
/* 13FC8 */ { "EGYPTIAN HIEROGLYPH-13FC8",NULL},
/* 13FC9 */ { "EGYPTIAN HIEROGLYPH-13FC9","	* logogram (jubilee, sed-festival) : ḥb-sd"},
/* 13FCA */ { "EGYPTIAN HIEROGLYPH-13FCA","	* classifier jubilee, sed-festival : ḥb-sd"},
/* 13FCB */ { "EGYPTIAN HIEROGLYPH-13FCB","	* classifier jubilee, sed-festival : ḥb-sd"},
/* 13FCC */ { "EGYPTIAN HIEROGLYPH-13FCC","	* logogram (jubilee, sed-festival) : ḥb-sd"},
/* 13FCD */ { "EGYPTIAN HIEROGLYPH-13FCD","	* logogram (festival) : ḥb"},
/* 13FCE */ { "EGYPTIAN HIEROGLYPH-13FCE","	* logogram (jubilee, sed-festival) : ḥb-sd"},
/* 13FCF */ { "EGYPTIAN HIEROGLYPH-13FCF","	* logogram (jubilee, sed-festival) : ḥb-sd"},
/* 13FD0 */ { "EGYPTIAN HIEROGLYPH-13FD0","	* logogram (jubilee, sed-festival) : ḥb-sd"},
/* 13FD1 */ { "EGYPTIAN HIEROGLYPH-13FD1",NULL},
/* 13FD2 */ { "EGYPTIAN HIEROGLYPH-13FD2","	* logogram (jubilee, sed-festival) : ḥb-sd"},
/* 13FD3 */ { "EGYPTIAN HIEROGLYPH-13FD3","	* logogram (jubilee, sed-festival) : ḥb-sd"},
/* 13FD4 */ { "EGYPTIAN HIEROGLYPH-13FD4","	* logogram (jubilee, sed-festival) : ḥb-sd"},
/* 13FD5 */ { "EGYPTIAN HIEROGLYPH-13FD5","	* logogram (festival) : h(ꜣ)b"},
/* 13FD6 */ { "EGYPTIAN HIEROGLYPH-13FD6","	* logogram (ceiling, heaven) : hꜣy.t"},
/* 13FD7 */ { "EGYPTIAN HIEROGLYPH-13FD7","	* phonemogram/Logogram : ḥꜣy.t n bꜣ"},
/* 13FD8 */ { "EGYPTIAN HIEROGLYPH-13FD8","	* classifier to ascend, to mount up : sꞽꜥ"},
/* 13FD9 */ { "EGYPTIAN HIEROGLYPH-13FD9","	* ?"},
/* 13FDA */ { "EGYPTIAN HIEROGLYPH-13FDA","	* classifier obelisk : tḫn"},
/* 13FDB */ { "EGYPTIAN HIEROGLYPH-13FDB","	* phonemogram/logogram (to beget, to ejaculate, to create) : bnbn"},
/* 13FDC */ { "EGYPTIAN HIEROGLYPH-13FDC","	* classifier solar temple : s.t-ꞽb-rꜥ"},
/* 13FDD */ { "EGYPTIAN HIEROGLYPH-13FDD","	* classifier shrine/chapel : ꞽtr.t"},
/* 13FDE */ { "EGYPTIAN HIEROGLYPH-13FDE","	* logogram (shrine, row of shrines) : ꞽtr.t"},
/* 13FDF */ { "EGYPTIAN HIEROGLYPH-13FDF","	* phonemogram : ꞽwn"},
/* 13FE0 */ { "EGYPTIAN HIEROGLYPH-13FE0","	* phonemogram : wṯs"},
/* 13FE1 */ { "EGYPTIAN HIEROGLYPH-13FE1","	* phonemogram : ꞽwn"},
/* 13FE2 */ { "EGYPTIAN HIEROGLYPH-13FE2","	* phonemogram : ꞽwn"},
/* 13FE3 */ { "EGYPTIAN HIEROGLYPH-13FE3",NULL},
/* 13FE4 */ { "EGYPTIAN HIEROGLYPH-13FE4","	* logogram (papyriform column) : wꜣḏ"},
/* 13FE5 */ { "EGYPTIAN HIEROGLYPH-13FE5","	* classifier column (columned hall) : wḫꜣ"},
/* 13FE6 */ { "EGYPTIAN HIEROGLYPH-13FE6",NULL},
/* 13FE7 */ { "EGYPTIAN HIEROGLYPH-13FE7","	* classifier column (columned hall) : wḫꜣ"},
/* 13FE8 */ { "EGYPTIAN HIEROGLYPH-13FE8",NULL},
/* 13FE9 */ { "EGYPTIAN HIEROGLYPH-13FE9",NULL},
/* 13FEA */ { "EGYPTIAN HIEROGLYPH-13FEA","	* phonemogram : šnꜥ"},
/* 13FEB */ { "EGYPTIAN HIEROGLYPH-13FEB","	* classifier pillar : ꞽwn"},
/* 13FEC */ { "EGYPTIAN HIEROGLYPH-13FEC","	* logogram (face, sight) : ḥr"},
/* 13FED */ { "EGYPTIAN HIEROGLYPH-13FED",NULL},
/* 13FEE */ { "EGYPTIAN HIEROGLYPH-13FEE","	* classifier door bolt : ḥkn"},
/* 13FEF */ { "EGYPTIAN HIEROGLYPH-13FEF","	* classifier door bolt : kfꜣ/pḥ-ꜥḥꜥ"},
/* 13FF0 */ { "EGYPTIAN HIEROGLYPH-13FF0","	* classifier door bolt : ḳꜣn"},
/* 13FF1 */ { "EGYPTIAN HIEROGLYPH-13FF1","	* phonemogram : sn"},
/* 13FF2 */ { "EGYPTIAN HIEROGLYPH-13FF2","	* phonemogram : sbb"},
/* 13FF3 */ { "EGYPTIAN HIEROGLYPH-13FF3","	* classifier gateway : sbḫ.t"},
/* 13FF4 */ { "EGYPTIAN HIEROGLYPH-13FF4","	* classifier dais, terrace, platform : ḫt(.w)"},
/* 13FF5 */ { "EGYPTIAN HIEROGLYPH-13FF5","	* phonemogram : sšp"},
/* 13FF6 */ { "EGYPTIAN HIEROGLYPH-13FF6","	* phonemogram : šsp"},
/* 13FF7 */ { "EGYPTIAN HIEROGLYPH-13FF7","	* phonemogram : šsp"},
/* 13FF8 */ { "EGYPTIAN HIEROGLYPH-13FF8",NULL},
/* 13FF9 */ { "EGYPTIAN HIEROGLYPH-13FF9",NULL},
/* 13FFA */ { "EGYPTIAN HIEROGLYPH-13FFA","	* phonemogram : šsp"},
/* 13FFB */ { "EGYPTIAN HIEROGLYPH-13FFB","	* phonemogram : šsp"},
/* 13FFC */ { "EGYPTIAN HIEROGLYPH-13FFC",NULL},
/* 13FFD */ { "EGYPTIAN HIEROGLYPH-13FFD","	* logogram (field, arable land) : ꜣḥ.t"},
/* 13FFE */ { "EGYPTIAN HIEROGLYPH-13FFE","	* phonemogram : šsp"},
/* 13FFF */ { "EGYPTIAN HIEROGLYPH-13FFF",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_40[] = {
/* 14000 */ { "EGYPTIAN HIEROGLYPH-14000","	* classifier granary : šnw.wt"},
/* 14001 */ { "EGYPTIAN HIEROGLYPH-14001",NULL},
/* 14002 */ { "EGYPTIAN HIEROGLYPH-14002","	* logogram (granary) : šnw.t"},
/* 14003 */ { "EGYPTIAN HIEROGLYPH-14003","	* logogram (granary) : šnw.t"},
/* 14004 */ { "EGYPTIAN HIEROGLYPH-14004",NULL},
/* 14005 */ { "EGYPTIAN HIEROGLYPH-14005","	* logogram (granary) : šnw.t"},
/* 14006 */ { "EGYPTIAN HIEROGLYPH-14006","	* logogram (ornament) : ẖkr"},
/* 14007 */ { "EGYPTIAN HIEROGLYPH-14007","	* logogram (ornament) : ẖkr"},
/* 14008 */ { "EGYPTIAN HIEROGLYPH-14008","	* classifier tower : swn.w"},
/* 14009 */ { "EGYPTIAN HIEROGLYPH-14009","	* classifier to ascend, to mount up : sꞽꜥ"},
/* 1400A */ { "EGYPTIAN HIEROGLYPH-1400A","	* logogram (the emblem of the cult of Min) : ꞽꜣw.t"},
/* 1400B */ { "EGYPTIAN HIEROGLYPH-1400B","	* logogram (office, rank, function) : ꞽꜣw.t"},
/* 1400C */ { "EGYPTIAN HIEROGLYPH-1400C","	* logogram (office, rank, function) : ꞽꜣw.t"},
/* 1400D */ { "EGYPTIAN HIEROGLYPH-1400D","	* classifier harim, inner chamber : ꞽp.t"},
/* 1400E */ { "EGYPTIAN HIEROGLYPH-1400E","	* phonemogram : ꞽp.t"},
/* 1400F */ { "EGYPTIAN HIEROGLYPH-1400F","	* phonemogram : ꞽp.t"},
/* 14010 */ { "EGYPTIAN HIEROGLYPH-14010","	* phonemogram : nḫn"},
/* 14011 */ { "EGYPTIAN HIEROGLYPH-14011","	* logogram (Hierakonpolis) : nḫn"},
/* 14012 */ { "EGYPTIAN HIEROGLYPH-14012","	* logogram (Hierakonpolis) : nḫn"},
/* 14013 */ { "EGYPTIAN HIEROGLYPH-14013",NULL},
/* 14014 */ { "EGYPTIAN HIEROGLYPH-14014","	* classifier part of a building : sꜣw"},
/* 14015 */ { "EGYPTIAN HIEROGLYPH-14015",NULL},
/* 14016 */ { "EGYPTIAN HIEROGLYPH-14016",NULL},
/* 14017 */ { "EGYPTIAN HIEROGLYPH-14017","	* classifier conflagration : snsn.t"},
/* 14018 */ { "EGYPTIAN HIEROGLYPH-14018","	* logogram (fortress) : mn(n).w"},
/* 14019 */ { "EGYPTIAN HIEROGLYPH-14019","	* classifier stair"},
/* 1401A */ { "EGYPTIAN HIEROGLYPH-1401A","	* classifier movement : nmꞽ"},
/* 1401B */ { "EGYPTIAN HIEROGLYPH-1401B","	* classifier boat/ship/bark : ḥnw"},
/* 1401C */ { "EGYPTIAN HIEROGLYPH-1401C","	* logogram (ship, boat, bark) : wꞽꜣ"},
/* 1401D */ { "EGYPTIAN HIEROGLYPH-1401D","	* classifier movement : ḫns"},
/* 1401E */ { "EGYPTIAN HIEROGLYPH-1401E","	* classifier movement : ḫns"},
/* 1401F */ { "EGYPTIAN HIEROGLYPH-1401F","	* classifier movement : ḏꜣ"},
/* 14020 */ { "EGYPTIAN HIEROGLYPH-14020","	* classifier to upset, to overturn : pnꜥ"},
/* 14021 */ { "EGYPTIAN HIEROGLYPH-14021","	* classifier movement : ḫd"},
/* 14022 */ { "EGYPTIAN HIEROGLYPH-14022","	* classifier boat/ship : mẖn.t"},
/* 14023 */ { "EGYPTIAN HIEROGLYPH-14023","	* classifier movement : ẖn"},
/* 14024 */ { "EGYPTIAN HIEROGLYPH-14024","	* phonemogram : ꞽm"},
/* 14025 */ { "EGYPTIAN HIEROGLYPH-14025","	* classifier (to capsize) : ꜥḳw"},
/* 14026 */ { "EGYPTIAN HIEROGLYPH-14026","	* phonemogram : ꞽm"},
/* 14027 */ { "EGYPTIAN HIEROGLYPH-14027","	* classifier mooring : mnꞽ"},
/* 14028 */ { "EGYPTIAN HIEROGLYPH-14028","	* classifier boat/ship : ꞽm(w)"},
/* 14029 */ { "EGYPTIAN HIEROGLYPH-14029","	* classifier death : smꜣ(-tꜣ)"},
/* 1402A */ { "EGYPTIAN HIEROGLYPH-1402A",NULL},
/* 1402B */ { "EGYPTIAN HIEROGLYPH-1402B","	* logogram (ship, boat, bark) : wꞽꜣ"},
/* 1402C */ { "EGYPTIAN HIEROGLYPH-1402C",NULL},
/* 1402D */ { "EGYPTIAN HIEROGLYPH-1402D",NULL},
/* 1402E */ { "EGYPTIAN HIEROGLYPH-1402E",NULL},
/* 1402F */ { "EGYPTIAN HIEROGLYPH-1402F","	* classifier bark/boat : (m)skt.t"},
/* 14030 */ { "EGYPTIAN HIEROGLYPH-14030","	* classifier bark/boat : ꜥnḏ(.t)"},
/* 14031 */ { "EGYPTIAN HIEROGLYPH-14031","	* logogram (ship, boat, bark) : wꞽꜣ"},
/* 14032 */ { "EGYPTIAN HIEROGLYPH-14032","	* classifier bark/boat : nšm.t"},
/* 14033 */ { "EGYPTIAN HIEROGLYPH-14033","	* classifier bark/boat : (m)skt.t"},
/* 14034 */ { "EGYPTIAN HIEROGLYPH-14034","	* classifier bark/boat : (m)sk.t"},
/* 14035 */ { "EGYPTIAN HIEROGLYPH-14035","	* classifier bark/boat : mskt.t"},
/* 14036 */ { "EGYPTIAN HIEROGLYPH-14036","	* classifier bark/boat : ḥbꜣ"},
/* 14037 */ { "EGYPTIAN HIEROGLYPH-14037","	* classifier papyrus float : ḥnk"},
/* 14038 */ { "EGYPTIAN HIEROGLYPH-14038","	* classifier movement : ḫnt.yt"},
/* 14039 */ { "EGYPTIAN HIEROGLYPH-14039","	* logogram (ship, boat, bark) : wꞽꜣ"},
/* 1403A */ { "EGYPTIAN HIEROGLYPH-1403A","	* logogram (bark of the king/royal bark) : wꞽꜣ-n(.y)-sw.t"},
/* 1403B */ { "EGYPTIAN HIEROGLYPH-1403B",NULL},
/* 1403C */ { "EGYPTIAN HIEROGLYPH-1403C","	* logogram (ship, boat, bark) : wꞽꜣ"},
/* 1403D */ { "EGYPTIAN HIEROGLYPH-1403D",NULL},
/* 1403E */ { "EGYPTIAN HIEROGLYPH-1403E",NULL},
/* 1403F */ { "EGYPTIAN HIEROGLYPH-1403F","	* logogram (to go south (sailing upstream)) : ḫntꞽ"},
/* 14040 */ { "EGYPTIAN HIEROGLYPH-14040","	* classifier sailing upstream/going south : ḫnt(ꞽ)"},
/* 14041 */ { "EGYPTIAN HIEROGLYPH-14041","	* logogram (to go south (sailing upstream)) : ḫntꞽ"},
/* 14042 */ { "EGYPTIAN HIEROGLYPH-14042","	* classifier sailing upstream/going south : ḫnt(ꞽ)"},
/* 14043 */ { "EGYPTIAN HIEROGLYPH-14043","	* classifier boat/ship : sꜣṯ"},
/* 14044 */ { "EGYPTIAN HIEROGLYPH-14044","	* logogram (ship, boat, bark) : wꞽꜣ"},
/* 14045 */ { "EGYPTIAN HIEROGLYPH-14045","	* classifier bark/boat : nšm.t"},
/* 14046 */ { "EGYPTIAN HIEROGLYPH-14046","	* logogram/classifier (bark/boat) : wꞽꜣ"},
/* 14047 */ { "EGYPTIAN HIEROGLYPH-14047",NULL},
/* 14048 */ { "EGYPTIAN HIEROGLYPH-14048","	* classifier boat/ship : wṯs-nfr.w"},
/* 14049 */ { "EGYPTIAN HIEROGLYPH-14049","	* classifier boat/ship : wṯs-nfr(.w)"},
/* 1404A */ { "EGYPTIAN HIEROGLYPH-1404A",NULL},
/* 1404B */ { "EGYPTIAN HIEROGLYPH-1404B","	* classifier boat/ship : wṯs-nfr.w"},
/* 1404C */ { "EGYPTIAN HIEROGLYPH-1404C","	* classifier boat/ship : wṯs-nfr.w"},
/* 1404D */ { "EGYPTIAN HIEROGLYPH-1404D","	* logogram wiA(ship, boat, bark) : wṯs-nfr.w"},
/* 1404E */ { "EGYPTIAN HIEROGLYPH-1404E","	* logogram (ship, boat, bark) : wꞽꜣ"},
/* 1404F */ { "EGYPTIAN HIEROGLYPH-1404F","	* logogram (Amon-Re) : ꞽmn-rꜥ"},
/* 14050 */ { "EGYPTIAN HIEROGLYPH-14050","	* phonemogram : wḥꜥ"},
/* 14051 */ { "EGYPTIAN HIEROGLYPH-14051","	* logogram : wꞽꜣ"},
/* 14052 */ { "EGYPTIAN HIEROGLYPH-14052","	* classifier boat/ship : (m)ꜥnḏ.t"},
/* 14053 */ { "EGYPTIAN HIEROGLYPH-14053",NULL},
/* 14054 */ { "EGYPTIAN HIEROGLYPH-14054","	* classifier bark/boat : (m)skt.t"},
/* 14055 */ { "EGYPTIAN HIEROGLYPH-14055",NULL},
/* 14056 */ { "EGYPTIAN HIEROGLYPH-14056","	* logogram (bark of the two divine falcons) : nṯr.wy"},
/* 14057 */ { "EGYPTIAN HIEROGLYPH-14057","	* classifier bark : skt.t"},
/* 14058 */ { "EGYPTIAN HIEROGLYPH-14058","	* classifier bark : mskt.t"},
/* 14059 */ { "EGYPTIAN HIEROGLYPH-14059","	* logogram (Sothis) : spd.t"},
/* 1405A */ { "EGYPTIAN HIEROGLYPH-1405A","	* logogram (Orion (constellation)) : sꜣḥ"},
/* 1405B */ { "EGYPTIAN HIEROGLYPH-1405B",NULL},
/* 1405C */ { "EGYPTIAN HIEROGLYPH-1405C","	* classifier bark : wꞽꜣ"},
/* 1405D */ { "EGYPTIAN HIEROGLYPH-1405D",NULL},
/* 1405E */ { "EGYPTIAN HIEROGLYPH-1405E","	* logogram (protection) : gs-dp.t"},
/* 1405F */ { "EGYPTIAN HIEROGLYPH-1405F","	* logogram (protection) : gs-dp.t"},
/* 14060 */ { "EGYPTIAN HIEROGLYPH-14060",NULL},
/* 14061 */ { "EGYPTIAN HIEROGLYPH-14061","	* phonemogram : mnḫ.t"},
/* 14062 */ { "EGYPTIAN HIEROGLYPH-14062","	* logogram (cloth, clothing) : mnḫ.t"},
/* 14063 */ { "EGYPTIAN HIEROGLYPH-14063","	* logogram (cloth, clothing) : mnḫ.t"},
/* 14064 */ { "EGYPTIAN HIEROGLYPH-14064",NULL},
/* 14065 */ { "EGYPTIAN HIEROGLYPH-14065","	* logogram ḥnw (Henu-bark of Sokar) or phonemogram skr : ḥnw | skr"},
/* 14066 */ { "EGYPTIAN HIEROGLYPH-14066","	* logogram (Henu-bark of Sokar) : ḥnw"},
/* 14067 */ { "EGYPTIAN HIEROGLYPH-14067","	* logogram (Henu-bark of Sokar) : ḥnw"},
/* 14068 */ { "EGYPTIAN HIEROGLYPH-14068","	* classifier bark of Sokar : ḥny"},
/* 14069 */ { "EGYPTIAN HIEROGLYPH-14069","	* classifier bark of Sokar : ḥnw"},
/* 1406A */ { "EGYPTIAN HIEROGLYPH-1406A","	* classifier bark of Sokar : ḥnw"},
/* 1406B */ { "EGYPTIAN HIEROGLYPH-1406B","	* logogram (Henu-bark of Sokar) : ḥnw"},
/* 1406C */ { "EGYPTIAN HIEROGLYPH-1406C","	* classifier bark of Sokar : ḥnw"},
/* 1406D */ { "EGYPTIAN HIEROGLYPH-1406D","	* logogram (Henu-bark of Sokar) : ḥnw"},
/* 1406E */ { "EGYPTIAN HIEROGLYPH-1406E","	* logogram (Henu-bark of Sokar) : ḥnw"},
/* 1406F */ { "EGYPTIAN HIEROGLYPH-1406F","	* logogram (Henu-bark of Sokar) : ḥnw"},
/* 14070 */ { "EGYPTIAN HIEROGLYPH-14070","	* logogram (Sokar) : skr"},
/* 14071 */ { "EGYPTIAN HIEROGLYPH-14071","	* logogram (Sokar) : skr"},
/* 14072 */ { "EGYPTIAN HIEROGLYPH-14072",NULL},
/* 14073 */ { "EGYPTIAN HIEROGLYPH-14073","	* logogram (Henu-bark of Sokar) : ḥnw"},
/* 14074 */ { "EGYPTIAN HIEROGLYPH-14074","	* logogram (Henu-bark of Sokar) : ḥnw"},
/* 14075 */ { "EGYPTIAN HIEROGLYPH-14075","	* logogram (Sokar) : skr"},
/* 14076 */ { "EGYPTIAN HIEROGLYPH-14076","	* phonemogram : wꜣḥ"},
/* 14077 */ { "EGYPTIAN HIEROGLYPH-14077","	* phonemogram : wḥꜥ"},
/* 14078 */ { "EGYPTIAN HIEROGLYPH-14078","	* logogram (to loosen, to explain) : wḥꜥ"},
/* 14079 */ { "EGYPTIAN HIEROGLYPH-14079","	* classifier boat/ship : mnš"},
/* 1407A */ { "EGYPTIAN HIEROGLYPH-1407A","	* classifier boat/ship : mnš"},
/* 1407B */ { "EGYPTIAN HIEROGLYPH-1407B",NULL},
/* 1407C */ { "EGYPTIAN HIEROGLYPH-1407C","	* logogram (wind, breath, air) : ṯꜣw"},
/* 1407D */ { "EGYPTIAN HIEROGLYPH-1407D","	* classifier wind, breath, air : mḥy.t"},
/* 1407E */ { "EGYPTIAN HIEROGLYPH-1407E","	* logogram (wind, breath, air) : ṯꜣw"},
/* 1407F */ { "EGYPTIAN HIEROGLYPH-1407F",NULL},
/* 14080 */ { "EGYPTIAN HIEROGLYPH-14080","	* classifier wind, breath, air : mꜣꜥ"},
/* 14081 */ { "EGYPTIAN HIEROGLYPH-14081","	* logogram (wind, breath, air) : ṯꜣw"},
/* 14082 */ { "EGYPTIAN HIEROGLYPH-14082","	* classifier wind, breath, air : nfw/y"},
/* 14083 */ { "EGYPTIAN HIEROGLYPH-14083",NULL},
/* 14084 */ { "EGYPTIAN HIEROGLYPH-14084","	* classifier wind, breath, air : ꞽwn"},
/* 14085 */ { "EGYPTIAN HIEROGLYPH-14085","	* classifier wind, breath, air : nfw/y"},
/* 14086 */ { "EGYPTIAN HIEROGLYPH-14086","	* logogram (wind, breath, air) : ṯꜣw"},
/* 14087 */ { "EGYPTIAN HIEROGLYPH-14087",NULL},
/* 14088 */ { "EGYPTIAN HIEROGLYPH-14088","	* logogram (wind, breath, air) : ṯꜣw"},
/* 14089 */ { "EGYPTIAN HIEROGLYPH-14089","	* classifier wind, breath, air : mḥy.t"},
/* 1408A */ { "EGYPTIAN HIEROGLYPH-1408A","	* logogram (wind, breath, air) : ṯꜣw"},
/* 1408B */ { "EGYPTIAN HIEROGLYPH-1408B","	* phonemogram : ꜥḥꜥ"},
/* 1408C */ { "EGYPTIAN HIEROGLYPH-1408C","	* phonemogram : ꜥḥꜥ"},
/* 1408D */ { "EGYPTIAN HIEROGLYPH-1408D","	* phonemogram : ꜥḥꜥ"},
/* 1408E */ { "EGYPTIAN HIEROGLYPH-1408E",NULL},
/* 1408F */ { "EGYPTIAN HIEROGLYPH-1408F",NULL},
/* 14090 */ { "EGYPTIAN HIEROGLYPH-14090","	* logogram (snake divinity) : ꜥḥꜥ.w"},
/* 14091 */ { "EGYPTIAN HIEROGLYPH-14091",NULL},
/* 14092 */ { "EGYPTIAN HIEROGLYPH-14092",NULL},
/* 14093 */ { "EGYPTIAN HIEROGLYPH-14093","	* phonemogram : ẖn"},
/* 14094 */ { "EGYPTIAN HIEROGLYPH-14094","	* classifier (ferries/bridges) : mꜣḏw"},
/* 14095 */ { "EGYPTIAN HIEROGLYPH-14095","	* phonemogram : ḥp"},
/* 14096 */ { "EGYPTIAN HIEROGLYPH-14096",NULL},
/* 14097 */ { "EGYPTIAN HIEROGLYPH-14097","	* phonemogram : ḥp"},
/* 14098 */ { "EGYPTIAN HIEROGLYPH-14098",NULL},
/* 14099 */ { "EGYPTIAN HIEROGLYPH-14099","	* phonemogram : ꜣs.t"},
/* 1409A */ { "EGYPTIAN HIEROGLYPH-1409A","	* phonemogram : ws"},
/* 1409B */ { "EGYPTIAN HIEROGLYPH-1409B","	* phonemogram : ḥtm"},
/* 1409C */ { "EGYPTIAN HIEROGLYPH-1409C","	* classifier throne : ns.t"},
/* 1409D */ { "EGYPTIAN HIEROGLYPH-1409D",NULL},
/* 1409E */ { "EGYPTIAN HIEROGLYPH-1409E","	* classifier seat, chair, throne : ꞽsb.t"},
/* 1409F */ { "EGYPTIAN HIEROGLYPH-1409F","	* classifier seat/chair : ḫndw"},
/* 140A0 */ { "EGYPTIAN HIEROGLYPH-140A0","	* classifier carrying chair : spꜣ"},
/* 140A1 */ { "EGYPTIAN HIEROGLYPH-140A1","	* logogram (seat, throne, place) : s.t"},
/* 140A2 */ { "EGYPTIAN HIEROGLYPH-140A2",NULL},
/* 140A3 */ { "EGYPTIAN HIEROGLYPH-140A3","	* phonemogram : p"},
/* 140A4 */ { "EGYPTIAN HIEROGLYPH-140A4","	* classifier (sedan chair) : wr-ꜥ"},
/* 140A5 */ { "EGYPTIAN HIEROGLYPH-140A5","	* classifier (seat with backrest?) : pḥḏ.w"},
/* 140A6 */ { "EGYPTIAN HIEROGLYPH-140A6","	* classifier headrest : wrs"},
/* 140A7 */ { "EGYPTIAN HIEROGLYPH-140A7",NULL},
/* 140A8 */ { "EGYPTIAN HIEROGLYPH-140A8","	* classifier to rest : sḏr"},
/* 140A9 */ { "EGYPTIAN HIEROGLYPH-140A9","	* classifier inclined bed : gsꜣ.t"},
/* 140AA */ { "EGYPTIAN HIEROGLYPH-140AA","	* classifier seat/chair : ḫnd"},
/* 140AB */ { "EGYPTIAN HIEROGLYPH-140AB","	* classifier bed : ꜣṯ.t"},
/* 140AC */ { "EGYPTIAN HIEROGLYPH-140AC","	* classifier to sleep/to spend the night : sḏr"},
/* 140AD */ { "EGYPTIAN HIEROGLYPH-140AD","	* classifier bed : ḥnk(.yt)"},
/* 140AE */ { "EGYPTIAN HIEROGLYPH-140AE",NULL},
/* 140AF */ { "EGYPTIAN HIEROGLYPH-140AF","	* logogram (throne dais) : ṯnṯꜣ.t"},
/* 140B0 */ { "EGYPTIAN HIEROGLYPH-140B0","	* logogram (mirror) : wn-ḥr"},
/* 140B1 */ { "EGYPTIAN HIEROGLYPH-140B1","	* classifier mirror : mꜣw-ḥr"},
/* 140B2 */ { "EGYPTIAN HIEROGLYPH-140B2","	* classifier box : hn(w)"},
/* 140B3 */ { "EGYPTIAN HIEROGLYPH-140B3","	* logogram (requirements, needs) : dbḥ.w"},
/* 140B4 */ { "EGYPTIAN HIEROGLYPH-140B4","	* logogram (requirements, needs) : dbḥ.w"},
/* 140B5 */ { "EGYPTIAN HIEROGLYPH-140B5","	* logogram (requirements, needs) : dbḥ.w"},
/* 140B6 */ { "EGYPTIAN HIEROGLYPH-140B6","	* classifier box/chest : mr.t"},
/* 140B7 */ { "EGYPTIAN HIEROGLYPH-140B7","	* logogram (box/chest) : mr.t"},
/* 140B8 */ { "EGYPTIAN HIEROGLYPH-140B8","	* classifier offering table : ꜥbꜣ"},
/* 140B9 */ { "EGYPTIAN HIEROGLYPH-140B9","	* classifier shrine/chapel : kꜣr"},
/* 140BA */ { "EGYPTIAN HIEROGLYPH-140BA","	* classifier to raise : ṯs"},
/* 140BB */ { "EGYPTIAN HIEROGLYPH-140BB","	* classifier to bury : ḳrs"},
/* 140BC */ { "EGYPTIAN HIEROGLYPH-140BC","	* classifier burial : ḳrs.t"},
/* 140BD */ { "EGYPTIAN HIEROGLYPH-140BD","	* classifier box : hn(w)"},
/* 140BE */ { "EGYPTIAN HIEROGLYPH-140BE",NULL},
/* 140BF */ { "EGYPTIAN HIEROGLYPH-140BF","	* logogram (Crocodilopolis) : Šd.t"},
/* 140C0 */ { "EGYPTIAN HIEROGLYPH-140C0",NULL},
/* 140C1 */ { "EGYPTIAN HIEROGLYPH-140C1","	* classifier burial : ḳrs"},
/* 140C2 */ { "EGYPTIAN HIEROGLYPH-140C2","	* classifier coffin : ḳrs.w"},
/* 140C3 */ { "EGYPTIAN HIEROGLYPH-140C3","	* classifier burial : ḳrs"},
/* 140C4 */ { "EGYPTIAN HIEROGLYPH-140C4","	* logogram (to bind) : mḏḥ"},
/* 140C5 */ { "EGYPTIAN HIEROGLYPH-140C5","	* classifier burial : ḳrs"},
/* 140C6 */ { "EGYPTIAN HIEROGLYPH-140C6","	* logogram (temperature, temperament) : srf"},
/* 140C7 */ { "EGYPTIAN HIEROGLYPH-140C7","	* logogram (fire) : nsrsr"},
/* 140C8 */ { "EGYPTIAN HIEROGLYPH-140C8","	* classifier fire associated action : nbꞽ"},
/* 140C9 */ { "EGYPTIAN HIEROGLYPH-140C9",NULL},
/* 140CA */ { "EGYPTIAN HIEROGLYPH-140CA","	* classifier brazier : ꜥḫ"},
/* 140CB */ { "EGYPTIAN HIEROGLYPH-140CB","	* classifier (burning festival) : rkḥ"},
/* 140CC */ { "EGYPTIAN HIEROGLYPH-140CC","	* classifier hearthstones : kt.ꞽt"},
/* 140CD */ { "EGYPTIAN HIEROGLYPH-140CD","	* classifier hearthstones : kt.ꞽt"},
/* 140CE */ { "EGYPTIAN HIEROGLYPH-140CE","	* classifier ladder : mꜣḳ.t"},
/* 140CF */ { "EGYPTIAN HIEROGLYPH-140CF","	* classifier altar : ḫꜣ(w).t"},
/* 140D0 */ { "EGYPTIAN HIEROGLYPH-140D0","	* logogram (altar) : ḫꜣw.t"},
/* 140D1 */ { "EGYPTIAN HIEROGLYPH-140D1",NULL},
/* 140D2 */ { "EGYPTIAN HIEROGLYPH-140D2",NULL},
/* 140D3 */ { "EGYPTIAN HIEROGLYPH-140D3",NULL},
/* 140D4 */ { "EGYPTIAN HIEROGLYPH-140D4",NULL},
/* 140D5 */ { "EGYPTIAN HIEROGLYPH-140D5",NULL},
/* 140D6 */ { "EGYPTIAN HIEROGLYPH-140D6","	* classifier supplies, provisions : wꜣg"},
/* 140D7 */ { "EGYPTIAN HIEROGLYPH-140D7",NULL},
/* 140D8 */ { "EGYPTIAN HIEROGLYPH-140D8","	* classifier table : ṯ.t"},
/* 140D9 */ { "EGYPTIAN HIEROGLYPH-140D9",NULL},
/* 140DA */ { "EGYPTIAN HIEROGLYPH-140DA","	* classifier table : ṯ.t"},
/* 140DB */ { "EGYPTIAN HIEROGLYPH-140DB","	* classifier table : ṯ.t"},
/* 140DC */ { "EGYPTIAN HIEROGLYPH-140DC","	* classifier table : ṯ.t"},
/* 140DD */ { "EGYPTIAN HIEROGLYPH-140DD","	* classifier table : ṯ.t"},
/* 140DE */ { "EGYPTIAN HIEROGLYPH-140DE","	* classifier table : ṯ.t"},
/* 140DF */ { "EGYPTIAN HIEROGLYPH-140DF",NULL},
/* 140E0 */ { "EGYPTIAN HIEROGLYPH-140E0",NULL},
/* 140E1 */ { "EGYPTIAN HIEROGLYPH-140E1","	* classifier altar : wḏḥ.w"},
/* 140E2 */ { "EGYPTIAN HIEROGLYPH-140E2","	* classifier offering table : ḥtp"},
/* 140E3 */ { "EGYPTIAN HIEROGLYPH-140E3","	* classifier altar, offering table : wdḥ.w"},
/* 140E4 */ { "EGYPTIAN HIEROGLYPH-140E4","	* logogram (altar of offerings) : wdḥ.w"},
/* 140E5 */ { "EGYPTIAN HIEROGLYPH-140E5","	* logogram (jar-stand, sideboard) : ḫnt"},
/* 140E6 */ { "EGYPTIAN HIEROGLYPH-140E6","	* logogram (offerings) : ḥtp(.w)"},
/* 140E7 */ { "EGYPTIAN HIEROGLYPH-140E7","	* classifier altar : ḫꜣw(.t)"},
/* 140E8 */ { "EGYPTIAN HIEROGLYPH-140E8",NULL},
/* 140E9 */ { "EGYPTIAN HIEROGLYPH-140E9",NULL},
/* 140EA */ { "EGYPTIAN HIEROGLYPH-140EA","	* classifier altar : ḫꜣw.t"},
/* 140EB */ { "EGYPTIAN HIEROGLYPH-140EB",NULL},
/* 140EC */ { "EGYPTIAN HIEROGLYPH-140EC","	* logogram (altar) : ḫꜣw.t"},
/* 140ED */ { "EGYPTIAN HIEROGLYPH-140ED","	* logogram (altar) : ḫꜣw.t"},
/* 140EE */ { "EGYPTIAN HIEROGLYPH-140EE","	* classifier altar : ḳdf"},
/* 140EF */ { "EGYPTIAN HIEROGLYPH-140EF","	* logogram (altar) : ḫꜣw.t"},
/* 140F0 */ { "EGYPTIAN HIEROGLYPH-140F0","	* classifier altar : ḳdf"},
/* 140F1 */ { "EGYPTIAN HIEROGLYPH-140F1","	* logogram (altar) : ḫꜣw.t"},
/* 140F2 */ { "EGYPTIAN HIEROGLYPH-140F2",NULL},
/* 140F3 */ { "EGYPTIAN HIEROGLYPH-140F3","	* classifier fumigation/censing : kꜣp"},
/* 140F4 */ { "EGYPTIAN HIEROGLYPH-140F4","	* classifier incense fire : snṯr-sḏ.t"},
/* 140F5 */ { "EGYPTIAN HIEROGLYPH-140F5",NULL},
/* 140F6 */ { "EGYPTIAN HIEROGLYPH-140F6","	* phonemogram/logogram (to satisfy) : (s)ḥtp"},
/* 140F7 */ { "EGYPTIAN HIEROGLYPH-140F7",NULL},
/* 140F8 */ { "EGYPTIAN HIEROGLYPH-140F8",NULL},
/* 140F9 */ { "EGYPTIAN HIEROGLYPH-140F9","	* logogram (incense) : snṯr"},
/* 140FA */ { "EGYPTIAN HIEROGLYPH-140FA",NULL},
/* 140FB */ { "EGYPTIAN HIEROGLYPH-140FB",NULL},
/* 140FC */ { "EGYPTIAN HIEROGLYPH-140FC","	* logogram (gods) : nṯr.w"},
/* 140FD */ { "EGYPTIAN HIEROGLYPH-140FD","	* logogram (all the gods) : nṯr.w-nb.w"},
/* 140FE */ { "EGYPTIAN HIEROGLYPH-140FE","	* logogram (Ennead) : psḏ.t"},
/* 140FF */ { "EGYPTIAN HIEROGLYPH-140FF","	* logogram (god and goddess) : nṯr-nṯr.t"}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_41[] = {
/* 14100 */ { "EGYPTIAN HIEROGLYPH-14100","	* logogram (gods and goddesses) : nṯr.w-nṯr.wt"},
/* 14101 */ { "EGYPTIAN HIEROGLYPH-14101","	* logogram (gods and goddesses) : nṯr.w-nṯr.wt"},
/* 14102 */ { "EGYPTIAN HIEROGLYPH-14102","	* logogram (god and goddess) : nṯr-nṯr.t"},
/* 14103 */ { "EGYPTIAN HIEROGLYPH-14103",NULL},
/* 14104 */ { "EGYPTIAN HIEROGLYPH-14104","	* logogram (natron) : ḥsmn"},
/* 14105 */ { "EGYPTIAN HIEROGLYPH-14105","	* logogram (necropolis) : ẖr.t-nṯr"},
/* 14106 */ { "EGYPTIAN HIEROGLYPH-14106","	* logogram (necropolis) : ẖr.t-nṯr"},
/* 14107 */ { "EGYPTIAN HIEROGLYPH-14107","	* logogram (necropolis) : ẖr.t-nṯr"},
/* 14108 */ { "EGYPTIAN HIEROGLYPH-14108",NULL},
/* 14109 */ { "EGYPTIAN HIEROGLYPH-14109","	* logogram (necropolis) : ẖr.t-nṯr"},
/* 1410A */ { "EGYPTIAN HIEROGLYPH-1410A","	* logogram (necropolis) : ẖr.t-nṯr"},
/* 1410B */ { "EGYPTIAN HIEROGLYPH-1410B","	* logogram (necropolis) : ẖr.t-nṯr"},
/* 1410C */ { "EGYPTIAN HIEROGLYPH-1410C","	* logogram (necropolis) : ẖr.t-nṯr"},
/* 1410D */ { "EGYPTIAN HIEROGLYPH-1410D","	* logogram (necropolis) : ẖr.t-nṯr"},
/* 1410E */ { "EGYPTIAN HIEROGLYPH-1410E","	* logogram (necropolis) : ẖr.t-nṯr"},
/* 1410F */ { "EGYPTIAN HIEROGLYPH-1410F",NULL},
/* 14110 */ { "EGYPTIAN HIEROGLYPH-14110","	* logogram (necropolis) : ẖr.t-nṯr"},
/* 14111 */ { "EGYPTIAN HIEROGLYPH-14111","	* logogram (18th nome of Upper Egypt) : nmt.y"},
/* 14112 */ { "EGYPTIAN HIEROGLYPH-14112","	* phonemogram : ḏd-kꜣ-ꞽmn"},
/* 14113 */ { "EGYPTIAN HIEROGLYPH-14113","	* phonemogram : psḏ"},
/* 14114 */ { "EGYPTIAN HIEROGLYPH-14114","	* phonemogram : ḏd"},
/* 14115 */ { "EGYPTIAN HIEROGLYPH-14115","	* classifier standard : ꞽꜣ.t"},
/* 14116 */ { "EGYPTIAN HIEROGLYPH-14116","	* classifier pole : snw.t"},
/* 14117 */ { "EGYPTIAN HIEROGLYPH-14117","	* logogram (standard) : ꞽꜣ.t"},
/* 14118 */ { "EGYPTIAN HIEROGLYPH-14118","	* classifier standard : ꞽꜣ.t"},
/* 14119 */ { "EGYPTIAN HIEROGLYPH-14119","	* classifier mirror : ꜥnḫ"},
/* 1411A */ { "EGYPTIAN HIEROGLYPH-1411A",NULL},
/* 1411B */ { "EGYPTIAN HIEROGLYPH-1411B","	* logogram (Duau (divinity)) : dwꜣ.w"},
/* 1411C */ { "EGYPTIAN HIEROGLYPH-1411C","	* logogram spd.t (Sothis) or ẖn.ty ꞽꜣb.t (foremost of the east) : spd.t | ẖn.ty ꞽꜣb.t"},
/* 1411D */ { "EGYPTIAN HIEROGLYPH-1411D","	* logogram (Duau (divinity)) : dwꜣ.w"},
/* 1411E */ { "EGYPTIAN HIEROGLYPH-1411E","	* logogram (border, boundry) : ṯnw"},
/* 1411F */ { "EGYPTIAN HIEROGLYPH-1411F","	* logogram (west) : ꞽmn.t"},
/* 14120 */ { "EGYPTIAN HIEROGLYPH-14120","	* logogram (west) : ꞽmn.t"},
/* 14121 */ { "EGYPTIAN HIEROGLYPH-14121","	* logogram (right, right side) : wnm.y"},
/* 14122 */ { "EGYPTIAN HIEROGLYPH-14122","	* logogram (west) : ꞽmn.t"},
/* 14123 */ { "EGYPTIAN HIEROGLYPH-14123",NULL},
/* 14124 */ { "EGYPTIAN HIEROGLYPH-14124","	* logogram (west) : ꞽmn.t"},
/* 14125 */ { "EGYPTIAN HIEROGLYPH-14125",NULL},
/* 14126 */ { "EGYPTIAN HIEROGLYPH-14126","	* logogram (west) : ꞽmn.t"},
/* 14127 */ { "EGYPTIAN HIEROGLYPH-14127",NULL},
/* 14128 */ { "EGYPTIAN HIEROGLYPH-14128","	* phonemogram : ꜣb"},
/* 14129 */ { "EGYPTIAN HIEROGLYPH-14129","	* logogram (east) : ꞽꜣb.t"},
/* 1412A */ { "EGYPTIAN HIEROGLYPH-1412A","	* radicogram (left eye) : ꞽꜣb.t"},
/* 1412B */ { "EGYPTIAN HIEROGLYPH-1412B","	* logogram (east) : ꞽꜣb.t"},
/* 1412C */ { "EGYPTIAN HIEROGLYPH-1412C","	* logogram (east) : ꞽꜣb.t"},
/* 1412D */ { "EGYPTIAN HIEROGLYPH-1412D","	* logogram (east) : ꞽꜣb.t"},
/* 1412E */ { "EGYPTIAN HIEROGLYPH-1412E",NULL},
/* 1412F */ { "EGYPTIAN HIEROGLYPH-1412F","	* logogram (east) : ꞽꜣb.t"},
/* 14130 */ { "EGYPTIAN HIEROGLYPH-14130",NULL},
/* 14131 */ { "EGYPTIAN HIEROGLYPH-14131","	* phonemogram : ꞽꜣb"},
/* 14132 */ { "EGYPTIAN HIEROGLYPH-14132","	* radicogram (left eye) : ꞽꜣb.t"},
/* 14133 */ { "EGYPTIAN HIEROGLYPH-14133",NULL},
/* 14134 */ { "EGYPTIAN HIEROGLYPH-14134",NULL},
/* 14135 */ { "EGYPTIAN HIEROGLYPH-14135",NULL},
/* 14136 */ { "EGYPTIAN HIEROGLYPH-14136","	* logogram (8th nome of Upper Egypt) : tꜣ-wr"},
/* 14137 */ { "EGYPTIAN HIEROGLYPH-14137","	* logogram (8th nome of Upper Egypt) : tꜣ-wr"},
/* 14138 */ { "EGYPTIAN HIEROGLYPH-14138","	* logogram (Abydos) : ꜣbḏw"},
/* 14139 */ { "EGYPTIAN HIEROGLYPH-14139",NULL},
/* 1413A */ { "EGYPTIAN HIEROGLYPH-1413A","	* logogram (Abydos) : ꜣbḏw"},
/* 1413B */ { "EGYPTIAN HIEROGLYPH-1413B","	* logogram (Abydos) : ꜣbḏw"},
/* 1413C */ { "EGYPTIAN HIEROGLYPH-1413C","	* logogram (Abydos) : ꜣbḏw"},
/* 1413D */ { "EGYPTIAN HIEROGLYPH-1413D",NULL},
/* 1413E */ { "EGYPTIAN HIEROGLYPH-1413E","	* phonemogram : nfr"},
/* 1413F */ { "EGYPTIAN HIEROGLYPH-1413F","	* logogram (Nefertem) : nfr-tm"},
/* 14140 */ { "EGYPTIAN HIEROGLYPH-14140","	* logogram (Nefertem) : nfr-tm"},
/* 14141 */ { "EGYPTIAN HIEROGLYPH-14141","	* logogram (Thebes) : wꜣs.t"},
/* 14142 */ { "EGYPTIAN HIEROGLYPH-14142","	* logogram (Thebes) : wꜣs.t"},
/* 14143 */ { "EGYPTIAN HIEROGLYPH-14143",NULL},
/* 14144 */ { "EGYPTIAN HIEROGLYPH-14144","	* logogram (Seshat (divinity)) : sšꜣ.t"},
/* 14145 */ { "EGYPTIAN HIEROGLYPH-14145","	* logogram (Letopolis) : ḫm"},
/* 14146 */ { "EGYPTIAN HIEROGLYPH-14146",NULL},
/* 14147 */ { "EGYPTIAN HIEROGLYPH-14147","	* logogram (Min (divinity)) : mnw"},
/* 14148 */ { "EGYPTIAN HIEROGLYPH-14148","	* classifier document holder : mks"},
/* 14149 */ { "EGYPTIAN HIEROGLYPH-14149","	* logogram/Classifier (the one of Shedet (i.e., Sobek)) : šd.ty"},
/* 1414A */ { "EGYPTIAN HIEROGLYPH-1414A",NULL},
/* 1414B */ { "EGYPTIAN HIEROGLYPH-1414B",NULL},
/* 1414C */ { "EGYPTIAN HIEROGLYPH-1414C","	* classifier (base, pedestal, plinth (of a shrine)) : ḏbꜣ.t"},
/* 1414D */ { "EGYPTIAN HIEROGLYPH-1414D","	* classifier crown : ḥḏ.t"},
/* 1414E */ { "EGYPTIAN HIEROGLYPH-1414E","	* logogram (the white crown) : ḥḏ.t"},
/* 1414F */ { "EGYPTIAN HIEROGLYPH-1414F","	* logogram (wearer of the sash (priest)) : ꜥrḳ-ꞽns"},
/* 14150 */ { "EGYPTIAN HIEROGLYPH-14150","	* logogram (the white crown) : wrr.t"},
/* 14151 */ { "EGYPTIAN HIEROGLYPH-14151","	* logogram (Tatenen (divinity)) : tꜣ-ṯnn"},
/* 14152 */ { "EGYPTIAN HIEROGLYPH-14152","	* logogram (Baby (divinity)) : bꜣby"},
/* 14153 */ { "EGYPTIAN HIEROGLYPH-14153","	* logogram (Upper Egypt) : šmꜥ.w"},
/* 14154 */ { "EGYPTIAN HIEROGLYPH-14154","	* classifier crown : wrr.t"},
/* 14155 */ { "EGYPTIAN HIEROGLYPH-14155","	* classifier crown : wrr.t"},
/* 14156 */ { "EGYPTIAN HIEROGLYPH-14156","	* logogram (to be divine) : nṯrꞽ"},
/* 14157 */ { "EGYPTIAN HIEROGLYPH-14157","	* logogram (Lower Egypt) : mḥ.w"},
/* 14158 */ { "EGYPTIAN HIEROGLYPH-14158","	* classifier crown : dšr.t/n.t"},
/* 14159 */ { "EGYPTIAN HIEROGLYPH-14159","	* phonemogram : wnn"},
/* 1415A */ { "EGYPTIAN HIEROGLYPH-1415A","	* classifier the red crown : dšr.t"},
/* 1415B */ { "EGYPTIAN HIEROGLYPH-1415B","	* classifier double crown : sḫm.ty"},
/* 1415C */ { "EGYPTIAN HIEROGLYPH-1415C","	* logogram (cap, crown) : mḏꜣ.t"},
/* 1415D */ { "EGYPTIAN HIEROGLYPH-1415D","	* logogram/phonemogram (carpenter) : mḏḥw"},
/* 1415E */ { "EGYPTIAN HIEROGLYPH-1415E","	* phonemogram : k"},
/* 1415F */ { "EGYPTIAN HIEROGLYPH-1415F","	* phonemogram : k"},
/* 14160 */ { "EGYPTIAN HIEROGLYPH-14160","	* classifier headcloth : ꜥfn(.t)"},
/* 14161 */ { "EGYPTIAN HIEROGLYPH-14161","	* classifier headcloth : ꞽbs"},
/* 14162 */ { "EGYPTIAN HIEROGLYPH-14162","	* classifier headcloth : ꜥfn.t"},
/* 14163 */ { "EGYPTIAN HIEROGLYPH-14163",NULL},
/* 14164 */ { "EGYPTIAN HIEROGLYPH-14164","	* logogram (to bind, to wind around) : mḏḥ"},
/* 14165 */ { "EGYPTIAN HIEROGLYPH-14165","	* logogram (to bind, to wind around) : mḏḥ"},
/* 14166 */ { "EGYPTIAN HIEROGLYPH-14166","	* classifier crown : ḫꜥ.w"},
/* 14167 */ { "EGYPTIAN HIEROGLYPH-14167",NULL},
/* 14168 */ { "EGYPTIAN HIEROGLYPH-14168","	* logogram (Atef crown) : ꜣtf"},
/* 14169 */ { "EGYPTIAN HIEROGLYPH-14169","	* logogram (Atef crown) : ꜣtf"},
/* 1416A */ { "EGYPTIAN HIEROGLYPH-1416A",NULL},
/* 1416B */ { "EGYPTIAN HIEROGLYPH-1416B","	* logogram (Hemhem crown) : hmhm"},
/* 1416C */ { "EGYPTIAN HIEROGLYPH-1416C","	* logogram (Hemhem crown) : hmhm"},
/* 1416D */ { "EGYPTIAN HIEROGLYPH-1416D","	* logogram (Hemhem crown) : hmhm"},
/* 1416E */ { "EGYPTIAN HIEROGLYPH-1416E","	* logogram (double plumes/two feather crown) : šw.ty"},
/* 1416F */ { "EGYPTIAN HIEROGLYPH-1416F","	* logogram (double plumes/two feather crown) : šw.ty"},
/* 14170 */ { "EGYPTIAN HIEROGLYPH-14170","	* logogram (double plumes/two feather crown) : šw.ty"},
/* 14171 */ { "EGYPTIAN HIEROGLYPH-14171",NULL},
/* 14172 */ { "EGYPTIAN HIEROGLYPH-14172",NULL},
/* 14173 */ { "EGYPTIAN HIEROGLYPH-14173","	* logogram (the four feather crown) : ?"},
/* 14174 */ { "EGYPTIAN HIEROGLYPH-14174","	* logogram (double plumes/two feather crown) : šw.ty"},
/* 14175 */ { "EGYPTIAN HIEROGLYPH-14175","	* logogram (double plumes/two feather crown) : šw.ty"},
/* 14176 */ { "EGYPTIAN HIEROGLYPH-14176","	* logogram (double plumes/two feather crown) : šw.ty"},
/* 14177 */ { "EGYPTIAN HIEROGLYPH-14177","	* logogram (double plumes/two feather crown) : šw.ty"},
/* 14178 */ { "EGYPTIAN HIEROGLYPH-14178","	* phonemogram : ṯn"},
/* 14179 */ { "EGYPTIAN HIEROGLYPH-14179","	* logogram (Elkab) : Nḫb"},
/* 1417A */ { "EGYPTIAN HIEROGLYPH-1417A","	* phonemogram : ṯn"},
/* 1417B */ { "EGYPTIAN HIEROGLYPH-1417B","	* classifier crown : ḥp.t"},
/* 1417C */ { "EGYPTIAN HIEROGLYPH-1417C","	* phonemogram : ṯn"},
/* 1417D */ { "EGYPTIAN HIEROGLYPH-1417D","	* logogram (3rd nome of Upper Egypt) : nḫn"},
/* 1417E */ { "EGYPTIAN HIEROGLYPH-1417E","	* classifier two halves : p(s)š.ty"},
/* 1417F */ { "EGYPTIAN HIEROGLYPH-1417F","	* phonemogram : ṯn"},
/* 14180 */ { "EGYPTIAN HIEROGLYPH-14180","	* logogram (the horizon) : ꜣḫ.t"},
/* 14181 */ { "EGYPTIAN HIEROGLYPH-14181","	* logogram (who goes forth from the horizon) : pr-m-ꜣḫ.t"},
/* 14182 */ { "EGYPTIAN HIEROGLYPH-14182","	* logogram (wreath, garland) : mꜣḥ"},
/* 14183 */ { "EGYPTIAN HIEROGLYPH-14183","	* logogram (wreath, garland) : mꜣḥ"},
/* 14184 */ { "EGYPTIAN HIEROGLYPH-14184","	* logogram (wreath, garland) : mꜣḥ"},
/* 14185 */ { "EGYPTIAN HIEROGLYPH-14185","	* logogram (wreath, garland) : mꜣḥ"},
/* 14186 */ { "EGYPTIAN HIEROGLYPH-14186","	* logogram (wreath, garland) : mꜣḥ"},
/* 14187 */ { "EGYPTIAN HIEROGLYPH-14187","	* classifier collar : wsḫ"},
/* 14188 */ { "EGYPTIAN HIEROGLYPH-14188",NULL},
/* 14189 */ { "EGYPTIAN HIEROGLYPH-14189","	* classifier collar : bb"},
/* 1418A */ { "EGYPTIAN HIEROGLYPH-1418A","	* classifier collar : bb.t"},
/* 1418B */ { "EGYPTIAN HIEROGLYPH-1418B","	* classifier collar : bb"},
/* 1418C */ { "EGYPTIAN HIEROGLYPH-1418C","	* logogram collar : bb"},
/* 1418D */ { "EGYPTIAN HIEROGLYPH-1418D","	* classifier collar : bb"},
/* 1418E */ { "EGYPTIAN HIEROGLYPH-1418E","	* classifier collar : bb"},
/* 1418F */ { "EGYPTIAN HIEROGLYPH-1418F",NULL},
/* 14190 */ { "EGYPTIAN HIEROGLYPH-14190","	* logogram (necklace, collar) : wsḫ"},
/* 14191 */ { "EGYPTIAN HIEROGLYPH-14191","	* logogram (necklace, collar) : wsḫ"},
/* 14192 */ { "EGYPTIAN HIEROGLYPH-14192","	* classifier vessel (twin vases for myrrh) : rrm"},
/* 14193 */ { "EGYPTIAN HIEROGLYPH-14193",NULL},
/* 14194 */ { "EGYPTIAN HIEROGLYPH-14194","	* classifier wreath, garland : m(ꜣ)ḥ"},
/* 14195 */ { "EGYPTIAN HIEROGLYPH-14195","	* logogram (necklace) : nb"},
/* 14196 */ { "EGYPTIAN HIEROGLYPH-14196","	* logogram (to be bright) : ṯḥn"},
/* 14197 */ { "EGYPTIAN HIEROGLYPH-14197","	* logogram (to be bright) or Classifier dew/scent/rain : ṯḥn | ꞽꜣd.t"},
/* 14198 */ { "EGYPTIAN HIEROGLYPH-14198",NULL},
/* 14199 */ { "EGYPTIAN HIEROGLYPH-14199","	* logogram (brightness) : ṯḥn"},
/* 1419A */ { "EGYPTIAN HIEROGLYPH-1419A","	* logogram (to be bright) : ṯḥn"},
/* 1419B */ { "EGYPTIAN HIEROGLYPH-1419B",NULL},
/* 1419C */ { "EGYPTIAN HIEROGLYPH-1419C","	* logogram (to be bright) : ṯḥn"},
/* 1419D */ { "EGYPTIAN HIEROGLYPH-1419D","	* logogram (faience) : ṯḥn.t"},
/* 1419E */ { "EGYPTIAN HIEROGLYPH-1419E","	* classifier place/divinity : šsm.t"},
/* 1419F */ { "EGYPTIAN HIEROGLYPH-1419F","	* logogram (menit necklace) : mnꞽ.t"},
/* 141A0 */ { "EGYPTIAN HIEROGLYPH-141A0",NULL},
/* 141A1 */ { "EGYPTIAN HIEROGLYPH-141A1","	* logogram (menit necklace) : mnꞽ.t"},
/* 141A2 */ { "EGYPTIAN HIEROGLYPH-141A2","	* classifier necklace : mnꞽ.t"},
/* 141A3 */ { "EGYPTIAN HIEROGLYPH-141A3",NULL},
/* 141A4 */ { "EGYPTIAN HIEROGLYPH-141A4","	* classifier pectoral : ꜣw(.t)-ꞽb"},
/* 141A5 */ { "EGYPTIAN HIEROGLYPH-141A5","	* classifier amulet : wḏꜣ(.w)"},
/* 141A6 */ { "EGYPTIAN HIEROGLYPH-141A6","	* classifier amulet : wḏꜣ.(w)"},
/* 141A7 */ { "EGYPTIAN HIEROGLYPH-141A7","	* classifier amulet (Logogram in line 3)? : wḏꜣ.w"},
/* 141A8 */ { "EGYPTIAN HIEROGLYPH-141A8","	* phonemogram : ḫtm"},
/* 141A9 */ { "EGYPTIAN HIEROGLYPH-141A9","	* phonemogram : sꜥḥ"},
/* 141AA */ { "EGYPTIAN HIEROGLYPH-141AA","	* phonemogram : st"},
/* 141AB */ { "EGYPTIAN HIEROGLYPH-141AB","	* phonemogram : st"},
/* 141AC */ { "EGYPTIAN HIEROGLYPH-141AC","	* classifier cloth/garment : nfr.t"},
/* 141AD */ { "EGYPTIAN HIEROGLYPH-141AD","	* classifier bracelet, anklet : mnf(r).ty"},
/* 141AE */ { "EGYPTIAN HIEROGLYPH-141AE",NULL},
/* 141AF */ { "EGYPTIAN HIEROGLYPH-141AF","	* logogram (kilt, royal apron) : šnḏ.wt"},
/* 141B0 */ { "EGYPTIAN HIEROGLYPH-141B0","	* classifier garment : nṯstn"},
/* 141B1 */ { "EGYPTIAN HIEROGLYPH-141B1","	* logogram (clothing) : mnḫ.t"},
/* 141B2 */ { "EGYPTIAN HIEROGLYPH-141B2","	* classifier cloth : šsr.w"},
/* 141B3 */ { "EGYPTIAN HIEROGLYPH-141B3","	* logogram (clothing) : mnḫ.t"},
/* 141B4 */ { "EGYPTIAN HIEROGLYPH-141B4","	* logogram (clothing) : mnḫ.t"},
/* 141B5 */ { "EGYPTIAN HIEROGLYPH-141B5","	* classifier cloth : šsr.w"},
/* 141B6 */ { "EGYPTIAN HIEROGLYPH-141B6","	* logogram (six-weave linen) : sꞽs"},
/* 141B7 */ { "EGYPTIAN HIEROGLYPH-141B7","	* logogram (linen) : sšr"},
/* 141B8 */ { "EGYPTIAN HIEROGLYPH-141B8","	* phonemogram : dr"},
/* 141B9 */ { "EGYPTIAN HIEROGLYPH-141B9","	* classifier clothing : ḥbs"},
/* 141BA */ { "EGYPTIAN HIEROGLYPH-141BA","	* phonemogram : sšm"},
/* 141BB */ { "EGYPTIAN HIEROGLYPH-141BB",NULL},
/* 141BC */ { "EGYPTIAN HIEROGLYPH-141BC",NULL},
/* 141BD */ { "EGYPTIAN HIEROGLYPH-141BD","	* phonemogram : sšm"},
/* 141BE */ { "EGYPTIAN HIEROGLYPH-141BE","	* phonemogram : sšm"},
/* 141BF */ { "EGYPTIAN HIEROGLYPH-141BF","	* phonemogram : s"},
/* 141C0 */ { "EGYPTIAN HIEROGLYPH-141C0","	* phonemogram : s"},
/* 141C1 */ { "EGYPTIAN HIEROGLYPH-141C1","	* phonemogram : sꞽꜣ"},
/* 141C2 */ { "EGYPTIAN HIEROGLYPH-141C2","	* classifier cloth : sšr"},
/* 141C3 */ { "EGYPTIAN HIEROGLYPH-141C3","	* classifier cloth : npnp.t"},
/* 141C4 */ { "EGYPTIAN HIEROGLYPH-141C4",NULL},
/* 141C5 */ { "EGYPTIAN HIEROGLYPH-141C5","	* classifier time : nḥḥ"},
/* 141C6 */ { "EGYPTIAN HIEROGLYPH-141C6","	* classifier ankh vessel : ꜥnḫ"},
/* 141C7 */ { "EGYPTIAN HIEROGLYPH-141C7","	* logogram (stability and life) : ḏd-ꜥnḫ"},
/* 141C8 */ { "EGYPTIAN HIEROGLYPH-141C8","	* logogram (all life, stability and dominion) : ꜥnḫ-ḏd-wꜣs-nb"},
/* 141C9 */ { "EGYPTIAN HIEROGLYPH-141C9","	* logogram (all life and dominion) : ꜥnḫ-wꜣs-nb"},
/* 141CA */ { "EGYPTIAN HIEROGLYPH-141CA",NULL},
/* 141CB */ { "EGYPTIAN HIEROGLYPH-141CB","	* phonemogram : ḥb"},
/* 141CC */ { "EGYPTIAN HIEROGLYPH-141CC","	* logogram (shadow, shade) : šw.t"},
/* 141CD */ { "EGYPTIAN HIEROGLYPH-141CD","	* phono-repeater/classifier (in ḥp.ty (extreme limits)) : ḥp"},
/* 141CE */ { "EGYPTIAN HIEROGLYPH-141CE","	* phonemogram : ḥb"},
/* 141CF */ { "EGYPTIAN HIEROGLYPH-141CF","	* phonemogram : ḫw"},
/* 141D0 */ { "EGYPTIAN HIEROGLYPH-141D0","	* phonemogram : ḫw"},
/* 141D1 */ { "EGYPTIAN HIEROGLYPH-141D1",NULL},
/* 141D2 */ { "EGYPTIAN HIEROGLYPH-141D2","	* logogram (fan) : ḫw"},
/* 141D3 */ { "EGYPTIAN HIEROGLYPH-141D3",NULL},
/* 141D4 */ { "EGYPTIAN HIEROGLYPH-141D4","	* logogram (Igai (divinity)) : ꞽgꜣꞽ"},
/* 141D5 */ { "EGYPTIAN HIEROGLYPH-141D5","	* phonemogram/Logogram (iatet drink) : ꞽꜣ.t(yt)"},
/* 141D6 */ { "EGYPTIAN HIEROGLYPH-141D6","	* phonemogram/Logogram (iatet drink) : ꞽꜣ.t(yt)"},
/* 141D7 */ { "EGYPTIAN HIEROGLYPH-141D7","	* logogram (Iat (divinity) : ꞽꜣ.t"},
/* 141D8 */ { "EGYPTIAN HIEROGLYPH-141D8","	* logogram (district, region) : w"},
/* 141D9 */ { "EGYPTIAN HIEROGLYPH-141D9",NULL},
/* 141DA */ { "EGYPTIAN HIEROGLYPH-141DA","	* phonemogram : ꜣms"},
/* 141DB */ { "EGYPTIAN HIEROGLYPH-141DB","	* phonemogram : md(w)"},
/* 141DC */ { "EGYPTIAN HIEROGLYPH-141DC","	* phonemogram : md(w)"},
/* 141DD */ { "EGYPTIAN HIEROGLYPH-141DD","	* classifier sceptre : nḥb.t"},
/* 141DE */ { "EGYPTIAN HIEROGLYPH-141DE","	* logogram (Hetes-staff, baton) : ḥts"},
/* 141DF */ { "EGYPTIAN HIEROGLYPH-141DF","	* logogram (ames-sceptre) : ꜣms"},
/* 141E0 */ { "EGYPTIAN HIEROGLYPH-141E0","	* classifier staff, sceptre : ꜣms"},
/* 141E1 */ { "EGYPTIAN HIEROGLYPH-141E1","	* classifier clothing : nṯstn"},
/* 141E2 */ { "EGYPTIAN HIEROGLYPH-141E2","	* phonemogram : smꜣ"},
/* 141E3 */ { "EGYPTIAN HIEROGLYPH-141E3","	* phonemogram : ḫb"},
/* 141E4 */ { "EGYPTIAN HIEROGLYPH-141E4","	* phonemogram : ḫb"},
/* 141E5 */ { "EGYPTIAN HIEROGLYPH-141E5","	* logogram (to judge, to separate) : wḏꜥ"},
/* 141E6 */ { "EGYPTIAN HIEROGLYPH-141E6","	* logogram (to judge, to separate) : wḏꜥ"},
/* 141E7 */ { "EGYPTIAN HIEROGLYPH-141E7","	* logogram (to judge, to separate) : wḏꜥ"},
/* 141E8 */ { "EGYPTIAN HIEROGLYPH-141E8","	* logogram (to judge, to separate) : wḏꜥ"},
/* 141E9 */ { "EGYPTIAN HIEROGLYPH-141E9","	* phonemogram : ꜥpr"},
/* 141EA */ { "EGYPTIAN HIEROGLYPH-141EA","	* phonemogram : ꜥpr"},
/* 141EB */ { "EGYPTIAN HIEROGLYPH-141EB","	* logogram (counterweight) : mꜥnḫ.t"},
/* 141EC */ { "EGYPTIAN HIEROGLYPH-141EC","	* phonemogram : ꜥpr"},
/* 141ED */ { "EGYPTIAN HIEROGLYPH-141ED","	* classifier to spit, to expel : nšꞽ/nẖꞽ"},
/* 141EE */ { "EGYPTIAN HIEROGLYPH-141EE","	* phonemogram : ꜥpr"},
/* 141EF */ { "EGYPTIAN HIEROGLYPH-141EF",NULL},
/* 141F0 */ { "EGYPTIAN HIEROGLYPH-141F0","	* phonemogram : ꜥpr"},
/* 141F1 */ { "EGYPTIAN HIEROGLYPH-141F1","	* classifier (curl) : ḥmꜣṯṯ"},
/* 141F2 */ { "EGYPTIAN HIEROGLYPH-141F2","	* classifier (bracelet) : msktw"},
/* 141F3 */ { "EGYPTIAN HIEROGLYPH-141F3","	* classifier cloth/garment : mḥ"},
/* 141F4 */ { "EGYPTIAN HIEROGLYPH-141F4","	* classifier cloth : wnḫ.wy"},
/* 141F5 */ { "EGYPTIAN HIEROGLYPH-141F5","	* classifier dignity, rank : sꜥḥ"},
/* 141F6 */ { "EGYPTIAN HIEROGLYPH-141F6","	* logogram (abode, birth place, birthing brick) : msḫn.t"},
/* 141F7 */ { "EGYPTIAN HIEROGLYPH-141F7","	* logogram (mace) : ḥḏ"},
/* 141F8 */ { "EGYPTIAN HIEROGLYPH-141F8",NULL},
/* 141F9 */ { "EGYPTIAN HIEROGLYPH-141F9",NULL},
/* 141FA */ { "EGYPTIAN HIEROGLYPH-141FA",NULL},
/* 141FB */ { "EGYPTIAN HIEROGLYPH-141FB","	* phonemogram : wḏ"},
/* 141FC */ { "EGYPTIAN HIEROGLYPH-141FC","	* phonemogram : wḏ"},
/* 141FD */ { "EGYPTIAN HIEROGLYPH-141FD","	* phonemogram : wḏ"},
/* 141FE */ { "EGYPTIAN HIEROGLYPH-141FE","	* phonemogram/logogram (white crown) : ḥḏ.t"},
/* 141FF */ { "EGYPTIAN HIEROGLYPH-141FF","	* logogram (silver) : ḥḏ"}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_42[] = {
/* 14200 */ { "EGYPTIAN HIEROGLYPH-14200","	* phonemogram (in (tꜣ)-ṯnn (divinity)) : ṯnn"},
/* 14201 */ { "EGYPTIAN HIEROGLYPH-14201","	* classifier shield : ꞽkm"},
/* 14202 */ { "EGYPTIAN HIEROGLYPH-14202","	* classifier shield : ꞽkm"},
/* 14203 */ { "EGYPTIAN HIEROGLYPH-14203","	* logogram (shield) : ꞽkm"},
/* 14204 */ { "EGYPTIAN HIEROGLYPH-14204","	* logogram (carpenter, shipwright) : mḏḥ.w"},
/* 14205 */ { "EGYPTIAN HIEROGLYPH-14205","	* classifier (strainer, colander) : ẖnm.t-wr.t"},
/* 14206 */ { "EGYPTIAN HIEROGLYPH-14206","	* logogram (metal) : bꞽꜣ"},
/* 14207 */ { "EGYPTIAN HIEROGLYPH-14207","	* phonemogram : mn"},
/* 14208 */ { "EGYPTIAN HIEROGLYPH-14208","	* phonemogram : pḏ"},
/* 14209 */ { "EGYPTIAN HIEROGLYPH-14209","	* logogram/phonemogram (to stretch out) : pḏ"},
/* 1420A */ { "EGYPTIAN HIEROGLYPH-1420A","	* classifier beyond, outside : m-rwt"},
/* 1420B */ { "EGYPTIAN HIEROGLYPH-1420B","	* phonemogram/logogram : wpš"},
/* 1420C */ { "EGYPTIAN HIEROGLYPH-1420C","	* classifier (arrow) : šsr"},
/* 1420D */ { "EGYPTIAN HIEROGLYPH-1420D","	* phonemogram : swn"},
/* 1420E */ { "EGYPTIAN HIEROGLYPH-1420E","	* logogram (Syene (Aswan)) : Swn.w"},
/* 1420F */ { "EGYPTIAN HIEROGLYPH-1420F","	* phono-repeater : swn"},
/* 14210 */ { "EGYPTIAN HIEROGLYPH-14210","	* phonemogram : sṯ/st"},
/* 14211 */ { "EGYPTIAN HIEROGLYPH-14211","	* phonemogram : sṯ/st"},
/* 14212 */ { "EGYPTIAN HIEROGLYPH-14212",NULL},
/* 14213 */ { "EGYPTIAN HIEROGLYPH-14213","	* logogram (Neith) : n.t"},
/* 14214 */ { "EGYPTIAN HIEROGLYPH-14214","	* logogram (Neith, 4th and 5th nomes of Lower Egypt) : n.t"},
/* 14215 */ { "EGYPTIAN HIEROGLYPH-14215","	* logogram (Neith, 4th and 5th nomes of Lower Egypt) : n.t"},
/* 14216 */ { "EGYPTIAN HIEROGLYPH-14216","	* logogram (Neith, 4th and 5th nomes of Lower Egypt) : n.t"},
/* 14217 */ { "EGYPTIAN HIEROGLYPH-14217","	* logogram (Neith, 4th and 5th nomes of Lower Egypt) : n.t"},
/* 14218 */ { "EGYPTIAN HIEROGLYPH-14218","	* logogram (Neith-North, 5th nome of Lower Egypt) : n.t-mḥ.yt"},
/* 14219 */ { "EGYPTIAN HIEROGLYPH-14219","	* logogram (Neith-South, 4th nome of Lower Egypt) : n.t-rs.yt"},
/* 1421A */ { "EGYPTIAN HIEROGLYPH-1421A",NULL},
/* 1421B */ { "EGYPTIAN HIEROGLYPH-1421B","	* logogram (Neith-South, 4th nome of Lower Egypt) : n.t-rs.yt"},
/* 1421C */ { "EGYPTIAN HIEROGLYPH-1421C","	* logogram (Neith-South, 4th nome of Lower Egypt) : n.t-rs.yt"},
/* 1421D */ { "EGYPTIAN HIEROGLYPH-1421D","	* phonemogram : ḥms.t"},
/* 1421E */ { "EGYPTIAN HIEROGLYPH-1421E",NULL},
/* 1421F */ { "EGYPTIAN HIEROGLYPH-1421F","	* classifier feminine life force : ḥms.t"},
/* 14220 */ { "EGYPTIAN HIEROGLYPH-14220","	* phonemogram : sꜣ"},
/* 14221 */ { "EGYPTIAN HIEROGLYPH-14221","	* logogram (back) : sꜣ"},
/* 14222 */ { "EGYPTIAN HIEROGLYPH-14222","	* phonemogram : sꜣ"},
/* 14223 */ { "EGYPTIAN HIEROGLYPH-14223","	* phonemogram : s"},
/* 14224 */ { "EGYPTIAN HIEROGLYPH-14224","	* phonemogram : dmꜣ"},
/* 14225 */ { "EGYPTIAN HIEROGLYPH-14225","	* phonemogram/logogram (mother) : tmꜣ(.t)"},
/* 14226 */ { "EGYPTIAN HIEROGLYPH-14226","	* phonemogram : rwḏ"},
/* 14227 */ { "EGYPTIAN HIEROGLYPH-14227","	* phonemogram : rwḏ"},
/* 14228 */ { "EGYPTIAN HIEROGLYPH-14228","	* phono-repeater : rd"},
/* 14229 */ { "EGYPTIAN HIEROGLYPH-14229","	* phonemogram : rs"},
/* 1422A */ { "EGYPTIAN HIEROGLYPH-1422A","	* phono-repeater : rs"},
/* 1422B */ { "EGYPTIAN HIEROGLYPH-1422B","	* phonemogram/logogram (strife) : šnt.t"},
/* 1422C */ { "EGYPTIAN HIEROGLYPH-1422C",NULL},
/* 1422D */ { "EGYPTIAN HIEROGLYPH-1422D","	* logogram/phonemogram (Meter canal) : Mtr"},
/* 1422E */ { "EGYPTIAN HIEROGLYPH-1422E","	* phonemogram : rs-wḏꜣ"},
/* 1422F */ { "EGYPTIAN HIEROGLYPH-1422F","	* logogram (to be strong, brave, capable) : ḳnꞽ"},
/* 14230 */ { "EGYPTIAN HIEROGLYPH-14230","	* logogram (valour, strength) : ḳn.t"},
/* 14231 */ { "EGYPTIAN HIEROGLYPH-14231","	* logogram (khopesh sword/scimitar) : ḫpš"},
/* 14232 */ { "EGYPTIAN HIEROGLYPH-14232","	* classifier to be strong, brave, capable : ḳn"},
/* 14233 */ { "EGYPTIAN HIEROGLYPH-14233","	* logogram (khopesh sword/scimitar) : ḫpš"},
/* 14234 */ { "EGYPTIAN HIEROGLYPH-14234","	* logogram (to be strong, brave, capable) : ḳnꞽ"},
/* 14235 */ { "EGYPTIAN HIEROGLYPH-14235","	* logogram (to follow) : šms"},
/* 14236 */ { "EGYPTIAN HIEROGLYPH-14236","	* logogram (follower, retainer) : šms.w"},
/* 14237 */ { "EGYPTIAN HIEROGLYPH-14237","	* logogram (to follow) : šms"},
/* 14238 */ { "EGYPTIAN HIEROGLYPH-14238","	* classifier stalk, reed"},
/* 14239 */ { "EGYPTIAN HIEROGLYPH-14239",NULL},
/* 1423A */ { "EGYPTIAN HIEROGLYPH-1423A","	* phono-repeater : twr"},
/* 1423B */ { "EGYPTIAN HIEROGLYPH-1423B","	* phonemogram : tr"},
/* 1423C */ { "EGYPTIAN HIEROGLYPH-1423C","	* phono-repeater : twr"},
/* 1423D */ { "EGYPTIAN HIEROGLYPH-1423D","	* phonemogram : msn"},
/* 1423E */ { "EGYPTIAN HIEROGLYPH-1423E","	* phonemogram : tr"},
/* 1423F */ { "EGYPTIAN HIEROGLYPH-1423F","	* phonemogram : ḳs"},
/* 14240 */ { "EGYPTIAN HIEROGLYPH-14240","	* phonemogram : tr"},
/* 14241 */ { "EGYPTIAN HIEROGLYPH-14241","	* logogram (one, sole) : wꜥ"},
/* 14242 */ { "EGYPTIAN HIEROGLYPH-14242","	* logogram (one, sole) : wꜥ.t"},
/* 14243 */ { "EGYPTIAN HIEROGLYPH-14243","	* logogram (one, sole) : wꜥ"},
/* 14244 */ { "EGYPTIAN HIEROGLYPH-14244",NULL},
/* 14245 */ { "EGYPTIAN HIEROGLYPH-14245","	* logogram (one, sole) : wꜥ"},
/* 14246 */ { "EGYPTIAN HIEROGLYPH-14246","	* logogram (one, sole) : wꜥ"},
/* 14247 */ { "EGYPTIAN HIEROGLYPH-14247","	* logogram (one, sole) : wꜥ"},
/* 14248 */ { "EGYPTIAN HIEROGLYPH-14248","	* logogram (one, sole) : wꜥ"},
/* 14249 */ { "EGYPTIAN HIEROGLYPH-14249","	* classifier lance, spear : nꞽw.y"},
/* 1424A */ { "EGYPTIAN HIEROGLYPH-1424A","	* phonemogram : sn"},
/* 1424B */ { "EGYPTIAN HIEROGLYPH-1424B","	* phonemogram : sn"},
/* 1424C */ { "EGYPTIAN HIEROGLYPH-1424C","	* phonemogram : sn"},
/* 1424D */ { "EGYPTIAN HIEROGLYPH-1424D","	* phonemogram : šn"},
/* 1424E */ { "EGYPTIAN HIEROGLYPH-1424E",NULL},
/* 1424F */ { "EGYPTIAN HIEROGLYPH-1424F",NULL},
/* 14250 */ { "EGYPTIAN HIEROGLYPH-14250","	* logogram (7th and 8th nomes of Lower Egypt) : wꜥ-m-ḥww"},
/* 14251 */ { "EGYPTIAN HIEROGLYPH-14251","	* logogram (7th and 8th nomes of Lower Egypt) : wꜥ-m-ḥww"},
/* 14252 */ { "EGYPTIAN HIEROGLYPH-14252",NULL},
/* 14253 */ { "EGYPTIAN HIEROGLYPH-14253","	* logogram (7th nome of Lower Egypt) : wꜥ-m-ḥww-ꞽmn.ty"},
/* 14254 */ { "EGYPTIAN HIEROGLYPH-14254",NULL},
/* 14255 */ { "EGYPTIAN HIEROGLYPH-14255",NULL},
/* 14256 */ { "EGYPTIAN HIEROGLYPH-14256","	* logogram (7th nome of Lower Egypt) : wꜥ-m-ḥww-ꞽmn.ty"},
/* 14257 */ { "EGYPTIAN HIEROGLYPH-14257",NULL},
/* 14258 */ { "EGYPTIAN HIEROGLYPH-14258",NULL},
/* 14259 */ { "EGYPTIAN HIEROGLYPH-14259","	* phonemogram : ꞽh"},
/* 1425A */ { "EGYPTIAN HIEROGLYPH-1425A","	* logogram (net) : ꜥḥ"},
/* 1425B */ { "EGYPTIAN HIEROGLYPH-1425B","	* classifier catching, netting : ꞽḥ"},
/* 1425C */ { "EGYPTIAN HIEROGLYPH-1425C","	* classifier catching, netting : ꞽḥ"},
/* 1425D */ { "EGYPTIAN HIEROGLYPH-1425D","	* logogram (net) : ꜥḥ/ꞽḥ"},
/* 1425E */ { "EGYPTIAN HIEROGLYPH-1425E","	* classifier net : ꞽḥ.y"},
/* 1425F */ { "EGYPTIAN HIEROGLYPH-1425F","	* classifier catching, netting : ꞽḥ.t"},
/* 14260 */ { "EGYPTIAN HIEROGLYPH-14260","	* classifier fish-trap : ḥꜥd"},
/* 14261 */ { "EGYPTIAN HIEROGLYPH-14261","	* phonemogram : ḏbꜣ"},
/* 14262 */ { "EGYPTIAN HIEROGLYPH-14262","	* phonemogram : ḏbꜣ"},
/* 14263 */ { "EGYPTIAN HIEROGLYPH-14263","	* phonemogram : ḏbꜣ"},
/* 14264 */ { "EGYPTIAN HIEROGLYPH-14264",NULL},
/* 14265 */ { "EGYPTIAN HIEROGLYPH-14265","	* phonemogram : ḏbꜣ"},
/* 14266 */ { "EGYPTIAN HIEROGLYPH-14266",NULL},
/* 14267 */ { "EGYPTIAN HIEROGLYPH-14267",NULL},
/* 14268 */ { "EGYPTIAN HIEROGLYPH-14268","	* phonemogram : sḫt"},
/* 14269 */ { "EGYPTIAN HIEROGLYPH-14269","	* phonemogram : sḫt"},
/* 1426A */ { "EGYPTIAN HIEROGLYPH-1426A","	* phonemogram : sḫt"},
/* 1426B */ { "EGYPTIAN HIEROGLYPH-1426B","	* logogram (to weave, to trap) : sḫt"},
/* 1426C */ { "EGYPTIAN HIEROGLYPH-1426C","	* phono-repeater : sḫt"},
/* 1426D */ { "EGYPTIAN HIEROGLYPH-1426D","	* phonemogram : sḫt"},
/* 1426E */ { "EGYPTIAN HIEROGLYPH-1426E","	* classifier catching, netting : sḫt"},
/* 1426F */ { "EGYPTIAN HIEROGLYPH-1426F","	* classifier shelter : kꜣp"},
/* 14270 */ { "EGYPTIAN HIEROGLYPH-14270","	* classifier net : ꞽꜣd.t"},
/* 14271 */ { "EGYPTIAN HIEROGLYPH-14271","	* classifier net : (ꞽ)ꜣd(.t)"},
/* 14272 */ { "EGYPTIAN HIEROGLYPH-14272","	* logogram (net) : ꞽꜣd.t"},
/* 14273 */ { "EGYPTIAN HIEROGLYPH-14273","	* classifier fish-trap : sḳ.t"},
/* 14274 */ { "EGYPTIAN HIEROGLYPH-14274","	* classifier cutting, slaughter : mds\n"
	"	~ 14274 FE01 rotated 180 degrees\n"
	"	~ 14274 FE02 rotated 270 degrees\n"
	"	~ 14274 FE05 rotated approximately 250 degrees [vertical]\n"
	"	~ 14274 FE06 rotated approximately 340 degrees [horizontal]"},
/* 14275 */ { "EGYPTIAN HIEROGLYPH-14275","	* logogram (flint, in ds-km, obsidian) : ds"},
/* 14276 */ { "EGYPTIAN HIEROGLYPH-14276","	* logogram (to carve, to enscribe, to engrave) : ḫtꞽ"},
/* 14277 */ { "EGYPTIAN HIEROGLYPH-14277","	* logogram (to carve, to enscribe, to engrave) : ḫtꞽ"},
/* 14278 */ { "EGYPTIAN HIEROGLYPH-14278","	* logogram (to carve, to enscribe, to engrave) : ḫtꞽ"},
/* 14279 */ { "EGYPTIAN HIEROGLYPH-14279",NULL},
/* 1427A */ { "EGYPTIAN HIEROGLYPH-1427A","	* classifier place of execution : ḫb.t"},
/* 1427B */ { "EGYPTIAN HIEROGLYPH-1427B","	* logogram (place of execution) : ḫb.t"},
/* 1427C */ { "EGYPTIAN HIEROGLYPH-1427C","	* logogram (place of slaughter) : nm.t"},
/* 1427D */ { "EGYPTIAN HIEROGLYPH-1427D","	* logogram (butchery, slaughter) : šꜥt"},
/* 1427E */ { "EGYPTIAN HIEROGLYPH-1427E","	* logogram (butchery, slaughter) : šꜥt"},
/* 1427F */ { "EGYPTIAN HIEROGLYPH-1427F","	* logogram (place of execution) : nm.t/ḫb.t"},
/* 14280 */ { "EGYPTIAN HIEROGLYPH-14280","	* logogram (to carve, to enscribe, to engrave) : ḫtꞽ"},
/* 14281 */ { "EGYPTIAN HIEROGLYPH-14281",NULL},
/* 14282 */ { "EGYPTIAN HIEROGLYPH-14282","	* classifier stench : sṯ"},
/* 14283 */ { "EGYPTIAN HIEROGLYPH-14283","	* logogram (place of slaughter) : nm.t"},
/* 14284 */ { "EGYPTIAN HIEROGLYPH-14284",NULL},
/* 14285 */ { "EGYPTIAN HIEROGLYPH-14285","	* phonemogram : ds"},
/* 14286 */ { "EGYPTIAN HIEROGLYPH-14286",NULL},
/* 14287 */ { "EGYPTIAN HIEROGLYPH-14287","	* phonemogram : sšm"},
/* 14288 */ { "EGYPTIAN HIEROGLYPH-14288",NULL},
/* 14289 */ { "EGYPTIAN HIEROGLYPH-14289","	* classifier to spread (in psš-kf (a type of flint knife)) : psš"},
/* 1428A */ { "EGYPTIAN HIEROGLYPH-1428A","	* classifier to cause to breathe : srḳ.t"},
/* 1428B */ { "EGYPTIAN HIEROGLYPH-1428B","	* classifier points (of a harpoon) : bwn"},
/* 1428C */ { "EGYPTIAN HIEROGLYPH-1428C","	* classifier hooks : snꜥḥ.t"},
/* 1428D */ { "EGYPTIAN HIEROGLYPH-1428D","	* classifier circumcision : sb"},
/* 1428E */ { "EGYPTIAN HIEROGLYPH-1428E",NULL},
/* 1428F */ { "EGYPTIAN HIEROGLYPH-1428F","	* phonemogram : mꜣ"},
/* 14290 */ { "EGYPTIAN HIEROGLYPH-14290","	* classifier hacking : ḫbss"},
/* 14291 */ { "EGYPTIAN HIEROGLYPH-14291","	* classifier hacking : ḫbss"},
/* 14292 */ { "EGYPTIAN HIEROGLYPH-14292","	* logogram (to hack the land) : ḫbs-tꜣ"},
/* 14293 */ { "EGYPTIAN HIEROGLYPH-14293","	* classifier hacking : ḫbss"},
/* 14294 */ { "EGYPTIAN HIEROGLYPH-14294","	* phonemogram : mr"},
/* 14295 */ { "EGYPTIAN HIEROGLYPH-14295",NULL},
/* 14296 */ { "EGYPTIAN HIEROGLYPH-14296","	* classifier harvest, crop : šm(.w)"},
/* 14297 */ { "EGYPTIAN HIEROGLYPH-14297","	* classifier grain/barley : npt"},
/* 14298 */ { "EGYPTIAN HIEROGLYPH-14298","	* classifier grain : mh.w"},
/* 14299 */ { "EGYPTIAN HIEROGLYPH-14299","	* classifier grain : mh.w | šmꜥ.w | wꜣḥ.yt"},
/* 1429A */ { "EGYPTIAN HIEROGLYPH-1429A","	* classifier grain : np(r)"},
/* 1429B */ { "EGYPTIAN HIEROGLYPH-1429B",NULL},
/* 1429C */ { "EGYPTIAN HIEROGLYPH-1429C","	* phonemogram : hb"},
/* 1429D */ { "EGYPTIAN HIEROGLYPH-1429D","	* phono-repeater : hb"},
/* 1429E */ { "EGYPTIAN HIEROGLYPH-1429E",NULL},
/* 1429F */ { "EGYPTIAN HIEROGLYPH-1429F","	* phono-repeater : hb"},
/* 142A0 */ { "EGYPTIAN HIEROGLYPH-142A0",NULL},
/* 142A1 */ { "EGYPTIAN HIEROGLYPH-142A1","	* logogram (fruit) : pr.t"},
/* 142A2 */ { "EGYPTIAN HIEROGLYPH-142A2","	* logogram (fruit) : pr.t"},
/* 142A3 */ { "EGYPTIAN HIEROGLYPH-142A3","	* phonemogram : tm"},
/* 142A4 */ { "EGYPTIAN HIEROGLYPH-142A4","	* phonemogram : tm"},
/* 142A5 */ { "EGYPTIAN HIEROGLYPH-142A5",NULL},
/* 142A6 */ { "EGYPTIAN HIEROGLYPH-142A6","	* phonemogram : bꞽꜣ"},
/* 142A7 */ { "EGYPTIAN HIEROGLYPH-142A7","	* classifier burial : ḳrs.t"},
/* 142A8 */ { "EGYPTIAN HIEROGLYPH-142A8","	* logogram (Re-Atoum) : rꜥ-ꞽtm.w"},
/* 142A9 */ { "EGYPTIAN HIEROGLYPH-142A9","	* logogram (to found, to establish, to hunt, to lay (a trap)) : grg"},
/* 142AA */ { "EGYPTIAN HIEROGLYPH-142AA","	* logogram (to found, to establish, to hunt, to lay (a trap)) : grg"},
/* 142AB */ { "EGYPTIAN HIEROGLYPH-142AB","	* classifier claw, nail : ꜥn.t"},
/* 142AC */ { "EGYPTIAN HIEROGLYPH-142AC","	* phonemogram : nw"},
/* 142AD */ { "EGYPTIAN HIEROGLYPH-142AD","	* logogram (nail) : ꜥn.t"},
/* 142AE */ { "EGYPTIAN HIEROGLYPH-142AE","	* phonemogram : stp"},
/* 142AF */ { "EGYPTIAN HIEROGLYPH-142AF","	* classifier claw, nail : ꜥn.t"},
/* 142B0 */ { "EGYPTIAN HIEROGLYPH-142B0","	* phonemogram : stp"},
/* 142B1 */ { "EGYPTIAN HIEROGLYPH-142B1","	* phonemogram : mnḫ"},
/* 142B2 */ { "EGYPTIAN HIEROGLYPH-142B2","	* phonemogram : mnḫ"},
/* 142B3 */ { "EGYPTIAN HIEROGLYPH-142B3","	* phonemogram : wbꜣ"},
/* 142B4 */ { "EGYPTIAN HIEROGLYPH-142B4","	* classifier chisel : ḥr.y-ṯꜣ.y-mḏꜣ.t"},
/* 142B5 */ { "EGYPTIAN HIEROGLYPH-142B5","	* phonemogram : w"},
/* 142B6 */ { "EGYPTIAN HIEROGLYPH-142B6",NULL},
/* 142B7 */ { "EGYPTIAN HIEROGLYPH-142B7","	* phonemogram : ꜣb"},
/* 142B8 */ { "EGYPTIAN HIEROGLYPH-142B8","	* phonemogram : ꜣb"},
/* 142B9 */ { "EGYPTIAN HIEROGLYPH-142B9","	* phonemogram : ꜣb"},
/* 142BA */ { "EGYPTIAN HIEROGLYPH-142BA","	* phonemogram : mr"},
/* 142BB */ { "EGYPTIAN HIEROGLYPH-142BB","	* classifier drilling : htꞽ"},
/* 142BC */ { "EGYPTIAN HIEROGLYPH-142BC","	* phonemogram : wb"},
/* 142BD */ { "EGYPTIAN HIEROGLYPH-142BD","	* phonemogram : wb"},
/* 142BE */ { "EGYPTIAN HIEROGLYPH-142BE","	* logogram (to open) : wbꜣ"},
/* 142BF */ { "EGYPTIAN HIEROGLYPH-142BF","	* phonemogram : wb(n)"},
/* 142C0 */ { "EGYPTIAN HIEROGLYPH-142C0",NULL},
/* 142C1 */ { "EGYPTIAN HIEROGLYPH-142C1","	* logogram (to open) : wbꜣ"},
/* 142C2 */ { "EGYPTIAN HIEROGLYPH-142C2","	* phonemogram : wḏ"},
/* 142C3 */ { "EGYPTIAN HIEROGLYPH-142C3",NULL},
/* 142C4 */ { "EGYPTIAN HIEROGLYPH-142C4","	* phonemogram : wbꜣ"},
/* 142C5 */ { "EGYPTIAN HIEROGLYPH-142C5","	* logogram (craftsman) : ḥmw.w"},
/* 142C6 */ { "EGYPTIAN HIEROGLYPH-142C6","	* phonemogram : wb"},
/* 142C7 */ { "EGYPTIAN HIEROGLYPH-142C7","	* logogram (to open) : wbꜣ"},
/* 142C8 */ { "EGYPTIAN HIEROGLYPH-142C8","	* phonemogram : wb"},
/* 142C9 */ { "EGYPTIAN HIEROGLYPH-142C9","	* logogram (craftsman) : ḥmw.w"},
/* 142CA */ { "EGYPTIAN HIEROGLYPH-142CA","	* logogram (to open) : wbꜣ"},
/* 142CB */ { "EGYPTIAN HIEROGLYPH-142CB","	* logogram (craftsman) : ḥmw.w"},
/* 142CC */ { "EGYPTIAN HIEROGLYPH-142CC",NULL},
/* 142CD */ { "EGYPTIAN HIEROGLYPH-142CD","	* logogram (skilled) : ḥmw.w"},
/* 142CE */ { "EGYPTIAN HIEROGLYPH-142CE","	* logogram (craft) : ḥmw.t"},
/* 142CF */ { "EGYPTIAN HIEROGLYPH-142CF",NULL},
/* 142D0 */ { "EGYPTIAN HIEROGLYPH-142D0","	* logogram (craftsman) : ḥmw.w"},
/* 142D1 */ { "EGYPTIAN HIEROGLYPH-142D1","	* logogram (to open) : wbꜣ"},
/* 142D2 */ { "EGYPTIAN HIEROGLYPH-142D2",NULL},
/* 142D3 */ { "EGYPTIAN HIEROGLYPH-142D3","	* logogram (craftsman) : ḥmw.w"},
/* 142D4 */ { "EGYPTIAN HIEROGLYPH-142D4","	* logogram (to open) : wbꜣ"},
/* 142D5 */ { "EGYPTIAN HIEROGLYPH-142D5","	* logogram (to open) : wbꜣ"},
/* 142D6 */ { "EGYPTIAN HIEROGLYPH-142D6","	* logogram (to open) : wbꜣ"},
/* 142D7 */ { "EGYPTIAN HIEROGLYPH-142D7","	* phonemogram : wb"},
/* 142D8 */ { "EGYPTIAN HIEROGLYPH-142D8","	* phonemogram : tꜣ"},
/* 142D9 */ { "EGYPTIAN HIEROGLYPH-142D9","	* phonemogram : tꜣ"},
/* 142DA */ { "EGYPTIAN HIEROGLYPH-142DA","	* phonemogram : mn"},
/* 142DB */ { "EGYPTIAN HIEROGLYPH-142DB","	* phono-repeater : smn"},
/* 142DC */ { "EGYPTIAN HIEROGLYPH-142DC","	* phonemogram : smn"},
/* 142DD */ { "EGYPTIAN HIEROGLYPH-142DD","	* phonemogram : t(ꞽ)"},
/* 142DE */ { "EGYPTIAN HIEROGLYPH-142DE","	* phonemogram : ḫsf"},
/* 142DF */ { "EGYPTIAN HIEROGLYPH-142DF","	* classifier shaving : ẖꜥḳ"},
/* 142E0 */ { "EGYPTIAN HIEROGLYPH-142E0","	* logogram (to shave) : ẖꜥḳ"},
/* 142E1 */ { "EGYPTIAN HIEROGLYPH-142E1",NULL},
/* 142E2 */ { "EGYPTIAN HIEROGLYPH-142E2","	* classifier balance, scale : mḫꜣ.t"},
/* 142E3 */ { "EGYPTIAN HIEROGLYPH-142E3","	* logogram (balance (in mḫꜣ.t-tꜣ.wy)) : mḫꜣ.t"},
/* 142E4 */ { "EGYPTIAN HIEROGLYPH-142E4","	* classifier balance, scale : mḫꜣ.t"},
/* 142E5 */ { "EGYPTIAN HIEROGLYPH-142E5","	* logogram (to lift, to raise) : ṯsꞽ"},
/* 142E6 */ { "EGYPTIAN HIEROGLYPH-142E6",NULL},
/* 142E7 */ { "EGYPTIAN HIEROGLYPH-142E7",NULL},
/* 142E8 */ { "EGYPTIAN HIEROGLYPH-142E8","	* classifier lifting, carrying : wṯs"},
/* 142E9 */ { "EGYPTIAN HIEROGLYPH-142E9","	* logogram (to lift, to carry) : wṯs"},
/* 142EA */ { "EGYPTIAN HIEROGLYPH-142EA","	* logogram (to lift, to carry) : wṯs"},
/* 142EB */ { "EGYPTIAN HIEROGLYPH-142EB","	* logogram (to lift, to carry) : wṯs"},
/* 142EC */ { "EGYPTIAN HIEROGLYPH-142EC","	* classifier lifting, carrying : ṯs"},
/* 142ED */ { "EGYPTIAN HIEROGLYPH-142ED",NULL},
/* 142EE */ { "EGYPTIAN HIEROGLYPH-142EE","	* classifier to raise, to lift up : sṯsꞽ"},
/* 142EF */ { "EGYPTIAN HIEROGLYPH-142EF","	* classifier measuring tool? : ḫꜥ.y"},
/* 142F0 */ { "EGYPTIAN HIEROGLYPH-142F0","	* classifier lifting, carrying : wṯs"},
/* 142F1 */ { "EGYPTIAN HIEROGLYPH-142F1","	* classifier lifting, carrying : ṯs"},
/* 142F2 */ { "EGYPTIAN HIEROGLYPH-142F2","	* phonemogram (ꞽn wṯs-ḥr) : wṯs"},
/* 142F3 */ { "EGYPTIAN HIEROGLYPH-142F3","	* classifier service, task : wnw.t"},
/* 142F4 */ { "EGYPTIAN HIEROGLYPH-142F4","	* logogram (service, task) : wnw.t"},
/* 142F5 */ { "EGYPTIAN HIEROGLYPH-142F5",NULL},
/* 142F6 */ { "EGYPTIAN HIEROGLYPH-142F6","	* logogram (service, task) : wnw.t"},
/* 142F7 */ { "EGYPTIAN HIEROGLYPH-142F7","	* classifier astronomical instrument : mrḫ.t"},
/* 142F8 */ { "EGYPTIAN HIEROGLYPH-142F8","	* logogram (service, task) : wnw.t"},
/* 142F9 */ { "EGYPTIAN HIEROGLYPH-142F9","	* classifier length, width : sḫḫ"},
/* 142FA */ { "EGYPTIAN HIEROGLYPH-142FA","	* phonemogram : sḫḫ"},
/* 142FB */ { "EGYPTIAN HIEROGLYPH-142FB","	* classifier to shape, to create : nḥp"},
/* 142FC */ { "EGYPTIAN HIEROGLYPH-142FC","	* logogram (life) : ꜥnḫ"},
/* 142FD */ { "EGYPTIAN HIEROGLYPH-142FD","	* classifier potter's wheel : nḥp"},
/* 142FE */ { "EGYPTIAN HIEROGLYPH-142FE","	* classifier potter : ḳd.w"},
/* 142FF */ { "EGYPTIAN HIEROGLYPH-142FF","	* logogram (potter's wheel) : nḥp"}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_43[] = {
/* 14300 */ { "EGYPTIAN HIEROGLYPH-14300","	* classifier potter's wheel : nḥb"},
/* 14301 */ { "EGYPTIAN HIEROGLYPH-14301",NULL},
/* 14302 */ { "EGYPTIAN HIEROGLYPH-14302",NULL},
/* 14303 */ { "EGYPTIAN HIEROGLYPH-14303","	* logogram (Chesemu (divinity)) : šsmw"},
/* 14304 */ { "EGYPTIAN HIEROGLYPH-14304","	* logogram (Chesemu (divinity)) : šsmw"},
/* 14305 */ { "EGYPTIAN HIEROGLYPH-14305",NULL},
/* 14306 */ { "EGYPTIAN HIEROGLYPH-14306","	* logogram (Chesemu (divinity)) : šsmw"},
/* 14307 */ { "EGYPTIAN HIEROGLYPH-14307","	* logogram (Chesemu (divinity)) : šsmw"},
/* 14308 */ { "EGYPTIAN HIEROGLYPH-14308","	* logogram (Chesemu (divinity)) : šsmw"},
/* 14309 */ { "EGYPTIAN HIEROGLYPH-14309",NULL},
/* 1430A */ { "EGYPTIAN HIEROGLYPH-1430A",NULL},
/* 1430B */ { "EGYPTIAN HIEROGLYPH-1430B","	* logogram (Chesemu (divinity)) : šsmw"},
/* 1430C */ { "EGYPTIAN HIEROGLYPH-1430C",NULL},
/* 1430D */ { "EGYPTIAN HIEROGLYPH-1430D",NULL},
/* 1430E */ { "EGYPTIAN HIEROGLYPH-1430E",NULL},
/* 1430F */ { "EGYPTIAN HIEROGLYPH-1430F","	* logogram (to press, to cling (to)) : mḏd"},
/* 14310 */ { "EGYPTIAN HIEROGLYPH-14310","	* classifier pressing, hitting : mḏd"},
/* 14311 */ { "EGYPTIAN HIEROGLYPH-14311",NULL},
/* 14312 */ { "EGYPTIAN HIEROGLYPH-14312","	* phonemogram : sš"},
/* 14313 */ { "EGYPTIAN HIEROGLYPH-14313","	* classifier gold dust : nḳr"},
/* 14314 */ { "EGYPTIAN HIEROGLYPH-14314","	* classifier cage : štb"},
/* 14315 */ { "EGYPTIAN HIEROGLYPH-14315","	* classifier cauldron : ḏsf.w"},
/* 14316 */ { "EGYPTIAN HIEROGLYPH-14316",NULL},
/* 14317 */ { "EGYPTIAN HIEROGLYPH-14317","	* phonemogram : nd"},
/* 14318 */ { "EGYPTIAN HIEROGLYPH-14318","	* phonemogram : nḏ"},
/* 14319 */ { "EGYPTIAN HIEROGLYPH-14319","	* classifier flame"},
/* 1431A */ { "EGYPTIAN HIEROGLYPH-1431A","	* classifier sweeping, wiping : sk"},
/* 1431B */ { "EGYPTIAN HIEROGLYPH-1431B","	* classifier saw : tfꜣ"},
/* 1431C */ { "EGYPTIAN HIEROGLYPH-1431C","	* classifier (upright of a ladder) : mꜥꜣꜥ"},
/* 1431D */ { "EGYPTIAN HIEROGLYPH-1431D","	* phonemogram : ḳd"},
/* 1431E */ { "EGYPTIAN HIEROGLYPH-1431E",NULL},
/* 1431F */ { "EGYPTIAN HIEROGLYPH-1431F","	* logogram (field, arable land) : ꜣḥ.t"},
/* 14320 */ { "EGYPTIAN HIEROGLYPH-14320","	* phono-repeater sṯꜣ and classifier movement sṯꜣ& : sṯꜣ & sṯꜣ"},
/* 14321 */ { "EGYPTIAN HIEROGLYPH-14321","	* phono-repeater : šn"},
/* 14322 */ { "EGYPTIAN HIEROGLYPH-14322","	* classifier clothing : ḥbs"},
/* 14323 */ { "EGYPTIAN HIEROGLYPH-14323","	* phonemogram : šn"},
/* 14324 */ { "EGYPTIAN HIEROGLYPH-14324","	* logogram (cult image?) : dmꞽ/ḫꜣdb"},
/* 14325 */ { "EGYPTIAN HIEROGLYPH-14325","	* logogram (name) : rn"},
/* 14326 */ { "EGYPTIAN HIEROGLYPH-14326",NULL},
/* 14327 */ { "EGYPTIAN HIEROGLYPH-14327","	* logogram (float? (part of the hunting equipment for hunting hippos)) : bb"},
/* 14328 */ { "EGYPTIAN HIEROGLYPH-14328",NULL},
/* 14329 */ { "EGYPTIAN HIEROGLYPH-14329","	* phonemogram : dn"},
/* 1432A */ { "EGYPTIAN HIEROGLYPH-1432A","	* phonemogram : sꜣ"},
/* 1432B */ { "EGYPTIAN HIEROGLYPH-1432B","	* phonemogram : sꜣ"},
/* 1432C */ { "EGYPTIAN HIEROGLYPH-1432C","	* phonemogram : sꜣ"},
/* 1432D */ { "EGYPTIAN HIEROGLYPH-1432D","	* logogram (protection) : sꜣ"},
/* 1432E */ { "EGYPTIAN HIEROGLYPH-1432E","	* logogram (protection) : sꜣ"},
/* 1432F */ { "EGYPTIAN HIEROGLYPH-1432F","	* phonemogram : mḏ"},
/* 14330 */ { "EGYPTIAN HIEROGLYPH-14330",NULL},
/* 14331 */ { "EGYPTIAN HIEROGLYPH-14331","	* logogram (19th nome of Upper Egypt) : brbr"},
/* 14332 */ { "EGYPTIAN HIEROGLYPH-14332","	* logogram (19th nome of Upper Egypt) : brbr"},
/* 14333 */ { "EGYPTIAN HIEROGLYPH-14333","	* phonemogram : mḥ"},
/* 14334 */ { "EGYPTIAN HIEROGLYPH-14334","	* phonemogram : mḥ"},
/* 14335 */ { "EGYPTIAN HIEROGLYPH-14335",NULL},
/* 14336 */ { "EGYPTIAN HIEROGLYPH-14336","	* phonemogram : ꜥḏ"},
/* 14337 */ { "EGYPTIAN HIEROGLYPH-14337","	* interpretant : ḥ"},
/* 14338 */ { "EGYPTIAN HIEROGLYPH-14338","	* interpretant : ḥ"},
/* 14339 */ { "EGYPTIAN HIEROGLYPH-14339","	* interpretant : ḥ"},
/* 1433A */ { "EGYPTIAN HIEROGLYPH-1433A",NULL},
/* 1433B */ { "EGYPTIAN HIEROGLYPH-1433B","	* phonemogram : sk"},
/* 1433C */ { "EGYPTIAN HIEROGLYPH-1433C","	* classifier to dispel, to drive away : ḫsr"},
/* 1433D */ { "EGYPTIAN HIEROGLYPH-1433D","	* logogram (to strike, to drive) : ḥwꞽ"},
/* 1433E */ { "EGYPTIAN HIEROGLYPH-1433E","	* phonemogram : wꜣḥ"},
/* 1433F */ { "EGYPTIAN HIEROGLYPH-1433F","	* phonemogram : wꜣḥ"},
/* 14340 */ { "EGYPTIAN HIEROGLYPH-14340","	* phonemogram : wꜣḥ"},
/* 14341 */ { "EGYPTIAN HIEROGLYPH-14341","	* phonemogram : wꜣḥ"},
/* 14342 */ { "EGYPTIAN HIEROGLYPH-14342","	* classifier (wick) : ḥꜥ.t"},
/* 14343 */ { "EGYPTIAN HIEROGLYPH-14343","	* phonemogram : k"},
/* 14344 */ { "EGYPTIAN HIEROGLYPH-14344","	* phonemogram : gꜣ"},
/* 14345 */ { "EGYPTIAN HIEROGLYPH-14345","	* phonemogram : sḫr(.w)"},
/* 14346 */ { "EGYPTIAN HIEROGLYPH-14346","	* classifier (offering) : dbḥ.t-ḥtp"},
/* 14347 */ { "EGYPTIAN HIEROGLYPH-14347",NULL},
/* 14348 */ { "EGYPTIAN HIEROGLYPH-14348","	* phonemogram : msn"},
/* 14349 */ { "EGYPTIAN HIEROGLYPH-14349","	* phonemogram : gꜣw"},
/* 1434A */ { "EGYPTIAN HIEROGLYPH-1434A","	* phonemogram : ḥn"},
/* 1434B */ { "EGYPTIAN HIEROGLYPH-1434B","	* phono-repeater : ḥn"},
/* 1434C */ { "EGYPTIAN HIEROGLYPH-1434C","	* phonemogram : ḥn"},
/* 1434D */ { "EGYPTIAN HIEROGLYPH-1434D","	* phonemogram : ḥn"},
/* 1434E */ { "EGYPTIAN HIEROGLYPH-1434E","	* phonemogram : ḥn"},
/* 1434F */ { "EGYPTIAN HIEROGLYPH-1434F","	* phonemogram : ḥn"},
/* 14350 */ { "EGYPTIAN HIEROGLYPH-14350","	* phono-repeater : ḥn"},
/* 14351 */ { "EGYPTIAN HIEROGLYPH-14351",NULL},
/* 14352 */ { "EGYPTIAN HIEROGLYPH-14352","	* phonemogram : sṯꞽ"},
/* 14353 */ { "EGYPTIAN HIEROGLYPH-14353","	* phonemogram : ḫnm"},
/* 14354 */ { "EGYPTIAN HIEROGLYPH-14354","	* phonemogram : ḥm"},
/* 14355 */ { "EGYPTIAN HIEROGLYPH-14355","	* logogram/phonemogram (womb) : kꜣ.t"},
/* 14356 */ { "EGYPTIAN HIEROGLYPH-14356","	* phonemogram : šd"},
/* 14357 */ { "EGYPTIAN HIEROGLYPH-14357","	* logogram (net) : ꞽḥ/ꜥḥ"},
/* 14358 */ { "EGYPTIAN HIEROGLYPH-14358","	* logogram (net) : ꞽꜣd.t"},
/* 14359 */ { "EGYPTIAN HIEROGLYPH-14359","	* classifier oil, unguent : ḥkn(w)"},
/* 1435A */ { "EGYPTIAN HIEROGLYPH-1435A","	* phonemogram : bꜣs"},
/* 1435B */ { "EGYPTIAN HIEROGLYPH-1435B","	* phonemogram : bꜣs"},
/* 1435C */ { "EGYPTIAN HIEROGLYPH-1435C","	* classifier oil, unguent : ꞽbr"},
/* 1435D */ { "EGYPTIAN HIEROGLYPH-1435D","	* classifier oil, unguent : mḏ.t"},
/* 1435E */ { "EGYPTIAN HIEROGLYPH-1435E","	* classifier liquid, fluid : (ꞽ)ḫ.t bnꞽ(.t)"},
/* 1435F */ { "EGYPTIAN HIEROGLYPH-1435F","	* classifier oil, unguent : sgn"},
/* 14360 */ { "EGYPTIAN HIEROGLYPH-14360","	* classifier oil, unguent : ḥꜣ.t(y)t"},
/* 14361 */ { "EGYPTIAN HIEROGLYPH-14361","	* classifier/logogram oil, unguent : mr(ḥ.t)"},
/* 14362 */ { "EGYPTIAN HIEROGLYPH-14362","	* logogram/Phonemogram (oil, unguent) : mḏ.t(y)"},
/* 14363 */ { "EGYPTIAN HIEROGLYPH-14363","	* logogram (lord) : nb"},
/* 14364 */ { "EGYPTIAN HIEROGLYPH-14364","	* logogram (lector priest) : ẖr.y-ḥ(ꜣ)b.t"},
/* 14365 */ { "EGYPTIAN HIEROGLYPH-14365",NULL},
/* 14366 */ { "EGYPTIAN HIEROGLYPH-14366","	* phonemogram : kꜣw"},
/* 14367 */ { "EGYPTIAN HIEROGLYPH-14367","	* phonemogram : ẖnm"},
/* 14368 */ { "EGYPTIAN HIEROGLYPH-14368",NULL},
/* 14369 */ { "EGYPTIAN HIEROGLYPH-14369","	* phonemogram : ẖnm"},
/* 1436A */ { "EGYPTIAN HIEROGLYPH-1436A","	* phonemogram : ẖnm"},
/* 1436B */ { "EGYPTIAN HIEROGLYPH-1436B","	* phonemogram : ẖnm"},
/* 1436C */ { "EGYPTIAN HIEROGLYPH-1436C","	* logogram (cup) : ꜥ"},
/* 1436D */ { "EGYPTIAN HIEROGLYPH-1436D","	* phonemogram : g"},
/* 1436E */ { "EGYPTIAN HIEROGLYPH-1436E","	* classifier jar, vessel : snb.t"},
/* 1436F */ { "EGYPTIAN HIEROGLYPH-1436F","	* classifier cool : ḳb"},
/* 14370 */ { "EGYPTIAN HIEROGLYPH-14370","	* classifier to be cool, to cool : ḳbḥ"},
/* 14371 */ { "EGYPTIAN HIEROGLYPH-14371","	* logogram (cool water/libation water) : ḳbḥ.w"},
/* 14372 */ { "EGYPTIAN HIEROGLYPH-14372","	* classifier to pour, to sprinkle : sṯ(ꞽ)"},
/* 14373 */ { "EGYPTIAN HIEROGLYPH-14373","	* logogram (to be cool, to cool) : ḳbḥ"},
/* 14374 */ { "EGYPTIAN HIEROGLYPH-14374","	* logogram (cool water/libation water) : ḳbḥ.w"},
/* 14375 */ { "EGYPTIAN HIEROGLYPH-14375","	* logogram (the (first) cataract) : ḳbḥ.w"},
/* 14376 */ { "EGYPTIAN HIEROGLYPH-14376","	* phonemogram/logogram (in ḳbḥ.wy (the two sources, i.e., Egypt)) : ḳbḥ"},
/* 14377 */ { "EGYPTIAN HIEROGLYPH-14377","	* logogram (the two sources, i.e. Egypt) : ḳbḥ.wy"},
/* 14378 */ { "EGYPTIAN HIEROGLYPH-14378","	* logogram (cool water/libation water) : ḳbḥ.w"},
/* 14379 */ { "EGYPTIAN HIEROGLYPH-14379","	* phonemogram : ḫnt"},
/* 1437A */ { "EGYPTIAN HIEROGLYPH-1437A","	* phonemogram : ḫnt"},
/* 1437B */ { "EGYPTIAN HIEROGLYPH-1437B","	* phonemogram : ḫnt"},
/* 1437C */ { "EGYPTIAN HIEROGLYPH-1437C","	* phonemogram : ḫnt"},
/* 1437D */ { "EGYPTIAN HIEROGLYPH-1437D","	* phonemogram : ḫnt"},
/* 1437E */ { "EGYPTIAN HIEROGLYPH-1437E",NULL},
/* 1437F */ { "EGYPTIAN HIEROGLYPH-1437F","	* phonemogram : mꞽ"},
/* 14380 */ { "EGYPTIAN HIEROGLYPH-14380","	* classifier milk : ꞽrṯ(.t)"},
/* 14381 */ { "EGYPTIAN HIEROGLYPH-14381","	* classifier milk : ꞽrṯ.t"},
/* 14382 */ { "EGYPTIAN HIEROGLYPH-14382",NULL},
/* 14383 */ { "EGYPTIAN HIEROGLYPH-14383",NULL},
/* 14384 */ { "EGYPTIAN HIEROGLYPH-14384","	* phonemogram : mꞽ"},
/* 14385 */ { "EGYPTIAN HIEROGLYPH-14385","	* classifier vessel (situla?) : wšb"},
/* 14386 */ { "EGYPTIAN HIEROGLYPH-14386","	* logogram (to be pure, to be clean) : wꜥb"},
/* 14387 */ { "EGYPTIAN HIEROGLYPH-14387","	* classifier to pour out, to empty : pnḳ"},
/* 14388 */ { "EGYPTIAN HIEROGLYPH-14388","	* phonemogram : rd"},
/* 14389 */ { "EGYPTIAN HIEROGLYPH-14389","	* classifier beer-jug : nb.ty"},
/* 1438A */ { "EGYPTIAN HIEROGLYPH-1438A",NULL},
/* 1438B */ { "EGYPTIAN HIEROGLYPH-1438B","	* classifier drunkenness : tḫ.t"},
/* 1438C */ { "EGYPTIAN HIEROGLYPH-1438C","	* classifier wine : ꞽrp"},
/* 1438D */ { "EGYPTIAN HIEROGLYPH-1438D",NULL},
/* 1438E */ { "EGYPTIAN HIEROGLYPH-1438E",NULL},
/* 1438F */ { "EGYPTIAN HIEROGLYPH-1438F","	* classifier liquid, fluid : ꞽrp"},
/* 14390 */ { "EGYPTIAN HIEROGLYPH-14390","	* classifier jar : ḥn(.w)"},
/* 14391 */ { "EGYPTIAN HIEROGLYPH-14391","	* classifier oil, unguent : mrḥ(.t)"},
/* 14392 */ { "EGYPTIAN HIEROGLYPH-14392","	* logogram diw-(the five pellets) : ṯꜣ.w"},
/* 14393 */ { "EGYPTIAN HIEROGLYPH-14393","	* classifier jug : nms.t"},
/* 14394 */ { "EGYPTIAN HIEROGLYPH-14394",NULL},
/* 14395 */ { "EGYPTIAN HIEROGLYPH-14395","	* phonemogram : ꞽn-ḥr"},
/* 14396 */ { "EGYPTIAN HIEROGLYPH-14396","	* phonemogram : r"},
/* 14397 */ { "EGYPTIAN HIEROGLYPH-14397","	* logogram (Elephantine) : ꜣbw"},
/* 14398 */ { "EGYPTIAN HIEROGLYPH-14398",NULL},
/* 14399 */ { "EGYPTIAN HIEROGLYPH-14399","	* classifier liquid, fluid : ḥḏ.t"},
/* 1439A */ { "EGYPTIAN HIEROGLYPH-1439A","	* classifier jar, vessel : dšr.yt"},
/* 1439B */ { "EGYPTIAN HIEROGLYPH-1439B","	* classifier breaking, destroying : sḏ"},
/* 1439C */ { "EGYPTIAN HIEROGLYPH-1439C","	* classifier alcoholic beverage : tḫ"},
/* 1439D */ { "EGYPTIAN HIEROGLYPH-1439D","	* logogram (libation vase) : šps.y"},
/* 1439E */ { "EGYPTIAN HIEROGLYPH-1439E","	* classifier to fill : ꜥḥb.t"},
/* 1439F */ { "EGYPTIAN HIEROGLYPH-1439F","	* classifier vessel : dšr.t"},
/* 143A0 */ { "EGYPTIAN HIEROGLYPH-143A0","	* classifier jar, vessel : nms.t"},
/* 143A1 */ { "EGYPTIAN HIEROGLYPH-143A1","	* classifier jar, vessel : nms.t"},
/* 143A2 */ { "EGYPTIAN HIEROGLYPH-143A2","	* classifier (to wash) : ꞽꜥꞽ"},
/* 143A3 */ { "EGYPTIAN HIEROGLYPH-143A3","	* logogram (nemset vase) : nms.t"},
/* 143A4 */ { "EGYPTIAN HIEROGLYPH-143A4","	* classifier vessel : ḏwj.w"},
/* 143A5 */ { "EGYPTIAN HIEROGLYPH-143A5","	* classifier vessel, jar : ṯꜣb"},
/* 143A6 */ { "EGYPTIAN HIEROGLYPH-143A6",NULL},
/* 143A7 */ { "EGYPTIAN HIEROGLYPH-143A7","	* classifier jar, vessel : nms.t"},
/* 143A8 */ { "EGYPTIAN HIEROGLYPH-143A8","	* classifier drinking vessel : swr"},
/* 143A9 */ { "EGYPTIAN HIEROGLYPH-143A9","	* classifier drinking vessel : ḫꜣw & (ṯ)nꞽw"},
/* 143AA */ { "EGYPTIAN HIEROGLYPH-143AA",NULL},
/* 143AB */ { "EGYPTIAN HIEROGLYPH-143AB","	* classifier dish : dd.t"},
/* 143AC */ { "EGYPTIAN HIEROGLYPH-143AC",NULL},
/* 143AD */ { "EGYPTIAN HIEROGLYPH-143AD",NULL},
/* 143AE */ { "EGYPTIAN HIEROGLYPH-143AE","	* logogram (some type of vessel) : ḏwꞽ.w"},
/* 143AF */ { "EGYPTIAN HIEROGLYPH-143AF","	* classifier milk : ꞽrṯ.t"},
/* 143B0 */ { "EGYPTIAN HIEROGLYPH-143B0","	* classifier vessel (possibly for oil) : bꜥ/bꜥꜥ"},
/* 143B1 */ { "EGYPTIAN HIEROGLYPH-143B1",NULL},
/* 143B2 */ { "EGYPTIAN HIEROGLYPH-143B2",NULL},
/* 143B3 */ { "EGYPTIAN HIEROGLYPH-143B3","	* logogram (beer) : ḥnḳ.t"},
/* 143B4 */ { "EGYPTIAN HIEROGLYPH-143B4","	* logogram (gold vase for myrrh) : rrm"},
/* 143B5 */ { "EGYPTIAN HIEROGLYPH-143B5","	* classifier oven : kꜣp.t"},
/* 143B6 */ { "EGYPTIAN HIEROGLYPH-143B6",NULL},
/* 143B7 */ { "EGYPTIAN HIEROGLYPH-143B7","	* ?"},
/* 143B8 */ { "EGYPTIAN HIEROGLYPH-143B8","	* classifier granite : mꜣṯ"},
/* 143B9 */ { "EGYPTIAN HIEROGLYPH-143B9","	* phonemogram : ꜣw"},
/* 143BA */ { "EGYPTIAN HIEROGLYPH-143BA","	* logogram (a nw-vase, representing an amulet of lapis-lazuli) : nw"},
/* 143BB */ { "EGYPTIAN HIEROGLYPH-143BB","	* classifier basin for washing feet : mꜥ"},
/* 143BC */ { "EGYPTIAN HIEROGLYPH-143BC","	* logogram (father) : ꞽt"},
/* 143BD */ { "EGYPTIAN HIEROGLYPH-143BD","	* logogram (father) : ꞽt"},
/* 143BE */ { "EGYPTIAN HIEROGLYPH-143BE","	* logogram (father) : ꞽt"},
/* 143BF */ { "EGYPTIAN HIEROGLYPH-143BF",NULL},
/* 143C0 */ { "EGYPTIAN HIEROGLYPH-143C0","	* classifier bread : t"},
/* 143C1 */ { "EGYPTIAN HIEROGLYPH-143C1","	* classifier bread : t-ḥḏ"},
/* 143C2 */ { "EGYPTIAN HIEROGLYPH-143C2","	* classifier bread/food : t"},
/* 143C3 */ { "EGYPTIAN HIEROGLYPH-143C3",NULL},
/* 143C4 */ { "EGYPTIAN HIEROGLYPH-143C4","	* classifier food : t ḥnḳ.t kꜣ ꜣpd"},
/* 143C5 */ { "EGYPTIAN HIEROGLYPH-143C5","	* classifier festival : ꜣbd"},
/* 143C6 */ { "EGYPTIAN HIEROGLYPH-143C6","	* classifier food : kꜣ.w"},
/* 143C7 */ { "EGYPTIAN HIEROGLYPH-143C7","	* classifier offering : drp"},
/* 143C8 */ { "EGYPTIAN HIEROGLYPH-143C8","	* logogram (type of bread) : šns"},
/* 143C9 */ { "EGYPTIAN HIEROGLYPH-143C9","	* logogram (to pass by) : sn"},
/* 143CA */ { "EGYPTIAN HIEROGLYPH-143CA",NULL},
/* 143CB */ { "EGYPTIAN HIEROGLYPH-143CB","	* phonemogram : pꜣ.t"},
/* 143CC */ { "EGYPTIAN HIEROGLYPH-143CC","	* classifier offering, cake, loaf : ḥn.w(t)"},
/* 143CD */ { "EGYPTIAN HIEROGLYPH-143CD",NULL},
/* 143CE */ { "EGYPTIAN HIEROGLYPH-143CE","	* classifier bread : t-ꞽm.y-tꜣ"},
/* 143CF */ { "EGYPTIAN HIEROGLYPH-143CF","	* classifier abstract words : gr"},
/* 143D0 */ { "EGYPTIAN HIEROGLYPH-143D0","	* classifier double flute : mꜣ.t"},
/* 143D1 */ { "EGYPTIAN HIEROGLYPH-143D1","	* logogram (to write, to draw) : sš"},
/* 143D2 */ { "EGYPTIAN HIEROGLYPH-143D2","	* logogram (scribe) : sš"},
/* 143D3 */ { "EGYPTIAN HIEROGLYPH-143D3","	* classifier red : ṯ(m)s"},
/* 143D4 */ { "EGYPTIAN HIEROGLYPH-143D4","	* classifier scribal pallet : gsty"},
/* 143D5 */ { "EGYPTIAN HIEROGLYPH-143D5","	* classifier (scribal water pot)"},
/* 143D6 */ { "EGYPTIAN HIEROGLYPH-143D6",NULL},
/* 143D7 */ { "EGYPTIAN HIEROGLYPH-143D7","	* classifier writing tablet : ꜥn"},
/* 143D8 */ { "EGYPTIAN HIEROGLYPH-143D8","	* classifier snake-game : mḥn"},
/* 143D9 */ { "EGYPTIAN HIEROGLYPH-143D9","	* phonemogram : ḏꜣ"},
/* 143DA */ { "EGYPTIAN HIEROGLYPH-143DA","	* phonemogram : ṯt"},
/* 143DB */ { "EGYPTIAN HIEROGLYPH-143DB","	* logogram (to say, to speak) : ḏd"},
/* 143DC */ { "EGYPTIAN HIEROGLYPH-143DC","	* logogram (to say, to speak) : ḏd"},
/* 143DD */ { "EGYPTIAN HIEROGLYPH-143DD","	* logogram (to say, to speak) : ḏd"},
/* 143DE */ { "EGYPTIAN HIEROGLYPH-143DE","	* classifier tambourine : sr"},
/* 143DF */ { "EGYPTIAN HIEROGLYPH-143DF","	* classifier tambourine : sr"},
/* 143E0 */ { "EGYPTIAN HIEROGLYPH-143E0","	* logogram (ball) : ḥmꜣ"},
/* 143E1 */ { "EGYPTIAN HIEROGLYPH-143E1","	* classifier sistrum : sšš(.t)"},
/* 143E2 */ { "EGYPTIAN HIEROGLYPH-143E2","	* logogram (sistrum) : sḫm"},
/* 143E3 */ { "EGYPTIAN HIEROGLYPH-143E3","	* classifier sistrum : sḫm"},
/* 143E4 */ { "EGYPTIAN HIEROGLYPH-143E4","	* logogram (sistrum) : sšš.t"},
/* 143E5 */ { "EGYPTIAN HIEROGLYPH-143E5","	* logogram (sistrum) : sšš.t"},
/* 143E6 */ { "EGYPTIAN HIEROGLYPH-143E6","	* classifier head-piece of a sistrum : bḫn"},
/* 143E7 */ { "EGYPTIAN HIEROGLYPH-143E7","	* classifier plural"},
/* 143E8 */ { "EGYPTIAN HIEROGLYPH-143E8",NULL},
/* 143E9 */ { "EGYPTIAN HIEROGLYPH-143E9","	* phonemogram : ꞽm.y"},
/* 143EA */ { "EGYPTIAN HIEROGLYPH-143EA","	* phonemogram : ꞽm.y"},
/* 143EB */ { "EGYPTIAN HIEROGLYPH-143EB",NULL},
/* 143EC */ { "EGYPTIAN HIEROGLYPH-143EC",NULL},
/* 143ED */ { "EGYPTIAN HIEROGLYPH-143ED",NULL},
/* 143EE */ { "EGYPTIAN HIEROGLYPH-143EE","	* logogram (1/2 aroura) : rmn"},
/* 143EF */ { "EGYPTIAN HIEROGLYPH-143EF","	* classifier writing tablet : ꜥn"},
/* 143F0 */ { "EGYPTIAN HIEROGLYPH-143F0","	* classifier enemy, opponent : pꜣ tꜣ-r"},
/* 143F1 */ { "EGYPTIAN HIEROGLYPH-143F1",NULL},
/* 143F2 */ { "EGYPTIAN HIEROGLYPH-143F2",NULL},
/* 143F3 */ { "EGYPTIAN HIEROGLYPH-143F3",NULL},
/* 143F4 */ { "EGYPTIAN HIEROGLYPH-143F4",NULL},
/* 143F5 */ { "EGYPTIAN HIEROGLYPH-143F5",NULL},
/* 143F6 */ { "EGYPTIAN HIEROGLYPH-143F6",NULL},
/* 143F7 */ { "EGYPTIAN HIEROGLYPH-143F7","	* logogram : ḏd-mdw"},
/* 143F8 */ { "EGYPTIAN HIEROGLYPH-143F8","	* phonemogram : smꜣ"},
/* 143F9 */ { "EGYPTIAN HIEROGLYPH-143F9",NULL},
/* 143FA */ { "EGYPTIAN HIEROGLYPH-143FA","	* phonemogram : ꜣb"},
/* 143FB */ { NULL,NULL},
/* 143FC */ { NULL,NULL},
/* 143FD */ { NULL,NULL},
/* 143FE */ { NULL,NULL},
/* 143FF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_44[] = {
/* 14400 */ { "ANATOLIAN HIEROGLYPH A001","	= ego"},
/* 14401 */ { "ANATOLIAN HIEROGLYPH A002","	= ego2"},
/* 14402 */ { "ANATOLIAN HIEROGLYPH A003",NULL},
/* 14403 */ { "ANATOLIAN HIEROGLYPH A004","	= mons2"},
/* 14404 */ { "ANATOLIAN HIEROGLYPH A005",NULL},
/* 14405 */ { "ANATOLIAN HIEROGLYPH A006","	= adorare"},
/* 14406 */ { "ANATOLIAN HIEROGLYPH A007","	= edere"},
/* 14407 */ { "ANATOLIAN HIEROGLYPH A008","	= bibere"},
/* 14408 */ { "ANATOLIAN HIEROGLYPH A009","	= amplecti"},
/* 14409 */ { "ANATOLIAN HIEROGLYPH A010","	= caput"},
/* 1440A */ { "ANATOLIAN HIEROGLYPH A010A","	= caput+scalprum"},
/* 1440B */ { "ANATOLIAN HIEROGLYPH A011",NULL},
/* 1440C */ { "ANATOLIAN HIEROGLYPH A012","	= statua"},
/* 1440D */ { "ANATOLIAN HIEROGLYPH A013",NULL},
/* 1440E */ { "ANATOLIAN HIEROGLYPH A014","	= prae\n"
	"	= logosyllabic pari"},
/* 1440F */ { "ANATOLIAN HIEROGLYPH A015","	= domina"},
/* 14410 */ { "ANATOLIAN HIEROGLYPH A016","	= magnus.domina"},
/* 14411 */ { "ANATOLIAN HIEROGLYPH A017","	= rex"},
/* 14412 */ { "ANATOLIAN HIEROGLYPH A018","	= magnus.rex"},
/* 14413 */ { "ANATOLIAN HIEROGLYPH A019","	= syllabic á"},
/* 14414 */ { "ANATOLIAN HIEROGLYPH A020",NULL},
/* 14415 */ { "ANATOLIAN HIEROGLYPH A021","	= heros"},
/* 14416 */ { "ANATOLIAN HIEROGLYPH A022","	= loqui"},
/* 14417 */ { "ANATOLIAN HIEROGLYPH A023",NULL},
/* 14418 */ { "ANATOLIAN HIEROGLYPH A024","	= lis"},
/* 14419 */ { "ANATOLIAN HIEROGLYPH A025","	= oculus"},
/* 1441A */ { "ANATOLIAN HIEROGLYPH A026","	= frons"},
/* 1441B */ { "ANATOLIAN HIEROGLYPH A026A","	= versus"},
/* 1441C */ { "ANATOLIAN HIEROGLYPH A027","	= libare"},
/* 1441D */ { "ANATOLIAN HIEROGLYPH A028","	= fortis"},
/* 1441E */ { "ANATOLIAN HIEROGLYPH A029","	= syllabic tá"},
/* 1441F */ { "ANATOLIAN HIEROGLYPH A030",NULL},
/* 14420 */ { "ANATOLIAN HIEROGLYPH A031","	= ligare, pugnus+pugnus"},
/* 14421 */ { "ANATOLIAN HIEROGLYPH A032","	= bracchium"},
/* 14422 */ { "ANATOLIAN HIEROGLYPH A033",NULL},
/* 14423 */ { "ANATOLIAN HIEROGLYPH A034","	= post"},
/* 14424 */ { "ANATOLIAN HIEROGLYPH A035","	= syllabic na"},
/* 14425 */ { "ANATOLIAN HIEROGLYPH A036","	= lituus+na"},
/* 14426 */ { "ANATOLIAN HIEROGLYPH A037",NULL},
/* 14427 */ { "ANATOLIAN HIEROGLYPH A038",NULL},
/* 14428 */ { "ANATOLIAN HIEROGLYPH A039","	= pugnus"},
/* 14429 */ { "ANATOLIAN HIEROGLYPH A039A","	= pugnus+x"},
/* 1442A */ { "ANATOLIAN HIEROGLYPH A040",NULL},
/* 1442B */ { "ANATOLIAN HIEROGLYPH A041","	= capere\n"
	"	= syllabic tà"},
/* 1442C */ { "ANATOLIAN HIEROGLYPH A041A","	= syllabic tà"},
/* 1442D */ { "ANATOLIAN HIEROGLYPH A042","	= capere2.capere2\n"
	"	= syllabic ta-x?"},
/* 1442E */ { "ANATOLIAN HIEROGLYPH A043","	= capere2"},
/* 1442F */ { "ANATOLIAN HIEROGLYPH A044",NULL},
/* 14430 */ { "ANATOLIAN HIEROGLYPH A045","	= infans, filius, frater"},
/* 14431 */ { "ANATOLIAN HIEROGLYPH A045A","	= filia"},
/* 14432 */ { "ANATOLIAN HIEROGLYPH A046","	= rex.infans, rex.filius"},
/* 14433 */ { "ANATOLIAN HIEROGLYPH A046A","	= rex.filia"},
/* 14434 */ { "ANATOLIAN HIEROGLYPH A046B","	= magnus.filia"},
/* 14435 */ { "ANATOLIAN HIEROGLYPH A047",NULL},
/* 14436 */ { "ANATOLIAN HIEROGLYPH A048",NULL},
/* 14437 */ { "ANATOLIAN HIEROGLYPH A049","	= syllabic a+tá"},
/* 14438 */ { "ANATOLIAN HIEROGLYPH A050",NULL},
/* 14439 */ { "ANATOLIAN HIEROGLYPH A051",NULL},
/* 1443A */ { "ANATOLIAN HIEROGLYPH A052","	= manus.culter"},
/* 1443B */ { "ANATOLIAN HIEROGLYPH A053","	= manus+culter, ensis"},
/* 1443C */ { "ANATOLIAN HIEROGLYPH A054",NULL},
/* 1443D */ { "ANATOLIAN HIEROGLYPH A055","	= syllabic nì"},
/* 1443E */ { "ANATOLIAN HIEROGLYPH A056","	= syllabic ká"},
/* 1443F */ { "ANATOLIAN HIEROGLYPH A057","	= infra, sub\n"
	"	= syllabic ká"},
/* 14440 */ { "ANATOLIAN HIEROGLYPH A058","	= cum"},
/* 14441 */ { "ANATOLIAN HIEROGLYPH A059","	= manus"},
/* 14442 */ { "ANATOLIAN HIEROGLYPH A060",NULL},
/* 14443 */ { "ANATOLIAN HIEROGLYPH A061",NULL},
/* 14444 */ { "ANATOLIAN HIEROGLYPH A062","	= longus, manus+minus?"},
/* 14445 */ { "ANATOLIAN HIEROGLYPH A063",NULL},
/* 14446 */ { "ANATOLIAN HIEROGLYPH A064",NULL},
/* 14447 */ { "ANATOLIAN HIEROGLYPH A065","	= ponere"},
/* 14448 */ { "ANATOLIAN HIEROGLYPH A066","	= dare\n"
	"	= syllabic pi"},
/* 14449 */ { "ANATOLIAN HIEROGLYPH A066A","	= syllabic pi"},
/* 1444A */ { "ANATOLIAN HIEROGLYPH A066B","	= mandare, dare.dare"},
/* 1444B */ { "ANATOLIAN HIEROGLYPH A066C","	= mandare2"},
/* 1444C */ { "ANATOLIAN HIEROGLYPH A067",NULL},
/* 1444D */ { "ANATOLIAN HIEROGLYPH A068",NULL},
/* 1444E */ { "ANATOLIAN HIEROGLYPH A069",NULL},
/* 1444F */ { "ANATOLIAN HIEROGLYPH A070","	= super\n"
	"	= logosyllabic sara/i"},
/* 14450 */ { "ANATOLIAN HIEROGLYPH A071",NULL},
/* 14451 */ { "ANATOLIAN HIEROGLYPH A072",NULL},
/* 14452 */ { "ANATOLIAN HIEROGLYPH A073","	= audire, auris+tu+mi"},
/* 14453 */ { "ANATOLIAN HIEROGLYPH A074",NULL},
/* 14454 */ { "ANATOLIAN HIEROGLYPH A075",NULL},
/* 14455 */ { "ANATOLIAN HIEROGLYPH A076",NULL},
/* 14456 */ { "ANATOLIAN HIEROGLYPH A077",NULL},
/* 14457 */ { "ANATOLIAN HIEROGLYPH A078","	= ala"},
/* 14458 */ { "ANATOLIAN HIEROGLYPH A079","	= femina, mater"},
/* 14459 */ { "ANATOLIAN HIEROGLYPH A080","	= Sarma"},
/* 1445A */ { "ANATOLIAN HIEROGLYPH A081","	= Sarma2"},
/* 1445B */ { "ANATOLIAN HIEROGLYPH A082","	= crus\n"
	"	= syllabic ta6"},
/* 1445C */ { "ANATOLIAN HIEROGLYPH A083","	= crus+flumen"},
/* 1445D */ { "ANATOLIAN HIEROGLYPH A084","	= crus2\n"
	"	= syllabic nà"},
/* 1445E */ { "ANATOLIAN HIEROGLYPH A085","	= genuflectere"},
/* 1445F */ { "ANATOLIAN HIEROGLYPH A086","	= crus.crus"},
/* 14460 */ { "ANATOLIAN HIEROGLYPH A087",NULL},
/* 14461 */ { "ANATOLIAN HIEROGLYPH A088",NULL},
/* 14462 */ { "ANATOLIAN HIEROGLYPH A089","	= syllabic tu"},
/* 14463 */ { "ANATOLIAN HIEROGLYPH A090","	= pes\n"
	"	= syllabic ti"},
/* 14464 */ { "ANATOLIAN HIEROGLYPH A091","	= pes.scala.rotae"},
/* 14465 */ { "ANATOLIAN HIEROGLYPH A092",NULL},
/* 14466 */ { "ANATOLIAN HIEROGLYPH A093","	= pes2"},
/* 14467 */ { "ANATOLIAN HIEROGLYPH A094",NULL},
/* 14468 */ { "ANATOLIAN HIEROGLYPH A095","	= pes2.pes2"},
/* 14469 */ { "ANATOLIAN HIEROGLYPH A096","	= pes2.pes"},
/* 1446A */ { "ANATOLIAN HIEROGLYPH A097","	= leo, bestia"},
/* 1446B */ { "ANATOLIAN HIEROGLYPH A097A","	= leo2"},
/* 1446C */ { "ANATOLIAN HIEROGLYPH A098","	= canis"},
/* 1446D */ { "ANATOLIAN HIEROGLYPH A098A","	= canis2"},
/* 1446E */ { "ANATOLIAN HIEROGLYPH A099","	= equus"},
/* 1446F */ { "ANATOLIAN HIEROGLYPH A100","	= asinus\n"
	"	= syllabic ta"},
/* 14470 */ { "ANATOLIAN HIEROGLYPH A100A","	= syllabic ta"},
/* 14471 */ { "ANATOLIAN HIEROGLYPH A101","	= asinus2"},
/* 14472 */ { "ANATOLIAN HIEROGLYPH A101A","	= asinus2a"},
/* 14473 */ { "ANATOLIAN HIEROGLYPH A102","	= cervus\n"
	"	= syllabic rú"},
/* 14474 */ { "ANATOLIAN HIEROGLYPH A102A","	= cervus2\n"
	"	= syllabic rú"},
/* 14475 */ { "ANATOLIAN HIEROGLYPH A103","	= cervus3\n"
	"	= syllabic rú"},
/* 14476 */ { "ANATOLIAN HIEROGLYPH A104","	= capra\n"
	"	= syllabic sà"},
/* 14477 */ { "ANATOLIAN HIEROGLYPH A104A","	= syllabic sà"},
/* 14478 */ { "ANATOLIAN HIEROGLYPH A104B","	= capra2\n"
	"	= syllabic sà"},
/* 14479 */ { "ANATOLIAN HIEROGLYPH A104C","	= capra2a\n"
	"	= syllabic sà"},
/* 1447A */ { "ANATOLIAN HIEROGLYPH A105","	= bos\n"
	"	= syllabic u"},
/* 1447B */ { "ANATOLIAN HIEROGLYPH A105A","	= bos\n"
	"	= syllabic u"},
/* 1447C */ { "ANATOLIAN HIEROGLYPH A105B","	= bos2\n"
	"	= syllabic u"},
/* 1447D */ { "ANATOLIAN HIEROGLYPH A106",NULL},
/* 1447E */ { "ANATOLIAN HIEROGLYPH A107","	= bos+mi\n"
	"	= syllabic mu\n"
	"	= logosyllabic muwa"},
/* 1447F */ { "ANATOLIAN HIEROGLYPH A107A","	= syllabic mu\n"
	"	= logosyllabic muwa"},
/* 14480 */ { "ANATOLIAN HIEROGLYPH A107B","	= bos.mi\n"
	"	= syllabic mu\n"
	"	= logosyllabic muwa"},
/* 14481 */ { "ANATOLIAN HIEROGLYPH A107C","	= bos2.mi\n"
	"	= syllabic mu\n"
	"	= logosyllabic muwa"},
/* 14482 */ { "ANATOLIAN HIEROGLYPH A108","	= cornu\n"
	"	= sú"},
/* 14483 */ { "ANATOLIAN HIEROGLYPH A109","	= vitellus\n"
	"	= syllabic ma-x"},
/* 14484 */ { "ANATOLIAN HIEROGLYPH A110","	= ovis\n"
	"	= syllabic ma"},
/* 14485 */ { "ANATOLIAN HIEROGLYPH A110A","	= syllabic ma"},
/* 14486 */ { "ANATOLIAN HIEROGLYPH A110B","	= ovis2\n"
	"	= syllabic ma"},
/* 14487 */ { "ANATOLIAN HIEROGLYPH A111","	= ovis3"},
/* 14488 */ { "ANATOLIAN HIEROGLYPH A112","	= lingere\n"
	"	= syllabic za4"},
/* 14489 */ { "ANATOLIAN HIEROGLYPH A113",NULL},
/* 1448A */ { "ANATOLIAN HIEROGLYPH A114","	= lituus+u"},
/* 1448B */ { "ANATOLIAN HIEROGLYPH A115","	= lepus\n"
	"	= logosyllabic tapa"},
/* 1448C */ { "ANATOLIAN HIEROGLYPH A115A","	= lepus2\n"
	"	= logosyllabic tapa"},
/* 1448D */ { "ANATOLIAN HIEROGLYPH A116",NULL},
/* 1448E */ { "ANATOLIAN HIEROGLYPH A117",NULL},
/* 1448F */ { "ANATOLIAN HIEROGLYPH A118",NULL},
/* 14490 */ { "ANATOLIAN HIEROGLYPH A119",NULL},
/* 14491 */ { "ANATOLIAN HIEROGLYPH A120","	= gryllus"},
/* 14492 */ { "ANATOLIAN HIEROGLYPH A121","	= sphinx"},
/* 14493 */ { "ANATOLIAN HIEROGLYPH A122",NULL},
/* 14494 */ { "ANATOLIAN HIEROGLYPH A123",NULL},
/* 14495 */ { "ANATOLIAN HIEROGLYPH A124",NULL},
/* 14496 */ { "ANATOLIAN HIEROGLYPH A125","	= syllabic lí"},
/* 14497 */ { "ANATOLIAN HIEROGLYPH A125A","	= ungula\n"
	"	= syllabic li-x"},
/* 14498 */ { "ANATOLIAN HIEROGLYPH A126",NULL},
/* 14499 */ { "ANATOLIAN HIEROGLYPH A127",NULL},
/* 1449A */ { "ANATOLIAN HIEROGLYPH A128","	= avis\n"
	"	= zi4"},
/* 1449B */ { "ANATOLIAN HIEROGLYPH A129",NULL},
/* 1449C */ { "ANATOLIAN HIEROGLYPH A130","	= avis3"},
/* 1449D */ { "ANATOLIAN HIEROGLYPH A131","	= avis5"},
/* 1449E */ { "ANATOLIAN HIEROGLYPH A132","	= avis2"},
/* 1449F */ { "ANATOLIAN HIEROGLYPH A133","	= aquila, avis4\n"
	"	= syllabic ara/i"},
/* 144A0 */ { "ANATOLIAN HIEROGLYPH A134","	= syllabic ara/i\n"
	"	* 1449F anatolian hieroglyph a133 + 145B1 anatolian hieroglyph a383 ra or ri"},
/* 144A1 */ { "ANATOLIAN HIEROGLYPH A135","	= avis-x"},
/* 144A2 */ { "ANATOLIAN HIEROGLYPH A135A",NULL},
/* 144A3 */ { "ANATOLIAN HIEROGLYPH A136",NULL},
/* 144A4 */ { "ANATOLIAN HIEROGLYPH A137","	= libatio"},
/* 144A5 */ { "ANATOLIAN HIEROGLYPH A138","	= piscis"},
/* 144A6 */ { "ANATOLIAN HIEROGLYPH A139",NULL},
/* 144A7 */ { "ANATOLIAN HIEROGLYPH A140",NULL},
/* 144A8 */ { "ANATOLIAN HIEROGLYPH A141",NULL},
/* 144A9 */ { "ANATOLIAN HIEROGLYPH A142",NULL},
/* 144AA */ { "ANATOLIAN HIEROGLYPH A143",NULL},
/* 144AB */ { "ANATOLIAN HIEROGLYPH A144",NULL},
/* 144AC */ { "ANATOLIAN HIEROGLYPH A145",NULL},
/* 144AD */ { "ANATOLIAN HIEROGLYPH A146",NULL},
/* 144AE */ { "ANATOLIAN HIEROGLYPH A147",NULL},
/* 144AF */ { "ANATOLIAN HIEROGLYPH A148","	= Janus"},
/* 144B0 */ { "ANATOLIAN HIEROGLYPH A149",NULL},
/* 144B1 */ { "ANATOLIAN HIEROGLYPH A150",NULL},
/* 144B2 */ { "ANATOLIAN HIEROGLYPH A151","	= Telipinu"},
/* 144B3 */ { "ANATOLIAN HIEROGLYPH A152",NULL},
/* 144B4 */ { "ANATOLIAN HIEROGLYPH A153","	= syllabic nu"},
/* 144B5 */ { "ANATOLIAN HIEROGLYPH A154",NULL},
/* 144B6 */ { "ANATOLIAN HIEROGLYPH A155",NULL},
/* 144B7 */ { "ANATOLIAN HIEROGLYPH A156",NULL},
/* 144B8 */ { "ANATOLIAN HIEROGLYPH A157",NULL},
/* 144B9 */ { "ANATOLIAN HIEROGLYPH A158",NULL},
/* 144BA */ { "ANATOLIAN HIEROGLYPH A159",NULL},
/* 144BB */ { "ANATOLIAN HIEROGLYPH A160","	= vitis\n"
	"	= syllabic wi(ya)"},
/* 144BC */ { "ANATOLIAN HIEROGLYPH A161",NULL},
/* 144BD */ { "ANATOLIAN HIEROGLYPH A162",NULL},
/* 144BE */ { "ANATOLIAN HIEROGLYPH A163",NULL},
/* 144BF */ { "ANATOLIAN HIEROGLYPH A164",NULL},
/* 144C0 */ { "ANATOLIAN HIEROGLYPH A165","	= bonus\n"
	"	= syllabic wà/ì"},
/* 144C1 */ { "ANATOLIAN HIEROGLYPH A166","	= syllabic wá/í"},
/* 144C2 */ { "ANATOLIAN HIEROGLYPH A167",NULL},
/* 144C3 */ { "ANATOLIAN HIEROGLYPH A168",NULL},
/* 144C4 */ { "ANATOLIAN HIEROGLYPH A169",NULL},
/* 144C5 */ { "ANATOLIAN HIEROGLYPH A170",NULL},
/* 144C6 */ { "ANATOLIAN HIEROGLYPH A171",NULL},
/* 144C7 */ { "ANATOLIAN HIEROGLYPH A172","	= syllabic ta/i5, lá/í"},
/* 144C8 */ { "ANATOLIAN HIEROGLYPH A173","	= hastarius"},
/* 144C9 */ { "ANATOLIAN HIEROGLYPH A174","	= syllabic si"},
/* 144CA */ { "ANATOLIAN HIEROGLYPH A175","	= lingua\n"
	"	= syllabic la"},
/* 144CB */ { "ANATOLIAN HIEROGLYPH A176","	= syllabic la+la"},
/* 144CC */ { "ANATOLIAN HIEROGLYPH A177","	= lingua+clavus"},
/* 144CD */ { "ANATOLIAN HIEROGLYPH A178","	= syllabic la+ra+a"},
/* 144CE */ { "ANATOLIAN HIEROGLYPH A179","	= hordeum\n"
	"	= syllabic hwi-x"},
/* 144CF */ { "ANATOLIAN HIEROGLYPH A180",NULL},
/* 144D0 */ { "ANATOLIAN HIEROGLYPH A181","	= panis\n"
	"	= syllabic pa-x"},
/* 144D1 */ { "ANATOLIAN HIEROGLYPH A182","	= caelum"},
/* 144D2 */ { "ANATOLIAN HIEROGLYPH A183",NULL},
/* 144D3 */ { "ANATOLIAN HIEROGLYPH A184",NULL},
/* 144D4 */ { "ANATOLIAN HIEROGLYPH A185",NULL},
/* 144D5 */ { "ANATOLIAN HIEROGLYPH A186",NULL},
/* 144D6 */ { "ANATOLIAN HIEROGLYPH A187",NULL},
/* 144D7 */ { "ANATOLIAN HIEROGLYPH A188",NULL},
/* 144D8 */ { "ANATOLIAN HIEROGLYPH A189",NULL},
/* 144D9 */ { "ANATOLIAN HIEROGLYPH A190","	= sol2"},
/* 144DA */ { "ANATOLIAN HIEROGLYPH A191","	= sol"},
/* 144DB */ { "ANATOLIAN HIEROGLYPH A192","	= oriens"},
/* 144DC */ { "ANATOLIAN HIEROGLYPH A193","	= luna"},
/* 144DD */ { "ANATOLIAN HIEROGLYPH A194",NULL},
/* 144DE */ { "ANATOLIAN HIEROGLYPH A195",NULL},
/* 144DF */ { "ANATOLIAN HIEROGLYPH A196","	= Hatti\n"
	"	= syllabic há"},
/* 144E0 */ { "ANATOLIAN HIEROGLYPH A197","	= Hatti+li, Hattusili\n"
	"	= logosyllabic há-li"},
/* 144E1 */ { "ANATOLIAN HIEROGLYPH A198",NULL},
/* 144E2 */ { "ANATOLIAN HIEROGLYPH A199","	= tonitrus"},
/* 144E3 */ { "ANATOLIAN HIEROGLYPH A200","	= fulgur"},
/* 144E4 */ { "ANATOLIAN HIEROGLYPH A201","	= terra, locus\n"
	"	= syllabic wa/i6"},
/* 144E5 */ { "ANATOLIAN HIEROGLYPH A202","	= via+terra.scalprum"},
/* 144E6 */ { "ANATOLIAN HIEROGLYPH A202A","	= via+terra+scalprum"},
/* 144E7 */ { "ANATOLIAN HIEROGLYPH A202B","	= (deus)via+terra"},
/* 144E8 */ { "ANATOLIAN HIEROGLYPH A203",NULL},
/* 144E9 */ { "ANATOLIAN HIEROGLYPH A204","	= syllabic wa/i5"},
/* 144EA */ { "ANATOLIAN HIEROGLYPH A205",NULL},
/* 144EB */ { "ANATOLIAN HIEROGLYPH A206",NULL},
/* 144EC */ { "ANATOLIAN HIEROGLYPH A207","	= mons\n"
	"	= syllabic wa/i5"},
/* 144ED */ { "ANATOLIAN HIEROGLYPH A207A","	= leo+mons.tu+leo"},
/* 144EE */ { "ANATOLIAN HIEROGLYPH A208",NULL},
/* 144EF */ { "ANATOLIAN HIEROGLYPH A209","	= syllabic i, i(a)"},
/* 144F0 */ { "ANATOLIAN HIEROGLYPH A209A","	= syllabic i+ra/i, ri+i\n"
	"	* 144EF anatolian hieroglyph a209 + 145B1 anatolian hieroglyph a383 ra or ri"},
/* 144F1 */ { "ANATOLIAN HIEROGLYPH A210","	= syllabic ia"},
/* 144F2 */ { "ANATOLIAN HIEROGLYPH A211",NULL},
/* 144F3 */ { "ANATOLIAN HIEROGLYPH A212","	= flumen"},
/* 144F4 */ { "ANATOLIAN HIEROGLYPH A213",NULL},
/* 144F5 */ { "ANATOLIAN HIEROGLYPH A214","	= syllabic ní"},
/* 144F6 */ { "ANATOLIAN HIEROGLYPH A215","	= fons"},
/* 144F7 */ { "ANATOLIAN HIEROGLYPH A215A","	= syllabic ha"},
/* 144F8 */ { "ANATOLIAN HIEROGLYPH A216","	= fines\n"
	"	= syllabic arha"},
/* 144F9 */ { "ANATOLIAN HIEROGLYPH A216A","	= fines+ha, arha"},
/* 144FA */ { "ANATOLIAN HIEROGLYPH A217",NULL},
/* 144FB */ { "ANATOLIAN HIEROGLYPH A218",NULL},
/* 144FC */ { "ANATOLIAN HIEROGLYPH A219",NULL},
/* 144FD */ { "ANATOLIAN HIEROGLYPH A220",NULL},
/* 144FE */ { "ANATOLIAN HIEROGLYPH A221","	= via"},
/* 144FF */ { "ANATOLIAN HIEROGLYPH A222",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_45[] = {
/* 14500 */ { "ANATOLIAN HIEROGLYPH A223","	= syllabic sa6"},
/* 14501 */ { "ANATOLIAN HIEROGLYPH A224","	= syllabic ha? pa?"},
/* 14502 */ { "ANATOLIAN HIEROGLYPH A225","	= urbs"},
/* 14503 */ { "ANATOLIAN HIEROGLYPH A226","	= Ishuwa"},
/* 14504 */ { "ANATOLIAN HIEROGLYPH A227","	= urbs+ra/i?+li, urbs+ra/i?-li"},
/* 14505 */ { "ANATOLIAN HIEROGLYPH A227A","	= urbs+li, urbs-li, Mursili"},
/* 14506 */ { "ANATOLIAN HIEROGLYPH A228","	= regio\n"
	"	= syllabic tu4"},
/* 14507 */ { "ANATOLIAN HIEROGLYPH A229","	= syllabic mí.regio"},
/* 14508 */ { "ANATOLIAN HIEROGLYPH A230",NULL},
/* 14509 */ { "ANATOLIAN HIEROGLYPH A231","	= castrum"},
/* 1450A */ { "ANATOLIAN HIEROGLYPH A232",NULL},
/* 1450B */ { "ANATOLIAN HIEROGLYPH A233",NULL},
/* 1450C */ { "ANATOLIAN HIEROGLYPH A234",NULL},
/* 1450D */ { "ANATOLIAN HIEROGLYPH A235","	= turris?"},
/* 1450E */ { "ANATOLIAN HIEROGLYPH A236","	= murus?"},
/* 1450F */ { "ANATOLIAN HIEROGLYPH A237","	= porta"},
/* 14510 */ { "ANATOLIAN HIEROGLYPH A238",NULL},
/* 14511 */ { "ANATOLIAN HIEROGLYPH A239","	= porta2"},
/* 14512 */ { "ANATOLIAN HIEROGLYPH A240",NULL},
/* 14513 */ { "ANATOLIAN HIEROGLYPH A241","	= syllabic ki-x"},
/* 14514 */ { "ANATOLIAN HIEROGLYPH A242",NULL},
/* 14515 */ { "ANATOLIAN HIEROGLYPH A243","	= cubitum"},
/* 14516 */ { "ANATOLIAN HIEROGLYPH A244","	= aedificium"},
/* 14517 */ { "ANATOLIAN HIEROGLYPH A245","	= vacuus, aedificium+minus"},
/* 14518 */ { "ANATOLIAN HIEROGLYPH A246","	= aedificare, aedificium.ponere"},
/* 14519 */ { "ANATOLIAN HIEROGLYPH A247","	= domus"},
/* 1451A */ { "ANATOLIAN HIEROGLYPH A248","	= delere, domus+minus"},
/* 1451B */ { "ANATOLIAN HIEROGLYPH A249","	= deus.domus"},
/* 1451C */ { "ANATOLIAN HIEROGLYPH A250","	= magnus.domus"},
/* 1451D */ { "ANATOLIAN HIEROGLYPH A251","	= domus+x"},
/* 1451E */ { "ANATOLIAN HIEROGLYPH A252","	= domus+scala"},
/* 1451F */ { "ANATOLIAN HIEROGLYPH A253",NULL},
/* 14520 */ { "ANATOLIAN HIEROGLYPH A254","	= eunuchus2"},
/* 14521 */ { "ANATOLIAN HIEROGLYPH A255","	= horreum"},
/* 14522 */ { "ANATOLIAN HIEROGLYPH A256",NULL},
/* 14523 */ { "ANATOLIAN HIEROGLYPH A257","	= argentum"},
/* 14524 */ { "ANATOLIAN HIEROGLYPH A258",NULL},
/* 14525 */ { "ANATOLIAN HIEROGLYPH A259",NULL},
/* 14526 */ { "ANATOLIAN HIEROGLYPH A260",NULL},
/* 14527 */ { "ANATOLIAN HIEROGLYPH A261",NULL},
/* 14528 */ { "ANATOLIAN HIEROGLYPH A262",NULL},
/* 14529 */ { "ANATOLIAN HIEROGLYPH A263",NULL},
/* 1452A */ { "ANATOLIAN HIEROGLYPH A264","	= podium"},
/* 1452B */ { "ANATOLIAN HIEROGLYPH A265",NULL},
/* 1452C */ { "ANATOLIAN HIEROGLYPH A266","	= pes.regio"},
/* 1452D */ { "ANATOLIAN HIEROGLYPH A267","	= stele, lapis+scalprum"},
/* 1452E */ { "ANATOLIAN HIEROGLYPH A267A","	= lapis"},
/* 1452F */ { "ANATOLIAN HIEROGLYPH A268","	= scalprum"},
/* 14530 */ { "ANATOLIAN HIEROGLYPH A269","	= exercitus"},
/* 14531 */ { "ANATOLIAN HIEROGLYPH A270",NULL},
/* 14532 */ { "ANATOLIAN HIEROGLYPH A271",NULL},
/* 14533 */ { "ANATOLIAN HIEROGLYPH A272","	= scutum"},
/* 14534 */ { "ANATOLIAN HIEROGLYPH A273",NULL},
/* 14535 */ { "ANATOLIAN HIEROGLYPH A274",NULL},
/* 14536 */ { "ANATOLIAN HIEROGLYPH A275",NULL},
/* 14537 */ { "ANATOLIAN HIEROGLYPH A276","	= frater2"},
/* 14538 */ { "ANATOLIAN HIEROGLYPH A277","	= iudex.la, iudex+la"},
/* 14539 */ { "ANATOLIAN HIEROGLYPH A278","	= syllabic li"},
/* 1453A */ { "ANATOLIAN HIEROGLYPH A279",NULL},
/* 1453B */ { "ANATOLIAN HIEROGLYPH A280","	= malleus\n"
	"	= syllabic wa/i9"},
/* 1453C */ { "ANATOLIAN HIEROGLYPH A281","	= ascia"},
/* 1453D */ { "ANATOLIAN HIEROGLYPH A282",NULL},
/* 1453E */ { "ANATOLIAN HIEROGLYPH A283","	= logosyllabic tuzzi"},
/* 1453F */ { "ANATOLIAN HIEROGLYPH A284",NULL},
/* 14540 */ { "ANATOLIAN HIEROGLYPH A285","	= iaculum\n"
	"	= syllabic zu?\n"
	"	= logosyllabic zuwa"},
/* 14541 */ { "ANATOLIAN HIEROGLYPH A286","	= syllabic wa/i7"},
/* 14542 */ { "ANATOLIAN HIEROGLYPH A287",NULL},
/* 14543 */ { "ANATOLIAN HIEROGLYPH A288","	= currus"},
/* 14544 */ { "ANATOLIAN HIEROGLYPH A289","	= auriga"},
/* 14545 */ { "ANATOLIAN HIEROGLYPH A289A","	= auriga2"},
/* 14546 */ { "ANATOLIAN HIEROGLYPH A290","	= syllabic hara/i\n"
	"	* 14548 anatolian hieroglyph a292 + 145B1 anatolian hieroglyph a383 ra or ri"},
/* 14547 */ { "ANATOLIAN HIEROGLYPH A291","	= syllabic lì"},
/* 14548 */ { "ANATOLIAN HIEROGLYPH A292","	= rota\n"
	"	= logosyllabic hala/i"},
/* 14549 */ { "ANATOLIAN HIEROGLYPH A293",NULL},
/* 1454A */ { "ANATOLIAN HIEROGLYPH A294","	= thronus, mensa"},
/* 1454B */ { "ANATOLIAN HIEROGLYPH A294A","	= thronus, mensa2\n"
	"	= Sarpa"},
/* 1454C */ { "ANATOLIAN HIEROGLYPH A295","	= sol2.thronus/mensa"},
/* 1454D */ { "ANATOLIAN HIEROGLYPH A296","	= (deus)mons.Sarpa, (deus)mons.mensa\n"
	"	= thronus"},
/* 1454E */ { "ANATOLIAN HIEROGLYPH A297",NULL},
/* 1454F */ { "ANATOLIAN HIEROGLYPH A298","	= thronus2"},
/* 14550 */ { "ANATOLIAN HIEROGLYPH A299","	= solium\n"
	"	= syllabic í"},
/* 14551 */ { "ANATOLIAN HIEROGLYPH A299A","	= syllabic iá"},
/* 14552 */ { "ANATOLIAN HIEROGLYPH A300","	= nepos"},
/* 14553 */ { "ANATOLIAN HIEROGLYPH A301","	= lectus"},
/* 14554 */ { "ANATOLIAN HIEROGLYPH A302",NULL},
/* 14555 */ { "ANATOLIAN HIEROGLYPH A303","	= syllabic sara/i\n"
	"	* 1456E anatolian hieroglyph a327 + 145B1 anatolian hieroglyph a383 ra or ri"},
/* 14556 */ { "ANATOLIAN HIEROGLYPH A304","	= syllabic mà"},
/* 14557 */ { "ANATOLIAN HIEROGLYPH A305","	= fusus"},
/* 14558 */ { "ANATOLIAN HIEROGLYPH A306","	= syllabic hí"},
/* 14559 */ { "ANATOLIAN HIEROGLYPH A307","	= syllabic hu"},
/* 1455A */ { "ANATOLIAN HIEROGLYPH A308",NULL},
/* 1455B */ { "ANATOLIAN HIEROGLYPH A309","	= crux"},
/* 1455C */ { "ANATOLIAN HIEROGLYPH A309A","	= crux2"},
/* 1455D */ { "ANATOLIAN HIEROGLYPH A310",NULL},
/* 1455E */ { "ANATOLIAN HIEROGLYPH A311",NULL},
/* 1455F */ { "ANATOLIAN HIEROGLYPH A312",NULL},
/* 14560 */ { "ANATOLIAN HIEROGLYPH A313","	= vir\n"
	"	= syllabic zí"},
/* 14561 */ { "ANATOLIAN HIEROGLYPH A314","	= syllabic ha-x"},
/* 14562 */ { "ANATOLIAN HIEROGLYPH A315","	= syllabic kar\n"
	"	* 14561 anatolian hieroglyph a314 + 145B1 anatolian hieroglyph a383 ra or ri"},
/* 14563 */ { "ANATOLIAN HIEROGLYPH A316","	= syllabic sa7"},
/* 14564 */ { "ANATOLIAN HIEROGLYPH A317",NULL},
/* 14565 */ { "ANATOLIAN HIEROGLYPH A318","	= Teshub"},
/* 14566 */ { "ANATOLIAN HIEROGLYPH A319","	= syllabic ta/i4, la/i"},
/* 14567 */ { "ANATOLIAN HIEROGLYPH A320",NULL},
/* 14568 */ { "ANATOLIAN HIEROGLYPH A321",NULL},
/* 14569 */ { "ANATOLIAN HIEROGLYPH A322","	= purus"},
/* 1456A */ { "ANATOLIAN HIEROGLYPH A323",NULL},
/* 1456B */ { "ANATOLIAN HIEROGLYPH A324",NULL},
/* 1456C */ { "ANATOLIAN HIEROGLYPH A325","	= syllabic tú"},
/* 1456D */ { "ANATOLIAN HIEROGLYPH A326","	= scriba\n"
	"	= syllabic tù"},
/* 1456E */ { "ANATOLIAN HIEROGLYPH A327","	= sigillum\n"
	"	= syllabic sa5"},
/* 1456F */ { "ANATOLIAN HIEROGLYPH A328","	= syllabic pu"},
/* 14570 */ { "ANATOLIAN HIEROGLYPH A329","	= relative\n"
	"	= syllabic kwi/a"},
/* 14571 */ { "ANATOLIAN HIEROGLYPH A329A",NULL},
/* 14572 */ { "ANATOLIAN HIEROGLYPH A330","	= capere+scalprum"},
/* 14573 */ { "ANATOLIAN HIEROGLYPH A331","	= avus"},
/* 14574 */ { "ANATOLIAN HIEROGLYPH A332A","	= negative"},
/* 14575 */ { "ANATOLIAN HIEROGLYPH A332B","	= negative2\n"
	"	= syllabic ná"},
/* 14576 */ { "ANATOLIAN HIEROGLYPH A332C","	= negative3"},
/* 14577 */ { "ANATOLIAN HIEROGLYPH A333",NULL},
/* 14578 */ { "ANATOLIAN HIEROGLYPH A334","	= syllabic pa"},
/* 14579 */ { "ANATOLIAN HIEROGLYPH A335","	= syllabic zá"},
/* 1457A */ { "ANATOLIAN HIEROGLYPH A336","	= annus, pithos.scutella, pithos\n"
	"	= syllabic zì"},
/* 1457B */ { "ANATOLIAN HIEROGLYPH A336A","	= syllabic zì"},
/* 1457C */ { "ANATOLIAN HIEROGLYPH A336B","	= syllabic zà"},
/* 1457D */ { "ANATOLIAN HIEROGLYPH A336C","	= syllabic za-x"},
/* 1457E */ { "ANATOLIAN HIEROGLYPH A337","	= pithos"},
/* 1457F */ { "ANATOLIAN HIEROGLYPH A338","	= culter"},
/* 14580 */ { "ANATOLIAN HIEROGLYPH A339",NULL},
/* 14581 */ { "ANATOLIAN HIEROGLYPH A340","	= annus+annus"},
/* 14582 */ { "ANATOLIAN HIEROGLYPH A341","	= vas"},
/* 14583 */ { "ANATOLIAN HIEROGLYPH A342",NULL},
/* 14584 */ { "ANATOLIAN HIEROGLYPH A343","	= pithos"},
/* 14585 */ { "ANATOLIAN HIEROGLYPH A344","	= contractus"},
/* 14586 */ { "ANATOLIAN HIEROGLYPH A345","	= urceus"},
/* 14587 */ { "ANATOLIAN HIEROGLYPH A346","	= poculum"},
/* 14588 */ { "ANATOLIAN HIEROGLYPH A347","	= syllabic hú"},
/* 14589 */ { "ANATOLIAN HIEROGLYPH A348",NULL},
/* 1458A */ { "ANATOLIAN HIEROGLYPH A349",NULL},
/* 1458B */ { "ANATOLIAN HIEROGLYPH A350",NULL},
/* 1458C */ { "ANATOLIAN HIEROGLYPH A351",NULL},
/* 1458D */ { "ANATOLIAN HIEROGLYPH A352",NULL},
/* 1458E */ { "ANATOLIAN HIEROGLYPH A353",NULL},
/* 1458F */ { "ANATOLIAN HIEROGLYPH A354",NULL},
/* 14590 */ { "ANATOLIAN HIEROGLYPH A355","	= sacerdos"},
/* 14591 */ { "ANATOLIAN HIEROGLYPH A356",NULL},
/* 14592 */ { "ANATOLIAN HIEROGLYPH A357",NULL},
/* 14593 */ { "ANATOLIAN HIEROGLYPH A358","	= dies"},
/* 14594 */ { "ANATOLIAN HIEROGLYPH A359",NULL},
/* 14595 */ { "ANATOLIAN HIEROGLYPH A359A",NULL},
/* 14596 */ { "ANATOLIAN HIEROGLYPH A360","	= deus"},
/* 14597 */ { "ANATOLIAN HIEROGLYPH A361",NULL},
/* 14598 */ { "ANATOLIAN HIEROGLYPH A362","	= syllabic má"},
/* 14599 */ { "ANATOLIAN HIEROGLYPH A363","	= magnus\n"
	"	= syllabic ur"},
/* 1459A */ { "ANATOLIAN HIEROGLYPH A364","	= syllabic u"},
/* 1459B */ { "ANATOLIAN HIEROGLYPH A364A","	= syllabic mu"},
/* 1459C */ { "ANATOLIAN HIEROGLYPH A365",NULL},
/* 1459D */ { "ANATOLIAN HIEROGLYPH A366","	= omnis(+mi)"},
/* 1459E */ { "ANATOLIAN HIEROGLYPH A367","	= logosyllabic tala"},
/* 1459F */ { "ANATOLIAN HIEROGLYPH A368","	= malus"},
/* 145A0 */ { "ANATOLIAN HIEROGLYPH A368A","	= malus2"},
/* 145A1 */ { "ANATOLIAN HIEROGLYPH A369","	= vita"},
/* 145A2 */ { "ANATOLIAN HIEROGLYPH A370","	= bonus2\n"
	"	= syllabic su"},
/* 145A3 */ { "ANATOLIAN HIEROGLYPH A371","	= iustitia, iudex"},
/* 145A4 */ { "ANATOLIAN HIEROGLYPH A371A","	= iudex+ra/i, tara/i-x\n"
	"	* 145A3 anatolian hieroglyph a371 + 145B1 anatolian hieroglyph a383 ra or ri"},
/* 145A5 */ { "ANATOLIAN HIEROGLYPH A372","	= sacerdos2"},
/* 145A6 */ { "ANATOLIAN HIEROGLYPH A373",NULL},
/* 145A7 */ { "ANATOLIAN HIEROGLYPH A374",NULL},
/* 145A8 */ { "ANATOLIAN HIEROGLYPH A375",NULL},
/* 145A9 */ { "ANATOLIAN HIEROGLYPH A376","	= syllabic zi, zi/a"},
/* 145AA */ { "ANATOLIAN HIEROGLYPH A377","	= syllabic za"},
/* 145AB */ { "ANATOLIAN HIEROGLYPH A378","	= lituus"},
/* 145AC */ { "ANATOLIAN HIEROGLYPH A379","	= occidens\n"
	"	= syllabic ià"},
/* 145AD */ { "ANATOLIAN HIEROGLYPH A380","	= one\n"
	"	= unus\n"
	"	= syllabic sa8"},
/* 145AE */ { "ANATOLIAN HIEROGLYPH A381","	= minus"},
/* 145AF */ { "ANATOLIAN HIEROGLYPH A381A","	= mori, vir2.minus"},
/* 145B0 */ { "ANATOLIAN HIEROGLYPH A382","	= lignum"},
/* 145B1 */ { "ANATOLIAN HIEROGLYPH A383 RA OR RI","	x (anatolian hieroglyph a134 - 144A0)\n"
	"	x (anatolian hieroglyph a209a - 144F0)\n"
	"	x (anatolian hieroglyph a290 - 14546)\n"
	"	x (anatolian hieroglyph a303 - 14555)\n"
	"	x (anatolian hieroglyph a315 - 14562)\n"
	"	x (anatolian hieroglyph a371a - 145A4)\n"
	"	x (anatolian hieroglyph a389 - 145B9)\n"
	"	x (anatolian hieroglyph a450a - 145F8)"},
/* 145B2 */ { "ANATOLIAN HIEROGLYPH A383A","	= personal determinative"},
/* 145B3 */ { "ANATOLIAN HIEROGLYPH A384","	= two"},
/* 145B4 */ { "ANATOLIAN HIEROGLYPH A385","	= two"},
/* 145B5 */ { "ANATOLIAN HIEROGLYPH A386","	= vir2\n"
	"	= word divider"},
/* 145B6 */ { "ANATOLIAN HIEROGLYPH A386A","	= vir2a"},
/* 145B7 */ { "ANATOLIAN HIEROGLYPH A387","	= servus\n"
	"	= syllabic mì"},
/* 145B8 */ { "ANATOLIAN HIEROGLYPH A388","	= three\n"
	"	= tara/i"},
/* 145B9 */ { "ANATOLIAN HIEROGLYPH A389","	= tara/i\n"
	"	* 145B8 anatolian hieroglyph a388 + 145B1 anatolian hieroglyph a383 ra or ri"},
/* 145BA */ { "ANATOLIAN HIEROGLYPH A390","	= dominus"},
/* 145BB */ { "ANATOLIAN HIEROGLYPH A391","	= four\n"
	"	= syllabic mi"},
/* 145BC */ { "ANATOLIAN HIEROGLYPH A392","	= five"},
/* 145BD */ { "ANATOLIAN HIEROGLYPH A393 EIGHT","	= eight\n"
	"	* the occurrence of \"EIGHT\" in the name of this character is a known anomaly"},
/* 145BE */ { "ANATOLIAN HIEROGLYPH A394",NULL},
/* 145BF */ { "ANATOLIAN HIEROGLYPH A395","	= nine\n"
	"	= syllabic nú"},
/* 145C0 */ { "ANATOLIAN HIEROGLYPH A396",NULL},
/* 145C1 */ { "ANATOLIAN HIEROGLYPH A397","	= ten\n"
	"	= decem"},
/* 145C2 */ { "ANATOLIAN HIEROGLYPH A398",NULL},
/* 145C3 */ { "ANATOLIAN HIEROGLYPH A399","	= hundred\n"
	"	= centum"},
/* 145C4 */ { "ANATOLIAN HIEROGLYPH A400","	= thousand\n"
	"	= mille"},
/* 145C5 */ { "ANATOLIAN HIEROGLYPH A401",NULL},
/* 145C6 */ { "ANATOLIAN HIEROGLYPH A402","	= scutella\n"
	"	= syllabic sa4"},
/* 145C7 */ { "ANATOLIAN HIEROGLYPH A403",NULL},
/* 145C8 */ { "ANATOLIAN HIEROGLYPH A404","	= animal"},
/* 145C9 */ { "ANATOLIAN HIEROGLYPH A405",NULL},
/* 145CA */ { "ANATOLIAN HIEROGLYPH A406",NULL},
/* 145CB */ { "ANATOLIAN HIEROGLYPH A407",NULL},
/* 145CC */ { "ANATOLIAN HIEROGLYPH A408",NULL},
/* 145CD */ { "ANATOLIAN HIEROGLYPH A409",NULL},
/* 145CE */ { "ANATOLIAN HIEROGLYPH A410 BEGIN LOGOGRAM MARK",NULL},
/* 145CF */ { "ANATOLIAN HIEROGLYPH A410A END LOGOGRAM MARK",NULL},
/* 145D0 */ { "ANATOLIAN HIEROGLYPH A411","	= syllabic ni"},
/* 145D1 */ { "ANATOLIAN HIEROGLYPH A412","	= syllabic ru"},
/* 145D2 */ { "ANATOLIAN HIEROGLYPH A413","	= syllabic hi"},
/* 145D3 */ { "ANATOLIAN HIEROGLYPH A414",NULL},
/* 145D4 */ { "ANATOLIAN HIEROGLYPH A415","	= syllabic sa"},
/* 145D5 */ { "ANATOLIAN HIEROGLYPH A416",NULL},
/* 145D6 */ { "ANATOLIAN HIEROGLYPH A417","	= syllabic sa-x"},
/* 145D7 */ { "ANATOLIAN HIEROGLYPH A418",NULL},
/* 145D8 */ { "ANATOLIAN HIEROGLYPH A419","	= syllabic mí\n"
	"	= logosyllabic urhi"},
/* 145D9 */ { "ANATOLIAN HIEROGLYPH A420",NULL},
/* 145DA */ { "ANATOLIAN HIEROGLYPH A421","	= syllabic us"},
/* 145DB */ { "ANATOLIAN HIEROGLYPH A422","	= panis.scutella"},
/* 145DC */ { "ANATOLIAN HIEROGLYPH A423","	= syllabic ku"},
/* 145DD */ { "ANATOLIAN HIEROGLYPH A424",NULL},
/* 145DE */ { "ANATOLIAN HIEROGLYPH A425",NULL},
/* 145DF */ { "ANATOLIAN HIEROGLYPH A426",NULL},
/* 145E0 */ { "ANATOLIAN HIEROGLYPH A427",NULL},
/* 145E1 */ { "ANATOLIAN HIEROGLYPH A428",NULL},
/* 145E2 */ { "ANATOLIAN HIEROGLYPH A429","	= syllabic tana"},
/* 145E3 */ { "ANATOLIAN HIEROGLYPH A430","	= omnis2\n"
	"	= syllabic pú"},
/* 145E4 */ { "ANATOLIAN HIEROGLYPH A431",NULL},
/* 145E5 */ { "ANATOLIAN HIEROGLYPH A432","	= syllabic zu?"},
/* 145E6 */ { "ANATOLIAN HIEROGLYPH A433","	= syllabic sá"},
/* 145E7 */ { "ANATOLIAN HIEROGLYPH A434","	= syllabic ka"},
/* 145E8 */ { "ANATOLIAN HIEROGLYPH A435","	= syllabic a-x?"},
/* 145E9 */ { "ANATOLIAN HIEROGLYPH A436",NULL},
/* 145EA */ { "ANATOLIAN HIEROGLYPH A437",NULL},
/* 145EB */ { "ANATOLIAN HIEROGLYPH A438","	= pastor"},
/* 145EC */ { "ANATOLIAN HIEROGLYPH A439","	= syllabic wa/i"},
/* 145ED */ { "ANATOLIAN HIEROGLYPH A440",NULL},
/* 145EE */ { "ANATOLIAN HIEROGLYPH A441",NULL},
/* 145EF */ { "ANATOLIAN HIEROGLYPH A442",NULL},
/* 145F0 */ { "ANATOLIAN HIEROGLYPH A443",NULL},
/* 145F1 */ { "ANATOLIAN HIEROGLYPH A444",NULL},
/* 145F2 */ { "ANATOLIAN HIEROGLYPH A445","	= syllabic la, li, lu"},
/* 145F3 */ { "ANATOLIAN HIEROGLYPH A446","	= syllabic ki"},
/* 145F4 */ { "ANATOLIAN HIEROGLYPH A447","	= syllabic ni-x"},
/* 145F5 */ { "ANATOLIAN HIEROGLYPH A448","	= syllabic sù?, zú?"},
/* 145F6 */ { "ANATOLIAN HIEROGLYPH A449",NULL},
/* 145F7 */ { "ANATOLIAN HIEROGLYPH A450","	= syllabic a\n"
	"	= end of a word"},
/* 145F8 */ { "ANATOLIAN HIEROGLYPH A450A","	= a+ra/i, ra+a\n"
	"	* 145F7 anatolian hieroglyph a450 + 145B1 anatolian hieroglyph a383 ra or ri"},
/* 145F9 */ { "ANATOLIAN HIEROGLYPH A451","	= logosyllabic huru"},
/* 145FA */ { "ANATOLIAN HIEROGLYPH A452",NULL},
/* 145FB */ { "ANATOLIAN HIEROGLYPH A453",NULL},
/* 145FC */ { "ANATOLIAN HIEROGLYPH A454",NULL},
/* 145FD */ { "ANATOLIAN HIEROGLYPH A455","	= syllabic la-x"},
/* 145FE */ { "ANATOLIAN HIEROGLYPH A456","	= syllabic sí?"},
/* 145FF */ { "ANATOLIAN HIEROGLYPH A457",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_46[] = {
/* 14600 */ { "ANATOLIAN HIEROGLYPH A457A",NULL},
/* 14601 */ { "ANATOLIAN HIEROGLYPH A458",NULL},
/* 14602 */ { "ANATOLIAN HIEROGLYPH A459",NULL},
/* 14603 */ { "ANATOLIAN HIEROGLYPH A460",NULL},
/* 14604 */ { "ANATOLIAN HIEROGLYPH A461",NULL},
/* 14605 */ { "ANATOLIAN HIEROGLYPH A462","	= syllabic ma-x?"},
/* 14606 */ { "ANATOLIAN HIEROGLYPH A463",NULL},
/* 14607 */ { "ANATOLIAN HIEROGLYPH A464",NULL},
/* 14608 */ { "ANATOLIAN HIEROGLYPH A465",NULL},
/* 14609 */ { "ANATOLIAN HIEROGLYPH A466",NULL},
/* 1460A */ { "ANATOLIAN HIEROGLYPH A467",NULL},
/* 1460B */ { "ANATOLIAN HIEROGLYPH A468",NULL},
/* 1460C */ { "ANATOLIAN HIEROGLYPH A469",NULL},
/* 1460D */ { "ANATOLIAN HIEROGLYPH A470","	= twelve"},
/* 1460E */ { "ANATOLIAN HIEROGLYPH A471",NULL},
/* 1460F */ { "ANATOLIAN HIEROGLYPH A472",NULL},
/* 14610 */ { "ANATOLIAN HIEROGLYPH A473",NULL},
/* 14611 */ { "ANATOLIAN HIEROGLYPH A474","	= eunuchus"},
/* 14612 */ { "ANATOLIAN HIEROGLYPH A475",NULL},
/* 14613 */ { "ANATOLIAN HIEROGLYPH A476",NULL},
/* 14614 */ { "ANATOLIAN HIEROGLYPH A477","	= flammae?"},
/* 14615 */ { "ANATOLIAN HIEROGLYPH A478",NULL},
/* 14616 */ { "ANATOLIAN HIEROGLYPH A479",NULL},
/* 14617 */ { "ANATOLIAN HIEROGLYPH A480",NULL},
/* 14618 */ { "ANATOLIAN HIEROGLYPH A481",NULL},
/* 14619 */ { "ANATOLIAN HIEROGLYPH A482",NULL},
/* 1461A */ { "ANATOLIAN HIEROGLYPH A483",NULL},
/* 1461B */ { "ANATOLIAN HIEROGLYPH A484",NULL},
/* 1461C */ { "ANATOLIAN HIEROGLYPH A485",NULL},
/* 1461D */ { "ANATOLIAN HIEROGLYPH A486","	= falx?"},
/* 1461E */ { "ANATOLIAN HIEROGLYPH A487",NULL},
/* 1461F */ { "ANATOLIAN HIEROGLYPH A488","	= syllabic tí"},
/* 14620 */ { "ANATOLIAN HIEROGLYPH A489",NULL},
/* 14621 */ { "ANATOLIAN HIEROGLYPH A490",NULL},
/* 14622 */ { "ANATOLIAN HIEROGLYPH A491",NULL},
/* 14623 */ { "ANATOLIAN HIEROGLYPH A492",NULL},
/* 14624 */ { "ANATOLIAN HIEROGLYPH A493",NULL},
/* 14625 */ { "ANATOLIAN HIEROGLYPH A494",NULL},
/* 14626 */ { "ANATOLIAN HIEROGLYPH A495",NULL},
/* 14627 */ { "ANATOLIAN HIEROGLYPH A496",NULL},
/* 14628 */ { "ANATOLIAN HIEROGLYPH A497",NULL},
/* 14629 */ { "ANATOLIAN HIEROGLYPH A501",NULL},
/* 1462A */ { "ANATOLIAN HIEROGLYPH A502",NULL},
/* 1462B */ { "ANATOLIAN HIEROGLYPH A503",NULL},
/* 1462C */ { "ANATOLIAN HIEROGLYPH A504",NULL},
/* 1462D */ { "ANATOLIAN HIEROGLYPH A505",NULL},
/* 1462E */ { "ANATOLIAN HIEROGLYPH A506","	= syllabic hana"},
/* 1462F */ { "ANATOLIAN HIEROGLYPH A507",NULL},
/* 14630 */ { "ANATOLIAN HIEROGLYPH A508","	= currere\n"
	"	= syllabic hwi/a"},
/* 14631 */ { "ANATOLIAN HIEROGLYPH A509",NULL},
/* 14632 */ { "ANATOLIAN HIEROGLYPH A510",NULL},
/* 14633 */ { "ANATOLIAN HIEROGLYPH A511",NULL},
/* 14634 */ { "ANATOLIAN HIEROGLYPH A512",NULL},
/* 14635 */ { "ANATOLIAN HIEROGLYPH A513",NULL},
/* 14636 */ { "ANATOLIAN HIEROGLYPH A514",NULL},
/* 14637 */ { "ANATOLIAN HIEROGLYPH A515",NULL},
/* 14638 */ { "ANATOLIAN HIEROGLYPH A516",NULL},
/* 14639 */ { "ANATOLIAN HIEROGLYPH A517",NULL},
/* 1463A */ { "ANATOLIAN HIEROGLYPH A518",NULL},
/* 1463B */ { "ANATOLIAN HIEROGLYPH A519",NULL},
/* 1463C */ { "ANATOLIAN HIEROGLYPH A520",NULL},
/* 1463D */ { "ANATOLIAN HIEROGLYPH A521",NULL},
/* 1463E */ { "ANATOLIAN HIEROGLYPH A522",NULL},
/* 1463F */ { "ANATOLIAN HIEROGLYPH A523",NULL},
/* 14640 */ { "ANATOLIAN HIEROGLYPH A524","	= propheta?, cornu+caput"},
/* 14641 */ { "ANATOLIAN HIEROGLYPH A525","	= princeps"},
/* 14642 */ { "ANATOLIAN HIEROGLYPH A526","	= Güterbock G195"},
/* 14643 */ { "ANATOLIAN HIEROGLYPH A527","	= aper"},
/* 14644 */ { "ANATOLIAN HIEROGLYPH A528","	= tì"},
/* 14645 */ { "ANATOLIAN HIEROGLYPH A529","	= lingua+x"},
/* 14646 */ { "ANATOLIAN HIEROGLYPH A530",NULL},
/* 14647 */ { NULL,NULL},
/* 14648 */ { NULL,NULL},
/* 14649 */ { NULL,NULL},
/* 1464A */ { NULL,NULL},
/* 1464B */ { NULL,NULL},
/* 1464C */ { NULL,NULL},
/* 1464D */ { NULL,NULL},
/* 1464E */ { NULL,NULL},
/* 1464F */ { NULL,NULL},
/* 14650 */ { NULL,NULL},
/* 14651 */ { NULL,NULL},
/* 14652 */ { NULL,NULL},
/* 14653 */ { NULL,NULL},
/* 14654 */ { NULL,NULL},
/* 14655 */ { NULL,NULL},
/* 14656 */ { NULL,NULL},
/* 14657 */ { NULL,NULL},
/* 14658 */ { NULL,NULL},
/* 14659 */ { NULL,NULL},
/* 1465A */ { NULL,NULL},
/* 1465B */ { NULL,NULL},
/* 1465C */ { NULL,NULL},
/* 1465D */ { NULL,NULL},
/* 1465E */ { NULL,NULL},
/* 1465F */ { NULL,NULL},
/* 14660 */ { NULL,NULL},
/* 14661 */ { NULL,NULL},
/* 14662 */ { NULL,NULL},
/* 14663 */ { NULL,NULL},
/* 14664 */ { NULL,NULL},
/* 14665 */ { NULL,NULL},
/* 14666 */ { NULL,NULL},
/* 14667 */ { NULL,NULL},
/* 14668 */ { NULL,NULL},
/* 14669 */ { NULL,NULL},
/* 1466A */ { NULL,NULL},
/* 1466B */ { NULL,NULL},
/* 1466C */ { NULL,NULL},
/* 1466D */ { NULL,NULL},
/* 1466E */ { NULL,NULL},
/* 1466F */ { NULL,NULL},
/* 14670 */ { NULL,NULL},
/* 14671 */ { NULL,NULL},
/* 14672 */ { NULL,NULL},
/* 14673 */ { NULL,NULL},
/* 14674 */ { NULL,NULL},
/* 14675 */ { NULL,NULL},
/* 14676 */ { NULL,NULL},
/* 14677 */ { NULL,NULL},
/* 14678 */ { NULL,NULL},
/* 14679 */ { NULL,NULL},
/* 1467A */ { NULL,NULL},
/* 1467B */ { NULL,NULL},
/* 1467C */ { NULL,NULL},
/* 1467D */ { NULL,NULL},
/* 1467E */ { NULL,NULL},
/* 1467F */ { NULL,NULL},
/* 14680 */ { NULL,NULL},
/* 14681 */ { NULL,NULL},
/* 14682 */ { NULL,NULL},
/* 14683 */ { NULL,NULL},
/* 14684 */ { NULL,NULL},
/* 14685 */ { NULL,NULL},
/* 14686 */ { NULL,NULL},
/* 14687 */ { NULL,NULL},
/* 14688 */ { NULL,NULL},
/* 14689 */ { NULL,NULL},
/* 1468A */ { NULL,NULL},
/* 1468B */ { NULL,NULL},
/* 1468C */ { NULL,NULL},
/* 1468D */ { NULL,NULL},
/* 1468E */ { NULL,NULL},
/* 1468F */ { NULL,NULL},
/* 14690 */ { NULL,NULL},
/* 14691 */ { NULL,NULL},
/* 14692 */ { NULL,NULL},
/* 14693 */ { NULL,NULL},
/* 14694 */ { NULL,NULL},
/* 14695 */ { NULL,NULL},
/* 14696 */ { NULL,NULL},
/* 14697 */ { NULL,NULL},
/* 14698 */ { NULL,NULL},
/* 14699 */ { NULL,NULL},
/* 1469A */ { NULL,NULL},
/* 1469B */ { NULL,NULL},
/* 1469C */ { NULL,NULL},
/* 1469D */ { NULL,NULL},
/* 1469E */ { NULL,NULL},
/* 1469F */ { NULL,NULL},
/* 146A0 */ { NULL,NULL},
/* 146A1 */ { NULL,NULL},
/* 146A2 */ { NULL,NULL},
/* 146A3 */ { NULL,NULL},
/* 146A4 */ { NULL,NULL},
/* 146A5 */ { NULL,NULL},
/* 146A6 */ { NULL,NULL},
/* 146A7 */ { NULL,NULL},
/* 146A8 */ { NULL,NULL},
/* 146A9 */ { NULL,NULL},
/* 146AA */ { NULL,NULL},
/* 146AB */ { NULL,NULL},
/* 146AC */ { NULL,NULL},
/* 146AD */ { NULL,NULL},
/* 146AE */ { NULL,NULL},
/* 146AF */ { NULL,NULL},
/* 146B0 */ { NULL,NULL},
/* 146B1 */ { NULL,NULL},
/* 146B2 */ { NULL,NULL},
/* 146B3 */ { NULL,NULL},
/* 146B4 */ { NULL,NULL},
/* 146B5 */ { NULL,NULL},
/* 146B6 */ { NULL,NULL},
/* 146B7 */ { NULL,NULL},
/* 146B8 */ { NULL,NULL},
/* 146B9 */ { NULL,NULL},
/* 146BA */ { NULL,NULL},
/* 146BB */ { NULL,NULL},
/* 146BC */ { NULL,NULL},
/* 146BD */ { NULL,NULL},
/* 146BE */ { NULL,NULL},
/* 146BF */ { NULL,NULL},
/* 146C0 */ { NULL,NULL},
/* 146C1 */ { NULL,NULL},
/* 146C2 */ { NULL,NULL},
/* 146C3 */ { NULL,NULL},
/* 146C4 */ { NULL,NULL},
/* 146C5 */ { NULL,NULL},
/* 146C6 */ { NULL,NULL},
/* 146C7 */ { NULL,NULL},
/* 146C8 */ { NULL,NULL},
/* 146C9 */ { NULL,NULL},
/* 146CA */ { NULL,NULL},
/* 146CB */ { NULL,NULL},
/* 146CC */ { NULL,NULL},
/* 146CD */ { NULL,NULL},
/* 146CE */ { NULL,NULL},
/* 146CF */ { NULL,NULL},
/* 146D0 */ { NULL,NULL},
/* 146D1 */ { NULL,NULL},
/* 146D2 */ { NULL,NULL},
/* 146D3 */ { NULL,NULL},
/* 146D4 */ { NULL,NULL},
/* 146D5 */ { NULL,NULL},
/* 146D6 */ { NULL,NULL},
/* 146D7 */ { NULL,NULL},
/* 146D8 */ { NULL,NULL},
/* 146D9 */ { NULL,NULL},
/* 146DA */ { NULL,NULL},
/* 146DB */ { NULL,NULL},
/* 146DC */ { NULL,NULL},
/* 146DD */ { NULL,NULL},
/* 146DE */ { NULL,NULL},
/* 146DF */ { NULL,NULL},
/* 146E0 */ { NULL,NULL},
/* 146E1 */ { NULL,NULL},
/* 146E2 */ { NULL,NULL},
/* 146E3 */ { NULL,NULL},
/* 146E4 */ { NULL,NULL},
/* 146E5 */ { NULL,NULL},
/* 146E6 */ { NULL,NULL},
/* 146E7 */ { NULL,NULL},
/* 146E8 */ { NULL,NULL},
/* 146E9 */ { NULL,NULL},
/* 146EA */ { NULL,NULL},
/* 146EB */ { NULL,NULL},
/* 146EC */ { NULL,NULL},
/* 146ED */ { NULL,NULL},
/* 146EE */ { NULL,NULL},
/* 146EF */ { NULL,NULL},
/* 146F0 */ { NULL,NULL},
/* 146F1 */ { NULL,NULL},
/* 146F2 */ { NULL,NULL},
/* 146F3 */ { NULL,NULL},
/* 146F4 */ { NULL,NULL},
/* 146F5 */ { NULL,NULL},
/* 146F6 */ { NULL,NULL},
/* 146F7 */ { NULL,NULL},
/* 146F8 */ { NULL,NULL},
/* 146F9 */ { NULL,NULL},
/* 146FA */ { NULL,NULL},
/* 146FB */ { NULL,NULL},
/* 146FC */ { NULL,NULL},
/* 146FD */ { NULL,NULL},
/* 146FE */ { NULL,NULL},
/* 146FF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_61[] = {
/* 16100 */ { "GURUNG KHEMA LETTER A",NULL},
/* 16101 */ { "GURUNG KHEMA LETTER KA",NULL},
/* 16102 */ { "GURUNG KHEMA LETTER KHA",NULL},
/* 16103 */ { "GURUNG KHEMA LETTER GA",NULL},
/* 16104 */ { "GURUNG KHEMA LETTER GHA",NULL},
/* 16105 */ { "GURUNG KHEMA LETTER NGA",NULL},
/* 16106 */ { "GURUNG KHEMA LETTER CA",NULL},
/* 16107 */ { "GURUNG KHEMA LETTER CHA",NULL},
/* 16108 */ { "GURUNG KHEMA LETTER JA",NULL},
/* 16109 */ { "GURUNG KHEMA LETTER JHA",NULL},
/* 1610A */ { "GURUNG KHEMA LETTER HA",NULL},
/* 1610B */ { "GURUNG KHEMA LETTER TTA",NULL},
/* 1610C */ { "GURUNG KHEMA LETTER TTHA",NULL},
/* 1610D */ { "GURUNG KHEMA LETTER DDA",NULL},
/* 1610E */ { "GURUNG KHEMA LETTER DDHA",NULL},
/* 1610F */ { "GURUNG KHEMA LETTER VA",NULL},
/* 16110 */ { "GURUNG KHEMA LETTER TA",NULL},
/* 16111 */ { "GURUNG KHEMA LETTER THA",NULL},
/* 16112 */ { "GURUNG KHEMA LETTER DA",NULL},
/* 16113 */ { "GURUNG KHEMA LETTER DHA",NULL},
/* 16114 */ { "GURUNG KHEMA LETTER NA",NULL},
/* 16115 */ { "GURUNG KHEMA LETTER PA",NULL},
/* 16116 */ { "GURUNG KHEMA LETTER PHA",NULL},
/* 16117 */ { "GURUNG KHEMA LETTER BA",NULL},
/* 16118 */ { "GURUNG KHEMA LETTER BHA",NULL},
/* 16119 */ { "GURUNG KHEMA LETTER MA",NULL},
/* 1611A */ { "GURUNG KHEMA LETTER YA",NULL},
/* 1611B */ { "GURUNG KHEMA LETTER RA",NULL},
/* 1611C */ { "GURUNG KHEMA LETTER LA",NULL},
/* 1611D */ { "GURUNG KHEMA LETTER SA",NULL},
/* 1611E */ { "GURUNG KHEMA VOWEL SIGN AA",NULL},
/* 1611F */ { "GURUNG KHEMA VOWEL SIGN I",NULL},
/* 16120 */ { "GURUNG KHEMA VOWEL SIGN II",NULL},
/* 16121 */ { "GURUNG KHEMA VOWEL SIGN U","	: 1611E 1611E"},
/* 16122 */ { "GURUNG KHEMA VOWEL SIGN UU","	: 1611E 16129"},
/* 16123 */ { "GURUNG KHEMA VOWEL SIGN E","	: 1611E 1611F"},
/* 16124 */ { "GURUNG KHEMA VOWEL SIGN EE","	: 16129 1611F"},
/* 16125 */ { "GURUNG KHEMA VOWEL SIGN AI","	: 1611E 16120"},
/* 16126 */ { "GURUNG KHEMA VOWEL SIGN O","	: 16121 1611F"},
/* 16127 */ { "GURUNG KHEMA VOWEL SIGN OO","	: 16122 1611F"},
/* 16128 */ { "GURUNG KHEMA VOWEL SIGN AU","	: 16121 16120"},
/* 16129 */ { "GURUNG KHEMA VOWEL LENGTH MARK",NULL},
/* 1612A */ { "GURUNG KHEMA CONSONANT SIGN MEDIAL YA",NULL},
/* 1612B */ { "GURUNG KHEMA CONSONANT SIGN MEDIAL VA",NULL},
/* 1612C */ { "GURUNG KHEMA CONSONANT SIGN MEDIAL HA",NULL},
/* 1612D */ { "GURUNG KHEMA SIGN ANUSVARA",NULL},
/* 1612E */ { "GURUNG KHEMA CONSONANT SIGN MEDIAL RA",NULL},
/* 1612F */ { "GURUNG KHEMA SIGN THOLHOMA",NULL},
/* 16130 */ { "GURUNG KHEMA DIGIT ZERO",NULL},
/* 16131 */ { "GURUNG KHEMA DIGIT ONE",NULL},
/* 16132 */ { "GURUNG KHEMA DIGIT TWO",NULL},
/* 16133 */ { "GURUNG KHEMA DIGIT THREE",NULL},
/* 16134 */ { "GURUNG KHEMA DIGIT FOUR",NULL},
/* 16135 */ { "GURUNG KHEMA DIGIT FIVE",NULL},
/* 16136 */ { "GURUNG KHEMA DIGIT SIX",NULL},
/* 16137 */ { "GURUNG KHEMA DIGIT SEVEN",NULL},
/* 16138 */ { "GURUNG KHEMA DIGIT EIGHT",NULL},
/* 16139 */ { "GURUNG KHEMA DIGIT NINE",NULL},
/* 1613A */ { NULL,NULL},
/* 1613B */ { NULL,NULL},
/* 1613C */ { NULL,NULL},
/* 1613D */ { NULL,NULL},
/* 1613E */ { NULL,NULL},
/* 1613F */ { NULL,NULL},
/* 16140 */ { NULL,NULL},
/* 16141 */ { NULL,NULL},
/* 16142 */ { NULL,NULL},
/* 16143 */ { NULL,NULL},
/* 16144 */ { NULL,NULL},
/* 16145 */ { NULL,NULL},
/* 16146 */ { NULL,NULL},
/* 16147 */ { NULL,NULL},
/* 16148 */ { NULL,NULL},
/* 16149 */ { NULL,NULL},
/* 1614A */ { NULL,NULL},
/* 1614B */ { NULL,NULL},
/* 1614C */ { NULL,NULL},
/* 1614D */ { NULL,NULL},
/* 1614E */ { NULL,NULL},
/* 1614F */ { NULL,NULL},
/* 16150 */ { NULL,NULL},
/* 16151 */ { NULL,NULL},
/* 16152 */ { NULL,NULL},
/* 16153 */ { NULL,NULL},
/* 16154 */ { NULL,NULL},
/* 16155 */ { NULL,NULL},
/* 16156 */ { NULL,NULL},
/* 16157 */ { NULL,NULL},
/* 16158 */ { NULL,NULL},
/* 16159 */ { NULL,NULL},
/* 1615A */ { NULL,NULL},
/* 1615B */ { NULL,NULL},
/* 1615C */ { NULL,NULL},
/* 1615D */ { NULL,NULL},
/* 1615E */ { NULL,NULL},
/* 1615F */ { NULL,NULL},
/* 16160 */ { NULL,NULL},
/* 16161 */ { NULL,NULL},
/* 16162 */ { NULL,NULL},
/* 16163 */ { NULL,NULL},
/* 16164 */ { NULL,NULL},
/* 16165 */ { NULL,NULL},
/* 16166 */ { NULL,NULL},
/* 16167 */ { NULL,NULL},
/* 16168 */ { NULL,NULL},
/* 16169 */ { NULL,NULL},
/* 1616A */ { NULL,NULL},
/* 1616B */ { NULL,NULL},
/* 1616C */ { NULL,NULL},
/* 1616D */ { NULL,NULL},
/* 1616E */ { NULL,NULL},
/* 1616F */ { NULL,NULL},
/* 16170 */ { NULL,NULL},
/* 16171 */ { NULL,NULL},
/* 16172 */ { NULL,NULL},
/* 16173 */ { NULL,NULL},
/* 16174 */ { NULL,NULL},
/* 16175 */ { NULL,NULL},
/* 16176 */ { NULL,NULL},
/* 16177 */ { NULL,NULL},
/* 16178 */ { NULL,NULL},
/* 16179 */ { NULL,NULL},
/* 1617A */ { NULL,NULL},
/* 1617B */ { NULL,NULL},
/* 1617C */ { NULL,NULL},
/* 1617D */ { NULL,NULL},
/* 1617E */ { NULL,NULL},
/* 1617F */ { NULL,NULL},
/* 16180 */ { NULL,NULL},
/* 16181 */ { NULL,NULL},
/* 16182 */ { NULL,NULL},
/* 16183 */ { NULL,NULL},
/* 16184 */ { NULL,NULL},
/* 16185 */ { NULL,NULL},
/* 16186 */ { NULL,NULL},
/* 16187 */ { NULL,NULL},
/* 16188 */ { NULL,NULL},
/* 16189 */ { NULL,NULL},
/* 1618A */ { NULL,NULL},
/* 1618B */ { NULL,NULL},
/* 1618C */ { NULL,NULL},
/* 1618D */ { NULL,NULL},
/* 1618E */ { NULL,NULL},
/* 1618F */ { NULL,NULL},
/* 16190 */ { NULL,NULL},
/* 16191 */ { NULL,NULL},
/* 16192 */ { NULL,NULL},
/* 16193 */ { NULL,NULL},
/* 16194 */ { NULL,NULL},
/* 16195 */ { NULL,NULL},
/* 16196 */ { NULL,NULL},
/* 16197 */ { NULL,NULL},
/* 16198 */ { NULL,NULL},
/* 16199 */ { NULL,NULL},
/* 1619A */ { NULL,NULL},
/* 1619B */ { NULL,NULL},
/* 1619C */ { NULL,NULL},
/* 1619D */ { NULL,NULL},
/* 1619E */ { NULL,NULL},
/* 1619F */ { NULL,NULL},
/* 161A0 */ { NULL,NULL},
/* 161A1 */ { NULL,NULL},
/* 161A2 */ { NULL,NULL},
/* 161A3 */ { NULL,NULL},
/* 161A4 */ { NULL,NULL},
/* 161A5 */ { NULL,NULL},
/* 161A6 */ { NULL,NULL},
/* 161A7 */ { NULL,NULL},
/* 161A8 */ { NULL,NULL},
/* 161A9 */ { NULL,NULL},
/* 161AA */ { NULL,NULL},
/* 161AB */ { NULL,NULL},
/* 161AC */ { NULL,NULL},
/* 161AD */ { NULL,NULL},
/* 161AE */ { NULL,NULL},
/* 161AF */ { NULL,NULL},
/* 161B0 */ { NULL,NULL},
/* 161B1 */ { NULL,NULL},
/* 161B2 */ { NULL,NULL},
/* 161B3 */ { NULL,NULL},
/* 161B4 */ { NULL,NULL},
/* 161B5 */ { NULL,NULL},
/* 161B6 */ { NULL,NULL},
/* 161B7 */ { NULL,NULL},
/* 161B8 */ { NULL,NULL},
/* 161B9 */ { NULL,NULL},
/* 161BA */ { NULL,NULL},
/* 161BB */ { NULL,NULL},
/* 161BC */ { NULL,NULL},
/* 161BD */ { NULL,NULL},
/* 161BE */ { NULL,NULL},
/* 161BF */ { NULL,NULL},
/* 161C0 */ { NULL,NULL},
/* 161C1 */ { NULL,NULL},
/* 161C2 */ { NULL,NULL},
/* 161C3 */ { NULL,NULL},
/* 161C4 */ { NULL,NULL},
/* 161C5 */ { NULL,NULL},
/* 161C6 */ { NULL,NULL},
/* 161C7 */ { NULL,NULL},
/* 161C8 */ { NULL,NULL},
/* 161C9 */ { NULL,NULL},
/* 161CA */ { NULL,NULL},
/* 161CB */ { NULL,NULL},
/* 161CC */ { NULL,NULL},
/* 161CD */ { NULL,NULL},
/* 161CE */ { NULL,NULL},
/* 161CF */ { NULL,NULL},
/* 161D0 */ { NULL,NULL},
/* 161D1 */ { NULL,NULL},
/* 161D2 */ { NULL,NULL},
/* 161D3 */ { NULL,NULL},
/* 161D4 */ { NULL,NULL},
/* 161D5 */ { NULL,NULL},
/* 161D6 */ { NULL,NULL},
/* 161D7 */ { NULL,NULL},
/* 161D8 */ { NULL,NULL},
/* 161D9 */ { NULL,NULL},
/* 161DA */ { NULL,NULL},
/* 161DB */ { NULL,NULL},
/* 161DC */ { NULL,NULL},
/* 161DD */ { NULL,NULL},
/* 161DE */ { NULL,NULL},
/* 161DF */ { NULL,NULL},
/* 161E0 */ { NULL,NULL},
/* 161E1 */ { NULL,NULL},
/* 161E2 */ { NULL,NULL},
/* 161E3 */ { NULL,NULL},
/* 161E4 */ { NULL,NULL},
/* 161E5 */ { NULL,NULL},
/* 161E6 */ { NULL,NULL},
/* 161E7 */ { NULL,NULL},
/* 161E8 */ { NULL,NULL},
/* 161E9 */ { NULL,NULL},
/* 161EA */ { NULL,NULL},
/* 161EB */ { NULL,NULL},
/* 161EC */ { NULL,NULL},
/* 161ED */ { NULL,NULL},
/* 161EE */ { NULL,NULL},
/* 161EF */ { NULL,NULL},
/* 161F0 */ { NULL,NULL},
/* 161F1 */ { NULL,NULL},
/* 161F2 */ { NULL,NULL},
/* 161F3 */ { NULL,NULL},
/* 161F4 */ { NULL,NULL},
/* 161F5 */ { NULL,NULL},
/* 161F6 */ { NULL,NULL},
/* 161F7 */ { NULL,NULL},
/* 161F8 */ { NULL,NULL},
/* 161F9 */ { NULL,NULL},
/* 161FA */ { NULL,NULL},
/* 161FB */ { NULL,NULL},
/* 161FC */ { NULL,NULL},
/* 161FD */ { NULL,NULL},
/* 161FE */ { NULL,NULL},
/* 161FF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_68[] = {
/* 16800 */ { "BAMUM LETTER PHASE-A NGKUE MFON",NULL},
/* 16801 */ { "BAMUM LETTER PHASE-A GBIEE FON",NULL},
/* 16802 */ { "BAMUM LETTER PHASE-A PON MFON PIPAEMGBIEE",NULL},
/* 16803 */ { "BAMUM LETTER PHASE-A PON MFON PIPAEMBA",NULL},
/* 16804 */ { "BAMUM LETTER PHASE-A NAA MFON",NULL},
/* 16805 */ { "BAMUM LETTER PHASE-A SHUENSHUET",NULL},
/* 16806 */ { "BAMUM LETTER PHASE-A TITA MFON",NULL},
/* 16807 */ { "BAMUM LETTER PHASE-A NZA MFON",NULL},
/* 16808 */ { "BAMUM LETTER PHASE-A SHINDA PA NJI",NULL},
/* 16809 */ { "BAMUM LETTER PHASE-A PON PA NJI PIPAEMGBIEE",NULL},
/* 1680A */ { "BAMUM LETTER PHASE-A PON PA NJI PIPAEMBA",NULL},
/* 1680B */ { "BAMUM LETTER PHASE-A MAEMBGBIEE","	% BAMUM LETTER PHASE-A MAEMGBIEE"},
/* 1680C */ { "BAMUM LETTER PHASE-A TU MAEMBA",NULL},
/* 1680D */ { "BAMUM LETTER PHASE-A NGANGU",NULL},
/* 1680E */ { "BAMUM LETTER PHASE-A MAEMVEUX",NULL},
/* 1680F */ { "BAMUM LETTER PHASE-A MANSUAE",NULL},
/* 16810 */ { "BAMUM LETTER PHASE-A MVEUAENGAM",NULL},
/* 16811 */ { "BAMUM LETTER PHASE-A SEUNYAM",NULL},
/* 16812 */ { "BAMUM LETTER PHASE-A NTOQPEN",NULL},
/* 16813 */ { "BAMUM LETTER PHASE-A KEUKEUTNDA",NULL},
/* 16814 */ { "BAMUM LETTER PHASE-A NKINDI",NULL},
/* 16815 */ { "BAMUM LETTER PHASE-A SUU",NULL},
/* 16816 */ { "BAMUM LETTER PHASE-A NGKUENZEUM",NULL},
/* 16817 */ { "BAMUM LETTER PHASE-A LAPAQ",NULL},
/* 16818 */ { "BAMUM LETTER PHASE-A LET KUT",NULL},
/* 16819 */ { "BAMUM LETTER PHASE-A NTAP MFAA",NULL},
/* 1681A */ { "BAMUM LETTER PHASE-A MAEKEUP",NULL},
/* 1681B */ { "BAMUM LETTER PHASE-A PASHAE",NULL},
/* 1681C */ { "BAMUM LETTER PHASE-A GHEUAERAE",NULL},
/* 1681D */ { "BAMUM LETTER PHASE-A PAMSHAE",NULL},
/* 1681E */ { "BAMUM LETTER PHASE-A MON NGGEUAET",NULL},
/* 1681F */ { "BAMUM LETTER PHASE-A NZUN MEUT",NULL},
/* 16820 */ { "BAMUM LETTER PHASE-A U YUQ NAE",NULL},
/* 16821 */ { "BAMUM LETTER PHASE-A GHEUAEGHEUAE",NULL},
/* 16822 */ { "BAMUM LETTER PHASE-A NTAP NTAA",NULL},
/* 16823 */ { "BAMUM LETTER PHASE-A SISA",NULL},
/* 16824 */ { "BAMUM LETTER PHASE-A MGBASA",NULL},
/* 16825 */ { "BAMUM LETTER PHASE-A MEUNJOMNDEUQ",NULL},
/* 16826 */ { "BAMUM LETTER PHASE-A MOOMPUQ",NULL},
/* 16827 */ { "BAMUM LETTER PHASE-A KAFA",NULL},
/* 16828 */ { "BAMUM LETTER PHASE-A PA LEERAEWA",NULL},
/* 16829 */ { "BAMUM LETTER PHASE-A NDA LEERAEWA",NULL},
/* 1682A */ { "BAMUM LETTER PHASE-A PET",NULL},
/* 1682B */ { "BAMUM LETTER PHASE-A MAEMKPEN",NULL},
/* 1682C */ { "BAMUM LETTER PHASE-A NIKA",NULL},
/* 1682D */ { "BAMUM LETTER PHASE-A PUP",NULL},
/* 1682E */ { "BAMUM LETTER PHASE-A TUAEP",NULL},
/* 1682F */ { "BAMUM LETTER PHASE-A LUAEP",NULL},
/* 16830 */ { "BAMUM LETTER PHASE-A SONJAM",NULL},
/* 16831 */ { "BAMUM LETTER PHASE-A TEUTEUWEN",NULL},
/* 16832 */ { "BAMUM LETTER PHASE-A MAENYI",NULL},
/* 16833 */ { "BAMUM LETTER PHASE-A KET",NULL},
/* 16834 */ { "BAMUM LETTER PHASE-A NDAANGGEUAET",NULL},
/* 16835 */ { "BAMUM LETTER PHASE-A KUOQ",NULL},
/* 16836 */ { "BAMUM LETTER PHASE-A MOOMEUT",NULL},
/* 16837 */ { "BAMUM LETTER PHASE-A SHUM",NULL},
/* 16838 */ { "BAMUM LETTER PHASE-A LOMMAE",NULL},
/* 16839 */ { "BAMUM LETTER PHASE-A FIRI",NULL},
/* 1683A */ { "BAMUM LETTER PHASE-A ROM",NULL},
/* 1683B */ { "BAMUM LETTER PHASE-A KPOQ",NULL},
/* 1683C */ { "BAMUM LETTER PHASE-A SOQ",NULL},
/* 1683D */ { "BAMUM LETTER PHASE-A MAP PIEET",NULL},
/* 1683E */ { "BAMUM LETTER PHASE-A SHIRAE",NULL},
/* 1683F */ { "BAMUM LETTER PHASE-A NTAP",NULL},
/* 16840 */ { "BAMUM LETTER PHASE-A SHOQ NSHUT YUM",NULL},
/* 16841 */ { "BAMUM LETTER PHASE-A NYIT MONGKEUAEQ",NULL},
/* 16842 */ { "BAMUM LETTER PHASE-A PAARAE",NULL},
/* 16843 */ { "BAMUM LETTER PHASE-A NKAARAE",NULL},
/* 16844 */ { "BAMUM LETTER PHASE-A UNKNOWN",NULL},
/* 16845 */ { "BAMUM LETTER PHASE-A NGGEN",NULL},
/* 16846 */ { "BAMUM LETTER PHASE-A MAESI",NULL},
/* 16847 */ { "BAMUM LETTER PHASE-A NJAM",NULL},
/* 16848 */ { "BAMUM LETTER PHASE-A MBANYI",NULL},
/* 16849 */ { "BAMUM LETTER PHASE-A NYET",NULL},
/* 1684A */ { "BAMUM LETTER PHASE-A TEUAEN",NULL},
/* 1684B */ { "BAMUM LETTER PHASE-A SOT",NULL},
/* 1684C */ { "BAMUM LETTER PHASE-A PAAM",NULL},
/* 1684D */ { "BAMUM LETTER PHASE-A NSHIEE",NULL},
/* 1684E */ { "BAMUM LETTER PHASE-A MAEM",NULL},
/* 1684F */ { "BAMUM LETTER PHASE-A NYI",NULL},
/* 16850 */ { "BAMUM LETTER PHASE-A KAQ",NULL},
/* 16851 */ { "BAMUM LETTER PHASE-A NSHA",NULL},
/* 16852 */ { "BAMUM LETTER PHASE-A VEE",NULL},
/* 16853 */ { "BAMUM LETTER PHASE-A LU",NULL},
/* 16854 */ { "BAMUM LETTER PHASE-A NEN",NULL},
/* 16855 */ { "BAMUM LETTER PHASE-A NAQ",NULL},
/* 16856 */ { "BAMUM LETTER PHASE-A MBAQ",NULL},
/* 16857 */ { "BAMUM LETTER PHASE-B NSHUET",NULL},
/* 16858 */ { "BAMUM LETTER PHASE-B TU MAEMGBIEE",NULL},
/* 16859 */ { "BAMUM LETTER PHASE-B SIEE",NULL},
/* 1685A */ { "BAMUM LETTER PHASE-B SET TU",NULL},
/* 1685B */ { "BAMUM LETTER PHASE-B LOM NTEUM",NULL},
/* 1685C */ { "BAMUM LETTER PHASE-B MBA MAELEE",NULL},
/* 1685D */ { "BAMUM LETTER PHASE-B KIEEM",NULL},
/* 1685E */ { "BAMUM LETTER PHASE-B YEURAE",NULL},
/* 1685F */ { "BAMUM LETTER PHASE-B MBAARAE",NULL},
/* 16860 */ { "BAMUM LETTER PHASE-B KAM",NULL},
/* 16861 */ { "BAMUM LETTER PHASE-B PEESHI",NULL},
/* 16862 */ { "BAMUM LETTER PHASE-B YAFU LEERAEWA",NULL},
/* 16863 */ { "BAMUM LETTER PHASE-B LAM NSHUT NYAM",NULL},
/* 16864 */ { "BAMUM LETTER PHASE-B NTIEE SHEUOQ",NULL},
/* 16865 */ { "BAMUM LETTER PHASE-B NDU NJAA",NULL},
/* 16866 */ { "BAMUM LETTER PHASE-B GHEUGHEUAEM",NULL},
/* 16867 */ { "BAMUM LETTER PHASE-B PIT",NULL},
/* 16868 */ { "BAMUM LETTER PHASE-B TU NSIEE",NULL},
/* 16869 */ { "BAMUM LETTER PHASE-B SHET NJAQ",NULL},
/* 1686A */ { "BAMUM LETTER PHASE-B SHEUAEQTU",NULL},
/* 1686B */ { "BAMUM LETTER PHASE-B MFON TEUAEQ",NULL},
/* 1686C */ { "BAMUM LETTER PHASE-B MBIT MBAAKET",NULL},
/* 1686D */ { "BAMUM LETTER PHASE-B NYI NTEUM",NULL},
/* 1686E */ { "BAMUM LETTER PHASE-B KEUPUQ",NULL},
/* 1686F */ { "BAMUM LETTER PHASE-B GHEUGHEN",NULL},
/* 16870 */ { "BAMUM LETTER PHASE-B KEUYEUX",NULL},
/* 16871 */ { "BAMUM LETTER PHASE-B LAANAE",NULL},
/* 16872 */ { "BAMUM LETTER PHASE-B PARUM","	* nsen in Phases C-E"},
/* 16873 */ { "BAMUM LETTER PHASE-B VEUM",NULL},
/* 16874 */ { "BAMUM LETTER PHASE-B NGKINDI MVOP",NULL},
/* 16875 */ { "BAMUM LETTER PHASE-B NGGEU MBU",NULL},
/* 16876 */ { "BAMUM LETTER PHASE-B WUAET",NULL},
/* 16877 */ { "BAMUM LETTER PHASE-B SAKEUAE",NULL},
/* 16878 */ { "BAMUM LETTER PHASE-B TAAM",NULL},
/* 16879 */ { "BAMUM LETTER PHASE-B MEUQ",NULL},
/* 1687A */ { "BAMUM LETTER PHASE-B NGGUOQ",NULL},
/* 1687B */ { "BAMUM LETTER PHASE-B NGGUOQ LARGE",NULL},
/* 1687C */ { "BAMUM LETTER PHASE-B MFIYAQ",NULL},
/* 1687D */ { "BAMUM LETTER PHASE-B SUE",NULL},
/* 1687E */ { "BAMUM LETTER PHASE-B MBEURI",NULL},
/* 1687F */ { "BAMUM LETTER PHASE-B MONTIEEN",NULL},
/* 16880 */ { "BAMUM LETTER PHASE-B NYAEMAE",NULL},
/* 16881 */ { "BAMUM LETTER PHASE-B PUNGAAM","	% BAMUM LETTER PHASE-B PUNGGAAM"},
/* 16882 */ { "BAMUM LETTER PHASE-B MEUT NGGEET",NULL},
/* 16883 */ { "BAMUM LETTER PHASE-B FEUX",NULL},
/* 16884 */ { "BAMUM LETTER PHASE-B MBUOQ",NULL},
/* 16885 */ { "BAMUM LETTER PHASE-B FEE",NULL},
/* 16886 */ { "BAMUM LETTER PHASE-B KEUAEM",NULL},
/* 16887 */ { "BAMUM LETTER PHASE-B MA NJEUAENA",NULL},
/* 16888 */ { "BAMUM LETTER PHASE-B MA NJUQA",NULL},
/* 16889 */ { "BAMUM LETTER PHASE-B LET",NULL},
/* 1688A */ { "BAMUM LETTER PHASE-B NGGAAM",NULL},
/* 1688B */ { "BAMUM LETTER PHASE-B NSEN",NULL},
/* 1688C */ { "BAMUM LETTER PHASE-B MA",NULL},
/* 1688D */ { "BAMUM LETTER PHASE-B KIQ",NULL},
/* 1688E */ { "BAMUM LETTER PHASE-B NGOM","	% BAMUM LETTER PHASE-B NGGOM"},
/* 1688F */ { "BAMUM LETTER PHASE-C NGKUE MAEMBA",NULL},
/* 16890 */ { "BAMUM LETTER PHASE-C NZA",NULL},
/* 16891 */ { "BAMUM LETTER PHASE-C YUM",NULL},
/* 16892 */ { "BAMUM LETTER PHASE-C WANGKUOQ",NULL},
/* 16893 */ { "BAMUM LETTER PHASE-C NGGEN",NULL},
/* 16894 */ { "BAMUM LETTER PHASE-C NDEUAEREE",NULL},
/* 16895 */ { "BAMUM LETTER PHASE-C NGKAQ",NULL},
/* 16896 */ { "BAMUM LETTER PHASE-C GHARAE",NULL},
/* 16897 */ { "BAMUM LETTER PHASE-C MBEEKEET",NULL},
/* 16898 */ { "BAMUM LETTER PHASE-C GBAYI",NULL},
/* 16899 */ { "BAMUM LETTER PHASE-C NYIR MKPARAQ MEUN",NULL},
/* 1689A */ { "BAMUM LETTER PHASE-C NTU MBIT",NULL},
/* 1689B */ { "BAMUM LETTER PHASE-C MBEUM",NULL},
/* 1689C */ { "BAMUM LETTER PHASE-C PIRIEEN",NULL},
/* 1689D */ { "BAMUM LETTER PHASE-C NDOMBU",NULL},
/* 1689E */ { "BAMUM LETTER PHASE-C MBAA CABBAGE-TREE",NULL},
/* 1689F */ { "BAMUM LETTER PHASE-C KEUSHEUAEP",NULL},
/* 168A0 */ { "BAMUM LETTER PHASE-C GHAP",NULL},
/* 168A1 */ { "BAMUM LETTER PHASE-C KEUKAQ",NULL},
/* 168A2 */ { "BAMUM LETTER PHASE-C YU MUOMAE",NULL},
/* 168A3 */ { "BAMUM LETTER PHASE-C NZEUM",NULL},
/* 168A4 */ { "BAMUM LETTER PHASE-C MBUE",NULL},
/* 168A5 */ { "BAMUM LETTER PHASE-C NSEUAEN",NULL},
/* 168A6 */ { "BAMUM LETTER PHASE-C MBIT",NULL},
/* 168A7 */ { "BAMUM LETTER PHASE-C YEUQ",NULL},
/* 168A8 */ { "BAMUM LETTER PHASE-C KPARAQ",NULL},
/* 168A9 */ { "BAMUM LETTER PHASE-C KAA",NULL},
/* 168AA */ { "BAMUM LETTER PHASE-C SEUX",NULL},
/* 168AB */ { "BAMUM LETTER PHASE-C NDIDA",NULL},
/* 168AC */ { "BAMUM LETTER PHASE-C TAASHAE",NULL},
/* 168AD */ { "BAMUM LETTER PHASE-C NJUEQ",NULL},
/* 168AE */ { "BAMUM LETTER PHASE-C TITA YUE",NULL},
/* 168AF */ { "BAMUM LETTER PHASE-C SUAET",NULL},
/* 168B0 */ { "BAMUM LETTER PHASE-C NGGUAEN NYAM",NULL},
/* 168B1 */ { "BAMUM LETTER PHASE-C VEUX",NULL},
/* 168B2 */ { "BAMUM LETTER PHASE-C NANSANAQ",NULL},
/* 168B3 */ { "BAMUM LETTER PHASE-C MA KEUAERI",NULL},
/* 168B4 */ { "BAMUM LETTER PHASE-C NTAA",NULL},
/* 168B5 */ { "BAMUM LETTER PHASE-C NGGUON",NULL},
/* 168B6 */ { "BAMUM LETTER PHASE-C LAP",NULL},
/* 168B7 */ { "BAMUM LETTER PHASE-C MBIRIEEN",NULL},
/* 168B8 */ { "BAMUM LETTER PHASE-C MGBASAQ",NULL},
/* 168B9 */ { "BAMUM LETTER PHASE-C NTEUNGBA",NULL},
/* 168BA */ { "BAMUM LETTER PHASE-C TEUTEUX",NULL},
/* 168BB */ { "BAMUM LETTER PHASE-C NGGUM",NULL},
/* 168BC */ { "BAMUM LETTER PHASE-C FUE",NULL},
/* 168BD */ { "BAMUM LETTER PHASE-C NDEUT",NULL},
/* 168BE */ { "BAMUM LETTER PHASE-C NSA",NULL},
/* 168BF */ { "BAMUM LETTER PHASE-C NSHAQ",NULL},
/* 168C0 */ { "BAMUM LETTER PHASE-C BUNG",NULL},
/* 168C1 */ { "BAMUM LETTER PHASE-C VEUAEPEN",NULL},
/* 168C2 */ { "BAMUM LETTER PHASE-C MBERAE",NULL},
/* 168C3 */ { "BAMUM LETTER PHASE-C RU",NULL},
/* 168C4 */ { "BAMUM LETTER PHASE-C NJAEM",NULL},
/* 168C5 */ { "BAMUM LETTER PHASE-C LAM",NULL},
/* 168C6 */ { "BAMUM LETTER PHASE-C TITUAEP",NULL},
/* 168C7 */ { "BAMUM LETTER PHASE-C NSUOT NGOM",NULL},
/* 168C8 */ { "BAMUM LETTER PHASE-C NJEEEE",NULL},
/* 168C9 */ { "BAMUM LETTER PHASE-C KET",NULL},
/* 168CA */ { "BAMUM LETTER PHASE-C NGGU",NULL},
/* 168CB */ { "BAMUM LETTER PHASE-C MAESI",NULL},
/* 168CC */ { "BAMUM LETTER PHASE-C MBUAEM",NULL},
/* 168CD */ { "BAMUM LETTER PHASE-C LU",NULL},
/* 168CE */ { "BAMUM LETTER PHASE-C KUT",NULL},
/* 168CF */ { "BAMUM LETTER PHASE-C NJAM",NULL},
/* 168D0 */ { "BAMUM LETTER PHASE-C NGOM",NULL},
/* 168D1 */ { "BAMUM LETTER PHASE-C WUP",NULL},
/* 168D2 */ { "BAMUM LETTER PHASE-C NGGUEET",NULL},
/* 168D3 */ { "BAMUM LETTER PHASE-C NSOM",NULL},
/* 168D4 */ { "BAMUM LETTER PHASE-C NTEN",NULL},
/* 168D5 */ { "BAMUM LETTER PHASE-C KUOP NKAARAE",NULL},
/* 168D6 */ { "BAMUM LETTER PHASE-C NSUN",NULL},
/* 168D7 */ { "BAMUM LETTER PHASE-C NDAM","	* pen in Phase D"},
/* 168D8 */ { "BAMUM LETTER PHASE-C MA NSIEE",NULL},
/* 168D9 */ { "BAMUM LETTER PHASE-C YAA",NULL},
/* 168DA */ { "BAMUM LETTER PHASE-C NDAP",NULL},
/* 168DB */ { "BAMUM LETTER PHASE-C SHUEQ",NULL},
/* 168DC */ { "BAMUM LETTER PHASE-C SETFON","	% BAMUM LETTER PHASE-C SHETFON"},
/* 168DD */ { "BAMUM LETTER PHASE-C MBI",NULL},
/* 168DE */ { "BAMUM LETTER PHASE-C MAEMBA",NULL},
/* 168DF */ { "BAMUM LETTER PHASE-C MBANYI",NULL},
/* 168E0 */ { "BAMUM LETTER PHASE-C KEUSEUX",NULL},
/* 168E1 */ { "BAMUM LETTER PHASE-C MBEUX",NULL},
/* 168E2 */ { "BAMUM LETTER PHASE-C KEUM",NULL},
/* 168E3 */ { "BAMUM LETTER PHASE-C MBAA PICKET",NULL},
/* 168E4 */ { "BAMUM LETTER PHASE-C YUWOQ",NULL},
/* 168E5 */ { "BAMUM LETTER PHASE-C NJEUX",NULL},
/* 168E6 */ { "BAMUM LETTER PHASE-C MIEE",NULL},
/* 168E7 */ { "BAMUM LETTER PHASE-C MUAE",NULL},
/* 168E8 */ { "BAMUM LETTER PHASE-C SHIQ",NULL},
/* 168E9 */ { "BAMUM LETTER PHASE-C KEN LAW",NULL},
/* 168EA */ { "BAMUM LETTER PHASE-C KEN FATIGUE",NULL},
/* 168EB */ { "BAMUM LETTER PHASE-C NGAQ",NULL},
/* 168EC */ { "BAMUM LETTER PHASE-C NAQ",NULL},
/* 168ED */ { "BAMUM LETTER PHASE-C LIQ",NULL},
/* 168EE */ { "BAMUM LETTER PHASE-C PIN",NULL},
/* 168EF */ { "BAMUM LETTER PHASE-C PEN",NULL},
/* 168F0 */ { "BAMUM LETTER PHASE-C TET",NULL},
/* 168F1 */ { "BAMUM LETTER PHASE-D MBUO",NULL},
/* 168F2 */ { "BAMUM LETTER PHASE-D WAP",NULL},
/* 168F3 */ { "BAMUM LETTER PHASE-D NJI",NULL},
/* 168F4 */ { "BAMUM LETTER PHASE-D MFON",NULL},
/* 168F5 */ { "BAMUM LETTER PHASE-D NJIEE",NULL},
/* 168F6 */ { "BAMUM LETTER PHASE-D LIEE",NULL},
/* 168F7 */ { "BAMUM LETTER PHASE-D NJEUT",NULL},
/* 168F8 */ { "BAMUM LETTER PHASE-D NSHEE",NULL},
/* 168F9 */ { "BAMUM LETTER PHASE-D NGGAAMAE",NULL},
/* 168FA */ { "BAMUM LETTER PHASE-D NYAM",NULL},
/* 168FB */ { "BAMUM LETTER PHASE-D WUAEN","	* ti in Phases E-F"},
/* 168FC */ { "BAMUM LETTER PHASE-D NGKUN",NULL},
/* 168FD */ { "BAMUM LETTER PHASE-D SHEE",NULL},
/* 168FE */ { "BAMUM LETTER PHASE-D NGKAP",NULL},
/* 168FF */ { "BAMUM LETTER PHASE-D KEUAETMEUN",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_69[] = {
/* 16900 */ { "BAMUM LETTER PHASE-D TEUT",NULL},
/* 16901 */ { "BAMUM LETTER PHASE-D SHEUAE",NULL},
/* 16902 */ { "BAMUM LETTER PHASE-D NJAP",NULL},
/* 16903 */ { "BAMUM LETTER PHASE-D SUE",NULL},
/* 16904 */ { "BAMUM LETTER PHASE-D KET",NULL},
/* 16905 */ { "BAMUM LETTER PHASE-D YAEMMAE",NULL},
/* 16906 */ { "BAMUM LETTER PHASE-D KUOM",NULL},
/* 16907 */ { "BAMUM LETTER PHASE-D SAP",NULL},
/* 16908 */ { "BAMUM LETTER PHASE-D MFEUT",NULL},
/* 16909 */ { "BAMUM LETTER PHASE-D NDEUX",NULL},
/* 1690A */ { "BAMUM LETTER PHASE-D MALEERI",NULL},
/* 1690B */ { "BAMUM LETTER PHASE-D MEUT",NULL},
/* 1690C */ { "BAMUM LETTER PHASE-D SEUAEQ",NULL},
/* 1690D */ { "BAMUM LETTER PHASE-D YEN",NULL},
/* 1690E */ { "BAMUM LETTER PHASE-D NJEUAEM",NULL},
/* 1690F */ { "BAMUM LETTER PHASE-D KEUOT MBUAE",NULL},
/* 16910 */ { "BAMUM LETTER PHASE-D NGKEURI",NULL},
/* 16911 */ { "BAMUM LETTER PHASE-D TU",NULL},
/* 16912 */ { "BAMUM LETTER PHASE-D GHAA",NULL},
/* 16913 */ { "BAMUM LETTER PHASE-D NGKYEE",NULL},
/* 16914 */ { "BAMUM LETTER PHASE-D FEUFEUAET",NULL},
/* 16915 */ { "BAMUM LETTER PHASE-D NDEE",NULL},
/* 16916 */ { "BAMUM LETTER PHASE-D MGBOFUM",NULL},
/* 16917 */ { "BAMUM LETTER PHASE-D LEUAEP",NULL},
/* 16918 */ { "BAMUM LETTER PHASE-D NDON",NULL},
/* 16919 */ { "BAMUM LETTER PHASE-D MONI",NULL},
/* 1691A */ { "BAMUM LETTER PHASE-D MGBEUN",NULL},
/* 1691B */ { "BAMUM LETTER PHASE-D PUUT",NULL},
/* 1691C */ { "BAMUM LETTER PHASE-D MGBIEE",NULL},
/* 1691D */ { "BAMUM LETTER PHASE-D MFO",NULL},
/* 1691E */ { "BAMUM LETTER PHASE-D LUM",NULL},
/* 1691F */ { "BAMUM LETTER PHASE-D NSIEEP",NULL},
/* 16920 */ { "BAMUM LETTER PHASE-D MBAA",NULL},
/* 16921 */ { "BAMUM LETTER PHASE-D KWAET",NULL},
/* 16922 */ { "BAMUM LETTER PHASE-D NYET",NULL},
/* 16923 */ { "BAMUM LETTER PHASE-D TEUAEN",NULL},
/* 16924 */ { "BAMUM LETTER PHASE-D SOT",NULL},
/* 16925 */ { "BAMUM LETTER PHASE-D YUWOQ",NULL},
/* 16926 */ { "BAMUM LETTER PHASE-D KEUM",NULL},
/* 16927 */ { "BAMUM LETTER PHASE-D RAEM",NULL},
/* 16928 */ { "BAMUM LETTER PHASE-D TEEEE",NULL},
/* 16929 */ { "BAMUM LETTER PHASE-D NGKEUAEQ","	* faamae '8' in Phase F"},
/* 1692A */ { "BAMUM LETTER PHASE-D MFEUAE",NULL},
/* 1692B */ { "BAMUM LETTER PHASE-D NSIEET",NULL},
/* 1692C */ { "BAMUM LETTER PHASE-D KEUP",NULL},
/* 1692D */ { "BAMUM LETTER PHASE-D PIP",NULL},
/* 1692E */ { "BAMUM LETTER PHASE-D PEUTAE",NULL},
/* 1692F */ { "BAMUM LETTER PHASE-D NYUE",NULL},
/* 16930 */ { "BAMUM LETTER PHASE-D LET","	* lee in Phases E-F"},
/* 16931 */ { "BAMUM LETTER PHASE-D NGGAAM","	* mu in Phases E-F"},
/* 16932 */ { "BAMUM LETTER PHASE-D MFIEE",NULL},
/* 16933 */ { "BAMUM LETTER PHASE-D NGGWAEN",NULL},
/* 16934 */ { "BAMUM LETTER PHASE-D YUOM",NULL},
/* 16935 */ { "BAMUM LETTER PHASE-D PAP",NULL},
/* 16936 */ { "BAMUM LETTER PHASE-D YUOP",NULL},
/* 16937 */ { "BAMUM LETTER PHASE-D NDAM",NULL},
/* 16938 */ { "BAMUM LETTER PHASE-D NTEUM",NULL},
/* 16939 */ { "BAMUM LETTER PHASE-D SUAE",NULL},
/* 1693A */ { "BAMUM LETTER PHASE-D KUN",NULL},
/* 1693B */ { "BAMUM LETTER PHASE-D NGGEUX",NULL},
/* 1693C */ { "BAMUM LETTER PHASE-D NGKIEE",NULL},
/* 1693D */ { "BAMUM LETTER PHASE-D TUOT",NULL},
/* 1693E */ { "BAMUM LETTER PHASE-D MEUN",NULL},
/* 1693F */ { "BAMUM LETTER PHASE-D KUQ",NULL},
/* 16940 */ { "BAMUM LETTER PHASE-D NSUM",NULL},
/* 16941 */ { "BAMUM LETTER PHASE-D TEUN",NULL},
/* 16942 */ { "BAMUM LETTER PHASE-D MAENJET",NULL},
/* 16943 */ { "BAMUM LETTER PHASE-D NGGAP",NULL},
/* 16944 */ { "BAMUM LETTER PHASE-D LEUM",NULL},
/* 16945 */ { "BAMUM LETTER PHASE-D NGGUOM",NULL},
/* 16946 */ { "BAMUM LETTER PHASE-D NSHUT",NULL},
/* 16947 */ { "BAMUM LETTER PHASE-D NJUEQ",NULL},
/* 16948 */ { "BAMUM LETTER PHASE-D GHEUAE",NULL},
/* 16949 */ { "BAMUM LETTER PHASE-D KU",NULL},
/* 1694A */ { "BAMUM LETTER PHASE-D REN OLD",NULL},
/* 1694B */ { "BAMUM LETTER PHASE-D TAE",NULL},
/* 1694C */ { "BAMUM LETTER PHASE-D TOQ",NULL},
/* 1694D */ { "BAMUM LETTER PHASE-D NYI",NULL},
/* 1694E */ { "BAMUM LETTER PHASE-D RII",NULL},
/* 1694F */ { "BAMUM LETTER PHASE-D LEEEE",NULL},
/* 16950 */ { "BAMUM LETTER PHASE-D MEEEE","	* meq in Phase E"},
/* 16951 */ { "BAMUM LETTER PHASE-D M",NULL},
/* 16952 */ { "BAMUM LETTER PHASE-D SUU",NULL},
/* 16953 */ { "BAMUM LETTER PHASE-D MU",NULL},
/* 16954 */ { "BAMUM LETTER PHASE-D SHII",NULL},
/* 16955 */ { "BAMUM LETTER PHASE-D SHEUX",NULL},
/* 16956 */ { "BAMUM LETTER PHASE-D KYEE",NULL},
/* 16957 */ { "BAMUM LETTER PHASE-D NU",NULL},
/* 16958 */ { "BAMUM LETTER PHASE-D SHU",NULL},
/* 16959 */ { "BAMUM LETTER PHASE-D NTEE",NULL},
/* 1695A */ { "BAMUM LETTER PHASE-D PEE",NULL},
/* 1695B */ { "BAMUM LETTER PHASE-D NI",NULL},
/* 1695C */ { "BAMUM LETTER PHASE-D SHOQ",NULL},
/* 1695D */ { "BAMUM LETTER PHASE-D PUQ",NULL},
/* 1695E */ { "BAMUM LETTER PHASE-D MVOP",NULL},
/* 1695F */ { "BAMUM LETTER PHASE-D LOQ",NULL},
/* 16960 */ { "BAMUM LETTER PHASE-D REN MUCH",NULL},
/* 16961 */ { "BAMUM LETTER PHASE-D TI",NULL},
/* 16962 */ { "BAMUM LETTER PHASE-D NTUU",NULL},
/* 16963 */ { "BAMUM LETTER PHASE-D MBAA SEVEN","	* used after 16985 for samba '7' in Phases A-D"},
/* 16964 */ { "BAMUM LETTER PHASE-D SAQ",NULL},
/* 16965 */ { "BAMUM LETTER PHASE-D FAA","	* used before 169B8 for faamae '8' in Phases A-D"},
/* 16966 */ { "BAMUM LETTER PHASE-E NDAP","	* i in Phase F"},
/* 16967 */ { "BAMUM LETTER PHASE-E TOON",NULL},
/* 16968 */ { "BAMUM LETTER PHASE-E MBEUM",NULL},
/* 16969 */ { "BAMUM LETTER PHASE-E LAP","	* men in Phase F"},
/* 1696A */ { "BAMUM LETTER PHASE-E VOM",NULL},
/* 1696B */ { "BAMUM LETTER PHASE-E LOON",NULL},
/* 1696C */ { "BAMUM LETTER PHASE-E PAA",NULL},
/* 1696D */ { "BAMUM LETTER PHASE-E SOM",NULL},
/* 1696E */ { "BAMUM LETTER PHASE-E RAQ","	* nga in Phase F"},
/* 1696F */ { "BAMUM LETTER PHASE-E NSHUOP","	* pa in Phase F"},
/* 16970 */ { "BAMUM LETTER PHASE-E NDUN","	* pue in Phase F"},
/* 16971 */ { "BAMUM LETTER PHASE-E PUAE","	* fae in Phase F"},
/* 16972 */ { "BAMUM LETTER PHASE-E TAM",NULL},
/* 16973 */ { "BAMUM LETTER PHASE-E NGKA",NULL},
/* 16974 */ { "BAMUM LETTER PHASE-E KPEUX",NULL},
/* 16975 */ { "BAMUM LETTER PHASE-E WUO",NULL},
/* 16976 */ { "BAMUM LETTER PHASE-E SEE",NULL},
/* 16977 */ { "BAMUM LETTER PHASE-E NGGEUAET",NULL},
/* 16978 */ { "BAMUM LETTER PHASE-E PAAM",NULL},
/* 16979 */ { "BAMUM LETTER PHASE-E TOO",NULL},
/* 1697A */ { "BAMUM LETTER PHASE-E KUOP",NULL},
/* 1697B */ { "BAMUM LETTER PHASE-E LOM",NULL},
/* 1697C */ { "BAMUM LETTER PHASE-E NSHIEE",NULL},
/* 1697D */ { "BAMUM LETTER PHASE-E NGOP","	% BAMUM LETTER PHASE-E NGGOP"},
/* 1697E */ { "BAMUM LETTER PHASE-E MAEM",NULL},
/* 1697F */ { "BAMUM LETTER PHASE-E NGKEUX",NULL},
/* 16980 */ { "BAMUM LETTER PHASE-E NGOQ",NULL},
/* 16981 */ { "BAMUM LETTER PHASE-E NSHUE",NULL},
/* 16982 */ { "BAMUM LETTER PHASE-E RIMGBA",NULL},
/* 16983 */ { "BAMUM LETTER PHASE-E NJEUX",NULL},
/* 16984 */ { "BAMUM LETTER PHASE-E PEEM",NULL},
/* 16985 */ { "BAMUM LETTER PHASE-E SAA","	* used before 16963 for samba '7' in Phases A-D"},
/* 16986 */ { "BAMUM LETTER PHASE-E NGGURAE",NULL},
/* 16987 */ { "BAMUM LETTER PHASE-E MGBA",NULL},
/* 16988 */ { "BAMUM LETTER PHASE-E GHEUX",NULL},
/* 16989 */ { "BAMUM LETTER PHASE-E NGKEUAEM",NULL},
/* 1698A */ { "BAMUM LETTER PHASE-E NJAEMLI",NULL},
/* 1698B */ { "BAMUM LETTER PHASE-E MAP",NULL},
/* 1698C */ { "BAMUM LETTER PHASE-E LOOT",NULL},
/* 1698D */ { "BAMUM LETTER PHASE-E NGGEEEE",NULL},
/* 1698E */ { "BAMUM LETTER PHASE-E NDIQ",NULL},
/* 1698F */ { "BAMUM LETTER PHASE-E TAEN NTEUM",NULL},
/* 16990 */ { "BAMUM LETTER PHASE-E SET",NULL},
/* 16991 */ { "BAMUM LETTER PHASE-E PUM","	* o in Phase F"},
/* 16992 */ { "BAMUM LETTER PHASE-E NDAA SOFTNESS",NULL},
/* 16993 */ { "BAMUM LETTER PHASE-E NGGUAESHAE NYAM","	* fee in Phase F"},
/* 16994 */ { "BAMUM LETTER PHASE-E YIEE",NULL},
/* 16995 */ { "BAMUM LETTER PHASE-E GHEUN",NULL},
/* 16996 */ { "BAMUM LETTER PHASE-E TUAE",NULL},
/* 16997 */ { "BAMUM LETTER PHASE-E YEUAE",NULL},
/* 16998 */ { "BAMUM LETTER PHASE-E PO",NULL},
/* 16999 */ { "BAMUM LETTER PHASE-E TUMAE",NULL},
/* 1699A */ { "BAMUM LETTER PHASE-E KEUAE",NULL},
/* 1699B */ { "BAMUM LETTER PHASE-E SUAEN",NULL},
/* 1699C */ { "BAMUM LETTER PHASE-E TEUAEQ",NULL},
/* 1699D */ { "BAMUM LETTER PHASE-E VEUAE",NULL},
/* 1699E */ { "BAMUM LETTER PHASE-E WEUX",NULL},
/* 1699F */ { "BAMUM LETTER PHASE-E LAAM",NULL},
/* 169A0 */ { "BAMUM LETTER PHASE-E PU","	* also puq in Phase E"},
/* 169A1 */ { "BAMUM LETTER PHASE-E TAAQ",NULL},
/* 169A2 */ { "BAMUM LETTER PHASE-E GHAAMAE",NULL},
/* 169A3 */ { "BAMUM LETTER PHASE-E NGEUREUT",NULL},
/* 169A4 */ { "BAMUM LETTER PHASE-E SHEUAEQ",NULL},
/* 169A5 */ { "BAMUM LETTER PHASE-E MGBEN",NULL},
/* 169A6 */ { "BAMUM LETTER PHASE-E MBEE",NULL},
/* 169A7 */ { "BAMUM LETTER PHASE-E NZAQ",NULL},
/* 169A8 */ { "BAMUM LETTER PHASE-E NKOM","	* ten in Phase F"},
/* 169A9 */ { "BAMUM LETTER PHASE-E GBET",NULL},
/* 169AA */ { "BAMUM LETTER PHASE-E TUM",NULL},
/* 169AB */ { "BAMUM LETTER PHASE-E KUET",NULL},
/* 169AC */ { "BAMUM LETTER PHASE-E YAP",NULL},
/* 169AD */ { "BAMUM LETTER PHASE-E NYI CLEAVER",NULL},
/* 169AE */ { "BAMUM LETTER PHASE-E YIT",NULL},
/* 169AF */ { "BAMUM LETTER PHASE-E MFEUQ",NULL},
/* 169B0 */ { "BAMUM LETTER PHASE-E NDIAQ",NULL},
/* 169B1 */ { "BAMUM LETTER PHASE-E PIEEQ",NULL},
/* 169B2 */ { "BAMUM LETTER PHASE-E YUEQ",NULL},
/* 169B3 */ { "BAMUM LETTER PHASE-E LEUAEM",NULL},
/* 169B4 */ { "BAMUM LETTER PHASE-E FUE",NULL},
/* 169B5 */ { "BAMUM LETTER PHASE-E GBEUX",NULL},
/* 169B6 */ { "BAMUM LETTER PHASE-E NGKUP",NULL},
/* 169B7 */ { "BAMUM LETTER PHASE-E KET",NULL},
/* 169B8 */ { "BAMUM LETTER PHASE-E MAE","	* used after 16965 for faamae '8' in Phases A-D"},
/* 169B9 */ { "BAMUM LETTER PHASE-E NGKAAMI",NULL},
/* 169BA */ { "BAMUM LETTER PHASE-E GHET",NULL},
/* 169BB */ { "BAMUM LETTER PHASE-E FA",NULL},
/* 169BC */ { "BAMUM LETTER PHASE-E NTUM",NULL},
/* 169BD */ { "BAMUM LETTER PHASE-E PEUT",NULL},
/* 169BE */ { "BAMUM LETTER PHASE-E YEUM",NULL},
/* 169BF */ { "BAMUM LETTER PHASE-E NGGEUAE",NULL},
/* 169C0 */ { "BAMUM LETTER PHASE-E NYI BETWEEN",NULL},
/* 169C1 */ { "BAMUM LETTER PHASE-E NZUQ",NULL},
/* 169C2 */ { "BAMUM LETTER PHASE-E POON",NULL},
/* 169C3 */ { "BAMUM LETTER PHASE-E MIEE",NULL},
/* 169C4 */ { "BAMUM LETTER PHASE-E FUET",NULL},
/* 169C5 */ { "BAMUM LETTER PHASE-E NAE",NULL},
/* 169C6 */ { "BAMUM LETTER PHASE-E MUAE",NULL},
/* 169C7 */ { "BAMUM LETTER PHASE-E GHEUAE",NULL},
/* 169C8 */ { "BAMUM LETTER PHASE-E FU I",NULL},
/* 169C9 */ { "BAMUM LETTER PHASE-E MVI",NULL},
/* 169CA */ { "BAMUM LETTER PHASE-E PUAQ",NULL},
/* 169CB */ { "BAMUM LETTER PHASE-E NGKUM",NULL},
/* 169CC */ { "BAMUM LETTER PHASE-E KUT",NULL},
/* 169CD */ { "BAMUM LETTER PHASE-E PIET",NULL},
/* 169CE */ { "BAMUM LETTER PHASE-E NTAP",NULL},
/* 169CF */ { "BAMUM LETTER PHASE-E YEUAET",NULL},
/* 169D0 */ { "BAMUM LETTER PHASE-E NGGUP",NULL},
/* 169D1 */ { "BAMUM LETTER PHASE-E PA PEOPLE",NULL},
/* 169D2 */ { "BAMUM LETTER PHASE-E FU CALL",NULL},
/* 169D3 */ { "BAMUM LETTER PHASE-E FOM",NULL},
/* 169D4 */ { "BAMUM LETTER PHASE-E NJEE",NULL},
/* 169D5 */ { "BAMUM LETTER PHASE-E A",NULL},
/* 169D6 */ { "BAMUM LETTER PHASE-E TOQ",NULL},
/* 169D7 */ { "BAMUM LETTER PHASE-E O",NULL},
/* 169D8 */ { "BAMUM LETTER PHASE-E I",NULL},
/* 169D9 */ { "BAMUM LETTER PHASE-E LAQ",NULL},
/* 169DA */ { "BAMUM LETTER PHASE-E PA PLURAL",NULL},
/* 169DB */ { "BAMUM LETTER PHASE-E TAA",NULL},
/* 169DC */ { "BAMUM LETTER PHASE-E TAQ",NULL},
/* 169DD */ { "BAMUM LETTER PHASE-E NDAA MY HOUSE",NULL},
/* 169DE */ { "BAMUM LETTER PHASE-E SHIQ",NULL},
/* 169DF */ { "BAMUM LETTER PHASE-E YEUX",NULL},
/* 169E0 */ { "BAMUM LETTER PHASE-E NGUAE",NULL},
/* 169E1 */ { "BAMUM LETTER PHASE-E YUAEN","	* pi in Phase F"},
/* 169E2 */ { "BAMUM LETTER PHASE-E YOQ SWIMMING",NULL},
/* 169E3 */ { "BAMUM LETTER PHASE-E YOQ COVER",NULL},
/* 169E4 */ { "BAMUM LETTER PHASE-E YUQ",NULL},
/* 169E5 */ { "BAMUM LETTER PHASE-E YUN",NULL},
/* 169E6 */ { "BAMUM LETTER PHASE-E KEUX",NULL},
/* 169E7 */ { "BAMUM LETTER PHASE-E PEUX",NULL},
/* 169E8 */ { "BAMUM LETTER PHASE-E NJEE EPOCH",NULL},
/* 169E9 */ { "BAMUM LETTER PHASE-E PUE",NULL},
/* 169EA */ { "BAMUM LETTER PHASE-E WUE",NULL},
/* 169EB */ { "BAMUM LETTER PHASE-E FEE",NULL},
/* 169EC */ { "BAMUM LETTER PHASE-E VEE",NULL},
/* 169ED */ { "BAMUM LETTER PHASE-E LU",NULL},
/* 169EE */ { "BAMUM LETTER PHASE-E MI",NULL},
/* 169EF */ { "BAMUM LETTER PHASE-E REUX",NULL},
/* 169F0 */ { "BAMUM LETTER PHASE-E RAE",NULL},
/* 169F1 */ { "BAMUM LETTER PHASE-E NGUAET",NULL},
/* 169F2 */ { "BAMUM LETTER PHASE-E NGA",NULL},
/* 169F3 */ { "BAMUM LETTER PHASE-E SHO",NULL},
/* 169F4 */ { "BAMUM LETTER PHASE-E SHOQ",NULL},
/* 169F5 */ { "BAMUM LETTER PHASE-E FU REMEDY",NULL},
/* 169F6 */ { "BAMUM LETTER PHASE-E NA",NULL},
/* 169F7 */ { "BAMUM LETTER PHASE-E PI",NULL},
/* 169F8 */ { "BAMUM LETTER PHASE-E LOQ",NULL},
/* 169F9 */ { "BAMUM LETTER PHASE-E KO","	* used before 16A02 for koghom '10' in Phases A-D\n"
	"	* used before 16A38 for kovue '9' in Phases A-D"},
/* 169FA */ { "BAMUM LETTER PHASE-E MEN",NULL},
/* 169FB */ { "BAMUM LETTER PHASE-E MA",NULL},
/* 169FC */ { "BAMUM LETTER PHASE-E MAQ",NULL},
/* 169FD */ { "BAMUM LETTER PHASE-E TEU",NULL},
/* 169FE */ { "BAMUM LETTER PHASE-E KI","	* koghom in Phase F"},
/* 169FF */ { "BAMUM LETTER PHASE-E MON",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_6A[] = {
/* 16A00 */ { "BAMUM LETTER PHASE-E TEN",NULL},
/* 16A01 */ { "BAMUM LETTER PHASE-E FAQ",NULL},
/* 16A02 */ { "BAMUM LETTER PHASE-E GHOM","	* used after 169F9 for koghom '10' in Phases A-D"},
/* 16A03 */ { "BAMUM LETTER PHASE-F KA",NULL},
/* 16A04 */ { "BAMUM LETTER PHASE-F U",NULL},
/* 16A05 */ { "BAMUM LETTER PHASE-F KU",NULL},
/* 16A06 */ { "BAMUM LETTER PHASE-F EE",NULL},
/* 16A07 */ { "BAMUM LETTER PHASE-F REE",NULL},
/* 16A08 */ { "BAMUM LETTER PHASE-F TAE",NULL},
/* 16A09 */ { "BAMUM LETTER PHASE-F NYI",NULL},
/* 16A0A */ { "BAMUM LETTER PHASE-F LA",NULL},
/* 16A0B */ { "BAMUM LETTER PHASE-F RII",NULL},
/* 16A0C */ { "BAMUM LETTER PHASE-F RIEE",NULL},
/* 16A0D */ { "BAMUM LETTER PHASE-F MEEEE",NULL},
/* 16A0E */ { "BAMUM LETTER PHASE-F TAA",NULL},
/* 16A0F */ { "BAMUM LETTER PHASE-F NDAA",NULL},
/* 16A10 */ { "BAMUM LETTER PHASE-F NJAEM",NULL},
/* 16A11 */ { "BAMUM LETTER PHASE-F M",NULL},
/* 16A12 */ { "BAMUM LETTER PHASE-F SUU",NULL},
/* 16A13 */ { "BAMUM LETTER PHASE-F SHII",NULL},
/* 16A14 */ { "BAMUM LETTER PHASE-F SI",NULL},
/* 16A15 */ { "BAMUM LETTER PHASE-F SEUX",NULL},
/* 16A16 */ { "BAMUM LETTER PHASE-F KYEE",NULL},
/* 16A17 */ { "BAMUM LETTER PHASE-F KET",NULL},
/* 16A18 */ { "BAMUM LETTER PHASE-F NUAE",NULL},
/* 16A19 */ { "BAMUM LETTER PHASE-F NU",NULL},
/* 16A1A */ { "BAMUM LETTER PHASE-F NJUAE",NULL},
/* 16A1B */ { "BAMUM LETTER PHASE-F YOQ",NULL},
/* 16A1C */ { "BAMUM LETTER PHASE-F SHU",NULL},
/* 16A1D */ { "BAMUM LETTER PHASE-F YA",NULL},
/* 16A1E */ { "BAMUM LETTER PHASE-F NSHA",NULL},
/* 16A1F */ { "BAMUM LETTER PHASE-F PEUX",NULL},
/* 16A20 */ { "BAMUM LETTER PHASE-F NTEE",NULL},
/* 16A21 */ { "BAMUM LETTER PHASE-F WUE",NULL},
/* 16A22 */ { "BAMUM LETTER PHASE-F PEE",NULL},
/* 16A23 */ { "BAMUM LETTER PHASE-F RU",NULL},
/* 16A24 */ { "BAMUM LETTER PHASE-F NI",NULL},
/* 16A25 */ { "BAMUM LETTER PHASE-F REUX",NULL},
/* 16A26 */ { "BAMUM LETTER PHASE-F KEN",NULL},
/* 16A27 */ { "BAMUM LETTER PHASE-F NGKWAEN",NULL},
/* 16A28 */ { "BAMUM LETTER PHASE-F NGGA",NULL},
/* 16A29 */ { "BAMUM LETTER PHASE-F SHO",NULL},
/* 16A2A */ { "BAMUM LETTER PHASE-F PUAE",NULL},
/* 16A2B */ { "BAMUM LETTER PHASE-F FOM",NULL},
/* 16A2C */ { "BAMUM LETTER PHASE-F WA",NULL},
/* 16A2D */ { "BAMUM LETTER PHASE-F LI",NULL},
/* 16A2E */ { "BAMUM LETTER PHASE-F LOQ",NULL},
/* 16A2F */ { "BAMUM LETTER PHASE-F KO",NULL},
/* 16A30 */ { "BAMUM LETTER PHASE-F MBEN",NULL},
/* 16A31 */ { "BAMUM LETTER PHASE-F REN",NULL},
/* 16A32 */ { "BAMUM LETTER PHASE-F MA",NULL},
/* 16A33 */ { "BAMUM LETTER PHASE-F MO",NULL},
/* 16A34 */ { "BAMUM LETTER PHASE-F MBAA",NULL},
/* 16A35 */ { "BAMUM LETTER PHASE-F TET",NULL},
/* 16A36 */ { "BAMUM LETTER PHASE-F KPA",NULL},
/* 16A37 */ { "BAMUM LETTER PHASE-F SAMBA",NULL},
/* 16A38 */ { "BAMUM LETTER PHASE-F VUEQ","	* used after 169F9 for kovue '9' in Phases A-D"},
/* 16A39 */ { NULL,NULL},
/* 16A3A */ { NULL,NULL},
/* 16A3B */ { NULL,NULL},
/* 16A3C */ { NULL,NULL},
/* 16A3D */ { NULL,NULL},
/* 16A3E */ { NULL,NULL},
/* 16A3F */ { NULL,NULL},
/* 16A40 */ { "MRO LETTER TA",NULL},
/* 16A41 */ { "MRO LETTER NGI",NULL},
/* 16A42 */ { "MRO LETTER YO",NULL},
/* 16A43 */ { "MRO LETTER MIM",NULL},
/* 16A44 */ { "MRO LETTER BA",NULL},
/* 16A45 */ { "MRO LETTER DA",NULL},
/* 16A46 */ { "MRO LETTER A",NULL},
/* 16A47 */ { "MRO LETTER PHI",NULL},
/* 16A48 */ { "MRO LETTER KHAI",NULL},
/* 16A49 */ { "MRO LETTER HAO",NULL},
/* 16A4A */ { "MRO LETTER DAI","	= i"},
/* 16A4B */ { "MRO LETTER CHU",NULL},
/* 16A4C */ { "MRO LETTER KEAAE",NULL},
/* 16A4D */ { "MRO LETTER OL",NULL},
/* 16A4E */ { "MRO LETTER MAEM",NULL},
/* 16A4F */ { "MRO LETTER NIN",NULL},
/* 16A50 */ { "MRO LETTER PA",NULL},
/* 16A51 */ { "MRO LETTER OO",NULL},
/* 16A52 */ { "MRO LETTER O",NULL},
/* 16A53 */ { "MRO LETTER RO",NULL},
/* 16A54 */ { "MRO LETTER SHI",NULL},
/* 16A55 */ { "MRO LETTER THEA",NULL},
/* 16A56 */ { "MRO LETTER EA",NULL},
/* 16A57 */ { "MRO LETTER WA",NULL},
/* 16A58 */ { "MRO LETTER E",NULL},
/* 16A59 */ { "MRO LETTER KO",NULL},
/* 16A5A */ { "MRO LETTER LAN",NULL},
/* 16A5B */ { "MRO LETTER LA","	* symbol for 'month'"},
/* 16A5C */ { "MRO LETTER HAI",NULL},
/* 16A5D */ { "MRO LETTER RI","	= o"},
/* 16A5E */ { "MRO LETTER TEK",NULL},
/* 16A5F */ { NULL,NULL},
/* 16A60 */ { "MRO DIGIT ZERO",NULL},
/* 16A61 */ { "MRO DIGIT ONE",NULL},
/* 16A62 */ { "MRO DIGIT TWO",NULL},
/* 16A63 */ { "MRO DIGIT THREE",NULL},
/* 16A64 */ { "MRO DIGIT FOUR",NULL},
/* 16A65 */ { "MRO DIGIT FIVE",NULL},
/* 16A66 */ { "MRO DIGIT SIX",NULL},
/* 16A67 */ { "MRO DIGIT SEVEN",NULL},
/* 16A68 */ { "MRO DIGIT EIGHT",NULL},
/* 16A69 */ { "MRO DIGIT NINE",NULL},
/* 16A6A */ { NULL,NULL},
/* 16A6B */ { NULL,NULL},
/* 16A6C */ { NULL,NULL},
/* 16A6D */ { NULL,NULL},
/* 16A6E */ { "MRO DANDA",NULL},
/* 16A6F */ { "MRO DOUBLE DANDA",NULL},
/* 16A70 */ { "TANGSA LETTER OZ",NULL},
/* 16A71 */ { "TANGSA LETTER OC",NULL},
/* 16A72 */ { "TANGSA LETTER OQ",NULL},
/* 16A73 */ { "TANGSA LETTER OX",NULL},
/* 16A74 */ { "TANGSA LETTER AZ",NULL},
/* 16A75 */ { "TANGSA LETTER AC",NULL},
/* 16A76 */ { "TANGSA LETTER AQ",NULL},
/* 16A77 */ { "TANGSA LETTER AX",NULL},
/* 16A78 */ { "TANGSA LETTER VZ",NULL},
/* 16A79 */ { "TANGSA LETTER VC",NULL},
/* 16A7A */ { "TANGSA LETTER VQ",NULL},
/* 16A7B */ { "TANGSA LETTER VX",NULL},
/* 16A7C */ { "TANGSA LETTER EZ",NULL},
/* 16A7D */ { "TANGSA LETTER EC",NULL},
/* 16A7E */ { "TANGSA LETTER EQ",NULL},
/* 16A7F */ { "TANGSA LETTER EX",NULL},
/* 16A80 */ { "TANGSA LETTER IZ",NULL},
/* 16A81 */ { "TANGSA LETTER IC",NULL},
/* 16A82 */ { "TANGSA LETTER IQ",NULL},
/* 16A83 */ { "TANGSA LETTER IX",NULL},
/* 16A84 */ { "TANGSA LETTER UZ",NULL},
/* 16A85 */ { "TANGSA LETTER UC",NULL},
/* 16A86 */ { "TANGSA LETTER UQ",NULL},
/* 16A87 */ { "TANGSA LETTER UX",NULL},
/* 16A88 */ { "TANGSA LETTER AWZ",NULL},
/* 16A89 */ { "TANGSA LETTER AWC",NULL},
/* 16A8A */ { "TANGSA LETTER AWQ",NULL},
/* 16A8B */ { "TANGSA LETTER AWX",NULL},
/* 16A8C */ { "TANGSA LETTER UIZ",NULL},
/* 16A8D */ { "TANGSA LETTER UIC",NULL},
/* 16A8E */ { "TANGSA LETTER UIQ",NULL},
/* 16A8F */ { "TANGSA LETTER UIX",NULL},
/* 16A90 */ { "TANGSA LETTER FINAL NG",NULL},
/* 16A91 */ { "TANGSA LETTER LONG UEX",NULL},
/* 16A92 */ { "TANGSA LETTER SHORT UEZ",NULL},
/* 16A93 */ { "TANGSA LETTER SHORT AWX",NULL},
/* 16A94 */ { "TANGSA LETTER UEC",NULL},
/* 16A95 */ { "TANGSA LETTER UEZ",NULL},
/* 16A96 */ { "TANGSA LETTER UEQ",NULL},
/* 16A97 */ { "TANGSA LETTER UEX",NULL},
/* 16A98 */ { "TANGSA LETTER UIUZ",NULL},
/* 16A99 */ { "TANGSA LETTER UIUC",NULL},
/* 16A9A */ { "TANGSA LETTER UIUQ",NULL},
/* 16A9B */ { "TANGSA LETTER UIUX",NULL},
/* 16A9C */ { "TANGSA LETTER MZ",NULL},
/* 16A9D */ { "TANGSA LETTER MC",NULL},
/* 16A9E */ { "TANGSA LETTER MQ",NULL},
/* 16A9F */ { "TANGSA LETTER MX",NULL},
/* 16AA0 */ { "TANGSA LETTER KA",NULL},
/* 16AA1 */ { "TANGSA LETTER KHA",NULL},
/* 16AA2 */ { "TANGSA LETTER GA",NULL},
/* 16AA3 */ { "TANGSA LETTER NGA",NULL},
/* 16AA4 */ { "TANGSA LETTER SA",NULL},
/* 16AA5 */ { "TANGSA LETTER YA",NULL},
/* 16AA6 */ { "TANGSA LETTER WA",NULL},
/* 16AA7 */ { "TANGSA LETTER PA",NULL},
/* 16AA8 */ { "TANGSA LETTER NYA",NULL},
/* 16AA9 */ { "TANGSA LETTER PHA",NULL},
/* 16AAA */ { "TANGSA LETTER BA",NULL},
/* 16AAB */ { "TANGSA LETTER MA",NULL},
/* 16AAC */ { "TANGSA LETTER NA",NULL},
/* 16AAD */ { "TANGSA LETTER HA",NULL},
/* 16AAE */ { "TANGSA LETTER LA",NULL},
/* 16AAF */ { "TANGSA LETTER HTA",NULL},
/* 16AB0 */ { "TANGSA LETTER TA",NULL},
/* 16AB1 */ { "TANGSA LETTER DA",NULL},
/* 16AB2 */ { "TANGSA LETTER RA",NULL},
/* 16AB3 */ { "TANGSA LETTER NHA",NULL},
/* 16AB4 */ { "TANGSA LETTER SHA",NULL},
/* 16AB5 */ { "TANGSA LETTER CA",NULL},
/* 16AB6 */ { "TANGSA LETTER TSA",NULL},
/* 16AB7 */ { "TANGSA LETTER GHA",NULL},
/* 16AB8 */ { "TANGSA LETTER HTTA",NULL},
/* 16AB9 */ { "TANGSA LETTER THA",NULL},
/* 16ABA */ { "TANGSA LETTER XA",NULL},
/* 16ABB */ { "TANGSA LETTER FA",NULL},
/* 16ABC */ { "TANGSA LETTER DHA",NULL},
/* 16ABD */ { "TANGSA LETTER CHA",NULL},
/* 16ABE */ { "TANGSA LETTER ZA",NULL},
/* 16ABF */ { NULL,NULL},
/* 16AC0 */ { "TANGSA DIGIT ZERO",NULL},
/* 16AC1 */ { "TANGSA DIGIT ONE",NULL},
/* 16AC2 */ { "TANGSA DIGIT TWO",NULL},
/* 16AC3 */ { "TANGSA DIGIT THREE",NULL},
/* 16AC4 */ { "TANGSA DIGIT FOUR",NULL},
/* 16AC5 */ { "TANGSA DIGIT FIVE",NULL},
/* 16AC6 */ { "TANGSA DIGIT SIX",NULL},
/* 16AC7 */ { "TANGSA DIGIT SEVEN",NULL},
/* 16AC8 */ { "TANGSA DIGIT EIGHT",NULL},
/* 16AC9 */ { "TANGSA DIGIT NINE",NULL},
/* 16ACA */ { NULL,NULL},
/* 16ACB */ { NULL,NULL},
/* 16ACC */ { NULL,NULL},
/* 16ACD */ { NULL,NULL},
/* 16ACE */ { NULL,NULL},
/* 16ACF */ { NULL,NULL},
/* 16AD0 */ { "BASSA VAH LETTER ENNI",NULL},
/* 16AD1 */ { "BASSA VAH LETTER KA",NULL},
/* 16AD2 */ { "BASSA VAH LETTER SE",NULL},
/* 16AD3 */ { "BASSA VAH LETTER FA",NULL},
/* 16AD4 */ { "BASSA VAH LETTER MBE",NULL},
/* 16AD5 */ { "BASSA VAH LETTER YIE",NULL},
/* 16AD6 */ { "BASSA VAH LETTER GAH",NULL},
/* 16AD7 */ { "BASSA VAH LETTER DHII",NULL},
/* 16AD8 */ { "BASSA VAH LETTER KPAH",NULL},
/* 16AD9 */ { "BASSA VAH LETTER JO",NULL},
/* 16ADA */ { "BASSA VAH LETTER HWAH",NULL},
/* 16ADB */ { "BASSA VAH LETTER WA",NULL},
/* 16ADC */ { "BASSA VAH LETTER ZO",NULL},
/* 16ADD */ { "BASSA VAH LETTER GBU",NULL},
/* 16ADE */ { "BASSA VAH LETTER DO",NULL},
/* 16ADF */ { "BASSA VAH LETTER CE",NULL},
/* 16AE0 */ { "BASSA VAH LETTER UWU",NULL},
/* 16AE1 */ { "BASSA VAH LETTER TO",NULL},
/* 16AE2 */ { "BASSA VAH LETTER BA",NULL},
/* 16AE3 */ { "BASSA VAH LETTER VU",NULL},
/* 16AE4 */ { "BASSA VAH LETTER YEIN",NULL},
/* 16AE5 */ { "BASSA VAH LETTER PA",NULL},
/* 16AE6 */ { "BASSA VAH LETTER WADDA",NULL},
/* 16AE7 */ { "BASSA VAH LETTER A",NULL},
/* 16AE8 */ { "BASSA VAH LETTER O",NULL},
/* 16AE9 */ { "BASSA VAH LETTER OO",NULL},
/* 16AEA */ { "BASSA VAH LETTER U",NULL},
/* 16AEB */ { "BASSA VAH LETTER EE",NULL},
/* 16AEC */ { "BASSA VAH LETTER E",NULL},
/* 16AED */ { "BASSA VAH LETTER I",NULL},
/* 16AEE */ { NULL,NULL},
/* 16AEF */ { NULL,NULL},
/* 16AF0 */ { "BASSA VAH COMBINING HIGH TONE",NULL},
/* 16AF1 */ { "BASSA VAH COMBINING LOW TONE",NULL},
/* 16AF2 */ { "BASSA VAH COMBINING MID TONE",NULL},
/* 16AF3 */ { "BASSA VAH COMBINING LOW-MID TONE",NULL},
/* 16AF4 */ { "BASSA VAH COMBINING HIGH-LOW TONE",NULL},
/* 16AF5 */ { "BASSA VAH FULL STOP",NULL},
/* 16AF6 */ { NULL,NULL},
/* 16AF7 */ { NULL,NULL},
/* 16AF8 */ { NULL,NULL},
/* 16AF9 */ { NULL,NULL},
/* 16AFA */ { NULL,NULL},
/* 16AFB */ { NULL,NULL},
/* 16AFC */ { NULL,NULL},
/* 16AFD */ { NULL,NULL},
/* 16AFE */ { NULL,NULL},
/* 16AFF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_6B[] = {
/* 16B00 */ { "PAHAWH HMONG VOWEL KEEB","	= keem"},
/* 16B01 */ { "PAHAWH HMONG VOWEL KEEV","	= kee"},
/* 16B02 */ { "PAHAWH HMONG VOWEL KIB","	= kim"},
/* 16B03 */ { "PAHAWH HMONG VOWEL KIV","	= ki"},
/* 16B04 */ { "PAHAWH HMONG VOWEL KAUB","	= kaum"},
/* 16B05 */ { "PAHAWH HMONG VOWEL KAUV","	= kau"},
/* 16B06 */ { "PAHAWH HMONG VOWEL KUB","	= kum"},
/* 16B07 */ { "PAHAWH HMONG VOWEL KUV","	= ke"},
/* 16B08 */ { "PAHAWH HMONG VOWEL KEB","	= kem"},
/* 16B09 */ { "PAHAWH HMONG VOWEL KEV",NULL},
/* 16B0A */ { "PAHAWH HMONG VOWEL KAIB","	= kaim"},
/* 16B0B */ { "PAHAWH HMONG VOWEL KAIV","	= kai"},
/* 16B0C */ { "PAHAWH HMONG VOWEL KOOB",NULL},
/* 16B0D */ { "PAHAWH HMONG VOWEL KOOV",NULL},
/* 16B0E */ { "PAHAWH HMONG VOWEL KAWB",NULL},
/* 16B0F */ { "PAHAWH HMONG VOWEL KAWV","	= kaw"},
/* 16B10 */ { "PAHAWH HMONG VOWEL KUAB","	= kuam"},
/* 16B11 */ { "PAHAWH HMONG VOWEL KUAV","	= kua"},
/* 16B12 */ { "PAHAWH HMONG VOWEL KOB","	= kom"},
/* 16B13 */ { "PAHAWH HMONG VOWEL KOV","	= kog"},
/* 16B14 */ { "PAHAWH HMONG VOWEL KIAB",NULL},
/* 16B15 */ { "PAHAWH HMONG VOWEL KIAV","	= kia"},
/* 16B16 */ { "PAHAWH HMONG VOWEL KAB","	= kam"},
/* 16B17 */ { "PAHAWH HMONG VOWEL KAV",NULL},
/* 16B18 */ { "PAHAWH HMONG VOWEL KWB","	= kwm"},
/* 16B19 */ { "PAHAWH HMONG VOWEL KWV",NULL},
/* 16B1A */ { "PAHAWH HMONG VOWEL KAAB","	= kaam"},
/* 16B1B */ { "PAHAWH HMONG VOWEL KAAV",NULL},
/* 16B1C */ { "PAHAWH HMONG CONSONANT VAU",NULL},
/* 16B1D */ { "PAHAWH HMONG CONSONANT NTSAU",NULL},
/* 16B1E */ { "PAHAWH HMONG CONSONANT LAU",NULL},
/* 16B1F */ { "PAHAWH HMONG CONSONANT HAU",NULL},
/* 16B20 */ { "PAHAWH HMONG CONSONANT NLAU",NULL},
/* 16B21 */ { "PAHAWH HMONG CONSONANT RAU",NULL},
/* 16B22 */ { "PAHAWH HMONG CONSONANT NKAU",NULL},
/* 16B23 */ { "PAHAWH HMONG CONSONANT QHAU",NULL},
/* 16B24 */ { "PAHAWH HMONG CONSONANT YAU",NULL},
/* 16B25 */ { "PAHAWH HMONG CONSONANT HLAU",NULL},
/* 16B26 */ { "PAHAWH HMONG CONSONANT MAU",NULL},
/* 16B27 */ { "PAHAWH HMONG CONSONANT CHAU",NULL},
/* 16B28 */ { "PAHAWH HMONG CONSONANT NCHAU",NULL},
/* 16B29 */ { "PAHAWH HMONG CONSONANT HNAU",NULL},
/* 16B2A */ { "PAHAWH HMONG CONSONANT PLHAU",NULL},
/* 16B2B */ { "PAHAWH HMONG CONSONANT NTHAU",NULL},
/* 16B2C */ { "PAHAWH HMONG CONSONANT NAU",NULL},
/* 16B2D */ { "PAHAWH HMONG CONSONANT AU",NULL},
/* 16B2E */ { "PAHAWH HMONG CONSONANT XAU",NULL},
/* 16B2F */ { "PAHAWH HMONG CONSONANT CAU",NULL},
/* 16B30 */ { "PAHAWH HMONG MARK CIM TUB",NULL},
/* 16B31 */ { "PAHAWH HMONG MARK CIM SO",NULL},
/* 16B32 */ { "PAHAWH HMONG MARK CIM KES",NULL},
/* 16B33 */ { "PAHAWH HMONG MARK CIM KHAV",NULL},
/* 16B34 */ { "PAHAWH HMONG MARK CIM SUAM",NULL},
/* 16B35 */ { "PAHAWH HMONG MARK CIM HOM",NULL},
/* 16B36 */ { "PAHAWH HMONG MARK CIM TAUM",NULL},
/* 16B37 */ { "PAHAWH HMONG SIGN VOS THOM","	* functions as a question mark"},
/* 16B38 */ { "PAHAWH HMONG SIGN VOS TSHAB CEEB","	* functions as an exclamation mark"},
/* 16B39 */ { "PAHAWH HMONG SIGN CIM CHEEM","	* functions as a comma"},
/* 16B3A */ { "PAHAWH HMONG SIGN VOS THIAB","	* functions as an ampersand\n"
	"	x (ampersand - 0026)"},
/* 16B3B */ { "PAHAWH HMONG SIGN VOS FEEM","	* functions as a percent sign\n"
	"	x (percent sign - 0025)"},
/* 16B3C */ { "PAHAWH HMONG SIGN XYEEM NTXIV","	* functions as a plus sign"},
/* 16B3D */ { "PAHAWH HMONG SIGN XYEEM RHO","	* functions as a minus sign"},
/* 16B3E */ { "PAHAWH HMONG SIGN XYEEM TOV","	* functions as a multiplication sign"},
/* 16B3F */ { "PAHAWH HMONG SIGN XYEEM FAIB","	* functions as a division sign"},
/* 16B40 */ { "PAHAWH HMONG SIGN VOS SEEV","	* indicates chanting intonation"},
/* 16B41 */ { "PAHAWH HMONG SIGN MEEJ SUAB","	* indicates foreign pronunciation"},
/* 16B42 */ { "PAHAWH HMONG SIGN VOS NRUA","	* reduplication"},
/* 16B43 */ { "PAHAWH HMONG SIGN IB YAM","	* replication, ditto mark"},
/* 16B44 */ { "PAHAWH HMONG SIGN XAUS","	* indicates completion of a section"},
/* 16B45 */ { "PAHAWH HMONG SIGN CIM TSOV ROG","	* indicates military topics"},
/* 16B46 */ { NULL,NULL},
/* 16B47 */ { NULL,NULL},
/* 16B48 */ { NULL,NULL},
/* 16B49 */ { NULL,NULL},
/* 16B4A */ { NULL,NULL},
/* 16B4B */ { NULL,NULL},
/* 16B4C */ { NULL,NULL},
/* 16B4D */ { NULL,NULL},
/* 16B4E */ { NULL,NULL},
/* 16B4F */ { NULL,NULL},
/* 16B50 */ { "PAHAWH HMONG DIGIT ZERO","	* some users prefer a circular glyph for this character"},
/* 16B51 */ { "PAHAWH HMONG DIGIT ONE",NULL},
/* 16B52 */ { "PAHAWH HMONG DIGIT TWO",NULL},
/* 16B53 */ { "PAHAWH HMONG DIGIT THREE",NULL},
/* 16B54 */ { "PAHAWH HMONG DIGIT FOUR",NULL},
/* 16B55 */ { "PAHAWH HMONG DIGIT FIVE",NULL},
/* 16B56 */ { "PAHAWH HMONG DIGIT SIX",NULL},
/* 16B57 */ { "PAHAWH HMONG DIGIT SEVEN",NULL},
/* 16B58 */ { "PAHAWH HMONG DIGIT EIGHT",NULL},
/* 16B59 */ { "PAHAWH HMONG DIGIT NINE",NULL},
/* 16B5A */ { NULL,NULL},
/* 16B5B */ { "PAHAWH HMONG NUMBER TENS","	= caum\n"
	"	* some users prefer a vertical bar glyph for this character"},
/* 16B5C */ { "PAHAWH HMONG NUMBER HUNDREDS","	= pua"},
/* 16B5D */ { "PAHAWH HMONG NUMBER TEN THOUSANDS","	= vam"},
/* 16B5E */ { "PAHAWH HMONG NUMBER MILLIONS","	= roob"},
/* 16B5F */ { "PAHAWH HMONG NUMBER HUNDRED MILLIONS","	= neev"},
/* 16B60 */ { "PAHAWH HMONG NUMBER TEN BILLIONS","	= ruav"},
/* 16B61 */ { "PAHAWH HMONG NUMBER TRILLIONS","	= tas"},
/* 16B62 */ { NULL,NULL},
/* 16B63 */ { "PAHAWH HMONG SIGN VOS LUB","	* a classifier"},
/* 16B64 */ { "PAHAWH HMONG SIGN XYOO","	= year"},
/* 16B65 */ { "PAHAWH HMONG SIGN HLI","	= month"},
/* 16B66 */ { "PAHAWH HMONG SIGN THIRD-STAGE HLI","	= month"},
/* 16B67 */ { "PAHAWH HMONG SIGN ZWJ THAJ","	= date"},
/* 16B68 */ { "PAHAWH HMONG SIGN HNUB","	= day"},
/* 16B69 */ { "PAHAWH HMONG SIGN NQIG","	= waning moon"},
/* 16B6A */ { "PAHAWH HMONG SIGN XIAB","	= waxing moon"},
/* 16B6B */ { "PAHAWH HMONG SIGN NTUJ","	= season"},
/* 16B6C */ { "PAHAWH HMONG SIGN AV","	= earth"},
/* 16B6D */ { "PAHAWH HMONG SIGN TXHEEJ CEEV","	= urgent"},
/* 16B6E */ { "PAHAWH HMONG SIGN MEEJ TSEEB","	= facts"},
/* 16B6F */ { "PAHAWH HMONG SIGN TAU","	= received"},
/* 16B70 */ { "PAHAWH HMONG SIGN LOS","	= come"},
/* 16B71 */ { "PAHAWH HMONG SIGN MUS","	= go"},
/* 16B72 */ { "PAHAWH HMONG SIGN CIM HAIS LUS NTOG NTOG","	= smooth"},
/* 16B73 */ { "PAHAWH HMONG SIGN CIM CUAM TSHOOJ","	= fraction"},
/* 16B74 */ { "PAHAWH HMONG SIGN CIM TXWV","	= do not open"},
/* 16B75 */ { "PAHAWH HMONG SIGN CIM TXWV CHWV","	= do not touch"},
/* 16B76 */ { "PAHAWH HMONG SIGN CIM PUB DAWB","	= give freely"},
/* 16B77 */ { "PAHAWH HMONG SIGN CIM NRES TOS","	= stop"},
/* 16B78 */ { NULL,NULL},
/* 16B79 */ { NULL,NULL},
/* 16B7A */ { NULL,NULL},
/* 16B7B */ { NULL,NULL},
/* 16B7C */ { NULL,NULL},
/* 16B7D */ { "PAHAWH HMONG CLAN SIGN TSHEEJ","	= Cheng"},
/* 16B7E */ { "PAHAWH HMONG CLAN SIGN YEEG","	= Yeng"},
/* 16B7F */ { "PAHAWH HMONG CLAN SIGN LIS","	= Lee"},
/* 16B80 */ { "PAHAWH HMONG CLAN SIGN LAUJ","	= Lor"},
/* 16B81 */ { "PAHAWH HMONG CLAN SIGN XYOOJ","	= Xiong"},
/* 16B82 */ { "PAHAWH HMONG CLAN SIGN KOO","	= Kong"},
/* 16B83 */ { "PAHAWH HMONG CLAN SIGN HAWJ","	= Her"},
/* 16B84 */ { "PAHAWH HMONG CLAN SIGN MUAS","	= Moua"},
/* 16B85 */ { "PAHAWH HMONG CLAN SIGN THOJ","	= Thao"},
/* 16B86 */ { "PAHAWH HMONG CLAN SIGN TSAB","	= Chang"},
/* 16B87 */ { "PAHAWH HMONG CLAN SIGN PHAB","	= Pha"},
/* 16B88 */ { "PAHAWH HMONG CLAN SIGN KHAB","	= Khang"},
/* 16B89 */ { "PAHAWH HMONG CLAN SIGN HAM","	= Hang"},
/* 16B8A */ { "PAHAWH HMONG CLAN SIGN VAJ","	= Vang"},
/* 16B8B */ { "PAHAWH HMONG CLAN SIGN FAJ","	= Fang"},
/* 16B8C */ { "PAHAWH HMONG CLAN SIGN YAJ","	= Yang"},
/* 16B8D */ { "PAHAWH HMONG CLAN SIGN TSWB","	= Chue"},
/* 16B8E */ { "PAHAWH HMONG CLAN SIGN KWM","	= Kw"},
/* 16B8F */ { "PAHAWH HMONG CLAN SIGN VWJ","	= Vue"},
/* 16B90 */ { NULL,NULL},
/* 16B91 */ { NULL,NULL},
/* 16B92 */ { NULL,NULL},
/* 16B93 */ { NULL,NULL},
/* 16B94 */ { NULL,NULL},
/* 16B95 */ { NULL,NULL},
/* 16B96 */ { NULL,NULL},
/* 16B97 */ { NULL,NULL},
/* 16B98 */ { NULL,NULL},
/* 16B99 */ { NULL,NULL},
/* 16B9A */ { NULL,NULL},
/* 16B9B */ { NULL,NULL},
/* 16B9C */ { NULL,NULL},
/* 16B9D */ { NULL,NULL},
/* 16B9E */ { NULL,NULL},
/* 16B9F */ { NULL,NULL},
/* 16BA0 */ { NULL,NULL},
/* 16BA1 */ { NULL,NULL},
/* 16BA2 */ { NULL,NULL},
/* 16BA3 */ { NULL,NULL},
/* 16BA4 */ { NULL,NULL},
/* 16BA5 */ { NULL,NULL},
/* 16BA6 */ { NULL,NULL},
/* 16BA7 */ { NULL,NULL},
/* 16BA8 */ { NULL,NULL},
/* 16BA9 */ { NULL,NULL},
/* 16BAA */ { NULL,NULL},
/* 16BAB */ { NULL,NULL},
/* 16BAC */ { NULL,NULL},
/* 16BAD */ { NULL,NULL},
/* 16BAE */ { NULL,NULL},
/* 16BAF */ { NULL,NULL},
/* 16BB0 */ { NULL,NULL},
/* 16BB1 */ { NULL,NULL},
/* 16BB2 */ { NULL,NULL},
/* 16BB3 */ { NULL,NULL},
/* 16BB4 */ { NULL,NULL},
/* 16BB5 */ { NULL,NULL},
/* 16BB6 */ { NULL,NULL},
/* 16BB7 */ { NULL,NULL},
/* 16BB8 */ { NULL,NULL},
/* 16BB9 */ { NULL,NULL},
/* 16BBA */ { NULL,NULL},
/* 16BBB */ { NULL,NULL},
/* 16BBC */ { NULL,NULL},
/* 16BBD */ { NULL,NULL},
/* 16BBE */ { NULL,NULL},
/* 16BBF */ { NULL,NULL},
/* 16BC0 */ { NULL,NULL},
/* 16BC1 */ { NULL,NULL},
/* 16BC2 */ { NULL,NULL},
/* 16BC3 */ { NULL,NULL},
/* 16BC4 */ { NULL,NULL},
/* 16BC5 */ { NULL,NULL},
/* 16BC6 */ { NULL,NULL},
/* 16BC7 */ { NULL,NULL},
/* 16BC8 */ { NULL,NULL},
/* 16BC9 */ { NULL,NULL},
/* 16BCA */ { NULL,NULL},
/* 16BCB */ { NULL,NULL},
/* 16BCC */ { NULL,NULL},
/* 16BCD */ { NULL,NULL},
/* 16BCE */ { NULL,NULL},
/* 16BCF */ { NULL,NULL},
/* 16BD0 */ { NULL,NULL},
/* 16BD1 */ { NULL,NULL},
/* 16BD2 */ { NULL,NULL},
/* 16BD3 */ { NULL,NULL},
/* 16BD4 */ { NULL,NULL},
/* 16BD5 */ { NULL,NULL},
/* 16BD6 */ { NULL,NULL},
/* 16BD7 */ { NULL,NULL},
/* 16BD8 */ { NULL,NULL},
/* 16BD9 */ { NULL,NULL},
/* 16BDA */ { NULL,NULL},
/* 16BDB */ { NULL,NULL},
/* 16BDC */ { NULL,NULL},
/* 16BDD */ { NULL,NULL},
/* 16BDE */ { NULL,NULL},
/* 16BDF */ { NULL,NULL},
/* 16BE0 */ { NULL,NULL},
/* 16BE1 */ { NULL,NULL},
/* 16BE2 */ { NULL,NULL},
/* 16BE3 */ { NULL,NULL},
/* 16BE4 */ { NULL,NULL},
/* 16BE5 */ { NULL,NULL},
/* 16BE6 */ { NULL,NULL},
/* 16BE7 */ { NULL,NULL},
/* 16BE8 */ { NULL,NULL},
/* 16BE9 */ { NULL,NULL},
/* 16BEA */ { NULL,NULL},
/* 16BEB */ { NULL,NULL},
/* 16BEC */ { NULL,NULL},
/* 16BED */ { NULL,NULL},
/* 16BEE */ { NULL,NULL},
/* 16BEF */ { NULL,NULL},
/* 16BF0 */ { NULL,NULL},
/* 16BF1 */ { NULL,NULL},
/* 16BF2 */ { NULL,NULL},
/* 16BF3 */ { NULL,NULL},
/* 16BF4 */ { NULL,NULL},
/* 16BF5 */ { NULL,NULL},
/* 16BF6 */ { NULL,NULL},
/* 16BF7 */ { NULL,NULL},
/* 16BF8 */ { NULL,NULL},
/* 16BF9 */ { NULL,NULL},
/* 16BFA */ { NULL,NULL},
/* 16BFB */ { NULL,NULL},
/* 16BFC */ { NULL,NULL},
/* 16BFD */ { NULL,NULL},
/* 16BFE */ { NULL,NULL},
/* 16BFF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_6D[] = {
/* 16D00 */ { NULL,NULL},
/* 16D01 */ { NULL,NULL},
/* 16D02 */ { NULL,NULL},
/* 16D03 */ { NULL,NULL},
/* 16D04 */ { NULL,NULL},
/* 16D05 */ { NULL,NULL},
/* 16D06 */ { NULL,NULL},
/* 16D07 */ { NULL,NULL},
/* 16D08 */ { NULL,NULL},
/* 16D09 */ { NULL,NULL},
/* 16D0A */ { NULL,NULL},
/* 16D0B */ { NULL,NULL},
/* 16D0C */ { NULL,NULL},
/* 16D0D */ { NULL,NULL},
/* 16D0E */ { NULL,NULL},
/* 16D0F */ { NULL,NULL},
/* 16D10 */ { NULL,NULL},
/* 16D11 */ { NULL,NULL},
/* 16D12 */ { NULL,NULL},
/* 16D13 */ { NULL,NULL},
/* 16D14 */ { NULL,NULL},
/* 16D15 */ { NULL,NULL},
/* 16D16 */ { NULL,NULL},
/* 16D17 */ { NULL,NULL},
/* 16D18 */ { NULL,NULL},
/* 16D19 */ { NULL,NULL},
/* 16D1A */ { NULL,NULL},
/* 16D1B */ { NULL,NULL},
/* 16D1C */ { NULL,NULL},
/* 16D1D */ { NULL,NULL},
/* 16D1E */ { NULL,NULL},
/* 16D1F */ { NULL,NULL},
/* 16D20 */ { NULL,NULL},
/* 16D21 */ { NULL,NULL},
/* 16D22 */ { NULL,NULL},
/* 16D23 */ { NULL,NULL},
/* 16D24 */ { NULL,NULL},
/* 16D25 */ { NULL,NULL},
/* 16D26 */ { NULL,NULL},
/* 16D27 */ { NULL,NULL},
/* 16D28 */ { NULL,NULL},
/* 16D29 */ { NULL,NULL},
/* 16D2A */ { NULL,NULL},
/* 16D2B */ { NULL,NULL},
/* 16D2C */ { NULL,NULL},
/* 16D2D */ { NULL,NULL},
/* 16D2E */ { NULL,NULL},
/* 16D2F */ { NULL,NULL},
/* 16D30 */ { NULL,NULL},
/* 16D31 */ { NULL,NULL},
/* 16D32 */ { NULL,NULL},
/* 16D33 */ { NULL,NULL},
/* 16D34 */ { NULL,NULL},
/* 16D35 */ { NULL,NULL},
/* 16D36 */ { NULL,NULL},
/* 16D37 */ { NULL,NULL},
/* 16D38 */ { NULL,NULL},
/* 16D39 */ { NULL,NULL},
/* 16D3A */ { NULL,NULL},
/* 16D3B */ { NULL,NULL},
/* 16D3C */ { NULL,NULL},
/* 16D3D */ { NULL,NULL},
/* 16D3E */ { NULL,NULL},
/* 16D3F */ { NULL,NULL},
/* 16D40 */ { "KIRAT RAI SIGN ANUSVARA",NULL},
/* 16D41 */ { "KIRAT RAI SIGN TONPI",NULL},
/* 16D42 */ { "KIRAT RAI SIGN VISARGA",NULL},
/* 16D43 */ { "KIRAT RAI LETTER A",NULL},
/* 16D44 */ { "KIRAT RAI LETTER KA",NULL},
/* 16D45 */ { "KIRAT RAI LETTER KHA",NULL},
/* 16D46 */ { "KIRAT RAI LETTER GA",NULL},
/* 16D47 */ { "KIRAT RAI LETTER GHA",NULL},
/* 16D48 */ { "KIRAT RAI LETTER NGA",NULL},
/* 16D49 */ { "KIRAT RAI LETTER CA",NULL},
/* 16D4A */ { "KIRAT RAI LETTER CHA",NULL},
/* 16D4B */ { "KIRAT RAI LETTER JA",NULL},
/* 16D4C */ { "KIRAT RAI LETTER JHA",NULL},
/* 16D4D */ { "KIRAT RAI LETTER NYA",NULL},
/* 16D4E */ { "KIRAT RAI LETTER TTA",NULL},
/* 16D4F */ { "KIRAT RAI LETTER TTHA",NULL},
/* 16D50 */ { "KIRAT RAI LETTER DDA",NULL},
/* 16D51 */ { "KIRAT RAI LETTER DDHA",NULL},
/* 16D52 */ { "KIRAT RAI LETTER TA",NULL},
/* 16D53 */ { "KIRAT RAI LETTER THA",NULL},
/* 16D54 */ { "KIRAT RAI LETTER DA",NULL},
/* 16D55 */ { "KIRAT RAI LETTER DHA",NULL},
/* 16D56 */ { "KIRAT RAI LETTER NA",NULL},
/* 16D57 */ { "KIRAT RAI LETTER PA",NULL},
/* 16D58 */ { "KIRAT RAI LETTER PHA",NULL},
/* 16D59 */ { "KIRAT RAI LETTER BA",NULL},
/* 16D5A */ { "KIRAT RAI LETTER BHA",NULL},
/* 16D5B */ { "KIRAT RAI LETTER MA",NULL},
/* 16D5C */ { "KIRAT RAI LETTER YA",NULL},
/* 16D5D */ { "KIRAT RAI LETTER RA",NULL},
/* 16D5E */ { "KIRAT RAI LETTER LA",NULL},
/* 16D5F */ { "KIRAT RAI LETTER VA",NULL},
/* 16D60 */ { "KIRAT RAI LETTER SA",NULL},
/* 16D61 */ { "KIRAT RAI LETTER SHA",NULL},
/* 16D62 */ { "KIRAT RAI LETTER HA",NULL},
/* 16D63 */ { "KIRAT RAI VOWEL SIGN AA",NULL},
/* 16D64 */ { "KIRAT RAI VOWEL SIGN I",NULL},
/* 16D65 */ { "KIRAT RAI VOWEL SIGN U",NULL},
/* 16D66 */ { "KIRAT RAI VOWEL SIGN UE",NULL},
/* 16D67 */ { "KIRAT RAI VOWEL SIGN E",NULL},
/* 16D68 */ { "KIRAT RAI VOWEL SIGN AI","	: 16D67 16D67"},
/* 16D69 */ { "KIRAT RAI VOWEL SIGN O","	: 16D63 16D67"},
/* 16D6A */ { "KIRAT RAI VOWEL SIGN AU","	: 16D69 16D67"},
/* 16D6B */ { "KIRAT RAI SIGN VIRAMA",NULL},
/* 16D6C */ { "KIRAT RAI SIGN SAAT",NULL},
/* 16D6D */ { "KIRAT RAI SIGN YUPI",NULL},
/* 16D6E */ { "KIRAT RAI DANDA",NULL},
/* 16D6F */ { "KIRAT RAI DOUBLE DANDA",NULL},
/* 16D70 */ { "KIRAT RAI DIGIT ZERO",NULL},
/* 16D71 */ { "KIRAT RAI DIGIT ONE",NULL},
/* 16D72 */ { "KIRAT RAI DIGIT TWO",NULL},
/* 16D73 */ { "KIRAT RAI DIGIT THREE",NULL},
/* 16D74 */ { "KIRAT RAI DIGIT FOUR",NULL},
/* 16D75 */ { "KIRAT RAI DIGIT FIVE",NULL},
/* 16D76 */ { "KIRAT RAI DIGIT SIX",NULL},
/* 16D77 */ { "KIRAT RAI DIGIT SEVEN",NULL},
/* 16D78 */ { "KIRAT RAI DIGIT EIGHT",NULL},
/* 16D79 */ { "KIRAT RAI DIGIT NINE",NULL},
/* 16D7A */ { NULL,NULL},
/* 16D7B */ { NULL,NULL},
/* 16D7C */ { NULL,NULL},
/* 16D7D */ { NULL,NULL},
/* 16D7E */ { NULL,NULL},
/* 16D7F */ { NULL,NULL},
/* 16D80 */ { NULL,NULL},
/* 16D81 */ { NULL,NULL},
/* 16D82 */ { NULL,NULL},
/* 16D83 */ { NULL,NULL},
/* 16D84 */ { NULL,NULL},
/* 16D85 */ { NULL,NULL},
/* 16D86 */ { NULL,NULL},
/* 16D87 */ { NULL,NULL},
/* 16D88 */ { NULL,NULL},
/* 16D89 */ { NULL,NULL},
/* 16D8A */ { NULL,NULL},
/* 16D8B */ { NULL,NULL},
/* 16D8C */ { NULL,NULL},
/* 16D8D */ { NULL,NULL},
/* 16D8E */ { NULL,NULL},
/* 16D8F */ { NULL,NULL},
/* 16D90 */ { NULL,NULL},
/* 16D91 */ { NULL,NULL},
/* 16D92 */ { NULL,NULL},
/* 16D93 */ { NULL,NULL},
/* 16D94 */ { NULL,NULL},
/* 16D95 */ { NULL,NULL},
/* 16D96 */ { NULL,NULL},
/* 16D97 */ { NULL,NULL},
/* 16D98 */ { NULL,NULL},
/* 16D99 */ { NULL,NULL},
/* 16D9A */ { NULL,NULL},
/* 16D9B */ { NULL,NULL},
/* 16D9C */ { NULL,NULL},
/* 16D9D */ { NULL,NULL},
/* 16D9E */ { NULL,NULL},
/* 16D9F */ { NULL,NULL},
/* 16DA0 */ { NULL,NULL},
/* 16DA1 */ { NULL,NULL},
/* 16DA2 */ { NULL,NULL},
/* 16DA3 */ { NULL,NULL},
/* 16DA4 */ { NULL,NULL},
/* 16DA5 */ { NULL,NULL},
/* 16DA6 */ { NULL,NULL},
/* 16DA7 */ { NULL,NULL},
/* 16DA8 */ { NULL,NULL},
/* 16DA9 */ { NULL,NULL},
/* 16DAA */ { NULL,NULL},
/* 16DAB */ { NULL,NULL},
/* 16DAC */ { NULL,NULL},
/* 16DAD */ { NULL,NULL},
/* 16DAE */ { NULL,NULL},
/* 16DAF */ { NULL,NULL},
/* 16DB0 */ { NULL,NULL},
/* 16DB1 */ { NULL,NULL},
/* 16DB2 */ { NULL,NULL},
/* 16DB3 */ { NULL,NULL},
/* 16DB4 */ { NULL,NULL},
/* 16DB5 */ { NULL,NULL},
/* 16DB6 */ { NULL,NULL},
/* 16DB7 */ { NULL,NULL},
/* 16DB8 */ { NULL,NULL},
/* 16DB9 */ { NULL,NULL},
/* 16DBA */ { NULL,NULL},
/* 16DBB */ { NULL,NULL},
/* 16DBC */ { NULL,NULL},
/* 16DBD */ { NULL,NULL},
/* 16DBE */ { NULL,NULL},
/* 16DBF */ { NULL,NULL},
/* 16DC0 */ { NULL,NULL},
/* 16DC1 */ { NULL,NULL},
/* 16DC2 */ { NULL,NULL},
/* 16DC3 */ { NULL,NULL},
/* 16DC4 */ { NULL,NULL},
/* 16DC5 */ { NULL,NULL},
/* 16DC6 */ { NULL,NULL},
/* 16DC7 */ { NULL,NULL},
/* 16DC8 */ { NULL,NULL},
/* 16DC9 */ { NULL,NULL},
/* 16DCA */ { NULL,NULL},
/* 16DCB */ { NULL,NULL},
/* 16DCC */ { NULL,NULL},
/* 16DCD */ { NULL,NULL},
/* 16DCE */ { NULL,NULL},
/* 16DCF */ { NULL,NULL},
/* 16DD0 */ { NULL,NULL},
/* 16DD1 */ { NULL,NULL},
/* 16DD2 */ { NULL,NULL},
/* 16DD3 */ { NULL,NULL},
/* 16DD4 */ { NULL,NULL},
/* 16DD5 */ { NULL,NULL},
/* 16DD6 */ { NULL,NULL},
/* 16DD7 */ { NULL,NULL},
/* 16DD8 */ { NULL,NULL},
/* 16DD9 */ { NULL,NULL},
/* 16DDA */ { NULL,NULL},
/* 16DDB */ { NULL,NULL},
/* 16DDC */ { NULL,NULL},
/* 16DDD */ { NULL,NULL},
/* 16DDE */ { NULL,NULL},
/* 16DDF */ { NULL,NULL},
/* 16DE0 */ { NULL,NULL},
/* 16DE1 */ { NULL,NULL},
/* 16DE2 */ { NULL,NULL},
/* 16DE3 */ { NULL,NULL},
/* 16DE4 */ { NULL,NULL},
/* 16DE5 */ { NULL,NULL},
/* 16DE6 */ { NULL,NULL},
/* 16DE7 */ { NULL,NULL},
/* 16DE8 */ { NULL,NULL},
/* 16DE9 */ { NULL,NULL},
/* 16DEA */ { NULL,NULL},
/* 16DEB */ { NULL,NULL},
/* 16DEC */ { NULL,NULL},
/* 16DED */ { NULL,NULL},
/* 16DEE */ { NULL,NULL},
/* 16DEF */ { NULL,NULL},
/* 16DF0 */ { NULL,NULL},
/* 16DF1 */ { NULL,NULL},
/* 16DF2 */ { NULL,NULL},
/* 16DF3 */ { NULL,NULL},
/* 16DF4 */ { NULL,NULL},
/* 16DF5 */ { NULL,NULL},
/* 16DF6 */ { NULL,NULL},
/* 16DF7 */ { NULL,NULL},
/* 16DF8 */ { NULL,NULL},
/* 16DF9 */ { NULL,NULL},
/* 16DFA */ { NULL,NULL},
/* 16DFB */ { NULL,NULL},
/* 16DFC */ { NULL,NULL},
/* 16DFD */ { NULL,NULL},
/* 16DFE */ { NULL,NULL},
/* 16DFF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_6E[] = {
/* 16E00 */ { NULL,NULL},
/* 16E01 */ { NULL,NULL},
/* 16E02 */ { NULL,NULL},
/* 16E03 */ { NULL,NULL},
/* 16E04 */ { NULL,NULL},
/* 16E05 */ { NULL,NULL},
/* 16E06 */ { NULL,NULL},
/* 16E07 */ { NULL,NULL},
/* 16E08 */ { NULL,NULL},
/* 16E09 */ { NULL,NULL},
/* 16E0A */ { NULL,NULL},
/* 16E0B */ { NULL,NULL},
/* 16E0C */ { NULL,NULL},
/* 16E0D */ { NULL,NULL},
/* 16E0E */ { NULL,NULL},
/* 16E0F */ { NULL,NULL},
/* 16E10 */ { NULL,NULL},
/* 16E11 */ { NULL,NULL},
/* 16E12 */ { NULL,NULL},
/* 16E13 */ { NULL,NULL},
/* 16E14 */ { NULL,NULL},
/* 16E15 */ { NULL,NULL},
/* 16E16 */ { NULL,NULL},
/* 16E17 */ { NULL,NULL},
/* 16E18 */ { NULL,NULL},
/* 16E19 */ { NULL,NULL},
/* 16E1A */ { NULL,NULL},
/* 16E1B */ { NULL,NULL},
/* 16E1C */ { NULL,NULL},
/* 16E1D */ { NULL,NULL},
/* 16E1E */ { NULL,NULL},
/* 16E1F */ { NULL,NULL},
/* 16E20 */ { NULL,NULL},
/* 16E21 */ { NULL,NULL},
/* 16E22 */ { NULL,NULL},
/* 16E23 */ { NULL,NULL},
/* 16E24 */ { NULL,NULL},
/* 16E25 */ { NULL,NULL},
/* 16E26 */ { NULL,NULL},
/* 16E27 */ { NULL,NULL},
/* 16E28 */ { NULL,NULL},
/* 16E29 */ { NULL,NULL},
/* 16E2A */ { NULL,NULL},
/* 16E2B */ { NULL,NULL},
/* 16E2C */ { NULL,NULL},
/* 16E2D */ { NULL,NULL},
/* 16E2E */ { NULL,NULL},
/* 16E2F */ { NULL,NULL},
/* 16E30 */ { NULL,NULL},
/* 16E31 */ { NULL,NULL},
/* 16E32 */ { NULL,NULL},
/* 16E33 */ { NULL,NULL},
/* 16E34 */ { NULL,NULL},
/* 16E35 */ { NULL,NULL},
/* 16E36 */ { NULL,NULL},
/* 16E37 */ { NULL,NULL},
/* 16E38 */ { NULL,NULL},
/* 16E39 */ { NULL,NULL},
/* 16E3A */ { NULL,NULL},
/* 16E3B */ { NULL,NULL},
/* 16E3C */ { NULL,NULL},
/* 16E3D */ { NULL,NULL},
/* 16E3E */ { NULL,NULL},
/* 16E3F */ { NULL,NULL},
/* 16E40 */ { "MEDEFAIDRIN CAPITAL LETTER M",NULL},
/* 16E41 */ { "MEDEFAIDRIN CAPITAL LETTER S",NULL},
/* 16E42 */ { "MEDEFAIDRIN CAPITAL LETTER V",NULL},
/* 16E43 */ { "MEDEFAIDRIN CAPITAL LETTER W",NULL},
/* 16E44 */ { "MEDEFAIDRIN CAPITAL LETTER ATIU",NULL},
/* 16E45 */ { "MEDEFAIDRIN CAPITAL LETTER Z",NULL},
/* 16E46 */ { "MEDEFAIDRIN CAPITAL LETTER KP",NULL},
/* 16E47 */ { "MEDEFAIDRIN CAPITAL LETTER P",NULL},
/* 16E48 */ { "MEDEFAIDRIN CAPITAL LETTER T",NULL},
/* 16E49 */ { "MEDEFAIDRIN CAPITAL LETTER G",NULL},
/* 16E4A */ { "MEDEFAIDRIN CAPITAL LETTER F",NULL},
/* 16E4B */ { "MEDEFAIDRIN CAPITAL LETTER I",NULL},
/* 16E4C */ { "MEDEFAIDRIN CAPITAL LETTER K",NULL},
/* 16E4D */ { "MEDEFAIDRIN CAPITAL LETTER A",NULL},
/* 16E4E */ { "MEDEFAIDRIN CAPITAL LETTER J",NULL},
/* 16E4F */ { "MEDEFAIDRIN CAPITAL LETTER E",NULL},
/* 16E50 */ { "MEDEFAIDRIN CAPITAL LETTER B",NULL},
/* 16E51 */ { "MEDEFAIDRIN CAPITAL LETTER C",NULL},
/* 16E52 */ { "MEDEFAIDRIN CAPITAL LETTER U",NULL},
/* 16E53 */ { "MEDEFAIDRIN CAPITAL LETTER YU",NULL},
/* 16E54 */ { "MEDEFAIDRIN CAPITAL LETTER L",NULL},
/* 16E55 */ { "MEDEFAIDRIN CAPITAL LETTER Q",NULL},
/* 16E56 */ { "MEDEFAIDRIN CAPITAL LETTER HP","	% MEDEFAIDRIN CAPITAL LETTER H"},
/* 16E57 */ { "MEDEFAIDRIN CAPITAL LETTER NY","	% MEDEFAIDRIN CAPITAL LETTER NG"},
/* 16E58 */ { "MEDEFAIDRIN CAPITAL LETTER X",NULL},
/* 16E59 */ { "MEDEFAIDRIN CAPITAL LETTER D",NULL},
/* 16E5A */ { "MEDEFAIDRIN CAPITAL LETTER OE","	* represents the open o vowel"},
/* 16E5B */ { "MEDEFAIDRIN CAPITAL LETTER N",NULL},
/* 16E5C */ { "MEDEFAIDRIN CAPITAL LETTER R",NULL},
/* 16E5D */ { "MEDEFAIDRIN CAPITAL LETTER O",NULL},
/* 16E5E */ { "MEDEFAIDRIN CAPITAL LETTER AI",NULL},
/* 16E5F */ { "MEDEFAIDRIN CAPITAL LETTER Y",NULL},
/* 16E60 */ { "MEDEFAIDRIN SMALL LETTER M",NULL},
/* 16E61 */ { "MEDEFAIDRIN SMALL LETTER S",NULL},
/* 16E62 */ { "MEDEFAIDRIN SMALL LETTER V",NULL},
/* 16E63 */ { "MEDEFAIDRIN SMALL LETTER W",NULL},
/* 16E64 */ { "MEDEFAIDRIN SMALL LETTER ATIU",NULL},
/* 16E65 */ { "MEDEFAIDRIN SMALL LETTER Z",NULL},
/* 16E66 */ { "MEDEFAIDRIN SMALL LETTER KP",NULL},
/* 16E67 */ { "MEDEFAIDRIN SMALL LETTER P",NULL},
/* 16E68 */ { "MEDEFAIDRIN SMALL LETTER T",NULL},
/* 16E69 */ { "MEDEFAIDRIN SMALL LETTER G",NULL},
/* 16E6A */ { "MEDEFAIDRIN SMALL LETTER F",NULL},
/* 16E6B */ { "MEDEFAIDRIN SMALL LETTER I",NULL},
/* 16E6C */ { "MEDEFAIDRIN SMALL LETTER K",NULL},
/* 16E6D */ { "MEDEFAIDRIN SMALL LETTER A",NULL},
/* 16E6E */ { "MEDEFAIDRIN SMALL LETTER J",NULL},
/* 16E6F */ { "MEDEFAIDRIN SMALL LETTER E",NULL},
/* 16E70 */ { "MEDEFAIDRIN SMALL LETTER B",NULL},
/* 16E71 */ { "MEDEFAIDRIN SMALL LETTER C",NULL},
/* 16E72 */ { "MEDEFAIDRIN SMALL LETTER U",NULL},
/* 16E73 */ { "MEDEFAIDRIN SMALL LETTER YU",NULL},
/* 16E74 */ { "MEDEFAIDRIN SMALL LETTER L",NULL},
/* 16E75 */ { "MEDEFAIDRIN SMALL LETTER Q",NULL},
/* 16E76 */ { "MEDEFAIDRIN SMALL LETTER HP","	% MEDEFAIDRIN SMALL LETTER H"},
/* 16E77 */ { "MEDEFAIDRIN SMALL LETTER NY","	% MEDEFAIDRIN SMALL LETTER NG"},
/* 16E78 */ { "MEDEFAIDRIN SMALL LETTER X",NULL},
/* 16E79 */ { "MEDEFAIDRIN SMALL LETTER D",NULL},
/* 16E7A */ { "MEDEFAIDRIN SMALL LETTER OE","	* represents the open o vowel"},
/* 16E7B */ { "MEDEFAIDRIN SMALL LETTER N",NULL},
/* 16E7C */ { "MEDEFAIDRIN SMALL LETTER R",NULL},
/* 16E7D */ { "MEDEFAIDRIN SMALL LETTER O",NULL},
/* 16E7E */ { "MEDEFAIDRIN SMALL LETTER AI",NULL},
/* 16E7F */ { "MEDEFAIDRIN SMALL LETTER Y",NULL},
/* 16E80 */ { "MEDEFAIDRIN DIGIT ZERO",NULL},
/* 16E81 */ { "MEDEFAIDRIN DIGIT ONE",NULL},
/* 16E82 */ { "MEDEFAIDRIN DIGIT TWO",NULL},
/* 16E83 */ { "MEDEFAIDRIN DIGIT THREE",NULL},
/* 16E84 */ { "MEDEFAIDRIN DIGIT FOUR",NULL},
/* 16E85 */ { "MEDEFAIDRIN DIGIT FIVE",NULL},
/* 16E86 */ { "MEDEFAIDRIN DIGIT SIX",NULL},
/* 16E87 */ { "MEDEFAIDRIN DIGIT SEVEN",NULL},
/* 16E88 */ { "MEDEFAIDRIN DIGIT EIGHT",NULL},
/* 16E89 */ { "MEDEFAIDRIN DIGIT NINE",NULL},
/* 16E8A */ { "MEDEFAIDRIN NUMBER TEN",NULL},
/* 16E8B */ { "MEDEFAIDRIN NUMBER ELEVEN",NULL},
/* 16E8C */ { "MEDEFAIDRIN NUMBER TWELVE",NULL},
/* 16E8D */ { "MEDEFAIDRIN NUMBER THIRTEEN",NULL},
/* 16E8E */ { "MEDEFAIDRIN NUMBER FOURTEEN",NULL},
/* 16E8F */ { "MEDEFAIDRIN NUMBER FIFTEEN",NULL},
/* 16E90 */ { "MEDEFAIDRIN NUMBER SIXTEEN",NULL},
/* 16E91 */ { "MEDEFAIDRIN NUMBER SEVENTEEN",NULL},
/* 16E92 */ { "MEDEFAIDRIN NUMBER EIGHTEEN",NULL},
/* 16E93 */ { "MEDEFAIDRIN NUMBER NINETEEN",NULL},
/* 16E94 */ { "MEDEFAIDRIN DIGIT ONE ALTERNATE FORM",NULL},
/* 16E95 */ { "MEDEFAIDRIN DIGIT TWO ALTERNATE FORM",NULL},
/* 16E96 */ { "MEDEFAIDRIN DIGIT THREE ALTERNATE FORM",NULL},
/* 16E97 */ { "MEDEFAIDRIN COMMA",NULL},
/* 16E98 */ { "MEDEFAIDRIN FULL STOP",NULL},
/* 16E99 */ { "MEDEFAIDRIN SYMBOL AIVA","	* or"},
/* 16E9A */ { "MEDEFAIDRIN EXCLAMATION OH",NULL},
/* 16E9B */ { NULL,NULL},
/* 16E9C */ { NULL,NULL},
/* 16E9D */ { NULL,NULL},
/* 16E9E */ { NULL,NULL},
/* 16E9F */ { NULL,NULL},
/* 16EA0 */ { "BERIA ERFE CAPITAL LETTER ARKAB",NULL},
/* 16EA1 */ { "BERIA ERFE CAPITAL LETTER BASIGNA",NULL},
/* 16EA2 */ { "BERIA ERFE CAPITAL LETTER DARBAI",NULL},
/* 16EA3 */ { "BERIA ERFE CAPITAL LETTER EH",NULL},
/* 16EA4 */ { "BERIA ERFE CAPITAL LETTER FITKO",NULL},
/* 16EA5 */ { "BERIA ERFE CAPITAL LETTER GOWAY",NULL},
/* 16EA6 */ { "BERIA ERFE CAPITAL LETTER HIRDEABO",NULL},
/* 16EA7 */ { "BERIA ERFE CAPITAL LETTER I",NULL},
/* 16EA8 */ { "BERIA ERFE CAPITAL LETTER DJAI",NULL},
/* 16EA9 */ { "BERIA ERFE CAPITAL LETTER KOBO",NULL},
/* 16EAA */ { "BERIA ERFE CAPITAL LETTER LAKKO",NULL},
/* 16EAB */ { "BERIA ERFE CAPITAL LETTER MERI",NULL},
/* 16EAC */ { "BERIA ERFE CAPITAL LETTER NINI",NULL},
/* 16EAD */ { "BERIA ERFE CAPITAL LETTER GNA",NULL},
/* 16EAE */ { "BERIA ERFE CAPITAL LETTER NGAY",NULL},
/* 16EAF */ { "BERIA ERFE CAPITAL LETTER OI",NULL},
/* 16EB0 */ { "BERIA ERFE CAPITAL LETTER PI",NULL},
/* 16EB1 */ { "BERIA ERFE CAPITAL LETTER ERIGO",NULL},
/* 16EB2 */ { "BERIA ERFE CAPITAL LETTER ERIGO TAMURA",NULL},
/* 16EB3 */ { "BERIA ERFE CAPITAL LETTER SERI",NULL},
/* 16EB4 */ { "BERIA ERFE CAPITAL LETTER SHEP",NULL},
/* 16EB5 */ { "BERIA ERFE CAPITAL LETTER TATASOUE",NULL},
/* 16EB6 */ { "BERIA ERFE CAPITAL LETTER UI",NULL},
/* 16EB7 */ { "BERIA ERFE CAPITAL LETTER WASSE",NULL},
/* 16EB8 */ { "BERIA ERFE CAPITAL LETTER AY",NULL},
/* 16EB9 */ { NULL,NULL},
/* 16EBA */ { NULL,NULL},
/* 16EBB */ { "BERIA ERFE SMALL LETTER ARKAB",NULL},
/* 16EBC */ { "BERIA ERFE SMALL LETTER BASIGNA",NULL},
/* 16EBD */ { "BERIA ERFE SMALL LETTER DARBAI",NULL},
/* 16EBE */ { "BERIA ERFE SMALL LETTER EH",NULL},
/* 16EBF */ { "BERIA ERFE SMALL LETTER FITKO",NULL},
/* 16EC0 */ { "BERIA ERFE SMALL LETTER GOWAY",NULL},
/* 16EC1 */ { "BERIA ERFE SMALL LETTER HIRDEABO",NULL},
/* 16EC2 */ { "BERIA ERFE SMALL LETTER I",NULL},
/* 16EC3 */ { "BERIA ERFE SMALL LETTER DJAI",NULL},
/* 16EC4 */ { "BERIA ERFE SMALL LETTER KOBO",NULL},
/* 16EC5 */ { "BERIA ERFE SMALL LETTER LAKKO",NULL},
/* 16EC6 */ { "BERIA ERFE SMALL LETTER MERI",NULL},
/* 16EC7 */ { "BERIA ERFE SMALL LETTER NINI",NULL},
/* 16EC8 */ { "BERIA ERFE SMALL LETTER GNA",NULL},
/* 16EC9 */ { "BERIA ERFE SMALL LETTER NGAY",NULL},
/* 16ECA */ { "BERIA ERFE SMALL LETTER OI",NULL},
/* 16ECB */ { "BERIA ERFE SMALL LETTER PI",NULL},
/* 16ECC */ { "BERIA ERFE SMALL LETTER ERIGO",NULL},
/* 16ECD */ { "BERIA ERFE SMALL LETTER ERIGO TAMURA",NULL},
/* 16ECE */ { "BERIA ERFE SMALL LETTER SERI",NULL},
/* 16ECF */ { "BERIA ERFE SMALL LETTER SHEP",NULL},
/* 16ED0 */ { "BERIA ERFE SMALL LETTER TATASOUE",NULL},
/* 16ED1 */ { "BERIA ERFE SMALL LETTER UI",NULL},
/* 16ED2 */ { "BERIA ERFE SMALL LETTER WASSE",NULL},
/* 16ED3 */ { "BERIA ERFE SMALL LETTER AY",NULL},
/* 16ED4 */ { NULL,NULL},
/* 16ED5 */ { NULL,NULL},
/* 16ED6 */ { NULL,NULL},
/* 16ED7 */ { NULL,NULL},
/* 16ED8 */ { NULL,NULL},
/* 16ED9 */ { NULL,NULL},
/* 16EDA */ { NULL,NULL},
/* 16EDB */ { NULL,NULL},
/* 16EDC */ { NULL,NULL},
/* 16EDD */ { NULL,NULL},
/* 16EDE */ { NULL,NULL},
/* 16EDF */ { NULL,NULL},
/* 16EE0 */ { NULL,NULL},
/* 16EE1 */ { NULL,NULL},
/* 16EE2 */ { NULL,NULL},
/* 16EE3 */ { NULL,NULL},
/* 16EE4 */ { NULL,NULL},
/* 16EE5 */ { NULL,NULL},
/* 16EE6 */ { NULL,NULL},
/* 16EE7 */ { NULL,NULL},
/* 16EE8 */ { NULL,NULL},
/* 16EE9 */ { NULL,NULL},
/* 16EEA */ { NULL,NULL},
/* 16EEB */ { NULL,NULL},
/* 16EEC */ { NULL,NULL},
/* 16EED */ { NULL,NULL},
/* 16EEE */ { NULL,NULL},
/* 16EEF */ { NULL,NULL},
/* 16EF0 */ { NULL,NULL},
/* 16EF1 */ { NULL,NULL},
/* 16EF2 */ { NULL,NULL},
/* 16EF3 */ { NULL,NULL},
/* 16EF4 */ { NULL,NULL},
/* 16EF5 */ { NULL,NULL},
/* 16EF6 */ { NULL,NULL},
/* 16EF7 */ { NULL,NULL},
/* 16EF8 */ { NULL,NULL},
/* 16EF9 */ { NULL,NULL},
/* 16EFA */ { NULL,NULL},
/* 16EFB */ { NULL,NULL},
/* 16EFC */ { NULL,NULL},
/* 16EFD */ { NULL,NULL},
/* 16EFE */ { NULL,NULL},
/* 16EFF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_6F[] = {
/* 16F00 */ { "MIAO LETTER PA","	* used for ba in Gan Yi"},
/* 16F01 */ { "MIAO LETTER BA",NULL},
/* 16F02 */ { "MIAO LETTER YI PA","	* used for pa in Gan Yi"},
/* 16F03 */ { "MIAO LETTER PLA","	* used in Sichuan Hmong"},
/* 16F04 */ { "MIAO LETTER MA",NULL},
/* 16F05 */ { "MIAO LETTER MHA",NULL},
/* 16F06 */ { "MIAO LETTER ARCHAIC MA","	* used in Pollard's early orthography"},
/* 16F07 */ { "MIAO LETTER FA",NULL},
/* 16F08 */ { "MIAO LETTER VA",NULL},
/* 16F09 */ { "MIAO LETTER VFA","	* used in Hei Yi"},
/* 16F0A */ { "MIAO LETTER TA","	* used for da in Gan Yi"},
/* 16F0B */ { "MIAO LETTER DA",NULL},
/* 16F0C */ { "MIAO LETTER YI TTA","	* used in Hei Yi"},
/* 16F0D */ { "MIAO LETTER YI TA","	* used for ta in Gan Yi"},
/* 16F0E */ { "MIAO LETTER TTA",NULL},
/* 16F0F */ { "MIAO LETTER DDA",NULL},
/* 16F10 */ { "MIAO LETTER NA",NULL},
/* 16F11 */ { "MIAO LETTER NHA",NULL},
/* 16F12 */ { "MIAO LETTER YI NNA","	* used in Hei Yi"},
/* 16F13 */ { "MIAO LETTER ARCHAIC NA","	* used in Pollard's early orthography"},
/* 16F14 */ { "MIAO LETTER NNA",NULL},
/* 16F15 */ { "MIAO LETTER NNHA",NULL},
/* 16F16 */ { "MIAO LETTER LA",NULL},
/* 16F17 */ { "MIAO LETTER LYA","	* used in Hei Yi"},
/* 16F18 */ { "MIAO LETTER LHA",NULL},
/* 16F19 */ { "MIAO LETTER LHYA","	* used in Hei Yi"},
/* 16F1A */ { "MIAO LETTER TLHA",NULL},
/* 16F1B */ { "MIAO LETTER DLHA",NULL},
/* 16F1C */ { "MIAO LETTER TLHYA",NULL},
/* 16F1D */ { "MIAO LETTER DLHYA",NULL},
/* 16F1E */ { "MIAO LETTER KA","	* used for ga in Gan Yi"},
/* 16F1F */ { "MIAO LETTER GA",NULL},
/* 16F20 */ { "MIAO LETTER YI KA","	* used for ka in Gan Yi"},
/* 16F21 */ { "MIAO LETTER QA",NULL},
/* 16F22 */ { "MIAO LETTER QGA",NULL},
/* 16F23 */ { "MIAO LETTER NGA",NULL},
/* 16F24 */ { "MIAO LETTER NGHA",NULL},
/* 16F25 */ { "MIAO LETTER ARCHAIC NGA","	* used in Pollard's early orthography"},
/* 16F26 */ { "MIAO LETTER HA",NULL},
/* 16F27 */ { "MIAO LETTER XA","	* archaic character used in a post-1949 reformed orthography"},
/* 16F28 */ { "MIAO LETTER GHA",NULL},
/* 16F29 */ { "MIAO LETTER GHHA",NULL},
/* 16F2A */ { "MIAO LETTER TSSA",NULL},
/* 16F2B */ { "MIAO LETTER DZZA",NULL},
/* 16F2C */ { "MIAO LETTER NYA",NULL},
/* 16F2D */ { "MIAO LETTER NYHA","	* used in Bai Yi"},
/* 16F2E */ { "MIAO LETTER TSHA",NULL},
/* 16F2F */ { "MIAO LETTER DZHA",NULL},
/* 16F30 */ { "MIAO LETTER YI TSHA","	* used for tsha in Gan Yi"},
/* 16F31 */ { "MIAO LETTER YI DZHA","	* used in Hei Yi"},
/* 16F32 */ { "MIAO LETTER REFORMED TSHA","	* archaic character used before 1949 reformed orthography"},
/* 16F33 */ { "MIAO LETTER SHA",NULL},
/* 16F34 */ { "MIAO LETTER SSA",NULL},
/* 16F35 */ { "MIAO LETTER ZHA","	* used in Hei Yi"},
/* 16F36 */ { "MIAO LETTER ZSHA","	* used in Hei Yi"},
/* 16F37 */ { "MIAO LETTER TSA","	* used for dza in Gan Yi"},
/* 16F38 */ { "MIAO LETTER DZA",NULL},
/* 16F39 */ { "MIAO LETTER YI TSA","	* used for tsa in Gan Yi"},
/* 16F3A */ { "MIAO LETTER SA",NULL},
/* 16F3B */ { "MIAO LETTER ZA",NULL},
/* 16F3C */ { "MIAO LETTER ZSA","	* used in Hei Yi"},
/* 16F3D */ { "MIAO LETTER ZZA",NULL},
/* 16F3E */ { "MIAO LETTER ZZSA","	* used in Hei Yi"},
/* 16F3F */ { "MIAO LETTER ARCHAIC ZZA","	* used in Pollard's early orthography"},
/* 16F40 */ { "MIAO LETTER ZZYA","	* used in Hei Yi"},
/* 16F41 */ { "MIAO LETTER ZZSYA","	* used in Hei Yi"},
/* 16F42 */ { "MIAO LETTER WA",NULL},
/* 16F43 */ { "MIAO LETTER AH","	* glottal stop"},
/* 16F44 */ { "MIAO LETTER HHA","	* used in Hei Yi"},
/* 16F45 */ { "MIAO LETTER BRI","	* used in Xiaohua Miao"},
/* 16F46 */ { "MIAO LETTER SYI","	* used in Xiaohua Miao"},
/* 16F47 */ { "MIAO LETTER DZYI","	* used in Xiaohua Miao"},
/* 16F48 */ { "MIAO LETTER TE","	* used in Bai Yi"},
/* 16F49 */ { "MIAO LETTER TSE","	* used in Bai Yi"},
/* 16F4A */ { "MIAO LETTER RTE","	* used in Bai Yi"},
/* 16F4B */ { NULL,NULL},
/* 16F4C */ { NULL,NULL},
/* 16F4D */ { NULL,NULL},
/* 16F4E */ { NULL,NULL},
/* 16F4F */ { "MIAO SIGN CONSONANT MODIFIER BAR","	* used in Gan Yi\n"
	"	* functions similarly to Indic nuktas"},
/* 16F50 */ { "MIAO LETTER NASALIZATION",NULL},
/* 16F51 */ { "MIAO SIGN ASPIRATION",NULL},
/* 16F52 */ { "MIAO SIGN REFORMED VOICING","	* archaic character used in a post-1949 reformed orthography"},
/* 16F53 */ { "MIAO SIGN REFORMED ASPIRATION","	* archaic character used in a post-1949 reformed orthography"},
/* 16F54 */ { "MIAO VOWEL SIGN A",NULL},
/* 16F55 */ { "MIAO VOWEL SIGN AA","	* used in Eastern Lisu"},
/* 16F56 */ { "MIAO VOWEL SIGN AHH","	* used in Gan Yi"},
/* 16F57 */ { "MIAO VOWEL SIGN AN",NULL},
/* 16F58 */ { "MIAO VOWEL SIGN ANG","	* also used for aw"},
/* 16F59 */ { "MIAO VOWEL SIGN O",NULL},
/* 16F5A */ { "MIAO VOWEL SIGN OO",NULL},
/* 16F5B */ { "MIAO VOWEL SIGN WO","	* used in Hei Yi"},
/* 16F5C */ { "MIAO VOWEL SIGN W",NULL},
/* 16F5D */ { "MIAO VOWEL SIGN E",NULL},
/* 16F5E */ { "MIAO VOWEL SIGN EN",NULL},
/* 16F5F */ { "MIAO VOWEL SIGN ENG",NULL},
/* 16F60 */ { "MIAO VOWEL SIGN OEY",NULL},
/* 16F61 */ { "MIAO VOWEL SIGN I",NULL},
/* 16F62 */ { "MIAO VOWEL SIGN IA",NULL},
/* 16F63 */ { "MIAO VOWEL SIGN IAN",NULL},
/* 16F64 */ { "MIAO VOWEL SIGN IANG","	* also used for iaw"},
/* 16F65 */ { "MIAO VOWEL SIGN IO",NULL},
/* 16F66 */ { "MIAO VOWEL SIGN IE",NULL},
/* 16F67 */ { "MIAO VOWEL SIGN II","	* used in Eastern Lisu"},
/* 16F68 */ { "MIAO VOWEL SIGN IU",NULL},
/* 16F69 */ { "MIAO VOWEL SIGN ING","	* also used for in"},
/* 16F6A */ { "MIAO VOWEL SIGN U",NULL},
/* 16F6B */ { "MIAO VOWEL SIGN UA",NULL},
/* 16F6C */ { "MIAO VOWEL SIGN UAN",NULL},
/* 16F6D */ { "MIAO VOWEL SIGN UANG","	* also used for uaw"},
/* 16F6E */ { "MIAO VOWEL SIGN UU","	* used in Eastern Lisu"},
/* 16F6F */ { "MIAO VOWEL SIGN UEI",NULL},
/* 16F70 */ { "MIAO VOWEL SIGN UNG",NULL},
/* 16F71 */ { "MIAO VOWEL SIGN Y",NULL},
/* 16F72 */ { "MIAO VOWEL SIGN YI",NULL},
/* 16F73 */ { "MIAO VOWEL SIGN AE",NULL},
/* 16F74 */ { "MIAO VOWEL SIGN AEE","	* used in Eastern Lisu"},
/* 16F75 */ { "MIAO VOWEL SIGN ERR",NULL},
/* 16F76 */ { "MIAO VOWEL SIGN ROUNDED ERR","	* used in Eastern Lisu"},
/* 16F77 */ { "MIAO VOWEL SIGN ER",NULL},
/* 16F78 */ { "MIAO VOWEL SIGN ROUNDED ER","	* used in Eastern Lisu"},
/* 16F79 */ { "MIAO VOWEL SIGN AI",NULL},
/* 16F7A */ { "MIAO VOWEL SIGN EI",NULL},
/* 16F7B */ { "MIAO VOWEL SIGN AU",NULL},
/* 16F7C */ { "MIAO VOWEL SIGN OU",NULL},
/* 16F7D */ { "MIAO VOWEL SIGN N",NULL},
/* 16F7E */ { "MIAO VOWEL SIGN NG",NULL},
/* 16F7F */ { "MIAO VOWEL SIGN UOG","	* used in Hei Yi"},
/* 16F80 */ { "MIAO VOWEL SIGN YUI","	* used in Hei Yi"},
/* 16F81 */ { "MIAO VOWEL SIGN OG","	* used in Gan Yi and Bai Yi"},
/* 16F82 */ { "MIAO VOWEL SIGN OER","	* used in Gan Yi and Xiaohua Miao"},
/* 16F83 */ { "MIAO VOWEL SIGN VW","	* used in Xiaohua Miao and Bai Yi"},
/* 16F84 */ { "MIAO VOWEL SIGN IG","	* used in Bai Yi"},
/* 16F85 */ { "MIAO VOWEL SIGN EA","	* used in Bai Yi"},
/* 16F86 */ { "MIAO VOWEL SIGN IONG","	* used in Bai Yi"},
/* 16F87 */ { "MIAO VOWEL SIGN UI","	* used in Bai Yi"},
/* 16F88 */ { NULL,NULL},
/* 16F89 */ { NULL,NULL},
/* 16F8A */ { NULL,NULL},
/* 16F8B */ { NULL,NULL},
/* 16F8C */ { NULL,NULL},
/* 16F8D */ { NULL,NULL},
/* 16F8E */ { NULL,NULL},
/* 16F8F */ { "MIAO TONE RIGHT",NULL},
/* 16F90 */ { "MIAO TONE TOP RIGHT",NULL},
/* 16F91 */ { "MIAO TONE ABOVE",NULL},
/* 16F92 */ { "MIAO TONE BELOW",NULL},
/* 16F93 */ { "MIAO LETTER TONE-2",NULL},
/* 16F94 */ { "MIAO LETTER TONE-3",NULL},
/* 16F95 */ { "MIAO LETTER TONE-4",NULL},
/* 16F96 */ { "MIAO LETTER TONE-5",NULL},
/* 16F97 */ { "MIAO LETTER TONE-6",NULL},
/* 16F98 */ { "MIAO LETTER TONE-7",NULL},
/* 16F99 */ { "MIAO LETTER TONE-8",NULL},
/* 16F9A */ { "MIAO LETTER REFORMED TONE-1",NULL},
/* 16F9B */ { "MIAO LETTER REFORMED TONE-2",NULL},
/* 16F9C */ { "MIAO LETTER REFORMED TONE-4",NULL},
/* 16F9D */ { "MIAO LETTER REFORMED TONE-5",NULL},
/* 16F9E */ { "MIAO LETTER REFORMED TONE-6",NULL},
/* 16F9F */ { "MIAO LETTER REFORMED TONE-8",NULL},
/* 16FA0 */ { NULL,NULL},
/* 16FA1 */ { NULL,NULL},
/* 16FA2 */ { NULL,NULL},
/* 16FA3 */ { NULL,NULL},
/* 16FA4 */ { NULL,NULL},
/* 16FA5 */ { NULL,NULL},
/* 16FA6 */ { NULL,NULL},
/* 16FA7 */ { NULL,NULL},
/* 16FA8 */ { NULL,NULL},
/* 16FA9 */ { NULL,NULL},
/* 16FAA */ { NULL,NULL},
/* 16FAB */ { NULL,NULL},
/* 16FAC */ { NULL,NULL},
/* 16FAD */ { NULL,NULL},
/* 16FAE */ { NULL,NULL},
/* 16FAF */ { NULL,NULL},
/* 16FB0 */ { NULL,NULL},
/* 16FB1 */ { NULL,NULL},
/* 16FB2 */ { NULL,NULL},
/* 16FB3 */ { NULL,NULL},
/* 16FB4 */ { NULL,NULL},
/* 16FB5 */ { NULL,NULL},
/* 16FB6 */ { NULL,NULL},
/* 16FB7 */ { NULL,NULL},
/* 16FB8 */ { NULL,NULL},
/* 16FB9 */ { NULL,NULL},
/* 16FBA */ { NULL,NULL},
/* 16FBB */ { NULL,NULL},
/* 16FBC */ { NULL,NULL},
/* 16FBD */ { NULL,NULL},
/* 16FBE */ { NULL,NULL},
/* 16FBF */ { NULL,NULL},
/* 16FC0 */ { NULL,NULL},
/* 16FC1 */ { NULL,NULL},
/* 16FC2 */ { NULL,NULL},
/* 16FC3 */ { NULL,NULL},
/* 16FC4 */ { NULL,NULL},
/* 16FC5 */ { NULL,NULL},
/* 16FC6 */ { NULL,NULL},
/* 16FC7 */ { NULL,NULL},
/* 16FC8 */ { NULL,NULL},
/* 16FC9 */ { NULL,NULL},
/* 16FCA */ { NULL,NULL},
/* 16FCB */ { NULL,NULL},
/* 16FCC */ { NULL,NULL},
/* 16FCD */ { NULL,NULL},
/* 16FCE */ { NULL,NULL},
/* 16FCF */ { NULL,NULL},
/* 16FD0 */ { NULL,NULL},
/* 16FD1 */ { NULL,NULL},
/* 16FD2 */ { NULL,NULL},
/* 16FD3 */ { NULL,NULL},
/* 16FD4 */ { NULL,NULL},
/* 16FD5 */ { NULL,NULL},
/* 16FD6 */ { NULL,NULL},
/* 16FD7 */ { NULL,NULL},
/* 16FD8 */ { NULL,NULL},
/* 16FD9 */ { NULL,NULL},
/* 16FDA */ { NULL,NULL},
/* 16FDB */ { NULL,NULL},
/* 16FDC */ { NULL,NULL},
/* 16FDD */ { NULL,NULL},
/* 16FDE */ { NULL,NULL},
/* 16FDF */ { NULL,NULL},
/* 16FE0 */ { "TANGUT ITERATION MARK","	x (ideographic iteration mark - 3005)"},
/* 16FE1 */ { "NUSHU ITERATION MARK",NULL},
/* 16FE2 */ { "OLD CHINESE HOOK MARK","	* indicates a pause or break in the text"},
/* 16FE3 */ { "OLD CHINESE ITERATION MARK","	x (ideographic iteration mark - 3005)\n"
	"	x (vertical ideographic iteration mark - 303B)"},
/* 16FE4 */ { "KHITAN SMALL SCRIPT FILLER",NULL},
/* 16FE5 */ { NULL,NULL},
/* 16FE6 */ { NULL,NULL},
/* 16FE7 */ { NULL,NULL},
/* 16FE8 */ { NULL,NULL},
/* 16FE9 */ { NULL,NULL},
/* 16FEA */ { NULL,NULL},
/* 16FEB */ { NULL,NULL},
/* 16FEC */ { NULL,NULL},
/* 16FED */ { NULL,NULL},
/* 16FEE */ { NULL,NULL},
/* 16FEF */ { NULL,NULL},
/* 16FF0 */ { "VIETNAMESE ALTERNATE READING MARK CA","	x 4E2A\n"
	"	x 4E87"},
/* 16FF1 */ { "VIETNAMESE ALTERNATE READING MARK NHAY","	x 21FE8"},
/* 16FF2 */ { "CHINESE SMALL SIMPLIFIED ER","	x 513F"},
/* 16FF3 */ { "CHINESE SMALL TRADITIONAL ER","	x 5152"},
/* 16FF4 */ { "YANGQIN SIGN SLOW ONE BEAT","	x (hangzhou numeral six - 3026)"},
/* 16FF5 */ { "YANGQIN SIGN SLOW THREE HALF BEATS",NULL},
/* 16FF6 */ { "YANGQIN SIGN SLOW TWO BEATS",NULL},
/* 16FF7 */ { NULL,NULL},
/* 16FF8 */ { NULL,NULL},
/* 16FF9 */ { NULL,NULL},
/* 16FFA */ { NULL,NULL},
/* 16FFB */ { NULL,NULL},
/* 16FFC */ { NULL,NULL},
/* 16FFD */ { NULL,NULL},
/* 16FFE */ { NULL,NULL},
/* 16FFF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_88[] = {
/* 18800 */ { "TANGUT COMPONENT-001",NULL},
/* 18801 */ { "TANGUT COMPONENT-002",NULL},
/* 18802 */ { "TANGUT COMPONENT-003",NULL},
/* 18803 */ { "TANGUT COMPONENT-004",NULL},
/* 18804 */ { "TANGUT COMPONENT-005",NULL},
/* 18805 */ { "TANGUT COMPONENT-006",NULL},
/* 18806 */ { "TANGUT COMPONENT-007",NULL},
/* 18807 */ { "TANGUT COMPONENT-008",NULL},
/* 18808 */ { "TANGUT COMPONENT-009",NULL},
/* 18809 */ { "TANGUT COMPONENT-010",NULL},
/* 1880A */ { "TANGUT COMPONENT-011",NULL},
/* 1880B */ { "TANGUT COMPONENT-012",NULL},
/* 1880C */ { "TANGUT COMPONENT-013",NULL},
/* 1880D */ { "TANGUT COMPONENT-014",NULL},
/* 1880E */ { "TANGUT COMPONENT-015",NULL},
/* 1880F */ { "TANGUT COMPONENT-016",NULL},
/* 18810 */ { "TANGUT COMPONENT-017",NULL},
/* 18811 */ { "TANGUT COMPONENT-018",NULL},
/* 18812 */ { "TANGUT COMPONENT-019",NULL},
/* 18813 */ { "TANGUT COMPONENT-020",NULL},
/* 18814 */ { "TANGUT COMPONENT-021",NULL},
/* 18815 */ { "TANGUT COMPONENT-022",NULL},
/* 18816 */ { "TANGUT COMPONENT-023",NULL},
/* 18817 */ { "TANGUT COMPONENT-024",NULL},
/* 18818 */ { "TANGUT COMPONENT-025",NULL},
/* 18819 */ { "TANGUT COMPONENT-026",NULL},
/* 1881A */ { "TANGUT COMPONENT-027",NULL},
/* 1881B */ { "TANGUT COMPONENT-028",NULL},
/* 1881C */ { "TANGUT COMPONENT-029",NULL},
/* 1881D */ { "TANGUT COMPONENT-030",NULL},
/* 1881E */ { "TANGUT COMPONENT-031",NULL},
/* 1881F */ { "TANGUT COMPONENT-032",NULL},
/* 18820 */ { "TANGUT COMPONENT-033",NULL},
/* 18821 */ { "TANGUT COMPONENT-034",NULL},
/* 18822 */ { "TANGUT COMPONENT-035",NULL},
/* 18823 */ { "TANGUT COMPONENT-036",NULL},
/* 18824 */ { "TANGUT COMPONENT-037",NULL},
/* 18825 */ { "TANGUT COMPONENT-038",NULL},
/* 18826 */ { "TANGUT COMPONENT-039",NULL},
/* 18827 */ { "TANGUT COMPONENT-040",NULL},
/* 18828 */ { "TANGUT COMPONENT-041",NULL},
/* 18829 */ { "TANGUT COMPONENT-042",NULL},
/* 1882A */ { "TANGUT COMPONENT-043",NULL},
/* 1882B */ { "TANGUT COMPONENT-044",NULL},
/* 1882C */ { "TANGUT COMPONENT-045",NULL},
/* 1882D */ { "TANGUT COMPONENT-046",NULL},
/* 1882E */ { "TANGUT COMPONENT-047",NULL},
/* 1882F */ { "TANGUT COMPONENT-048",NULL},
/* 18830 */ { "TANGUT COMPONENT-049",NULL},
/* 18831 */ { "TANGUT COMPONENT-050",NULL},
/* 18832 */ { "TANGUT COMPONENT-051",NULL},
/* 18833 */ { "TANGUT COMPONENT-052",NULL},
/* 18834 */ { "TANGUT COMPONENT-053",NULL},
/* 18835 */ { "TANGUT COMPONENT-054",NULL},
/* 18836 */ { "TANGUT COMPONENT-055",NULL},
/* 18837 */ { "TANGUT COMPONENT-056",NULL},
/* 18838 */ { "TANGUT COMPONENT-057",NULL},
/* 18839 */ { "TANGUT COMPONENT-058",NULL},
/* 1883A */ { "TANGUT COMPONENT-059",NULL},
/* 1883B */ { "TANGUT COMPONENT-060",NULL},
/* 1883C */ { "TANGUT COMPONENT-061",NULL},
/* 1883D */ { "TANGUT COMPONENT-062",NULL},
/* 1883E */ { "TANGUT COMPONENT-063",NULL},
/* 1883F */ { "TANGUT COMPONENT-064",NULL},
/* 18840 */ { "TANGUT COMPONENT-065",NULL},
/* 18841 */ { "TANGUT COMPONENT-066",NULL},
/* 18842 */ { "TANGUT COMPONENT-067",NULL},
/* 18843 */ { "TANGUT COMPONENT-068",NULL},
/* 18844 */ { "TANGUT COMPONENT-069",NULL},
/* 18845 */ { "TANGUT COMPONENT-070",NULL},
/* 18846 */ { "TANGUT COMPONENT-071",NULL},
/* 18847 */ { "TANGUT COMPONENT-072",NULL},
/* 18848 */ { "TANGUT COMPONENT-073",NULL},
/* 18849 */ { "TANGUT COMPONENT-074",NULL},
/* 1884A */ { "TANGUT COMPONENT-075",NULL},
/* 1884B */ { "TANGUT COMPONENT-076",NULL},
/* 1884C */ { "TANGUT COMPONENT-077",NULL},
/* 1884D */ { "TANGUT COMPONENT-078",NULL},
/* 1884E */ { "TANGUT COMPONENT-079",NULL},
/* 1884F */ { "TANGUT COMPONENT-080",NULL},
/* 18850 */ { "TANGUT COMPONENT-081",NULL},
/* 18851 */ { "TANGUT COMPONENT-082",NULL},
/* 18852 */ { "TANGUT COMPONENT-083",NULL},
/* 18853 */ { "TANGUT COMPONENT-084",NULL},
/* 18854 */ { "TANGUT COMPONENT-085",NULL},
/* 18855 */ { "TANGUT COMPONENT-086",NULL},
/* 18856 */ { "TANGUT COMPONENT-087",NULL},
/* 18857 */ { "TANGUT COMPONENT-088",NULL},
/* 18858 */ { "TANGUT COMPONENT-089",NULL},
/* 18859 */ { "TANGUT COMPONENT-090",NULL},
/* 1885A */ { "TANGUT COMPONENT-091",NULL},
/* 1885B */ { "TANGUT COMPONENT-092",NULL},
/* 1885C */ { "TANGUT COMPONENT-093",NULL},
/* 1885D */ { "TANGUT COMPONENT-094",NULL},
/* 1885E */ { "TANGUT COMPONENT-095",NULL},
/* 1885F */ { "TANGUT COMPONENT-096",NULL},
/* 18860 */ { "TANGUT COMPONENT-097",NULL},
/* 18861 */ { "TANGUT COMPONENT-098",NULL},
/* 18862 */ { "TANGUT COMPONENT-099",NULL},
/* 18863 */ { "TANGUT COMPONENT-100",NULL},
/* 18864 */ { "TANGUT COMPONENT-101",NULL},
/* 18865 */ { "TANGUT COMPONENT-102",NULL},
/* 18866 */ { "TANGUT COMPONENT-103",NULL},
/* 18867 */ { "TANGUT COMPONENT-104",NULL},
/* 18868 */ { "TANGUT COMPONENT-105",NULL},
/* 18869 */ { "TANGUT COMPONENT-106",NULL},
/* 1886A */ { "TANGUT COMPONENT-107",NULL},
/* 1886B */ { "TANGUT COMPONENT-108",NULL},
/* 1886C */ { "TANGUT COMPONENT-109",NULL},
/* 1886D */ { "TANGUT COMPONENT-110",NULL},
/* 1886E */ { "TANGUT COMPONENT-111",NULL},
/* 1886F */ { "TANGUT COMPONENT-112",NULL},
/* 18870 */ { "TANGUT COMPONENT-113",NULL},
/* 18871 */ { "TANGUT COMPONENT-114",NULL},
/* 18872 */ { "TANGUT COMPONENT-115",NULL},
/* 18873 */ { "TANGUT COMPONENT-116",NULL},
/* 18874 */ { "TANGUT COMPONENT-117",NULL},
/* 18875 */ { "TANGUT COMPONENT-118",NULL},
/* 18876 */ { "TANGUT COMPONENT-119",NULL},
/* 18877 */ { "TANGUT COMPONENT-120",NULL},
/* 18878 */ { "TANGUT COMPONENT-121",NULL},
/* 18879 */ { "TANGUT COMPONENT-122",NULL},
/* 1887A */ { "TANGUT COMPONENT-123",NULL},
/* 1887B */ { "TANGUT COMPONENT-124",NULL},
/* 1887C */ { "TANGUT COMPONENT-125",NULL},
/* 1887D */ { "TANGUT COMPONENT-126",NULL},
/* 1887E */ { "TANGUT COMPONENT-127",NULL},
/* 1887F */ { "TANGUT COMPONENT-128",NULL},
/* 18880 */ { "TANGUT COMPONENT-129",NULL},
/* 18881 */ { "TANGUT COMPONENT-130",NULL},
/* 18882 */ { "TANGUT COMPONENT-131",NULL},
/* 18883 */ { "TANGUT COMPONENT-132",NULL},
/* 18884 */ { "TANGUT COMPONENT-133",NULL},
/* 18885 */ { "TANGUT COMPONENT-134",NULL},
/* 18886 */ { "TANGUT COMPONENT-135",NULL},
/* 18887 */ { "TANGUT COMPONENT-136",NULL},
/* 18888 */ { "TANGUT COMPONENT-137",NULL},
/* 18889 */ { "TANGUT COMPONENT-138",NULL},
/* 1888A */ { "TANGUT COMPONENT-139",NULL},
/* 1888B */ { "TANGUT COMPONENT-140",NULL},
/* 1888C */ { "TANGUT COMPONENT-141",NULL},
/* 1888D */ { "TANGUT COMPONENT-142",NULL},
/* 1888E */ { "TANGUT COMPONENT-143",NULL},
/* 1888F */ { "TANGUT COMPONENT-144",NULL},
/* 18890 */ { "TANGUT COMPONENT-145",NULL},
/* 18891 */ { "TANGUT COMPONENT-146",NULL},
/* 18892 */ { "TANGUT COMPONENT-147",NULL},
/* 18893 */ { "TANGUT COMPONENT-148",NULL},
/* 18894 */ { "TANGUT COMPONENT-149",NULL},
/* 18895 */ { "TANGUT COMPONENT-150",NULL},
/* 18896 */ { "TANGUT COMPONENT-151",NULL},
/* 18897 */ { "TANGUT COMPONENT-152",NULL},
/* 18898 */ { "TANGUT COMPONENT-153",NULL},
/* 18899 */ { "TANGUT COMPONENT-154",NULL},
/* 1889A */ { "TANGUT COMPONENT-155",NULL},
/* 1889B */ { "TANGUT COMPONENT-156",NULL},
/* 1889C */ { "TANGUT COMPONENT-157",NULL},
/* 1889D */ { "TANGUT COMPONENT-158",NULL},
/* 1889E */ { "TANGUT COMPONENT-159",NULL},
/* 1889F */ { "TANGUT COMPONENT-160",NULL},
/* 188A0 */ { "TANGUT COMPONENT-161",NULL},
/* 188A1 */ { "TANGUT COMPONENT-162",NULL},
/* 188A2 */ { "TANGUT COMPONENT-163",NULL},
/* 188A3 */ { "TANGUT COMPONENT-164",NULL},
/* 188A4 */ { "TANGUT COMPONENT-165",NULL},
/* 188A5 */ { "TANGUT COMPONENT-166",NULL},
/* 188A6 */ { "TANGUT COMPONENT-167",NULL},
/* 188A7 */ { "TANGUT COMPONENT-168",NULL},
/* 188A8 */ { "TANGUT COMPONENT-169",NULL},
/* 188A9 */ { "TANGUT COMPONENT-170",NULL},
/* 188AA */ { "TANGUT COMPONENT-171",NULL},
/* 188AB */ { "TANGUT COMPONENT-172",NULL},
/* 188AC */ { "TANGUT COMPONENT-173",NULL},
/* 188AD */ { "TANGUT COMPONENT-174",NULL},
/* 188AE */ { "TANGUT COMPONENT-175",NULL},
/* 188AF */ { "TANGUT COMPONENT-176",NULL},
/* 188B0 */ { "TANGUT COMPONENT-177",NULL},
/* 188B1 */ { "TANGUT COMPONENT-178",NULL},
/* 188B2 */ { "TANGUT COMPONENT-179",NULL},
/* 188B3 */ { "TANGUT COMPONENT-180",NULL},
/* 188B4 */ { "TANGUT COMPONENT-181",NULL},
/* 188B5 */ { "TANGUT COMPONENT-182",NULL},
/* 188B6 */ { "TANGUT COMPONENT-183",NULL},
/* 188B7 */ { "TANGUT COMPONENT-184",NULL},
/* 188B8 */ { "TANGUT COMPONENT-185",NULL},
/* 188B9 */ { "TANGUT COMPONENT-186",NULL},
/* 188BA */ { "TANGUT COMPONENT-187",NULL},
/* 188BB */ { "TANGUT COMPONENT-188",NULL},
/* 188BC */ { "TANGUT COMPONENT-189",NULL},
/* 188BD */ { "TANGUT COMPONENT-190",NULL},
/* 188BE */ { "TANGUT COMPONENT-191",NULL},
/* 188BF */ { "TANGUT COMPONENT-192",NULL},
/* 188C0 */ { "TANGUT COMPONENT-193",NULL},
/* 188C1 */ { "TANGUT COMPONENT-194",NULL},
/* 188C2 */ { "TANGUT COMPONENT-195",NULL},
/* 188C3 */ { "TANGUT COMPONENT-196",NULL},
/* 188C4 */ { "TANGUT COMPONENT-197",NULL},
/* 188C5 */ { "TANGUT COMPONENT-198",NULL},
/* 188C6 */ { "TANGUT COMPONENT-199",NULL},
/* 188C7 */ { "TANGUT COMPONENT-200",NULL},
/* 188C8 */ { "TANGUT COMPONENT-201",NULL},
/* 188C9 */ { "TANGUT COMPONENT-202",NULL},
/* 188CA */ { "TANGUT COMPONENT-203",NULL},
/* 188CB */ { "TANGUT COMPONENT-204",NULL},
/* 188CC */ { "TANGUT COMPONENT-205",NULL},
/* 188CD */ { "TANGUT COMPONENT-206",NULL},
/* 188CE */ { "TANGUT COMPONENT-207",NULL},
/* 188CF */ { "TANGUT COMPONENT-208",NULL},
/* 188D0 */ { "TANGUT COMPONENT-209",NULL},
/* 188D1 */ { "TANGUT COMPONENT-210",NULL},
/* 188D2 */ { "TANGUT COMPONENT-211",NULL},
/* 188D3 */ { "TANGUT COMPONENT-212",NULL},
/* 188D4 */ { "TANGUT COMPONENT-213",NULL},
/* 188D5 */ { "TANGUT COMPONENT-214",NULL},
/* 188D6 */ { "TANGUT COMPONENT-215",NULL},
/* 188D7 */ { "TANGUT COMPONENT-216",NULL},
/* 188D8 */ { "TANGUT COMPONENT-217",NULL},
/* 188D9 */ { "TANGUT COMPONENT-218",NULL},
/* 188DA */ { "TANGUT COMPONENT-219",NULL},
/* 188DB */ { "TANGUT COMPONENT-220",NULL},
/* 188DC */ { "TANGUT COMPONENT-221",NULL},
/* 188DD */ { "TANGUT COMPONENT-222",NULL},
/* 188DE */ { "TANGUT COMPONENT-223",NULL},
/* 188DF */ { "TANGUT COMPONENT-224",NULL},
/* 188E0 */ { "TANGUT COMPONENT-225",NULL},
/* 188E1 */ { "TANGUT COMPONENT-226",NULL},
/* 188E2 */ { "TANGUT COMPONENT-227",NULL},
/* 188E3 */ { "TANGUT COMPONENT-228",NULL},
/* 188E4 */ { "TANGUT COMPONENT-229",NULL},
/* 188E5 */ { "TANGUT COMPONENT-230",NULL},
/* 188E6 */ { "TANGUT COMPONENT-231",NULL},
/* 188E7 */ { "TANGUT COMPONENT-232",NULL},
/* 188E8 */ { "TANGUT COMPONENT-233",NULL},
/* 188E9 */ { "TANGUT COMPONENT-234",NULL},
/* 188EA */ { "TANGUT COMPONENT-235",NULL},
/* 188EB */ { "TANGUT COMPONENT-236",NULL},
/* 188EC */ { "TANGUT COMPONENT-237",NULL},
/* 188ED */ { "TANGUT COMPONENT-238",NULL},
/* 188EE */ { "TANGUT COMPONENT-239",NULL},
/* 188EF */ { "TANGUT COMPONENT-240",NULL},
/* 188F0 */ { "TANGUT COMPONENT-241",NULL},
/* 188F1 */ { "TANGUT COMPONENT-242",NULL},
/* 188F2 */ { "TANGUT COMPONENT-243",NULL},
/* 188F3 */ { "TANGUT COMPONENT-244",NULL},
/* 188F4 */ { "TANGUT COMPONENT-245",NULL},
/* 188F5 */ { "TANGUT COMPONENT-246",NULL},
/* 188F6 */ { "TANGUT COMPONENT-247",NULL},
/* 188F7 */ { "TANGUT COMPONENT-248",NULL},
/* 188F8 */ { "TANGUT COMPONENT-249",NULL},
/* 188F9 */ { "TANGUT COMPONENT-250",NULL},
/* 188FA */ { "TANGUT COMPONENT-251",NULL},
/* 188FB */ { "TANGUT COMPONENT-252",NULL},
/* 188FC */ { "TANGUT COMPONENT-253",NULL},
/* 188FD */ { "TANGUT COMPONENT-254",NULL},
/* 188FE */ { "TANGUT COMPONENT-255",NULL},
/* 188FF */ { "TANGUT COMPONENT-256",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_89[] = {
/* 18900 */ { "TANGUT COMPONENT-257",NULL},
/* 18901 */ { "TANGUT COMPONENT-258",NULL},
/* 18902 */ { "TANGUT COMPONENT-259",NULL},
/* 18903 */ { "TANGUT COMPONENT-260",NULL},
/* 18904 */ { "TANGUT COMPONENT-261",NULL},
/* 18905 */ { "TANGUT COMPONENT-262",NULL},
/* 18906 */ { "TANGUT COMPONENT-263",NULL},
/* 18907 */ { "TANGUT COMPONENT-264",NULL},
/* 18908 */ { "TANGUT COMPONENT-265",NULL},
/* 18909 */ { "TANGUT COMPONENT-266",NULL},
/* 1890A */ { "TANGUT COMPONENT-267",NULL},
/* 1890B */ { "TANGUT COMPONENT-268",NULL},
/* 1890C */ { "TANGUT COMPONENT-269",NULL},
/* 1890D */ { "TANGUT COMPONENT-270",NULL},
/* 1890E */ { "TANGUT COMPONENT-271",NULL},
/* 1890F */ { "TANGUT COMPONENT-272",NULL},
/* 18910 */ { "TANGUT COMPONENT-273",NULL},
/* 18911 */ { "TANGUT COMPONENT-274",NULL},
/* 18912 */ { "TANGUT COMPONENT-275",NULL},
/* 18913 */ { "TANGUT COMPONENT-276",NULL},
/* 18914 */ { "TANGUT COMPONENT-277",NULL},
/* 18915 */ { "TANGUT COMPONENT-278",NULL},
/* 18916 */ { "TANGUT COMPONENT-279",NULL},
/* 18917 */ { "TANGUT COMPONENT-280",NULL},
/* 18918 */ { "TANGUT COMPONENT-281",NULL},
/* 18919 */ { "TANGUT COMPONENT-282",NULL},
/* 1891A */ { "TANGUT COMPONENT-283",NULL},
/* 1891B */ { "TANGUT COMPONENT-284",NULL},
/* 1891C */ { "TANGUT COMPONENT-285",NULL},
/* 1891D */ { "TANGUT COMPONENT-286",NULL},
/* 1891E */ { "TANGUT COMPONENT-287",NULL},
/* 1891F */ { "TANGUT COMPONENT-288",NULL},
/* 18920 */ { "TANGUT COMPONENT-289",NULL},
/* 18921 */ { "TANGUT COMPONENT-290",NULL},
/* 18922 */ { "TANGUT COMPONENT-291",NULL},
/* 18923 */ { "TANGUT COMPONENT-292",NULL},
/* 18924 */ { "TANGUT COMPONENT-293",NULL},
/* 18925 */ { "TANGUT COMPONENT-294",NULL},
/* 18926 */ { "TANGUT COMPONENT-295",NULL},
/* 18927 */ { "TANGUT COMPONENT-296",NULL},
/* 18928 */ { "TANGUT COMPONENT-297",NULL},
/* 18929 */ { "TANGUT COMPONENT-298",NULL},
/* 1892A */ { "TANGUT COMPONENT-299",NULL},
/* 1892B */ { "TANGUT COMPONENT-300",NULL},
/* 1892C */ { "TANGUT COMPONENT-301",NULL},
/* 1892D */ { "TANGUT COMPONENT-302",NULL},
/* 1892E */ { "TANGUT COMPONENT-303",NULL},
/* 1892F */ { "TANGUT COMPONENT-304",NULL},
/* 18930 */ { "TANGUT COMPONENT-305",NULL},
/* 18931 */ { "TANGUT COMPONENT-306",NULL},
/* 18932 */ { "TANGUT COMPONENT-307",NULL},
/* 18933 */ { "TANGUT COMPONENT-308",NULL},
/* 18934 */ { "TANGUT COMPONENT-309",NULL},
/* 18935 */ { "TANGUT COMPONENT-310",NULL},
/* 18936 */ { "TANGUT COMPONENT-311",NULL},
/* 18937 */ { "TANGUT COMPONENT-312",NULL},
/* 18938 */ { "TANGUT COMPONENT-313",NULL},
/* 18939 */ { "TANGUT COMPONENT-314",NULL},
/* 1893A */ { "TANGUT COMPONENT-315",NULL},
/* 1893B */ { "TANGUT COMPONENT-316",NULL},
/* 1893C */ { "TANGUT COMPONENT-317",NULL},
/* 1893D */ { "TANGUT COMPONENT-318",NULL},
/* 1893E */ { "TANGUT COMPONENT-319",NULL},
/* 1893F */ { "TANGUT COMPONENT-320",NULL},
/* 18940 */ { "TANGUT COMPONENT-321",NULL},
/* 18941 */ { "TANGUT COMPONENT-322",NULL},
/* 18942 */ { "TANGUT COMPONENT-323",NULL},
/* 18943 */ { "TANGUT COMPONENT-324",NULL},
/* 18944 */ { "TANGUT COMPONENT-325",NULL},
/* 18945 */ { "TANGUT COMPONENT-326",NULL},
/* 18946 */ { "TANGUT COMPONENT-327",NULL},
/* 18947 */ { "TANGUT COMPONENT-328",NULL},
/* 18948 */ { "TANGUT COMPONENT-329",NULL},
/* 18949 */ { "TANGUT COMPONENT-330",NULL},
/* 1894A */ { "TANGUT COMPONENT-331",NULL},
/* 1894B */ { "TANGUT COMPONENT-332",NULL},
/* 1894C */ { "TANGUT COMPONENT-333",NULL},
/* 1894D */ { "TANGUT COMPONENT-334",NULL},
/* 1894E */ { "TANGUT COMPONENT-335",NULL},
/* 1894F */ { "TANGUT COMPONENT-336",NULL},
/* 18950 */ { "TANGUT COMPONENT-337",NULL},
/* 18951 */ { "TANGUT COMPONENT-338",NULL},
/* 18952 */ { "TANGUT COMPONENT-339",NULL},
/* 18953 */ { "TANGUT COMPONENT-340",NULL},
/* 18954 */ { "TANGUT COMPONENT-341",NULL},
/* 18955 */ { "TANGUT COMPONENT-342",NULL},
/* 18956 */ { "TANGUT COMPONENT-343",NULL},
/* 18957 */ { "TANGUT COMPONENT-344",NULL},
/* 18958 */ { "TANGUT COMPONENT-345",NULL},
/* 18959 */ { "TANGUT COMPONENT-346",NULL},
/* 1895A */ { "TANGUT COMPONENT-347",NULL},
/* 1895B */ { "TANGUT COMPONENT-348",NULL},
/* 1895C */ { "TANGUT COMPONENT-349",NULL},
/* 1895D */ { "TANGUT COMPONENT-350",NULL},
/* 1895E */ { "TANGUT COMPONENT-351",NULL},
/* 1895F */ { "TANGUT COMPONENT-352",NULL},
/* 18960 */ { "TANGUT COMPONENT-353",NULL},
/* 18961 */ { "TANGUT COMPONENT-354",NULL},
/* 18962 */ { "TANGUT COMPONENT-355",NULL},
/* 18963 */ { "TANGUT COMPONENT-356",NULL},
/* 18964 */ { "TANGUT COMPONENT-357",NULL},
/* 18965 */ { "TANGUT COMPONENT-358",NULL},
/* 18966 */ { "TANGUT COMPONENT-359",NULL},
/* 18967 */ { "TANGUT COMPONENT-360",NULL},
/* 18968 */ { "TANGUT COMPONENT-361",NULL},
/* 18969 */ { "TANGUT COMPONENT-362",NULL},
/* 1896A */ { "TANGUT COMPONENT-363",NULL},
/* 1896B */ { "TANGUT COMPONENT-364",NULL},
/* 1896C */ { "TANGUT COMPONENT-365",NULL},
/* 1896D */ { "TANGUT COMPONENT-366",NULL},
/* 1896E */ { "TANGUT COMPONENT-367",NULL},
/* 1896F */ { "TANGUT COMPONENT-368",NULL},
/* 18970 */ { "TANGUT COMPONENT-369",NULL},
/* 18971 */ { "TANGUT COMPONENT-370",NULL},
/* 18972 */ { "TANGUT COMPONENT-371",NULL},
/* 18973 */ { "TANGUT COMPONENT-372",NULL},
/* 18974 */ { "TANGUT COMPONENT-373",NULL},
/* 18975 */ { "TANGUT COMPONENT-374",NULL},
/* 18976 */ { "TANGUT COMPONENT-375",NULL},
/* 18977 */ { "TANGUT COMPONENT-376",NULL},
/* 18978 */ { "TANGUT COMPONENT-377",NULL},
/* 18979 */ { "TANGUT COMPONENT-378",NULL},
/* 1897A */ { "TANGUT COMPONENT-379",NULL},
/* 1897B */ { "TANGUT COMPONENT-380",NULL},
/* 1897C */ { "TANGUT COMPONENT-381",NULL},
/* 1897D */ { "TANGUT COMPONENT-382",NULL},
/* 1897E */ { "TANGUT COMPONENT-383",NULL},
/* 1897F */ { "TANGUT COMPONENT-384",NULL},
/* 18980 */ { "TANGUT COMPONENT-385",NULL},
/* 18981 */ { "TANGUT COMPONENT-386",NULL},
/* 18982 */ { "TANGUT COMPONENT-387",NULL},
/* 18983 */ { "TANGUT COMPONENT-388",NULL},
/* 18984 */ { "TANGUT COMPONENT-389",NULL},
/* 18985 */ { "TANGUT COMPONENT-390",NULL},
/* 18986 */ { "TANGUT COMPONENT-391",NULL},
/* 18987 */ { "TANGUT COMPONENT-392",NULL},
/* 18988 */ { "TANGUT COMPONENT-393",NULL},
/* 18989 */ { "TANGUT COMPONENT-394",NULL},
/* 1898A */ { "TANGUT COMPONENT-395",NULL},
/* 1898B */ { "TANGUT COMPONENT-396",NULL},
/* 1898C */ { "TANGUT COMPONENT-397",NULL},
/* 1898D */ { "TANGUT COMPONENT-398",NULL},
/* 1898E */ { "TANGUT COMPONENT-399",NULL},
/* 1898F */ { "TANGUT COMPONENT-400",NULL},
/* 18990 */ { "TANGUT COMPONENT-401",NULL},
/* 18991 */ { "TANGUT COMPONENT-402",NULL},
/* 18992 */ { "TANGUT COMPONENT-403",NULL},
/* 18993 */ { "TANGUT COMPONENT-404",NULL},
/* 18994 */ { "TANGUT COMPONENT-405",NULL},
/* 18995 */ { "TANGUT COMPONENT-406",NULL},
/* 18996 */ { "TANGUT COMPONENT-407",NULL},
/* 18997 */ { "TANGUT COMPONENT-408",NULL},
/* 18998 */ { "TANGUT COMPONENT-409",NULL},
/* 18999 */ { "TANGUT COMPONENT-410",NULL},
/* 1899A */ { "TANGUT COMPONENT-411",NULL},
/* 1899B */ { "TANGUT COMPONENT-412",NULL},
/* 1899C */ { "TANGUT COMPONENT-413",NULL},
/* 1899D */ { "TANGUT COMPONENT-414",NULL},
/* 1899E */ { "TANGUT COMPONENT-415",NULL},
/* 1899F */ { "TANGUT COMPONENT-416",NULL},
/* 189A0 */ { "TANGUT COMPONENT-417",NULL},
/* 189A1 */ { "TANGUT COMPONENT-418",NULL},
/* 189A2 */ { "TANGUT COMPONENT-419",NULL},
/* 189A3 */ { "TANGUT COMPONENT-420",NULL},
/* 189A4 */ { "TANGUT COMPONENT-421",NULL},
/* 189A5 */ { "TANGUT COMPONENT-422",NULL},
/* 189A6 */ { "TANGUT COMPONENT-423",NULL},
/* 189A7 */ { "TANGUT COMPONENT-424",NULL},
/* 189A8 */ { "TANGUT COMPONENT-425",NULL},
/* 189A9 */ { "TANGUT COMPONENT-426",NULL},
/* 189AA */ { "TANGUT COMPONENT-427",NULL},
/* 189AB */ { "TANGUT COMPONENT-428",NULL},
/* 189AC */ { "TANGUT COMPONENT-429",NULL},
/* 189AD */ { "TANGUT COMPONENT-430",NULL},
/* 189AE */ { "TANGUT COMPONENT-431",NULL},
/* 189AF */ { "TANGUT COMPONENT-432",NULL},
/* 189B0 */ { "TANGUT COMPONENT-433",NULL},
/* 189B1 */ { "TANGUT COMPONENT-434",NULL},
/* 189B2 */ { "TANGUT COMPONENT-435",NULL},
/* 189B3 */ { "TANGUT COMPONENT-436",NULL},
/* 189B4 */ { "TANGUT COMPONENT-437",NULL},
/* 189B5 */ { "TANGUT COMPONENT-438",NULL},
/* 189B6 */ { "TANGUT COMPONENT-439",NULL},
/* 189B7 */ { "TANGUT COMPONENT-440",NULL},
/* 189B8 */ { "TANGUT COMPONENT-441",NULL},
/* 189B9 */ { "TANGUT COMPONENT-442",NULL},
/* 189BA */ { "TANGUT COMPONENT-443",NULL},
/* 189BB */ { "TANGUT COMPONENT-444",NULL},
/* 189BC */ { "TANGUT COMPONENT-445",NULL},
/* 189BD */ { "TANGUT COMPONENT-446",NULL},
/* 189BE */ { "TANGUT COMPONENT-447",NULL},
/* 189BF */ { "TANGUT COMPONENT-448",NULL},
/* 189C0 */ { "TANGUT COMPONENT-449",NULL},
/* 189C1 */ { "TANGUT COMPONENT-450",NULL},
/* 189C2 */ { "TANGUT COMPONENT-451",NULL},
/* 189C3 */ { "TANGUT COMPONENT-452",NULL},
/* 189C4 */ { "TANGUT COMPONENT-453",NULL},
/* 189C5 */ { "TANGUT COMPONENT-454",NULL},
/* 189C6 */ { "TANGUT COMPONENT-455",NULL},
/* 189C7 */ { "TANGUT COMPONENT-456",NULL},
/* 189C8 */ { "TANGUT COMPONENT-457",NULL},
/* 189C9 */ { "TANGUT COMPONENT-458",NULL},
/* 189CA */ { "TANGUT COMPONENT-459",NULL},
/* 189CB */ { "TANGUT COMPONENT-460",NULL},
/* 189CC */ { "TANGUT COMPONENT-461",NULL},
/* 189CD */ { "TANGUT COMPONENT-462",NULL},
/* 189CE */ { "TANGUT COMPONENT-463",NULL},
/* 189CF */ { "TANGUT COMPONENT-464",NULL},
/* 189D0 */ { "TANGUT COMPONENT-465",NULL},
/* 189D1 */ { "TANGUT COMPONENT-466",NULL},
/* 189D2 */ { "TANGUT COMPONENT-467",NULL},
/* 189D3 */ { "TANGUT COMPONENT-468",NULL},
/* 189D4 */ { "TANGUT COMPONENT-469",NULL},
/* 189D5 */ { "TANGUT COMPONENT-470",NULL},
/* 189D6 */ { "TANGUT COMPONENT-471",NULL},
/* 189D7 */ { "TANGUT COMPONENT-472",NULL},
/* 189D8 */ { "TANGUT COMPONENT-473",NULL},
/* 189D9 */ { "TANGUT COMPONENT-474",NULL},
/* 189DA */ { "TANGUT COMPONENT-475",NULL},
/* 189DB */ { "TANGUT COMPONENT-476",NULL},
/* 189DC */ { "TANGUT COMPONENT-477",NULL},
/* 189DD */ { "TANGUT COMPONENT-478",NULL},
/* 189DE */ { "TANGUT COMPONENT-479",NULL},
/* 189DF */ { "TANGUT COMPONENT-480",NULL},
/* 189E0 */ { "TANGUT COMPONENT-481",NULL},
/* 189E1 */ { "TANGUT COMPONENT-482",NULL},
/* 189E2 */ { "TANGUT COMPONENT-483",NULL},
/* 189E3 */ { "TANGUT COMPONENT-484",NULL},
/* 189E4 */ { "TANGUT COMPONENT-485",NULL},
/* 189E5 */ { "TANGUT COMPONENT-486",NULL},
/* 189E6 */ { "TANGUT COMPONENT-487",NULL},
/* 189E7 */ { "TANGUT COMPONENT-488",NULL},
/* 189E8 */ { "TANGUT COMPONENT-489",NULL},
/* 189E9 */ { "TANGUT COMPONENT-490",NULL},
/* 189EA */ { "TANGUT COMPONENT-491",NULL},
/* 189EB */ { "TANGUT COMPONENT-492",NULL},
/* 189EC */ { "TANGUT COMPONENT-493",NULL},
/* 189ED */ { "TANGUT COMPONENT-494",NULL},
/* 189EE */ { "TANGUT COMPONENT-495",NULL},
/* 189EF */ { "TANGUT COMPONENT-496",NULL},
/* 189F0 */ { "TANGUT COMPONENT-497",NULL},
/* 189F1 */ { "TANGUT COMPONENT-498",NULL},
/* 189F2 */ { "TANGUT COMPONENT-499",NULL},
/* 189F3 */ { "TANGUT COMPONENT-500",NULL},
/* 189F4 */ { "TANGUT COMPONENT-501",NULL},
/* 189F5 */ { "TANGUT COMPONENT-502",NULL},
/* 189F6 */ { "TANGUT COMPONENT-503",NULL},
/* 189F7 */ { "TANGUT COMPONENT-504",NULL},
/* 189F8 */ { "TANGUT COMPONENT-505",NULL},
/* 189F9 */ { "TANGUT COMPONENT-506",NULL},
/* 189FA */ { "TANGUT COMPONENT-507",NULL},
/* 189FB */ { "TANGUT COMPONENT-508",NULL},
/* 189FC */ { "TANGUT COMPONENT-509",NULL},
/* 189FD */ { "TANGUT COMPONENT-510",NULL},
/* 189FE */ { "TANGUT COMPONENT-511",NULL},
/* 189FF */ { "TANGUT COMPONENT-512",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_8A[] = {
/* 18A00 */ { "TANGUT COMPONENT-513",NULL},
/* 18A01 */ { "TANGUT COMPONENT-514",NULL},
/* 18A02 */ { "TANGUT COMPONENT-515",NULL},
/* 18A03 */ { "TANGUT COMPONENT-516",NULL},
/* 18A04 */ { "TANGUT COMPONENT-517",NULL},
/* 18A05 */ { "TANGUT COMPONENT-518",NULL},
/* 18A06 */ { "TANGUT COMPONENT-519",NULL},
/* 18A07 */ { "TANGUT COMPONENT-520",NULL},
/* 18A08 */ { "TANGUT COMPONENT-521",NULL},
/* 18A09 */ { "TANGUT COMPONENT-522",NULL},
/* 18A0A */ { "TANGUT COMPONENT-523",NULL},
/* 18A0B */ { "TANGUT COMPONENT-524",NULL},
/* 18A0C */ { "TANGUT COMPONENT-525",NULL},
/* 18A0D */ { "TANGUT COMPONENT-526",NULL},
/* 18A0E */ { "TANGUT COMPONENT-527",NULL},
/* 18A0F */ { "TANGUT COMPONENT-528",NULL},
/* 18A10 */ { "TANGUT COMPONENT-529",NULL},
/* 18A11 */ { "TANGUT COMPONENT-530",NULL},
/* 18A12 */ { "TANGUT COMPONENT-531",NULL},
/* 18A13 */ { "TANGUT COMPONENT-532",NULL},
/* 18A14 */ { "TANGUT COMPONENT-533",NULL},
/* 18A15 */ { "TANGUT COMPONENT-534",NULL},
/* 18A16 */ { "TANGUT COMPONENT-535",NULL},
/* 18A17 */ { "TANGUT COMPONENT-536",NULL},
/* 18A18 */ { "TANGUT COMPONENT-537",NULL},
/* 18A19 */ { "TANGUT COMPONENT-538",NULL},
/* 18A1A */ { "TANGUT COMPONENT-539",NULL},
/* 18A1B */ { "TANGUT COMPONENT-540",NULL},
/* 18A1C */ { "TANGUT COMPONENT-541",NULL},
/* 18A1D */ { "TANGUT COMPONENT-542",NULL},
/* 18A1E */ { "TANGUT COMPONENT-543",NULL},
/* 18A1F */ { "TANGUT COMPONENT-544",NULL},
/* 18A20 */ { "TANGUT COMPONENT-545",NULL},
/* 18A21 */ { "TANGUT COMPONENT-546",NULL},
/* 18A22 */ { "TANGUT COMPONENT-547",NULL},
/* 18A23 */ { "TANGUT COMPONENT-548",NULL},
/* 18A24 */ { "TANGUT COMPONENT-549",NULL},
/* 18A25 */ { "TANGUT COMPONENT-550",NULL},
/* 18A26 */ { "TANGUT COMPONENT-551",NULL},
/* 18A27 */ { "TANGUT COMPONENT-552",NULL},
/* 18A28 */ { "TANGUT COMPONENT-553",NULL},
/* 18A29 */ { "TANGUT COMPONENT-554",NULL},
/* 18A2A */ { "TANGUT COMPONENT-555",NULL},
/* 18A2B */ { "TANGUT COMPONENT-556",NULL},
/* 18A2C */ { "TANGUT COMPONENT-557",NULL},
/* 18A2D */ { "TANGUT COMPONENT-558",NULL},
/* 18A2E */ { "TANGUT COMPONENT-559",NULL},
/* 18A2F */ { "TANGUT COMPONENT-560",NULL},
/* 18A30 */ { "TANGUT COMPONENT-561",NULL},
/* 18A31 */ { "TANGUT COMPONENT-562",NULL},
/* 18A32 */ { "TANGUT COMPONENT-563",NULL},
/* 18A33 */ { "TANGUT COMPONENT-564",NULL},
/* 18A34 */ { "TANGUT COMPONENT-565",NULL},
/* 18A35 */ { "TANGUT COMPONENT-566",NULL},
/* 18A36 */ { "TANGUT COMPONENT-567",NULL},
/* 18A37 */ { "TANGUT COMPONENT-568",NULL},
/* 18A38 */ { "TANGUT COMPONENT-569",NULL},
/* 18A39 */ { "TANGUT COMPONENT-570",NULL},
/* 18A3A */ { "TANGUT COMPONENT-571",NULL},
/* 18A3B */ { "TANGUT COMPONENT-572",NULL},
/* 18A3C */ { "TANGUT COMPONENT-573",NULL},
/* 18A3D */ { "TANGUT COMPONENT-574",NULL},
/* 18A3E */ { "TANGUT COMPONENT-575",NULL},
/* 18A3F */ { "TANGUT COMPONENT-576",NULL},
/* 18A40 */ { "TANGUT COMPONENT-577",NULL},
/* 18A41 */ { "TANGUT COMPONENT-578",NULL},
/* 18A42 */ { "TANGUT COMPONENT-579",NULL},
/* 18A43 */ { "TANGUT COMPONENT-580",NULL},
/* 18A44 */ { "TANGUT COMPONENT-581",NULL},
/* 18A45 */ { "TANGUT COMPONENT-582",NULL},
/* 18A46 */ { "TANGUT COMPONENT-583",NULL},
/* 18A47 */ { "TANGUT COMPONENT-584",NULL},
/* 18A48 */ { "TANGUT COMPONENT-585",NULL},
/* 18A49 */ { "TANGUT COMPONENT-586",NULL},
/* 18A4A */ { "TANGUT COMPONENT-587",NULL},
/* 18A4B */ { "TANGUT COMPONENT-588",NULL},
/* 18A4C */ { "TANGUT COMPONENT-589",NULL},
/* 18A4D */ { "TANGUT COMPONENT-590",NULL},
/* 18A4E */ { "TANGUT COMPONENT-591",NULL},
/* 18A4F */ { "TANGUT COMPONENT-592",NULL},
/* 18A50 */ { "TANGUT COMPONENT-593",NULL},
/* 18A51 */ { "TANGUT COMPONENT-594",NULL},
/* 18A52 */ { "TANGUT COMPONENT-595",NULL},
/* 18A53 */ { "TANGUT COMPONENT-596",NULL},
/* 18A54 */ { "TANGUT COMPONENT-597",NULL},
/* 18A55 */ { "TANGUT COMPONENT-598",NULL},
/* 18A56 */ { "TANGUT COMPONENT-599",NULL},
/* 18A57 */ { "TANGUT COMPONENT-600",NULL},
/* 18A58 */ { "TANGUT COMPONENT-601",NULL},
/* 18A59 */ { "TANGUT COMPONENT-602",NULL},
/* 18A5A */ { "TANGUT COMPONENT-603",NULL},
/* 18A5B */ { "TANGUT COMPONENT-604",NULL},
/* 18A5C */ { "TANGUT COMPONENT-605",NULL},
/* 18A5D */ { "TANGUT COMPONENT-606",NULL},
/* 18A5E */ { "TANGUT COMPONENT-607",NULL},
/* 18A5F */ { "TANGUT COMPONENT-608",NULL},
/* 18A60 */ { "TANGUT COMPONENT-609",NULL},
/* 18A61 */ { "TANGUT COMPONENT-610",NULL},
/* 18A62 */ { "TANGUT COMPONENT-611",NULL},
/* 18A63 */ { "TANGUT COMPONENT-612",NULL},
/* 18A64 */ { "TANGUT COMPONENT-613",NULL},
/* 18A65 */ { "TANGUT COMPONENT-614",NULL},
/* 18A66 */ { "TANGUT COMPONENT-615",NULL},
/* 18A67 */ { "TANGUT COMPONENT-616",NULL},
/* 18A68 */ { "TANGUT COMPONENT-617",NULL},
/* 18A69 */ { "TANGUT COMPONENT-618",NULL},
/* 18A6A */ { "TANGUT COMPONENT-619",NULL},
/* 18A6B */ { "TANGUT COMPONENT-620",NULL},
/* 18A6C */ { "TANGUT COMPONENT-621",NULL},
/* 18A6D */ { "TANGUT COMPONENT-622",NULL},
/* 18A6E */ { "TANGUT COMPONENT-623",NULL},
/* 18A6F */ { "TANGUT COMPONENT-624",NULL},
/* 18A70 */ { "TANGUT COMPONENT-625",NULL},
/* 18A71 */ { "TANGUT COMPONENT-626",NULL},
/* 18A72 */ { "TANGUT COMPONENT-627",NULL},
/* 18A73 */ { "TANGUT COMPONENT-628",NULL},
/* 18A74 */ { "TANGUT COMPONENT-629",NULL},
/* 18A75 */ { "TANGUT COMPONENT-630",NULL},
/* 18A76 */ { "TANGUT COMPONENT-631",NULL},
/* 18A77 */ { "TANGUT COMPONENT-632",NULL},
/* 18A78 */ { "TANGUT COMPONENT-633",NULL},
/* 18A79 */ { "TANGUT COMPONENT-634",NULL},
/* 18A7A */ { "TANGUT COMPONENT-635",NULL},
/* 18A7B */ { "TANGUT COMPONENT-636",NULL},
/* 18A7C */ { "TANGUT COMPONENT-637",NULL},
/* 18A7D */ { "TANGUT COMPONENT-638",NULL},
/* 18A7E */ { "TANGUT COMPONENT-639",NULL},
/* 18A7F */ { "TANGUT COMPONENT-640",NULL},
/* 18A80 */ { "TANGUT COMPONENT-641",NULL},
/* 18A81 */ { "TANGUT COMPONENT-642",NULL},
/* 18A82 */ { "TANGUT COMPONENT-643",NULL},
/* 18A83 */ { "TANGUT COMPONENT-644",NULL},
/* 18A84 */ { "TANGUT COMPONENT-645",NULL},
/* 18A85 */ { "TANGUT COMPONENT-646",NULL},
/* 18A86 */ { "TANGUT COMPONENT-647",NULL},
/* 18A87 */ { "TANGUT COMPONENT-648",NULL},
/* 18A88 */ { "TANGUT COMPONENT-649",NULL},
/* 18A89 */ { "TANGUT COMPONENT-650",NULL},
/* 18A8A */ { "TANGUT COMPONENT-651",NULL},
/* 18A8B */ { "TANGUT COMPONENT-652",NULL},
/* 18A8C */ { "TANGUT COMPONENT-653",NULL},
/* 18A8D */ { "TANGUT COMPONENT-654",NULL},
/* 18A8E */ { "TANGUT COMPONENT-655",NULL},
/* 18A8F */ { "TANGUT COMPONENT-656",NULL},
/* 18A90 */ { "TANGUT COMPONENT-657",NULL},
/* 18A91 */ { "TANGUT COMPONENT-658",NULL},
/* 18A92 */ { "TANGUT COMPONENT-659",NULL},
/* 18A93 */ { "TANGUT COMPONENT-660",NULL},
/* 18A94 */ { "TANGUT COMPONENT-661",NULL},
/* 18A95 */ { "TANGUT COMPONENT-662",NULL},
/* 18A96 */ { "TANGUT COMPONENT-663",NULL},
/* 18A97 */ { "TANGUT COMPONENT-664",NULL},
/* 18A98 */ { "TANGUT COMPONENT-665",NULL},
/* 18A99 */ { "TANGUT COMPONENT-666",NULL},
/* 18A9A */ { "TANGUT COMPONENT-667",NULL},
/* 18A9B */ { "TANGUT COMPONENT-668",NULL},
/* 18A9C */ { "TANGUT COMPONENT-669",NULL},
/* 18A9D */ { "TANGUT COMPONENT-670",NULL},
/* 18A9E */ { "TANGUT COMPONENT-671",NULL},
/* 18A9F */ { "TANGUT COMPONENT-672",NULL},
/* 18AA0 */ { "TANGUT COMPONENT-673",NULL},
/* 18AA1 */ { "TANGUT COMPONENT-674",NULL},
/* 18AA2 */ { "TANGUT COMPONENT-675",NULL},
/* 18AA3 */ { "TANGUT COMPONENT-676",NULL},
/* 18AA4 */ { "TANGUT COMPONENT-677",NULL},
/* 18AA5 */ { "TANGUT COMPONENT-678",NULL},
/* 18AA6 */ { "TANGUT COMPONENT-679",NULL},
/* 18AA7 */ { "TANGUT COMPONENT-680",NULL},
/* 18AA8 */ { "TANGUT COMPONENT-681",NULL},
/* 18AA9 */ { "TANGUT COMPONENT-682",NULL},
/* 18AAA */ { "TANGUT COMPONENT-683",NULL},
/* 18AAB */ { "TANGUT COMPONENT-684",NULL},
/* 18AAC */ { "TANGUT COMPONENT-685",NULL},
/* 18AAD */ { "TANGUT COMPONENT-686",NULL},
/* 18AAE */ { "TANGUT COMPONENT-687",NULL},
/* 18AAF */ { "TANGUT COMPONENT-688",NULL},
/* 18AB0 */ { "TANGUT COMPONENT-689",NULL},
/* 18AB1 */ { "TANGUT COMPONENT-690",NULL},
/* 18AB2 */ { "TANGUT COMPONENT-691",NULL},
/* 18AB3 */ { "TANGUT COMPONENT-692",NULL},
/* 18AB4 */ { "TANGUT COMPONENT-693",NULL},
/* 18AB5 */ { "TANGUT COMPONENT-694",NULL},
/* 18AB6 */ { "TANGUT COMPONENT-695",NULL},
/* 18AB7 */ { "TANGUT COMPONENT-696",NULL},
/* 18AB8 */ { "TANGUT COMPONENT-697",NULL},
/* 18AB9 */ { "TANGUT COMPONENT-698",NULL},
/* 18ABA */ { "TANGUT COMPONENT-699",NULL},
/* 18ABB */ { "TANGUT COMPONENT-700",NULL},
/* 18ABC */ { "TANGUT COMPONENT-701",NULL},
/* 18ABD */ { "TANGUT COMPONENT-702",NULL},
/* 18ABE */ { "TANGUT COMPONENT-703",NULL},
/* 18ABF */ { "TANGUT COMPONENT-704",NULL},
/* 18AC0 */ { "TANGUT COMPONENT-705",NULL},
/* 18AC1 */ { "TANGUT COMPONENT-706",NULL},
/* 18AC2 */ { "TANGUT COMPONENT-707",NULL},
/* 18AC3 */ { "TANGUT COMPONENT-708",NULL},
/* 18AC4 */ { "TANGUT COMPONENT-709",NULL},
/* 18AC5 */ { "TANGUT COMPONENT-710",NULL},
/* 18AC6 */ { "TANGUT COMPONENT-711",NULL},
/* 18AC7 */ { "TANGUT COMPONENT-712",NULL},
/* 18AC8 */ { "TANGUT COMPONENT-713",NULL},
/* 18AC9 */ { "TANGUT COMPONENT-714",NULL},
/* 18ACA */ { "TANGUT COMPONENT-715",NULL},
/* 18ACB */ { "TANGUT COMPONENT-716",NULL},
/* 18ACC */ { "TANGUT COMPONENT-717",NULL},
/* 18ACD */ { "TANGUT COMPONENT-718",NULL},
/* 18ACE */ { "TANGUT COMPONENT-719",NULL},
/* 18ACF */ { "TANGUT COMPONENT-720",NULL},
/* 18AD0 */ { "TANGUT COMPONENT-721",NULL},
/* 18AD1 */ { "TANGUT COMPONENT-722",NULL},
/* 18AD2 */ { "TANGUT COMPONENT-723",NULL},
/* 18AD3 */ { "TANGUT COMPONENT-724",NULL},
/* 18AD4 */ { "TANGUT COMPONENT-725",NULL},
/* 18AD5 */ { "TANGUT COMPONENT-726",NULL},
/* 18AD6 */ { "TANGUT COMPONENT-727",NULL},
/* 18AD7 */ { "TANGUT COMPONENT-728",NULL},
/* 18AD8 */ { "TANGUT COMPONENT-729",NULL},
/* 18AD9 */ { "TANGUT COMPONENT-730",NULL},
/* 18ADA */ { "TANGUT COMPONENT-731",NULL},
/* 18ADB */ { "TANGUT COMPONENT-732",NULL},
/* 18ADC */ { "TANGUT COMPONENT-733",NULL},
/* 18ADD */ { "TANGUT COMPONENT-734",NULL},
/* 18ADE */ { "TANGUT COMPONENT-735",NULL},
/* 18ADF */ { "TANGUT COMPONENT-736",NULL},
/* 18AE0 */ { "TANGUT COMPONENT-737",NULL},
/* 18AE1 */ { "TANGUT COMPONENT-738",NULL},
/* 18AE2 */ { "TANGUT COMPONENT-739",NULL},
/* 18AE3 */ { "TANGUT COMPONENT-740",NULL},
/* 18AE4 */ { "TANGUT COMPONENT-741",NULL},
/* 18AE5 */ { "TANGUT COMPONENT-742",NULL},
/* 18AE6 */ { "TANGUT COMPONENT-743",NULL},
/* 18AE7 */ { "TANGUT COMPONENT-744",NULL},
/* 18AE8 */ { "TANGUT COMPONENT-745",NULL},
/* 18AE9 */ { "TANGUT COMPONENT-746",NULL},
/* 18AEA */ { "TANGUT COMPONENT-747",NULL},
/* 18AEB */ { "TANGUT COMPONENT-748",NULL},
/* 18AEC */ { "TANGUT COMPONENT-749",NULL},
/* 18AED */ { "TANGUT COMPONENT-750",NULL},
/* 18AEE */ { "TANGUT COMPONENT-751",NULL},
/* 18AEF */ { "TANGUT COMPONENT-752",NULL},
/* 18AF0 */ { "TANGUT COMPONENT-753",NULL},
/* 18AF1 */ { "TANGUT COMPONENT-754",NULL},
/* 18AF2 */ { "TANGUT COMPONENT-755",NULL},
/* 18AF3 */ { "TANGUT COMPONENT-756","	* two strokes"},
/* 18AF4 */ { "TANGUT COMPONENT-757","	* eight strokes"},
/* 18AF5 */ { "TANGUT COMPONENT-758","	* seven strokes"},
/* 18AF6 */ { "TANGUT COMPONENT-759","	* eight strokes"},
/* 18AF7 */ { "TANGUT COMPONENT-760","	* six strokes"},
/* 18AF8 */ { "TANGUT COMPONENT-761","	* seven strokes"},
/* 18AF9 */ { "TANGUT COMPONENT-762","	* ten strokes"},
/* 18AFA */ { "TANGUT COMPONENT-763","	* two strokes"},
/* 18AFB */ { "TANGUT COMPONENT-764","	* two strokes"},
/* 18AFC */ { "TANGUT COMPONENT-765","	* three strokes"},
/* 18AFD */ { "TANGUT COMPONENT-766","	* three strokes"},
/* 18AFE */ { "TANGUT COMPONENT-767","	* four strokes"},
/* 18AFF */ { "TANGUT COMPONENT-768","	* four strokes"}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_8B[] = {
/* 18B00 */ { "KHITAN SMALL SCRIPT CHARACTER-18B00",NULL},
/* 18B01 */ { "KHITAN SMALL SCRIPT CHARACTER-18B01",NULL},
/* 18B02 */ { "KHITAN SMALL SCRIPT CHARACTER-18B02",NULL},
/* 18B03 */ { "KHITAN SMALL SCRIPT CHARACTER-18B03",NULL},
/* 18B04 */ { "KHITAN SMALL SCRIPT CHARACTER-18B04",NULL},
/* 18B05 */ { "KHITAN SMALL SCRIPT CHARACTER-18B05",NULL},
/* 18B06 */ { "KHITAN SMALL SCRIPT CHARACTER-18B06",NULL},
/* 18B07 */ { "KHITAN SMALL SCRIPT CHARACTER-18B07",NULL},
/* 18B08 */ { "KHITAN SMALL SCRIPT CHARACTER-18B08",NULL},
/* 18B09 */ { "KHITAN SMALL SCRIPT CHARACTER-18B09",NULL},
/* 18B0A */ { "KHITAN SMALL SCRIPT CHARACTER-18B0A",NULL},
/* 18B0B */ { "KHITAN SMALL SCRIPT CHARACTER-18B0B",NULL},
/* 18B0C */ { "KHITAN SMALL SCRIPT CHARACTER-18B0C",NULL},
/* 18B0D */ { "KHITAN SMALL SCRIPT CHARACTER-18B0D",NULL},
/* 18B0E */ { "KHITAN SMALL SCRIPT CHARACTER-18B0E",NULL},
/* 18B0F */ { "KHITAN SMALL SCRIPT CHARACTER-18B0F",NULL},
/* 18B10 */ { "KHITAN SMALL SCRIPT CHARACTER-18B10",NULL},
/* 18B11 */ { "KHITAN SMALL SCRIPT CHARACTER-18B11",NULL},
/* 18B12 */ { "KHITAN SMALL SCRIPT CHARACTER-18B12",NULL},
/* 18B13 */ { "KHITAN SMALL SCRIPT CHARACTER-18B13",NULL},
/* 18B14 */ { "KHITAN SMALL SCRIPT CHARACTER-18B14",NULL},
/* 18B15 */ { "KHITAN SMALL SCRIPT CHARACTER-18B15",NULL},
/* 18B16 */ { "KHITAN SMALL SCRIPT CHARACTER-18B16",NULL},
/* 18B17 */ { "KHITAN SMALL SCRIPT CHARACTER-18B17",NULL},
/* 18B18 */ { "KHITAN SMALL SCRIPT CHARACTER-18B18",NULL},
/* 18B19 */ { "KHITAN SMALL SCRIPT CHARACTER-18B19",NULL},
/* 18B1A */ { "KHITAN SMALL SCRIPT CHARACTER-18B1A",NULL},
/* 18B1B */ { "KHITAN SMALL SCRIPT CHARACTER-18B1B",NULL},
/* 18B1C */ { "KHITAN SMALL SCRIPT CHARACTER-18B1C",NULL},
/* 18B1D */ { "KHITAN SMALL SCRIPT CHARACTER-18B1D",NULL},
/* 18B1E */ { "KHITAN SMALL SCRIPT CHARACTER-18B1E",NULL},
/* 18B1F */ { "KHITAN SMALL SCRIPT CHARACTER-18B1F",NULL},
/* 18B20 */ { "KHITAN SMALL SCRIPT CHARACTER-18B20",NULL},
/* 18B21 */ { "KHITAN SMALL SCRIPT CHARACTER-18B21",NULL},
/* 18B22 */ { "KHITAN SMALL SCRIPT CHARACTER-18B22",NULL},
/* 18B23 */ { "KHITAN SMALL SCRIPT CHARACTER-18B23",NULL},
/* 18B24 */ { "KHITAN SMALL SCRIPT CHARACTER-18B24",NULL},
/* 18B25 */ { "KHITAN SMALL SCRIPT CHARACTER-18B25",NULL},
/* 18B26 */ { "KHITAN SMALL SCRIPT CHARACTER-18B26",NULL},
/* 18B27 */ { "KHITAN SMALL SCRIPT CHARACTER-18B27",NULL},
/* 18B28 */ { "KHITAN SMALL SCRIPT CHARACTER-18B28",NULL},
/* 18B29 */ { "KHITAN SMALL SCRIPT CHARACTER-18B29",NULL},
/* 18B2A */ { "KHITAN SMALL SCRIPT CHARACTER-18B2A",NULL},
/* 18B2B */ { "KHITAN SMALL SCRIPT CHARACTER-18B2B",NULL},
/* 18B2C */ { "KHITAN SMALL SCRIPT CHARACTER-18B2C",NULL},
/* 18B2D */ { "KHITAN SMALL SCRIPT CHARACTER-18B2D",NULL},
/* 18B2E */ { "KHITAN SMALL SCRIPT CHARACTER-18B2E",NULL},
/* 18B2F */ { "KHITAN SMALL SCRIPT CHARACTER-18B2F",NULL},
/* 18B30 */ { "KHITAN SMALL SCRIPT CHARACTER-18B30",NULL},
/* 18B31 */ { "KHITAN SMALL SCRIPT CHARACTER-18B31",NULL},
/* 18B32 */ { "KHITAN SMALL SCRIPT CHARACTER-18B32",NULL},
/* 18B33 */ { "KHITAN SMALL SCRIPT CHARACTER-18B33",NULL},
/* 18B34 */ { "KHITAN SMALL SCRIPT CHARACTER-18B34",NULL},
/* 18B35 */ { "KHITAN SMALL SCRIPT CHARACTER-18B35",NULL},
/* 18B36 */ { "KHITAN SMALL SCRIPT CHARACTER-18B36",NULL},
/* 18B37 */ { "KHITAN SMALL SCRIPT CHARACTER-18B37",NULL},
/* 18B38 */ { "KHITAN SMALL SCRIPT CHARACTER-18B38",NULL},
/* 18B39 */ { "KHITAN SMALL SCRIPT CHARACTER-18B39",NULL},
/* 18B3A */ { "KHITAN SMALL SCRIPT CHARACTER-18B3A",NULL},
/* 18B3B */ { "KHITAN SMALL SCRIPT CHARACTER-18B3B",NULL},
/* 18B3C */ { "KHITAN SMALL SCRIPT CHARACTER-18B3C",NULL},
/* 18B3D */ { "KHITAN SMALL SCRIPT CHARACTER-18B3D",NULL},
/* 18B3E */ { "KHITAN SMALL SCRIPT CHARACTER-18B3E",NULL},
/* 18B3F */ { "KHITAN SMALL SCRIPT CHARACTER-18B3F",NULL},
/* 18B40 */ { "KHITAN SMALL SCRIPT CHARACTER-18B40",NULL},
/* 18B41 */ { "KHITAN SMALL SCRIPT CHARACTER-18B41",NULL},
/* 18B42 */ { "KHITAN SMALL SCRIPT CHARACTER-18B42",NULL},
/* 18B43 */ { "KHITAN SMALL SCRIPT CHARACTER-18B43",NULL},
/* 18B44 */ { "KHITAN SMALL SCRIPT CHARACTER-18B44",NULL},
/* 18B45 */ { "KHITAN SMALL SCRIPT CHARACTER-18B45",NULL},
/* 18B46 */ { "KHITAN SMALL SCRIPT CHARACTER-18B46",NULL},
/* 18B47 */ { "KHITAN SMALL SCRIPT CHARACTER-18B47",NULL},
/* 18B48 */ { "KHITAN SMALL SCRIPT CHARACTER-18B48",NULL},
/* 18B49 */ { "KHITAN SMALL SCRIPT CHARACTER-18B49",NULL},
/* 18B4A */ { "KHITAN SMALL SCRIPT CHARACTER-18B4A",NULL},
/* 18B4B */ { "KHITAN SMALL SCRIPT CHARACTER-18B4B",NULL},
/* 18B4C */ { "KHITAN SMALL SCRIPT CHARACTER-18B4C",NULL},
/* 18B4D */ { "KHITAN SMALL SCRIPT CHARACTER-18B4D",NULL},
/* 18B4E */ { "KHITAN SMALL SCRIPT CHARACTER-18B4E",NULL},
/* 18B4F */ { "KHITAN SMALL SCRIPT CHARACTER-18B4F",NULL},
/* 18B50 */ { "KHITAN SMALL SCRIPT CHARACTER-18B50",NULL},
/* 18B51 */ { "KHITAN SMALL SCRIPT CHARACTER-18B51",NULL},
/* 18B52 */ { "KHITAN SMALL SCRIPT CHARACTER-18B52",NULL},
/* 18B53 */ { "KHITAN SMALL SCRIPT CHARACTER-18B53",NULL},
/* 18B54 */ { "KHITAN SMALL SCRIPT CHARACTER-18B54",NULL},
/* 18B55 */ { "KHITAN SMALL SCRIPT CHARACTER-18B55",NULL},
/* 18B56 */ { "KHITAN SMALL SCRIPT CHARACTER-18B56",NULL},
/* 18B57 */ { "KHITAN SMALL SCRIPT CHARACTER-18B57",NULL},
/* 18B58 */ { "KHITAN SMALL SCRIPT CHARACTER-18B58",NULL},
/* 18B59 */ { "KHITAN SMALL SCRIPT CHARACTER-18B59",NULL},
/* 18B5A */ { "KHITAN SMALL SCRIPT CHARACTER-18B5A",NULL},
/* 18B5B */ { "KHITAN SMALL SCRIPT CHARACTER-18B5B",NULL},
/* 18B5C */ { "KHITAN SMALL SCRIPT CHARACTER-18B5C",NULL},
/* 18B5D */ { "KHITAN SMALL SCRIPT CHARACTER-18B5D",NULL},
/* 18B5E */ { "KHITAN SMALL SCRIPT CHARACTER-18B5E",NULL},
/* 18B5F */ { "KHITAN SMALL SCRIPT CHARACTER-18B5F",NULL},
/* 18B60 */ { "KHITAN SMALL SCRIPT CHARACTER-18B60",NULL},
/* 18B61 */ { "KHITAN SMALL SCRIPT CHARACTER-18B61",NULL},
/* 18B62 */ { "KHITAN SMALL SCRIPT CHARACTER-18B62",NULL},
/* 18B63 */ { "KHITAN SMALL SCRIPT CHARACTER-18B63",NULL},
/* 18B64 */ { "KHITAN SMALL SCRIPT CHARACTER-18B64",NULL},
/* 18B65 */ { "KHITAN SMALL SCRIPT CHARACTER-18B65",NULL},
/* 18B66 */ { "KHITAN SMALL SCRIPT CHARACTER-18B66",NULL},
/* 18B67 */ { "KHITAN SMALL SCRIPT CHARACTER-18B67",NULL},
/* 18B68 */ { "KHITAN SMALL SCRIPT CHARACTER-18B68",NULL},
/* 18B69 */ { "KHITAN SMALL SCRIPT CHARACTER-18B69",NULL},
/* 18B6A */ { "KHITAN SMALL SCRIPT CHARACTER-18B6A",NULL},
/* 18B6B */ { "KHITAN SMALL SCRIPT CHARACTER-18B6B",NULL},
/* 18B6C */ { "KHITAN SMALL SCRIPT CHARACTER-18B6C",NULL},
/* 18B6D */ { "KHITAN SMALL SCRIPT CHARACTER-18B6D",NULL},
/* 18B6E */ { "KHITAN SMALL SCRIPT CHARACTER-18B6E",NULL},
/* 18B6F */ { "KHITAN SMALL SCRIPT CHARACTER-18B6F",NULL},
/* 18B70 */ { "KHITAN SMALL SCRIPT CHARACTER-18B70",NULL},
/* 18B71 */ { "KHITAN SMALL SCRIPT CHARACTER-18B71",NULL},
/* 18B72 */ { "KHITAN SMALL SCRIPT CHARACTER-18B72",NULL},
/* 18B73 */ { "KHITAN SMALL SCRIPT CHARACTER-18B73",NULL},
/* 18B74 */ { "KHITAN SMALL SCRIPT CHARACTER-18B74",NULL},
/* 18B75 */ { "KHITAN SMALL SCRIPT CHARACTER-18B75",NULL},
/* 18B76 */ { "KHITAN SMALL SCRIPT CHARACTER-18B76",NULL},
/* 18B77 */ { "KHITAN SMALL SCRIPT CHARACTER-18B77",NULL},
/* 18B78 */ { "KHITAN SMALL SCRIPT CHARACTER-18B78",NULL},
/* 18B79 */ { "KHITAN SMALL SCRIPT CHARACTER-18B79",NULL},
/* 18B7A */ { "KHITAN SMALL SCRIPT CHARACTER-18B7A",NULL},
/* 18B7B */ { "KHITAN SMALL SCRIPT CHARACTER-18B7B",NULL},
/* 18B7C */ { "KHITAN SMALL SCRIPT CHARACTER-18B7C",NULL},
/* 18B7D */ { "KHITAN SMALL SCRIPT CHARACTER-18B7D",NULL},
/* 18B7E */ { "KHITAN SMALL SCRIPT CHARACTER-18B7E",NULL},
/* 18B7F */ { "KHITAN SMALL SCRIPT CHARACTER-18B7F",NULL},
/* 18B80 */ { "KHITAN SMALL SCRIPT CHARACTER-18B80",NULL},
/* 18B81 */ { "KHITAN SMALL SCRIPT CHARACTER-18B81",NULL},
/* 18B82 */ { "KHITAN SMALL SCRIPT CHARACTER-18B82",NULL},
/* 18B83 */ { "KHITAN SMALL SCRIPT CHARACTER-18B83",NULL},
/* 18B84 */ { "KHITAN SMALL SCRIPT CHARACTER-18B84",NULL},
/* 18B85 */ { "KHITAN SMALL SCRIPT CHARACTER-18B85",NULL},
/* 18B86 */ { "KHITAN SMALL SCRIPT CHARACTER-18B86",NULL},
/* 18B87 */ { "KHITAN SMALL SCRIPT CHARACTER-18B87",NULL},
/* 18B88 */ { "KHITAN SMALL SCRIPT CHARACTER-18B88",NULL},
/* 18B89 */ { "KHITAN SMALL SCRIPT CHARACTER-18B89",NULL},
/* 18B8A */ { "KHITAN SMALL SCRIPT CHARACTER-18B8A",NULL},
/* 18B8B */ { "KHITAN SMALL SCRIPT CHARACTER-18B8B",NULL},
/* 18B8C */ { "KHITAN SMALL SCRIPT CHARACTER-18B8C",NULL},
/* 18B8D */ { "KHITAN SMALL SCRIPT CHARACTER-18B8D",NULL},
/* 18B8E */ { "KHITAN SMALL SCRIPT CHARACTER-18B8E",NULL},
/* 18B8F */ { "KHITAN SMALL SCRIPT CHARACTER-18B8F",NULL},
/* 18B90 */ { "KHITAN SMALL SCRIPT CHARACTER-18B90",NULL},
/* 18B91 */ { "KHITAN SMALL SCRIPT CHARACTER-18B91",NULL},
/* 18B92 */ { "KHITAN SMALL SCRIPT CHARACTER-18B92",NULL},
/* 18B93 */ { "KHITAN SMALL SCRIPT CHARACTER-18B93",NULL},
/* 18B94 */ { "KHITAN SMALL SCRIPT CHARACTER-18B94",NULL},
/* 18B95 */ { "KHITAN SMALL SCRIPT CHARACTER-18B95",NULL},
/* 18B96 */ { "KHITAN SMALL SCRIPT CHARACTER-18B96",NULL},
/* 18B97 */ { "KHITAN SMALL SCRIPT CHARACTER-18B97",NULL},
/* 18B98 */ { "KHITAN SMALL SCRIPT CHARACTER-18B98",NULL},
/* 18B99 */ { "KHITAN SMALL SCRIPT CHARACTER-18B99",NULL},
/* 18B9A */ { "KHITAN SMALL SCRIPT CHARACTER-18B9A",NULL},
/* 18B9B */ { "KHITAN SMALL SCRIPT CHARACTER-18B9B",NULL},
/* 18B9C */ { "KHITAN SMALL SCRIPT CHARACTER-18B9C",NULL},
/* 18B9D */ { "KHITAN SMALL SCRIPT CHARACTER-18B9D",NULL},
/* 18B9E */ { "KHITAN SMALL SCRIPT CHARACTER-18B9E",NULL},
/* 18B9F */ { "KHITAN SMALL SCRIPT CHARACTER-18B9F",NULL},
/* 18BA0 */ { "KHITAN SMALL SCRIPT CHARACTER-18BA0",NULL},
/* 18BA1 */ { "KHITAN SMALL SCRIPT CHARACTER-18BA1",NULL},
/* 18BA2 */ { "KHITAN SMALL SCRIPT CHARACTER-18BA2",NULL},
/* 18BA3 */ { "KHITAN SMALL SCRIPT CHARACTER-18BA3",NULL},
/* 18BA4 */ { "KHITAN SMALL SCRIPT CHARACTER-18BA4",NULL},
/* 18BA5 */ { "KHITAN SMALL SCRIPT CHARACTER-18BA5",NULL},
/* 18BA6 */ { "KHITAN SMALL SCRIPT CHARACTER-18BA6",NULL},
/* 18BA7 */ { "KHITAN SMALL SCRIPT CHARACTER-18BA7",NULL},
/* 18BA8 */ { "KHITAN SMALL SCRIPT CHARACTER-18BA8",NULL},
/* 18BA9 */ { "KHITAN SMALL SCRIPT CHARACTER-18BA9",NULL},
/* 18BAA */ { "KHITAN SMALL SCRIPT CHARACTER-18BAA",NULL},
/* 18BAB */ { "KHITAN SMALL SCRIPT CHARACTER-18BAB",NULL},
/* 18BAC */ { "KHITAN SMALL SCRIPT CHARACTER-18BAC",NULL},
/* 18BAD */ { "KHITAN SMALL SCRIPT CHARACTER-18BAD",NULL},
/* 18BAE */ { "KHITAN SMALL SCRIPT CHARACTER-18BAE",NULL},
/* 18BAF */ { "KHITAN SMALL SCRIPT CHARACTER-18BAF",NULL},
/* 18BB0 */ { "KHITAN SMALL SCRIPT CHARACTER-18BB0",NULL},
/* 18BB1 */ { "KHITAN SMALL SCRIPT CHARACTER-18BB1",NULL},
/* 18BB2 */ { "KHITAN SMALL SCRIPT CHARACTER-18BB2",NULL},
/* 18BB3 */ { "KHITAN SMALL SCRIPT CHARACTER-18BB3",NULL},
/* 18BB4 */ { "KHITAN SMALL SCRIPT CHARACTER-18BB4",NULL},
/* 18BB5 */ { "KHITAN SMALL SCRIPT CHARACTER-18BB5",NULL},
/* 18BB6 */ { "KHITAN SMALL SCRIPT CHARACTER-18BB6",NULL},
/* 18BB7 */ { "KHITAN SMALL SCRIPT CHARACTER-18BB7",NULL},
/* 18BB8 */ { "KHITAN SMALL SCRIPT CHARACTER-18BB8",NULL},
/* 18BB9 */ { "KHITAN SMALL SCRIPT CHARACTER-18BB9",NULL},
/* 18BBA */ { "KHITAN SMALL SCRIPT CHARACTER-18BBA",NULL},
/* 18BBB */ { "KHITAN SMALL SCRIPT CHARACTER-18BBB",NULL},
/* 18BBC */ { "KHITAN SMALL SCRIPT CHARACTER-18BBC",NULL},
/* 18BBD */ { "KHITAN SMALL SCRIPT CHARACTER-18BBD",NULL},
/* 18BBE */ { "KHITAN SMALL SCRIPT CHARACTER-18BBE",NULL},
/* 18BBF */ { "KHITAN SMALL SCRIPT CHARACTER-18BBF",NULL},
/* 18BC0 */ { "KHITAN SMALL SCRIPT CHARACTER-18BC0",NULL},
/* 18BC1 */ { "KHITAN SMALL SCRIPT CHARACTER-18BC1",NULL},
/* 18BC2 */ { "KHITAN SMALL SCRIPT CHARACTER-18BC2",NULL},
/* 18BC3 */ { "KHITAN SMALL SCRIPT CHARACTER-18BC3",NULL},
/* 18BC4 */ { "KHITAN SMALL SCRIPT CHARACTER-18BC4",NULL},
/* 18BC5 */ { "KHITAN SMALL SCRIPT CHARACTER-18BC5",NULL},
/* 18BC6 */ { "KHITAN SMALL SCRIPT CHARACTER-18BC6",NULL},
/* 18BC7 */ { "KHITAN SMALL SCRIPT CHARACTER-18BC7",NULL},
/* 18BC8 */ { "KHITAN SMALL SCRIPT CHARACTER-18BC8",NULL},
/* 18BC9 */ { "KHITAN SMALL SCRIPT CHARACTER-18BC9",NULL},
/* 18BCA */ { "KHITAN SMALL SCRIPT CHARACTER-18BCA",NULL},
/* 18BCB */ { "KHITAN SMALL SCRIPT CHARACTER-18BCB",NULL},
/* 18BCC */ { "KHITAN SMALL SCRIPT CHARACTER-18BCC",NULL},
/* 18BCD */ { "KHITAN SMALL SCRIPT CHARACTER-18BCD",NULL},
/* 18BCE */ { "KHITAN SMALL SCRIPT CHARACTER-18BCE",NULL},
/* 18BCF */ { "KHITAN SMALL SCRIPT CHARACTER-18BCF",NULL},
/* 18BD0 */ { "KHITAN SMALL SCRIPT CHARACTER-18BD0",NULL},
/* 18BD1 */ { "KHITAN SMALL SCRIPT CHARACTER-18BD1",NULL},
/* 18BD2 */ { "KHITAN SMALL SCRIPT CHARACTER-18BD2",NULL},
/* 18BD3 */ { "KHITAN SMALL SCRIPT CHARACTER-18BD3",NULL},
/* 18BD4 */ { "KHITAN SMALL SCRIPT CHARACTER-18BD4",NULL},
/* 18BD5 */ { "KHITAN SMALL SCRIPT CHARACTER-18BD5",NULL},
/* 18BD6 */ { "KHITAN SMALL SCRIPT CHARACTER-18BD6",NULL},
/* 18BD7 */ { "KHITAN SMALL SCRIPT CHARACTER-18BD7",NULL},
/* 18BD8 */ { "KHITAN SMALL SCRIPT CHARACTER-18BD8",NULL},
/* 18BD9 */ { "KHITAN SMALL SCRIPT CHARACTER-18BD9",NULL},
/* 18BDA */ { "KHITAN SMALL SCRIPT CHARACTER-18BDA",NULL},
/* 18BDB */ { "KHITAN SMALL SCRIPT CHARACTER-18BDB",NULL},
/* 18BDC */ { "KHITAN SMALL SCRIPT CHARACTER-18BDC",NULL},
/* 18BDD */ { "KHITAN SMALL SCRIPT CHARACTER-18BDD",NULL},
/* 18BDE */ { "KHITAN SMALL SCRIPT CHARACTER-18BDE","	x (khitan small script character-18cca - 18CCA)"},
/* 18BDF */ { "KHITAN SMALL SCRIPT CHARACTER-18BDF",NULL},
/* 18BE0 */ { "KHITAN SMALL SCRIPT CHARACTER-18BE0",NULL},
/* 18BE1 */ { "KHITAN SMALL SCRIPT CHARACTER-18BE1",NULL},
/* 18BE2 */ { "KHITAN SMALL SCRIPT CHARACTER-18BE2",NULL},
/* 18BE3 */ { "KHITAN SMALL SCRIPT CHARACTER-18BE3",NULL},
/* 18BE4 */ { "KHITAN SMALL SCRIPT CHARACTER-18BE4",NULL},
/* 18BE5 */ { "KHITAN SMALL SCRIPT CHARACTER-18BE5",NULL},
/* 18BE6 */ { "KHITAN SMALL SCRIPT CHARACTER-18BE6",NULL},
/* 18BE7 */ { "KHITAN SMALL SCRIPT CHARACTER-18BE7",NULL},
/* 18BE8 */ { "KHITAN SMALL SCRIPT CHARACTER-18BE8",NULL},
/* 18BE9 */ { "KHITAN SMALL SCRIPT CHARACTER-18BE9",NULL},
/* 18BEA */ { "KHITAN SMALL SCRIPT CHARACTER-18BEA",NULL},
/* 18BEB */ { "KHITAN SMALL SCRIPT CHARACTER-18BEB",NULL},
/* 18BEC */ { "KHITAN SMALL SCRIPT CHARACTER-18BEC",NULL},
/* 18BED */ { "KHITAN SMALL SCRIPT CHARACTER-18BED",NULL},
/* 18BEE */ { "KHITAN SMALL SCRIPT CHARACTER-18BEE",NULL},
/* 18BEF */ { "KHITAN SMALL SCRIPT CHARACTER-18BEF",NULL},
/* 18BF0 */ { "KHITAN SMALL SCRIPT CHARACTER-18BF0",NULL},
/* 18BF1 */ { "KHITAN SMALL SCRIPT CHARACTER-18BF1",NULL},
/* 18BF2 */ { "KHITAN SMALL SCRIPT CHARACTER-18BF2",NULL},
/* 18BF3 */ { "KHITAN SMALL SCRIPT CHARACTER-18BF3",NULL},
/* 18BF4 */ { "KHITAN SMALL SCRIPT CHARACTER-18BF4",NULL},
/* 18BF5 */ { "KHITAN SMALL SCRIPT CHARACTER-18BF5",NULL},
/* 18BF6 */ { "KHITAN SMALL SCRIPT CHARACTER-18BF6",NULL},
/* 18BF7 */ { "KHITAN SMALL SCRIPT CHARACTER-18BF7",NULL},
/* 18BF8 */ { "KHITAN SMALL SCRIPT CHARACTER-18BF8",NULL},
/* 18BF9 */ { "KHITAN SMALL SCRIPT CHARACTER-18BF9",NULL},
/* 18BFA */ { "KHITAN SMALL SCRIPT CHARACTER-18BFA",NULL},
/* 18BFB */ { "KHITAN SMALL SCRIPT CHARACTER-18BFB",NULL},
/* 18BFC */ { "KHITAN SMALL SCRIPT CHARACTER-18BFC",NULL},
/* 18BFD */ { "KHITAN SMALL SCRIPT CHARACTER-18BFD",NULL},
/* 18BFE */ { "KHITAN SMALL SCRIPT CHARACTER-18BFE",NULL},
/* 18BFF */ { "KHITAN SMALL SCRIPT CHARACTER-18BFF",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_8C[] = {
/* 18C00 */ { "KHITAN SMALL SCRIPT CHARACTER-18C00",NULL},
/* 18C01 */ { "KHITAN SMALL SCRIPT CHARACTER-18C01",NULL},
/* 18C02 */ { "KHITAN SMALL SCRIPT CHARACTER-18C02",NULL},
/* 18C03 */ { "KHITAN SMALL SCRIPT CHARACTER-18C03",NULL},
/* 18C04 */ { "KHITAN SMALL SCRIPT CHARACTER-18C04",NULL},
/* 18C05 */ { "KHITAN SMALL SCRIPT CHARACTER-18C05",NULL},
/* 18C06 */ { "KHITAN SMALL SCRIPT CHARACTER-18C06",NULL},
/* 18C07 */ { "KHITAN SMALL SCRIPT CHARACTER-18C07",NULL},
/* 18C08 */ { "KHITAN SMALL SCRIPT CHARACTER-18C08",NULL},
/* 18C09 */ { "KHITAN SMALL SCRIPT CHARACTER-18C09",NULL},
/* 18C0A */ { "KHITAN SMALL SCRIPT CHARACTER-18C0A",NULL},
/* 18C0B */ { "KHITAN SMALL SCRIPT CHARACTER-18C0B",NULL},
/* 18C0C */ { "KHITAN SMALL SCRIPT CHARACTER-18C0C",NULL},
/* 18C0D */ { "KHITAN SMALL SCRIPT CHARACTER-18C0D",NULL},
/* 18C0E */ { "KHITAN SMALL SCRIPT CHARACTER-18C0E",NULL},
/* 18C0F */ { "KHITAN SMALL SCRIPT CHARACTER-18C0F",NULL},
/* 18C10 */ { "KHITAN SMALL SCRIPT CHARACTER-18C10",NULL},
/* 18C11 */ { "KHITAN SMALL SCRIPT CHARACTER-18C11",NULL},
/* 18C12 */ { "KHITAN SMALL SCRIPT CHARACTER-18C12",NULL},
/* 18C13 */ { "KHITAN SMALL SCRIPT CHARACTER-18C13",NULL},
/* 18C14 */ { "KHITAN SMALL SCRIPT CHARACTER-18C14",NULL},
/* 18C15 */ { "KHITAN SMALL SCRIPT CHARACTER-18C15",NULL},
/* 18C16 */ { "KHITAN SMALL SCRIPT CHARACTER-18C16",NULL},
/* 18C17 */ { "KHITAN SMALL SCRIPT CHARACTER-18C17",NULL},
/* 18C18 */ { "KHITAN SMALL SCRIPT CHARACTER-18C18",NULL},
/* 18C19 */ { "KHITAN SMALL SCRIPT CHARACTER-18C19",NULL},
/* 18C1A */ { "KHITAN SMALL SCRIPT CHARACTER-18C1A",NULL},
/* 18C1B */ { "KHITAN SMALL SCRIPT CHARACTER-18C1B",NULL},
/* 18C1C */ { "KHITAN SMALL SCRIPT CHARACTER-18C1C",NULL},
/* 18C1D */ { "KHITAN SMALL SCRIPT CHARACTER-18C1D",NULL},
/* 18C1E */ { "KHITAN SMALL SCRIPT CHARACTER-18C1E",NULL},
/* 18C1F */ { "KHITAN SMALL SCRIPT CHARACTER-18C1F",NULL},
/* 18C20 */ { "KHITAN SMALL SCRIPT CHARACTER-18C20",NULL},
/* 18C21 */ { "KHITAN SMALL SCRIPT CHARACTER-18C21",NULL},
/* 18C22 */ { "KHITAN SMALL SCRIPT CHARACTER-18C22",NULL},
/* 18C23 */ { "KHITAN SMALL SCRIPT CHARACTER-18C23",NULL},
/* 18C24 */ { "KHITAN SMALL SCRIPT CHARACTER-18C24",NULL},
/* 18C25 */ { "KHITAN SMALL SCRIPT CHARACTER-18C25",NULL},
/* 18C26 */ { "KHITAN SMALL SCRIPT CHARACTER-18C26",NULL},
/* 18C27 */ { "KHITAN SMALL SCRIPT CHARACTER-18C27",NULL},
/* 18C28 */ { "KHITAN SMALL SCRIPT CHARACTER-18C28",NULL},
/* 18C29 */ { "KHITAN SMALL SCRIPT CHARACTER-18C29",NULL},
/* 18C2A */ { "KHITAN SMALL SCRIPT CHARACTER-18C2A",NULL},
/* 18C2B */ { "KHITAN SMALL SCRIPT CHARACTER-18C2B",NULL},
/* 18C2C */ { "KHITAN SMALL SCRIPT CHARACTER-18C2C",NULL},
/* 18C2D */ { "KHITAN SMALL SCRIPT CHARACTER-18C2D",NULL},
/* 18C2E */ { "KHITAN SMALL SCRIPT CHARACTER-18C2E",NULL},
/* 18C2F */ { "KHITAN SMALL SCRIPT CHARACTER-18C2F",NULL},
/* 18C30 */ { "KHITAN SMALL SCRIPT CHARACTER-18C30",NULL},
/* 18C31 */ { "KHITAN SMALL SCRIPT CHARACTER-18C31",NULL},
/* 18C32 */ { "KHITAN SMALL SCRIPT CHARACTER-18C32",NULL},
/* 18C33 */ { "KHITAN SMALL SCRIPT CHARACTER-18C33",NULL},
/* 18C34 */ { "KHITAN SMALL SCRIPT CHARACTER-18C34",NULL},
/* 18C35 */ { "KHITAN SMALL SCRIPT CHARACTER-18C35",NULL},
/* 18C36 */ { "KHITAN SMALL SCRIPT CHARACTER-18C36",NULL},
/* 18C37 */ { "KHITAN SMALL SCRIPT CHARACTER-18C37",NULL},
/* 18C38 */ { "KHITAN SMALL SCRIPT CHARACTER-18C38",NULL},
/* 18C39 */ { "KHITAN SMALL SCRIPT CHARACTER-18C39",NULL},
/* 18C3A */ { "KHITAN SMALL SCRIPT CHARACTER-18C3A",NULL},
/* 18C3B */ { "KHITAN SMALL SCRIPT CHARACTER-18C3B",NULL},
/* 18C3C */ { "KHITAN SMALL SCRIPT CHARACTER-18C3C",NULL},
/* 18C3D */ { "KHITAN SMALL SCRIPT CHARACTER-18C3D",NULL},
/* 18C3E */ { "KHITAN SMALL SCRIPT CHARACTER-18C3E",NULL},
/* 18C3F */ { "KHITAN SMALL SCRIPT CHARACTER-18C3F",NULL},
/* 18C40 */ { "KHITAN SMALL SCRIPT CHARACTER-18C40",NULL},
/* 18C41 */ { "KHITAN SMALL SCRIPT CHARACTER-18C41",NULL},
/* 18C42 */ { "KHITAN SMALL SCRIPT CHARACTER-18C42",NULL},
/* 18C43 */ { "KHITAN SMALL SCRIPT CHARACTER-18C43",NULL},
/* 18C44 */ { "KHITAN SMALL SCRIPT CHARACTER-18C44",NULL},
/* 18C45 */ { "KHITAN SMALL SCRIPT CHARACTER-18C45",NULL},
/* 18C46 */ { "KHITAN SMALL SCRIPT CHARACTER-18C46",NULL},
/* 18C47 */ { "KHITAN SMALL SCRIPT CHARACTER-18C47",NULL},
/* 18C48 */ { "KHITAN SMALL SCRIPT CHARACTER-18C48",NULL},
/* 18C49 */ { "KHITAN SMALL SCRIPT CHARACTER-18C49",NULL},
/* 18C4A */ { "KHITAN SMALL SCRIPT CHARACTER-18C4A",NULL},
/* 18C4B */ { "KHITAN SMALL SCRIPT CHARACTER-18C4B",NULL},
/* 18C4C */ { "KHITAN SMALL SCRIPT CHARACTER-18C4C",NULL},
/* 18C4D */ { "KHITAN SMALL SCRIPT CHARACTER-18C4D",NULL},
/* 18C4E */ { "KHITAN SMALL SCRIPT CHARACTER-18C4E",NULL},
/* 18C4F */ { "KHITAN SMALL SCRIPT CHARACTER-18C4F",NULL},
/* 18C50 */ { "KHITAN SMALL SCRIPT CHARACTER-18C50",NULL},
/* 18C51 */ { "KHITAN SMALL SCRIPT CHARACTER-18C51",NULL},
/* 18C52 */ { "KHITAN SMALL SCRIPT CHARACTER-18C52",NULL},
/* 18C53 */ { "KHITAN SMALL SCRIPT CHARACTER-18C53",NULL},
/* 18C54 */ { "KHITAN SMALL SCRIPT CHARACTER-18C54",NULL},
/* 18C55 */ { "KHITAN SMALL SCRIPT CHARACTER-18C55",NULL},
/* 18C56 */ { "KHITAN SMALL SCRIPT CHARACTER-18C56",NULL},
/* 18C57 */ { "KHITAN SMALL SCRIPT CHARACTER-18C57",NULL},
/* 18C58 */ { "KHITAN SMALL SCRIPT CHARACTER-18C58",NULL},
/* 18C59 */ { "KHITAN SMALL SCRIPT CHARACTER-18C59",NULL},
/* 18C5A */ { "KHITAN SMALL SCRIPT CHARACTER-18C5A",NULL},
/* 18C5B */ { "KHITAN SMALL SCRIPT CHARACTER-18C5B",NULL},
/* 18C5C */ { "KHITAN SMALL SCRIPT CHARACTER-18C5C",NULL},
/* 18C5D */ { "KHITAN SMALL SCRIPT CHARACTER-18C5D",NULL},
/* 18C5E */ { "KHITAN SMALL SCRIPT CHARACTER-18C5E",NULL},
/* 18C5F */ { "KHITAN SMALL SCRIPT CHARACTER-18C5F",NULL},
/* 18C60 */ { "KHITAN SMALL SCRIPT CHARACTER-18C60",NULL},
/* 18C61 */ { "KHITAN SMALL SCRIPT CHARACTER-18C61",NULL},
/* 18C62 */ { "KHITAN SMALL SCRIPT CHARACTER-18C62",NULL},
/* 18C63 */ { "KHITAN SMALL SCRIPT CHARACTER-18C63",NULL},
/* 18C64 */ { "KHITAN SMALL SCRIPT CHARACTER-18C64",NULL},
/* 18C65 */ { "KHITAN SMALL SCRIPT CHARACTER-18C65",NULL},
/* 18C66 */ { "KHITAN SMALL SCRIPT CHARACTER-18C66",NULL},
/* 18C67 */ { "KHITAN SMALL SCRIPT CHARACTER-18C67",NULL},
/* 18C68 */ { "KHITAN SMALL SCRIPT CHARACTER-18C68",NULL},
/* 18C69 */ { "KHITAN SMALL SCRIPT CHARACTER-18C69",NULL},
/* 18C6A */ { "KHITAN SMALL SCRIPT CHARACTER-18C6A",NULL},
/* 18C6B */ { "KHITAN SMALL SCRIPT CHARACTER-18C6B",NULL},
/* 18C6C */ { "KHITAN SMALL SCRIPT CHARACTER-18C6C",NULL},
/* 18C6D */ { "KHITAN SMALL SCRIPT CHARACTER-18C6D",NULL},
/* 18C6E */ { "KHITAN SMALL SCRIPT CHARACTER-18C6E",NULL},
/* 18C6F */ { "KHITAN SMALL SCRIPT CHARACTER-18C6F",NULL},
/* 18C70 */ { "KHITAN SMALL SCRIPT CHARACTER-18C70",NULL},
/* 18C71 */ { "KHITAN SMALL SCRIPT CHARACTER-18C71",NULL},
/* 18C72 */ { "KHITAN SMALL SCRIPT CHARACTER-18C72",NULL},
/* 18C73 */ { "KHITAN SMALL SCRIPT CHARACTER-18C73",NULL},
/* 18C74 */ { "KHITAN SMALL SCRIPT CHARACTER-18C74",NULL},
/* 18C75 */ { "KHITAN SMALL SCRIPT CHARACTER-18C75",NULL},
/* 18C76 */ { "KHITAN SMALL SCRIPT CHARACTER-18C76",NULL},
/* 18C77 */ { "KHITAN SMALL SCRIPT CHARACTER-18C77",NULL},
/* 18C78 */ { "KHITAN SMALL SCRIPT CHARACTER-18C78",NULL},
/* 18C79 */ { "KHITAN SMALL SCRIPT CHARACTER-18C79",NULL},
/* 18C7A */ { "KHITAN SMALL SCRIPT CHARACTER-18C7A",NULL},
/* 18C7B */ { "KHITAN SMALL SCRIPT CHARACTER-18C7B",NULL},
/* 18C7C */ { "KHITAN SMALL SCRIPT CHARACTER-18C7C",NULL},
/* 18C7D */ { "KHITAN SMALL SCRIPT CHARACTER-18C7D",NULL},
/* 18C7E */ { "KHITAN SMALL SCRIPT CHARACTER-18C7E",NULL},
/* 18C7F */ { "KHITAN SMALL SCRIPT CHARACTER-18C7F",NULL},
/* 18C80 */ { "KHITAN SMALL SCRIPT CHARACTER-18C80",NULL},
/* 18C81 */ { "KHITAN SMALL SCRIPT CHARACTER-18C81",NULL},
/* 18C82 */ { "KHITAN SMALL SCRIPT CHARACTER-18C82",NULL},
/* 18C83 */ { "KHITAN SMALL SCRIPT CHARACTER-18C83",NULL},
/* 18C84 */ { "KHITAN SMALL SCRIPT CHARACTER-18C84",NULL},
/* 18C85 */ { "KHITAN SMALL SCRIPT CHARACTER-18C85",NULL},
/* 18C86 */ { "KHITAN SMALL SCRIPT CHARACTER-18C86",NULL},
/* 18C87 */ { "KHITAN SMALL SCRIPT CHARACTER-18C87",NULL},
/* 18C88 */ { "KHITAN SMALL SCRIPT CHARACTER-18C88",NULL},
/* 18C89 */ { "KHITAN SMALL SCRIPT CHARACTER-18C89",NULL},
/* 18C8A */ { "KHITAN SMALL SCRIPT CHARACTER-18C8A",NULL},
/* 18C8B */ { "KHITAN SMALL SCRIPT CHARACTER-18C8B",NULL},
/* 18C8C */ { "KHITAN SMALL SCRIPT CHARACTER-18C8C",NULL},
/* 18C8D */ { "KHITAN SMALL SCRIPT CHARACTER-18C8D",NULL},
/* 18C8E */ { "KHITAN SMALL SCRIPT CHARACTER-18C8E",NULL},
/* 18C8F */ { "KHITAN SMALL SCRIPT CHARACTER-18C8F",NULL},
/* 18C90 */ { "KHITAN SMALL SCRIPT CHARACTER-18C90",NULL},
/* 18C91 */ { "KHITAN SMALL SCRIPT CHARACTER-18C91",NULL},
/* 18C92 */ { "KHITAN SMALL SCRIPT CHARACTER-18C92",NULL},
/* 18C93 */ { "KHITAN SMALL SCRIPT CHARACTER-18C93",NULL},
/* 18C94 */ { "KHITAN SMALL SCRIPT CHARACTER-18C94",NULL},
/* 18C95 */ { "KHITAN SMALL SCRIPT CHARACTER-18C95",NULL},
/* 18C96 */ { "KHITAN SMALL SCRIPT CHARACTER-18C96",NULL},
/* 18C97 */ { "KHITAN SMALL SCRIPT CHARACTER-18C97",NULL},
/* 18C98 */ { "KHITAN SMALL SCRIPT CHARACTER-18C98",NULL},
/* 18C99 */ { "KHITAN SMALL SCRIPT CHARACTER-18C99",NULL},
/* 18C9A */ { "KHITAN SMALL SCRIPT CHARACTER-18C9A",NULL},
/* 18C9B */ { "KHITAN SMALL SCRIPT CHARACTER-18C9B",NULL},
/* 18C9C */ { "KHITAN SMALL SCRIPT CHARACTER-18C9C",NULL},
/* 18C9D */ { "KHITAN SMALL SCRIPT CHARACTER-18C9D",NULL},
/* 18C9E */ { "KHITAN SMALL SCRIPT CHARACTER-18C9E",NULL},
/* 18C9F */ { "KHITAN SMALL SCRIPT CHARACTER-18C9F",NULL},
/* 18CA0 */ { "KHITAN SMALL SCRIPT CHARACTER-18CA0",NULL},
/* 18CA1 */ { "KHITAN SMALL SCRIPT CHARACTER-18CA1",NULL},
/* 18CA2 */ { "KHITAN SMALL SCRIPT CHARACTER-18CA2",NULL},
/* 18CA3 */ { "KHITAN SMALL SCRIPT CHARACTER-18CA3",NULL},
/* 18CA4 */ { "KHITAN SMALL SCRIPT CHARACTER-18CA4",NULL},
/* 18CA5 */ { "KHITAN SMALL SCRIPT CHARACTER-18CA5",NULL},
/* 18CA6 */ { "KHITAN SMALL SCRIPT CHARACTER-18CA6",NULL},
/* 18CA7 */ { "KHITAN SMALL SCRIPT CHARACTER-18CA7",NULL},
/* 18CA8 */ { "KHITAN SMALL SCRIPT CHARACTER-18CA8",NULL},
/* 18CA9 */ { "KHITAN SMALL SCRIPT CHARACTER-18CA9",NULL},
/* 18CAA */ { "KHITAN SMALL SCRIPT CHARACTER-18CAA",NULL},
/* 18CAB */ { "KHITAN SMALL SCRIPT CHARACTER-18CAB",NULL},
/* 18CAC */ { "KHITAN SMALL SCRIPT CHARACTER-18CAC",NULL},
/* 18CAD */ { "KHITAN SMALL SCRIPT CHARACTER-18CAD",NULL},
/* 18CAE */ { "KHITAN SMALL SCRIPT CHARACTER-18CAE",NULL},
/* 18CAF */ { "KHITAN SMALL SCRIPT CHARACTER-18CAF",NULL},
/* 18CB0 */ { "KHITAN SMALL SCRIPT CHARACTER-18CB0",NULL},
/* 18CB1 */ { "KHITAN SMALL SCRIPT CHARACTER-18CB1",NULL},
/* 18CB2 */ { "KHITAN SMALL SCRIPT CHARACTER-18CB2",NULL},
/* 18CB3 */ { "KHITAN SMALL SCRIPT CHARACTER-18CB3",NULL},
/* 18CB4 */ { "KHITAN SMALL SCRIPT CHARACTER-18CB4",NULL},
/* 18CB5 */ { "KHITAN SMALL SCRIPT CHARACTER-18CB5",NULL},
/* 18CB6 */ { "KHITAN SMALL SCRIPT CHARACTER-18CB6",NULL},
/* 18CB7 */ { "KHITAN SMALL SCRIPT CHARACTER-18CB7",NULL},
/* 18CB8 */ { "KHITAN SMALL SCRIPT CHARACTER-18CB8",NULL},
/* 18CB9 */ { "KHITAN SMALL SCRIPT CHARACTER-18CB9",NULL},
/* 18CBA */ { "KHITAN SMALL SCRIPT CHARACTER-18CBA",NULL},
/* 18CBB */ { "KHITAN SMALL SCRIPT CHARACTER-18CBB",NULL},
/* 18CBC */ { "KHITAN SMALL SCRIPT CHARACTER-18CBC",NULL},
/* 18CBD */ { "KHITAN SMALL SCRIPT CHARACTER-18CBD",NULL},
/* 18CBE */ { "KHITAN SMALL SCRIPT CHARACTER-18CBE",NULL},
/* 18CBF */ { "KHITAN SMALL SCRIPT CHARACTER-18CBF",NULL},
/* 18CC0 */ { "KHITAN SMALL SCRIPT CHARACTER-18CC0",NULL},
/* 18CC1 */ { "KHITAN SMALL SCRIPT CHARACTER-18CC1",NULL},
/* 18CC2 */ { "KHITAN SMALL SCRIPT CHARACTER-18CC2",NULL},
/* 18CC3 */ { "KHITAN SMALL SCRIPT CHARACTER-18CC3",NULL},
/* 18CC4 */ { "KHITAN SMALL SCRIPT CHARACTER-18CC4",NULL},
/* 18CC5 */ { "KHITAN SMALL SCRIPT CHARACTER-18CC5",NULL},
/* 18CC6 */ { "KHITAN SMALL SCRIPT CHARACTER-18CC6",NULL},
/* 18CC7 */ { "KHITAN SMALL SCRIPT CHARACTER-18CC7",NULL},
/* 18CC8 */ { "KHITAN SMALL SCRIPT CHARACTER-18CC8",NULL},
/* 18CC9 */ { "KHITAN SMALL SCRIPT CHARACTER-18CC9",NULL},
/* 18CCA */ { "KHITAN SMALL SCRIPT CHARACTER-18CCA","	x (khitan small script character-18bde - 18BDE)"},
/* 18CCB */ { "KHITAN SMALL SCRIPT CHARACTER-18CCB",NULL},
/* 18CCC */ { "KHITAN SMALL SCRIPT CHARACTER-18CCC",NULL},
/* 18CCD */ { "KHITAN SMALL SCRIPT CHARACTER-18CCD",NULL},
/* 18CCE */ { "KHITAN SMALL SCRIPT CHARACTER-18CCE",NULL},
/* 18CCF */ { "KHITAN SMALL SCRIPT CHARACTER-18CCF",NULL},
/* 18CD0 */ { "KHITAN SMALL SCRIPT CHARACTER-18CD0",NULL},
/* 18CD1 */ { "KHITAN SMALL SCRIPT CHARACTER-18CD1",NULL},
/* 18CD2 */ { "KHITAN SMALL SCRIPT CHARACTER-18CD2",NULL},
/* 18CD3 */ { "KHITAN SMALL SCRIPT CHARACTER-18CD3",NULL},
/* 18CD4 */ { "KHITAN SMALL SCRIPT CHARACTER-18CD4",NULL},
/* 18CD5 */ { "KHITAN SMALL SCRIPT CHARACTER-18CD5",NULL},
/* 18CD6 */ { NULL,NULL},
/* 18CD7 */ { NULL,NULL},
/* 18CD8 */ { NULL,NULL},
/* 18CD9 */ { NULL,NULL},
/* 18CDA */ { NULL,NULL},
/* 18CDB */ { NULL,NULL},
/* 18CDC */ { NULL,NULL},
/* 18CDD */ { NULL,NULL},
/* 18CDE */ { NULL,NULL},
/* 18CDF */ { NULL,NULL},
/* 18CE0 */ { NULL,NULL},
/* 18CE1 */ { NULL,NULL},
/* 18CE2 */ { NULL,NULL},
/* 18CE3 */ { NULL,NULL},
/* 18CE4 */ { NULL,NULL},
/* 18CE5 */ { NULL,NULL},
/* 18CE6 */ { NULL,NULL},
/* 18CE7 */ { NULL,NULL},
/* 18CE8 */ { NULL,NULL},
/* 18CE9 */ { NULL,NULL},
/* 18CEA */ { NULL,NULL},
/* 18CEB */ { NULL,NULL},
/* 18CEC */ { NULL,NULL},
/* 18CED */ { NULL,NULL},
/* 18CEE */ { NULL,NULL},
/* 18CEF */ { NULL,NULL},
/* 18CF0 */ { NULL,NULL},
/* 18CF1 */ { NULL,NULL},
/* 18CF2 */ { NULL,NULL},
/* 18CF3 */ { NULL,NULL},
/* 18CF4 */ { NULL,NULL},
/* 18CF5 */ { NULL,NULL},
/* 18CF6 */ { NULL,NULL},
/* 18CF7 */ { NULL,NULL},
/* 18CF8 */ { NULL,NULL},
/* 18CF9 */ { NULL,NULL},
/* 18CFA */ { NULL,NULL},
/* 18CFB */ { NULL,NULL},
/* 18CFC */ { NULL,NULL},
/* 18CFD */ { NULL,NULL},
/* 18CFE */ { NULL,NULL},
/* 18CFF */ { "KHITAN SMALL SCRIPT CHARACTER-18CFF","	* represents a lost or illegible character"}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_8D[] = {
/* 18D00 */ { NULL,NULL},
/* 18D01 */ { NULL,NULL},
/* 18D02 */ { NULL,NULL},
/* 18D03 */ { NULL,NULL},
/* 18D04 */ { NULL,NULL},
/* 18D05 */ { NULL,NULL},
/* 18D06 */ { NULL,NULL},
/* 18D07 */ { NULL,NULL},
/* 18D08 */ { NULL,NULL},
/* 18D09 */ { NULL,NULL},
/* 18D0A */ { NULL,NULL},
/* 18D0B */ { NULL,NULL},
/* 18D0C */ { NULL,NULL},
/* 18D0D */ { NULL,NULL},
/* 18D0E */ { NULL,NULL},
/* 18D0F */ { NULL,NULL},
/* 18D10 */ { NULL,NULL},
/* 18D11 */ { NULL,NULL},
/* 18D12 */ { NULL,NULL},
/* 18D13 */ { NULL,NULL},
/* 18D14 */ { NULL,NULL},
/* 18D15 */ { NULL,NULL},
/* 18D16 */ { NULL,NULL},
/* 18D17 */ { NULL,NULL},
/* 18D18 */ { NULL,NULL},
/* 18D19 */ { NULL,NULL},
/* 18D1A */ { NULL,NULL},
/* 18D1B */ { NULL,NULL},
/* 18D1C */ { NULL,NULL},
/* 18D1D */ { NULL,NULL},
/* 18D1E */ { NULL,NULL},
/* 18D1F */ { NULL,NULL},
/* 18D20 */ { NULL,NULL},
/* 18D21 */ { NULL,NULL},
/* 18D22 */ { NULL,NULL},
/* 18D23 */ { NULL,NULL},
/* 18D24 */ { NULL,NULL},
/* 18D25 */ { NULL,NULL},
/* 18D26 */ { NULL,NULL},
/* 18D27 */ { NULL,NULL},
/* 18D28 */ { NULL,NULL},
/* 18D29 */ { NULL,NULL},
/* 18D2A */ { NULL,NULL},
/* 18D2B */ { NULL,NULL},
/* 18D2C */ { NULL,NULL},
/* 18D2D */ { NULL,NULL},
/* 18D2E */ { NULL,NULL},
/* 18D2F */ { NULL,NULL},
/* 18D30 */ { NULL,NULL},
/* 18D31 */ { NULL,NULL},
/* 18D32 */ { NULL,NULL},
/* 18D33 */ { NULL,NULL},
/* 18D34 */ { NULL,NULL},
/* 18D35 */ { NULL,NULL},
/* 18D36 */ { NULL,NULL},
/* 18D37 */ { NULL,NULL},
/* 18D38 */ { NULL,NULL},
/* 18D39 */ { NULL,NULL},
/* 18D3A */ { NULL,NULL},
/* 18D3B */ { NULL,NULL},
/* 18D3C */ { NULL,NULL},
/* 18D3D */ { NULL,NULL},
/* 18D3E */ { NULL,NULL},
/* 18D3F */ { NULL,NULL},
/* 18D40 */ { NULL,NULL},
/* 18D41 */ { NULL,NULL},
/* 18D42 */ { NULL,NULL},
/* 18D43 */ { NULL,NULL},
/* 18D44 */ { NULL,NULL},
/* 18D45 */ { NULL,NULL},
/* 18D46 */ { NULL,NULL},
/* 18D47 */ { NULL,NULL},
/* 18D48 */ { NULL,NULL},
/* 18D49 */ { NULL,NULL},
/* 18D4A */ { NULL,NULL},
/* 18D4B */ { NULL,NULL},
/* 18D4C */ { NULL,NULL},
/* 18D4D */ { NULL,NULL},
/* 18D4E */ { NULL,NULL},
/* 18D4F */ { NULL,NULL},
/* 18D50 */ { NULL,NULL},
/* 18D51 */ { NULL,NULL},
/* 18D52 */ { NULL,NULL},
/* 18D53 */ { NULL,NULL},
/* 18D54 */ { NULL,NULL},
/* 18D55 */ { NULL,NULL},
/* 18D56 */ { NULL,NULL},
/* 18D57 */ { NULL,NULL},
/* 18D58 */ { NULL,NULL},
/* 18D59 */ { NULL,NULL},
/* 18D5A */ { NULL,NULL},
/* 18D5B */ { NULL,NULL},
/* 18D5C */ { NULL,NULL},
/* 18D5D */ { NULL,NULL},
/* 18D5E */ { NULL,NULL},
/* 18D5F */ { NULL,NULL},
/* 18D60 */ { NULL,NULL},
/* 18D61 */ { NULL,NULL},
/* 18D62 */ { NULL,NULL},
/* 18D63 */ { NULL,NULL},
/* 18D64 */ { NULL,NULL},
/* 18D65 */ { NULL,NULL},
/* 18D66 */ { NULL,NULL},
/* 18D67 */ { NULL,NULL},
/* 18D68 */ { NULL,NULL},
/* 18D69 */ { NULL,NULL},
/* 18D6A */ { NULL,NULL},
/* 18D6B */ { NULL,NULL},
/* 18D6C */ { NULL,NULL},
/* 18D6D */ { NULL,NULL},
/* 18D6E */ { NULL,NULL},
/* 18D6F */ { NULL,NULL},
/* 18D70 */ { NULL,NULL},
/* 18D71 */ { NULL,NULL},
/* 18D72 */ { NULL,NULL},
/* 18D73 */ { NULL,NULL},
/* 18D74 */ { NULL,NULL},
/* 18D75 */ { NULL,NULL},
/* 18D76 */ { NULL,NULL},
/* 18D77 */ { NULL,NULL},
/* 18D78 */ { NULL,NULL},
/* 18D79 */ { NULL,NULL},
/* 18D7A */ { NULL,NULL},
/* 18D7B */ { NULL,NULL},
/* 18D7C */ { NULL,NULL},
/* 18D7D */ { NULL,NULL},
/* 18D7E */ { NULL,NULL},
/* 18D7F */ { NULL,NULL},
/* 18D80 */ { "TANGUT COMPONENT-769","	* seven strokes"},
/* 18D81 */ { "TANGUT COMPONENT-770","	* three strokes"},
/* 18D82 */ { "TANGUT COMPONENT-771",NULL},
/* 18D83 */ { "TANGUT COMPONENT-772",NULL},
/* 18D84 */ { "TANGUT COMPONENT-773",NULL},
/* 18D85 */ { "TANGUT COMPONENT-774",NULL},
/* 18D86 */ { "TANGUT COMPONENT-775",NULL},
/* 18D87 */ { "TANGUT COMPONENT-776",NULL},
/* 18D88 */ { "TANGUT COMPONENT-777",NULL},
/* 18D89 */ { "TANGUT COMPONENT-778",NULL},
/* 18D8A */ { "TANGUT COMPONENT-779",NULL},
/* 18D8B */ { "TANGUT COMPONENT-780",NULL},
/* 18D8C */ { "TANGUT COMPONENT-781",NULL},
/* 18D8D */ { "TANGUT COMPONENT-782",NULL},
/* 18D8E */ { "TANGUT COMPONENT-783",NULL},
/* 18D8F */ { "TANGUT COMPONENT-784",NULL},
/* 18D90 */ { "TANGUT COMPONENT-785",NULL},
/* 18D91 */ { "TANGUT COMPONENT-786",NULL},
/* 18D92 */ { "TANGUT COMPONENT-787",NULL},
/* 18D93 */ { "TANGUT COMPONENT-788",NULL},
/* 18D94 */ { "TANGUT COMPONENT-789",NULL},
/* 18D95 */ { "TANGUT COMPONENT-790",NULL},
/* 18D96 */ { "TANGUT COMPONENT-791",NULL},
/* 18D97 */ { "TANGUT COMPONENT-792",NULL},
/* 18D98 */ { "TANGUT COMPONENT-793",NULL},
/* 18D99 */ { "TANGUT COMPONENT-794",NULL},
/* 18D9A */ { "TANGUT COMPONENT-795",NULL},
/* 18D9B */ { "TANGUT COMPONENT-796",NULL},
/* 18D9C */ { "TANGUT COMPONENT-797",NULL},
/* 18D9D */ { "TANGUT COMPONENT-798",NULL},
/* 18D9E */ { "TANGUT COMPONENT-799",NULL},
/* 18D9F */ { "TANGUT COMPONENT-800",NULL},
/* 18DA0 */ { "TANGUT COMPONENT-801",NULL},
/* 18DA1 */ { "TANGUT COMPONENT-802",NULL},
/* 18DA2 */ { "TANGUT COMPONENT-803",NULL},
/* 18DA3 */ { "TANGUT COMPONENT-804",NULL},
/* 18DA4 */ { "TANGUT COMPONENT-805",NULL},
/* 18DA5 */ { "TANGUT COMPONENT-806",NULL},
/* 18DA6 */ { "TANGUT COMPONENT-807",NULL},
/* 18DA7 */ { "TANGUT COMPONENT-808",NULL},
/* 18DA8 */ { "TANGUT COMPONENT-809",NULL},
/* 18DA9 */ { "TANGUT COMPONENT-810",NULL},
/* 18DAA */ { "TANGUT COMPONENT-811",NULL},
/* 18DAB */ { "TANGUT COMPONENT-812",NULL},
/* 18DAC */ { "TANGUT COMPONENT-813",NULL},
/* 18DAD */ { "TANGUT COMPONENT-814",NULL},
/* 18DAE */ { "TANGUT COMPONENT-815",NULL},
/* 18DAF */ { "TANGUT COMPONENT-816",NULL},
/* 18DB0 */ { "TANGUT COMPONENT-817",NULL},
/* 18DB1 */ { "TANGUT COMPONENT-818",NULL},
/* 18DB2 */ { "TANGUT COMPONENT-819",NULL},
/* 18DB3 */ { "TANGUT COMPONENT-820",NULL},
/* 18DB4 */ { "TANGUT COMPONENT-821",NULL},
/* 18DB5 */ { "TANGUT COMPONENT-822",NULL},
/* 18DB6 */ { "TANGUT COMPONENT-823",NULL},
/* 18DB7 */ { "TANGUT COMPONENT-824",NULL},
/* 18DB8 */ { "TANGUT COMPONENT-825",NULL},
/* 18DB9 */ { "TANGUT COMPONENT-826",NULL},
/* 18DBA */ { "TANGUT COMPONENT-827",NULL},
/* 18DBB */ { "TANGUT COMPONENT-828",NULL},
/* 18DBC */ { "TANGUT COMPONENT-829",NULL},
/* 18DBD */ { "TANGUT COMPONENT-830",NULL},
/* 18DBE */ { "TANGUT COMPONENT-831",NULL},
/* 18DBF */ { "TANGUT COMPONENT-832",NULL},
/* 18DC0 */ { "TANGUT COMPONENT-833",NULL},
/* 18DC1 */ { "TANGUT COMPONENT-834",NULL},
/* 18DC2 */ { "TANGUT COMPONENT-835",NULL},
/* 18DC3 */ { "TANGUT COMPONENT-836",NULL},
/* 18DC4 */ { "TANGUT COMPONENT-837",NULL},
/* 18DC5 */ { "TANGUT COMPONENT-838",NULL},
/* 18DC6 */ { "TANGUT COMPONENT-839",NULL},
/* 18DC7 */ { "TANGUT COMPONENT-840",NULL},
/* 18DC8 */ { "TANGUT COMPONENT-841",NULL},
/* 18DC9 */ { "TANGUT COMPONENT-842",NULL},
/* 18DCA */ { "TANGUT COMPONENT-843",NULL},
/* 18DCB */ { "TANGUT COMPONENT-844",NULL},
/* 18DCC */ { "TANGUT COMPONENT-845",NULL},
/* 18DCD */ { "TANGUT COMPONENT-846",NULL},
/* 18DCE */ { "TANGUT COMPONENT-847",NULL},
/* 18DCF */ { "TANGUT COMPONENT-848",NULL},
/* 18DD0 */ { "TANGUT COMPONENT-849",NULL},
/* 18DD1 */ { "TANGUT COMPONENT-850",NULL},
/* 18DD2 */ { "TANGUT COMPONENT-851",NULL},
/* 18DD3 */ { "TANGUT COMPONENT-852",NULL},
/* 18DD4 */ { "TANGUT COMPONENT-853",NULL},
/* 18DD5 */ { "TANGUT COMPONENT-854",NULL},
/* 18DD6 */ { "TANGUT COMPONENT-855",NULL},
/* 18DD7 */ { "TANGUT COMPONENT-856",NULL},
/* 18DD8 */ { "TANGUT COMPONENT-857",NULL},
/* 18DD9 */ { "TANGUT COMPONENT-858",NULL},
/* 18DDA */ { "TANGUT COMPONENT-859",NULL},
/* 18DDB */ { "TANGUT COMPONENT-860",NULL},
/* 18DDC */ { "TANGUT COMPONENT-861",NULL},
/* 18DDD */ { "TANGUT COMPONENT-862",NULL},
/* 18DDE */ { "TANGUT COMPONENT-863",NULL},
/* 18DDF */ { "TANGUT COMPONENT-864",NULL},
/* 18DE0 */ { "TANGUT COMPONENT-865",NULL},
/* 18DE1 */ { "TANGUT COMPONENT-866",NULL},
/* 18DE2 */ { "TANGUT COMPONENT-867",NULL},
/* 18DE3 */ { "TANGUT COMPONENT-868",NULL},
/* 18DE4 */ { "TANGUT COMPONENT-869",NULL},
/* 18DE5 */ { "TANGUT COMPONENT-870",NULL},
/* 18DE6 */ { "TANGUT COMPONENT-871",NULL},
/* 18DE7 */ { "TANGUT COMPONENT-872",NULL},
/* 18DE8 */ { "TANGUT COMPONENT-873",NULL},
/* 18DE9 */ { "TANGUT COMPONENT-874",NULL},
/* 18DEA */ { "TANGUT COMPONENT-875",NULL},
/* 18DEB */ { "TANGUT COMPONENT-876",NULL},
/* 18DEC */ { "TANGUT COMPONENT-877",NULL},
/* 18DED */ { "TANGUT COMPONENT-878",NULL},
/* 18DEE */ { "TANGUT COMPONENT-879",NULL},
/* 18DEF */ { "TANGUT COMPONENT-880",NULL},
/* 18DF0 */ { "TANGUT COMPONENT-881",NULL},
/* 18DF1 */ { "TANGUT COMPONENT-882",NULL},
/* 18DF2 */ { "TANGUT COMPONENT-883",NULL},
/* 18DF3 */ { NULL,NULL},
/* 18DF4 */ { NULL,NULL},
/* 18DF5 */ { NULL,NULL},
/* 18DF6 */ { NULL,NULL},
/* 18DF7 */ { NULL,NULL},
/* 18DF8 */ { NULL,NULL},
/* 18DF9 */ { NULL,NULL},
/* 18DFA */ { NULL,NULL},
/* 18DFB */ { NULL,NULL},
/* 18DFC */ { NULL,NULL},
/* 18DFD */ { NULL,NULL},
/* 18DFE */ { NULL,NULL},
/* 18DFF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_AF[] = {
/* 1AF00 */ { NULL,NULL},
/* 1AF01 */ { NULL,NULL},
/* 1AF02 */ { NULL,NULL},
/* 1AF03 */ { NULL,NULL},
/* 1AF04 */ { NULL,NULL},
/* 1AF05 */ { NULL,NULL},
/* 1AF06 */ { NULL,NULL},
/* 1AF07 */ { NULL,NULL},
/* 1AF08 */ { NULL,NULL},
/* 1AF09 */ { NULL,NULL},
/* 1AF0A */ { NULL,NULL},
/* 1AF0B */ { NULL,NULL},
/* 1AF0C */ { NULL,NULL},
/* 1AF0D */ { NULL,NULL},
/* 1AF0E */ { NULL,NULL},
/* 1AF0F */ { NULL,NULL},
/* 1AF10 */ { NULL,NULL},
/* 1AF11 */ { NULL,NULL},
/* 1AF12 */ { NULL,NULL},
/* 1AF13 */ { NULL,NULL},
/* 1AF14 */ { NULL,NULL},
/* 1AF15 */ { NULL,NULL},
/* 1AF16 */ { NULL,NULL},
/* 1AF17 */ { NULL,NULL},
/* 1AF18 */ { NULL,NULL},
/* 1AF19 */ { NULL,NULL},
/* 1AF1A */ { NULL,NULL},
/* 1AF1B */ { NULL,NULL},
/* 1AF1C */ { NULL,NULL},
/* 1AF1D */ { NULL,NULL},
/* 1AF1E */ { NULL,NULL},
/* 1AF1F */ { NULL,NULL},
/* 1AF20 */ { NULL,NULL},
/* 1AF21 */ { NULL,NULL},
/* 1AF22 */ { NULL,NULL},
/* 1AF23 */ { NULL,NULL},
/* 1AF24 */ { NULL,NULL},
/* 1AF25 */ { NULL,NULL},
/* 1AF26 */ { NULL,NULL},
/* 1AF27 */ { NULL,NULL},
/* 1AF28 */ { NULL,NULL},
/* 1AF29 */ { NULL,NULL},
/* 1AF2A */ { NULL,NULL},
/* 1AF2B */ { NULL,NULL},
/* 1AF2C */ { NULL,NULL},
/* 1AF2D */ { NULL,NULL},
/* 1AF2E */ { NULL,NULL},
/* 1AF2F */ { NULL,NULL},
/* 1AF30 */ { NULL,NULL},
/* 1AF31 */ { NULL,NULL},
/* 1AF32 */ { NULL,NULL},
/* 1AF33 */ { NULL,NULL},
/* 1AF34 */ { NULL,NULL},
/* 1AF35 */ { NULL,NULL},
/* 1AF36 */ { NULL,NULL},
/* 1AF37 */ { NULL,NULL},
/* 1AF38 */ { NULL,NULL},
/* 1AF39 */ { NULL,NULL},
/* 1AF3A */ { NULL,NULL},
/* 1AF3B */ { NULL,NULL},
/* 1AF3C */ { NULL,NULL},
/* 1AF3D */ { NULL,NULL},
/* 1AF3E */ { NULL,NULL},
/* 1AF3F */ { NULL,NULL},
/* 1AF40 */ { NULL,NULL},
/* 1AF41 */ { NULL,NULL},
/* 1AF42 */ { NULL,NULL},
/* 1AF43 */ { NULL,NULL},
/* 1AF44 */ { NULL,NULL},
/* 1AF45 */ { NULL,NULL},
/* 1AF46 */ { NULL,NULL},
/* 1AF47 */ { NULL,NULL},
/* 1AF48 */ { NULL,NULL},
/* 1AF49 */ { NULL,NULL},
/* 1AF4A */ { NULL,NULL},
/* 1AF4B */ { NULL,NULL},
/* 1AF4C */ { NULL,NULL},
/* 1AF4D */ { NULL,NULL},
/* 1AF4E */ { NULL,NULL},
/* 1AF4F */ { NULL,NULL},
/* 1AF50 */ { NULL,NULL},
/* 1AF51 */ { NULL,NULL},
/* 1AF52 */ { NULL,NULL},
/* 1AF53 */ { NULL,NULL},
/* 1AF54 */ { NULL,NULL},
/* 1AF55 */ { NULL,NULL},
/* 1AF56 */ { NULL,NULL},
/* 1AF57 */ { NULL,NULL},
/* 1AF58 */ { NULL,NULL},
/* 1AF59 */ { NULL,NULL},
/* 1AF5A */ { NULL,NULL},
/* 1AF5B */ { NULL,NULL},
/* 1AF5C */ { NULL,NULL},
/* 1AF5D */ { NULL,NULL},
/* 1AF5E */ { NULL,NULL},
/* 1AF5F */ { NULL,NULL},
/* 1AF60 */ { NULL,NULL},
/* 1AF61 */ { NULL,NULL},
/* 1AF62 */ { NULL,NULL},
/* 1AF63 */ { NULL,NULL},
/* 1AF64 */ { NULL,NULL},
/* 1AF65 */ { NULL,NULL},
/* 1AF66 */ { NULL,NULL},
/* 1AF67 */ { NULL,NULL},
/* 1AF68 */ { NULL,NULL},
/* 1AF69 */ { NULL,NULL},
/* 1AF6A */ { NULL,NULL},
/* 1AF6B */ { NULL,NULL},
/* 1AF6C */ { NULL,NULL},
/* 1AF6D */ { NULL,NULL},
/* 1AF6E */ { NULL,NULL},
/* 1AF6F */ { NULL,NULL},
/* 1AF70 */ { NULL,NULL},
/* 1AF71 */ { NULL,NULL},
/* 1AF72 */ { NULL,NULL},
/* 1AF73 */ { NULL,NULL},
/* 1AF74 */ { NULL,NULL},
/* 1AF75 */ { NULL,NULL},
/* 1AF76 */ { NULL,NULL},
/* 1AF77 */ { NULL,NULL},
/* 1AF78 */ { NULL,NULL},
/* 1AF79 */ { NULL,NULL},
/* 1AF7A */ { NULL,NULL},
/* 1AF7B */ { NULL,NULL},
/* 1AF7C */ { NULL,NULL},
/* 1AF7D */ { NULL,NULL},
/* 1AF7E */ { NULL,NULL},
/* 1AF7F */ { NULL,NULL},
/* 1AF80 */ { NULL,NULL},
/* 1AF81 */ { NULL,NULL},
/* 1AF82 */ { NULL,NULL},
/* 1AF83 */ { NULL,NULL},
/* 1AF84 */ { NULL,NULL},
/* 1AF85 */ { NULL,NULL},
/* 1AF86 */ { NULL,NULL},
/* 1AF87 */ { NULL,NULL},
/* 1AF88 */ { NULL,NULL},
/* 1AF89 */ { NULL,NULL},
/* 1AF8A */ { NULL,NULL},
/* 1AF8B */ { NULL,NULL},
/* 1AF8C */ { NULL,NULL},
/* 1AF8D */ { NULL,NULL},
/* 1AF8E */ { NULL,NULL},
/* 1AF8F */ { NULL,NULL},
/* 1AF90 */ { NULL,NULL},
/* 1AF91 */ { NULL,NULL},
/* 1AF92 */ { NULL,NULL},
/* 1AF93 */ { NULL,NULL},
/* 1AF94 */ { NULL,NULL},
/* 1AF95 */ { NULL,NULL},
/* 1AF96 */ { NULL,NULL},
/* 1AF97 */ { NULL,NULL},
/* 1AF98 */ { NULL,NULL},
/* 1AF99 */ { NULL,NULL},
/* 1AF9A */ { NULL,NULL},
/* 1AF9B */ { NULL,NULL},
/* 1AF9C */ { NULL,NULL},
/* 1AF9D */ { NULL,NULL},
/* 1AF9E */ { NULL,NULL},
/* 1AF9F */ { NULL,NULL},
/* 1AFA0 */ { NULL,NULL},
/* 1AFA1 */ { NULL,NULL},
/* 1AFA2 */ { NULL,NULL},
/* 1AFA3 */ { NULL,NULL},
/* 1AFA4 */ { NULL,NULL},
/* 1AFA5 */ { NULL,NULL},
/* 1AFA6 */ { NULL,NULL},
/* 1AFA7 */ { NULL,NULL},
/* 1AFA8 */ { NULL,NULL},
/* 1AFA9 */ { NULL,NULL},
/* 1AFAA */ { NULL,NULL},
/* 1AFAB */ { NULL,NULL},
/* 1AFAC */ { NULL,NULL},
/* 1AFAD */ { NULL,NULL},
/* 1AFAE */ { NULL,NULL},
/* 1AFAF */ { NULL,NULL},
/* 1AFB0 */ { NULL,NULL},
/* 1AFB1 */ { NULL,NULL},
/* 1AFB2 */ { NULL,NULL},
/* 1AFB3 */ { NULL,NULL},
/* 1AFB4 */ { NULL,NULL},
/* 1AFB5 */ { NULL,NULL},
/* 1AFB6 */ { NULL,NULL},
/* 1AFB7 */ { NULL,NULL},
/* 1AFB8 */ { NULL,NULL},
/* 1AFB9 */ { NULL,NULL},
/* 1AFBA */ { NULL,NULL},
/* 1AFBB */ { NULL,NULL},
/* 1AFBC */ { NULL,NULL},
/* 1AFBD */ { NULL,NULL},
/* 1AFBE */ { NULL,NULL},
/* 1AFBF */ { NULL,NULL},
/* 1AFC0 */ { NULL,NULL},
/* 1AFC1 */ { NULL,NULL},
/* 1AFC2 */ { NULL,NULL},
/* 1AFC3 */ { NULL,NULL},
/* 1AFC4 */ { NULL,NULL},
/* 1AFC5 */ { NULL,NULL},
/* 1AFC6 */ { NULL,NULL},
/* 1AFC7 */ { NULL,NULL},
/* 1AFC8 */ { NULL,NULL},
/* 1AFC9 */ { NULL,NULL},
/* 1AFCA */ { NULL,NULL},
/* 1AFCB */ { NULL,NULL},
/* 1AFCC */ { NULL,NULL},
/* 1AFCD */ { NULL,NULL},
/* 1AFCE */ { NULL,NULL},
/* 1AFCF */ { NULL,NULL},
/* 1AFD0 */ { NULL,NULL},
/* 1AFD1 */ { NULL,NULL},
/* 1AFD2 */ { NULL,NULL},
/* 1AFD3 */ { NULL,NULL},
/* 1AFD4 */ { NULL,NULL},
/* 1AFD5 */ { NULL,NULL},
/* 1AFD6 */ { NULL,NULL},
/* 1AFD7 */ { NULL,NULL},
/* 1AFD8 */ { NULL,NULL},
/* 1AFD9 */ { NULL,NULL},
/* 1AFDA */ { NULL,NULL},
/* 1AFDB */ { NULL,NULL},
/* 1AFDC */ { NULL,NULL},
/* 1AFDD */ { NULL,NULL},
/* 1AFDE */ { NULL,NULL},
/* 1AFDF */ { NULL,NULL},
/* 1AFE0 */ { NULL,NULL},
/* 1AFE1 */ { NULL,NULL},
/* 1AFE2 */ { NULL,NULL},
/* 1AFE3 */ { NULL,NULL},
/* 1AFE4 */ { NULL,NULL},
/* 1AFE5 */ { NULL,NULL},
/* 1AFE6 */ { NULL,NULL},
/* 1AFE7 */ { NULL,NULL},
/* 1AFE8 */ { NULL,NULL},
/* 1AFE9 */ { NULL,NULL},
/* 1AFEA */ { NULL,NULL},
/* 1AFEB */ { NULL,NULL},
/* 1AFEC */ { NULL,NULL},
/* 1AFED */ { NULL,NULL},
/* 1AFEE */ { NULL,NULL},
/* 1AFEF */ { NULL,NULL},
/* 1AFF0 */ { "KATAKANA LETTER MINNAN TONE-2",NULL},
/* 1AFF1 */ { "KATAKANA LETTER MINNAN TONE-3",NULL},
/* 1AFF2 */ { "KATAKANA LETTER MINNAN TONE-4",NULL},
/* 1AFF3 */ { "KATAKANA LETTER MINNAN TONE-5",NULL},
/* 1AFF4 */ { NULL,NULL},
/* 1AFF5 */ { "KATAKANA LETTER MINNAN TONE-7",NULL},
/* 1AFF6 */ { "KATAKANA LETTER MINNAN TONE-8",NULL},
/* 1AFF7 */ { "KATAKANA LETTER MINNAN NASALIZED TONE-1",NULL},
/* 1AFF8 */ { "KATAKANA LETTER MINNAN NASALIZED TONE-2",NULL},
/* 1AFF9 */ { "KATAKANA LETTER MINNAN NASALIZED TONE-3",NULL},
/* 1AFFA */ { "KATAKANA LETTER MINNAN NASALIZED TONE-4",NULL},
/* 1AFFB */ { "KATAKANA LETTER MINNAN NASALIZED TONE-5",NULL},
/* 1AFFC */ { NULL,NULL},
/* 1AFFD */ { "KATAKANA LETTER MINNAN NASALIZED TONE-7",NULL},
/* 1AFFE */ { "KATAKANA LETTER MINNAN NASALIZED TONE-8",NULL},
/* 1AFFF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_B0[] = {
/* 1B000 */ { "KATAKANA LETTER ARCHAIC E",NULL},
/* 1B001 */ { "HIRAGANA LETTER ARCHAIC YE","	% HENTAIGANA LETTER E-1\n"
	"	* derived from 6C5F"},
/* 1B002 */ { "HENTAIGANA LETTER A-1","	* derived from 5B89"},
/* 1B003 */ { "HENTAIGANA LETTER A-2","	* derived from 611B"},
/* 1B004 */ { "HENTAIGANA LETTER A-3","	* derived from 963F"},
/* 1B005 */ { "HENTAIGANA LETTER A-WO","	* derived from 60E1"},
/* 1B006 */ { "HENTAIGANA LETTER I-1","	* derived from 4EE5"},
/* 1B007 */ { "HENTAIGANA LETTER I-2","	* derived from 4F0A"},
/* 1B008 */ { "HENTAIGANA LETTER I-3","	* derived from 610F"},
/* 1B009 */ { "HENTAIGANA LETTER I-4","	* derived from 79FB"},
/* 1B00A */ { "HENTAIGANA LETTER U-1","	* derived from 5B87"},
/* 1B00B */ { "HENTAIGANA LETTER U-2","	* derived from 5B87"},
/* 1B00C */ { "HENTAIGANA LETTER U-3","	* derived from 6182"},
/* 1B00D */ { "HENTAIGANA LETTER U-4","	* derived from 6709"},
/* 1B00E */ { "HENTAIGANA LETTER U-5","	* derived from 96F2"},
/* 1B00F */ { "HENTAIGANA LETTER E-2","	* derived from 76C8"},
/* 1B010 */ { "HENTAIGANA LETTER E-3","	* derived from 7E01"},
/* 1B011 */ { "HENTAIGANA LETTER E-4","	* derived from 8863"},
/* 1B012 */ { "HENTAIGANA LETTER E-5","	* derived from 8863"},
/* 1B013 */ { "HENTAIGANA LETTER E-6","	* derived from 8981"},
/* 1B014 */ { "HENTAIGANA LETTER O-1","	* derived from 65BC"},
/* 1B015 */ { "HENTAIGANA LETTER O-2","	* derived from 65BC"},
/* 1B016 */ { "HENTAIGANA LETTER O-3","	* derived from 96B1"},
/* 1B017 */ { "HENTAIGANA LETTER KA-1","	* derived from 4F73"},
/* 1B018 */ { "HENTAIGANA LETTER KA-2","	* derived from 52A0"},
/* 1B019 */ { "HENTAIGANA LETTER KA-3","	* derived from 53EF"},
/* 1B01A */ { "HENTAIGANA LETTER KA-4","	* derived from 53EF"},
/* 1B01B */ { "HENTAIGANA LETTER KA-5","	* derived from 5609"},
/* 1B01C */ { "HENTAIGANA LETTER KA-6","	* derived from 6211"},
/* 1B01D */ { "HENTAIGANA LETTER KA-7","	* derived from 6B5F"},
/* 1B01E */ { "HENTAIGANA LETTER KA-8","	* derived from 8CC0"},
/* 1B01F */ { "HENTAIGANA LETTER KA-9","	* derived from 9591"},
/* 1B020 */ { "HENTAIGANA LETTER KA-10","	* derived from 9999"},
/* 1B021 */ { "HENTAIGANA LETTER KA-11","	* derived from 99D5"},
/* 1B022 */ { "HENTAIGANA LETTER KA-KE","	* derived from 5BB6"},
/* 1B023 */ { "HENTAIGANA LETTER KI-1","	* derived from 559C"},
/* 1B024 */ { "HENTAIGANA LETTER KI-2","	* derived from 5E7E"},
/* 1B025 */ { "HENTAIGANA LETTER KI-3","	* derived from 5E7E"},
/* 1B026 */ { "HENTAIGANA LETTER KI-4","	* derived from 652F"},
/* 1B027 */ { "HENTAIGANA LETTER KI-5","	* derived from 6728"},
/* 1B028 */ { "HENTAIGANA LETTER KI-6","	* derived from 7948"},
/* 1B029 */ { "HENTAIGANA LETTER KI-7","	* derived from 8CB4"},
/* 1B02A */ { "HENTAIGANA LETTER KI-8","	* derived from 8D77"},
/* 1B02B */ { "HENTAIGANA LETTER KU-1","	* derived from 4E45"},
/* 1B02C */ { "HENTAIGANA LETTER KU-2","	* derived from 4E45"},
/* 1B02D */ { "HENTAIGANA LETTER KU-3","	* derived from 4E5D"},
/* 1B02E */ { "HENTAIGANA LETTER KU-4","	* derived from 4F9B"},
/* 1B02F */ { "HENTAIGANA LETTER KU-5","	* derived from 5036"},
/* 1B030 */ { "HENTAIGANA LETTER KU-6","	* derived from 5177"},
/* 1B031 */ { "HENTAIGANA LETTER KU-7","	* derived from 6C42"},
/* 1B032 */ { "HENTAIGANA LETTER KE-1","	* derived from 4ECB"},
/* 1B033 */ { "HENTAIGANA LETTER KE-2","	* derived from 4ECB"},
/* 1B034 */ { "HENTAIGANA LETTER KE-3","	* derived from 5E0C"},
/* 1B035 */ { "HENTAIGANA LETTER KE-4","	* derived from 6C23"},
/* 1B036 */ { "HENTAIGANA LETTER KE-5","	* derived from 8A08"},
/* 1B037 */ { "HENTAIGANA LETTER KE-6","	* derived from 9063"},
/* 1B038 */ { "HENTAIGANA LETTER KO-1","	* derived from 53E4"},
/* 1B039 */ { "HENTAIGANA LETTER KO-2","	* derived from 6545"},
/* 1B03A */ { "HENTAIGANA LETTER KO-3","	* derived from 8A31"},
/* 1B03B */ { "HENTAIGANA LETTER KO-KI","	* derived from 671F"},
/* 1B03C */ { "HENTAIGANA LETTER SA-1","	* derived from 4E4D"},
/* 1B03D */ { "HENTAIGANA LETTER SA-2","	* derived from 4F50"},
/* 1B03E */ { "HENTAIGANA LETTER SA-3","	* derived from 4F50"},
/* 1B03F */ { "HENTAIGANA LETTER SA-4","	* derived from 5DE6"},
/* 1B040 */ { "HENTAIGANA LETTER SA-5","	* derived from 5DEE"},
/* 1B041 */ { "HENTAIGANA LETTER SA-6","	* derived from 6563"},
/* 1B042 */ { "HENTAIGANA LETTER SA-7","	* derived from 659C"},
/* 1B043 */ { "HENTAIGANA LETTER SA-8","	* derived from 6C99"},
/* 1B044 */ { "HENTAIGANA LETTER SI-1","	* derived from 4E4B"},
/* 1B045 */ { "HENTAIGANA LETTER SI-2","	* derived from 4E4B"},
/* 1B046 */ { "HENTAIGANA LETTER SI-3","	* derived from 4E8B"},
/* 1B047 */ { "HENTAIGANA LETTER SI-4","	* derived from 56DB"},
/* 1B048 */ { "HENTAIGANA LETTER SI-5","	* derived from 5FD7"},
/* 1B049 */ { "HENTAIGANA LETTER SI-6","	* derived from 65B0"},
/* 1B04A */ { "HENTAIGANA LETTER SU-1","	* derived from 53D7"},
/* 1B04B */ { "HENTAIGANA LETTER SU-2","	* derived from 58FD"},
/* 1B04C */ { "HENTAIGANA LETTER SU-3","	* derived from 6578"},
/* 1B04D */ { "HENTAIGANA LETTER SU-4","	* derived from 6578"},
/* 1B04E */ { "HENTAIGANA LETTER SU-5","	* derived from 6625"},
/* 1B04F */ { "HENTAIGANA LETTER SU-6","	* derived from 6625"},
/* 1B050 */ { "HENTAIGANA LETTER SU-7","	* derived from 9808"},
/* 1B051 */ { "HENTAIGANA LETTER SU-8","	* derived from 9808"},
/* 1B052 */ { "HENTAIGANA LETTER SE-1","	* derived from 4E16"},
/* 1B053 */ { "HENTAIGANA LETTER SE-2","	* derived from 4E16"},
/* 1B054 */ { "HENTAIGANA LETTER SE-3","	* derived from 4E16"},
/* 1B055 */ { "HENTAIGANA LETTER SE-4","	* derived from 52E2"},
/* 1B056 */ { "HENTAIGANA LETTER SE-5","	* derived from 8072"},
/* 1B057 */ { "HENTAIGANA LETTER SO-1","	* derived from 6240"},
/* 1B058 */ { "HENTAIGANA LETTER SO-2","	* derived from 6240"},
/* 1B059 */ { "HENTAIGANA LETTER SO-3","	* derived from 66FE"},
/* 1B05A */ { "HENTAIGANA LETTER SO-4","	* derived from 66FE"},
/* 1B05B */ { "HENTAIGANA LETTER SO-5","	* derived from 695A"},
/* 1B05C */ { "HENTAIGANA LETTER SO-6","	* derived from 8607"},
/* 1B05D */ { "HENTAIGANA LETTER SO-7","	* derived from 8655"},
/* 1B05E */ { "HENTAIGANA LETTER TA-1","	* derived from 5802"},
/* 1B05F */ { "HENTAIGANA LETTER TA-2","	* derived from 591A"},
/* 1B060 */ { "HENTAIGANA LETTER TA-3","	* derived from 591A"},
/* 1B061 */ { "HENTAIGANA LETTER TA-4","	* derived from 7576"},
/* 1B062 */ { "HENTAIGANA LETTER TI-1","	* derived from 5343"},
/* 1B063 */ { "HENTAIGANA LETTER TI-2","	* derived from 5730"},
/* 1B064 */ { "HENTAIGANA LETTER TI-3","	* derived from 667A"},
/* 1B065 */ { "HENTAIGANA LETTER TI-4","	* derived from 77E5"},
/* 1B066 */ { "HENTAIGANA LETTER TI-5","	* derived from 77E5"},
/* 1B067 */ { "HENTAIGANA LETTER TI-6","	* derived from 81F4"},
/* 1B068 */ { "HENTAIGANA LETTER TI-7","	* derived from 9072"},
/* 1B069 */ { "HENTAIGANA LETTER TU-1","	* derived from 5DDD"},
/* 1B06A */ { "HENTAIGANA LETTER TU-2","	* derived from 5DDD"},
/* 1B06B */ { "HENTAIGANA LETTER TU-3","	* derived from 6D25"},
/* 1B06C */ { "HENTAIGANA LETTER TU-4","	* derived from 90FD"},
/* 1B06D */ { "HENTAIGANA LETTER TU-TO","	* derived from 5F92"},
/* 1B06E */ { "HENTAIGANA LETTER TE-1","	* derived from 4EAD"},
/* 1B06F */ { "HENTAIGANA LETTER TE-2","	* derived from 4F4E"},
/* 1B070 */ { "HENTAIGANA LETTER TE-3","	* derived from 50B3"},
/* 1B071 */ { "HENTAIGANA LETTER TE-4","	* derived from 5929"},
/* 1B072 */ { "HENTAIGANA LETTER TE-5","	* derived from 5929"},
/* 1B073 */ { "HENTAIGANA LETTER TE-6","	* derived from 5929"},
/* 1B074 */ { "HENTAIGANA LETTER TE-7","	* derived from 5E1D"},
/* 1B075 */ { "HENTAIGANA LETTER TE-8","	* derived from 5F16"},
/* 1B076 */ { "HENTAIGANA LETTER TE-9","	* derived from 8F49"},
/* 1B077 */ { "HENTAIGANA LETTER TO-1","	* derived from 571F"},
/* 1B078 */ { "HENTAIGANA LETTER TO-2","	* derived from 5EA6"},
/* 1B079 */ { "HENTAIGANA LETTER TO-3","	* derived from 6771"},
/* 1B07A */ { "HENTAIGANA LETTER TO-4","	* derived from 767B"},
/* 1B07B */ { "HENTAIGANA LETTER TO-5","	* derived from 767B"},
/* 1B07C */ { "HENTAIGANA LETTER TO-6","	* derived from 7825"},
/* 1B07D */ { "HENTAIGANA LETTER TO-RA","	* derived from 7B49"},
/* 1B07E */ { "HENTAIGANA LETTER NA-1","	* derived from 5357"},
/* 1B07F */ { "HENTAIGANA LETTER NA-2","	* derived from 540D"},
/* 1B080 */ { "HENTAIGANA LETTER NA-3","	* derived from 5948"},
/* 1B081 */ { "HENTAIGANA LETTER NA-4","	* derived from 5948"},
/* 1B082 */ { "HENTAIGANA LETTER NA-5","	* derived from 5948"},
/* 1B083 */ { "HENTAIGANA LETTER NA-6","	* derived from 83DC"},
/* 1B084 */ { "HENTAIGANA LETTER NA-7","	* derived from 90A3"},
/* 1B085 */ { "HENTAIGANA LETTER NA-8","	* derived from 90A3"},
/* 1B086 */ { "HENTAIGANA LETTER NA-9","	* derived from 96E3"},
/* 1B087 */ { "HENTAIGANA LETTER NI-1","	* derived from 4E39"},
/* 1B088 */ { "HENTAIGANA LETTER NI-2","	* derived from 4E8C"},
/* 1B089 */ { "HENTAIGANA LETTER NI-3","	* derived from 4EC1"},
/* 1B08A */ { "HENTAIGANA LETTER NI-4","	* derived from 5152"},
/* 1B08B */ { "HENTAIGANA LETTER NI-5","	* derived from 723E"},
/* 1B08C */ { "HENTAIGANA LETTER NI-6","	* derived from 723E"},
/* 1B08D */ { "HENTAIGANA LETTER NI-7","	* derived from 8033"},
/* 1B08E */ { "HENTAIGANA LETTER NI-TE","	* derived from 800C"},
/* 1B08F */ { "HENTAIGANA LETTER NU-1","	* derived from 52AA"},
/* 1B090 */ { "HENTAIGANA LETTER NU-2","	* derived from 5974"},
/* 1B091 */ { "HENTAIGANA LETTER NU-3","	* derived from 6012"},
/* 1B092 */ { "HENTAIGANA LETTER NE-1","	* derived from 5E74"},
/* 1B093 */ { "HENTAIGANA LETTER NE-2","	* derived from 5E74"},
/* 1B094 */ { "HENTAIGANA LETTER NE-3","	* derived from 5E74"},
/* 1B095 */ { "HENTAIGANA LETTER NE-4","	* derived from 6839"},
/* 1B096 */ { "HENTAIGANA LETTER NE-5","	* derived from 71B1"},
/* 1B097 */ { "HENTAIGANA LETTER NE-6","	* derived from 79B0"},
/* 1B098 */ { "HENTAIGANA LETTER NE-KO","	* derived from 5B50"},
/* 1B099 */ { "HENTAIGANA LETTER NO-1","	* derived from 4E43"},
/* 1B09A */ { "HENTAIGANA LETTER NO-2","	* derived from 6FC3"},
/* 1B09B */ { "HENTAIGANA LETTER NO-3","	* derived from 80FD"},
/* 1B09C */ { "HENTAIGANA LETTER NO-4","	* derived from 80FD"},
/* 1B09D */ { "HENTAIGANA LETTER NO-5","	* derived from 8FB2"},
/* 1B09E */ { "HENTAIGANA LETTER HA-1","	* derived from 516B"},
/* 1B09F */ { "HENTAIGANA LETTER HA-2","	* derived from 534A"},
/* 1B0A0 */ { "HENTAIGANA LETTER HA-3","	* derived from 5A46"},
/* 1B0A1 */ { "HENTAIGANA LETTER HA-4","	* derived from 6CE2"},
/* 1B0A2 */ { "HENTAIGANA LETTER HA-5","	* derived from 76E4"},
/* 1B0A3 */ { "HENTAIGANA LETTER HA-6","	* derived from 76E4"},
/* 1B0A4 */ { "HENTAIGANA LETTER HA-7","	* derived from 7834"},
/* 1B0A5 */ { "HENTAIGANA LETTER HA-8","	* derived from 8005"},
/* 1B0A6 */ { "HENTAIGANA LETTER HA-9","	* derived from 8005"},
/* 1B0A7 */ { "HENTAIGANA LETTER HA-10","	* derived from 8449"},
/* 1B0A8 */ { "HENTAIGANA LETTER HA-11","	* derived from 9817"},
/* 1B0A9 */ { "HENTAIGANA LETTER HI-1","	* derived from 60B2"},
/* 1B0AA */ { "HENTAIGANA LETTER HI-2","	* derived from 65E5"},
/* 1B0AB */ { "HENTAIGANA LETTER HI-3","	* derived from 6BD4"},
/* 1B0AC */ { "HENTAIGANA LETTER HI-4","	* derived from 907F"},
/* 1B0AD */ { "HENTAIGANA LETTER HI-5","	* derived from 975E"},
/* 1B0AE */ { "HENTAIGANA LETTER HI-6","	* derived from 98DB"},
/* 1B0AF */ { "HENTAIGANA LETTER HI-7","	* derived from 98DB"},
/* 1B0B0 */ { "HENTAIGANA LETTER HU-1","	* derived from 4E0D"},
/* 1B0B1 */ { "HENTAIGANA LETTER HU-2","	* derived from 5A66"},
/* 1B0B2 */ { "HENTAIGANA LETTER HU-3","	* derived from 5E03"},
/* 1B0B3 */ { "HENTAIGANA LETTER HE-1","	* derived from 500D"},
/* 1B0B4 */ { "HENTAIGANA LETTER HE-2","	* derived from 5F0A"},
/* 1B0B5 */ { "HENTAIGANA LETTER HE-3","	* derived from 5F0A"},
/* 1B0B6 */ { "HENTAIGANA LETTER HE-4","	* derived from 904D"},
/* 1B0B7 */ { "HENTAIGANA LETTER HE-5","	* derived from 908A"},
/* 1B0B8 */ { "HENTAIGANA LETTER HE-6","	* derived from 908A"},
/* 1B0B9 */ { "HENTAIGANA LETTER HE-7","	* derived from 90E8"},
/* 1B0BA */ { "HENTAIGANA LETTER HO-1","	* derived from 4FDD"},
/* 1B0BB */ { "HENTAIGANA LETTER HO-2","	* derived from 4FDD"},
/* 1B0BC */ { "HENTAIGANA LETTER HO-3","	* derived from 5831"},
/* 1B0BD */ { "HENTAIGANA LETTER HO-4","	* derived from 5949"},
/* 1B0BE */ { "HENTAIGANA LETTER HO-5","	* derived from 5BF6"},
/* 1B0BF */ { "HENTAIGANA LETTER HO-6","	* derived from 672C"},
/* 1B0C0 */ { "HENTAIGANA LETTER HO-7","	* derived from 672C"},
/* 1B0C1 */ { "HENTAIGANA LETTER HO-8","	* derived from 8C50"},
/* 1B0C2 */ { "HENTAIGANA LETTER MA-1","	* derived from 4E07"},
/* 1B0C3 */ { "HENTAIGANA LETTER MA-2","	* derived from 672B"},
/* 1B0C4 */ { "HENTAIGANA LETTER MA-3","	* derived from 672B"},
/* 1B0C5 */ { "HENTAIGANA LETTER MA-4","	* derived from 6EFF"},
/* 1B0C6 */ { "HENTAIGANA LETTER MA-5","	* derived from 6EFF"},
/* 1B0C7 */ { "HENTAIGANA LETTER MA-6","	* derived from 842C"},
/* 1B0C8 */ { "HENTAIGANA LETTER MA-7","	* derived from 9EBB"},
/* 1B0C9 */ { "HENTAIGANA LETTER MI-1","	* derived from 4E09"},
/* 1B0CA */ { "HENTAIGANA LETTER MI-2","	* derived from 5FAE"},
/* 1B0CB */ { "HENTAIGANA LETTER MI-3","	* derived from 7F8E"},
/* 1B0CC */ { "HENTAIGANA LETTER MI-4","	* derived from 7F8E"},
/* 1B0CD */ { "HENTAIGANA LETTER MI-5","	* derived from 7F8E"},
/* 1B0CE */ { "HENTAIGANA LETTER MI-6","	* derived from 898B"},
/* 1B0CF */ { "HENTAIGANA LETTER MI-7","	* derived from 8EAB"},
/* 1B0D0 */ { "HENTAIGANA LETTER MU-1","	* derived from 6B66"},
/* 1B0D1 */ { "HENTAIGANA LETTER MU-2","	* derived from 7121"},
/* 1B0D2 */ { "HENTAIGANA LETTER MU-3","	* derived from 725F"},
/* 1B0D3 */ { "HENTAIGANA LETTER MU-4","	* derived from 821E"},
/* 1B0D4 */ { "HENTAIGANA LETTER ME-1","	* derived from 514D"},
/* 1B0D5 */ { "HENTAIGANA LETTER ME-2","	* derived from 9762"},
/* 1B0D6 */ { "HENTAIGANA LETTER ME-MA","	* derived from 99AC"},
/* 1B0D7 */ { "HENTAIGANA LETTER MO-1","	* derived from 6BCD"},
/* 1B0D8 */ { "HENTAIGANA LETTER MO-2","	* derived from 6BDB"},
/* 1B0D9 */ { "HENTAIGANA LETTER MO-3","	* derived from 6BDB"},
/* 1B0DA */ { "HENTAIGANA LETTER MO-4","	* derived from 6BDB"},
/* 1B0DB */ { "HENTAIGANA LETTER MO-5","	* derived from 8302"},
/* 1B0DC */ { "HENTAIGANA LETTER MO-6","	* derived from 88F3"},
/* 1B0DD */ { "HENTAIGANA LETTER YA-1","	* derived from 4E5F"},
/* 1B0DE */ { "HENTAIGANA LETTER YA-2","	* derived from 4E5F"},
/* 1B0DF */ { "HENTAIGANA LETTER YA-3","	* derived from 5C4B"},
/* 1B0E0 */ { "HENTAIGANA LETTER YA-4","	* derived from 8036"},
/* 1B0E1 */ { "HENTAIGANA LETTER YA-5","	* derived from 8036"},
/* 1B0E2 */ { "HENTAIGANA LETTER YA-YO","	* derived from 591C"},
/* 1B0E3 */ { "HENTAIGANA LETTER YU-1","	* derived from 6E38"},
/* 1B0E4 */ { "HENTAIGANA LETTER YU-2","	* derived from 7531"},
/* 1B0E5 */ { "HENTAIGANA LETTER YU-3","	* derived from 7531"},
/* 1B0E6 */ { "HENTAIGANA LETTER YU-4","	* derived from 904A"},
/* 1B0E7 */ { "HENTAIGANA LETTER YO-1","	* derived from 4EE3"},
/* 1B0E8 */ { "HENTAIGANA LETTER YO-2","	* derived from 4F59"},
/* 1B0E9 */ { "HENTAIGANA LETTER YO-3","	* derived from 8207"},
/* 1B0EA */ { "HENTAIGANA LETTER YO-4","	* derived from 8207"},
/* 1B0EB */ { "HENTAIGANA LETTER YO-5","	* derived from 8207"},
/* 1B0EC */ { "HENTAIGANA LETTER YO-6","	* derived from 9918"},
/* 1B0ED */ { "HENTAIGANA LETTER RA-1","	* derived from 7F85"},
/* 1B0EE */ { "HENTAIGANA LETTER RA-2","	* derived from 826F"},
/* 1B0EF */ { "HENTAIGANA LETTER RA-3","	* derived from 826F"},
/* 1B0F0 */ { "HENTAIGANA LETTER RA-4","	* derived from 826F"},
/* 1B0F1 */ { "HENTAIGANA LETTER RI-1","	* derived from 5229"},
/* 1B0F2 */ { "HENTAIGANA LETTER RI-2","	* derived from 5229"},
/* 1B0F3 */ { "HENTAIGANA LETTER RI-3","	* derived from 674E"},
/* 1B0F4 */ { "HENTAIGANA LETTER RI-4","	* derived from 68A8"},
/* 1B0F5 */ { "HENTAIGANA LETTER RI-5","	* derived from 7406"},
/* 1B0F6 */ { "HENTAIGANA LETTER RI-6","	* derived from 91CC"},
/* 1B0F7 */ { "HENTAIGANA LETTER RI-7","	* derived from 96E2"},
/* 1B0F8 */ { "HENTAIGANA LETTER RU-1","	* derived from 6D41"},
/* 1B0F9 */ { "HENTAIGANA LETTER RU-2","	* derived from 7559"},
/* 1B0FA */ { "HENTAIGANA LETTER RU-3","	* derived from 7559"},
/* 1B0FB */ { "HENTAIGANA LETTER RU-4","	* derived from 7559"},
/* 1B0FC */ { "HENTAIGANA LETTER RU-5","	* derived from 7D2F"},
/* 1B0FD */ { "HENTAIGANA LETTER RU-6","	* derived from 985E"},
/* 1B0FE */ { "HENTAIGANA LETTER RE-1","	* derived from 79AE"},
/* 1B0FF */ { "HENTAIGANA LETTER RE-2","	* derived from 79AE"}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_B1[] = {
/* 1B100 */ { "HENTAIGANA LETTER RE-3","	* derived from 9023"},
/* 1B101 */ { "HENTAIGANA LETTER RE-4","	* derived from 9E97"},
/* 1B102 */ { "HENTAIGANA LETTER RO-1","	* derived from 5442"},
/* 1B103 */ { "HENTAIGANA LETTER RO-2","	* derived from 5442"},
/* 1B104 */ { "HENTAIGANA LETTER RO-3","	* derived from 5A41"},
/* 1B105 */ { "HENTAIGANA LETTER RO-4","	* derived from 6A13"},
/* 1B106 */ { "HENTAIGANA LETTER RO-5","	* derived from 8DEF"},
/* 1B107 */ { "HENTAIGANA LETTER RO-6","	* derived from 9732"},
/* 1B108 */ { "HENTAIGANA LETTER WA-1","	* derived from 502D"},
/* 1B109 */ { "HENTAIGANA LETTER WA-2","	* derived from 548C"},
/* 1B10A */ { "HENTAIGANA LETTER WA-3","	* derived from 548C"},
/* 1B10B */ { "HENTAIGANA LETTER WA-4","	* derived from 738B"},
/* 1B10C */ { "HENTAIGANA LETTER WA-5","	* derived from 738B"},
/* 1B10D */ { "HENTAIGANA LETTER WI-1","	* derived from 4E95"},
/* 1B10E */ { "HENTAIGANA LETTER WI-2","	* derived from 4E95"},
/* 1B10F */ { "HENTAIGANA LETTER WI-3","	* derived from 5C45"},
/* 1B110 */ { "HENTAIGANA LETTER WI-4","	* derived from 7232"},
/* 1B111 */ { "HENTAIGANA LETTER WI-5","	* derived from 907A"},
/* 1B112 */ { "HENTAIGANA LETTER WE-1","	* derived from 60E0"},
/* 1B113 */ { "HENTAIGANA LETTER WE-2","	* derived from 885E"},
/* 1B114 */ { "HENTAIGANA LETTER WE-3","	* derived from 885E"},
/* 1B115 */ { "HENTAIGANA LETTER WE-4","	* derived from 885E"},
/* 1B116 */ { "HENTAIGANA LETTER WO-1","	* derived from 4E4E"},
/* 1B117 */ { "HENTAIGANA LETTER WO-2","	* derived from 4E4E"},
/* 1B118 */ { "HENTAIGANA LETTER WO-3","	* derived from 5C3E"},
/* 1B119 */ { "HENTAIGANA LETTER WO-4","	* derived from 7DD2"},
/* 1B11A */ { "HENTAIGANA LETTER WO-5","	* derived from 8D8A"},
/* 1B11B */ { "HENTAIGANA LETTER WO-6","	* derived from 9060"},
/* 1B11C */ { "HENTAIGANA LETTER WO-7","	* derived from 9060"},
/* 1B11D */ { "HENTAIGANA LETTER N-MU-MO-1","	* derived from 65E0"},
/* 1B11E */ { "HENTAIGANA LETTER N-MU-MO-2","	* derived from 65E0"},
/* 1B11F */ { "HIRAGANA LETTER ARCHAIC WU","	* derived from 6C59"},
/* 1B120 */ { "KATAKANA LETTER ARCHAIC YI",NULL},
/* 1B121 */ { "KATAKANA LETTER ARCHAIC YE",NULL},
/* 1B122 */ { "KATAKANA LETTER ARCHAIC WU",NULL},
/* 1B123 */ { NULL,NULL},
/* 1B124 */ { NULL,NULL},
/* 1B125 */ { NULL,NULL},
/* 1B126 */ { NULL,NULL},
/* 1B127 */ { NULL,NULL},
/* 1B128 */ { NULL,NULL},
/* 1B129 */ { NULL,NULL},
/* 1B12A */ { NULL,NULL},
/* 1B12B */ { NULL,NULL},
/* 1B12C */ { NULL,NULL},
/* 1B12D */ { NULL,NULL},
/* 1B12E */ { NULL,NULL},
/* 1B12F */ { NULL,NULL},
/* 1B130 */ { NULL,NULL},
/* 1B131 */ { NULL,NULL},
/* 1B132 */ { "HIRAGANA LETTER SMALL KO",NULL},
/* 1B133 */ { NULL,NULL},
/* 1B134 */ { NULL,NULL},
/* 1B135 */ { NULL,NULL},
/* 1B136 */ { NULL,NULL},
/* 1B137 */ { NULL,NULL},
/* 1B138 */ { NULL,NULL},
/* 1B139 */ { NULL,NULL},
/* 1B13A */ { NULL,NULL},
/* 1B13B */ { NULL,NULL},
/* 1B13C */ { NULL,NULL},
/* 1B13D */ { NULL,NULL},
/* 1B13E */ { NULL,NULL},
/* 1B13F */ { NULL,NULL},
/* 1B140 */ { NULL,NULL},
/* 1B141 */ { NULL,NULL},
/* 1B142 */ { NULL,NULL},
/* 1B143 */ { NULL,NULL},
/* 1B144 */ { NULL,NULL},
/* 1B145 */ { NULL,NULL},
/* 1B146 */ { NULL,NULL},
/* 1B147 */ { NULL,NULL},
/* 1B148 */ { NULL,NULL},
/* 1B149 */ { NULL,NULL},
/* 1B14A */ { NULL,NULL},
/* 1B14B */ { NULL,NULL},
/* 1B14C */ { NULL,NULL},
/* 1B14D */ { NULL,NULL},
/* 1B14E */ { NULL,NULL},
/* 1B14F */ { NULL,NULL},
/* 1B150 */ { "HIRAGANA LETTER SMALL WI",NULL},
/* 1B151 */ { "HIRAGANA LETTER SMALL WE",NULL},
/* 1B152 */ { "HIRAGANA LETTER SMALL WO",NULL},
/* 1B153 */ { NULL,NULL},
/* 1B154 */ { NULL,NULL},
/* 1B155 */ { "KATAKANA LETTER SMALL KO",NULL},
/* 1B156 */ { NULL,NULL},
/* 1B157 */ { NULL,NULL},
/* 1B158 */ { NULL,NULL},
/* 1B159 */ { NULL,NULL},
/* 1B15A */ { NULL,NULL},
/* 1B15B */ { NULL,NULL},
/* 1B15C */ { NULL,NULL},
/* 1B15D */ { NULL,NULL},
/* 1B15E */ { NULL,NULL},
/* 1B15F */ { NULL,NULL},
/* 1B160 */ { NULL,NULL},
/* 1B161 */ { NULL,NULL},
/* 1B162 */ { NULL,NULL},
/* 1B163 */ { NULL,NULL},
/* 1B164 */ { "KATAKANA LETTER SMALL WI",NULL},
/* 1B165 */ { "KATAKANA LETTER SMALL WE",NULL},
/* 1B166 */ { "KATAKANA LETTER SMALL WO",NULL},
/* 1B167 */ { "KATAKANA LETTER SMALL N",NULL},
/* 1B168 */ { NULL,NULL},
/* 1B169 */ { NULL,NULL},
/* 1B16A */ { NULL,NULL},
/* 1B16B */ { NULL,NULL},
/* 1B16C */ { NULL,NULL},
/* 1B16D */ { NULL,NULL},
/* 1B16E */ { NULL,NULL},
/* 1B16F */ { NULL,NULL},
/* 1B170 */ { "NUSHU CHARACTER-1B170","	x 4E00"},
/* 1B171 */ { "NUSHU CHARACTER-1B171","	x 4E8C"},
/* 1B172 */ { "NUSHU CHARACTER-1B172",NULL},
/* 1B173 */ { "NUSHU CHARACTER-1B173",NULL},
/* 1B174 */ { "NUSHU CHARACTER-1B174",NULL},
/* 1B175 */ { "NUSHU CHARACTER-1B175",NULL},
/* 1B176 */ { "NUSHU CHARACTER-1B176",NULL},
/* 1B177 */ { "NUSHU CHARACTER-1B177",NULL},
/* 1B178 */ { "NUSHU CHARACTER-1B178","	x 6C34"},
/* 1B179 */ { "NUSHU CHARACTER-1B179",NULL},
/* 1B17A */ { "NUSHU CHARACTER-1B17A",NULL},
/* 1B17B */ { "NUSHU CHARACTER-1B17B",NULL},
/* 1B17C */ { "NUSHU CHARACTER-1B17C",NULL},
/* 1B17D */ { "NUSHU CHARACTER-1B17D",NULL},
/* 1B17E */ { "NUSHU CHARACTER-1B17E",NULL},
/* 1B17F */ { "NUSHU CHARACTER-1B17F",NULL},
/* 1B180 */ { "NUSHU CHARACTER-1B180","	x 571F"},
/* 1B181 */ { "NUSHU CHARACTER-1B181",NULL},
/* 1B182 */ { "NUSHU CHARACTER-1B182",NULL},
/* 1B183 */ { "NUSHU CHARACTER-1B183","	x 5DE5"},
/* 1B184 */ { "NUSHU CHARACTER-1B184",NULL},
/* 1B185 */ { "NUSHU CHARACTER-1B185","	x 4E2A"},
/* 1B186 */ { "NUSHU CHARACTER-1B186",NULL},
/* 1B187 */ { "NUSHU CHARACTER-1B187",NULL},
/* 1B188 */ { "NUSHU CHARACTER-1B188",NULL},
/* 1B189 */ { "NUSHU CHARACTER-1B189",NULL},
/* 1B18A */ { "NUSHU CHARACTER-1B18A","	x 4E09"},
/* 1B18B */ { "NUSHU CHARACTER-1B18B",NULL},
/* 1B18C */ { "NUSHU CHARACTER-1B18C",NULL},
/* 1B18D */ { "NUSHU CHARACTER-1B18D",NULL},
/* 1B18E */ { "NUSHU CHARACTER-1B18E",NULL},
/* 1B18F */ { "NUSHU CHARACTER-1B18F",NULL},
/* 1B190 */ { "NUSHU CHARACTER-1B190",NULL},
/* 1B191 */ { "NUSHU CHARACTER-1B191",NULL},
/* 1B192 */ { "NUSHU CHARACTER-1B192",NULL},
/* 1B193 */ { "NUSHU CHARACTER-1B193",NULL},
/* 1B194 */ { "NUSHU CHARACTER-1B194","	x 592B"},
/* 1B195 */ { "NUSHU CHARACTER-1B195","	x 706B"},
/* 1B196 */ { "NUSHU CHARACTER-1B196",NULL},
/* 1B197 */ { "NUSHU CHARACTER-1B197",NULL},
/* 1B198 */ { "NUSHU CHARACTER-1B198",NULL},
/* 1B199 */ { "NUSHU CHARACTER-1B199",NULL},
/* 1B19A */ { "NUSHU CHARACTER-1B19A",NULL},
/* 1B19B */ { "NUSHU CHARACTER-1B19B",NULL},
/* 1B19C */ { "NUSHU CHARACTER-1B19C",NULL},
/* 1B19D */ { "NUSHU CHARACTER-1B19D",NULL},
/* 1B19E */ { "NUSHU CHARACTER-1B19E",NULL},
/* 1B19F */ { "NUSHU CHARACTER-1B19F",NULL},
/* 1B1A0 */ { "NUSHU CHARACTER-1B1A0",NULL},
/* 1B1A1 */ { "NUSHU CHARACTER-1B1A1","	x 4EA1"},
/* 1B1A2 */ { "NUSHU CHARACTER-1B1A2",NULL},
/* 1B1A3 */ { "NUSHU CHARACTER-1B1A3",NULL},
/* 1B1A4 */ { "NUSHU CHARACTER-1B1A4",NULL},
/* 1B1A5 */ { "NUSHU CHARACTER-1B1A5",NULL},
/* 1B1A6 */ { "NUSHU CHARACTER-1B1A6",NULL},
/* 1B1A7 */ { "NUSHU CHARACTER-1B1A7","	x 738B"},
/* 1B1A8 */ { "NUSHU CHARACTER-1B1A8","	x 672A"},
/* 1B1A9 */ { "NUSHU CHARACTER-1B1A9",NULL},
/* 1B1AA */ { "NUSHU CHARACTER-1B1AA",NULL},
/* 1B1AB */ { "NUSHU CHARACTER-1B1AB","	x 5185"},
/* 1B1AC */ { "NUSHU CHARACTER-1B1AC",NULL},
/* 1B1AD */ { "NUSHU CHARACTER-1B1AD",NULL},
/* 1B1AE */ { "NUSHU CHARACTER-1B1AE",NULL},
/* 1B1AF */ { "NUSHU CHARACTER-1B1AF",NULL},
/* 1B1B0 */ { "NUSHU CHARACTER-1B1B0",NULL},
/* 1B1B1 */ { "NUSHU CHARACTER-1B1B1",NULL},
/* 1B1B2 */ { "NUSHU CHARACTER-1B1B2",NULL},
/* 1B1B3 */ { "NUSHU CHARACTER-1B1B3",NULL},
/* 1B1B4 */ { "NUSHU CHARACTER-1B1B4",NULL},
/* 1B1B5 */ { "NUSHU CHARACTER-1B1B5",NULL},
/* 1B1B6 */ { "NUSHU CHARACTER-1B1B6",NULL},
/* 1B1B7 */ { "NUSHU CHARACTER-1B1B7",NULL},
/* 1B1B8 */ { "NUSHU CHARACTER-1B1B8",NULL},
/* 1B1B9 */ { "NUSHU CHARACTER-1B1B9",NULL},
/* 1B1BA */ { "NUSHU CHARACTER-1B1BA",NULL},
/* 1B1BB */ { "NUSHU CHARACTER-1B1BB",NULL},
/* 1B1BC */ { "NUSHU CHARACTER-1B1BC",NULL},
/* 1B1BD */ { "NUSHU CHARACTER-1B1BD",NULL},
/* 1B1BE */ { "NUSHU CHARACTER-1B1BE",NULL},
/* 1B1BF */ { "NUSHU CHARACTER-1B1BF",NULL},
/* 1B1C0 */ { "NUSHU CHARACTER-1B1C0",NULL},
/* 1B1C1 */ { "NUSHU CHARACTER-1B1C1",NULL},
/* 1B1C2 */ { "NUSHU CHARACTER-1B1C2",NULL},
/* 1B1C3 */ { "NUSHU CHARACTER-1B1C3",NULL},
/* 1B1C4 */ { "NUSHU CHARACTER-1B1C4",NULL},
/* 1B1C5 */ { "NUSHU CHARACTER-1B1C5",NULL},
/* 1B1C6 */ { "NUSHU CHARACTER-1B1C6",NULL},
/* 1B1C7 */ { "NUSHU CHARACTER-1B1C7",NULL},
/* 1B1C8 */ { "NUSHU CHARACTER-1B1C8",NULL},
/* 1B1C9 */ { "NUSHU CHARACTER-1B1C9",NULL},
/* 1B1CA */ { "NUSHU CHARACTER-1B1CA",NULL},
/* 1B1CB */ { "NUSHU CHARACTER-1B1CB",NULL},
/* 1B1CC */ { "NUSHU CHARACTER-1B1CC","	x 540E"},
/* 1B1CD */ { "NUSHU CHARACTER-1B1CD",NULL},
/* 1B1CE */ { "NUSHU CHARACTER-1B1CE",NULL},
/* 1B1CF */ { "NUSHU CHARACTER-1B1CF",NULL},
/* 1B1D0 */ { "NUSHU CHARACTER-1B1D0",NULL},
/* 1B1D1 */ { "NUSHU CHARACTER-1B1D1",NULL},
/* 1B1D2 */ { "NUSHU CHARACTER-1B1D2",NULL},
/* 1B1D3 */ { "NUSHU CHARACTER-1B1D3",NULL},
/* 1B1D4 */ { "NUSHU CHARACTER-1B1D4",NULL},
/* 1B1D5 */ { "NUSHU CHARACTER-1B1D5",NULL},
/* 1B1D6 */ { "NUSHU CHARACTER-1B1D6",NULL},
/* 1B1D7 */ { "NUSHU CHARACTER-1B1D7",NULL},
/* 1B1D8 */ { "NUSHU CHARACTER-1B1D8",NULL},
/* 1B1D9 */ { "NUSHU CHARACTER-1B1D9",NULL},
/* 1B1DA */ { "NUSHU CHARACTER-1B1DA",NULL},
/* 1B1DB */ { "NUSHU CHARACTER-1B1DB",NULL},
/* 1B1DC */ { "NUSHU CHARACTER-1B1DC",NULL},
/* 1B1DD */ { "NUSHU CHARACTER-1B1DD",NULL},
/* 1B1DE */ { "NUSHU CHARACTER-1B1DE",NULL},
/* 1B1DF */ { "NUSHU CHARACTER-1B1DF",NULL},
/* 1B1E0 */ { "NUSHU CHARACTER-1B1E0",NULL},
/* 1B1E1 */ { "NUSHU CHARACTER-1B1E1",NULL},
/* 1B1E2 */ { "NUSHU CHARACTER-1B1E2",NULL},
/* 1B1E3 */ { "NUSHU CHARACTER-1B1E3",NULL},
/* 1B1E4 */ { "NUSHU CHARACTER-1B1E4",NULL},
/* 1B1E5 */ { "NUSHU CHARACTER-1B1E5",NULL},
/* 1B1E6 */ { "NUSHU CHARACTER-1B1E6",NULL},
/* 1B1E7 */ { "NUSHU CHARACTER-1B1E7",NULL},
/* 1B1E8 */ { "NUSHU CHARACTER-1B1E8",NULL},
/* 1B1E9 */ { "NUSHU CHARACTER-1B1E9",NULL},
/* 1B1EA */ { "NUSHU CHARACTER-1B1EA",NULL},
/* 1B1EB */ { "NUSHU CHARACTER-1B1EB",NULL},
/* 1B1EC */ { "NUSHU CHARACTER-1B1EC",NULL},
/* 1B1ED */ { "NUSHU CHARACTER-1B1ED",NULL},
/* 1B1EE */ { "NUSHU CHARACTER-1B1EE",NULL},
/* 1B1EF */ { "NUSHU CHARACTER-1B1EF",NULL},
/* 1B1F0 */ { "NUSHU CHARACTER-1B1F0","	x 53E4"},
/* 1B1F1 */ { "NUSHU CHARACTER-1B1F1",NULL},
/* 1B1F2 */ { "NUSHU CHARACTER-1B1F2",NULL},
/* 1B1F3 */ { "NUSHU CHARACTER-1B1F3",NULL},
/* 1B1F4 */ { "NUSHU CHARACTER-1B1F4",NULL},
/* 1B1F5 */ { "NUSHU CHARACTER-1B1F5",NULL},
/* 1B1F6 */ { "NUSHU CHARACTER-1B1F6",NULL},
/* 1B1F7 */ { "NUSHU CHARACTER-1B1F7",NULL},
/* 1B1F8 */ { "NUSHU CHARACTER-1B1F8",NULL},
/* 1B1F9 */ { "NUSHU CHARACTER-1B1F9",NULL},
/* 1B1FA */ { "NUSHU CHARACTER-1B1FA",NULL},
/* 1B1FB */ { "NUSHU CHARACTER-1B1FB",NULL},
/* 1B1FC */ { "NUSHU CHARACTER-1B1FC",NULL},
/* 1B1FD */ { "NUSHU CHARACTER-1B1FD",NULL},
/* 1B1FE */ { "NUSHU CHARACTER-1B1FE",NULL},
/* 1B1FF */ { "NUSHU CHARACTER-1B1FF",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_B2[] = {
/* 1B200 */ { "NUSHU CHARACTER-1B200",NULL},
/* 1B201 */ { "NUSHU CHARACTER-1B201","	x 591A"},
/* 1B202 */ { "NUSHU CHARACTER-1B202",NULL},
/* 1B203 */ { "NUSHU CHARACTER-1B203",NULL},
/* 1B204 */ { "NUSHU CHARACTER-1B204",NULL},
/* 1B205 */ { "NUSHU CHARACTER-1B205","	x 7532"},
/* 1B206 */ { "NUSHU CHARACTER-1B206",NULL},
/* 1B207 */ { "NUSHU CHARACTER-1B207",NULL},
/* 1B208 */ { "NUSHU CHARACTER-1B208",NULL},
/* 1B209 */ { "NUSHU CHARACTER-1B209",NULL},
/* 1B20A */ { "NUSHU CHARACTER-1B20A","	x 53CC"},
/* 1B20B */ { "NUSHU CHARACTER-1B20B",NULL},
/* 1B20C */ { "NUSHU CHARACTER-1B20C",NULL},
/* 1B20D */ { "NUSHU CHARACTER-1B20D",NULL},
/* 1B20E */ { "NUSHU CHARACTER-1B20E","	x 7530"},
/* 1B20F */ { "NUSHU CHARACTER-1B20F",NULL},
/* 1B210 */ { "NUSHU CHARACTER-1B210",NULL},
/* 1B211 */ { "NUSHU CHARACTER-1B211",NULL},
/* 1B212 */ { "NUSHU CHARACTER-1B212",NULL},
/* 1B213 */ { "NUSHU CHARACTER-1B213","	x 5723"},
/* 1B214 */ { "NUSHU CHARACTER-1B214",NULL},
/* 1B215 */ { "NUSHU CHARACTER-1B215",NULL},
/* 1B216 */ { "NUSHU CHARACTER-1B216","	x 65E9"},
/* 1B217 */ { "NUSHU CHARACTER-1B217",NULL},
/* 1B218 */ { "NUSHU CHARACTER-1B218",NULL},
/* 1B219 */ { "NUSHU CHARACTER-1B219",NULL},
/* 1B21A */ { "NUSHU CHARACTER-1B21A",NULL},
/* 1B21B */ { "NUSHU CHARACTER-1B21B",NULL},
/* 1B21C */ { "NUSHU CHARACTER-1B21C",NULL},
/* 1B21D */ { "NUSHU CHARACTER-1B21D",NULL},
/* 1B21E */ { "NUSHU CHARACTER-1B21E",NULL},
/* 1B21F */ { "NUSHU CHARACTER-1B21F",NULL},
/* 1B220 */ { "NUSHU CHARACTER-1B220",NULL},
/* 1B221 */ { "NUSHU CHARACTER-1B221",NULL},
/* 1B222 */ { "NUSHU CHARACTER-1B222",NULL},
/* 1B223 */ { "NUSHU CHARACTER-1B223",NULL},
/* 1B224 */ { "NUSHU CHARACTER-1B224",NULL},
/* 1B225 */ { "NUSHU CHARACTER-1B225",NULL},
/* 1B226 */ { "NUSHU CHARACTER-1B226",NULL},
/* 1B227 */ { "NUSHU CHARACTER-1B227",NULL},
/* 1B228 */ { "NUSHU CHARACTER-1B228",NULL},
/* 1B229 */ { "NUSHU CHARACTER-1B229",NULL},
/* 1B22A */ { "NUSHU CHARACTER-1B22A",NULL},
/* 1B22B */ { "NUSHU CHARACTER-1B22B",NULL},
/* 1B22C */ { "NUSHU CHARACTER-1B22C",NULL},
/* 1B22D */ { "NUSHU CHARACTER-1B22D",NULL},
/* 1B22E */ { "NUSHU CHARACTER-1B22E","	x 6286"},
/* 1B22F */ { "NUSHU CHARACTER-1B22F",NULL},
/* 1B230 */ { "NUSHU CHARACTER-1B230",NULL},
/* 1B231 */ { "NUSHU CHARACTER-1B231",NULL},
/* 1B232 */ { "NUSHU CHARACTER-1B232",NULL},
/* 1B233 */ { "NUSHU CHARACTER-1B233",NULL},
/* 1B234 */ { "NUSHU CHARACTER-1B234",NULL},
/* 1B235 */ { "NUSHU CHARACTER-1B235",NULL},
/* 1B236 */ { "NUSHU CHARACTER-1B236",NULL},
/* 1B237 */ { "NUSHU CHARACTER-1B237",NULL},
/* 1B238 */ { "NUSHU CHARACTER-1B238",NULL},
/* 1B239 */ { "NUSHU CHARACTER-1B239",NULL},
/* 1B23A */ { "NUSHU CHARACTER-1B23A",NULL},
/* 1B23B */ { "NUSHU CHARACTER-1B23B",NULL},
/* 1B23C */ { "NUSHU CHARACTER-1B23C",NULL},
/* 1B23D */ { "NUSHU CHARACTER-1B23D",NULL},
/* 1B23E */ { "NUSHU CHARACTER-1B23E",NULL},
/* 1B23F */ { "NUSHU CHARACTER-1B23F",NULL},
/* 1B240 */ { "NUSHU CHARACTER-1B240",NULL},
/* 1B241 */ { "NUSHU CHARACTER-1B241",NULL},
/* 1B242 */ { "NUSHU CHARACTER-1B242",NULL},
/* 1B243 */ { "NUSHU CHARACTER-1B243",NULL},
/* 1B244 */ { "NUSHU CHARACTER-1B244","	x 91CC"},
/* 1B245 */ { "NUSHU CHARACTER-1B245",NULL},
/* 1B246 */ { "NUSHU CHARACTER-1B246",NULL},
/* 1B247 */ { "NUSHU CHARACTER-1B247",NULL},
/* 1B248 */ { "NUSHU CHARACTER-1B248",NULL},
/* 1B249 */ { "NUSHU CHARACTER-1B249",NULL},
/* 1B24A */ { "NUSHU CHARACTER-1B24A",NULL},
/* 1B24B */ { "NUSHU CHARACTER-1B24B",NULL},
/* 1B24C */ { "NUSHU CHARACTER-1B24C",NULL},
/* 1B24D */ { "NUSHU CHARACTER-1B24D",NULL},
/* 1B24E */ { "NUSHU CHARACTER-1B24E",NULL},
/* 1B24F */ { "NUSHU CHARACTER-1B24F",NULL},
/* 1B250 */ { "NUSHU CHARACTER-1B250",NULL},
/* 1B251 */ { "NUSHU CHARACTER-1B251",NULL},
/* 1B252 */ { "NUSHU CHARACTER-1B252",NULL},
/* 1B253 */ { "NUSHU CHARACTER-1B253",NULL},
/* 1B254 */ { "NUSHU CHARACTER-1B254",NULL},
/* 1B255 */ { "NUSHU CHARACTER-1B255",NULL},
/* 1B256 */ { "NUSHU CHARACTER-1B256",NULL},
/* 1B257 */ { "NUSHU CHARACTER-1B257",NULL},
/* 1B258 */ { "NUSHU CHARACTER-1B258",NULL},
/* 1B259 */ { "NUSHU CHARACTER-1B259",NULL},
/* 1B25A */ { "NUSHU CHARACTER-1B25A",NULL},
/* 1B25B */ { "NUSHU CHARACTER-1B25B",NULL},
/* 1B25C */ { "NUSHU CHARACTER-1B25C",NULL},
/* 1B25D */ { "NUSHU CHARACTER-1B25D",NULL},
/* 1B25E */ { "NUSHU CHARACTER-1B25E",NULL},
/* 1B25F */ { "NUSHU CHARACTER-1B25F",NULL},
/* 1B260 */ { "NUSHU CHARACTER-1B260",NULL},
/* 1B261 */ { "NUSHU CHARACTER-1B261",NULL},
/* 1B262 */ { "NUSHU CHARACTER-1B262",NULL},
/* 1B263 */ { "NUSHU CHARACTER-1B263",NULL},
/* 1B264 */ { "NUSHU CHARACTER-1B264",NULL},
/* 1B265 */ { "NUSHU CHARACTER-1B265","	x 53F7"},
/* 1B266 */ { "NUSHU CHARACTER-1B266",NULL},
/* 1B267 */ { "NUSHU CHARACTER-1B267",NULL},
/* 1B268 */ { "NUSHU CHARACTER-1B268",NULL},
/* 1B269 */ { "NUSHU CHARACTER-1B269",NULL},
/* 1B26A */ { "NUSHU CHARACTER-1B26A",NULL},
/* 1B26B */ { "NUSHU CHARACTER-1B26B",NULL},
/* 1B26C */ { "NUSHU CHARACTER-1B26C",NULL},
/* 1B26D */ { "NUSHU CHARACTER-1B26D",NULL},
/* 1B26E */ { "NUSHU CHARACTER-1B26E",NULL},
/* 1B26F */ { "NUSHU CHARACTER-1B26F",NULL},
/* 1B270 */ { "NUSHU CHARACTER-1B270",NULL},
/* 1B271 */ { "NUSHU CHARACTER-1B271",NULL},
/* 1B272 */ { "NUSHU CHARACTER-1B272",NULL},
/* 1B273 */ { "NUSHU CHARACTER-1B273",NULL},
/* 1B274 */ { "NUSHU CHARACTER-1B274",NULL},
/* 1B275 */ { "NUSHU CHARACTER-1B275",NULL},
/* 1B276 */ { "NUSHU CHARACTER-1B276",NULL},
/* 1B277 */ { "NUSHU CHARACTER-1B277",NULL},
/* 1B278 */ { "NUSHU CHARACTER-1B278",NULL},
/* 1B279 */ { "NUSHU CHARACTER-1B279",NULL},
/* 1B27A */ { "NUSHU CHARACTER-1B27A",NULL},
/* 1B27B */ { "NUSHU CHARACTER-1B27B",NULL},
/* 1B27C */ { "NUSHU CHARACTER-1B27C",NULL},
/* 1B27D */ { "NUSHU CHARACTER-1B27D",NULL},
/* 1B27E */ { "NUSHU CHARACTER-1B27E",NULL},
/* 1B27F */ { "NUSHU CHARACTER-1B27F",NULL},
/* 1B280 */ { "NUSHU CHARACTER-1B280",NULL},
/* 1B281 */ { "NUSHU CHARACTER-1B281",NULL},
/* 1B282 */ { "NUSHU CHARACTER-1B282",NULL},
/* 1B283 */ { "NUSHU CHARACTER-1B283",NULL},
/* 1B284 */ { "NUSHU CHARACTER-1B284",NULL},
/* 1B285 */ { "NUSHU CHARACTER-1B285",NULL},
/* 1B286 */ { "NUSHU CHARACTER-1B286",NULL},
/* 1B287 */ { "NUSHU CHARACTER-1B287",NULL},
/* 1B288 */ { "NUSHU CHARACTER-1B288",NULL},
/* 1B289 */ { "NUSHU CHARACTER-1B289",NULL},
/* 1B28A */ { "NUSHU CHARACTER-1B28A",NULL},
/* 1B28B */ { "NUSHU CHARACTER-1B28B",NULL},
/* 1B28C */ { "NUSHU CHARACTER-1B28C",NULL},
/* 1B28D */ { "NUSHU CHARACTER-1B28D",NULL},
/* 1B28E */ { "NUSHU CHARACTER-1B28E",NULL},
/* 1B28F */ { "NUSHU CHARACTER-1B28F",NULL},
/* 1B290 */ { "NUSHU CHARACTER-1B290",NULL},
/* 1B291 */ { "NUSHU CHARACTER-1B291",NULL},
/* 1B292 */ { "NUSHU CHARACTER-1B292",NULL},
/* 1B293 */ { "NUSHU CHARACTER-1B293",NULL},
/* 1B294 */ { "NUSHU CHARACTER-1B294",NULL},
/* 1B295 */ { "NUSHU CHARACTER-1B295",NULL},
/* 1B296 */ { "NUSHU CHARACTER-1B296",NULL},
/* 1B297 */ { "NUSHU CHARACTER-1B297",NULL},
/* 1B298 */ { "NUSHU CHARACTER-1B298",NULL},
/* 1B299 */ { "NUSHU CHARACTER-1B299",NULL},
/* 1B29A */ { "NUSHU CHARACTER-1B29A",NULL},
/* 1B29B */ { "NUSHU CHARACTER-1B29B",NULL},
/* 1B29C */ { "NUSHU CHARACTER-1B29C",NULL},
/* 1B29D */ { "NUSHU CHARACTER-1B29D",NULL},
/* 1B29E */ { "NUSHU CHARACTER-1B29E",NULL},
/* 1B29F */ { "NUSHU CHARACTER-1B29F",NULL},
/* 1B2A0 */ { "NUSHU CHARACTER-1B2A0",NULL},
/* 1B2A1 */ { "NUSHU CHARACTER-1B2A1",NULL},
/* 1B2A2 */ { "NUSHU CHARACTER-1B2A2",NULL},
/* 1B2A3 */ { "NUSHU CHARACTER-1B2A3","	x 82F1"},
/* 1B2A4 */ { "NUSHU CHARACTER-1B2A4",NULL},
/* 1B2A5 */ { "NUSHU CHARACTER-1B2A5",NULL},
/* 1B2A6 */ { "NUSHU CHARACTER-1B2A6",NULL},
/* 1B2A7 */ { "NUSHU CHARACTER-1B2A7",NULL},
/* 1B2A8 */ { "NUSHU CHARACTER-1B2A8",NULL},
/* 1B2A9 */ { "NUSHU CHARACTER-1B2A9",NULL},
/* 1B2AA */ { "NUSHU CHARACTER-1B2AA",NULL},
/* 1B2AB */ { "NUSHU CHARACTER-1B2AB",NULL},
/* 1B2AC */ { "NUSHU CHARACTER-1B2AC",NULL},
/* 1B2AD */ { "NUSHU CHARACTER-1B2AD",NULL},
/* 1B2AE */ { "NUSHU CHARACTER-1B2AE",NULL},
/* 1B2AF */ { "NUSHU CHARACTER-1B2AF",NULL},
/* 1B2B0 */ { "NUSHU CHARACTER-1B2B0",NULL},
/* 1B2B1 */ { "NUSHU CHARACTER-1B2B1",NULL},
/* 1B2B2 */ { "NUSHU CHARACTER-1B2B2",NULL},
/* 1B2B3 */ { "NUSHU CHARACTER-1B2B3",NULL},
/* 1B2B4 */ { "NUSHU CHARACTER-1B2B4",NULL},
/* 1B2B5 */ { "NUSHU CHARACTER-1B2B5",NULL},
/* 1B2B6 */ { "NUSHU CHARACTER-1B2B6",NULL},
/* 1B2B7 */ { "NUSHU CHARACTER-1B2B7",NULL},
/* 1B2B8 */ { "NUSHU CHARACTER-1B2B8",NULL},
/* 1B2B9 */ { "NUSHU CHARACTER-1B2B9",NULL},
/* 1B2BA */ { "NUSHU CHARACTER-1B2BA",NULL},
/* 1B2BB */ { "NUSHU CHARACTER-1B2BB",NULL},
/* 1B2BC */ { "NUSHU CHARACTER-1B2BC",NULL},
/* 1B2BD */ { "NUSHU CHARACTER-1B2BD",NULL},
/* 1B2BE */ { "NUSHU CHARACTER-1B2BE",NULL},
/* 1B2BF */ { "NUSHU CHARACTER-1B2BF",NULL},
/* 1B2C0 */ { "NUSHU CHARACTER-1B2C0",NULL},
/* 1B2C1 */ { "NUSHU CHARACTER-1B2C1","	x 9580"},
/* 1B2C2 */ { "NUSHU CHARACTER-1B2C2",NULL},
/* 1B2C3 */ { "NUSHU CHARACTER-1B2C3",NULL},
/* 1B2C4 */ { "NUSHU CHARACTER-1B2C4",NULL},
/* 1B2C5 */ { "NUSHU CHARACTER-1B2C5",NULL},
/* 1B2C6 */ { "NUSHU CHARACTER-1B2C6",NULL},
/* 1B2C7 */ { "NUSHU CHARACTER-1B2C7",NULL},
/* 1B2C8 */ { "NUSHU CHARACTER-1B2C8",NULL},
/* 1B2C9 */ { "NUSHU CHARACTER-1B2C9",NULL},
/* 1B2CA */ { "NUSHU CHARACTER-1B2CA",NULL},
/* 1B2CB */ { "NUSHU CHARACTER-1B2CB",NULL},
/* 1B2CC */ { "NUSHU CHARACTER-1B2CC",NULL},
/* 1B2CD */ { "NUSHU CHARACTER-1B2CD",NULL},
/* 1B2CE */ { "NUSHU CHARACTER-1B2CE",NULL},
/* 1B2CF */ { "NUSHU CHARACTER-1B2CF",NULL},
/* 1B2D0 */ { "NUSHU CHARACTER-1B2D0",NULL},
/* 1B2D1 */ { "NUSHU CHARACTER-1B2D1","	x 57CB"},
/* 1B2D2 */ { "NUSHU CHARACTER-1B2D2",NULL},
/* 1B2D3 */ { "NUSHU CHARACTER-1B2D3",NULL},
/* 1B2D4 */ { "NUSHU CHARACTER-1B2D4",NULL},
/* 1B2D5 */ { "NUSHU CHARACTER-1B2D5",NULL},
/* 1B2D6 */ { "NUSHU CHARACTER-1B2D6","	x 83AB"},
/* 1B2D7 */ { "NUSHU CHARACTER-1B2D7",NULL},
/* 1B2D8 */ { "NUSHU CHARACTER-1B2D8",NULL},
/* 1B2D9 */ { "NUSHU CHARACTER-1B2D9",NULL},
/* 1B2DA */ { "NUSHU CHARACTER-1B2DA",NULL},
/* 1B2DB */ { "NUSHU CHARACTER-1B2DB",NULL},
/* 1B2DC */ { "NUSHU CHARACTER-1B2DC",NULL},
/* 1B2DD */ { "NUSHU CHARACTER-1B2DD",NULL},
/* 1B2DE */ { "NUSHU CHARACTER-1B2DE",NULL},
/* 1B2DF */ { "NUSHU CHARACTER-1B2DF",NULL},
/* 1B2E0 */ { "NUSHU CHARACTER-1B2E0",NULL},
/* 1B2E1 */ { "NUSHU CHARACTER-1B2E1",NULL},
/* 1B2E2 */ { "NUSHU CHARACTER-1B2E2",NULL},
/* 1B2E3 */ { "NUSHU CHARACTER-1B2E3",NULL},
/* 1B2E4 */ { "NUSHU CHARACTER-1B2E4",NULL},
/* 1B2E5 */ { "NUSHU CHARACTER-1B2E5",NULL},
/* 1B2E6 */ { "NUSHU CHARACTER-1B2E6",NULL},
/* 1B2E7 */ { "NUSHU CHARACTER-1B2E7",NULL},
/* 1B2E8 */ { "NUSHU CHARACTER-1B2E8",NULL},
/* 1B2E9 */ { "NUSHU CHARACTER-1B2E9",NULL},
/* 1B2EA */ { "NUSHU CHARACTER-1B2EA",NULL},
/* 1B2EB */ { "NUSHU CHARACTER-1B2EB",NULL},
/* 1B2EC */ { "NUSHU CHARACTER-1B2EC",NULL},
/* 1B2ED */ { "NUSHU CHARACTER-1B2ED",NULL},
/* 1B2EE */ { "NUSHU CHARACTER-1B2EE",NULL},
/* 1B2EF */ { "NUSHU CHARACTER-1B2EF",NULL},
/* 1B2F0 */ { "NUSHU CHARACTER-1B2F0",NULL},
/* 1B2F1 */ { "NUSHU CHARACTER-1B2F1",NULL},
/* 1B2F2 */ { "NUSHU CHARACTER-1B2F2",NULL},
/* 1B2F3 */ { "NUSHU CHARACTER-1B2F3",NULL},
/* 1B2F4 */ { "NUSHU CHARACTER-1B2F4",NULL},
/* 1B2F5 */ { "NUSHU CHARACTER-1B2F5",NULL},
/* 1B2F6 */ { "NUSHU CHARACTER-1B2F6",NULL},
/* 1B2F7 */ { "NUSHU CHARACTER-1B2F7",NULL},
/* 1B2F8 */ { "NUSHU CHARACTER-1B2F8",NULL},
/* 1B2F9 */ { "NUSHU CHARACTER-1B2F9",NULL},
/* 1B2FA */ { "NUSHU CHARACTER-1B2FA",NULL},
/* 1B2FB */ { "NUSHU CHARACTER-1B2FB",NULL},
/* 1B2FC */ { NULL,NULL},
/* 1B2FD */ { NULL,NULL},
/* 1B2FE */ { NULL,NULL},
/* 1B2FF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_BC[] = {
/* 1BC00 */ { "DUPLOYAN LETTER H","	* Chinook, Pernin, Sloan, Perrault"},
/* 1BC01 */ { "DUPLOYAN LETTER X","	* Salishan"},
/* 1BC02 */ { "DUPLOYAN LETTER P","	* Chinook number 1"},
/* 1BC03 */ { "DUPLOYAN LETTER T","	* Chinook number 2"},
/* 1BC04 */ { "DUPLOYAN LETTER F","	* Chinook number 3"},
/* 1BC05 */ { "DUPLOYAN LETTER K","	* written down and to the left\n"
	"	* Chinook number 4"},
/* 1BC06 */ { "DUPLOYAN LETTER L","	* written up and to the right\n"
	"	* Pernin letter R"},
/* 1BC07 */ { "DUPLOYAN LETTER B","	x (duployan affix low vertical secant - 1BC73)\n"
	"	x (duployan affix mid vertical secant - 1BC74)\n"
	"	x (duployan affix high vertical secant - 1BC75)"},
/* 1BC08 */ { "DUPLOYAN LETTER D","	x (duployan affix left horizontal secant - 1BC70)\n"
	"	x (duployan affix mid horizontal secant - 1BC71)\n"
	"	x (duployan affix right horizontal secant - 1BC72)"},
/* 1BC09 */ { "DUPLOYAN LETTER V",NULL},
/* 1BC0A */ { "DUPLOYAN LETTER G","	* written down and to the left"},
/* 1BC0B */ { "DUPLOYAN LETTER R","	* written up and to the right\n"
	"	* Chinook number 5\n"
	"	* French number milliards\n"
	"	* Pernin L\n"
	"	* Pernin Reporters' word repeat sign"},
/* 1BC0C */ { "DUPLOYAN LETTER P N","	* Sloan B B\n"
	"	x (duployan letter p - 1BC02)\n"
	"	x (duployan letter n - 1BC1A)"},
/* 1BC0D */ { "DUPLOYAN LETTER D S","	* Sloan D D\n"
	"	x (duployan letter d - 1BC08)\n"
	"	x (duployan letter s - 1BC1C)"},
/* 1BC0E */ { "DUPLOYAN LETTER F N","	* Sloan V V\n"
	"	x (duployan letter f - 1BC04)\n"
	"	x (duployan letter n - 1BC1A)"},
/* 1BC0F */ { "DUPLOYAN LETTER K M","	* written down and to the left\n"
	"	* Sloan G G\n"
	"	x (duployan letter k - 1BC05)\n"
	"	x (duployan letter m - 1BC19)"},
/* 1BC10 */ { "DUPLOYAN LETTER R S","	* written up and to the right\n"
	"	* Sloan R R\n"
	"	x (duployan letter r - 1BC0B)\n"
	"	x (duployan letter s - 1BC1C)"},
/* 1BC11 */ { "DUPLOYAN LETTER TH","	* Chinook, Sloan, Pernin, Perrault"},
/* 1BC12 */ { "DUPLOYAN LETTER SLOAN DH",NULL},
/* 1BC13 */ { "DUPLOYAN LETTER DH","	* Chinook\n"
	"	x (duployan letter d - 1BC08)"},
/* 1BC14 */ { "DUPLOYAN LETTER KK","	* written down and to the left\n"
	"	* Chinook"},
/* 1BC15 */ { "DUPLOYAN LETTER SLOAN J","	* written down and to the left"},
/* 1BC16 */ { "DUPLOYAN LETTER HL","	* written up and to the right\n"
	"	* Chinook"},
/* 1BC17 */ { "DUPLOYAN LETTER LH","	* written up and to the right\n"
	"	* Chinook"},
/* 1BC18 */ { "DUPLOYAN LETTER RH","	* written up and to the right\n"
	"	* Chinook"},
/* 1BC19 */ { "DUPLOYAN LETTER M","	* Chinook number 6"},
/* 1BC1A */ { "DUPLOYAN LETTER N","	* Chinook number 7"},
/* 1BC1B */ { "DUPLOYAN LETTER J","	* Chinook number 8\n"
	"	* Chinook, Pernin sh"},
/* 1BC1C */ { "DUPLOYAN LETTER S","	* Chinook number 9\n"
	"	* French hundreds"},
/* 1BC1D */ { "DUPLOYAN LETTER M N","	* Romanian mai mult, not Romanian mult mai sign"},
/* 1BC1E */ { "DUPLOYAN LETTER N M","	* not Romanian nu nu sign"},
/* 1BC1F */ { "DUPLOYAN LETTER J M","	* not Romanian ceea ce sign"},
/* 1BC20 */ { "DUPLOYAN LETTER S J","	* not Romanian să se sign"},
/* 1BC21 */ { "DUPLOYAN LETTER M WITH DOT","	* Romanian sign mijloc"},
/* 1BC22 */ { "DUPLOYAN LETTER N WITH DOT","	* Chinook ng\n"
	"	* Romanian sign nici"},
/* 1BC23 */ { "DUPLOYAN LETTER J WITH DOT","	* Chinook ch\n"
	"	* Romanian ce, ci\n"
	"	* Sloan zh\n"
	"	* Chinook, Perrault j"},
/* 1BC24 */ { "DUPLOYAN LETTER J WITH DOTS INSIDE AND ABOVE","	* used in isolation\n"
	"	* Romanian sign ici și colo"},
/* 1BC25 */ { "DUPLOYAN LETTER S WITH DOT","	* Chinook ts\n"
	"	* Chinook, Romanian, Sloan z"},
/* 1BC26 */ { "DUPLOYAN LETTER S WITH DOT BELOW","	* Romanian ș"},
/* 1BC27 */ { "DUPLOYAN LETTER M S","	* Sloan m m"},
/* 1BC28 */ { "DUPLOYAN LETTER N S","	* Pernin, Sloan, Perrault ng"},
/* 1BC29 */ { "DUPLOYAN LETTER J S","	* Romanian ge, gi\n"
	"	* Pernin, Perrault zh\n"
	"	* Sloan ch"},
/* 1BC2A */ { "DUPLOYAN LETTER S S","	* French, Sloan\n"
	"	* Romanian ț\n"
	"	* Pernin, Perrault z"},
/* 1BC2B */ { "DUPLOYAN LETTER M N S",NULL},
/* 1BC2C */ { "DUPLOYAN LETTER N M S",NULL},
/* 1BC2D */ { "DUPLOYAN LETTER J M S",NULL},
/* 1BC2E */ { "DUPLOYAN LETTER S J S",NULL},
/* 1BC2F */ { "DUPLOYAN LETTER J S WITH DOT","	* Sloan hard ch\n"
	"	* Pernin, Perrault ch"},
/* 1BC30 */ { "DUPLOYAN LETTER J N",NULL},
/* 1BC31 */ { "DUPLOYAN LETTER J N S",NULL},
/* 1BC32 */ { "DUPLOYAN LETTER S T","	* Pernin, Perrault\n"
	"	* Sloan sm"},
/* 1BC33 */ { "DUPLOYAN LETTER S T R","	* Pernin, Perrault\n"
	"	* Sloan sn"},
/* 1BC34 */ { "DUPLOYAN LETTER S P","	* Pernin, Perrault\n"
	"	* Sloan kw"},
/* 1BC35 */ { "DUPLOYAN LETTER S P R","	* Pernin, Perrault\n"
	"	* Sloan skw"},
/* 1BC36 */ { "DUPLOYAN LETTER T S","	* Perrault\n"
	"	* Sloan std"},
/* 1BC37 */ { "DUPLOYAN LETTER T R S","	* Perrault\n"
	"	* Sloan sst"},
/* 1BC38 */ { "DUPLOYAN LETTER W","	* Sloan, Perrault, Pernin\n"
	"	* takes form of a hook or wave after k and g"},
/* 1BC39 */ { "DUPLOYAN LETTER WH",NULL},
/* 1BC3A */ { "DUPLOYAN LETTER W R","	* Perrault\n"
	"	* Sloan sw"},
/* 1BC3B */ { "DUPLOYAN LETTER S N","	* Perrault\n"
	"	* Pernin krs\n"
	"	* Sloan sp"},
/* 1BC3C */ { "DUPLOYAN LETTER S M","	* Perrault\n"
	"	* Pernin grs\n"
	"	* Sloan sl"},
/* 1BC3D */ { "DUPLOYAN LETTER K R S","	* Perrault"},
/* 1BC3E */ { "DUPLOYAN LETTER G R S","	* Perrault"},
/* 1BC3F */ { "DUPLOYAN LETTER S K","	* Perrault, Pernin\n"
	"	* Sloan ts"},
/* 1BC40 */ { "DUPLOYAN LETTER S K R","	* Perrault, Pernin\n"
	"	* Sloan ds"},
/* 1BC41 */ { "DUPLOYAN LETTER A","	* Chinook number tens"},
/* 1BC42 */ { "DUPLOYAN LETTER SLOAN OW","	* reverse circle vowel"},
/* 1BC43 */ { "DUPLOYAN LETTER OA","	* Pernin aw\n"
	"	* Perrault aw"},
/* 1BC44 */ { "DUPLOYAN LETTER O","	* Chinook number 0"},
/* 1BC45 */ { "DUPLOYAN LETTER AOU",NULL},
/* 1BC46 */ { "DUPLOYAN LETTER I","	* character rotates to match entry angle of preceding consonant\n"
	"	* primary orientating (right and up)\n"
	"	* Perrault long a, short e (with accents)"},
/* 1BC47 */ { "DUPLOYAN LETTER E","	* character rotates to match entry angle of preceding consonant\n"
	"	* secondary orientating (left and down)\n"
	"	* Sloan long a\n"
	"	* Perrault short i, long e (with dot accent)\n"
	"	x (duployan affix attached e hook - 1BC7A)"},
/* 1BC48 */ { "DUPLOYAN LETTER IE","	* used as an invariant vowel and for orientating word abbreviations consisting of only vowels\n"
	"	* Duployan\n"
	"	* Pernin a"},
/* 1BC49 */ { "DUPLOYAN LETTER SHORT I","	* used as an invariant vowel and for orientating word abbreviations consisting of only vowels\n"
	"	* Pernin, Duployan\n"
	"	* Consolidated Duployan r t r"},
/* 1BC4A */ { "DUPLOYAN LETTER UI","	* used as an invariant vowel and for orientating word abbreviations consisting of only vowels\n"
	"	* Duployan\n"
	"	* Pernin e"},
/* 1BC4B */ { "DUPLOYAN LETTER EE","	* used as an invariant vowel and for orientating word abbreviations consisting of only vowels\n"
	"	* Pernin, Duployan"},
/* 1BC4C */ { "DUPLOYAN LETTER SLOAN EH",NULL},
/* 1BC4D */ { "DUPLOYAN LETTER ROMANIAN I","	* character rotates to match entry angle of preceding consonant, with dot maintaining relative position\n"
	"	* secondary orientating (left and down)"},
/* 1BC4E */ { "DUPLOYAN LETTER SLOAN EE",NULL},
/* 1BC4F */ { "DUPLOYAN LETTER LONG I","	* Pernin\n"
	"	* angles like an \"f\" when adjacent to a k-type consonant"},
/* 1BC50 */ { "DUPLOYAN LETTER YE",NULL},
/* 1BC51 */ { "DUPLOYAN LETTER U","	* character rotates to match entry angle of preceding consonant\n"
	"	* primary orientating (right and up)\n"
	"	* Romanian en\n"
	"	x (duployan letter w - 1BC38)\n"
	"	x (duployan letter romanian u - 1BC56)\n"
	"	x (duployan letter long u - 1BC55)"},
/* 1BC52 */ { "DUPLOYAN LETTER EU","	* character rotates to match entry angle of preceding consonant\n"
	"	* secondary orientating (left and down)\n"
	"	* Romanian an\n"
	"	* in French usage, may be rendered with a dot contextually"},
/* 1BC53 */ { "DUPLOYAN LETTER XW","	* Perrault uh\n"
	"	* not French eu"},
/* 1BC54 */ { "DUPLOYAN LETTER U N","	x (duployan letter n - 1BC1A)"},
/* 1BC55 */ { "DUPLOYAN LETTER LONG U","	* this character does not rotate to match entry angle of preceding consonant\n"
	"	* Pernin, Perrault"},
/* 1BC56 */ { "DUPLOYAN LETTER ROMANIAN U",NULL},
/* 1BC57 */ { "DUPLOYAN LETTER UH","	* Sloan"},
/* 1BC58 */ { "DUPLOYAN LETTER SLOAN U",NULL},
/* 1BC59 */ { "DUPLOYAN LETTER OOH","	* Sloan"},
/* 1BC5A */ { "DUPLOYAN LETTER OW","	* should not be used for Romanian u"},
/* 1BC5B */ { "DUPLOYAN LETTER OU","	* should not be used for Perrault ow\n"
	"	* Chinook letter oo"},
/* 1BC5C */ { "DUPLOYAN LETTER WA","	* Chinook\n"
	"	* Chinook number hundreds\n"
	"	* Perrault oy\n"
	"	* not Romanian o+a"},
/* 1BC5D */ { "DUPLOYAN LETTER WO","	* Chinook"},
/* 1BC5E */ { "DUPLOYAN LETTER WI","	* Chinook"},
/* 1BC5F */ { "DUPLOYAN LETTER WEI","	* Salishan"},
/* 1BC60 */ { "DUPLOYAN LETTER WOW","	* Salishan"},
/* 1BC61 */ { "DUPLOYAN LETTER NASAL U","	* secondary orientating; invariant direction downwards\n"
	"	* French number 1\n"
	"	* Pernin in\n"
	"	* Consolidated Duployan affix int-r-"},
/* 1BC62 */ { "DUPLOYAN LETTER NASAL O","	* secondary orientating; invariant direction upwards\n"
	"	* neutral nasal vowel for transcription of an ambiguous secondary orientating nasal vowel\n"
	"	* Pernin om, im\n"
	"	* Perrault letters an, en, in, un (with accents)\n"
	"	* Consolidated Duployan affix int-r-"},
/* 1BC63 */ { "DUPLOYAN LETTER NASAL I","	* primary orientating; invariant direction downwards\n"
	"	* Pernin im\n"
	"	* Consolidated Duployan affix int-r-"},
/* 1BC64 */ { "DUPLOYAN LETTER NASAL A","	* primary orientating; invariant direction upwards\n"
	"	* neutral nasal vowel for transcription of an ambiguous primary orientating nasal vowel\n"
	"	* Perrault vocalic n - an, en, in, un (with accents)\n"
	"	* Pernin on\n"
	"	* Romanian în\n"
	"	* Romanian multiplicative number prefix"},
/* 1BC65 */ { "DUPLOYAN LETTER PERNIN AN","	* written downwards"},
/* 1BC66 */ { "DUPLOYAN LETTER PERNIN AM","	* written downwards"},
/* 1BC67 */ { "DUPLOYAN LETTER SLOAN EN",NULL},
/* 1BC68 */ { "DUPLOYAN LETTER SLOAN AN",NULL},
/* 1BC69 */ { "DUPLOYAN LETTER SLOAN ON",NULL},
/* 1BC6A */ { "DUPLOYAN LETTER VOCALIC M","	* primary orientating vowel\n"
	"	* Perrault am, em, im, um (with accents)"},
/* 1BC6B */ { NULL,NULL},
/* 1BC6C */ { NULL,NULL},
/* 1BC6D */ { NULL,NULL},
/* 1BC6E */ { NULL,NULL},
/* 1BC6F */ { NULL,NULL},
/* 1BC70 */ { "DUPLOYAN AFFIX LEFT HORIZONTAL SECANT","	* Pernin Reporters' extra-\n"
	"	x (duployan letter d - 1BC08)"},
/* 1BC71 */ { "DUPLOYAN AFFIX MID HORIZONTAL SECANT","	* Pernin Reporters' inter-"},
/* 1BC72 */ { "DUPLOYAN AFFIX RIGHT HORIZONTAL SECANT","	* Pernin Reporters' contra-"},
/* 1BC73 */ { "DUPLOYAN AFFIX LOW VERTICAL SECANT","	* Pernin Reporters' sub-\n"
	"	x (duployan letter b - 1BC07)"},
/* 1BC74 */ { "DUPLOYAN AFFIX MID VERTICAL SECANT","	* Pernin Reporters' trans-"},
/* 1BC75 */ { "DUPLOYAN AFFIX HIGH VERTICAL SECANT","	* Pernin Reporters' super-"},
/* 1BC76 */ { "DUPLOYAN AFFIX ATTACHED SECANT","	* generally crosses adjacent character at perpendicular, but has a bias towards SW/NE angle in contrast to 1BC77\n"
	"	* as a prefix, takes opposite relative position to following glyph\n"
	"	* default neutral secant affix\n"
	"	* French suffix -anse\n"
	"	* Pernin prefix pre-\n"
	"	* Sloan affix ax-/-ext"},
/* 1BC77 */ { "DUPLOYAN AFFIX ATTACHED LEFT-TO-RIGHT SECANT","	* generally crosses adjacent character at perpendicular, but has a bias towards NW/SE angle in contrast to 1BC76\n"
	"	* as a suffix, takes opposite relative position to following glyph\n"
	"	* Pernin prefix per-"},
/* 1BC78 */ { "DUPLOYAN AFFIX ATTACHED TANGENT","	* as a prefix, takes opposite relative position to following glyph\n"
	"	* French suffix -tan\n"
	"	* Romanian str-/-str"},
/* 1BC79 */ { "DUPLOYAN AFFIX ATTACHED TAIL","	* orientating character\n"
	"	* French suffix -sionnaire"},
/* 1BC7A */ { "DUPLOYAN AFFIX ATTACHED E HOOK","	* glyph is retrograde and opens up or down, depending on preceding letter\n"
	"	* French suffix -te\n"
	"	x (duployan letter e - 1BC47)"},
/* 1BC7B */ { "DUPLOYAN AFFIX ATTACHED I HOOK","	* glyph is retrograde and opens left or right, depending on preceding letter\n"
	"	* French suffix -tou\n"
	"	* Sloan affix irre-/-ary\n"
	"	x (duployan letter i - 1BC46)"},
/* 1BC7C */ { "DUPLOYAN AFFIX ATTACHED TANGENT HOOK","	* attached affix\n"
	"	* Romanian affix ist-/-ism\n"
	"	* Consolidated Duployan prefix t-r-"},
/* 1BC7D */ { NULL,NULL},
/* 1BC7E */ { NULL,NULL},
/* 1BC7F */ { NULL,NULL},
/* 1BC80 */ { "DUPLOYAN AFFIX HIGH ACUTE","	* French suffix -ment\n"
	"	* Romanian suffix -mant\n"
	"	* Pernin sub-\n"
	"	* Pernin Reporters' prefix pro-\n"
	"	x (modifier letter acute accent - 02CA)"},
/* 1BC81 */ { "DUPLOYAN AFFIX HIGH TIGHT ACUTE","	* as a suffix, placed above and to the right of the following letter\n"
	"	* Pernin Pro-"},
/* 1BC82 */ { "DUPLOYAN AFFIX HIGH GRAVE","	* French suffix -ien\n"
	"	* Pernin prefix con-\n"
	"	x (modifier letter grave accent - 02CB)"},
/* 1BC83 */ { "DUPLOYAN AFFIX HIGH LONG GRAVE","	* Pernin prefix contra-"},
/* 1BC84 */ { "DUPLOYAN AFFIX HIGH DOT","	* French number thousands\n"
	"	* French suffix -eur\n"
	"	* Romanian affix trans-/-lui\n"
	"	* not Romanian hundreds - use 0307 combining dot above and 0308 combining diaeresis\n"
	"	x (dot above - 02D9)"},
/* 1BC85 */ { "DUPLOYAN AFFIX HIGH CIRCLE","	* French ordinal number\n"
	"	* French suffix -euse\n"
	"	* not Romanian number grade or percent suffix\n"
	"	x (degree sign - 00B0)\n"
	"	x (ring above - 02DA)"},
/* 1BC86 */ { "DUPLOYAN AFFIX HIGH LINE","	* French suffix -iste\n"
	"	* Romanian affix -tor\n"
	"	* Pernin affix dis-\n"
	"	x (modifier letter macron - 02C9)"},
/* 1BC87 */ { "DUPLOYAN AFFIX HIGH WAVE","	* French suffix -ificatif\n"
	"	x (small tilde - 02DC)"},
/* 1BC88 */ { "DUPLOYAN AFFIX HIGH VERTICAL","	* also functions as attached affix vertical up with ZWJ\n"
	"	* about half as long as Duployan letter p\n"
	"	* as a prefix, has falling stroke direction\n"
	"	* Pernin ZWJ + -ime\n"
	"	* Sloan tele-\n"
	"	x (duployan letter p - 1BC02)"},
/* 1BC89 */ { NULL,NULL},
/* 1BC8A */ { NULL,NULL},
/* 1BC8B */ { NULL,NULL},
/* 1BC8C */ { NULL,NULL},
/* 1BC8D */ { NULL,NULL},
/* 1BC8E */ { NULL,NULL},
/* 1BC8F */ { NULL,NULL},
/* 1BC90 */ { "DUPLOYAN AFFIX LOW ACUTE","	* French suffix -cion\n"
	"	* Pernin prefix ex-\n"
	"	x (modifier letter low acute accent - 02CF)"},
/* 1BC91 */ { "DUPLOYAN AFFIX LOW TIGHT ACUTE","	* as a suffix, placed under and to the right of the following letter\n"
	"	* Pernin suf-, sug-"},
/* 1BC92 */ { "DUPLOYAN AFFIX LOW GRAVE","	* French suffix -ion\n"
	"	* French number millions\n"
	"	x (modifier letter low grave accent - 02CE)"},
/* 1BC93 */ { "DUPLOYAN AFFIX LOW LONG GRAVE","	* Pernin extra-"},
/* 1BC94 */ { "DUPLOYAN AFFIX LOW DOT","	* French suffix -ié\n"
	"	* French iterative number\n"
	"	* Romanian affix inter-\n"
	"	* not Romanian millions - see 0323 combining dot below and 0324 combining diaeresis below"},
/* 1BC95 */ { "DUPLOYAN AFFIX LOW CIRCLE","	* French suffix -ière\n"
	"	* French percent\n"
	"	x (modifier letter low ring - 02F3)"},
/* 1BC96 */ { "DUPLOYAN AFFIX LOW LINE","	* French suffix -isme\n"
	"	* Pernin affix mis-\n"
	"	x (modifier letter minus sign - 02D7)"},
/* 1BC97 */ { "DUPLOYAN AFFIX LOW WAVE","	* French suffix -ification\n"
	"	x (modifier letter low tilde - 02F7)"},
/* 1BC98 */ { "DUPLOYAN AFFIX LOW VERTICAL","	* functions as attached affix vertical down with ZWJ\n"
	"	* about half as long as the Duployan letter p\n"
	"	* as a prefix, has rising stroke direction\n"
	"	* Pernin ZWJ + -ine\n"
	"	x (duployan letter p - 1BC02)"},
/* 1BC99 */ { "DUPLOYAN AFFIX LOW ARROW","	* Romanian prefix sub-"},
/* 1BC9A */ { NULL,NULL},
/* 1BC9B */ { NULL,NULL},
/* 1BC9C */ { "DUPLOYAN SIGN O WITH CROSS","	* Chinook Likalisti"},
/* 1BC9D */ { "DUPLOYAN THICK LETTER SELECTOR",NULL},
/* 1BC9E */ { "DUPLOYAN DOUBLE MARK","	* Romanian, Sloan\n"
	"	* should be used with m, n, j, and s for the Romanian word signs mai mult, nu nu, ceea ce, and să se\n"
	"	* can be doubled and tripled"},
/* 1BC9F */ { "DUPLOYAN PUNCTUATION CHINOOK FULL STOP",NULL},
/* 1BCA0 */ { "SHORTHAND FORMAT LETTER OVERLAP",NULL},
/* 1BCA1 */ { "SHORTHAND FORMAT CONTINUING OVERLAP",NULL},
/* 1BCA2 */ { "SHORTHAND FORMAT DOWN STEP","	= Romanian affix -tsion-\n"
	"	= Sloan contracted ending oo/o + ZWSP"},
/* 1BCA3 */ { "SHORTHAND FORMAT UP STEP","	= Sloan contracted ending uh/au/aui + ZWSP"},
/* 1BCA4 */ { NULL,NULL},
/* 1BCA5 */ { NULL,NULL},
/* 1BCA6 */ { NULL,NULL},
/* 1BCA7 */ { NULL,NULL},
/* 1BCA8 */ { NULL,NULL},
/* 1BCA9 */ { NULL,NULL},
/* 1BCAA */ { NULL,NULL},
/* 1BCAB */ { NULL,NULL},
/* 1BCAC */ { NULL,NULL},
/* 1BCAD */ { NULL,NULL},
/* 1BCAE */ { NULL,NULL},
/* 1BCAF */ { NULL,NULL},
/* 1BCB0 */ { NULL,NULL},
/* 1BCB1 */ { NULL,NULL},
/* 1BCB2 */ { NULL,NULL},
/* 1BCB3 */ { NULL,NULL},
/* 1BCB4 */ { NULL,NULL},
/* 1BCB5 */ { NULL,NULL},
/* 1BCB6 */ { NULL,NULL},
/* 1BCB7 */ { NULL,NULL},
/* 1BCB8 */ { NULL,NULL},
/* 1BCB9 */ { NULL,NULL},
/* 1BCBA */ { NULL,NULL},
/* 1BCBB */ { NULL,NULL},
/* 1BCBC */ { NULL,NULL},
/* 1BCBD */ { NULL,NULL},
/* 1BCBE */ { NULL,NULL},
/* 1BCBF */ { NULL,NULL},
/* 1BCC0 */ { NULL,NULL},
/* 1BCC1 */ { NULL,NULL},
/* 1BCC2 */ { NULL,NULL},
/* 1BCC3 */ { NULL,NULL},
/* 1BCC4 */ { NULL,NULL},
/* 1BCC5 */ { NULL,NULL},
/* 1BCC6 */ { NULL,NULL},
/* 1BCC7 */ { NULL,NULL},
/* 1BCC8 */ { NULL,NULL},
/* 1BCC9 */ { NULL,NULL},
/* 1BCCA */ { NULL,NULL},
/* 1BCCB */ { NULL,NULL},
/* 1BCCC */ { NULL,NULL},
/* 1BCCD */ { NULL,NULL},
/* 1BCCE */ { NULL,NULL},
/* 1BCCF */ { NULL,NULL},
/* 1BCD0 */ { NULL,NULL},
/* 1BCD1 */ { NULL,NULL},
/* 1BCD2 */ { NULL,NULL},
/* 1BCD3 */ { NULL,NULL},
/* 1BCD4 */ { NULL,NULL},
/* 1BCD5 */ { NULL,NULL},
/* 1BCD6 */ { NULL,NULL},
/* 1BCD7 */ { NULL,NULL},
/* 1BCD8 */ { NULL,NULL},
/* 1BCD9 */ { NULL,NULL},
/* 1BCDA */ { NULL,NULL},
/* 1BCDB */ { NULL,NULL},
/* 1BCDC */ { NULL,NULL},
/* 1BCDD */ { NULL,NULL},
/* 1BCDE */ { NULL,NULL},
/* 1BCDF */ { NULL,NULL},
/* 1BCE0 */ { NULL,NULL},
/* 1BCE1 */ { NULL,NULL},
/* 1BCE2 */ { NULL,NULL},
/* 1BCE3 */ { NULL,NULL},
/* 1BCE4 */ { NULL,NULL},
/* 1BCE5 */ { NULL,NULL},
/* 1BCE6 */ { NULL,NULL},
/* 1BCE7 */ { NULL,NULL},
/* 1BCE8 */ { NULL,NULL},
/* 1BCE9 */ { NULL,NULL},
/* 1BCEA */ { NULL,NULL},
/* 1BCEB */ { NULL,NULL},
/* 1BCEC */ { NULL,NULL},
/* 1BCED */ { NULL,NULL},
/* 1BCEE */ { NULL,NULL},
/* 1BCEF */ { NULL,NULL},
/* 1BCF0 */ { NULL,NULL},
/* 1BCF1 */ { NULL,NULL},
/* 1BCF2 */ { NULL,NULL},
/* 1BCF3 */ { NULL,NULL},
/* 1BCF4 */ { NULL,NULL},
/* 1BCF5 */ { NULL,NULL},
/* 1BCF6 */ { NULL,NULL},
/* 1BCF7 */ { NULL,NULL},
/* 1BCF8 */ { NULL,NULL},
/* 1BCF9 */ { NULL,NULL},
/* 1BCFA */ { NULL,NULL},
/* 1BCFB */ { NULL,NULL},
/* 1BCFC */ { NULL,NULL},
/* 1BCFD */ { NULL,NULL},
/* 1BCFE */ { NULL,NULL},
/* 1BCFF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_CC[] = {
/* 1CC00 */ { "UP-POINTING GO-KART",NULL},
/* 1CC01 */ { "RIGHT-POINTING GO-KART",NULL},
/* 1CC02 */ { "LEFT-POINTING STICK FIGURE",NULL},
/* 1CC03 */ { "RIGHT-POINTING STICK FIGURE",NULL},
/* 1CC04 */ { "DOWN-POINTING STICK FIGURE",NULL},
/* 1CC05 */ { "LOWER HORIZONTAL RULER SEGMENT",NULL},
/* 1CC06 */ { "RIGHT VERTICAL RULER SEGMENT",NULL},
/* 1CC07 */ { "LOWER RIGHT RULER SEGMENT",NULL},
/* 1CC08 */ { "ANTENNA",NULL},
/* 1CC09 */ { "HORIZONTAL RESISTOR SEGMENT",NULL},
/* 1CC0A */ { "VERTICAL RESISTOR SEGMENT",NULL},
/* 1CC0B */ { "LEFT THIRD INDUCTOR",NULL},
/* 1CC0C */ { "MIDDLE THIRD INDUCTOR",NULL},
/* 1CC0D */ { "RIGHT THIRD INDUCTOR",NULL},
/* 1CC0E */ { "LEFT-POINTING DIODE",NULL},
/* 1CC0F */ { "RIGHT-POINTING DIODE",NULL},
/* 1CC10 */ { "NPN TRANSISTOR",NULL},
/* 1CC11 */ { "PNP TRANSISTOR",NULL},
/* 1CC12 */ { "RECEPTACLE",NULL},
/* 1CC13 */ { "HORIZONTAL CAPACITOR",NULL},
/* 1CC14 */ { "VERTICAL CAPACITOR",NULL},
/* 1CC15 */ { "LOGIC GATE OR",NULL},
/* 1CC16 */ { "LOGIC GATE AND",NULL},
/* 1CC17 */ { "LOGIC GATE INVERTED INPUTS",NULL},
/* 1CC18 */ { "LOGIC GATE INVERTED OUTPUT",NULL},
/* 1CC19 */ { "LOGIC GATE BUFFER",NULL},
/* 1CC1A */ { "LOGIC GATE BUFFER WITH INVERTED INPUT",NULL},
/* 1CC1B */ { "BOX DRAWINGS LIGHT HORIZONTAL AND UPPER RIGHT",NULL},
/* 1CC1C */ { "BOX DRAWINGS LIGHT HORIZONTAL AND LOWER RIGHT",NULL},
/* 1CC1D */ { "BOX DRAWINGS LIGHT TOP AND UPPER LEFT",NULL},
/* 1CC1E */ { "BOX DRAWINGS LIGHT BOTTOM AND LOWER LEFT",NULL},
/* 1CC1F */ { "BOX DRAWINGS DOUBLE DIAGONAL UPPER RIGHT TO LOWER LEFT",NULL},
/* 1CC20 */ { "BOX DRAWINGS DOUBLE DIAGONAL UPPER LEFT TO LOWER RIGHT",NULL},
/* 1CC21 */ { "SEPARATED BLOCK QUADRANT-1",NULL},
/* 1CC22 */ { "SEPARATED BLOCK QUADRANT-2",NULL},
/* 1CC23 */ { "SEPARATED BLOCK QUADRANT-12",NULL},
/* 1CC24 */ { "SEPARATED BLOCK QUADRANT-3",NULL},
/* 1CC25 */ { "SEPARATED BLOCK QUADRANT-13",NULL},
/* 1CC26 */ { "SEPARATED BLOCK QUADRANT-23",NULL},
/* 1CC27 */ { "SEPARATED BLOCK QUADRANT-123",NULL},
/* 1CC28 */ { "SEPARATED BLOCK QUADRANT-4",NULL},
/* 1CC29 */ { "SEPARATED BLOCK QUADRANT-14",NULL},
/* 1CC2A */ { "SEPARATED BLOCK QUADRANT-24",NULL},
/* 1CC2B */ { "SEPARATED BLOCK QUADRANT-124",NULL},
/* 1CC2C */ { "SEPARATED BLOCK QUADRANT-34",NULL},
/* 1CC2D */ { "SEPARATED BLOCK QUADRANT-134",NULL},
/* 1CC2E */ { "SEPARATED BLOCK QUADRANT-234",NULL},
/* 1CC2F */ { "SEPARATED BLOCK QUADRANT-1234",NULL},
/* 1CC30 */ { "UPPER LEFT TWELFTH CIRCLE",NULL},
/* 1CC31 */ { "UPPER CENTRE LEFT TWELFTH CIRCLE",NULL},
/* 1CC32 */ { "UPPER CENTRE RIGHT TWELFTH CIRCLE",NULL},
/* 1CC33 */ { "UPPER RIGHT TWELFTH CIRCLE",NULL},
/* 1CC34 */ { "UPPER MIDDLE LEFT TWELFTH CIRCLE",NULL},
/* 1CC35 */ { "UPPER LEFT QUARTER CIRCLE",NULL},
/* 1CC36 */ { "UPPER RIGHT QUARTER CIRCLE",NULL},
/* 1CC37 */ { "UPPER MIDDLE RIGHT TWELFTH CIRCLE",NULL},
/* 1CC38 */ { "LOWER MIDDLE LEFT TWELFTH CIRCLE",NULL},
/* 1CC39 */ { "LOWER LEFT QUARTER CIRCLE",NULL},
/* 1CC3A */ { "LOWER RIGHT QUARTER CIRCLE",NULL},
/* 1CC3B */ { "LOWER MIDDLE RIGHT TWELFTH CIRCLE",NULL},
/* 1CC3C */ { "LOWER LEFT TWELFTH CIRCLE",NULL},
/* 1CC3D */ { "LOWER CENTRE LEFT TWELFTH CIRCLE",NULL},
/* 1CC3E */ { "LOWER CENTRE RIGHT TWELFTH CIRCLE",NULL},
/* 1CC3F */ { "LOWER RIGHT TWELFTH CIRCLE",NULL},
/* 1CC40 */ { "SPARSE HORIZONTAL FILL",NULL},
/* 1CC41 */ { "SPARSE VERTICAL FILL",NULL},
/* 1CC42 */ { "ORTHOGONAL CROSSHATCH FILL",NULL},
/* 1CC43 */ { "DIAGONAL CROSSHATCH FILL",NULL},
/* 1CC44 */ { "DENSE VERTICAL FILL",NULL},
/* 1CC45 */ { "DENSE HORIZONTAL FILL",NULL},
/* 1CC46 */ { "SPECKLE FILL FRAME-1",NULL},
/* 1CC47 */ { "SPECKLE FILL FRAME-2",NULL},
/* 1CC48 */ { "LEFT-FACING BASSINET",NULL},
/* 1CC49 */ { "RIGHT-FACING BASSINET",NULL},
/* 1CC4A */ { "FLYING SAUCER WITH BEAMS",NULL},
/* 1CC4B */ { "FLYING SAUCER WITHOUT BEAMS",NULL},
/* 1CC4C */ { "ALIEN MONSTER OPEN JAWS",NULL},
/* 1CC4D */ { "ALIEN MONSTER CLOSED JAWS",NULL},
/* 1CC4E */ { "ALIEN SQUID OPEN TENTACLES",NULL},
/* 1CC4F */ { "ALIEN SQUID CLOSED TENTACLES",NULL},
/* 1CC50 */ { "ALIEN CRAB STEPPING RIGHT",NULL},
/* 1CC51 */ { "ALIEN CRAB STEPPING LEFT",NULL},
/* 1CC52 */ { "ALIEN SPIDER CROUCHING",NULL},
/* 1CC53 */ { "ALIEN SPIDER SPREAD",NULL},
/* 1CC54 */ { "ALIEN MONSTER STEP-1",NULL},
/* 1CC55 */ { "ALIEN MONSTER STEP-2",NULL},
/* 1CC56 */ { "LEFT-POINTING ROCKET SHIP",NULL},
/* 1CC57 */ { "UP-POINTING ROCKET SHIP",NULL},
/* 1CC58 */ { "RIGHT-POINTING ROCKET SHIP",NULL},
/* 1CC59 */ { "DOWN-POINTING ROCKET SHIP",NULL},
/* 1CC5A */ { "TOP HALF LEFT-FACING ROBOT",NULL},
/* 1CC5B */ { "TOP HALF FORWARD-FACING ROBOT",NULL},
/* 1CC5C */ { "TOP HALF RIGHT-FACING ROBOT",NULL},
/* 1CC5D */ { "BOTTOM HALF LEFT-FACING ROBOT",NULL},
/* 1CC5E */ { "BOTTOM HALF FORWARD-FACING ROBOT",NULL},
/* 1CC5F */ { "BOTTOM HALF RIGHT-FACING ROBOT",NULL},
/* 1CC60 */ { "LEFT-POINTING ATOMIC BOMB",NULL},
/* 1CC61 */ { "UP-POINTING ATOMIC BOMB",NULL},
/* 1CC62 */ { "RIGHT-POINTING ATOMIC BOMB",NULL},
/* 1CC63 */ { "DOWN-POINTING ATOMIC BOMB",NULL},
/* 1CC64 */ { "MUSHROOM CLOUD",NULL},
/* 1CC65 */ { "LEFT-POINTING RIFLE",NULL},
/* 1CC66 */ { "UP-POINTING RIFLE",NULL},
/* 1CC67 */ { "RIGHT-POINTING RIFLE",NULL},
/* 1CC68 */ { "DOWN-POINTING RIFLE",NULL},
/* 1CC69 */ { "EIGHT RAYS INWARD",NULL},
/* 1CC6A */ { "EIGHT RAYS OUTWARD",NULL},
/* 1CC6B */ { "BLACK LARGE CIRCLE MINUS LEFT QUARTER SECTION",NULL},
/* 1CC6C */ { "BLACK LARGE CIRCLE MINUS UPPER QUARTER SECTION",NULL},
/* 1CC6D */ { "BLACK LARGE CIRCLE MINUS RIGHT QUARTER SECTION",NULL},
/* 1CC6E */ { "BLACK LARGE CIRCLE MINUS LOWER QUARTER SECTION",NULL},
/* 1CC6F */ { "BLACK NEUTRAL FACE",NULL},
/* 1CC70 */ { "LEFT-FACING SNAKE HEAD WITH OPEN MOUTH",NULL},
/* 1CC71 */ { "UP-FACING SNAKE HEAD WITH OPEN MOUTH",NULL},
/* 1CC72 */ { "RIGHT-FACING SNAKE HEAD WITH OPEN MOUTH",NULL},
/* 1CC73 */ { "DOWN-FACING SNAKE HEAD WITH OPEN MOUTH",NULL},
/* 1CC74 */ { "LEFT-FACING SNAKE HEAD WITH CLOSED MOUTH",NULL},
/* 1CC75 */ { "UP-FACING SNAKE HEAD WITH CLOSED MOUTH",NULL},
/* 1CC76 */ { "RIGHT-FACING SNAKE HEAD WITH CLOSED MOUTH",NULL},
/* 1CC77 */ { "DOWN-FACING SNAKE HEAD WITH CLOSED MOUTH",NULL},
/* 1CC78 */ { "LEFT-POINTING ENERGY WAVE",NULL},
/* 1CC79 */ { "UP-POINTING ENERGY WAVE",NULL},
/* 1CC7A */ { "RIGHT-POINTING ENERGY WAVE",NULL},
/* 1CC7B */ { "DOWN-POINTING ENERGY WAVE",NULL},
/* 1CC7C */ { "SQUARE SPIRAL FROM TOP LEFT",NULL},
/* 1CC7D */ { "SQUARE SPIRAL FROM TOP RIGHT",NULL},
/* 1CC7E */ { "SQUARE SPIRAL FROM BOTTOM RIGHT",NULL},
/* 1CC7F */ { "SQUARE SPIRAL FROM BOTTOM LEFT",NULL},
/* 1CC80 */ { "STRIPED LEFT-POINTING TRIANGLE",NULL},
/* 1CC81 */ { "STRIPED UP-POINTING TRIANGLE",NULL},
/* 1CC82 */ { "STRIPED RIGHT-POINTING TRIANGLE",NULL},
/* 1CC83 */ { "STRIPED DOWN-POINTING TRIANGLE",NULL},
/* 1CC84 */ { "VERTICAL LADDER",NULL},
/* 1CC85 */ { "HORIZONTAL LADDER",NULL},
/* 1CC86 */ { "WHITE LOWER LEFT POINTER",NULL},
/* 1CC87 */ { "WHITE LOWER RIGHT POINTER",NULL},
/* 1CC88 */ { "TWO RINGS ALIGNED HORIZONTALLY","	x (united symbol - 2BFA)"},
/* 1CC89 */ { "SQUARE FOUR CORNER SALTIRES",NULL},
/* 1CC8A */ { "SQUARE FOUR CORNER DIAGONALS",NULL},
/* 1CC8B */ { "SQUARE FOUR CORNER BLACK TRIANGLES",NULL},
/* 1CC8C */ { "SQUARE APERTURE",NULL},
/* 1CC8D */ { "INVERSE BLACK DIAMOND",NULL},
/* 1CC8E */ { "LEFT AND UPPER ONE EIGHTH BLOCK CONTAINING BLACK SMALL SQUARE",NULL},
/* 1CC8F */ { "INVERSE BLACK SMALL SQUARE",NULL},
/* 1CC90 */ { "VERTICAL LINE WITH FOUR TICK MARKS",NULL},
/* 1CC91 */ { "HORIZONTAL LINE WITH FOUR TICK MARKS",NULL},
/* 1CC92 */ { "LEFT-FACING FISH",NULL},
/* 1CC93 */ { "RIGHT-FACING FISH",NULL},
/* 1CC94 */ { "LEFT-FACING FISH WITH OPEN MOUTH",NULL},
/* 1CC95 */ { "RIGHT-FACING FISH WITH OPEN MOUTH",NULL},
/* 1CC96 */ { "FLAPPING BIRD",NULL},
/* 1CC97 */ { "LEFT-POINTING RACING CAR",NULL},
/* 1CC98 */ { "UP-POINTING RACING CAR",NULL},
/* 1CC99 */ { "RIGHT-POINTING RACING CAR",NULL},
/* 1CC9A */ { "DOWN-POINTING RACING CAR",NULL},
/* 1CC9B */ { "HORIZONTAL RACING CAR",NULL},
/* 1CC9C */ { "VERTICAL RACING CAR",NULL},
/* 1CC9D */ { "VERTICAL GO-KART",NULL},
/* 1CC9E */ { "LEFT-POINTING TANK",NULL},
/* 1CC9F */ { "RIGHT-POINTING TANK",NULL},
/* 1CCA0 */ { "LEFT-POINTING ROCKET BOOSTER",NULL},
/* 1CCA1 */ { "RIGHT-POINTING ROCKET BOOSTER",NULL},
/* 1CCA2 */ { "LEFT-POINTING ROLLER COASTER CAR",NULL},
/* 1CCA3 */ { "RIGHT-POINTING ROLLER COASTER CAR",NULL},
/* 1CCA4 */ { "LEFT HALF FLYING SAUCER",NULL},
/* 1CCA5 */ { "RIGHT HALF FLYING SAUCER",NULL},
/* 1CCA6 */ { "UPPER LEFT QUADRANT FACE WITH OPEN EYES",NULL},
/* 1CCA7 */ { "UPPER RIGHT QUADRANT FACE WITH OPEN EYES",NULL},
/* 1CCA8 */ { "UPPER LEFT QUADRANT FACE WITH CLOSED EYES",NULL},
/* 1CCA9 */ { "UPPER RIGHT QUADRANT FACE WITH CLOSED EYES",NULL},
/* 1CCAA */ { "LOWER LEFT QUADRANT SMILING FACE",NULL},
/* 1CCAB */ { "LOWER RIGHT QUADRANT SMILING FACE",NULL},
/* 1CCAC */ { "LOWER LEFT QUADRANT NEUTRAL FACE",NULL},
/* 1CCAD */ { "LOWER RIGHT QUADRANT NEUTRAL FACE",NULL},
/* 1CCAE */ { "LOWER LEFT QUADRANT FACE WITH OPEN MOUTH",NULL},
/* 1CCAF */ { "LOWER RIGHT QUADRANT FACE WITH OPEN MOUTH",NULL},
/* 1CCB0 */ { "LOWER LEFT QUADRANT FROWNING FACE",NULL},
/* 1CCB1 */ { "LOWER RIGHT QUADRANT FROWNING FACE",NULL},
/* 1CCB2 */ { "UPPER LEFT QUADRANT TELEVISION",NULL},
/* 1CCB3 */ { "UPPER RIGHT QUADRANT TELEVISION",NULL},
/* 1CCB4 */ { "LOWER LEFT QUADRANT TELEVISION",NULL},
/* 1CCB5 */ { "LOWER RIGHT QUADRANT TELEVISION",NULL},
/* 1CCB6 */ { "UPPER LEFT QUADRANT MICROCOMPUTER",NULL},
/* 1CCB7 */ { "UPPER RIGHT QUADRANT MICROCOMPUTER",NULL},
/* 1CCB8 */ { "LOWER LEFT QUADRANT MICROCOMPUTER",NULL},
/* 1CCB9 */ { "LOWER RIGHT QUADRANT MICROCOMPUTER",NULL},
/* 1CCBA */ { "UPPER LEFT QUADRANT CHESS KING",NULL},
/* 1CCBB */ { "UPPER RIGHT QUADRANT CHESS KING",NULL},
/* 1CCBC */ { "LOWER LEFT QUADRANT CHESS KING",NULL},
/* 1CCBD */ { "LOWER RIGHT QUADRANT CHESS KING",NULL},
/* 1CCBE */ { "UPPER LEFT QUADRANT CHESS QUEEN",NULL},
/* 1CCBF */ { "UPPER RIGHT QUADRANT CHESS QUEEN",NULL},
/* 1CCC0 */ { "LOWER LEFT QUADRANT CHESS QUEEN",NULL},
/* 1CCC1 */ { "LOWER RIGHT QUADRANT CHESS QUEEN",NULL},
/* 1CCC2 */ { "UPPER LEFT QUADRANT CHESS ROOK",NULL},
/* 1CCC3 */ { "UPPER RIGHT QUADRANT CHESS ROOK",NULL},
/* 1CCC4 */ { "LOWER LEFT QUADRANT CHESS ROOK",NULL},
/* 1CCC5 */ { "LOWER RIGHT QUADRANT CHESS ROOK",NULL},
/* 1CCC6 */ { "UPPER LEFT QUADRANT CHESS BISHOP",NULL},
/* 1CCC7 */ { "UPPER RIGHT QUADRANT CHESS BISHOP",NULL},
/* 1CCC8 */ { "LOWER LEFT QUADRANT CHESS BISHOP",NULL},
/* 1CCC9 */ { "LOWER RIGHT QUADRANT CHESS BISHOP",NULL},
/* 1CCCA */ { "UPPER LEFT QUADRANT CHESS KNIGHT",NULL},
/* 1CCCB */ { "UPPER RIGHT QUADRANT CHESS KNIGHT",NULL},
/* 1CCCC */ { "LOWER LEFT QUADRANT CHESS KNIGHT",NULL},
/* 1CCCD */ { "LOWER RIGHT QUADRANT CHESS KNIGHT",NULL},
/* 1CCCE */ { "UPPER LEFT QUADRANT CHESS PAWN",NULL},
/* 1CCCF */ { "UPPER RIGHT QUADRANT CHESS PAWN",NULL},
/* 1CCD0 */ { "LOWER LEFT QUADRANT CHESS PAWN",NULL},
/* 1CCD1 */ { "LOWER RIGHT QUADRANT CHESS PAWN",NULL},
/* 1CCD2 */ { "UPPER LEFT QUADRANT STANDING KNIGHT",NULL},
/* 1CCD3 */ { "UPPER RIGHT QUADRANT STANDING KNIGHT",NULL},
/* 1CCD4 */ { "LOWER LEFT QUADRANT STANDING KNIGHT",NULL},
/* 1CCD5 */ { "LOWER RIGHT QUADRANT STANDING KNIGHT",NULL},
/* 1CCD6 */ { "OUTLINED LATIN CAPITAL LETTER A","	# <font> 0041 latin capital letter a"},
/* 1CCD7 */ { "OUTLINED LATIN CAPITAL LETTER B","	# <font> 0042 latin capital letter b"},
/* 1CCD8 */ { "OUTLINED LATIN CAPITAL LETTER C","	# <font> 0043 latin capital letter c"},
/* 1CCD9 */ { "OUTLINED LATIN CAPITAL LETTER D","	# <font> 0044 latin capital letter d"},
/* 1CCDA */ { "OUTLINED LATIN CAPITAL LETTER E","	# <font> 0045 latin capital letter e"},
/* 1CCDB */ { "OUTLINED LATIN CAPITAL LETTER F","	# <font> 0046 latin capital letter f"},
/* 1CCDC */ { "OUTLINED LATIN CAPITAL LETTER G","	# <font> 0047 latin capital letter g"},
/* 1CCDD */ { "OUTLINED LATIN CAPITAL LETTER H","	# <font> 0048 latin capital letter h"},
/* 1CCDE */ { "OUTLINED LATIN CAPITAL LETTER I","	# <font> 0049 latin capital letter i"},
/* 1CCDF */ { "OUTLINED LATIN CAPITAL LETTER J","	# <font> 004A latin capital letter j"},
/* 1CCE0 */ { "OUTLINED LATIN CAPITAL LETTER K","	# <font> 004B latin capital letter k"},
/* 1CCE1 */ { "OUTLINED LATIN CAPITAL LETTER L","	# <font> 004C latin capital letter l"},
/* 1CCE2 */ { "OUTLINED LATIN CAPITAL LETTER M","	# <font> 004D latin capital letter m"},
/* 1CCE3 */ { "OUTLINED LATIN CAPITAL LETTER N","	# <font> 004E latin capital letter n"},
/* 1CCE4 */ { "OUTLINED LATIN CAPITAL LETTER O","	# <font> 004F latin capital letter o"},
/* 1CCE5 */ { "OUTLINED LATIN CAPITAL LETTER P","	# <font> 0050 latin capital letter p"},
/* 1CCE6 */ { "OUTLINED LATIN CAPITAL LETTER Q","	# <font> 0051 latin capital letter q"},
/* 1CCE7 */ { "OUTLINED LATIN CAPITAL LETTER R","	# <font> 0052 latin capital letter r"},
/* 1CCE8 */ { "OUTLINED LATIN CAPITAL LETTER S","	# <font> 0053 latin capital letter s"},
/* 1CCE9 */ { "OUTLINED LATIN CAPITAL LETTER T","	# <font> 0054 latin capital letter t"},
/* 1CCEA */ { "OUTLINED LATIN CAPITAL LETTER U","	# <font> 0055 latin capital letter u"},
/* 1CCEB */ { "OUTLINED LATIN CAPITAL LETTER V","	# <font> 0056 latin capital letter v"},
/* 1CCEC */ { "OUTLINED LATIN CAPITAL LETTER W","	# <font> 0057 latin capital letter w"},
/* 1CCED */ { "OUTLINED LATIN CAPITAL LETTER X","	# <font> 0058 latin capital letter x"},
/* 1CCEE */ { "OUTLINED LATIN CAPITAL LETTER Y","	# <font> 0059 latin capital letter y"},
/* 1CCEF */ { "OUTLINED LATIN CAPITAL LETTER Z","	# <font> 005A latin capital letter z"},
/* 1CCF0 */ { "OUTLINED DIGIT ZERO","	# <font> 0030 digit zero"},
/* 1CCF1 */ { "OUTLINED DIGIT ONE","	# <font> 0031 digit one"},
/* 1CCF2 */ { "OUTLINED DIGIT TWO","	# <font> 0032 digit two"},
/* 1CCF3 */ { "OUTLINED DIGIT THREE","	# <font> 0033 digit three"},
/* 1CCF4 */ { "OUTLINED DIGIT FOUR","	# <font> 0034 digit four"},
/* 1CCF5 */ { "OUTLINED DIGIT FIVE","	# <font> 0035 digit five"},
/* 1CCF6 */ { "OUTLINED DIGIT SIX","	# <font> 0036 digit six"},
/* 1CCF7 */ { "OUTLINED DIGIT SEVEN","	# <font> 0037 digit seven"},
/* 1CCF8 */ { "OUTLINED DIGIT EIGHT","	# <font> 0038 digit eight"},
/* 1CCF9 */ { "OUTLINED DIGIT NINE","	# <font> 0039 digit nine"},
/* 1CCFA */ { "SNAKE SYMBOL","	x (snake - 1F40D)"},
/* 1CCFB */ { "FLYING SAUCER SYMBOL","	x (flying saucer - 1F6F8)"},
/* 1CCFC */ { "NOSE SYMBOL","	x (nose - 1F443)"},
/* 1CCFD */ { NULL,NULL},
/* 1CCFE */ { NULL,NULL},
/* 1CCFF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_CD[] = {
/* 1CD00 */ { "BLOCK OCTANT-3",NULL},
/* 1CD01 */ { "BLOCK OCTANT-23",NULL},
/* 1CD02 */ { "BLOCK OCTANT-123",NULL},
/* 1CD03 */ { "BLOCK OCTANT-4",NULL},
/* 1CD04 */ { "BLOCK OCTANT-14",NULL},
/* 1CD05 */ { "BLOCK OCTANT-124",NULL},
/* 1CD06 */ { "BLOCK OCTANT-34",NULL},
/* 1CD07 */ { "BLOCK OCTANT-134",NULL},
/* 1CD08 */ { "BLOCK OCTANT-234",NULL},
/* 1CD09 */ { "BLOCK OCTANT-5",NULL},
/* 1CD0A */ { "BLOCK OCTANT-15",NULL},
/* 1CD0B */ { "BLOCK OCTANT-25",NULL},
/* 1CD0C */ { "BLOCK OCTANT-125",NULL},
/* 1CD0D */ { "BLOCK OCTANT-135",NULL},
/* 1CD0E */ { "BLOCK OCTANT-235",NULL},
/* 1CD0F */ { "BLOCK OCTANT-1235",NULL},
/* 1CD10 */ { "BLOCK OCTANT-45",NULL},
/* 1CD11 */ { "BLOCK OCTANT-145",NULL},
/* 1CD12 */ { "BLOCK OCTANT-245",NULL},
/* 1CD13 */ { "BLOCK OCTANT-1245",NULL},
/* 1CD14 */ { "BLOCK OCTANT-345",NULL},
/* 1CD15 */ { "BLOCK OCTANT-1345",NULL},
/* 1CD16 */ { "BLOCK OCTANT-2345",NULL},
/* 1CD17 */ { "BLOCK OCTANT-12345",NULL},
/* 1CD18 */ { "BLOCK OCTANT-6",NULL},
/* 1CD19 */ { "BLOCK OCTANT-16",NULL},
/* 1CD1A */ { "BLOCK OCTANT-26",NULL},
/* 1CD1B */ { "BLOCK OCTANT-126",NULL},
/* 1CD1C */ { "BLOCK OCTANT-36",NULL},
/* 1CD1D */ { "BLOCK OCTANT-136",NULL},
/* 1CD1E */ { "BLOCK OCTANT-236",NULL},
/* 1CD1F */ { "BLOCK OCTANT-1236",NULL},
/* 1CD20 */ { "BLOCK OCTANT-146",NULL},
/* 1CD21 */ { "BLOCK OCTANT-246",NULL},
/* 1CD22 */ { "BLOCK OCTANT-1246",NULL},
/* 1CD23 */ { "BLOCK OCTANT-346",NULL},
/* 1CD24 */ { "BLOCK OCTANT-1346",NULL},
/* 1CD25 */ { "BLOCK OCTANT-2346",NULL},
/* 1CD26 */ { "BLOCK OCTANT-12346",NULL},
/* 1CD27 */ { "BLOCK OCTANT-56",NULL},
/* 1CD28 */ { "BLOCK OCTANT-156",NULL},
/* 1CD29 */ { "BLOCK OCTANT-256",NULL},
/* 1CD2A */ { "BLOCK OCTANT-1256",NULL},
/* 1CD2B */ { "BLOCK OCTANT-356",NULL},
/* 1CD2C */ { "BLOCK OCTANT-1356",NULL},
/* 1CD2D */ { "BLOCK OCTANT-2356",NULL},
/* 1CD2E */ { "BLOCK OCTANT-12356",NULL},
/* 1CD2F */ { "BLOCK OCTANT-456",NULL},
/* 1CD30 */ { "BLOCK OCTANT-1456",NULL},
/* 1CD31 */ { "BLOCK OCTANT-2456",NULL},
/* 1CD32 */ { "BLOCK OCTANT-12456",NULL},
/* 1CD33 */ { "BLOCK OCTANT-3456",NULL},
/* 1CD34 */ { "BLOCK OCTANT-13456",NULL},
/* 1CD35 */ { "BLOCK OCTANT-23456",NULL},
/* 1CD36 */ { "BLOCK OCTANT-17",NULL},
/* 1CD37 */ { "BLOCK OCTANT-27",NULL},
/* 1CD38 */ { "BLOCK OCTANT-127",NULL},
/* 1CD39 */ { "BLOCK OCTANT-37",NULL},
/* 1CD3A */ { "BLOCK OCTANT-137",NULL},
/* 1CD3B */ { "BLOCK OCTANT-237",NULL},
/* 1CD3C */ { "BLOCK OCTANT-1237",NULL},
/* 1CD3D */ { "BLOCK OCTANT-47",NULL},
/* 1CD3E */ { "BLOCK OCTANT-147",NULL},
/* 1CD3F */ { "BLOCK OCTANT-247",NULL},
/* 1CD40 */ { "BLOCK OCTANT-1247",NULL},
/* 1CD41 */ { "BLOCK OCTANT-347",NULL},
/* 1CD42 */ { "BLOCK OCTANT-1347",NULL},
/* 1CD43 */ { "BLOCK OCTANT-2347",NULL},
/* 1CD44 */ { "BLOCK OCTANT-12347",NULL},
/* 1CD45 */ { "BLOCK OCTANT-157",NULL},
/* 1CD46 */ { "BLOCK OCTANT-257",NULL},
/* 1CD47 */ { "BLOCK OCTANT-1257",NULL},
/* 1CD48 */ { "BLOCK OCTANT-357",NULL},
/* 1CD49 */ { "BLOCK OCTANT-2357",NULL},
/* 1CD4A */ { "BLOCK OCTANT-12357",NULL},
/* 1CD4B */ { "BLOCK OCTANT-457",NULL},
/* 1CD4C */ { "BLOCK OCTANT-1457",NULL},
/* 1CD4D */ { "BLOCK OCTANT-12457",NULL},
/* 1CD4E */ { "BLOCK OCTANT-3457",NULL},
/* 1CD4F */ { "BLOCK OCTANT-13457",NULL},
/* 1CD50 */ { "BLOCK OCTANT-23457",NULL},
/* 1CD51 */ { "BLOCK OCTANT-67",NULL},
/* 1CD52 */ { "BLOCK OCTANT-167",NULL},
/* 1CD53 */ { "BLOCK OCTANT-267",NULL},
/* 1CD54 */ { "BLOCK OCTANT-1267",NULL},
/* 1CD55 */ { "BLOCK OCTANT-367",NULL},
/* 1CD56 */ { "BLOCK OCTANT-1367",NULL},
/* 1CD57 */ { "BLOCK OCTANT-2367",NULL},
/* 1CD58 */ { "BLOCK OCTANT-12367",NULL},
/* 1CD59 */ { "BLOCK OCTANT-467",NULL},
/* 1CD5A */ { "BLOCK OCTANT-1467",NULL},
/* 1CD5B */ { "BLOCK OCTANT-2467",NULL},
/* 1CD5C */ { "BLOCK OCTANT-12467",NULL},
/* 1CD5D */ { "BLOCK OCTANT-3467",NULL},
/* 1CD5E */ { "BLOCK OCTANT-13467",NULL},
/* 1CD5F */ { "BLOCK OCTANT-23467",NULL},
/* 1CD60 */ { "BLOCK OCTANT-123467",NULL},
/* 1CD61 */ { "BLOCK OCTANT-567",NULL},
/* 1CD62 */ { "BLOCK OCTANT-1567",NULL},
/* 1CD63 */ { "BLOCK OCTANT-2567",NULL},
/* 1CD64 */ { "BLOCK OCTANT-12567",NULL},
/* 1CD65 */ { "BLOCK OCTANT-3567",NULL},
/* 1CD66 */ { "BLOCK OCTANT-13567",NULL},
/* 1CD67 */ { "BLOCK OCTANT-23567",NULL},
/* 1CD68 */ { "BLOCK OCTANT-123567",NULL},
/* 1CD69 */ { "BLOCK OCTANT-4567",NULL},
/* 1CD6A */ { "BLOCK OCTANT-14567",NULL},
/* 1CD6B */ { "BLOCK OCTANT-24567",NULL},
/* 1CD6C */ { "BLOCK OCTANT-124567",NULL},
/* 1CD6D */ { "BLOCK OCTANT-34567",NULL},
/* 1CD6E */ { "BLOCK OCTANT-134567",NULL},
/* 1CD6F */ { "BLOCK OCTANT-234567",NULL},
/* 1CD70 */ { "BLOCK OCTANT-1234567",NULL},
/* 1CD71 */ { "BLOCK OCTANT-18",NULL},
/* 1CD72 */ { "BLOCK OCTANT-28",NULL},
/* 1CD73 */ { "BLOCK OCTANT-128",NULL},
/* 1CD74 */ { "BLOCK OCTANT-38",NULL},
/* 1CD75 */ { "BLOCK OCTANT-138",NULL},
/* 1CD76 */ { "BLOCK OCTANT-238",NULL},
/* 1CD77 */ { "BLOCK OCTANT-1238",NULL},
/* 1CD78 */ { "BLOCK OCTANT-48",NULL},
/* 1CD79 */ { "BLOCK OCTANT-148",NULL},
/* 1CD7A */ { "BLOCK OCTANT-248",NULL},
/* 1CD7B */ { "BLOCK OCTANT-1248",NULL},
/* 1CD7C */ { "BLOCK OCTANT-348",NULL},
/* 1CD7D */ { "BLOCK OCTANT-1348",NULL},
/* 1CD7E */ { "BLOCK OCTANT-2348",NULL},
/* 1CD7F */ { "BLOCK OCTANT-12348",NULL},
/* 1CD80 */ { "BLOCK OCTANT-58",NULL},
/* 1CD81 */ { "BLOCK OCTANT-158",NULL},
/* 1CD82 */ { "BLOCK OCTANT-258",NULL},
/* 1CD83 */ { "BLOCK OCTANT-1258",NULL},
/* 1CD84 */ { "BLOCK OCTANT-358",NULL},
/* 1CD85 */ { "BLOCK OCTANT-1358",NULL},
/* 1CD86 */ { "BLOCK OCTANT-2358",NULL},
/* 1CD87 */ { "BLOCK OCTANT-12358",NULL},
/* 1CD88 */ { "BLOCK OCTANT-458",NULL},
/* 1CD89 */ { "BLOCK OCTANT-1458",NULL},
/* 1CD8A */ { "BLOCK OCTANT-2458",NULL},
/* 1CD8B */ { "BLOCK OCTANT-12458",NULL},
/* 1CD8C */ { "BLOCK OCTANT-3458",NULL},
/* 1CD8D */ { "BLOCK OCTANT-13458",NULL},
/* 1CD8E */ { "BLOCK OCTANT-23458",NULL},
/* 1CD8F */ { "BLOCK OCTANT-123458",NULL},
/* 1CD90 */ { "BLOCK OCTANT-168",NULL},
/* 1CD91 */ { "BLOCK OCTANT-268",NULL},
/* 1CD92 */ { "BLOCK OCTANT-1268",NULL},
/* 1CD93 */ { "BLOCK OCTANT-368",NULL},
/* 1CD94 */ { "BLOCK OCTANT-2368",NULL},
/* 1CD95 */ { "BLOCK OCTANT-12368",NULL},
/* 1CD96 */ { "BLOCK OCTANT-468",NULL},
/* 1CD97 */ { "BLOCK OCTANT-1468",NULL},
/* 1CD98 */ { "BLOCK OCTANT-12468",NULL},
/* 1CD99 */ { "BLOCK OCTANT-3468",NULL},
/* 1CD9A */ { "BLOCK OCTANT-13468",NULL},
/* 1CD9B */ { "BLOCK OCTANT-23468",NULL},
/* 1CD9C */ { "BLOCK OCTANT-568",NULL},
/* 1CD9D */ { "BLOCK OCTANT-1568",NULL},
/* 1CD9E */ { "BLOCK OCTANT-2568",NULL},
/* 1CD9F */ { "BLOCK OCTANT-12568",NULL},
/* 1CDA0 */ { "BLOCK OCTANT-3568",NULL},
/* 1CDA1 */ { "BLOCK OCTANT-13568",NULL},
/* 1CDA2 */ { "BLOCK OCTANT-23568",NULL},
/* 1CDA3 */ { "BLOCK OCTANT-123568",NULL},
/* 1CDA4 */ { "BLOCK OCTANT-4568",NULL},
/* 1CDA5 */ { "BLOCK OCTANT-14568",NULL},
/* 1CDA6 */ { "BLOCK OCTANT-24568",NULL},
/* 1CDA7 */ { "BLOCK OCTANT-124568",NULL},
/* 1CDA8 */ { "BLOCK OCTANT-34568",NULL},
/* 1CDA9 */ { "BLOCK OCTANT-134568",NULL},
/* 1CDAA */ { "BLOCK OCTANT-234568",NULL},
/* 1CDAB */ { "BLOCK OCTANT-1234568",NULL},
/* 1CDAC */ { "BLOCK OCTANT-178",NULL},
/* 1CDAD */ { "BLOCK OCTANT-278",NULL},
/* 1CDAE */ { "BLOCK OCTANT-1278",NULL},
/* 1CDAF */ { "BLOCK OCTANT-378",NULL},
/* 1CDB0 */ { "BLOCK OCTANT-1378",NULL},
/* 1CDB1 */ { "BLOCK OCTANT-2378",NULL},
/* 1CDB2 */ { "BLOCK OCTANT-12378",NULL},
/* 1CDB3 */ { "BLOCK OCTANT-478",NULL},
/* 1CDB4 */ { "BLOCK OCTANT-1478",NULL},
/* 1CDB5 */ { "BLOCK OCTANT-2478",NULL},
/* 1CDB6 */ { "BLOCK OCTANT-12478",NULL},
/* 1CDB7 */ { "BLOCK OCTANT-3478","	x (heavy horizontal fill - 1FB97)"},
/* 1CDB8 */ { "BLOCK OCTANT-13478",NULL},
/* 1CDB9 */ { "BLOCK OCTANT-23478",NULL},
/* 1CDBA */ { "BLOCK OCTANT-123478",NULL},
/* 1CDBB */ { "BLOCK OCTANT-578",NULL},
/* 1CDBC */ { "BLOCK OCTANT-1578",NULL},
/* 1CDBD */ { "BLOCK OCTANT-2578",NULL},
/* 1CDBE */ { "BLOCK OCTANT-12578",NULL},
/* 1CDBF */ { "BLOCK OCTANT-3578",NULL},
/* 1CDC0 */ { "BLOCK OCTANT-13578",NULL},
/* 1CDC1 */ { "BLOCK OCTANT-23578",NULL},
/* 1CDC2 */ { "BLOCK OCTANT-123578",NULL},
/* 1CDC3 */ { "BLOCK OCTANT-4578",NULL},
/* 1CDC4 */ { "BLOCK OCTANT-14578",NULL},
/* 1CDC5 */ { "BLOCK OCTANT-24578",NULL},
/* 1CDC6 */ { "BLOCK OCTANT-124578",NULL},
/* 1CDC7 */ { "BLOCK OCTANT-34578",NULL},
/* 1CDC8 */ { "BLOCK OCTANT-134578",NULL},
/* 1CDC9 */ { "BLOCK OCTANT-234578",NULL},
/* 1CDCA */ { "BLOCK OCTANT-1234578",NULL},
/* 1CDCB */ { "BLOCK OCTANT-678",NULL},
/* 1CDCC */ { "BLOCK OCTANT-1678",NULL},
/* 1CDCD */ { "BLOCK OCTANT-2678",NULL},
/* 1CDCE */ { "BLOCK OCTANT-12678",NULL},
/* 1CDCF */ { "BLOCK OCTANT-3678",NULL},
/* 1CDD0 */ { "BLOCK OCTANT-13678",NULL},
/* 1CDD1 */ { "BLOCK OCTANT-23678",NULL},
/* 1CDD2 */ { "BLOCK OCTANT-123678",NULL},
/* 1CDD3 */ { "BLOCK OCTANT-4678",NULL},
/* 1CDD4 */ { "BLOCK OCTANT-14678",NULL},
/* 1CDD5 */ { "BLOCK OCTANT-24678",NULL},
/* 1CDD6 */ { "BLOCK OCTANT-124678",NULL},
/* 1CDD7 */ { "BLOCK OCTANT-34678",NULL},
/* 1CDD8 */ { "BLOCK OCTANT-134678",NULL},
/* 1CDD9 */ { "BLOCK OCTANT-234678",NULL},
/* 1CDDA */ { "BLOCK OCTANT-1234678",NULL},
/* 1CDDB */ { "BLOCK OCTANT-15678",NULL},
/* 1CDDC */ { "BLOCK OCTANT-25678",NULL},
/* 1CDDD */ { "BLOCK OCTANT-125678",NULL},
/* 1CDDE */ { "BLOCK OCTANT-35678",NULL},
/* 1CDDF */ { "BLOCK OCTANT-235678",NULL},
/* 1CDE0 */ { "BLOCK OCTANT-1235678",NULL},
/* 1CDE1 */ { "BLOCK OCTANT-45678",NULL},
/* 1CDE2 */ { "BLOCK OCTANT-145678",NULL},
/* 1CDE3 */ { "BLOCK OCTANT-1245678",NULL},
/* 1CDE4 */ { "BLOCK OCTANT-1345678",NULL},
/* 1CDE5 */ { "BLOCK OCTANT-2345678",NULL},
/* 1CDE6 */ { "TOP HALF STANDING PERSON",NULL},
/* 1CDE7 */ { "BOTTOM HALF STANDING PERSON",NULL},
/* 1CDE8 */ { "TOP HALF RIGHT-FACING RUNNER FRAME-1",NULL},
/* 1CDE9 */ { "BOTTOM HALF RIGHT-FACING RUNNER FRAME-1",NULL},
/* 1CDEA */ { "TOP HALF RIGHT-FACING RUNNER FRAME-2",NULL},
/* 1CDEB */ { "BOTTOM HALF RIGHT-FACING RUNNER FRAME-2",NULL},
/* 1CDEC */ { "TOP HALF LEFT-FACING RUNNER FRAME-1",NULL},
/* 1CDED */ { "BOTTOM HALF LEFT-FACING RUNNER FRAME-1",NULL},
/* 1CDEE */ { "TOP HALF LEFT-FACING RUNNER FRAME-2",NULL},
/* 1CDEF */ { "BOTTOM HALF LEFT-FACING RUNNER FRAME-2",NULL},
/* 1CDF0 */ { "TOP HALF FORWARD-FACING RUNNER",NULL},
/* 1CDF1 */ { "BOTTOM HALF FORWARD-FACING RUNNER FRAME-1",NULL},
/* 1CDF2 */ { "BOTTOM HALF FORWARD-FACING RUNNER FRAME-2",NULL},
/* 1CDF3 */ { "BOTTOM HALF FORWARD-FACING RUNNER FRAME-3",NULL},
/* 1CDF4 */ { "BOTTOM HALF FORWARD-FACING RUNNER FRAME-4",NULL},
/* 1CDF5 */ { "MOON LANDER",NULL},
/* 1CDF6 */ { "TOP HALF FLAILING ROBOT FRAME-1",NULL},
/* 1CDF7 */ { "TOP HALF FLAILING ROBOT FRAME-2",NULL},
/* 1CDF8 */ { "DOWN-POINTING AIRPLANE",NULL},
/* 1CDF9 */ { "LEFT-POINTING AIRPLANE",NULL},
/* 1CDFA */ { "SMALL UP-POINTING AIRPLANE",NULL},
/* 1CDFB */ { "UP-POINTING FROG",NULL},
/* 1CDFC */ { "DOWN-POINTING FROG",NULL},
/* 1CDFD */ { "EXPLOSION FRAME-1",NULL},
/* 1CDFE */ { "EXPLOSION FRAME-2",NULL},
/* 1CDFF */ { "EXPLOSION FRAME-3",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_CE[] = {
/* 1CE00 */ { "RIGHT HALF AND LEFT HALF WHITE CIRCLE",NULL},
/* 1CE01 */ { "LOWER HALF AND UPPER HALF WHITE CIRCLE",NULL},
/* 1CE02 */ { "EXPLOSION AT HORIZON",NULL},
/* 1CE03 */ { "UPPER HALF HEAVY WHITE SQUARE",NULL},
/* 1CE04 */ { "LOWER HALF HEAVY WHITE SQUARE",NULL},
/* 1CE05 */ { "HEAVY WHITE SQUARE CONTAINING BLACK VERY SMALL SQUARE",NULL},
/* 1CE06 */ { "WHITE VERTICAL RECTANGLE WITH HORIZONTAL BAR",NULL},
/* 1CE07 */ { "TOP LEFT BLACK LEFT-POINTING SMALL TRIANGLE",NULL},
/* 1CE08 */ { "FUNNEL",NULL},
/* 1CE09 */ { "BOX DRAWINGS DOUBLE DIAGONAL LOWER LEFT TO MIDDLE CENTRE TO LOWER RIGHT",NULL},
/* 1CE0A */ { "BOX DRAWINGS DOUBLE DIAGONAL UPPER LEFT TO MIDDLE CENTRE TO UPPER RIGHT",NULL},
/* 1CE0B */ { "LEFT HALF WHITE ELLIPSE",NULL},
/* 1CE0C */ { "RIGHT HALF WHITE ELLIPSE",NULL},
/* 1CE0D */ { "LEFT HALF TRIPLE DASH HORIZONTAL",NULL},
/* 1CE0E */ { "RIGHT HALF TRIPLE DASH HORIZONTAL",NULL},
/* 1CE0F */ { "HORIZONTAL LINE WITH TICK MARK",NULL},
/* 1CE10 */ { "LEFT HALF HORIZONTAL LINE WITH THREE TICK MARKS",NULL},
/* 1CE11 */ { "RIGHT HALF HORIZONTAL LINE WITH THREE TICK MARKS",NULL},
/* 1CE12 */ { "HORIZONTAL LINE WITH THREE TICK MARKS",NULL},
/* 1CE13 */ { "LOWER HALF VERTICAL LINE WITH THREE TICK MARKS",NULL},
/* 1CE14 */ { "UPPER HALF VERTICAL LINE WITH THREE TICK MARKS",NULL},
/* 1CE15 */ { "VERTICAL LINE WITH THREE TICK MARKS",NULL},
/* 1CE16 */ { "BOX DRAWINGS LIGHT VERTICAL AND TOP RIGHT",NULL},
/* 1CE17 */ { "BOX DRAWINGS LIGHT VERTICAL AND BOTTOM RIGHT",NULL},
/* 1CE18 */ { "BOX DRAWINGS LIGHT VERTICAL AND TOP LEFT",NULL},
/* 1CE19 */ { "BOX DRAWINGS LIGHT VERTICAL AND BOTTOM LEFT",NULL},
/* 1CE1A */ { "LARGE TYPE PIECE UPPER LEFT ARC",NULL},
/* 1CE1B */ { "LARGE TYPE PIECE UPPER LEFT CORNER",NULL},
/* 1CE1C */ { "LARGE TYPE PIECE UPPER TERMINAL",NULL},
/* 1CE1D */ { "LARGE TYPE PIECE UPPER LEFT CROTCH",NULL},
/* 1CE1E */ { "LARGE TYPE PIECE LEFT ARM",NULL},
/* 1CE1F */ { "LARGE TYPE PIECE CROSSBAR",NULL},
/* 1CE20 */ { "LARGE TYPE PIECE CROSSBAR WITH LOWER STEM",NULL},
/* 1CE21 */ { "LARGE TYPE PIECE UPPER HALF VERTEX OF M",NULL},
/* 1CE22 */ { "LARGE TYPE PIECE DIAGONAL LOWER LEFT",NULL},
/* 1CE23 */ { "LARGE TYPE PIECE SHORT UPPER TERMINAL",NULL},
/* 1CE24 */ { "LARGE TYPE PIECE UPPER RIGHT ARC",NULL},
/* 1CE25 */ { "LARGE TYPE PIECE RIGHT ARM",NULL},
/* 1CE26 */ { "LARGE TYPE PIECE UPPER RIGHT CROTCH",NULL},
/* 1CE27 */ { "LARGE TYPE PIECE UPPER RIGHT CORNER",NULL},
/* 1CE28 */ { "LARGE TYPE PIECE STEM WITH RIGHT CROSSBAR",NULL},
/* 1CE29 */ { "LARGE TYPE PIECE STEM",NULL},
/* 1CE2A */ { "LARGE TYPE PIECE DIAGONAL UPPER RIGHT AND LOWER RIGHT",NULL},
/* 1CE2B */ { "LARGE TYPE PIECE DIAGONAL UPPER RIGHT",NULL},
/* 1CE2C */ { "LARGE TYPE PIECE DIAGONAL LOWER RIGHT",NULL},
/* 1CE2D */ { "LARGE TYPE PIECE SHORT LOWER TERMINAL",NULL},
/* 1CE2E */ { "LARGE TYPE PIECE LOWER LEFT AND UPPER LEFT ARC",NULL},
/* 1CE2F */ { "LARGE TYPE PIECE CENTRE OF K",NULL},
/* 1CE30 */ { "LARGE TYPE PIECE LOWER HALF VERTEX OF M",NULL},
/* 1CE31 */ { "LARGE TYPE PIECE UPPER HALF VERTEX OF W",NULL},
/* 1CE32 */ { "LARGE TYPE PIECE CENTRE OF X",NULL},
/* 1CE33 */ { "LARGE TYPE PIECE CENTRE OF Y",NULL},
/* 1CE34 */ { "LARGE TYPE PIECE CENTRE OF Z WITH CROSSBAR",NULL},
/* 1CE35 */ { "LARGE TYPE PIECE RAISED UPPER LEFT ARC",NULL},
/* 1CE36 */ { "LARGE TYPE PIECE STEM WITH LEFT CROSSBAR",NULL},
/* 1CE37 */ { "LARGE TYPE PIECE LOWER RIGHT AND UPPER RIGHT ARC",NULL},
/* 1CE38 */ { "LARGE TYPE PIECE DIAGONAL UPPER LEFT AND LOWER LEFT",NULL},
/* 1CE39 */ { "LARGE TYPE PIECE STEM WITH LEFT JOINT",NULL},
/* 1CE3A */ { "LARGE TYPE PIECE STEM WITH CROSSBAR",NULL},
/* 1CE3B */ { "LARGE TYPE PIECE DIAGONAL UPPER LEFT",NULL},
/* 1CE3C */ { "LARGE TYPE PIECE LOWER TERMINAL",NULL},
/* 1CE3D */ { "LARGE TYPE PIECE LOWER LEFT CORNER",NULL},
/* 1CE3E */ { "LARGE TYPE PIECE LOWER LEFT ARC",NULL},
/* 1CE3F */ { "LARGE TYPE PIECE LOWER LEFT CROTCH",NULL},
/* 1CE40 */ { "LARGE TYPE PIECE CROSSBAR WITH UPPER STEM",NULL},
/* 1CE41 */ { "LARGE TYPE PIECE VERTEX OF V",NULL},
/* 1CE42 */ { "LARGE TYPE PIECE LOWER HALF VERTEX OF W",NULL},
/* 1CE43 */ { "LARGE TYPE PIECE LOWER RIGHT ARC",NULL},
/* 1CE44 */ { "LARGE TYPE PIECE LOWER RIGHT CORNER",NULL},
/* 1CE45 */ { "LARGE TYPE PIECE LOWER RIGHT ARC WITH TAIL",NULL},
/* 1CE46 */ { "LARGE TYPE PIECE LOWER RIGHT CROTCH",NULL},
/* 1CE47 */ { "LARGE TYPE PIECE STEM-45",NULL},
/* 1CE48 */ { "LARGE TYPE PIECE STEM-2345",NULL},
/* 1CE49 */ { "LARGE TYPE PIECE STEM-4",NULL},
/* 1CE4A */ { "LARGE TYPE PIECE STEM-34",NULL},
/* 1CE4B */ { "LARGE TYPE PIECE STEM-234",NULL},
/* 1CE4C */ { "LARGE TYPE PIECE STEM-1234",NULL},
/* 1CE4D */ { "LARGE TYPE PIECE STEM-3",NULL},
/* 1CE4E */ { "LARGE TYPE PIECE STEM-23",NULL},
/* 1CE4F */ { "LARGE TYPE PIECE STEM-2",NULL},
/* 1CE50 */ { "LARGE TYPE PIECE STEM-12",NULL},
/* 1CE51 */ { "SEPARATED BLOCK SEXTANT-1",NULL},
/* 1CE52 */ { "SEPARATED BLOCK SEXTANT-2",NULL},
/* 1CE53 */ { "SEPARATED BLOCK SEXTANT-12",NULL},
/* 1CE54 */ { "SEPARATED BLOCK SEXTANT-3",NULL},
/* 1CE55 */ { "SEPARATED BLOCK SEXTANT-13",NULL},
/* 1CE56 */ { "SEPARATED BLOCK SEXTANT-23",NULL},
/* 1CE57 */ { "SEPARATED BLOCK SEXTANT-123",NULL},
/* 1CE58 */ { "SEPARATED BLOCK SEXTANT-4",NULL},
/* 1CE59 */ { "SEPARATED BLOCK SEXTANT-14",NULL},
/* 1CE5A */ { "SEPARATED BLOCK SEXTANT-24",NULL},
/* 1CE5B */ { "SEPARATED BLOCK SEXTANT-124",NULL},
/* 1CE5C */ { "SEPARATED BLOCK SEXTANT-34",NULL},
/* 1CE5D */ { "SEPARATED BLOCK SEXTANT-134",NULL},
/* 1CE5E */ { "SEPARATED BLOCK SEXTANT-234",NULL},
/* 1CE5F */ { "SEPARATED BLOCK SEXTANT-1234",NULL},
/* 1CE60 */ { "SEPARATED BLOCK SEXTANT-5",NULL},
/* 1CE61 */ { "SEPARATED BLOCK SEXTANT-15",NULL},
/* 1CE62 */ { "SEPARATED BLOCK SEXTANT-25",NULL},
/* 1CE63 */ { "SEPARATED BLOCK SEXTANT-125",NULL},
/* 1CE64 */ { "SEPARATED BLOCK SEXTANT-35",NULL},
/* 1CE65 */ { "SEPARATED BLOCK SEXTANT-135",NULL},
/* 1CE66 */ { "SEPARATED BLOCK SEXTANT-235",NULL},
/* 1CE67 */ { "SEPARATED BLOCK SEXTANT-1235",NULL},
/* 1CE68 */ { "SEPARATED BLOCK SEXTANT-45",NULL},
/* 1CE69 */ { "SEPARATED BLOCK SEXTANT-145",NULL},
/* 1CE6A */ { "SEPARATED BLOCK SEXTANT-245",NULL},
/* 1CE6B */ { "SEPARATED BLOCK SEXTANT-1245",NULL},
/* 1CE6C */ { "SEPARATED BLOCK SEXTANT-345",NULL},
/* 1CE6D */ { "SEPARATED BLOCK SEXTANT-1345",NULL},
/* 1CE6E */ { "SEPARATED BLOCK SEXTANT-2345",NULL},
/* 1CE6F */ { "SEPARATED BLOCK SEXTANT-12345",NULL},
/* 1CE70 */ { "SEPARATED BLOCK SEXTANT-6",NULL},
/* 1CE71 */ { "SEPARATED BLOCK SEXTANT-16",NULL},
/* 1CE72 */ { "SEPARATED BLOCK SEXTANT-26",NULL},
/* 1CE73 */ { "SEPARATED BLOCK SEXTANT-126",NULL},
/* 1CE74 */ { "SEPARATED BLOCK SEXTANT-36",NULL},
/* 1CE75 */ { "SEPARATED BLOCK SEXTANT-136",NULL},
/* 1CE76 */ { "SEPARATED BLOCK SEXTANT-236",NULL},
/* 1CE77 */ { "SEPARATED BLOCK SEXTANT-1236",NULL},
/* 1CE78 */ { "SEPARATED BLOCK SEXTANT-46",NULL},
/* 1CE79 */ { "SEPARATED BLOCK SEXTANT-146",NULL},
/* 1CE7A */ { "SEPARATED BLOCK SEXTANT-246",NULL},
/* 1CE7B */ { "SEPARATED BLOCK SEXTANT-1246",NULL},
/* 1CE7C */ { "SEPARATED BLOCK SEXTANT-346",NULL},
/* 1CE7D */ { "SEPARATED BLOCK SEXTANT-1346",NULL},
/* 1CE7E */ { "SEPARATED BLOCK SEXTANT-2346",NULL},
/* 1CE7F */ { "SEPARATED BLOCK SEXTANT-12346",NULL},
/* 1CE80 */ { "SEPARATED BLOCK SEXTANT-56",NULL},
/* 1CE81 */ { "SEPARATED BLOCK SEXTANT-156",NULL},
/* 1CE82 */ { "SEPARATED BLOCK SEXTANT-256",NULL},
/* 1CE83 */ { "SEPARATED BLOCK SEXTANT-1256",NULL},
/* 1CE84 */ { "SEPARATED BLOCK SEXTANT-356",NULL},
/* 1CE85 */ { "SEPARATED BLOCK SEXTANT-1356",NULL},
/* 1CE86 */ { "SEPARATED BLOCK SEXTANT-2356",NULL},
/* 1CE87 */ { "SEPARATED BLOCK SEXTANT-12356",NULL},
/* 1CE88 */ { "SEPARATED BLOCK SEXTANT-456",NULL},
/* 1CE89 */ { "SEPARATED BLOCK SEXTANT-1456",NULL},
/* 1CE8A */ { "SEPARATED BLOCK SEXTANT-2456",NULL},
/* 1CE8B */ { "SEPARATED BLOCK SEXTANT-12456",NULL},
/* 1CE8C */ { "SEPARATED BLOCK SEXTANT-3456",NULL},
/* 1CE8D */ { "SEPARATED BLOCK SEXTANT-13456",NULL},
/* 1CE8E */ { "SEPARATED BLOCK SEXTANT-23456",NULL},
/* 1CE8F */ { "SEPARATED BLOCK SEXTANT-123456",NULL},
/* 1CE90 */ { "UPPER LEFT ONE SIXTEENTH BLOCK",NULL},
/* 1CE91 */ { "UPPER CENTRE LEFT ONE SIXTEENTH BLOCK",NULL},
/* 1CE92 */ { "UPPER CENTRE RIGHT ONE SIXTEENTH BLOCK",NULL},
/* 1CE93 */ { "UPPER RIGHT ONE SIXTEENTH BLOCK",NULL},
/* 1CE94 */ { "UPPER MIDDLE LEFT ONE SIXTEENTH BLOCK",NULL},
/* 1CE95 */ { "UPPER MIDDLE CENTRE LEFT ONE SIXTEENTH BLOCK",NULL},
/* 1CE96 */ { "UPPER MIDDLE CENTRE RIGHT ONE SIXTEENTH BLOCK",NULL},
/* 1CE97 */ { "UPPER MIDDLE RIGHT ONE SIXTEENTH BLOCK",NULL},
/* 1CE98 */ { "LOWER MIDDLE LEFT ONE SIXTEENTH BLOCK",NULL},
/* 1CE99 */ { "LOWER MIDDLE CENTRE LEFT ONE SIXTEENTH BLOCK",NULL},
/* 1CE9A */ { "LOWER MIDDLE CENTRE RIGHT ONE SIXTEENTH BLOCK",NULL},
/* 1CE9B */ { "LOWER MIDDLE RIGHT ONE SIXTEENTH BLOCK",NULL},
/* 1CE9C */ { "LOWER LEFT ONE SIXTEENTH BLOCK",NULL},
/* 1CE9D */ { "LOWER CENTRE LEFT ONE SIXTEENTH BLOCK",NULL},
/* 1CE9E */ { "LOWER CENTRE RIGHT ONE SIXTEENTH BLOCK",NULL},
/* 1CE9F */ { "LOWER RIGHT ONE SIXTEENTH BLOCK",NULL},
/* 1CEA0 */ { "RIGHT HALF LOWER ONE QUARTER BLOCK",NULL},
/* 1CEA1 */ { "RIGHT THREE QUARTERS LOWER ONE QUARTER BLOCK",NULL},
/* 1CEA2 */ { "LEFT THREE QUARTERS LOWER ONE QUARTER BLOCK",NULL},
/* 1CEA3 */ { "LEFT HALF LOWER ONE QUARTER BLOCK",NULL},
/* 1CEA4 */ { "LOWER HALF LEFT ONE QUARTER BLOCK",NULL},
/* 1CEA5 */ { "LOWER THREE QUARTERS LEFT ONE QUARTER BLOCK",NULL},
/* 1CEA6 */ { "UPPER THREE QUARTERS LEFT ONE QUARTER BLOCK",NULL},
/* 1CEA7 */ { "UPPER HALF LEFT ONE QUARTER BLOCK",NULL},
/* 1CEA8 */ { "LEFT HALF UPPER ONE QUARTER BLOCK",NULL},
/* 1CEA9 */ { "LEFT THREE QUARTERS UPPER ONE QUARTER BLOCK",NULL},
/* 1CEAA */ { "RIGHT THREE QUARTERS UPPER ONE QUARTER BLOCK",NULL},
/* 1CEAB */ { "RIGHT HALF UPPER ONE QUARTER BLOCK",NULL},
/* 1CEAC */ { "UPPER HALF RIGHT ONE QUARTER BLOCK",NULL},
/* 1CEAD */ { "UPPER THREE QUARTERS RIGHT ONE QUARTER BLOCK",NULL},
/* 1CEAE */ { "LOWER THREE QUARTERS RIGHT ONE QUARTER BLOCK",NULL},
/* 1CEAF */ { "LOWER HALF RIGHT ONE QUARTER BLOCK",NULL},
/* 1CEB0 */ { "HORIZONTAL ZIGZAG LINE",NULL},
/* 1CEB1 */ { "KEYHOLE",NULL},
/* 1CEB2 */ { "OLD PERSONAL COMPUTER WITH MONITOR IN PORTRAIT ORIENTATION",NULL},
/* 1CEB3 */ { "BLACK RIGHT TRIANGLE CARET",NULL},
/* 1CEB4 */ { NULL,NULL},
/* 1CEB5 */ { NULL,NULL},
/* 1CEB6 */ { NULL,NULL},
/* 1CEB7 */ { NULL,NULL},
/* 1CEB8 */ { NULL,NULL},
/* 1CEB9 */ { NULL,NULL},
/* 1CEBA */ { "FRAGILE SYMBOL","	x (wine glass - 1F377)"},
/* 1CEBB */ { "OFFICE BUILDING SYMBOL","	x (office building - 1F3E2)"},
/* 1CEBC */ { "TREE SYMBOL","	x (deciduous tree - 1F333)"},
/* 1CEBD */ { "APPLE SYMBOL","	x (red apple - 1F34E)\n"
	"	x (green apple - 1F34F)"},
/* 1CEBE */ { "CHERRY SYMBOL","	x (cherries - 1F352)"},
/* 1CEBF */ { "STRAWBERRY SYMBOL","	x (strawberry - 1F353)"},
/* 1CEC0 */ { "HEBE",NULL},
/* 1CEC1 */ { "IRIS",NULL},
/* 1CEC2 */ { "FLORA",NULL},
/* 1CEC3 */ { "METIS",NULL},
/* 1CEC4 */ { "PARTHENOPE","	x (parthenope form two - 1F77A)"},
/* 1CEC5 */ { "VICTORIA",NULL},
/* 1CEC6 */ { "EGERIA",NULL},
/* 1CEC7 */ { "IRENE",NULL},
/* 1CEC8 */ { "EUNOMIA",NULL},
/* 1CEC9 */ { "PSYCHE",NULL},
/* 1CECA */ { "THETIS",NULL},
/* 1CECB */ { "MELPOMENE",NULL},
/* 1CECC */ { "FORTUNA",NULL},
/* 1CECD */ { "ASTRONOMICAL SYMBOL FOR ASTEROID PROSERPINA","	x (proserpina - 2BD8)"},
/* 1CECE */ { "BELLONA",NULL},
/* 1CECF */ { "AMPHITRITE",NULL},
/* 1CED0 */ { "LEUKOTHEA",NULL},
/* 1CED1 */ { NULL,NULL},
/* 1CED2 */ { NULL,NULL},
/* 1CED3 */ { NULL,NULL},
/* 1CED4 */ { NULL,NULL},
/* 1CED5 */ { NULL,NULL},
/* 1CED6 */ { NULL,NULL},
/* 1CED7 */ { NULL,NULL},
/* 1CED8 */ { NULL,NULL},
/* 1CED9 */ { NULL,NULL},
/* 1CEDA */ { NULL,NULL},
/* 1CEDB */ { NULL,NULL},
/* 1CEDC */ { NULL,NULL},
/* 1CEDD */ { NULL,NULL},
/* 1CEDE */ { NULL,NULL},
/* 1CEDF */ { NULL,NULL},
/* 1CEE0 */ { "GEOMANTIC FIGURE POPULUS",NULL},
/* 1CEE1 */ { "GEOMANTIC FIGURE TRISTITIA",NULL},
/* 1CEE2 */ { "GEOMANTIC FIGURE ALBUS",NULL},
/* 1CEE3 */ { "GEOMANTIC FIGURE FORTUNA MAJOR",NULL},
/* 1CEE4 */ { "GEOMANTIC FIGURE RUBEUS",NULL},
/* 1CEE5 */ { "GEOMANTIC FIGURE ACQUISITIO",NULL},
/* 1CEE6 */ { "GEOMANTIC FIGURE CONJUNCTIO",NULL},
/* 1CEE7 */ { "GEOMANTIC FIGURE CAPUT DRACONIS",NULL},
/* 1CEE8 */ { "GEOMANTIC FIGURE LAETITIA",NULL},
/* 1CEE9 */ { "GEOMANTIC FIGURE CARCER",NULL},
/* 1CEEA */ { "GEOMANTIC FIGURE AMISSIO",NULL},
/* 1CEEB */ { "GEOMANTIC FIGURE PUELLA",NULL},
/* 1CEEC */ { "GEOMANTIC FIGURE FORTUNA MINOR",NULL},
/* 1CEED */ { "GEOMANTIC FIGURE PUER",NULL},
/* 1CEEE */ { "GEOMANTIC FIGURE CAUDA DRACONIS",NULL},
/* 1CEEF */ { "GEOMANTIC FIGURE VIA",NULL},
/* 1CEF0 */ { "MEDIUM SMALL WHITE CIRCLE WITH HORIZONTAL BAR","	* used in superscripted form to mean standard state (chemistry)\n"
	"	x (circle with horizontal bar - 29B5)"},
/* 1CEF1 */ { NULL,NULL},
/* 1CEF2 */ { NULL,NULL},
/* 1CEF3 */ { NULL,NULL},
/* 1CEF4 */ { NULL,NULL},
/* 1CEF5 */ { NULL,NULL},
/* 1CEF6 */ { NULL,NULL},
/* 1CEF7 */ { NULL,NULL},
/* 1CEF8 */ { NULL,NULL},
/* 1CEF9 */ { NULL,NULL},
/* 1CEFA */ { NULL,NULL},
/* 1CEFB */ { NULL,NULL},
/* 1CEFC */ { NULL,NULL},
/* 1CEFD */ { NULL,NULL},
/* 1CEFE */ { NULL,NULL},
/* 1CEFF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_CF[] = {
/* 1CF00 */ { "ZNAMENNY COMBINING MARK GORAZDO NIZKO S KRYZHEM ON LEFT",NULL},
/* 1CF01 */ { "ZNAMENNY COMBINING MARK NIZKO S KRYZHEM ON LEFT",NULL},
/* 1CF02 */ { "ZNAMENNY COMBINING MARK TSATA ON LEFT",NULL},
/* 1CF03 */ { "ZNAMENNY COMBINING MARK GORAZDO NIZKO ON LEFT",NULL},
/* 1CF04 */ { "ZNAMENNY COMBINING MARK NIZKO ON LEFT",NULL},
/* 1CF05 */ { "ZNAMENNY COMBINING MARK SREDNE ON LEFT",NULL},
/* 1CF06 */ { "ZNAMENNY COMBINING MARK MALO POVYSHE ON LEFT",NULL},
/* 1CF07 */ { "ZNAMENNY COMBINING MARK POVYSHE ON LEFT",NULL},
/* 1CF08 */ { "ZNAMENNY COMBINING MARK VYSOKO ON LEFT",NULL},
/* 1CF09 */ { "ZNAMENNY COMBINING MARK MALO POVYSHE S KHOKHLOM ON LEFT",NULL},
/* 1CF0A */ { "ZNAMENNY COMBINING MARK POVYSHE S KHOKHLOM ON LEFT",NULL},
/* 1CF0B */ { "ZNAMENNY COMBINING MARK VYSOKO S KHOKHLOM ON LEFT",NULL},
/* 1CF0C */ { "ZNAMENNY COMBINING MARK GORAZDO NIZKO S KRYZHEM ON RIGHT",NULL},
/* 1CF0D */ { "ZNAMENNY COMBINING MARK NIZKO S KRYZHEM ON RIGHT",NULL},
/* 1CF0E */ { "ZNAMENNY COMBINING MARK TSATA ON RIGHT",NULL},
/* 1CF0F */ { "ZNAMENNY COMBINING MARK GORAZDO NIZKO ON RIGHT",NULL},
/* 1CF10 */ { "ZNAMENNY COMBINING MARK NIZKO ON RIGHT",NULL},
/* 1CF11 */ { "ZNAMENNY COMBINING MARK SREDNE ON RIGHT",NULL},
/* 1CF12 */ { "ZNAMENNY COMBINING MARK MALO POVYSHE ON RIGHT",NULL},
/* 1CF13 */ { "ZNAMENNY COMBINING MARK POVYSHE ON RIGHT",NULL},
/* 1CF14 */ { "ZNAMENNY COMBINING MARK VYSOKO ON RIGHT",NULL},
/* 1CF15 */ { "ZNAMENNY COMBINING MARK MALO POVYSHE S KHOKHLOM ON RIGHT",NULL},
/* 1CF16 */ { "ZNAMENNY COMBINING MARK POVYSHE S KHOKHLOM ON RIGHT",NULL},
/* 1CF17 */ { "ZNAMENNY COMBINING MARK VYSOKO S KHOKHLOM ON RIGHT",NULL},
/* 1CF18 */ { "ZNAMENNY COMBINING MARK TSATA S KRYZHEM",NULL},
/* 1CF19 */ { "ZNAMENNY COMBINING MARK MALO POVYSHE S KRYZHEM",NULL},
/* 1CF1A */ { "ZNAMENNY COMBINING MARK STRANNO MALO POVYSHE",NULL},
/* 1CF1B */ { "ZNAMENNY COMBINING MARK POVYSHE S KRYZHEM",NULL},
/* 1CF1C */ { "ZNAMENNY COMBINING MARK POVYSHE STRANNO",NULL},
/* 1CF1D */ { "ZNAMENNY COMBINING MARK VYSOKO S KRYZHEM",NULL},
/* 1CF1E */ { "ZNAMENNY COMBINING MARK MALO POVYSHE STRANNO",NULL},
/* 1CF1F */ { "ZNAMENNY COMBINING MARK GORAZDO VYSOKO",NULL},
/* 1CF20 */ { "ZNAMENNY COMBINING MARK ZELO",NULL},
/* 1CF21 */ { "ZNAMENNY COMBINING MARK ON",NULL},
/* 1CF22 */ { "ZNAMENNY COMBINING MARK RAVNO",NULL},
/* 1CF23 */ { "ZNAMENNY COMBINING MARK TIKHAYA",NULL},
/* 1CF24 */ { "ZNAMENNY COMBINING MARK BORZAYA",NULL},
/* 1CF25 */ { "ZNAMENNY COMBINING MARK UDARKA",NULL},
/* 1CF26 */ { "ZNAMENNY COMBINING MARK PODVERTKA",NULL},
/* 1CF27 */ { "ZNAMENNY COMBINING MARK LOMKA",NULL},
/* 1CF28 */ { "ZNAMENNY COMBINING MARK KUPNAYA",NULL},
/* 1CF29 */ { "ZNAMENNY COMBINING MARK KACHKA",NULL},
/* 1CF2A */ { "ZNAMENNY COMBINING MARK ZEVOK",NULL},
/* 1CF2B */ { "ZNAMENNY COMBINING MARK SKOBA",NULL},
/* 1CF2C */ { "ZNAMENNY COMBINING MARK RAZSEKA",NULL},
/* 1CF2D */ { "ZNAMENNY COMBINING MARK KRYZH ON LEFT",NULL},
/* 1CF2E */ { NULL,NULL},
/* 1CF2F */ { NULL,NULL},
/* 1CF30 */ { "ZNAMENNY COMBINING TONAL RANGE MARK MRACHNO",NULL},
/* 1CF31 */ { "ZNAMENNY COMBINING TONAL RANGE MARK SVETLO",NULL},
/* 1CF32 */ { "ZNAMENNY COMBINING TONAL RANGE MARK TRESVETLO",NULL},
/* 1CF33 */ { "ZNAMENNY COMBINING MARK ZADERZHKA","	= ottyazhka"},
/* 1CF34 */ { "ZNAMENNY COMBINING MARK DEMESTVENNY ZADERZHKA",NULL},
/* 1CF35 */ { "ZNAMENNY COMBINING MARK OTSECHKA",NULL},
/* 1CF36 */ { "ZNAMENNY COMBINING MARK PODCHASHIE",NULL},
/* 1CF37 */ { "ZNAMENNY COMBINING MARK PODCHASHIE WITH VERTICAL STROKE",NULL},
/* 1CF38 */ { "ZNAMENNY COMBINING MARK CHASHKA",NULL},
/* 1CF39 */ { "ZNAMENNY COMBINING MARK CHASHKA POLNAYA",NULL},
/* 1CF3A */ { "ZNAMENNY COMBINING MARK OBLACHKO",NULL},
/* 1CF3B */ { "ZNAMENNY COMBINING MARK SOROCHYA NOZHKA","	= sokolik"},
/* 1CF3C */ { "ZNAMENNY COMBINING MARK TOCHKA",NULL},
/* 1CF3D */ { "ZNAMENNY COMBINING MARK DVOETOCHIE",NULL},
/* 1CF3E */ { "ZNAMENNY COMBINING ATTACHING VERTICAL OMET",NULL},
/* 1CF3F */ { "ZNAMENNY COMBINING MARK CURVED OMET",NULL},
/* 1CF40 */ { "ZNAMENNY COMBINING MARK KRYZH",NULL},
/* 1CF41 */ { "ZNAMENNY COMBINING LOWER TONAL RANGE INDICATOR",NULL},
/* 1CF42 */ { "ZNAMENNY PRIZNAK MODIFIER LEVEL-2",NULL},
/* 1CF43 */ { "ZNAMENNY PRIZNAK MODIFIER LEVEL-3",NULL},
/* 1CF44 */ { "ZNAMENNY PRIZNAK MODIFIER DIRECTION FLIP",NULL},
/* 1CF45 */ { "ZNAMENNY PRIZNAK MODIFIER KRYZH",NULL},
/* 1CF46 */ { "ZNAMENNY PRIZNAK MODIFIER ROG",NULL},
/* 1CF47 */ { NULL,NULL},
/* 1CF48 */ { NULL,NULL},
/* 1CF49 */ { NULL,NULL},
/* 1CF4A */ { NULL,NULL},
/* 1CF4B */ { NULL,NULL},
/* 1CF4C */ { NULL,NULL},
/* 1CF4D */ { NULL,NULL},
/* 1CF4E */ { NULL,NULL},
/* 1CF4F */ { NULL,NULL},
/* 1CF50 */ { "ZNAMENNY NEUME KRYUK",NULL},
/* 1CF51 */ { "ZNAMENNY NEUME KRYUK TIKHY",NULL},
/* 1CF52 */ { "ZNAMENNY NEUME PARAKLIT",NULL},
/* 1CF53 */ { "ZNAMENNY NEUME DVA V CHELNU",NULL},
/* 1CF54 */ { "ZNAMENNY NEUME KLYUCH","	= kryuk klyuchevoy"},
/* 1CF55 */ { "ZNAMENNY NEUME ZANOZHEK",NULL},
/* 1CF56 */ { "ZNAMENNY NEUME STOPITSA",NULL},
/* 1CF57 */ { "ZNAMENNY NEUME STOPITSA S OCHKOM",NULL},
/* 1CF58 */ { "ZNAMENNY NEUME PEREVODKA",NULL},
/* 1CF59 */ { "ZNAMENNY NEUME PEREVODKA NEPOSTOYANNAYA",NULL},
/* 1CF5A */ { "ZNAMENNY NEUME STOPITSA WITH SOROCHYA NOZHKA","	* not a decomposable character"},
/* 1CF5B */ { "ZNAMENNY NEUME CHELYUSTKA",NULL},
/* 1CF5C */ { "ZNAMENNY NEUME PALKA",NULL},
/* 1CF5D */ { "ZNAMENNY NEUME ZAPYATAYA",NULL},
/* 1CF5E */ { "ZNAMENNY NEUME GOLUBCHIK BORZY",NULL},
/* 1CF5F */ { "ZNAMENNY NEUME GOLUBCHIK TIKHY",NULL},
/* 1CF60 */ { "ZNAMENNY NEUME GOLUBCHIK MRACHNY",NULL},
/* 1CF61 */ { "ZNAMENNY NEUME GOLUBCHIK SVETLY",NULL},
/* 1CF62 */ { "ZNAMENNY NEUME GOLUBCHIK TRESVETLY","	= golubchik nepostoyanny"},
/* 1CF63 */ { "ZNAMENNY NEUME VRAKHIYA PROSTAYA",NULL},
/* 1CF64 */ { "ZNAMENNY NEUME VRAKHIYA MRACHNAYA",NULL},
/* 1CF65 */ { "ZNAMENNY NEUME VRAKHIYA SVETLAYA",NULL},
/* 1CF66 */ { "ZNAMENNY NEUME VRAKHIYA TRESVETLAYA","	= vrakhia nepostoyannaya"},
/* 1CF67 */ { "ZNAMENNY NEUME VRAKHIYA KLYUCHEVAYA PROSTAYA",NULL},
/* 1CF68 */ { "ZNAMENNY NEUME VRAKHIYA KLYUCHEVAYA MRACHNAYA",NULL},
/* 1CF69 */ { "ZNAMENNY NEUME VRAKHIYA KLYUCHEVAYA SVETLAYA",NULL},
/* 1CF6A */ { "ZNAMENNY NEUME VRAKHIYA KLYUCHEVAYA TRESVETLAYA","	= vrakhia klyuchevaya nepostoyannaya"},
/* 1CF6B */ { "ZNAMENNY NEUME DOUBLE ZAPYATAYA",NULL},
/* 1CF6C */ { "ZNAMENNY NEUME REVERSED CHELYUSTKA",NULL},
/* 1CF6D */ { "ZNAMENNY NEUME DERBITSA",NULL},
/* 1CF6E */ { "ZNAMENNY NEUME KHAMILO",NULL},
/* 1CF6F */ { "ZNAMENNY NEUME CHASHKA",NULL},
/* 1CF70 */ { "ZNAMENNY NEUME PODCHASHIE",NULL},
/* 1CF71 */ { "ZNAMENNY NEUME SKAMEYTSA MRACHNAYA",NULL},
/* 1CF72 */ { "ZNAMENNY NEUME SKAMEYTSA SVETLAYA",NULL},
/* 1CF73 */ { "ZNAMENNY NEUME SKAMEYTSA TRESVETLAYA",NULL},
/* 1CF74 */ { "ZNAMENNY NEUME SKAMEYTSA TIKHAYA",NULL},
/* 1CF75 */ { "ZNAMENNY NEUME DEMESTVENNY KLYUCH","	= skameytsa klyuchevaya"},
/* 1CF76 */ { "ZNAMENNY NEUME SKAMEYTSA KLYUCHEVAYA SVETLAYA",NULL},
/* 1CF77 */ { "ZNAMENNY NEUME SKAMEYTSA KLYUCHENEPOSTOYANNAYA",NULL},
/* 1CF78 */ { "ZNAMENNY NEUME SKAMEYTSA KLYUCHEVAYA TIKHAYA",NULL},
/* 1CF79 */ { "ZNAMENNY NEUME SKAMEYTSA DVOECHELNAYA PROSTAYA",NULL},
/* 1CF7A */ { "ZNAMENNY NEUME SKAMEYTSA DVOECHELNAYA SVETLAYA",NULL},
/* 1CF7B */ { "ZNAMENNY NEUME SKAMEYTSA DVOECHELNAYA NEPOSTOYANNAYA",NULL},
/* 1CF7C */ { "ZNAMENNY NEUME SKAMEYTSA DVOECHELNAYA KLYUCHEVAYA",NULL},
/* 1CF7D */ { "ZNAMENNY NEUME SLOZHITIE",NULL},
/* 1CF7E */ { "ZNAMENNY NEUME SLOZHITIE S ZAPYATOY",NULL},
/* 1CF7F */ { "ZNAMENNY NEUME SLOZHITIE ZAKRYTOE",NULL},
/* 1CF80 */ { "ZNAMENNY NEUME SLOZHITIE S KRYZHEM",NULL},
/* 1CF81 */ { "ZNAMENNY NEUME KRYZH",NULL},
/* 1CF82 */ { "ZNAMENNY NEUME ROG",NULL},
/* 1CF83 */ { "ZNAMENNY NEUME FITA",NULL},
/* 1CF84 */ { "ZNAMENNY NEUME KOBYLA",NULL},
/* 1CF85 */ { "ZNAMENNY NEUME ZMEYTSA","	= litso"},
/* 1CF86 */ { "ZNAMENNY NEUME STATYA",NULL},
/* 1CF87 */ { "ZNAMENNY NEUME STATYA S ZAPYATOY",NULL},
/* 1CF88 */ { "ZNAMENNY NEUME STATYA S KRYZHEM",NULL},
/* 1CF89 */ { "ZNAMENNY NEUME STATYA S ZAPYATOY I KRYZHEM",NULL},
/* 1CF8A */ { "ZNAMENNY NEUME STATYA S KRYZHEM I ZAPYATOY",NULL},
/* 1CF8B */ { "ZNAMENNY NEUME STATYA ZAKRYTAYA",NULL},
/* 1CF8C */ { "ZNAMENNY NEUME STATYA ZAKRYTAYA S ZAPYATOY",NULL},
/* 1CF8D */ { "ZNAMENNY NEUME STATYA S ROGOM",NULL},
/* 1CF8E */ { "ZNAMENNY NEUME STATYA S DVUMYA ZAPYATYMI",NULL},
/* 1CF8F */ { "ZNAMENNY NEUME STATYA S ZAPYATOY I PODCHASHIEM",NULL},
/* 1CF90 */ { "ZNAMENNY NEUME POLKULIZMY","	* not a decomposable character"},
/* 1CF91 */ { "ZNAMENNY NEUME STATYA NEPOSTOYANNAYA",NULL},
/* 1CF92 */ { "ZNAMENNY NEUME STRELA PROSTAYA",NULL},
/* 1CF93 */ { "ZNAMENNY NEUME STRELA MRACHNOTIKHAYA",NULL},
/* 1CF94 */ { "ZNAMENNY NEUME STRELA KRYZHEVAYA","	= strela polukryzhevaya"},
/* 1CF95 */ { "ZNAMENNY NEUME STRELA POLUPOVODNAYA",NULL},
/* 1CF96 */ { "ZNAMENNY NEUME STRELA POVODNAYA",NULL},
/* 1CF97 */ { "ZNAMENNY NEUME STRELA NEPOSTOYANNAYA",NULL},
/* 1CF98 */ { "ZNAMENNY NEUME STRELA KLYUCHEPOVODNAYA",NULL},
/* 1CF99 */ { "ZNAMENNY NEUME STRELA KLYUCHENEPOSTOYANNAYA",NULL},
/* 1CF9A */ { "ZNAMENNY NEUME STRELA TIKHAYA PUTNAYA",NULL},
/* 1CF9B */ { "ZNAMENNY NEUME STRELA DVOECHELNAYA",NULL},
/* 1CF9C */ { "ZNAMENNY NEUME STRELA DVOECHELNOKRYZHEVAYA",NULL},
/* 1CF9D */ { "ZNAMENNY NEUME STRELA DVOECHELNOPOVODNAYA",NULL},
/* 1CF9E */ { "ZNAMENNY NEUME STRELA DVOECHELNAYA KLYUCHEVAYA",NULL},
/* 1CF9F */ { "ZNAMENNY NEUME STRELA DVOECHELNOPOVODNAYA KLYUCHEVAYA",NULL},
/* 1CFA0 */ { "ZNAMENNY NEUME STRELA GROMNAYA WITH SINGLE ZAPYATAYA",NULL},
/* 1CFA1 */ { "ZNAMENNY NEUME STRELA GROMOPOVODNAYA WITH SINGLE ZAPYATAYA",NULL},
/* 1CFA2 */ { "ZNAMENNY NEUME STRELA GROMNAYA",NULL},
/* 1CFA3 */ { "ZNAMENNY NEUME STRELA GROMOPOVODNAYA",NULL},
/* 1CFA4 */ { "ZNAMENNY NEUME STRELA GROMOPOVODNAYA WITH DOUBLE ZAPYATAYA",NULL},
/* 1CFA5 */ { "ZNAMENNY NEUME STRELA GROMOKRYZHEVAYA",NULL},
/* 1CFA6 */ { "ZNAMENNY NEUME STRELA GROMOKRYZHEVAYA POVODNAYA","	= strela gromomrachnaya s kryzhem"},
/* 1CFA7 */ { "ZNAMENNY NEUME MECHIK",NULL},
/* 1CFA8 */ { "ZNAMENNY NEUME MECHIK POVODNY",NULL},
/* 1CFA9 */ { "ZNAMENNY NEUME MECHIK KLYUCHEVOY",NULL},
/* 1CFAA */ { "ZNAMENNY NEUME MECHIK KLYUCHEPOVODNY",NULL},
/* 1CFAB */ { "ZNAMENNY NEUME MECHIK KLYUCHENEPOSTOYANNY",NULL},
/* 1CFAC */ { "ZNAMENNY NEUME STRELA TRYASOGLASNAYA",NULL},
/* 1CFAD */ { "ZNAMENNY NEUME STRELA TRYASOPOVODNAYA",NULL},
/* 1CFAE */ { "ZNAMENNY NEUME STRELA TRYASOSTRELNAYA",NULL},
/* 1CFAF */ { "ZNAMENNY NEUME OSOKA",NULL},
/* 1CFB0 */ { "ZNAMENNY NEUME OSOKA SVETLAYA",NULL},
/* 1CFB1 */ { "ZNAMENNY NEUME OSOKA TRESVETLAYA","	= osoka nepostoyannaya"},
/* 1CFB2 */ { "ZNAMENNY NEUME OSOKA KRYUKOVAYA SVETLAYA",NULL},
/* 1CFB3 */ { "ZNAMENNY NEUME OSOKA KLYUCHEVAYA SVETLAYA",NULL},
/* 1CFB4 */ { "ZNAMENNY NEUME OSOKA KLYUCHEVAYA NEPOSTOYANNAYA",NULL},
/* 1CFB5 */ { "ZNAMENNY NEUME STRELA KRYUKOVAYA",NULL},
/* 1CFB6 */ { "ZNAMENNY NEUME STRELA KRYUKOVAYA POVODNAYA",NULL},
/* 1CFB7 */ { "ZNAMENNY NEUME STRELA KRYUKOVAYA GROMNAYA WITH SINGLE ZAPYATAYA",NULL},
/* 1CFB8 */ { "ZNAMENNY NEUME STRELA KRYUKOVAYA GROMOPOVODNAYA WITH SINGLE ZAPYATAYA",NULL},
/* 1CFB9 */ { "ZNAMENNY NEUME STRELA KRYUKOVAYA GROMNAYA",NULL},
/* 1CFBA */ { "ZNAMENNY NEUME STRELA KRYUKOVAYA GROMOPOVODNAYA",NULL},
/* 1CFBB */ { "ZNAMENNY NEUME STRELA KRYUKOVAYA GROMOPOVODNAYA WITH DOUBLE ZAPYATAYA",NULL},
/* 1CFBC */ { "ZNAMENNY NEUME STRELA KRYUKOVAYA GROMOKRYZHEVAYA",NULL},
/* 1CFBD */ { "ZNAMENNY NEUME STRELA KRYUKOVAYA GROMOKRYZHEVAYA POVODNAYA","	= strela kryukovaya gromomrachnaya s kryzhem"},
/* 1CFBE */ { "ZNAMENNY NEUME STRELA KRYUKOVAYA TRYASKA",NULL},
/* 1CFBF */ { "ZNAMENNY NEUME KUFISMA",NULL},
/* 1CFC0 */ { "ZNAMENNY NEUME OBLAKO",NULL},
/* 1CFC1 */ { "ZNAMENNY NEUME DUDA",NULL},
/* 1CFC2 */ { "ZNAMENNY NEUME NEMKA",NULL},
/* 1CFC3 */ { "ZNAMENNY NEUME PAUK",NULL},
/* 1CFC4 */ { NULL,NULL},
/* 1CFC5 */ { NULL,NULL},
/* 1CFC6 */ { NULL,NULL},
/* 1CFC7 */ { NULL,NULL},
/* 1CFC8 */ { NULL,NULL},
/* 1CFC9 */ { NULL,NULL},
/* 1CFCA */ { NULL,NULL},
/* 1CFCB */ { NULL,NULL},
/* 1CFCC */ { NULL,NULL},
/* 1CFCD */ { NULL,NULL},
/* 1CFCE */ { NULL,NULL},
/* 1CFCF */ { NULL,NULL},
/* 1CFD0 */ { NULL,NULL},
/* 1CFD1 */ { NULL,NULL},
/* 1CFD2 */ { NULL,NULL},
/* 1CFD3 */ { NULL,NULL},
/* 1CFD4 */ { NULL,NULL},
/* 1CFD5 */ { NULL,NULL},
/* 1CFD6 */ { NULL,NULL},
/* 1CFD7 */ { NULL,NULL},
/* 1CFD8 */ { NULL,NULL},
/* 1CFD9 */ { NULL,NULL},
/* 1CFDA */ { NULL,NULL},
/* 1CFDB */ { NULL,NULL},
/* 1CFDC */ { NULL,NULL},
/* 1CFDD */ { NULL,NULL},
/* 1CFDE */ { NULL,NULL},
/* 1CFDF */ { NULL,NULL},
/* 1CFE0 */ { NULL,NULL},
/* 1CFE1 */ { NULL,NULL},
/* 1CFE2 */ { NULL,NULL},
/* 1CFE3 */ { NULL,NULL},
/* 1CFE4 */ { NULL,NULL},
/* 1CFE5 */ { NULL,NULL},
/* 1CFE6 */ { NULL,NULL},
/* 1CFE7 */ { NULL,NULL},
/* 1CFE8 */ { NULL,NULL},
/* 1CFE9 */ { NULL,NULL},
/* 1CFEA */ { NULL,NULL},
/* 1CFEB */ { NULL,NULL},
/* 1CFEC */ { NULL,NULL},
/* 1CFED */ { NULL,NULL},
/* 1CFEE */ { NULL,NULL},
/* 1CFEF */ { NULL,NULL},
/* 1CFF0 */ { NULL,NULL},
/* 1CFF1 */ { NULL,NULL},
/* 1CFF2 */ { NULL,NULL},
/* 1CFF3 */ { NULL,NULL},
/* 1CFF4 */ { NULL,NULL},
/* 1CFF5 */ { NULL,NULL},
/* 1CFF6 */ { NULL,NULL},
/* 1CFF7 */ { NULL,NULL},
/* 1CFF8 */ { NULL,NULL},
/* 1CFF9 */ { NULL,NULL},
/* 1CFFA */ { NULL,NULL},
/* 1CFFB */ { NULL,NULL},
/* 1CFFC */ { NULL,NULL},
/* 1CFFD */ { NULL,NULL},
/* 1CFFE */ { NULL,NULL},
/* 1CFFF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_D0[] = {
/* 1D000 */ { "BYZANTINE MUSICAL SYMBOL PSILI",NULL},
/* 1D001 */ { "BYZANTINE MUSICAL SYMBOL DASEIA",NULL},
/* 1D002 */ { "BYZANTINE MUSICAL SYMBOL PERISPOMENI",NULL},
/* 1D003 */ { "BYZANTINE MUSICAL SYMBOL OXEIA EKFONITIKON",NULL},
/* 1D004 */ { "BYZANTINE MUSICAL SYMBOL OXEIA DIPLI",NULL},
/* 1D005 */ { "BYZANTINE MUSICAL SYMBOL VAREIA EKFONITIKON",NULL},
/* 1D006 */ { "BYZANTINE MUSICAL SYMBOL VAREIA DIPLI",NULL},
/* 1D007 */ { "BYZANTINE MUSICAL SYMBOL KATHISTI",NULL},
/* 1D008 */ { "BYZANTINE MUSICAL SYMBOL SYRMATIKI",NULL},
/* 1D009 */ { "BYZANTINE MUSICAL SYMBOL PARAKLITIKI",NULL},
/* 1D00A */ { "BYZANTINE MUSICAL SYMBOL YPOKRISIS",NULL},
/* 1D00B */ { "BYZANTINE MUSICAL SYMBOL YPOKRISIS DIPLI",NULL},
/* 1D00C */ { "BYZANTINE MUSICAL SYMBOL KREMASTI",NULL},
/* 1D00D */ { "BYZANTINE MUSICAL SYMBOL APESO EKFONITIKON",NULL},
/* 1D00E */ { "BYZANTINE MUSICAL SYMBOL EXO EKFONITIKON",NULL},
/* 1D00F */ { "BYZANTINE MUSICAL SYMBOL TELEIA",NULL},
/* 1D010 */ { "BYZANTINE MUSICAL SYMBOL KENTIMATA",NULL},
/* 1D011 */ { "BYZANTINE MUSICAL SYMBOL APOSTROFOS",NULL},
/* 1D012 */ { "BYZANTINE MUSICAL SYMBOL APOSTROFOS DIPLI",NULL},
/* 1D013 */ { "BYZANTINE MUSICAL SYMBOL SYNEVMA",NULL},
/* 1D014 */ { "BYZANTINE MUSICAL SYMBOL THITA",NULL},
/* 1D015 */ { "BYZANTINE MUSICAL SYMBOL OLIGON ARCHAION",NULL},
/* 1D016 */ { "BYZANTINE MUSICAL SYMBOL GORGON ARCHAION",NULL},
/* 1D017 */ { "BYZANTINE MUSICAL SYMBOL PSILON",NULL},
/* 1D018 */ { "BYZANTINE MUSICAL SYMBOL CHAMILON",NULL},
/* 1D019 */ { "BYZANTINE MUSICAL SYMBOL VATHY",NULL},
/* 1D01A */ { "BYZANTINE MUSICAL SYMBOL ISON ARCHAION",NULL},
/* 1D01B */ { "BYZANTINE MUSICAL SYMBOL KENTIMA ARCHAION",NULL},
/* 1D01C */ { "BYZANTINE MUSICAL SYMBOL KENTIMATA ARCHAION",NULL},
/* 1D01D */ { "BYZANTINE MUSICAL SYMBOL SAXIMATA",NULL},
/* 1D01E */ { "BYZANTINE MUSICAL SYMBOL PARICHON",NULL},
/* 1D01F */ { "BYZANTINE MUSICAL SYMBOL STAVROS APODEXIA",NULL},
/* 1D020 */ { "BYZANTINE MUSICAL SYMBOL OXEIAI ARCHAION",NULL},
/* 1D021 */ { "BYZANTINE MUSICAL SYMBOL VAREIAI ARCHAION",NULL},
/* 1D022 */ { "BYZANTINE MUSICAL SYMBOL APODERMA ARCHAION",NULL},
/* 1D023 */ { "BYZANTINE MUSICAL SYMBOL APOTHEMA",NULL},
/* 1D024 */ { "BYZANTINE MUSICAL SYMBOL KLASMA",NULL},
/* 1D025 */ { "BYZANTINE MUSICAL SYMBOL REVMA",NULL},
/* 1D026 */ { "BYZANTINE MUSICAL SYMBOL PIASMA ARCHAION",NULL},
/* 1D027 */ { "BYZANTINE MUSICAL SYMBOL TINAGMA",NULL},
/* 1D028 */ { "BYZANTINE MUSICAL SYMBOL ANATRICHISMA",NULL},
/* 1D029 */ { "BYZANTINE MUSICAL SYMBOL SEISMA",NULL},
/* 1D02A */ { "BYZANTINE MUSICAL SYMBOL SYNAGMA ARCHAION",NULL},
/* 1D02B */ { "BYZANTINE MUSICAL SYMBOL SYNAGMA META STAVROU",NULL},
/* 1D02C */ { "BYZANTINE MUSICAL SYMBOL OYRANISMA ARCHAION",NULL},
/* 1D02D */ { "BYZANTINE MUSICAL SYMBOL THEMA",NULL},
/* 1D02E */ { "BYZANTINE MUSICAL SYMBOL LEMOI",NULL},
/* 1D02F */ { "BYZANTINE MUSICAL SYMBOL DYO",NULL},
/* 1D030 */ { "BYZANTINE MUSICAL SYMBOL TRIA",NULL},
/* 1D031 */ { "BYZANTINE MUSICAL SYMBOL TESSERA",NULL},
/* 1D032 */ { "BYZANTINE MUSICAL SYMBOL KRATIMATA",NULL},
/* 1D033 */ { "BYZANTINE MUSICAL SYMBOL APESO EXO NEO",NULL},
/* 1D034 */ { "BYZANTINE MUSICAL SYMBOL FTHORA ARCHAION",NULL},
/* 1D035 */ { "BYZANTINE MUSICAL SYMBOL IMIFTHORA",NULL},
/* 1D036 */ { "BYZANTINE MUSICAL SYMBOL TROMIKON ARCHAION",NULL},
/* 1D037 */ { "BYZANTINE MUSICAL SYMBOL KATAVA TROMIKON",NULL},
/* 1D038 */ { "BYZANTINE MUSICAL SYMBOL PELASTON",NULL},
/* 1D039 */ { "BYZANTINE MUSICAL SYMBOL PSIFISTON",NULL},
/* 1D03A */ { "BYZANTINE MUSICAL SYMBOL KONTEVMA",NULL},
/* 1D03B */ { "BYZANTINE MUSICAL SYMBOL CHOREVMA ARCHAION",NULL},
/* 1D03C */ { "BYZANTINE MUSICAL SYMBOL RAPISMA",NULL},
/* 1D03D */ { "BYZANTINE MUSICAL SYMBOL PARAKALESMA ARCHAION",NULL},
/* 1D03E */ { "BYZANTINE MUSICAL SYMBOL PARAKLITIKI ARCHAION",NULL},
/* 1D03F */ { "BYZANTINE MUSICAL SYMBOL ICHADIN",NULL},
/* 1D040 */ { "BYZANTINE MUSICAL SYMBOL NANA",NULL},
/* 1D041 */ { "BYZANTINE MUSICAL SYMBOL PETASMA",NULL},
/* 1D042 */ { "BYZANTINE MUSICAL SYMBOL KONTEVMA ALLO",NULL},
/* 1D043 */ { "BYZANTINE MUSICAL SYMBOL TROMIKON ALLO",NULL},
/* 1D044 */ { "BYZANTINE MUSICAL SYMBOL STRAGGISMATA",NULL},
/* 1D045 */ { "BYZANTINE MUSICAL SYMBOL GRONTHISMATA",NULL},
/* 1D046 */ { "BYZANTINE MUSICAL SYMBOL ISON NEO",NULL},
/* 1D047 */ { "BYZANTINE MUSICAL SYMBOL OLIGON NEO",NULL},
/* 1D048 */ { "BYZANTINE MUSICAL SYMBOL OXEIA NEO",NULL},
/* 1D049 */ { "BYZANTINE MUSICAL SYMBOL PETASTI",NULL},
/* 1D04A */ { "BYZANTINE MUSICAL SYMBOL KOUFISMA",NULL},
/* 1D04B */ { "BYZANTINE MUSICAL SYMBOL PETASTOKOUFISMA",NULL},
/* 1D04C */ { "BYZANTINE MUSICAL SYMBOL KRATIMOKOUFISMA",NULL},
/* 1D04D */ { "BYZANTINE MUSICAL SYMBOL PELASTON NEO",NULL},
/* 1D04E */ { "BYZANTINE MUSICAL SYMBOL KENTIMATA NEO ANO",NULL},
/* 1D04F */ { "BYZANTINE MUSICAL SYMBOL KENTIMA NEO ANO",NULL},
/* 1D050 */ { "BYZANTINE MUSICAL SYMBOL YPSILI",NULL},
/* 1D051 */ { "BYZANTINE MUSICAL SYMBOL APOSTROFOS NEO",NULL},
/* 1D052 */ { "BYZANTINE MUSICAL SYMBOL APOSTROFOI SYNDESMOS NEO",NULL},
/* 1D053 */ { "BYZANTINE MUSICAL SYMBOL YPORROI",NULL},
/* 1D054 */ { "BYZANTINE MUSICAL SYMBOL KRATIMOYPORROON",NULL},
/* 1D055 */ { "BYZANTINE MUSICAL SYMBOL ELAFRON",NULL},
/* 1D056 */ { "BYZANTINE MUSICAL SYMBOL CHAMILI",NULL},
/* 1D057 */ { "BYZANTINE MUSICAL SYMBOL MIKRON ISON",NULL},
/* 1D058 */ { "BYZANTINE MUSICAL SYMBOL VAREIA NEO",NULL},
/* 1D059 */ { "BYZANTINE MUSICAL SYMBOL PIASMA NEO",NULL},
/* 1D05A */ { "BYZANTINE MUSICAL SYMBOL PSIFISTON NEO",NULL},
/* 1D05B */ { "BYZANTINE MUSICAL SYMBOL OMALON",NULL},
/* 1D05C */ { "BYZANTINE MUSICAL SYMBOL ANTIKENOMA",NULL},
/* 1D05D */ { "BYZANTINE MUSICAL SYMBOL LYGISMA",NULL},
/* 1D05E */ { "BYZANTINE MUSICAL SYMBOL PARAKLITIKI NEO",NULL},
/* 1D05F */ { "BYZANTINE MUSICAL SYMBOL PARAKALESMA NEO",NULL},
/* 1D060 */ { "BYZANTINE MUSICAL SYMBOL ETERON PARAKALESMA",NULL},
/* 1D061 */ { "BYZANTINE MUSICAL SYMBOL KYLISMA",NULL},
/* 1D062 */ { "BYZANTINE MUSICAL SYMBOL ANTIKENOKYLISMA",NULL},
/* 1D063 */ { "BYZANTINE MUSICAL SYMBOL TROMIKON NEO",NULL},
/* 1D064 */ { "BYZANTINE MUSICAL SYMBOL EKSTREPTON",NULL},
/* 1D065 */ { "BYZANTINE MUSICAL SYMBOL SYNAGMA NEO",NULL},
/* 1D066 */ { "BYZANTINE MUSICAL SYMBOL SYRMA",NULL},
/* 1D067 */ { "BYZANTINE MUSICAL SYMBOL CHOREVMA NEO",NULL},
/* 1D068 */ { "BYZANTINE MUSICAL SYMBOL EPEGERMA",NULL},
/* 1D069 */ { "BYZANTINE MUSICAL SYMBOL SEISMA NEO",NULL},
/* 1D06A */ { "BYZANTINE MUSICAL SYMBOL XIRON KLASMA",NULL},
/* 1D06B */ { "BYZANTINE MUSICAL SYMBOL TROMIKOPSIFISTON",NULL},
/* 1D06C */ { "BYZANTINE MUSICAL SYMBOL PSIFISTOLYGISMA",NULL},
/* 1D06D */ { "BYZANTINE MUSICAL SYMBOL TROMIKOLYGISMA",NULL},
/* 1D06E */ { "BYZANTINE MUSICAL SYMBOL TROMIKOPARAKALESMA",NULL},
/* 1D06F */ { "BYZANTINE MUSICAL SYMBOL PSIFISTOPARAKALESMA",NULL},
/* 1D070 */ { "BYZANTINE MUSICAL SYMBOL TROMIKOSYNAGMA",NULL},
/* 1D071 */ { "BYZANTINE MUSICAL SYMBOL PSIFISTOSYNAGMA",NULL},
/* 1D072 */ { "BYZANTINE MUSICAL SYMBOL GORGOSYNTHETON",NULL},
/* 1D073 */ { "BYZANTINE MUSICAL SYMBOL ARGOSYNTHETON",NULL},
/* 1D074 */ { "BYZANTINE MUSICAL SYMBOL ETERON ARGOSYNTHETON",NULL},
/* 1D075 */ { "BYZANTINE MUSICAL SYMBOL OYRANISMA NEO",NULL},
/* 1D076 */ { "BYZANTINE MUSICAL SYMBOL THEMATISMOS ESO",NULL},
/* 1D077 */ { "BYZANTINE MUSICAL SYMBOL THEMATISMOS EXO",NULL},
/* 1D078 */ { "BYZANTINE MUSICAL SYMBOL THEMA APLOUN",NULL},
/* 1D079 */ { "BYZANTINE MUSICAL SYMBOL THES KAI APOTHES",NULL},
/* 1D07A */ { "BYZANTINE MUSICAL SYMBOL KATAVASMA",NULL},
/* 1D07B */ { "BYZANTINE MUSICAL SYMBOL ENDOFONON",NULL},
/* 1D07C */ { "BYZANTINE MUSICAL SYMBOL YFEN KATO",NULL},
/* 1D07D */ { "BYZANTINE MUSICAL SYMBOL YFEN ANO",NULL},
/* 1D07E */ { "BYZANTINE MUSICAL SYMBOL STAVROS",NULL},
/* 1D07F */ { "BYZANTINE MUSICAL SYMBOL KLASMA ANO",NULL},
/* 1D080 */ { "BYZANTINE MUSICAL SYMBOL DIPLI ARCHAION",NULL},
/* 1D081 */ { "BYZANTINE MUSICAL SYMBOL KRATIMA ARCHAION",NULL},
/* 1D082 */ { "BYZANTINE MUSICAL SYMBOL KRATIMA ALLO",NULL},
/* 1D083 */ { "BYZANTINE MUSICAL SYMBOL KRATIMA NEO",NULL},
/* 1D084 */ { "BYZANTINE MUSICAL SYMBOL APODERMA NEO",NULL},
/* 1D085 */ { "BYZANTINE MUSICAL SYMBOL APLI",NULL},
/* 1D086 */ { "BYZANTINE MUSICAL SYMBOL DIPLI",NULL},
/* 1D087 */ { "BYZANTINE MUSICAL SYMBOL TRIPLI",NULL},
/* 1D088 */ { "BYZANTINE MUSICAL SYMBOL TETRAPLI",NULL},
/* 1D089 */ { "BYZANTINE MUSICAL SYMBOL KORONIS",NULL},
/* 1D08A */ { "BYZANTINE MUSICAL SYMBOL LEIMMA ENOS CHRONOU",NULL},
/* 1D08B */ { "BYZANTINE MUSICAL SYMBOL LEIMMA DYO CHRONON",NULL},
/* 1D08C */ { "BYZANTINE MUSICAL SYMBOL LEIMMA TRION CHRONON",NULL},
/* 1D08D */ { "BYZANTINE MUSICAL SYMBOL LEIMMA TESSARON CHRONON",NULL},
/* 1D08E */ { "BYZANTINE MUSICAL SYMBOL LEIMMA IMISEOS CHRONOU",NULL},
/* 1D08F */ { "BYZANTINE MUSICAL SYMBOL GORGON NEO ANO",NULL},
/* 1D090 */ { "BYZANTINE MUSICAL SYMBOL GORGON PARESTIGMENON ARISTERA",NULL},
/* 1D091 */ { "BYZANTINE MUSICAL SYMBOL GORGON PARESTIGMENON DEXIA",NULL},
/* 1D092 */ { "BYZANTINE MUSICAL SYMBOL DIGORGON",NULL},
/* 1D093 */ { "BYZANTINE MUSICAL SYMBOL DIGORGON PARESTIGMENON ARISTERA KATO",NULL},
/* 1D094 */ { "BYZANTINE MUSICAL SYMBOL DIGORGON PARESTIGMENON ARISTERA ANO",NULL},
/* 1D095 */ { "BYZANTINE MUSICAL SYMBOL DIGORGON PARESTIGMENON DEXIA",NULL},
/* 1D096 */ { "BYZANTINE MUSICAL SYMBOL TRIGORGON",NULL},
/* 1D097 */ { "BYZANTINE MUSICAL SYMBOL ARGON",NULL},
/* 1D098 */ { "BYZANTINE MUSICAL SYMBOL IMIDIARGON","	* called diargon by some authorities"},
/* 1D099 */ { "BYZANTINE MUSICAL SYMBOL DIARGON","	* called triargon by some authorities"},
/* 1D09A */ { "BYZANTINE MUSICAL SYMBOL AGOGI POLI ARGI",NULL},
/* 1D09B */ { "BYZANTINE MUSICAL SYMBOL AGOGI ARGOTERI",NULL},
/* 1D09C */ { "BYZANTINE MUSICAL SYMBOL AGOGI ARGI",NULL},
/* 1D09D */ { "BYZANTINE MUSICAL SYMBOL AGOGI METRIA",NULL},
/* 1D09E */ { "BYZANTINE MUSICAL SYMBOL AGOGI MESI",NULL},
/* 1D09F */ { "BYZANTINE MUSICAL SYMBOL AGOGI GORGI",NULL},
/* 1D0A0 */ { "BYZANTINE MUSICAL SYMBOL AGOGI GORGOTERI",NULL},
/* 1D0A1 */ { "BYZANTINE MUSICAL SYMBOL AGOGI POLI GORGI",NULL},
/* 1D0A2 */ { "BYZANTINE MUSICAL SYMBOL MARTYRIA PROTOS ICHOS",NULL},
/* 1D0A3 */ { "BYZANTINE MUSICAL SYMBOL MARTYRIA ALLI PROTOS ICHOS",NULL},
/* 1D0A4 */ { "BYZANTINE MUSICAL SYMBOL MARTYRIA DEYTEROS ICHOS",NULL},
/* 1D0A5 */ { "BYZANTINE MUSICAL SYMBOL MARTYRIA ALLI DEYTEROS ICHOS",NULL},
/* 1D0A6 */ { "BYZANTINE MUSICAL SYMBOL MARTYRIA TRITOS ICHOS",NULL},
/* 1D0A7 */ { "BYZANTINE MUSICAL SYMBOL MARTYRIA TRIFONIAS",NULL},
/* 1D0A8 */ { "BYZANTINE MUSICAL SYMBOL MARTYRIA TETARTOS ICHOS",NULL},
/* 1D0A9 */ { "BYZANTINE MUSICAL SYMBOL MARTYRIA TETARTOS LEGETOS ICHOS",NULL},
/* 1D0AA */ { "BYZANTINE MUSICAL SYMBOL MARTYRIA LEGETOS ICHOS",NULL},
/* 1D0AB */ { "BYZANTINE MUSICAL SYMBOL MARTYRIA PLAGIOS ICHOS",NULL},
/* 1D0AC */ { "BYZANTINE MUSICAL SYMBOL ISAKIA TELOUS ICHIMATOS",NULL},
/* 1D0AD */ { "BYZANTINE MUSICAL SYMBOL APOSTROFOI TELOUS ICHIMATOS",NULL},
/* 1D0AE */ { "BYZANTINE MUSICAL SYMBOL FANEROSIS TETRAFONIAS",NULL},
/* 1D0AF */ { "BYZANTINE MUSICAL SYMBOL FANEROSIS MONOFONIAS",NULL},
/* 1D0B0 */ { "BYZANTINE MUSICAL SYMBOL FANEROSIS DIFONIAS",NULL},
/* 1D0B1 */ { "BYZANTINE MUSICAL SYMBOL MARTYRIA VARYS ICHOS",NULL},
/* 1D0B2 */ { "BYZANTINE MUSICAL SYMBOL MARTYRIA PROTOVARYS ICHOS",NULL},
/* 1D0B3 */ { "BYZANTINE MUSICAL SYMBOL MARTYRIA PLAGIOS TETARTOS ICHOS",NULL},
/* 1D0B4 */ { "BYZANTINE MUSICAL SYMBOL GORTHMIKON N APLOUN","	* used in intonation formulas instead of nu, before phonemes a, i, o, u\n"
	"	x (greek small letter nu - 03BD)"},
/* 1D0B5 */ { "BYZANTINE MUSICAL SYMBOL GORTHMIKON N DIPLOUN","	* used in intonation formulas instead of nu, before phoneme e\n"
	"	x (greek small letter nu - 03BD)"},
/* 1D0B6 */ { "BYZANTINE MUSICAL SYMBOL ENARXIS KAI FTHORA VOU",NULL},
/* 1D0B7 */ { "BYZANTINE MUSICAL SYMBOL IMIFONON",NULL},
/* 1D0B8 */ { "BYZANTINE MUSICAL SYMBOL IMIFTHORON",NULL},
/* 1D0B9 */ { "BYZANTINE MUSICAL SYMBOL FTHORA ARCHAION DEYTEROU ICHOU",NULL},
/* 1D0BA */ { "BYZANTINE MUSICAL SYMBOL FTHORA DIATONIKI PA",NULL},
/* 1D0BB */ { "BYZANTINE MUSICAL SYMBOL FTHORA DIATONIKI NANA",NULL},
/* 1D0BC */ { "BYZANTINE MUSICAL SYMBOL FTHORA NAOS ICHOS",NULL},
/* 1D0BD */ { "BYZANTINE MUSICAL SYMBOL FTHORA DIATONIKI DI",NULL},
/* 1D0BE */ { "BYZANTINE MUSICAL SYMBOL FTHORA SKLIRON DIATONON DI",NULL},
/* 1D0BF */ { "BYZANTINE MUSICAL SYMBOL FTHORA DIATONIKI KE",NULL},
/* 1D0C0 */ { "BYZANTINE MUSICAL SYMBOL FTHORA DIATONIKI ZO",NULL},
/* 1D0C1 */ { "BYZANTINE MUSICAL SYMBOL FTHORA DIATONIKI NI KATO",NULL},
/* 1D0C2 */ { "BYZANTINE MUSICAL SYMBOL FTHORA DIATONIKI NI ANO",NULL},
/* 1D0C3 */ { "BYZANTINE MUSICAL SYMBOL FTHORA MALAKON CHROMA DIFONIAS",NULL},
/* 1D0C4 */ { "BYZANTINE MUSICAL SYMBOL FTHORA MALAKON CHROMA MONOFONIAS",NULL},
/* 1D0C5 */ { "BYZANTINE MUSICAL SYMBOL FHTORA SKLIRON CHROMA VASIS","	% BYZANTINE MUSICAL SYMBOL FTHORA SKLIRON CHROMA VASIS\n"
	"	* misspelling of \"FTHORA\" in character name is a known defect"},
/* 1D0C6 */ { "BYZANTINE MUSICAL SYMBOL FTHORA SKLIRON CHROMA SYNAFI",NULL},
/* 1D0C7 */ { "BYZANTINE MUSICAL SYMBOL FTHORA NENANO",NULL},
/* 1D0C8 */ { "BYZANTINE MUSICAL SYMBOL CHROA ZYGOS",NULL},
/* 1D0C9 */ { "BYZANTINE MUSICAL SYMBOL CHROA KLITON",NULL},
/* 1D0CA */ { "BYZANTINE MUSICAL SYMBOL CHROA SPATHI",NULL},
/* 1D0CB */ { "BYZANTINE MUSICAL SYMBOL FTHORA I YFESIS TETARTIMORION",NULL},
/* 1D0CC */ { "BYZANTINE MUSICAL SYMBOL FTHORA ENARMONIOS ANTIFONIA",NULL},
/* 1D0CD */ { "BYZANTINE MUSICAL SYMBOL YFESIS TRITIMORION",NULL},
/* 1D0CE */ { "BYZANTINE MUSICAL SYMBOL DIESIS TRITIMORION",NULL},
/* 1D0CF */ { "BYZANTINE MUSICAL SYMBOL DIESIS TETARTIMORION",NULL},
/* 1D0D0 */ { "BYZANTINE MUSICAL SYMBOL DIESIS APLI DYO DODEKATA",NULL},
/* 1D0D1 */ { "BYZANTINE MUSICAL SYMBOL DIESIS MONOGRAMMOS TESSERA DODEKATA",NULL},
/* 1D0D2 */ { "BYZANTINE MUSICAL SYMBOL DIESIS DIGRAMMOS EX DODEKATA",NULL},
/* 1D0D3 */ { "BYZANTINE MUSICAL SYMBOL DIESIS TRIGRAMMOS OKTO DODEKATA",NULL},
/* 1D0D4 */ { "BYZANTINE MUSICAL SYMBOL YFESIS APLI DYO DODEKATA",NULL},
/* 1D0D5 */ { "BYZANTINE MUSICAL SYMBOL YFESIS MONOGRAMMOS TESSERA DODEKATA",NULL},
/* 1D0D6 */ { "BYZANTINE MUSICAL SYMBOL YFESIS DIGRAMMOS EX DODEKATA",NULL},
/* 1D0D7 */ { "BYZANTINE MUSICAL SYMBOL YFESIS TRIGRAMMOS OKTO DODEKATA",NULL},
/* 1D0D8 */ { "BYZANTINE MUSICAL SYMBOL GENIKI DIESIS",NULL},
/* 1D0D9 */ { "BYZANTINE MUSICAL SYMBOL GENIKI YFESIS",NULL},
/* 1D0DA */ { "BYZANTINE MUSICAL SYMBOL DIASTOLI APLI MIKRI","	x (musical symbol short barline - 1D105)"},
/* 1D0DB */ { "BYZANTINE MUSICAL SYMBOL DIASTOLI APLI MEGALI","	x (musical symbol single barline - 1D100)"},
/* 1D0DC */ { "BYZANTINE MUSICAL SYMBOL DIASTOLI DIPLI",NULL},
/* 1D0DD */ { "BYZANTINE MUSICAL SYMBOL DIASTOLI THESEOS",NULL},
/* 1D0DE */ { "BYZANTINE MUSICAL SYMBOL SIMANSIS THESEOS",NULL},
/* 1D0DF */ { "BYZANTINE MUSICAL SYMBOL SIMANSIS THESEOS DISIMOU",NULL},
/* 1D0E0 */ { "BYZANTINE MUSICAL SYMBOL SIMANSIS THESEOS TRISIMOU",NULL},
/* 1D0E1 */ { "BYZANTINE MUSICAL SYMBOL SIMANSIS THESEOS TETRASIMOU",NULL},
/* 1D0E2 */ { "BYZANTINE MUSICAL SYMBOL SIMANSIS ARSEOS",NULL},
/* 1D0E3 */ { "BYZANTINE MUSICAL SYMBOL SIMANSIS ARSEOS DISIMOU",NULL},
/* 1D0E4 */ { "BYZANTINE MUSICAL SYMBOL SIMANSIS ARSEOS TRISIMOU",NULL},
/* 1D0E5 */ { "BYZANTINE MUSICAL SYMBOL SIMANSIS ARSEOS TETRASIMOU",NULL},
/* 1D0E6 */ { "BYZANTINE MUSICAL SYMBOL DIGRAMMA GG",NULL},
/* 1D0E7 */ { "BYZANTINE MUSICAL SYMBOL DIFTOGGOS OU","	x (latin small letter ou - 0223)"},
/* 1D0E8 */ { "BYZANTINE MUSICAL SYMBOL STIGMA","	x (greek small letter stigma - 03DB)"},
/* 1D0E9 */ { "BYZANTINE MUSICAL SYMBOL ARKTIKO PA",NULL},
/* 1D0EA */ { "BYZANTINE MUSICAL SYMBOL ARKTIKO VOU",NULL},
/* 1D0EB */ { "BYZANTINE MUSICAL SYMBOL ARKTIKO GA",NULL},
/* 1D0EC */ { "BYZANTINE MUSICAL SYMBOL ARKTIKO DI",NULL},
/* 1D0ED */ { "BYZANTINE MUSICAL SYMBOL ARKTIKO KE",NULL},
/* 1D0EE */ { "BYZANTINE MUSICAL SYMBOL ARKTIKO ZO",NULL},
/* 1D0EF */ { "BYZANTINE MUSICAL SYMBOL ARKTIKO NI",NULL},
/* 1D0F0 */ { "BYZANTINE MUSICAL SYMBOL KENTIMATA NEO MESO",NULL},
/* 1D0F1 */ { "BYZANTINE MUSICAL SYMBOL KENTIMA NEO MESO",NULL},
/* 1D0F2 */ { "BYZANTINE MUSICAL SYMBOL KENTIMATA NEO KATO",NULL},
/* 1D0F3 */ { "BYZANTINE MUSICAL SYMBOL KENTIMA NEO KATO",NULL},
/* 1D0F4 */ { "BYZANTINE MUSICAL SYMBOL KLASMA KATO",NULL},
/* 1D0F5 */ { "BYZANTINE MUSICAL SYMBOL GORGON NEO KATO",NULL},
/* 1D0F6 */ { NULL,NULL},
/* 1D0F7 */ { NULL,NULL},
/* 1D0F8 */ { NULL,NULL},
/* 1D0F9 */ { NULL,NULL},
/* 1D0FA */ { NULL,NULL},
/* 1D0FB */ { NULL,NULL},
/* 1D0FC */ { NULL,NULL},
/* 1D0FD */ { NULL,NULL},
/* 1D0FE */ { NULL,NULL},
/* 1D0FF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_D1[] = {
/* 1D100 */ { "MUSICAL SYMBOL SINGLE BARLINE",NULL},
/* 1D101 */ { "MUSICAL SYMBOL DOUBLE BARLINE",NULL},
/* 1D102 */ { "MUSICAL SYMBOL FINAL BARLINE",NULL},
/* 1D103 */ { "MUSICAL SYMBOL REVERSE FINAL BARLINE",NULL},
/* 1D104 */ { "MUSICAL SYMBOL DASHED BARLINE",NULL},
/* 1D105 */ { "MUSICAL SYMBOL SHORT BARLINE",NULL},
/* 1D106 */ { "MUSICAL SYMBOL LEFT REPEAT SIGN",NULL},
/* 1D107 */ { "MUSICAL SYMBOL RIGHT REPEAT SIGN",NULL},
/* 1D108 */ { "MUSICAL SYMBOL REPEAT DOTS",NULL},
/* 1D109 */ { "MUSICAL SYMBOL DAL SEGNO",NULL},
/* 1D10A */ { "MUSICAL SYMBOL DA CAPO",NULL},
/* 1D10B */ { "MUSICAL SYMBOL SEGNO",NULL},
/* 1D10C */ { "MUSICAL SYMBOL CODA",NULL},
/* 1D10D */ { "MUSICAL SYMBOL REPEATED FIGURE-1",NULL},
/* 1D10E */ { "MUSICAL SYMBOL REPEATED FIGURE-2",NULL},
/* 1D10F */ { "MUSICAL SYMBOL REPEATED FIGURE-3",NULL},
/* 1D110 */ { "MUSICAL SYMBOL FERMATA",NULL},
/* 1D111 */ { "MUSICAL SYMBOL FERMATA BELOW",NULL},
/* 1D112 */ { "MUSICAL SYMBOL BREATH MARK",NULL},
/* 1D113 */ { "MUSICAL SYMBOL CAESURA",NULL},
/* 1D114 */ { "MUSICAL SYMBOL BRACE",NULL},
/* 1D115 */ { "MUSICAL SYMBOL BRACKET",NULL},
/* 1D116 */ { "MUSICAL SYMBOL ONE-LINE STAFF",NULL},
/* 1D117 */ { "MUSICAL SYMBOL TWO-LINE STAFF",NULL},
/* 1D118 */ { "MUSICAL SYMBOL THREE-LINE STAFF",NULL},
/* 1D119 */ { "MUSICAL SYMBOL FOUR-LINE STAFF",NULL},
/* 1D11A */ { "MUSICAL SYMBOL FIVE-LINE STAFF",NULL},
/* 1D11B */ { "MUSICAL SYMBOL SIX-LINE STAFF",NULL},
/* 1D11C */ { "MUSICAL SYMBOL SIX-STRING FRETBOARD",NULL},
/* 1D11D */ { "MUSICAL SYMBOL FOUR-STRING FRETBOARD",NULL},
/* 1D11E */ { "MUSICAL SYMBOL G CLEF","	x (musical score - 1F3BC)"},
/* 1D11F */ { "MUSICAL SYMBOL G CLEF OTTAVA ALTA",NULL},
/* 1D120 */ { "MUSICAL SYMBOL G CLEF OTTAVA BASSA",NULL},
/* 1D121 */ { "MUSICAL SYMBOL C CLEF",NULL},
/* 1D122 */ { "MUSICAL SYMBOL F CLEF",NULL},
/* 1D123 */ { "MUSICAL SYMBOL F CLEF OTTAVA ALTA",NULL},
/* 1D124 */ { "MUSICAL SYMBOL F CLEF OTTAVA BASSA",NULL},
/* 1D125 */ { "MUSICAL SYMBOL DRUM CLEF-1",NULL},
/* 1D126 */ { "MUSICAL SYMBOL DRUM CLEF-2",NULL},
/* 1D127 */ { NULL,NULL},
/* 1D128 */ { NULL,NULL},
/* 1D129 */ { "MUSICAL SYMBOL MULTIPLE MEASURE REST","	* used to represent rests of arbitrary lengths, extending across multiple measures\n"
	"	x (musical symbol multi rest - 1D13A)"},
/* 1D12A */ { "MUSICAL SYMBOL DOUBLE SHARP",NULL},
/* 1D12B */ { "MUSICAL SYMBOL DOUBLE FLAT",NULL},
/* 1D12C */ { "MUSICAL SYMBOL FLAT UP",NULL},
/* 1D12D */ { "MUSICAL SYMBOL FLAT DOWN",NULL},
/* 1D12E */ { "MUSICAL SYMBOL NATURAL UP",NULL},
/* 1D12F */ { "MUSICAL SYMBOL NATURAL DOWN",NULL},
/* 1D130 */ { "MUSICAL SYMBOL SHARP UP",NULL},
/* 1D131 */ { "MUSICAL SYMBOL SHARP DOWN",NULL},
/* 1D132 */ { "MUSICAL SYMBOL QUARTER TONE SHARP",NULL},
/* 1D133 */ { "MUSICAL SYMBOL QUARTER TONE FLAT",NULL},
/* 1D134 */ { "MUSICAL SYMBOL COMMON TIME",NULL},
/* 1D135 */ { "MUSICAL SYMBOL CUT TIME",NULL},
/* 1D136 */ { "MUSICAL SYMBOL OTTAVA ALTA",NULL},
/* 1D137 */ { "MUSICAL SYMBOL OTTAVA BASSA",NULL},
/* 1D138 */ { "MUSICAL SYMBOL QUINDICESIMA ALTA",NULL},
/* 1D139 */ { "MUSICAL SYMBOL QUINDICESIMA BASSA",NULL},
/* 1D13A */ { "MUSICAL SYMBOL MULTI REST","	= double whole-rest, breve rest\n"
	"	x (musical symbol multiple measure rest - 1D129)"},
/* 1D13B */ { "MUSICAL SYMBOL WHOLE REST","	= semibreve rest"},
/* 1D13C */ { "MUSICAL SYMBOL HALF REST","	= minim rest"},
/* 1D13D */ { "MUSICAL SYMBOL QUARTER REST","	= crochet rest"},
/* 1D13E */ { "MUSICAL SYMBOL EIGHTH REST","	= quaver rest"},
/* 1D13F */ { "MUSICAL SYMBOL SIXTEENTH REST","	= semiquaver rest"},
/* 1D140 */ { "MUSICAL SYMBOL THIRTY-SECOND REST","	= demisemiquaver rest"},
/* 1D141 */ { "MUSICAL SYMBOL SIXTY-FOURTH REST","	= hemidemisemiquaver rest, semidemisemiquaver rest"},
/* 1D142 */ { "MUSICAL SYMBOL ONE HUNDRED TWENTY-EIGHTH REST","	= semihemidemisemiquaver rest, quasihemidemisemiquaver rest"},
/* 1D143 */ { "MUSICAL SYMBOL X NOTEHEAD",NULL},
/* 1D144 */ { "MUSICAL SYMBOL PLUS NOTEHEAD",NULL},
/* 1D145 */ { "MUSICAL SYMBOL CIRCLE X NOTEHEAD",NULL},
/* 1D146 */ { "MUSICAL SYMBOL SQUARE NOTEHEAD WHITE",NULL},
/* 1D147 */ { "MUSICAL SYMBOL SQUARE NOTEHEAD BLACK",NULL},
/* 1D148 */ { "MUSICAL SYMBOL TRIANGLE NOTEHEAD UP WHITE",NULL},
/* 1D149 */ { "MUSICAL SYMBOL TRIANGLE NOTEHEAD UP BLACK",NULL},
/* 1D14A */ { "MUSICAL SYMBOL TRIANGLE NOTEHEAD LEFT WHITE",NULL},
/* 1D14B */ { "MUSICAL SYMBOL TRIANGLE NOTEHEAD LEFT BLACK",NULL},
/* 1D14C */ { "MUSICAL SYMBOL TRIANGLE NOTEHEAD RIGHT WHITE",NULL},
/* 1D14D */ { "MUSICAL SYMBOL TRIANGLE NOTEHEAD RIGHT BLACK",NULL},
/* 1D14E */ { "MUSICAL SYMBOL TRIANGLE NOTEHEAD DOWN WHITE",NULL},
/* 1D14F */ { "MUSICAL SYMBOL TRIANGLE NOTEHEAD DOWN BLACK",NULL},
/* 1D150 */ { "MUSICAL SYMBOL TRIANGLE NOTEHEAD UP RIGHT WHITE",NULL},
/* 1D151 */ { "MUSICAL SYMBOL TRIANGLE NOTEHEAD UP RIGHT BLACK",NULL},
/* 1D152 */ { "MUSICAL SYMBOL MOON NOTEHEAD WHITE",NULL},
/* 1D153 */ { "MUSICAL SYMBOL MOON NOTEHEAD BLACK",NULL},
/* 1D154 */ { "MUSICAL SYMBOL TRIANGLE-ROUND NOTEHEAD DOWN WHITE",NULL},
/* 1D155 */ { "MUSICAL SYMBOL TRIANGLE-ROUND NOTEHEAD DOWN BLACK",NULL},
/* 1D156 */ { "MUSICAL SYMBOL PARENTHESIS NOTEHEAD",NULL},
/* 1D157 */ { "MUSICAL SYMBOL VOID NOTEHEAD",NULL},
/* 1D158 */ { "MUSICAL SYMBOL NOTEHEAD BLACK",NULL},
/* 1D159 */ { "MUSICAL SYMBOL NULL NOTEHEAD",NULL},
/* 1D15A */ { "MUSICAL SYMBOL CLUSTER NOTEHEAD WHITE",NULL},
/* 1D15B */ { "MUSICAL SYMBOL CLUSTER NOTEHEAD BLACK",NULL},
/* 1D15C */ { "MUSICAL SYMBOL BREVE",NULL},
/* 1D15D */ { "MUSICAL SYMBOL WHOLE NOTE","	= semibreve"},
/* 1D15E */ { "MUSICAL SYMBOL HALF NOTE","	= minim\n"
	"	: 1D157 1D165"},
/* 1D15F */ { "MUSICAL SYMBOL QUARTER NOTE","	= crotchet\n"
	"	x (quarter note - 2669)\n"
	"	: 1D158 1D165"},
/* 1D160 */ { "MUSICAL SYMBOL EIGHTH NOTE","	= quaver\n"
	"	x (eighth note - 266A)\n"
	"	: 1D15F 1D16E"},
/* 1D161 */ { "MUSICAL SYMBOL SIXTEENTH NOTE","	= semiquaver\n"
	"	: 1D15F 1D16F"},
/* 1D162 */ { "MUSICAL SYMBOL THIRTY-SECOND NOTE","	= demisemiquaver\n"
	"	: 1D15F 1D170"},
/* 1D163 */ { "MUSICAL SYMBOL SIXTY-FOURTH NOTE","	= hemidemisemiquaver, semidemisemiquaver\n"
	"	: 1D15F 1D171"},
/* 1D164 */ { "MUSICAL SYMBOL ONE HUNDRED TWENTY-EIGHTH NOTE","	= semihemidemisemiquaver, quasihemidemisemiquaver\n"
	"	: 1D15F 1D172"},
/* 1D165 */ { "MUSICAL SYMBOL COMBINING STEM",NULL},
/* 1D166 */ { "MUSICAL SYMBOL COMBINING SPRECHGESANG STEM",NULL},
/* 1D167 */ { "MUSICAL SYMBOL COMBINING TREMOLO-1",NULL},
/* 1D168 */ { "MUSICAL SYMBOL COMBINING TREMOLO-2",NULL},
/* 1D169 */ { "MUSICAL SYMBOL COMBINING TREMOLO-3",NULL},
/* 1D16A */ { "MUSICAL SYMBOL FINGERED TREMOLO-1",NULL},
/* 1D16B */ { "MUSICAL SYMBOL FINGERED TREMOLO-2",NULL},
/* 1D16C */ { "MUSICAL SYMBOL FINGERED TREMOLO-3",NULL},
/* 1D16D */ { "MUSICAL SYMBOL COMBINING AUGMENTATION DOT",NULL},
/* 1D16E */ { "MUSICAL SYMBOL COMBINING FLAG-1",NULL},
/* 1D16F */ { "MUSICAL SYMBOL COMBINING FLAG-2",NULL},
/* 1D170 */ { "MUSICAL SYMBOL COMBINING FLAG-3",NULL},
/* 1D171 */ { "MUSICAL SYMBOL COMBINING FLAG-4",NULL},
/* 1D172 */ { "MUSICAL SYMBOL COMBINING FLAG-5",NULL},
/* 1D173 */ { "MUSICAL SYMBOL BEGIN BEAM",NULL},
/* 1D174 */ { "MUSICAL SYMBOL END BEAM",NULL},
/* 1D175 */ { "MUSICAL SYMBOL BEGIN TIE",NULL},
/* 1D176 */ { "MUSICAL SYMBOL END TIE",NULL},
/* 1D177 */ { "MUSICAL SYMBOL BEGIN SLUR",NULL},
/* 1D178 */ { "MUSICAL SYMBOL END SLUR",NULL},
/* 1D179 */ { "MUSICAL SYMBOL BEGIN PHRASE",NULL},
/* 1D17A */ { "MUSICAL SYMBOL END PHRASE",NULL},
/* 1D17B */ { "MUSICAL SYMBOL COMBINING ACCENT",NULL},
/* 1D17C */ { "MUSICAL SYMBOL COMBINING STACCATO",NULL},
/* 1D17D */ { "MUSICAL SYMBOL COMBINING TENUTO",NULL},
/* 1D17E */ { "MUSICAL SYMBOL COMBINING STACCATISSIMO",NULL},
/* 1D17F */ { "MUSICAL SYMBOL COMBINING MARCATO",NULL},
/* 1D180 */ { "MUSICAL SYMBOL COMBINING MARCATO-STACCATO",NULL},
/* 1D181 */ { "MUSICAL SYMBOL COMBINING ACCENT-STACCATO",NULL},
/* 1D182 */ { "MUSICAL SYMBOL COMBINING LOURE",NULL},
/* 1D183 */ { "MUSICAL SYMBOL ARPEGGIATO UP",NULL},
/* 1D184 */ { "MUSICAL SYMBOL ARPEGGIATO DOWN",NULL},
/* 1D185 */ { "MUSICAL SYMBOL COMBINING DOIT",NULL},
/* 1D186 */ { "MUSICAL SYMBOL COMBINING RIP",NULL},
/* 1D187 */ { "MUSICAL SYMBOL COMBINING FLIP",NULL},
/* 1D188 */ { "MUSICAL SYMBOL COMBINING SMEAR",NULL},
/* 1D189 */ { "MUSICAL SYMBOL COMBINING BEND",NULL},
/* 1D18A */ { "MUSICAL SYMBOL COMBINING DOUBLE TONGUE",NULL},
/* 1D18B */ { "MUSICAL SYMBOL COMBINING TRIPLE TONGUE",NULL},
/* 1D18C */ { "MUSICAL SYMBOL RINFORZANDO",NULL},
/* 1D18D */ { "MUSICAL SYMBOL SUBITO",NULL},
/* 1D18E */ { "MUSICAL SYMBOL Z",NULL},
/* 1D18F */ { "MUSICAL SYMBOL PIANO",NULL},
/* 1D190 */ { "MUSICAL SYMBOL MEZZO",NULL},
/* 1D191 */ { "MUSICAL SYMBOL FORTE",NULL},
/* 1D192 */ { "MUSICAL SYMBOL CRESCENDO",NULL},
/* 1D193 */ { "MUSICAL SYMBOL DECRESCENDO",NULL},
/* 1D194 */ { "MUSICAL SYMBOL GRACE NOTE SLASH",NULL},
/* 1D195 */ { "MUSICAL SYMBOL GRACE NOTE NO SLASH",NULL},
/* 1D196 */ { "MUSICAL SYMBOL TR",NULL},
/* 1D197 */ { "MUSICAL SYMBOL TURN",NULL},
/* 1D198 */ { "MUSICAL SYMBOL INVERTED TURN",NULL},
/* 1D199 */ { "MUSICAL SYMBOL TURN SLASH",NULL},
/* 1D19A */ { "MUSICAL SYMBOL TURN UP",NULL},
/* 1D19B */ { "MUSICAL SYMBOL ORNAMENT STROKE-1",NULL},
/* 1D19C */ { "MUSICAL SYMBOL ORNAMENT STROKE-2",NULL},
/* 1D19D */ { "MUSICAL SYMBOL ORNAMENT STROKE-3",NULL},
/* 1D19E */ { "MUSICAL SYMBOL ORNAMENT STROKE-4",NULL},
/* 1D19F */ { "MUSICAL SYMBOL ORNAMENT STROKE-5",NULL},
/* 1D1A0 */ { "MUSICAL SYMBOL ORNAMENT STROKE-6",NULL},
/* 1D1A1 */ { "MUSICAL SYMBOL ORNAMENT STROKE-7",NULL},
/* 1D1A2 */ { "MUSICAL SYMBOL ORNAMENT STROKE-8",NULL},
/* 1D1A3 */ { "MUSICAL SYMBOL ORNAMENT STROKE-9",NULL},
/* 1D1A4 */ { "MUSICAL SYMBOL ORNAMENT STROKE-10",NULL},
/* 1D1A5 */ { "MUSICAL SYMBOL ORNAMENT STROKE-11",NULL},
/* 1D1A6 */ { "MUSICAL SYMBOL HAUPTSTIMME",NULL},
/* 1D1A7 */ { "MUSICAL SYMBOL NEBENSTIMME",NULL},
/* 1D1A8 */ { "MUSICAL SYMBOL END OF STIMME",NULL},
/* 1D1A9 */ { "MUSICAL SYMBOL DEGREE SLASH",NULL},
/* 1D1AA */ { "MUSICAL SYMBOL COMBINING DOWN BOW",NULL},
/* 1D1AB */ { "MUSICAL SYMBOL COMBINING UP BOW",NULL},
/* 1D1AC */ { "MUSICAL SYMBOL COMBINING HARMONIC",NULL},
/* 1D1AD */ { "MUSICAL SYMBOL COMBINING SNAP PIZZICATO",NULL},
/* 1D1AE */ { "MUSICAL SYMBOL PEDAL MARK",NULL},
/* 1D1AF */ { "MUSICAL SYMBOL PEDAL UP MARK",NULL},
/* 1D1B0 */ { "MUSICAL SYMBOL HALF PEDAL MARK",NULL},
/* 1D1B1 */ { "MUSICAL SYMBOL GLISSANDO UP",NULL},
/* 1D1B2 */ { "MUSICAL SYMBOL GLISSANDO DOWN",NULL},
/* 1D1B3 */ { "MUSICAL SYMBOL WITH FINGERNAILS",NULL},
/* 1D1B4 */ { "MUSICAL SYMBOL DAMP",NULL},
/* 1D1B5 */ { "MUSICAL SYMBOL DAMP ALL",NULL},
/* 1D1B6 */ { "MUSICAL SYMBOL MAXIMA",NULL},
/* 1D1B7 */ { "MUSICAL SYMBOL LONGA",NULL},
/* 1D1B8 */ { "MUSICAL SYMBOL BREVIS",NULL},
/* 1D1B9 */ { "MUSICAL SYMBOL SEMIBREVIS WHITE",NULL},
/* 1D1BA */ { "MUSICAL SYMBOL SEMIBREVIS BLACK",NULL},
/* 1D1BB */ { "MUSICAL SYMBOL MINIMA","	: 1D1B9 1D165"},
/* 1D1BC */ { "MUSICAL SYMBOL MINIMA BLACK","	: 1D1BA 1D165"},
/* 1D1BD */ { "MUSICAL SYMBOL SEMIMINIMA WHITE","	: 1D1BB 1D16E"},
/* 1D1BE */ { "MUSICAL SYMBOL SEMIMINIMA BLACK","	: 1D1BC 1D16E"},
/* 1D1BF */ { "MUSICAL SYMBOL FUSA WHITE","	: 1D1BB 1D16F"},
/* 1D1C0 */ { "MUSICAL SYMBOL FUSA BLACK","	: 1D1BC 1D16F"},
/* 1D1C1 */ { "MUSICAL SYMBOL LONGA PERFECTA REST",NULL},
/* 1D1C2 */ { "MUSICAL SYMBOL LONGA IMPERFECTA REST",NULL},
/* 1D1C3 */ { "MUSICAL SYMBOL BREVIS REST",NULL},
/* 1D1C4 */ { "MUSICAL SYMBOL SEMIBREVIS REST",NULL},
/* 1D1C5 */ { "MUSICAL SYMBOL MINIMA REST",NULL},
/* 1D1C6 */ { "MUSICAL SYMBOL SEMIMINIMA REST",NULL},
/* 1D1C7 */ { "MUSICAL SYMBOL TEMPUS PERFECTUM CUM PROLATIONE PERFECTA",NULL},
/* 1D1C8 */ { "MUSICAL SYMBOL TEMPUS PERFECTUM CUM PROLATIONE IMPERFECTA",NULL},
/* 1D1C9 */ { "MUSICAL SYMBOL TEMPUS PERFECTUM CUM PROLATIONE PERFECTA DIMINUTION-1",NULL},
/* 1D1CA */ { "MUSICAL SYMBOL TEMPUS IMPERFECTUM CUM PROLATIONE PERFECTA",NULL},
/* 1D1CB */ { "MUSICAL SYMBOL TEMPUS IMPERFECTUM CUM PROLATIONE IMPERFECTA",NULL},
/* 1D1CC */ { "MUSICAL SYMBOL TEMPUS IMPERFECTUM CUM PROLATIONE IMPERFECTA DIMINUTION-1",NULL},
/* 1D1CD */ { "MUSICAL SYMBOL TEMPUS IMPERFECTUM CUM PROLATIONE IMPERFECTA DIMINUTION-2",NULL},
/* 1D1CE */ { "MUSICAL SYMBOL TEMPUS IMPERFECTUM CUM PROLATIONE IMPERFECTA DIMINUTION-3",NULL},
/* 1D1CF */ { "MUSICAL SYMBOL CROIX",NULL},
/* 1D1D0 */ { "MUSICAL SYMBOL GREGORIAN C CLEF",NULL},
/* 1D1D1 */ { "MUSICAL SYMBOL GREGORIAN F CLEF",NULL},
/* 1D1D2 */ { "MUSICAL SYMBOL SQUARE B",NULL},
/* 1D1D3 */ { "MUSICAL SYMBOL VIRGA",NULL},
/* 1D1D4 */ { "MUSICAL SYMBOL PODATUS",NULL},
/* 1D1D5 */ { "MUSICAL SYMBOL CLIVIS",NULL},
/* 1D1D6 */ { "MUSICAL SYMBOL SCANDICUS",NULL},
/* 1D1D7 */ { "MUSICAL SYMBOL CLIMACUS",NULL},
/* 1D1D8 */ { "MUSICAL SYMBOL TORCULUS",NULL},
/* 1D1D9 */ { "MUSICAL SYMBOL PORRECTUS",NULL},
/* 1D1DA */ { "MUSICAL SYMBOL PORRECTUS FLEXUS",NULL},
/* 1D1DB */ { "MUSICAL SYMBOL SCANDICUS FLEXUS",NULL},
/* 1D1DC */ { "MUSICAL SYMBOL TORCULUS RESUPINUS",NULL},
/* 1D1DD */ { "MUSICAL SYMBOL PES SUBPUNCTIS",NULL},
/* 1D1DE */ { "MUSICAL SYMBOL KIEVAN C CLEF","	* Tsefaut (do or fa) clef"},
/* 1D1DF */ { "MUSICAL SYMBOL KIEVAN END OF PIECE",NULL},
/* 1D1E0 */ { "MUSICAL SYMBOL KIEVAN FINAL NOTE","	* nominal note located between the two rectangles"},
/* 1D1E1 */ { "MUSICAL SYMBOL KIEVAN RECITATIVE MARK","	* nominal note located between the two rectangles"},
/* 1D1E2 */ { "MUSICAL SYMBOL KIEVAN WHOLE NOTE","	* nominal note located between the two diamonds"},
/* 1D1E3 */ { "MUSICAL SYMBOL KIEVAN HALF NOTE",NULL},
/* 1D1E4 */ { "MUSICAL SYMBOL KIEVAN QUARTER NOTE STEM DOWN",NULL},
/* 1D1E5 */ { "MUSICAL SYMBOL KIEVAN QUARTER NOTE STEM UP",NULL},
/* 1D1E6 */ { "MUSICAL SYMBOL KIEVAN EIGHTH NOTE STEM DOWN","	* nominal note located on the top diamond"},
/* 1D1E7 */ { "MUSICAL SYMBOL KIEVAN EIGHTH NOTE STEM UP",NULL},
/* 1D1E8 */ { "MUSICAL SYMBOL KIEVAN FLAT SIGN",NULL},
/* 1D1E9 */ { "MUSICAL SYMBOL SORI",NULL},
/* 1D1EA */ { "MUSICAL SYMBOL KORON",NULL},
/* 1D1EB */ { NULL,NULL},
/* 1D1EC */ { NULL,NULL},
/* 1D1ED */ { NULL,NULL},
/* 1D1EE */ { NULL,NULL},
/* 1D1EF */ { NULL,NULL},
/* 1D1F0 */ { NULL,NULL},
/* 1D1F1 */ { NULL,NULL},
/* 1D1F2 */ { NULL,NULL},
/* 1D1F3 */ { NULL,NULL},
/* 1D1F4 */ { NULL,NULL},
/* 1D1F5 */ { NULL,NULL},
/* 1D1F6 */ { NULL,NULL},
/* 1D1F7 */ { NULL,NULL},
/* 1D1F8 */ { NULL,NULL},
/* 1D1F9 */ { NULL,NULL},
/* 1D1FA */ { NULL,NULL},
/* 1D1FB */ { NULL,NULL},
/* 1D1FC */ { NULL,NULL},
/* 1D1FD */ { NULL,NULL},
/* 1D1FE */ { NULL,NULL},
/* 1D1FF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_D2[] = {
/* 1D200 */ { "GREEK VOCAL NOTATION SYMBOL-1","	* vocal E"},
/* 1D201 */ { "GREEK VOCAL NOTATION SYMBOL-2","	* vocal first sharp of E"},
/* 1D202 */ { "GREEK VOCAL NOTATION SYMBOL-3","	= Greek instrumental notation symbol-3\n"
	"	* vocal or instrumental second sharp of E"},
/* 1D203 */ { "GREEK VOCAL NOTATION SYMBOL-4","	* vocal F"},
/* 1D204 */ { "GREEK VOCAL NOTATION SYMBOL-5","	* vocal first sharp of F"},
/* 1D205 */ { "GREEK VOCAL NOTATION SYMBOL-6","	= Greek instrumental notation symbol-21\n"
	"	* vocal second sharp of F\n"
	"	* instrumental second sharp of d"},
/* 1D206 */ { "GREEK VOCAL NOTATION SYMBOL-7","	= Greek instrumental notation symbol-9\n"
	"	* vocal G\n"
	"	* instrumental second sharp of G"},
/* 1D207 */ { "GREEK VOCAL NOTATION SYMBOL-8","	* vocal first sharp of G"},
/* 1D208 */ { "GREEK VOCAL NOTATION SYMBOL-9","	= Greek instrumental notation symbol-44\n"
	"	* vocal second sharp of G\n"
	"	* instrumental first sharp of e´"},
/* 1D209 */ { "GREEK VOCAL NOTATION SYMBOL-10","	* vocal A\n"
	"	* this is a modification of 039F and is therefore not the same as 03D8"},
/* 1D20A */ { "GREEK VOCAL NOTATION SYMBOL-11","	* vocal first sharp of A"},
/* 1D20B */ { "GREEK VOCAL NOTATION SYMBOL-12","	* vocal second sharp of A"},
/* 1D20C */ { "GREEK VOCAL NOTATION SYMBOL-13","	* vocal B"},
/* 1D20D */ { "GREEK VOCAL NOTATION SYMBOL-14","	= Greek instrumental notation symbol-41\n"
	"	* vocal first sharp of B\n"
	"	* instrumental first sharp of d´\n"
	"	x (latin capital letter v - 0056)"},
/* 1D20E */ { "GREEK VOCAL NOTATION SYMBOL-15","	= Greek instrumental notation symbol-35\n"
	"	* vocal second sharp of B\n"
	"	* instrumental first sharp of b"},
/* 1D20F */ { "GREEK VOCAL NOTATION SYMBOL-16","	* vocal c\n"
	"	* unlike 1D23B this character has a glyph variant that looks like a horizontal line"},
/* 1D210 */ { "GREEK VOCAL NOTATION SYMBOL-17","	* vocal first sharp of c"},
/* 1D211 */ { "GREEK VOCAL NOTATION SYMBOL-18","	= Greek instrumental notation symbol-15\n"
	"	* vocal second sharp of c\n"
	"	* instrumental second sharp of B"},
/* 1D212 */ { "GREEK VOCAL NOTATION SYMBOL-19","	* vocal d"},
/* 1D213 */ { "GREEK VOCAL NOTATION SYMBOL-20","	= Greek instrumental notation symbol-28\n"
	"	* vocal first sharp of d\n"
	"	* instrumental g\n"
	"	* this is a modification of 0395 and is therefore not the same as 0046"},
/* 1D214 */ { "GREEK VOCAL NOTATION SYMBOL-21","	* vocal second sharp of d"},
/* 1D215 */ { "GREEK VOCAL NOTATION SYMBOL-22","	* vocal e"},
/* 1D216 */ { "GREEK VOCAL NOTATION SYMBOL-23","	* vocal first sharp of e\n"
	"	* this is a modification of 0392 and is therefore not the same as 0052"},
/* 1D217 */ { "GREEK VOCAL NOTATION SYMBOL-24","	* vocal second sharp of e"},
/* 1D218 */ { "GREEK VOCAL NOTATION SYMBOL-50","	* vocal first sharp of g´"},
/* 1D219 */ { "GREEK VOCAL NOTATION SYMBOL-51","	* vocal second sharp of g´"},
/* 1D21A */ { "GREEK VOCAL NOTATION SYMBOL-52","	* vocal a´"},
/* 1D21B */ { "GREEK VOCAL NOTATION SYMBOL-53","	* vocal first sharp of a´"},
/* 1D21C */ { "GREEK VOCAL NOTATION SYMBOL-54","	= Greek instrumental notation symbol-20\n"
	"	* vocal second sharp of a´\n"
	"	* instrumental first sharp of d"},
/* 1D21D */ { "GREEK INSTRUMENTAL NOTATION SYMBOL-1","	* instrumental E"},
/* 1D21E */ { "GREEK INSTRUMENTAL NOTATION SYMBOL-2","	* instrumental first sharp of E"},
/* 1D21F */ { "GREEK INSTRUMENTAL NOTATION SYMBOL-4","	* instrumental F"},
/* 1D220 */ { "GREEK INSTRUMENTAL NOTATION SYMBOL-5","	* instrumental first sharp of F"},
/* 1D221 */ { "GREEK INSTRUMENTAL NOTATION SYMBOL-7","	* instrumental G"},
/* 1D222 */ { "GREEK INSTRUMENTAL NOTATION SYMBOL-8","	* instrumental first sharp of G"},
/* 1D223 */ { "GREEK INSTRUMENTAL NOTATION SYMBOL-11","	* instrumental first sharp of A"},
/* 1D224 */ { "GREEK INSTRUMENTAL NOTATION SYMBOL-12","	* instrumental second sharp of A"},
/* 1D225 */ { "GREEK INSTRUMENTAL NOTATION SYMBOL-13","	* instrumental B"},
/* 1D226 */ { "GREEK INSTRUMENTAL NOTATION SYMBOL-14","	* instrumental first sharp of B"},
/* 1D227 */ { "GREEK INSTRUMENTAL NOTATION SYMBOL-17","	* instrumental first sharp of c"},
/* 1D228 */ { "GREEK INSTRUMENTAL NOTATION SYMBOL-18","	* instrumental second sharp of c"},
/* 1D229 */ { "GREEK INSTRUMENTAL NOTATION SYMBOL-19","	* instrumental d"},
/* 1D22A */ { "GREEK INSTRUMENTAL NOTATION SYMBOL-23","	* instrumental first sharp of e"},
/* 1D22B */ { "GREEK INSTRUMENTAL NOTATION SYMBOL-24","	* instrumental second sharp of e"},
/* 1D22C */ { "GREEK INSTRUMENTAL NOTATION SYMBOL-25","	* instrumental f"},
/* 1D22D */ { "GREEK INSTRUMENTAL NOTATION SYMBOL-26","	* instrumental first sharp of f"},
/* 1D22E */ { "GREEK INSTRUMENTAL NOTATION SYMBOL-27","	* instrumental second sharp of f"},
/* 1D22F */ { "GREEK INSTRUMENTAL NOTATION SYMBOL-29","	* instrumental first sharp of g"},
/* 1D230 */ { "GREEK INSTRUMENTAL NOTATION SYMBOL-30","	* instrumental second sharp of g"},
/* 1D231 */ { "GREEK INSTRUMENTAL NOTATION SYMBOL-32","	* instrumental first sharp of a"},
/* 1D232 */ { "GREEK INSTRUMENTAL NOTATION SYMBOL-36","	* instrumental second sharp of b"},
/* 1D233 */ { "GREEK INSTRUMENTAL NOTATION SYMBOL-37","	* instrumental c´"},
/* 1D234 */ { "GREEK INSTRUMENTAL NOTATION SYMBOL-38","	* instrumental first sharp of c´"},
/* 1D235 */ { "GREEK INSTRUMENTAL NOTATION SYMBOL-39","	* instrumental second sharp of c´"},
/* 1D236 */ { "GREEK INSTRUMENTAL NOTATION SYMBOL-40","	* instrumental d´"},
/* 1D237 */ { "GREEK INSTRUMENTAL NOTATION SYMBOL-42","	* instrumental second sharp of d´"},
/* 1D238 */ { "GREEK INSTRUMENTAL NOTATION SYMBOL-43","	* instrumental e´"},
/* 1D239 */ { "GREEK INSTRUMENTAL NOTATION SYMBOL-45","	* instrumental second sharp of e´"},
/* 1D23A */ { "GREEK INSTRUMENTAL NOTATION SYMBOL-47","	* instrumental first sharp of f´\n"
	"	* similar but not identical to 002F"},
/* 1D23B */ { "GREEK INSTRUMENTAL NOTATION SYMBOL-48","	* instrumental second sharp of f´\n"
	"	* similar but not identical to 005C"},
/* 1D23C */ { "GREEK INSTRUMENTAL NOTATION SYMBOL-49","	* instrumental g´"},
/* 1D23D */ { "GREEK INSTRUMENTAL NOTATION SYMBOL-50","	* instrumental first sharp of g´"},
/* 1D23E */ { "GREEK INSTRUMENTAL NOTATION SYMBOL-51","	* instrumental second sharp of g´"},
/* 1D23F */ { "GREEK INSTRUMENTAL NOTATION SYMBOL-52","	* instrumental a´"},
/* 1D240 */ { "GREEK INSTRUMENTAL NOTATION SYMBOL-53","	* instrumental first sharp of a´"},
/* 1D241 */ { "GREEK INSTRUMENTAL NOTATION SYMBOL-54","	* instrumental second sharp of a´"},
/* 1D242 */ { "COMBINING GREEK MUSICAL TRISEME","	x (metrical triseme - 23D7)"},
/* 1D243 */ { "COMBINING GREEK MUSICAL TETRASEME","	x (metrical tetraseme - 23D8)"},
/* 1D244 */ { "COMBINING GREEK MUSICAL PENTASEME","	x (metrical pentaseme - 23D9)"},
/* 1D245 */ { "GREEK MUSICAL LEIMMA",NULL},
/* 1D246 */ { NULL,NULL},
/* 1D247 */ { NULL,NULL},
/* 1D248 */ { NULL,NULL},
/* 1D249 */ { NULL,NULL},
/* 1D24A */ { NULL,NULL},
/* 1D24B */ { NULL,NULL},
/* 1D24C */ { NULL,NULL},
/* 1D24D */ { NULL,NULL},
/* 1D24E */ { NULL,NULL},
/* 1D24F */ { NULL,NULL},
/* 1D250 */ { NULL,NULL},
/* 1D251 */ { NULL,NULL},
/* 1D252 */ { NULL,NULL},
/* 1D253 */ { NULL,NULL},
/* 1D254 */ { NULL,NULL},
/* 1D255 */ { NULL,NULL},
/* 1D256 */ { NULL,NULL},
/* 1D257 */ { NULL,NULL},
/* 1D258 */ { NULL,NULL},
/* 1D259 */ { NULL,NULL},
/* 1D25A */ { NULL,NULL},
/* 1D25B */ { NULL,NULL},
/* 1D25C */ { NULL,NULL},
/* 1D25D */ { NULL,NULL},
/* 1D25E */ { NULL,NULL},
/* 1D25F */ { NULL,NULL},
/* 1D260 */ { NULL,NULL},
/* 1D261 */ { NULL,NULL},
/* 1D262 */ { NULL,NULL},
/* 1D263 */ { NULL,NULL},
/* 1D264 */ { NULL,NULL},
/* 1D265 */ { NULL,NULL},
/* 1D266 */ { NULL,NULL},
/* 1D267 */ { NULL,NULL},
/* 1D268 */ { NULL,NULL},
/* 1D269 */ { NULL,NULL},
/* 1D26A */ { NULL,NULL},
/* 1D26B */ { NULL,NULL},
/* 1D26C */ { NULL,NULL},
/* 1D26D */ { NULL,NULL},
/* 1D26E */ { NULL,NULL},
/* 1D26F */ { NULL,NULL},
/* 1D270 */ { NULL,NULL},
/* 1D271 */ { NULL,NULL},
/* 1D272 */ { NULL,NULL},
/* 1D273 */ { NULL,NULL},
/* 1D274 */ { NULL,NULL},
/* 1D275 */ { NULL,NULL},
/* 1D276 */ { NULL,NULL},
/* 1D277 */ { NULL,NULL},
/* 1D278 */ { NULL,NULL},
/* 1D279 */ { NULL,NULL},
/* 1D27A */ { NULL,NULL},
/* 1D27B */ { NULL,NULL},
/* 1D27C */ { NULL,NULL},
/* 1D27D */ { NULL,NULL},
/* 1D27E */ { NULL,NULL},
/* 1D27F */ { NULL,NULL},
/* 1D280 */ { NULL,NULL},
/* 1D281 */ { NULL,NULL},
/* 1D282 */ { NULL,NULL},
/* 1D283 */ { NULL,NULL},
/* 1D284 */ { NULL,NULL},
/* 1D285 */ { NULL,NULL},
/* 1D286 */ { NULL,NULL},
/* 1D287 */ { NULL,NULL},
/* 1D288 */ { NULL,NULL},
/* 1D289 */ { NULL,NULL},
/* 1D28A */ { NULL,NULL},
/* 1D28B */ { NULL,NULL},
/* 1D28C */ { NULL,NULL},
/* 1D28D */ { NULL,NULL},
/* 1D28E */ { NULL,NULL},
/* 1D28F */ { NULL,NULL},
/* 1D290 */ { NULL,NULL},
/* 1D291 */ { NULL,NULL},
/* 1D292 */ { NULL,NULL},
/* 1D293 */ { NULL,NULL},
/* 1D294 */ { NULL,NULL},
/* 1D295 */ { NULL,NULL},
/* 1D296 */ { NULL,NULL},
/* 1D297 */ { NULL,NULL},
/* 1D298 */ { NULL,NULL},
/* 1D299 */ { NULL,NULL},
/* 1D29A */ { NULL,NULL},
/* 1D29B */ { NULL,NULL},
/* 1D29C */ { NULL,NULL},
/* 1D29D */ { NULL,NULL},
/* 1D29E */ { NULL,NULL},
/* 1D29F */ { NULL,NULL},
/* 1D2A0 */ { NULL,NULL},
/* 1D2A1 */ { NULL,NULL},
/* 1D2A2 */ { NULL,NULL},
/* 1D2A3 */ { NULL,NULL},
/* 1D2A4 */ { NULL,NULL},
/* 1D2A5 */ { NULL,NULL},
/* 1D2A6 */ { NULL,NULL},
/* 1D2A7 */ { NULL,NULL},
/* 1D2A8 */ { NULL,NULL},
/* 1D2A9 */ { NULL,NULL},
/* 1D2AA */ { NULL,NULL},
/* 1D2AB */ { NULL,NULL},
/* 1D2AC */ { NULL,NULL},
/* 1D2AD */ { NULL,NULL},
/* 1D2AE */ { NULL,NULL},
/* 1D2AF */ { NULL,NULL},
/* 1D2B0 */ { NULL,NULL},
/* 1D2B1 */ { NULL,NULL},
/* 1D2B2 */ { NULL,NULL},
/* 1D2B3 */ { NULL,NULL},
/* 1D2B4 */ { NULL,NULL},
/* 1D2B5 */ { NULL,NULL},
/* 1D2B6 */ { NULL,NULL},
/* 1D2B7 */ { NULL,NULL},
/* 1D2B8 */ { NULL,NULL},
/* 1D2B9 */ { NULL,NULL},
/* 1D2BA */ { NULL,NULL},
/* 1D2BB */ { NULL,NULL},
/* 1D2BC */ { NULL,NULL},
/* 1D2BD */ { NULL,NULL},
/* 1D2BE */ { NULL,NULL},
/* 1D2BF */ { NULL,NULL},
/* 1D2C0 */ { "KAKTOVIK NUMERAL ZERO",NULL},
/* 1D2C1 */ { "KAKTOVIK NUMERAL ONE",NULL},
/* 1D2C2 */ { "KAKTOVIK NUMERAL TWO",NULL},
/* 1D2C3 */ { "KAKTOVIK NUMERAL THREE",NULL},
/* 1D2C4 */ { "KAKTOVIK NUMERAL FOUR",NULL},
/* 1D2C5 */ { "KAKTOVIK NUMERAL FIVE",NULL},
/* 1D2C6 */ { "KAKTOVIK NUMERAL SIX",NULL},
/* 1D2C7 */ { "KAKTOVIK NUMERAL SEVEN",NULL},
/* 1D2C8 */ { "KAKTOVIK NUMERAL EIGHT",NULL},
/* 1D2C9 */ { "KAKTOVIK NUMERAL NINE",NULL},
/* 1D2CA */ { "KAKTOVIK NUMERAL TEN",NULL},
/* 1D2CB */ { "KAKTOVIK NUMERAL ELEVEN",NULL},
/* 1D2CC */ { "KAKTOVIK NUMERAL TWELVE",NULL},
/* 1D2CD */ { "KAKTOVIK NUMERAL THIRTEEN",NULL},
/* 1D2CE */ { "KAKTOVIK NUMERAL FOURTEEN",NULL},
/* 1D2CF */ { "KAKTOVIK NUMERAL FIFTEEN",NULL},
/* 1D2D0 */ { "KAKTOVIK NUMERAL SIXTEEN",NULL},
/* 1D2D1 */ { "KAKTOVIK NUMERAL SEVENTEEN",NULL},
/* 1D2D2 */ { "KAKTOVIK NUMERAL EIGHTEEN",NULL},
/* 1D2D3 */ { "KAKTOVIK NUMERAL NINETEEN",NULL},
/* 1D2D4 */ { NULL,NULL},
/* 1D2D5 */ { NULL,NULL},
/* 1D2D6 */ { NULL,NULL},
/* 1D2D7 */ { NULL,NULL},
/* 1D2D8 */ { NULL,NULL},
/* 1D2D9 */ { NULL,NULL},
/* 1D2DA */ { NULL,NULL},
/* 1D2DB */ { NULL,NULL},
/* 1D2DC */ { NULL,NULL},
/* 1D2DD */ { NULL,NULL},
/* 1D2DE */ { NULL,NULL},
/* 1D2DF */ { NULL,NULL},
/* 1D2E0 */ { "MAYAN NUMERAL ZERO",NULL},
/* 1D2E1 */ { "MAYAN NUMERAL ONE",NULL},
/* 1D2E2 */ { "MAYAN NUMERAL TWO",NULL},
/* 1D2E3 */ { "MAYAN NUMERAL THREE",NULL},
/* 1D2E4 */ { "MAYAN NUMERAL FOUR",NULL},
/* 1D2E5 */ { "MAYAN NUMERAL FIVE",NULL},
/* 1D2E6 */ { "MAYAN NUMERAL SIX",NULL},
/* 1D2E7 */ { "MAYAN NUMERAL SEVEN",NULL},
/* 1D2E8 */ { "MAYAN NUMERAL EIGHT",NULL},
/* 1D2E9 */ { "MAYAN NUMERAL NINE",NULL},
/* 1D2EA */ { "MAYAN NUMERAL TEN",NULL},
/* 1D2EB */ { "MAYAN NUMERAL ELEVEN",NULL},
/* 1D2EC */ { "MAYAN NUMERAL TWELVE",NULL},
/* 1D2ED */ { "MAYAN NUMERAL THIRTEEN",NULL},
/* 1D2EE */ { "MAYAN NUMERAL FOURTEEN",NULL},
/* 1D2EF */ { "MAYAN NUMERAL FIFTEEN",NULL},
/* 1D2F0 */ { "MAYAN NUMERAL SIXTEEN",NULL},
/* 1D2F1 */ { "MAYAN NUMERAL SEVENTEEN",NULL},
/* 1D2F2 */ { "MAYAN NUMERAL EIGHTEEN",NULL},
/* 1D2F3 */ { "MAYAN NUMERAL NINETEEN",NULL},
/* 1D2F4 */ { NULL,NULL},
/* 1D2F5 */ { NULL,NULL},
/* 1D2F6 */ { NULL,NULL},
/* 1D2F7 */ { NULL,NULL},
/* 1D2F8 */ { NULL,NULL},
/* 1D2F9 */ { NULL,NULL},
/* 1D2FA */ { NULL,NULL},
/* 1D2FB */ { NULL,NULL},
/* 1D2FC */ { NULL,NULL},
/* 1D2FD */ { NULL,NULL},
/* 1D2FE */ { NULL,NULL},
/* 1D2FF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_D3[] = {
/* 1D300 */ { "MONOGRAM FOR EARTH","	= ren\n"
	"	* usually associated with human (Chinese rén), rather than earth (Chinese dì)\n"
	"	x (monogram for yang - 268A)\n"
	"	x (monogram for yin - 268B)"},
/* 1D301 */ { "DIGRAM FOR HEAVENLY EARTH","	= tian ren"},
/* 1D302 */ { "DIGRAM FOR HUMAN EARTH","	= di ren"},
/* 1D303 */ { "DIGRAM FOR EARTHLY HEAVEN","	= ren tian"},
/* 1D304 */ { "DIGRAM FOR EARTHLY HUMAN","	= ren di"},
/* 1D305 */ { "DIGRAM FOR EARTH","	= ren ren"},
/* 1D306 */ { "TETRAGRAM FOR CENTRE",NULL},
/* 1D307 */ { "TETRAGRAM FOR FULL CIRCLE",NULL},
/* 1D308 */ { "TETRAGRAM FOR MIRED",NULL},
/* 1D309 */ { "TETRAGRAM FOR BARRIER",NULL},
/* 1D30A */ { "TETRAGRAM FOR KEEPING SMALL",NULL},
/* 1D30B */ { "TETRAGRAM FOR CONTRARIETY",NULL},
/* 1D30C */ { "TETRAGRAM FOR ASCENT",NULL},
/* 1D30D */ { "TETRAGRAM FOR OPPOSITION",NULL},
/* 1D30E */ { "TETRAGRAM FOR BRANCHING OUT",NULL},
/* 1D30F */ { "TETRAGRAM FOR DEFECTIVENESS OR DISTORTION",NULL},
/* 1D310 */ { "TETRAGRAM FOR DIVERGENCE",NULL},
/* 1D311 */ { "TETRAGRAM FOR YOUTHFULNESS",NULL},
/* 1D312 */ { "TETRAGRAM FOR INCREASE",NULL},
/* 1D313 */ { "TETRAGRAM FOR PENETRATION",NULL},
/* 1D314 */ { "TETRAGRAM FOR REACH",NULL},
/* 1D315 */ { "TETRAGRAM FOR CONTACT",NULL},
/* 1D316 */ { "TETRAGRAM FOR HOLDING BACK",NULL},
/* 1D317 */ { "TETRAGRAM FOR WAITING",NULL},
/* 1D318 */ { "TETRAGRAM FOR FOLLOWING",NULL},
/* 1D319 */ { "TETRAGRAM FOR ADVANCE",NULL},
/* 1D31A */ { "TETRAGRAM FOR RELEASE",NULL},
/* 1D31B */ { "TETRAGRAM FOR RESISTANCE",NULL},
/* 1D31C */ { "TETRAGRAM FOR EASE",NULL},
/* 1D31D */ { "TETRAGRAM FOR JOY",NULL},
/* 1D31E */ { "TETRAGRAM FOR CONTENTION",NULL},
/* 1D31F */ { "TETRAGRAM FOR ENDEAVOUR",NULL},
/* 1D320 */ { "TETRAGRAM FOR DUTIES",NULL},
/* 1D321 */ { "TETRAGRAM FOR CHANGE",NULL},
/* 1D322 */ { "TETRAGRAM FOR DECISIVENESS",NULL},
/* 1D323 */ { "TETRAGRAM FOR BOLD RESOLUTION",NULL},
/* 1D324 */ { "TETRAGRAM FOR PACKING",NULL},
/* 1D325 */ { "TETRAGRAM FOR LEGION",NULL},
/* 1D326 */ { "TETRAGRAM FOR CLOSENESS",NULL},
/* 1D327 */ { "TETRAGRAM FOR KINSHIP",NULL},
/* 1D328 */ { "TETRAGRAM FOR GATHERING",NULL},
/* 1D329 */ { "TETRAGRAM FOR STRENGTH",NULL},
/* 1D32A */ { "TETRAGRAM FOR PURITY",NULL},
/* 1D32B */ { "TETRAGRAM FOR FULLNESS",NULL},
/* 1D32C */ { "TETRAGRAM FOR RESIDENCE",NULL},
/* 1D32D */ { "TETRAGRAM FOR LAW OR MODEL",NULL},
/* 1D32E */ { "TETRAGRAM FOR RESPONSE",NULL},
/* 1D32F */ { "TETRAGRAM FOR GOING TO MEET",NULL},
/* 1D330 */ { "TETRAGRAM FOR ENCOUNTERS",NULL},
/* 1D331 */ { "TETRAGRAM FOR STOVE",NULL},
/* 1D332 */ { "TETRAGRAM FOR GREATNESS",NULL},
/* 1D333 */ { "TETRAGRAM FOR ENLARGEMENT",NULL},
/* 1D334 */ { "TETRAGRAM FOR PATTERN",NULL},
/* 1D335 */ { "TETRAGRAM FOR RITUAL",NULL},
/* 1D336 */ { "TETRAGRAM FOR FLIGHT",NULL},
/* 1D337 */ { "TETRAGRAM FOR VASTNESS OR WASTING",NULL},
/* 1D338 */ { "TETRAGRAM FOR CONSTANCY",NULL},
/* 1D339 */ { "TETRAGRAM FOR MEASURE",NULL},
/* 1D33A */ { "TETRAGRAM FOR ETERNITY",NULL},
/* 1D33B */ { "TETRAGRAM FOR UNITY",NULL},
/* 1D33C */ { "TETRAGRAM FOR DIMINISHMENT",NULL},
/* 1D33D */ { "TETRAGRAM FOR CLOSED MOUTH",NULL},
/* 1D33E */ { "TETRAGRAM FOR GUARDEDNESS",NULL},
/* 1D33F */ { "TETRAGRAM FOR GATHERING IN",NULL},
/* 1D340 */ { "TETRAGRAM FOR MASSING",NULL},
/* 1D341 */ { "TETRAGRAM FOR ACCUMULATION",NULL},
/* 1D342 */ { "TETRAGRAM FOR EMBELLISHMENT",NULL},
/* 1D343 */ { "TETRAGRAM FOR DOUBT",NULL},
/* 1D344 */ { "TETRAGRAM FOR WATCH",NULL},
/* 1D345 */ { "TETRAGRAM FOR SINKING",NULL},
/* 1D346 */ { "TETRAGRAM FOR INNER",NULL},
/* 1D347 */ { "TETRAGRAM FOR DEPARTURE",NULL},
/* 1D348 */ { "TETRAGRAM FOR DARKENING",NULL},
/* 1D349 */ { "TETRAGRAM FOR DIMMING",NULL},
/* 1D34A */ { "TETRAGRAM FOR EXHAUSTION",NULL},
/* 1D34B */ { "TETRAGRAM FOR SEVERANCE",NULL},
/* 1D34C */ { "TETRAGRAM FOR STOPPAGE",NULL},
/* 1D34D */ { "TETRAGRAM FOR HARDNESS",NULL},
/* 1D34E */ { "TETRAGRAM FOR COMPLETION",NULL},
/* 1D34F */ { "TETRAGRAM FOR CLOSURE",NULL},
/* 1D350 */ { "TETRAGRAM FOR FAILURE",NULL},
/* 1D351 */ { "TETRAGRAM FOR AGGRAVATION",NULL},
/* 1D352 */ { "TETRAGRAM FOR COMPLIANCE",NULL},
/* 1D353 */ { "TETRAGRAM FOR ON THE VERGE",NULL},
/* 1D354 */ { "TETRAGRAM FOR DIFFICULTIES",NULL},
/* 1D355 */ { "TETRAGRAM FOR LABOURING",NULL},
/* 1D356 */ { "TETRAGRAM FOR FOSTERING",NULL},
/* 1D357 */ { NULL,NULL},
/* 1D358 */ { NULL,NULL},
/* 1D359 */ { NULL,NULL},
/* 1D35A */ { NULL,NULL},
/* 1D35B */ { NULL,NULL},
/* 1D35C */ { NULL,NULL},
/* 1D35D */ { NULL,NULL},
/* 1D35E */ { NULL,NULL},
/* 1D35F */ { NULL,NULL},
/* 1D360 */ { "COUNTING ROD UNIT DIGIT ONE",NULL},
/* 1D361 */ { "COUNTING ROD UNIT DIGIT TWO",NULL},
/* 1D362 */ { "COUNTING ROD UNIT DIGIT THREE",NULL},
/* 1D363 */ { "COUNTING ROD UNIT DIGIT FOUR",NULL},
/* 1D364 */ { "COUNTING ROD UNIT DIGIT FIVE",NULL},
/* 1D365 */ { "COUNTING ROD UNIT DIGIT SIX",NULL},
/* 1D366 */ { "COUNTING ROD UNIT DIGIT SEVEN",NULL},
/* 1D367 */ { "COUNTING ROD UNIT DIGIT EIGHT",NULL},
/* 1D368 */ { "COUNTING ROD UNIT DIGIT NINE",NULL},
/* 1D369 */ { "COUNTING ROD TENS DIGIT ONE",NULL},
/* 1D36A */ { "COUNTING ROD TENS DIGIT TWO",NULL},
/* 1D36B */ { "COUNTING ROD TENS DIGIT THREE",NULL},
/* 1D36C */ { "COUNTING ROD TENS DIGIT FOUR",NULL},
/* 1D36D */ { "COUNTING ROD TENS DIGIT FIVE",NULL},
/* 1D36E */ { "COUNTING ROD TENS DIGIT SIX",NULL},
/* 1D36F */ { "COUNTING ROD TENS DIGIT SEVEN",NULL},
/* 1D370 */ { "COUNTING ROD TENS DIGIT EIGHT",NULL},
/* 1D371 */ { "COUNTING ROD TENS DIGIT NINE",NULL},
/* 1D372 */ { "IDEOGRAPHIC TALLY MARK ONE",NULL},
/* 1D373 */ { "IDEOGRAPHIC TALLY MARK TWO",NULL},
/* 1D374 */ { "IDEOGRAPHIC TALLY MARK THREE",NULL},
/* 1D375 */ { "IDEOGRAPHIC TALLY MARK FOUR",NULL},
/* 1D376 */ { "IDEOGRAPHIC TALLY MARK FIVE","	x 6B63"},
/* 1D377 */ { "TALLY MARK ONE",NULL},
/* 1D378 */ { "TALLY MARK FIVE",NULL},
/* 1D379 */ { NULL,NULL},
/* 1D37A */ { NULL,NULL},
/* 1D37B */ { NULL,NULL},
/* 1D37C */ { NULL,NULL},
/* 1D37D */ { NULL,NULL},
/* 1D37E */ { NULL,NULL},
/* 1D37F */ { NULL,NULL},
/* 1D380 */ { NULL,NULL},
/* 1D381 */ { NULL,NULL},
/* 1D382 */ { NULL,NULL},
/* 1D383 */ { NULL,NULL},
/* 1D384 */ { NULL,NULL},
/* 1D385 */ { NULL,NULL},
/* 1D386 */ { NULL,NULL},
/* 1D387 */ { NULL,NULL},
/* 1D388 */ { NULL,NULL},
/* 1D389 */ { NULL,NULL},
/* 1D38A */ { NULL,NULL},
/* 1D38B */ { NULL,NULL},
/* 1D38C */ { NULL,NULL},
/* 1D38D */ { NULL,NULL},
/* 1D38E */ { NULL,NULL},
/* 1D38F */ { NULL,NULL},
/* 1D390 */ { NULL,NULL},
/* 1D391 */ { NULL,NULL},
/* 1D392 */ { NULL,NULL},
/* 1D393 */ { NULL,NULL},
/* 1D394 */ { NULL,NULL},
/* 1D395 */ { NULL,NULL},
/* 1D396 */ { NULL,NULL},
/* 1D397 */ { NULL,NULL},
/* 1D398 */ { NULL,NULL},
/* 1D399 */ { NULL,NULL},
/* 1D39A */ { NULL,NULL},
/* 1D39B */ { NULL,NULL},
/* 1D39C */ { NULL,NULL},
/* 1D39D */ { NULL,NULL},
/* 1D39E */ { NULL,NULL},
/* 1D39F */ { NULL,NULL},
/* 1D3A0 */ { NULL,NULL},
/* 1D3A1 */ { NULL,NULL},
/* 1D3A2 */ { NULL,NULL},
/* 1D3A3 */ { NULL,NULL},
/* 1D3A4 */ { NULL,NULL},
/* 1D3A5 */ { NULL,NULL},
/* 1D3A6 */ { NULL,NULL},
/* 1D3A7 */ { NULL,NULL},
/* 1D3A8 */ { NULL,NULL},
/* 1D3A9 */ { NULL,NULL},
/* 1D3AA */ { NULL,NULL},
/* 1D3AB */ { NULL,NULL},
/* 1D3AC */ { NULL,NULL},
/* 1D3AD */ { NULL,NULL},
/* 1D3AE */ { NULL,NULL},
/* 1D3AF */ { NULL,NULL},
/* 1D3B0 */ { NULL,NULL},
/* 1D3B1 */ { NULL,NULL},
/* 1D3B2 */ { NULL,NULL},
/* 1D3B3 */ { NULL,NULL},
/* 1D3B4 */ { NULL,NULL},
/* 1D3B5 */ { NULL,NULL},
/* 1D3B6 */ { NULL,NULL},
/* 1D3B7 */ { NULL,NULL},
/* 1D3B8 */ { NULL,NULL},
/* 1D3B9 */ { NULL,NULL},
/* 1D3BA */ { NULL,NULL},
/* 1D3BB */ { NULL,NULL},
/* 1D3BC */ { NULL,NULL},
/* 1D3BD */ { NULL,NULL},
/* 1D3BE */ { NULL,NULL},
/* 1D3BF */ { NULL,NULL},
/* 1D3C0 */ { NULL,NULL},
/* 1D3C1 */ { NULL,NULL},
/* 1D3C2 */ { NULL,NULL},
/* 1D3C3 */ { NULL,NULL},
/* 1D3C4 */ { NULL,NULL},
/* 1D3C5 */ { NULL,NULL},
/* 1D3C6 */ { NULL,NULL},
/* 1D3C7 */ { NULL,NULL},
/* 1D3C8 */ { NULL,NULL},
/* 1D3C9 */ { NULL,NULL},
/* 1D3CA */ { NULL,NULL},
/* 1D3CB */ { NULL,NULL},
/* 1D3CC */ { NULL,NULL},
/* 1D3CD */ { NULL,NULL},
/* 1D3CE */ { NULL,NULL},
/* 1D3CF */ { NULL,NULL},
/* 1D3D0 */ { NULL,NULL},
/* 1D3D1 */ { NULL,NULL},
/* 1D3D2 */ { NULL,NULL},
/* 1D3D3 */ { NULL,NULL},
/* 1D3D4 */ { NULL,NULL},
/* 1D3D5 */ { NULL,NULL},
/* 1D3D6 */ { NULL,NULL},
/* 1D3D7 */ { NULL,NULL},
/* 1D3D8 */ { NULL,NULL},
/* 1D3D9 */ { NULL,NULL},
/* 1D3DA */ { NULL,NULL},
/* 1D3DB */ { NULL,NULL},
/* 1D3DC */ { NULL,NULL},
/* 1D3DD */ { NULL,NULL},
/* 1D3DE */ { NULL,NULL},
/* 1D3DF */ { NULL,NULL},
/* 1D3E0 */ { NULL,NULL},
/* 1D3E1 */ { NULL,NULL},
/* 1D3E2 */ { NULL,NULL},
/* 1D3E3 */ { NULL,NULL},
/* 1D3E4 */ { NULL,NULL},
/* 1D3E5 */ { NULL,NULL},
/* 1D3E6 */ { NULL,NULL},
/* 1D3E7 */ { NULL,NULL},
/* 1D3E8 */ { NULL,NULL},
/* 1D3E9 */ { NULL,NULL},
/* 1D3EA */ { NULL,NULL},
/* 1D3EB */ { NULL,NULL},
/* 1D3EC */ { NULL,NULL},
/* 1D3ED */ { NULL,NULL},
/* 1D3EE */ { NULL,NULL},
/* 1D3EF */ { NULL,NULL},
/* 1D3F0 */ { NULL,NULL},
/* 1D3F1 */ { NULL,NULL},
/* 1D3F2 */ { NULL,NULL},
/* 1D3F3 */ { NULL,NULL},
/* 1D3F4 */ { NULL,NULL},
/* 1D3F5 */ { NULL,NULL},
/* 1D3F6 */ { NULL,NULL},
/* 1D3F7 */ { NULL,NULL},
/* 1D3F8 */ { NULL,NULL},
/* 1D3F9 */ { NULL,NULL},
/* 1D3FA */ { NULL,NULL},
/* 1D3FB */ { NULL,NULL},
/* 1D3FC */ { NULL,NULL},
/* 1D3FD */ { NULL,NULL},
/* 1D3FE */ { NULL,NULL},
/* 1D3FF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_D4[] = {
/* 1D400 */ { "MATHEMATICAL BOLD CAPITAL A","	# <font> 0041 latin capital letter a"},
/* 1D401 */ { "MATHEMATICAL BOLD CAPITAL B","	# <font> 0042 latin capital letter b"},
/* 1D402 */ { "MATHEMATICAL BOLD CAPITAL C","	# <font> 0043 latin capital letter c"},
/* 1D403 */ { "MATHEMATICAL BOLD CAPITAL D","	# <font> 0044 latin capital letter d"},
/* 1D404 */ { "MATHEMATICAL BOLD CAPITAL E","	# <font> 0045 latin capital letter e"},
/* 1D405 */ { "MATHEMATICAL BOLD CAPITAL F","	# <font> 0046 latin capital letter f"},
/* 1D406 */ { "MATHEMATICAL BOLD CAPITAL G","	# <font> 0047 latin capital letter g"},
/* 1D407 */ { "MATHEMATICAL BOLD CAPITAL H","	# <font> 0048 latin capital letter h"},
/* 1D408 */ { "MATHEMATICAL BOLD CAPITAL I","	# <font> 0049 latin capital letter i"},
/* 1D409 */ { "MATHEMATICAL BOLD CAPITAL J","	# <font> 004A latin capital letter j"},
/* 1D40A */ { "MATHEMATICAL BOLD CAPITAL K","	# <font> 004B latin capital letter k"},
/* 1D40B */ { "MATHEMATICAL BOLD CAPITAL L","	# <font> 004C latin capital letter l"},
/* 1D40C */ { "MATHEMATICAL BOLD CAPITAL M","	# <font> 004D latin capital letter m"},
/* 1D40D */ { "MATHEMATICAL BOLD CAPITAL N","	# <font> 004E latin capital letter n"},
/* 1D40E */ { "MATHEMATICAL BOLD CAPITAL O","	# <font> 004F latin capital letter o"},
/* 1D40F */ { "MATHEMATICAL BOLD CAPITAL P","	# <font> 0050 latin capital letter p"},
/* 1D410 */ { "MATHEMATICAL BOLD CAPITAL Q","	# <font> 0051 latin capital letter q"},
/* 1D411 */ { "MATHEMATICAL BOLD CAPITAL R","	# <font> 0052 latin capital letter r"},
/* 1D412 */ { "MATHEMATICAL BOLD CAPITAL S","	# <font> 0053 latin capital letter s"},
/* 1D413 */ { "MATHEMATICAL BOLD CAPITAL T","	# <font> 0054 latin capital letter t"},
/* 1D414 */ { "MATHEMATICAL BOLD CAPITAL U","	# <font> 0055 latin capital letter u"},
/* 1D415 */ { "MATHEMATICAL BOLD CAPITAL V","	# <font> 0056 latin capital letter v"},
/* 1D416 */ { "MATHEMATICAL BOLD CAPITAL W","	# <font> 0057 latin capital letter w"},
/* 1D417 */ { "MATHEMATICAL BOLD CAPITAL X","	# <font> 0058 latin capital letter x"},
/* 1D418 */ { "MATHEMATICAL BOLD CAPITAL Y","	# <font> 0059 latin capital letter y"},
/* 1D419 */ { "MATHEMATICAL BOLD CAPITAL Z","	# <font> 005A latin capital letter z"},
/* 1D41A */ { "MATHEMATICAL BOLD SMALL A","	# <font> 0061 latin small letter a"},
/* 1D41B */ { "MATHEMATICAL BOLD SMALL B","	# <font> 0062 latin small letter b"},
/* 1D41C */ { "MATHEMATICAL BOLD SMALL C","	# <font> 0063 latin small letter c"},
/* 1D41D */ { "MATHEMATICAL BOLD SMALL D","	# <font> 0064 latin small letter d"},
/* 1D41E */ { "MATHEMATICAL BOLD SMALL E","	# <font> 0065 latin small letter e"},
/* 1D41F */ { "MATHEMATICAL BOLD SMALL F","	# <font> 0066 latin small letter f"},
/* 1D420 */ { "MATHEMATICAL BOLD SMALL G","	# <font> 0067 latin small letter g"},
/* 1D421 */ { "MATHEMATICAL BOLD SMALL H","	# <font> 0068 latin small letter h"},
/* 1D422 */ { "MATHEMATICAL BOLD SMALL I","	# <font> 0069 latin small letter i"},
/* 1D423 */ { "MATHEMATICAL BOLD SMALL J","	# <font> 006A latin small letter j"},
/* 1D424 */ { "MATHEMATICAL BOLD SMALL K","	# <font> 006B latin small letter k"},
/* 1D425 */ { "MATHEMATICAL BOLD SMALL L","	# <font> 006C latin small letter l"},
/* 1D426 */ { "MATHEMATICAL BOLD SMALL M","	# <font> 006D latin small letter m"},
/* 1D427 */ { "MATHEMATICAL BOLD SMALL N","	# <font> 006E latin small letter n"},
/* 1D428 */ { "MATHEMATICAL BOLD SMALL O","	# <font> 006F latin small letter o"},
/* 1D429 */ { "MATHEMATICAL BOLD SMALL P","	# <font> 0070 latin small letter p"},
/* 1D42A */ { "MATHEMATICAL BOLD SMALL Q","	# <font> 0071 latin small letter q"},
/* 1D42B */ { "MATHEMATICAL BOLD SMALL R","	# <font> 0072 latin small letter r"},
/* 1D42C */ { "MATHEMATICAL BOLD SMALL S","	# <font> 0073 latin small letter s"},
/* 1D42D */ { "MATHEMATICAL BOLD SMALL T","	# <font> 0074 latin small letter t"},
/* 1D42E */ { "MATHEMATICAL BOLD SMALL U","	# <font> 0075 latin small letter u"},
/* 1D42F */ { "MATHEMATICAL BOLD SMALL V","	# <font> 0076 latin small letter v"},
/* 1D430 */ { "MATHEMATICAL BOLD SMALL W","	# <font> 0077 latin small letter w"},
/* 1D431 */ { "MATHEMATICAL BOLD SMALL X","	# <font> 0078 latin small letter x"},
/* 1D432 */ { "MATHEMATICAL BOLD SMALL Y","	# <font> 0079 latin small letter y"},
/* 1D433 */ { "MATHEMATICAL BOLD SMALL Z","	# <font> 007A latin small letter z"},
/* 1D434 */ { "MATHEMATICAL ITALIC CAPITAL A","	# <font> 0041 latin capital letter a"},
/* 1D435 */ { "MATHEMATICAL ITALIC CAPITAL B","	# <font> 0042 latin capital letter b"},
/* 1D436 */ { "MATHEMATICAL ITALIC CAPITAL C","	# <font> 0043 latin capital letter c"},
/* 1D437 */ { "MATHEMATICAL ITALIC CAPITAL D","	# <font> 0044 latin capital letter d"},
/* 1D438 */ { "MATHEMATICAL ITALIC CAPITAL E","	# <font> 0045 latin capital letter e"},
/* 1D439 */ { "MATHEMATICAL ITALIC CAPITAL F","	# <font> 0046 latin capital letter f"},
/* 1D43A */ { "MATHEMATICAL ITALIC CAPITAL G","	# <font> 0047 latin capital letter g"},
/* 1D43B */ { "MATHEMATICAL ITALIC CAPITAL H","	# <font> 0048 latin capital letter h"},
/* 1D43C */ { "MATHEMATICAL ITALIC CAPITAL I","	# <font> 0049 latin capital letter i"},
/* 1D43D */ { "MATHEMATICAL ITALIC CAPITAL J","	# <font> 004A latin capital letter j"},
/* 1D43E */ { "MATHEMATICAL ITALIC CAPITAL K","	# <font> 004B latin capital letter k"},
/* 1D43F */ { "MATHEMATICAL ITALIC CAPITAL L","	# <font> 004C latin capital letter l"},
/* 1D440 */ { "MATHEMATICAL ITALIC CAPITAL M","	# <font> 004D latin capital letter m"},
/* 1D441 */ { "MATHEMATICAL ITALIC CAPITAL N","	# <font> 004E latin capital letter n"},
/* 1D442 */ { "MATHEMATICAL ITALIC CAPITAL O","	# <font> 004F latin capital letter o"},
/* 1D443 */ { "MATHEMATICAL ITALIC CAPITAL P","	# <font> 0050 latin capital letter p"},
/* 1D444 */ { "MATHEMATICAL ITALIC CAPITAL Q","	# <font> 0051 latin capital letter q"},
/* 1D445 */ { "MATHEMATICAL ITALIC CAPITAL R","	# <font> 0052 latin capital letter r"},
/* 1D446 */ { "MATHEMATICAL ITALIC CAPITAL S","	# <font> 0053 latin capital letter s"},
/* 1D447 */ { "MATHEMATICAL ITALIC CAPITAL T","	# <font> 0054 latin capital letter t"},
/* 1D448 */ { "MATHEMATICAL ITALIC CAPITAL U","	# <font> 0055 latin capital letter u"},
/* 1D449 */ { "MATHEMATICAL ITALIC CAPITAL V","	# <font> 0056 latin capital letter v"},
/* 1D44A */ { "MATHEMATICAL ITALIC CAPITAL W","	# <font> 0057 latin capital letter w"},
/* 1D44B */ { "MATHEMATICAL ITALIC CAPITAL X","	# <font> 0058 latin capital letter x"},
/* 1D44C */ { "MATHEMATICAL ITALIC CAPITAL Y","	# <font> 0059 latin capital letter y"},
/* 1D44D */ { "MATHEMATICAL ITALIC CAPITAL Z","	# <font> 005A latin capital letter z"},
/* 1D44E */ { "MATHEMATICAL ITALIC SMALL A","	# <font> 0061 latin small letter a"},
/* 1D44F */ { "MATHEMATICAL ITALIC SMALL B","	# <font> 0062 latin small letter b"},
/* 1D450 */ { "MATHEMATICAL ITALIC SMALL C","	# <font> 0063 latin small letter c"},
/* 1D451 */ { "MATHEMATICAL ITALIC SMALL D","	# <font> 0064 latin small letter d"},
/* 1D452 */ { "MATHEMATICAL ITALIC SMALL E","	# <font> 0065 latin small letter e"},
/* 1D453 */ { "MATHEMATICAL ITALIC SMALL F","	# <font> 0066 latin small letter f"},
/* 1D454 */ { "MATHEMATICAL ITALIC SMALL G","	# <font> 0067 latin small letter g"},
/* 1D455 */ { NULL,"	x (planck constant - 210E)"},
/* 1D456 */ { "MATHEMATICAL ITALIC SMALL I","	# <font> 0069 latin small letter i"},
/* 1D457 */ { "MATHEMATICAL ITALIC SMALL J","	# <font> 006A latin small letter j"},
/* 1D458 */ { "MATHEMATICAL ITALIC SMALL K","	# <font> 006B latin small letter k"},
/* 1D459 */ { "MATHEMATICAL ITALIC SMALL L","	# <font> 006C latin small letter l"},
/* 1D45A */ { "MATHEMATICAL ITALIC SMALL M","	# <font> 006D latin small letter m"},
/* 1D45B */ { "MATHEMATICAL ITALIC SMALL N","	# <font> 006E latin small letter n"},
/* 1D45C */ { "MATHEMATICAL ITALIC SMALL O","	# <font> 006F latin small letter o"},
/* 1D45D */ { "MATHEMATICAL ITALIC SMALL P","	# <font> 0070 latin small letter p"},
/* 1D45E */ { "MATHEMATICAL ITALIC SMALL Q","	# <font> 0071 latin small letter q"},
/* 1D45F */ { "MATHEMATICAL ITALIC SMALL R","	# <font> 0072 latin small letter r"},
/* 1D460 */ { "MATHEMATICAL ITALIC SMALL S","	# <font> 0073 latin small letter s"},
/* 1D461 */ { "MATHEMATICAL ITALIC SMALL T","	# <font> 0074 latin small letter t"},
/* 1D462 */ { "MATHEMATICAL ITALIC SMALL U","	# <font> 0075 latin small letter u"},
/* 1D463 */ { "MATHEMATICAL ITALIC SMALL V","	# <font> 0076 latin small letter v"},
/* 1D464 */ { "MATHEMATICAL ITALIC SMALL W","	# <font> 0077 latin small letter w"},
/* 1D465 */ { "MATHEMATICAL ITALIC SMALL X","	# <font> 0078 latin small letter x"},
/* 1D466 */ { "MATHEMATICAL ITALIC SMALL Y","	# <font> 0079 latin small letter y"},
/* 1D467 */ { "MATHEMATICAL ITALIC SMALL Z","	# <font> 007A latin small letter z"},
/* 1D468 */ { "MATHEMATICAL BOLD ITALIC CAPITAL A","	# <font> 0041 latin capital letter a"},
/* 1D469 */ { "MATHEMATICAL BOLD ITALIC CAPITAL B","	# <font> 0042 latin capital letter b"},
/* 1D46A */ { "MATHEMATICAL BOLD ITALIC CAPITAL C","	# <font> 0043 latin capital letter c"},
/* 1D46B */ { "MATHEMATICAL BOLD ITALIC CAPITAL D","	# <font> 0044 latin capital letter d"},
/* 1D46C */ { "MATHEMATICAL BOLD ITALIC CAPITAL E","	# <font> 0045 latin capital letter e"},
/* 1D46D */ { "MATHEMATICAL BOLD ITALIC CAPITAL F","	# <font> 0046 latin capital letter f"},
/* 1D46E */ { "MATHEMATICAL BOLD ITALIC CAPITAL G","	# <font> 0047 latin capital letter g"},
/* 1D46F */ { "MATHEMATICAL BOLD ITALIC CAPITAL H","	# <font> 0048 latin capital letter h"},
/* 1D470 */ { "MATHEMATICAL BOLD ITALIC CAPITAL I","	# <font> 0049 latin capital letter i"},
/* 1D471 */ { "MATHEMATICAL BOLD ITALIC CAPITAL J","	# <font> 004A latin capital letter j"},
/* 1D472 */ { "MATHEMATICAL BOLD ITALIC CAPITAL K","	# <font> 004B latin capital letter k"},
/* 1D473 */ { "MATHEMATICAL BOLD ITALIC CAPITAL L","	# <font> 004C latin capital letter l"},
/* 1D474 */ { "MATHEMATICAL BOLD ITALIC CAPITAL M","	# <font> 004D latin capital letter m"},
/* 1D475 */ { "MATHEMATICAL BOLD ITALIC CAPITAL N","	# <font> 004E latin capital letter n"},
/* 1D476 */ { "MATHEMATICAL BOLD ITALIC CAPITAL O","	# <font> 004F latin capital letter o"},
/* 1D477 */ { "MATHEMATICAL BOLD ITALIC CAPITAL P","	# <font> 0050 latin capital letter p"},
/* 1D478 */ { "MATHEMATICAL BOLD ITALIC CAPITAL Q","	# <font> 0051 latin capital letter q"},
/* 1D479 */ { "MATHEMATICAL BOLD ITALIC CAPITAL R","	# <font> 0052 latin capital letter r"},
/* 1D47A */ { "MATHEMATICAL BOLD ITALIC CAPITAL S","	# <font> 0053 latin capital letter s"},
/* 1D47B */ { "MATHEMATICAL BOLD ITALIC CAPITAL T","	# <font> 0054 latin capital letter t"},
/* 1D47C */ { "MATHEMATICAL BOLD ITALIC CAPITAL U","	# <font> 0055 latin capital letter u"},
/* 1D47D */ { "MATHEMATICAL BOLD ITALIC CAPITAL V","	# <font> 0056 latin capital letter v"},
/* 1D47E */ { "MATHEMATICAL BOLD ITALIC CAPITAL W","	# <font> 0057 latin capital letter w"},
/* 1D47F */ { "MATHEMATICAL BOLD ITALIC CAPITAL X","	# <font> 0058 latin capital letter x"},
/* 1D480 */ { "MATHEMATICAL BOLD ITALIC CAPITAL Y","	# <font> 0059 latin capital letter y"},
/* 1D481 */ { "MATHEMATICAL BOLD ITALIC CAPITAL Z","	# <font> 005A latin capital letter z"},
/* 1D482 */ { "MATHEMATICAL BOLD ITALIC SMALL A","	# <font> 0061 latin small letter a"},
/* 1D483 */ { "MATHEMATICAL BOLD ITALIC SMALL B","	# <font> 0062 latin small letter b"},
/* 1D484 */ { "MATHEMATICAL BOLD ITALIC SMALL C","	# <font> 0063 latin small letter c"},
/* 1D485 */ { "MATHEMATICAL BOLD ITALIC SMALL D","	# <font> 0064 latin small letter d"},
/* 1D486 */ { "MATHEMATICAL BOLD ITALIC SMALL E","	# <font> 0065 latin small letter e"},
/* 1D487 */ { "MATHEMATICAL BOLD ITALIC SMALL F","	# <font> 0066 latin small letter f"},
/* 1D488 */ { "MATHEMATICAL BOLD ITALIC SMALL G","	# <font> 0067 latin small letter g"},
/* 1D489 */ { "MATHEMATICAL BOLD ITALIC SMALL H","	# <font> 0068 latin small letter h"},
/* 1D48A */ { "MATHEMATICAL BOLD ITALIC SMALL I","	# <font> 0069 latin small letter i"},
/* 1D48B */ { "MATHEMATICAL BOLD ITALIC SMALL J","	# <font> 006A latin small letter j"},
/* 1D48C */ { "MATHEMATICAL BOLD ITALIC SMALL K","	# <font> 006B latin small letter k"},
/* 1D48D */ { "MATHEMATICAL BOLD ITALIC SMALL L","	# <font> 006C latin small letter l"},
/* 1D48E */ { "MATHEMATICAL BOLD ITALIC SMALL M","	# <font> 006D latin small letter m"},
/* 1D48F */ { "MATHEMATICAL BOLD ITALIC SMALL N","	# <font> 006E latin small letter n"},
/* 1D490 */ { "MATHEMATICAL BOLD ITALIC SMALL O","	# <font> 006F latin small letter o"},
/* 1D491 */ { "MATHEMATICAL BOLD ITALIC SMALL P","	# <font> 0070 latin small letter p"},
/* 1D492 */ { "MATHEMATICAL BOLD ITALIC SMALL Q","	# <font> 0071 latin small letter q"},
/* 1D493 */ { "MATHEMATICAL BOLD ITALIC SMALL R","	# <font> 0072 latin small letter r"},
/* 1D494 */ { "MATHEMATICAL BOLD ITALIC SMALL S","	# <font> 0073 latin small letter s"},
/* 1D495 */ { "MATHEMATICAL BOLD ITALIC SMALL T","	# <font> 0074 latin small letter t"},
/* 1D496 */ { "MATHEMATICAL BOLD ITALIC SMALL U","	# <font> 0075 latin small letter u"},
/* 1D497 */ { "MATHEMATICAL BOLD ITALIC SMALL V","	# <font> 0076 latin small letter v"},
/* 1D498 */ { "MATHEMATICAL BOLD ITALIC SMALL W","	# <font> 0077 latin small letter w"},
/* 1D499 */ { "MATHEMATICAL BOLD ITALIC SMALL X","	# <font> 0078 latin small letter x"},
/* 1D49A */ { "MATHEMATICAL BOLD ITALIC SMALL Y","	# <font> 0079 latin small letter y"},
/* 1D49B */ { "MATHEMATICAL BOLD ITALIC SMALL Z","	# <font> 007A latin small letter z"},
/* 1D49C */ { "MATHEMATICAL SCRIPT CAPITAL A","	~ 1D49C FE00 chancery style\n"
	"	~ 1D49C FE01 roundhand style\n"
	"	# <font> 0041 latin capital letter a"},
/* 1D49D */ { NULL,"	x (script capital b - 212C)"},
/* 1D49E */ { "MATHEMATICAL SCRIPT CAPITAL C","	~ 1D49E FE00 chancery style\n"
	"	~ 1D49E FE01 roundhand style\n"
	"	# <font> 0043 latin capital letter c"},
/* 1D49F */ { "MATHEMATICAL SCRIPT CAPITAL D","	~ 1D49F FE00 chancery style\n"
	"	~ 1D49F FE01 roundhand style\n"
	"	# <font> 0044 latin capital letter d"},
/* 1D4A0 */ { NULL,"	x (script capital e - 2130)"},
/* 1D4A1 */ { NULL,"	x (script capital f - 2131)"},
/* 1D4A2 */ { "MATHEMATICAL SCRIPT CAPITAL G","	~ 1D4A2 FE00 chancery style\n"
	"	~ 1D4A2 FE01 roundhand style\n"
	"	# <font> 0047 latin capital letter g"},
/* 1D4A3 */ { NULL,"	x (script capital h - 210B)"},
/* 1D4A4 */ { NULL,"	x (script capital i - 2110)"},
/* 1D4A5 */ { "MATHEMATICAL SCRIPT CAPITAL J","	~ 1D4A5 FE00 chancery style\n"
	"	~ 1D4A5 FE01 roundhand style\n"
	"	# <font> 004A latin capital letter j"},
/* 1D4A6 */ { "MATHEMATICAL SCRIPT CAPITAL K","	~ 1D4A6 FE00 chancery style\n"
	"	~ 1D4A6 FE01 roundhand style\n"
	"	# <font> 004B latin capital letter k"},
/* 1D4A7 */ { NULL,"	x (script capital l - 2112)"},
/* 1D4A8 */ { NULL,"	x (script capital m - 2133)"},
/* 1D4A9 */ { "MATHEMATICAL SCRIPT CAPITAL N","	~ 1D4A9 FE00 chancery style\n"
	"	~ 1D4A9 FE01 roundhand style\n"
	"	# <font> 004E latin capital letter n"},
/* 1D4AA */ { "MATHEMATICAL SCRIPT CAPITAL O","	~ 1D4AA FE00 chancery style\n"
	"	~ 1D4AA FE01 roundhand style\n"
	"	# <font> 004F latin capital letter o"},
/* 1D4AB */ { "MATHEMATICAL SCRIPT CAPITAL P","	= power set\n"
	"	~ 1D4AB FE00 chancery style\n"
	"	~ 1D4AB FE01 roundhand style\n"
	"	# <font> 0050 latin capital letter p"},
/* 1D4AC */ { "MATHEMATICAL SCRIPT CAPITAL Q","	~ 1D4AC FE00 chancery style\n"
	"	~ 1D4AC FE01 roundhand style\n"
	"	# <font> 0051 latin capital letter q"},
/* 1D4AD */ { NULL,"	x (script capital r - 211B)"},
/* 1D4AE */ { "MATHEMATICAL SCRIPT CAPITAL S","	~ 1D4AE FE00 chancery style\n"
	"	~ 1D4AE FE01 roundhand style\n"
	"	# <font> 0053 latin capital letter s"},
/* 1D4AF */ { "MATHEMATICAL SCRIPT CAPITAL T","	~ 1D4AF FE00 chancery style\n"
	"	~ 1D4AF FE01 roundhand style\n"
	"	# <font> 0054 latin capital letter t"},
/* 1D4B0 */ { "MATHEMATICAL SCRIPT CAPITAL U","	~ 1D4B0 FE00 chancery style\n"
	"	~ 1D4B0 FE01 roundhand style\n"
	"	# <font> 0055 latin capital letter u"},
/* 1D4B1 */ { "MATHEMATICAL SCRIPT CAPITAL V","	~ 1D4B1 FE00 chancery style\n"
	"	~ 1D4B1 FE01 roundhand style\n"
	"	# <font> 0056 latin capital letter v"},
/* 1D4B2 */ { "MATHEMATICAL SCRIPT CAPITAL W","	~ 1D4B2 FE00 chancery style\n"
	"	~ 1D4B2 FE01 roundhand style\n"
	"	# <font> 0057 latin capital letter w"},
/* 1D4B3 */ { "MATHEMATICAL SCRIPT CAPITAL X","	~ 1D4B3 FE00 chancery style\n"
	"	~ 1D4B3 FE01 roundhand style\n"
	"	# <font> 0058 latin capital letter x"},
/* 1D4B4 */ { "MATHEMATICAL SCRIPT CAPITAL Y","	~ 1D4B4 FE00 chancery style\n"
	"	~ 1D4B4 FE01 roundhand style\n"
	"	# <font> 0059 latin capital letter y"},
/* 1D4B5 */ { "MATHEMATICAL SCRIPT CAPITAL Z","	~ 1D4B5 FE00 chancery style\n"
	"	~ 1D4B5 FE01 roundhand style\n"
	"	# <font> 005A latin capital letter z"},
/* 1D4B6 */ { "MATHEMATICAL SCRIPT SMALL A","	# <font> 0061 latin small letter a"},
/* 1D4B7 */ { "MATHEMATICAL SCRIPT SMALL B","	# <font> 0062 latin small letter b"},
/* 1D4B8 */ { "MATHEMATICAL SCRIPT SMALL C","	# <font> 0063 latin small letter c"},
/* 1D4B9 */ { "MATHEMATICAL SCRIPT SMALL D","	# <font> 0064 latin small letter d"},
/* 1D4BA */ { NULL,"	x (script small e - 212F)"},
/* 1D4BB */ { "MATHEMATICAL SCRIPT SMALL F","	# <font> 0066 latin small letter f"},
/* 1D4BC */ { NULL,"	x (script small g - 210A)"},
/* 1D4BD */ { "MATHEMATICAL SCRIPT SMALL H","	# <font> 0068 latin small letter h"},
/* 1D4BE */ { "MATHEMATICAL SCRIPT SMALL I","	# <font> 0069 latin small letter i"},
/* 1D4BF */ { "MATHEMATICAL SCRIPT SMALL J","	# <font> 006A latin small letter j"},
/* 1D4C0 */ { "MATHEMATICAL SCRIPT SMALL K","	# <font> 006B latin small letter k"},
/* 1D4C1 */ { "MATHEMATICAL SCRIPT SMALL L","	x (script small l - 2113)\n"
	"	# <font> 006C latin small letter l"},
/* 1D4C2 */ { "MATHEMATICAL SCRIPT SMALL M","	# <font> 006D latin small letter m"},
/* 1D4C3 */ { "MATHEMATICAL SCRIPT SMALL N","	# <font> 006E latin small letter n"},
/* 1D4C4 */ { NULL,"	x (script small o - 2134)"},
/* 1D4C5 */ { "MATHEMATICAL SCRIPT SMALL P","	# <font> 0070 latin small letter p"},
/* 1D4C6 */ { "MATHEMATICAL SCRIPT SMALL Q","	# <font> 0071 latin small letter q"},
/* 1D4C7 */ { "MATHEMATICAL SCRIPT SMALL R","	# <font> 0072 latin small letter r"},
/* 1D4C8 */ { "MATHEMATICAL SCRIPT SMALL S","	# <font> 0073 latin small letter s"},
/* 1D4C9 */ { "MATHEMATICAL SCRIPT SMALL T","	# <font> 0074 latin small letter t"},
/* 1D4CA */ { "MATHEMATICAL SCRIPT SMALL U","	# <font> 0075 latin small letter u"},
/* 1D4CB */ { "MATHEMATICAL SCRIPT SMALL V","	# <font> 0076 latin small letter v"},
/* 1D4CC */ { "MATHEMATICAL SCRIPT SMALL W","	# <font> 0077 latin small letter w"},
/* 1D4CD */ { "MATHEMATICAL SCRIPT SMALL X","	# <font> 0078 latin small letter x"},
/* 1D4CE */ { "MATHEMATICAL SCRIPT SMALL Y","	# <font> 0079 latin small letter y"},
/* 1D4CF */ { "MATHEMATICAL SCRIPT SMALL Z","	# <font> 007A latin small letter z"},
/* 1D4D0 */ { "MATHEMATICAL BOLD SCRIPT CAPITAL A","	# <font> 0041 latin capital letter a"},
/* 1D4D1 */ { "MATHEMATICAL BOLD SCRIPT CAPITAL B","	# <font> 0042 latin capital letter b"},
/* 1D4D2 */ { "MATHEMATICAL BOLD SCRIPT CAPITAL C","	# <font> 0043 latin capital letter c"},
/* 1D4D3 */ { "MATHEMATICAL BOLD SCRIPT CAPITAL D","	# <font> 0044 latin capital letter d"},
/* 1D4D4 */ { "MATHEMATICAL BOLD SCRIPT CAPITAL E","	# <font> 0045 latin capital letter e"},
/* 1D4D5 */ { "MATHEMATICAL BOLD SCRIPT CAPITAL F","	# <font> 0046 latin capital letter f"},
/* 1D4D6 */ { "MATHEMATICAL BOLD SCRIPT CAPITAL G","	# <font> 0047 latin capital letter g"},
/* 1D4D7 */ { "MATHEMATICAL BOLD SCRIPT CAPITAL H","	# <font> 0048 latin capital letter h"},
/* 1D4D8 */ { "MATHEMATICAL BOLD SCRIPT CAPITAL I","	# <font> 0049 latin capital letter i"},
/* 1D4D9 */ { "MATHEMATICAL BOLD SCRIPT CAPITAL J","	# <font> 004A latin capital letter j"},
/* 1D4DA */ { "MATHEMATICAL BOLD SCRIPT CAPITAL K","	# <font> 004B latin capital letter k"},
/* 1D4DB */ { "MATHEMATICAL BOLD SCRIPT CAPITAL L","	# <font> 004C latin capital letter l"},
/* 1D4DC */ { "MATHEMATICAL BOLD SCRIPT CAPITAL M","	# <font> 004D latin capital letter m"},
/* 1D4DD */ { "MATHEMATICAL BOLD SCRIPT CAPITAL N","	# <font> 004E latin capital letter n"},
/* 1D4DE */ { "MATHEMATICAL BOLD SCRIPT CAPITAL O","	# <font> 004F latin capital letter o"},
/* 1D4DF */ { "MATHEMATICAL BOLD SCRIPT CAPITAL P","	# <font> 0050 latin capital letter p"},
/* 1D4E0 */ { "MATHEMATICAL BOLD SCRIPT CAPITAL Q","	# <font> 0051 latin capital letter q"},
/* 1D4E1 */ { "MATHEMATICAL BOLD SCRIPT CAPITAL R","	# <font> 0052 latin capital letter r"},
/* 1D4E2 */ { "MATHEMATICAL BOLD SCRIPT CAPITAL S","	# <font> 0053 latin capital letter s"},
/* 1D4E3 */ { "MATHEMATICAL BOLD SCRIPT CAPITAL T","	# <font> 0054 latin capital letter t"},
/* 1D4E4 */ { "MATHEMATICAL BOLD SCRIPT CAPITAL U","	# <font> 0055 latin capital letter u"},
/* 1D4E5 */ { "MATHEMATICAL BOLD SCRIPT CAPITAL V","	# <font> 0056 latin capital letter v"},
/* 1D4E6 */ { "MATHEMATICAL BOLD SCRIPT CAPITAL W","	# <font> 0057 latin capital letter w"},
/* 1D4E7 */ { "MATHEMATICAL BOLD SCRIPT CAPITAL X","	# <font> 0058 latin capital letter x"},
/* 1D4E8 */ { "MATHEMATICAL BOLD SCRIPT CAPITAL Y","	# <font> 0059 latin capital letter y"},
/* 1D4E9 */ { "MATHEMATICAL BOLD SCRIPT CAPITAL Z","	# <font> 005A latin capital letter z"},
/* 1D4EA */ { "MATHEMATICAL BOLD SCRIPT SMALL A","	# <font> 0061 latin small letter a"},
/* 1D4EB */ { "MATHEMATICAL BOLD SCRIPT SMALL B","	# <font> 0062 latin small letter b"},
/* 1D4EC */ { "MATHEMATICAL BOLD SCRIPT SMALL C","	# <font> 0063 latin small letter c"},
/* 1D4ED */ { "MATHEMATICAL BOLD SCRIPT SMALL D","	# <font> 0064 latin small letter d"},
/* 1D4EE */ { "MATHEMATICAL BOLD SCRIPT SMALL E","	# <font> 0065 latin small letter e"},
/* 1D4EF */ { "MATHEMATICAL BOLD SCRIPT SMALL F","	# <font> 0066 latin small letter f"},
/* 1D4F0 */ { "MATHEMATICAL BOLD SCRIPT SMALL G","	# <font> 0067 latin small letter g"},
/* 1D4F1 */ { "MATHEMATICAL BOLD SCRIPT SMALL H","	# <font> 0068 latin small letter h"},
/* 1D4F2 */ { "MATHEMATICAL BOLD SCRIPT SMALL I","	# <font> 0069 latin small letter i"},
/* 1D4F3 */ { "MATHEMATICAL BOLD SCRIPT SMALL J","	# <font> 006A latin small letter j"},
/* 1D4F4 */ { "MATHEMATICAL BOLD SCRIPT SMALL K","	# <font> 006B latin small letter k"},
/* 1D4F5 */ { "MATHEMATICAL BOLD SCRIPT SMALL L","	# <font> 006C latin small letter l"},
/* 1D4F6 */ { "MATHEMATICAL BOLD SCRIPT SMALL M","	# <font> 006D latin small letter m"},
/* 1D4F7 */ { "MATHEMATICAL BOLD SCRIPT SMALL N","	# <font> 006E latin small letter n"},
/* 1D4F8 */ { "MATHEMATICAL BOLD SCRIPT SMALL O","	# <font> 006F latin small letter o"},
/* 1D4F9 */ { "MATHEMATICAL BOLD SCRIPT SMALL P","	# <font> 0070 latin small letter p"},
/* 1D4FA */ { "MATHEMATICAL BOLD SCRIPT SMALL Q","	# <font> 0071 latin small letter q"},
/* 1D4FB */ { "MATHEMATICAL BOLD SCRIPT SMALL R","	# <font> 0072 latin small letter r"},
/* 1D4FC */ { "MATHEMATICAL BOLD SCRIPT SMALL S","	# <font> 0073 latin small letter s"},
/* 1D4FD */ { "MATHEMATICAL BOLD SCRIPT SMALL T","	# <font> 0074 latin small letter t"},
/* 1D4FE */ { "MATHEMATICAL BOLD SCRIPT SMALL U","	# <font> 0075 latin small letter u"},
/* 1D4FF */ { "MATHEMATICAL BOLD SCRIPT SMALL V","	# <font> 0076 latin small letter v"}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_D5[] = {
/* 1D500 */ { "MATHEMATICAL BOLD SCRIPT SMALL W","	# <font> 0077 latin small letter w"},
/* 1D501 */ { "MATHEMATICAL BOLD SCRIPT SMALL X","	# <font> 0078 latin small letter x"},
/* 1D502 */ { "MATHEMATICAL BOLD SCRIPT SMALL Y","	# <font> 0079 latin small letter y"},
/* 1D503 */ { "MATHEMATICAL BOLD SCRIPT SMALL Z","	# <font> 007A latin small letter z"},
/* 1D504 */ { "MATHEMATICAL FRAKTUR CAPITAL A","	# <font> 0041 latin capital letter a"},
/* 1D505 */ { "MATHEMATICAL FRAKTUR CAPITAL B","	# <font> 0042 latin capital letter b"},
/* 1D506 */ { NULL,"	x (black-letter capital c - 212D)"},
/* 1D507 */ { "MATHEMATICAL FRAKTUR CAPITAL D","	# <font> 0044 latin capital letter d"},
/* 1D508 */ { "MATHEMATICAL FRAKTUR CAPITAL E","	# <font> 0045 latin capital letter e"},
/* 1D509 */ { "MATHEMATICAL FRAKTUR CAPITAL F","	# <font> 0046 latin capital letter f"},
/* 1D50A */ { "MATHEMATICAL FRAKTUR CAPITAL G","	# <font> 0047 latin capital letter g"},
/* 1D50B */ { NULL,"	x (black-letter capital h - 210C)"},
/* 1D50C */ { NULL,"	x (black-letter capital i - 2111)"},
/* 1D50D */ { "MATHEMATICAL FRAKTUR CAPITAL J","	# <font> 004A latin capital letter j"},
/* 1D50E */ { "MATHEMATICAL FRAKTUR CAPITAL K","	# <font> 004B latin capital letter k"},
/* 1D50F */ { "MATHEMATICAL FRAKTUR CAPITAL L","	# <font> 004C latin capital letter l"},
/* 1D510 */ { "MATHEMATICAL FRAKTUR CAPITAL M","	= New Testament majority text\n"
	"	# <font> 004D latin capital letter m"},
/* 1D511 */ { "MATHEMATICAL FRAKTUR CAPITAL N","	# <font> 004E latin capital letter n"},
/* 1D512 */ { "MATHEMATICAL FRAKTUR CAPITAL O","	# <font> 004F latin capital letter o"},
/* 1D513 */ { "MATHEMATICAL FRAKTUR CAPITAL P","	# <font> 0050 latin capital letter p"},
/* 1D514 */ { "MATHEMATICAL FRAKTUR CAPITAL Q","	# <font> 0051 latin capital letter q"},
/* 1D515 */ { NULL,"	x (black-letter capital r - 211C)"},
/* 1D516 */ { "MATHEMATICAL FRAKTUR CAPITAL S","	= Septuagint, Greek Old Testament\n"
	"	# <font> 0053 latin capital letter s"},
/* 1D517 */ { "MATHEMATICAL FRAKTUR CAPITAL T","	# <font> 0054 latin capital letter t"},
/* 1D518 */ { "MATHEMATICAL FRAKTUR CAPITAL U","	# <font> 0055 latin capital letter u"},
/* 1D519 */ { "MATHEMATICAL FRAKTUR CAPITAL V","	# <font> 0056 latin capital letter v"},
/* 1D51A */ { "MATHEMATICAL FRAKTUR CAPITAL W","	# <font> 0057 latin capital letter w"},
/* 1D51B */ { "MATHEMATICAL FRAKTUR CAPITAL X","	# <font> 0058 latin capital letter x"},
/* 1D51C */ { "MATHEMATICAL FRAKTUR CAPITAL Y","	# <font> 0059 latin capital letter y"},
/* 1D51D */ { NULL,"	x (black-letter capital z - 2128)"},
/* 1D51E */ { "MATHEMATICAL FRAKTUR SMALL A","	# <font> 0061 latin small letter a"},
/* 1D51F */ { "MATHEMATICAL FRAKTUR SMALL B","	# <font> 0062 latin small letter b"},
/* 1D520 */ { "MATHEMATICAL FRAKTUR SMALL C","	# <font> 0063 latin small letter c"},
/* 1D521 */ { "MATHEMATICAL FRAKTUR SMALL D","	# <font> 0064 latin small letter d"},
/* 1D522 */ { "MATHEMATICAL FRAKTUR SMALL E","	# <font> 0065 latin small letter e"},
/* 1D523 */ { "MATHEMATICAL FRAKTUR SMALL F","	# <font> 0066 latin small letter f"},
/* 1D524 */ { "MATHEMATICAL FRAKTUR SMALL G","	# <font> 0067 latin small letter g"},
/* 1D525 */ { "MATHEMATICAL FRAKTUR SMALL H","	# <font> 0068 latin small letter h"},
/* 1D526 */ { "MATHEMATICAL FRAKTUR SMALL I","	# <font> 0069 latin small letter i"},
/* 1D527 */ { "MATHEMATICAL FRAKTUR SMALL J","	# <font> 006A latin small letter j"},
/* 1D528 */ { "MATHEMATICAL FRAKTUR SMALL K","	# <font> 006B latin small letter k"},
/* 1D529 */ { "MATHEMATICAL FRAKTUR SMALL L","	# <font> 006C latin small letter l"},
/* 1D52A */ { "MATHEMATICAL FRAKTUR SMALL M","	# <font> 006D latin small letter m"},
/* 1D52B */ { "MATHEMATICAL FRAKTUR SMALL N","	# <font> 006E latin small letter n"},
/* 1D52C */ { "MATHEMATICAL FRAKTUR SMALL O","	# <font> 006F latin small letter o"},
/* 1D52D */ { "MATHEMATICAL FRAKTUR SMALL P","	# <font> 0070 latin small letter p"},
/* 1D52E */ { "MATHEMATICAL FRAKTUR SMALL Q","	# <font> 0071 latin small letter q"},
/* 1D52F */ { "MATHEMATICAL FRAKTUR SMALL R","	# <font> 0072 latin small letter r"},
/* 1D530 */ { "MATHEMATICAL FRAKTUR SMALL S","	# <font> 0073 latin small letter s"},
/* 1D531 */ { "MATHEMATICAL FRAKTUR SMALL T","	# <font> 0074 latin small letter t"},
/* 1D532 */ { "MATHEMATICAL FRAKTUR SMALL U","	# <font> 0075 latin small letter u"},
/* 1D533 */ { "MATHEMATICAL FRAKTUR SMALL V","	# <font> 0076 latin small letter v"},
/* 1D534 */ { "MATHEMATICAL FRAKTUR SMALL W","	# <font> 0077 latin small letter w"},
/* 1D535 */ { "MATHEMATICAL FRAKTUR SMALL X","	# <font> 0078 latin small letter x"},
/* 1D536 */ { "MATHEMATICAL FRAKTUR SMALL Y","	# <font> 0079 latin small letter y"},
/* 1D537 */ { "MATHEMATICAL FRAKTUR SMALL Z","	# <font> 007A latin small letter z"},
/* 1D538 */ { "MATHEMATICAL DOUBLE-STRUCK CAPITAL A","	* a glyph variant with doubled stroke on the left exists\n"
	"	# <font> 0041 latin capital letter a"},
/* 1D539 */ { "MATHEMATICAL DOUBLE-STRUCK CAPITAL B","	# <font> 0042 latin capital letter b"},
/* 1D53A */ { NULL,"	x (double-struck capital c - 2102)"},
/* 1D53B */ { "MATHEMATICAL DOUBLE-STRUCK CAPITAL D","	# <font> 0044 latin capital letter d"},
/* 1D53C */ { "MATHEMATICAL DOUBLE-STRUCK CAPITAL E","	# <font> 0045 latin capital letter e"},
/* 1D53D */ { "MATHEMATICAL DOUBLE-STRUCK CAPITAL F","	# <font> 0046 latin capital letter f"},
/* 1D53E */ { "MATHEMATICAL DOUBLE-STRUCK CAPITAL G","	# <font> 0047 latin capital letter g"},
/* 1D53F */ { NULL,"	x (double-struck capital h - 210D)"},
/* 1D540 */ { "MATHEMATICAL DOUBLE-STRUCK CAPITAL I","	# <font> 0049 latin capital letter i"},
/* 1D541 */ { "MATHEMATICAL DOUBLE-STRUCK CAPITAL J","	# <font> 004A latin capital letter j"},
/* 1D542 */ { "MATHEMATICAL DOUBLE-STRUCK CAPITAL K","	# <font> 004B latin capital letter k"},
/* 1D543 */ { "MATHEMATICAL DOUBLE-STRUCK CAPITAL L","	# <font> 004C latin capital letter l"},
/* 1D544 */ { "MATHEMATICAL DOUBLE-STRUCK CAPITAL M","	# <font> 004D latin capital letter m"},
/* 1D545 */ { NULL,"	x (double-struck capital n - 2115)"},
/* 1D546 */ { "MATHEMATICAL DOUBLE-STRUCK CAPITAL O","	# <font> 004F latin capital letter o"},
/* 1D547 */ { NULL,"	x (double-struck capital p - 2119)"},
/* 1D548 */ { NULL,"	x (double-struck capital q - 211A)"},
/* 1D549 */ { NULL,"	x (double-struck capital r - 211D)"},
/* 1D54A */ { "MATHEMATICAL DOUBLE-STRUCK CAPITAL S","	# <font> 0053 latin capital letter s"},
/* 1D54B */ { "MATHEMATICAL DOUBLE-STRUCK CAPITAL T","	# <font> 0054 latin capital letter t"},
/* 1D54C */ { "MATHEMATICAL DOUBLE-STRUCK CAPITAL U","	# <font> 0055 latin capital letter u"},
/* 1D54D */ { "MATHEMATICAL DOUBLE-STRUCK CAPITAL V","	# <font> 0056 latin capital letter v"},
/* 1D54E */ { "MATHEMATICAL DOUBLE-STRUCK CAPITAL W","	# <font> 0057 latin capital letter w"},
/* 1D54F */ { "MATHEMATICAL DOUBLE-STRUCK CAPITAL X","	# <font> 0058 latin capital letter x"},
/* 1D550 */ { "MATHEMATICAL DOUBLE-STRUCK CAPITAL Y","	# <font> 0059 latin capital letter y"},
/* 1D551 */ { NULL,"	x (double-struck capital z - 2124)"},
/* 1D552 */ { "MATHEMATICAL DOUBLE-STRUCK SMALL A","	# <font> 0061 latin small letter a"},
/* 1D553 */ { "MATHEMATICAL DOUBLE-STRUCK SMALL B","	# <font> 0062 latin small letter b"},
/* 1D554 */ { "MATHEMATICAL DOUBLE-STRUCK SMALL C","	# <font> 0063 latin small letter c"},
/* 1D555 */ { "MATHEMATICAL DOUBLE-STRUCK SMALL D","	# <font> 0064 latin small letter d"},
/* 1D556 */ { "MATHEMATICAL DOUBLE-STRUCK SMALL E","	# <font> 0065 latin small letter e"},
/* 1D557 */ { "MATHEMATICAL DOUBLE-STRUCK SMALL F","	# <font> 0066 latin small letter f"},
/* 1D558 */ { "MATHEMATICAL DOUBLE-STRUCK SMALL G","	# <font> 0067 latin small letter g"},
/* 1D559 */ { "MATHEMATICAL DOUBLE-STRUCK SMALL H","	# <font> 0068 latin small letter h"},
/* 1D55A */ { "MATHEMATICAL DOUBLE-STRUCK SMALL I","	# <font> 0069 latin small letter i"},
/* 1D55B */ { "MATHEMATICAL DOUBLE-STRUCK SMALL J","	# <font> 006A latin small letter j"},
/* 1D55C */ { "MATHEMATICAL DOUBLE-STRUCK SMALL K","	# <font> 006B latin small letter k"},
/* 1D55D */ { "MATHEMATICAL DOUBLE-STRUCK SMALL L","	# <font> 006C latin small letter l"},
/* 1D55E */ { "MATHEMATICAL DOUBLE-STRUCK SMALL M","	# <font> 006D latin small letter m"},
/* 1D55F */ { "MATHEMATICAL DOUBLE-STRUCK SMALL N","	# <font> 006E latin small letter n"},
/* 1D560 */ { "MATHEMATICAL DOUBLE-STRUCK SMALL O","	# <font> 006F latin small letter o"},
/* 1D561 */ { "MATHEMATICAL DOUBLE-STRUCK SMALL P","	# <font> 0070 latin small letter p"},
/* 1D562 */ { "MATHEMATICAL DOUBLE-STRUCK SMALL Q","	# <font> 0071 latin small letter q"},
/* 1D563 */ { "MATHEMATICAL DOUBLE-STRUCK SMALL R","	# <font> 0072 latin small letter r"},
/* 1D564 */ { "MATHEMATICAL DOUBLE-STRUCK SMALL S","	# <font> 0073 latin small letter s"},
/* 1D565 */ { "MATHEMATICAL DOUBLE-STRUCK SMALL T","	# <font> 0074 latin small letter t"},
/* 1D566 */ { "MATHEMATICAL DOUBLE-STRUCK SMALL U","	# <font> 0075 latin small letter u"},
/* 1D567 */ { "MATHEMATICAL DOUBLE-STRUCK SMALL V","	# <font> 0076 latin small letter v"},
/* 1D568 */ { "MATHEMATICAL DOUBLE-STRUCK SMALL W","	# <font> 0077 latin small letter w"},
/* 1D569 */ { "MATHEMATICAL DOUBLE-STRUCK SMALL X","	# <font> 0078 latin small letter x"},
/* 1D56A */ { "MATHEMATICAL DOUBLE-STRUCK SMALL Y","	# <font> 0079 latin small letter y"},
/* 1D56B */ { "MATHEMATICAL DOUBLE-STRUCK SMALL Z","	# <font> 007A latin small letter z"},
/* 1D56C */ { "MATHEMATICAL BOLD FRAKTUR CAPITAL A","	# <font> 0041 latin capital letter a"},
/* 1D56D */ { "MATHEMATICAL BOLD FRAKTUR CAPITAL B","	# <font> 0042 latin capital letter b"},
/* 1D56E */ { "MATHEMATICAL BOLD FRAKTUR CAPITAL C","	# <font> 0043 latin capital letter c"},
/* 1D56F */ { "MATHEMATICAL BOLD FRAKTUR CAPITAL D","	# <font> 0044 latin capital letter d"},
/* 1D570 */ { "MATHEMATICAL BOLD FRAKTUR CAPITAL E","	# <font> 0045 latin capital letter e"},
/* 1D571 */ { "MATHEMATICAL BOLD FRAKTUR CAPITAL F","	# <font> 0046 latin capital letter f"},
/* 1D572 */ { "MATHEMATICAL BOLD FRAKTUR CAPITAL G","	# <font> 0047 latin capital letter g"},
/* 1D573 */ { "MATHEMATICAL BOLD FRAKTUR CAPITAL H","	# <font> 0048 latin capital letter h"},
/* 1D574 */ { "MATHEMATICAL BOLD FRAKTUR CAPITAL I","	# <font> 0049 latin capital letter i"},
/* 1D575 */ { "MATHEMATICAL BOLD FRAKTUR CAPITAL J","	# <font> 004A latin capital letter j"},
/* 1D576 */ { "MATHEMATICAL BOLD FRAKTUR CAPITAL K","	# <font> 004B latin capital letter k"},
/* 1D577 */ { "MATHEMATICAL BOLD FRAKTUR CAPITAL L","	# <font> 004C latin capital letter l"},
/* 1D578 */ { "MATHEMATICAL BOLD FRAKTUR CAPITAL M","	# <font> 004D latin capital letter m"},
/* 1D579 */ { "MATHEMATICAL BOLD FRAKTUR CAPITAL N","	# <font> 004E latin capital letter n"},
/* 1D57A */ { "MATHEMATICAL BOLD FRAKTUR CAPITAL O","	# <font> 004F latin capital letter o"},
/* 1D57B */ { "MATHEMATICAL BOLD FRAKTUR CAPITAL P","	# <font> 0050 latin capital letter p"},
/* 1D57C */ { "MATHEMATICAL BOLD FRAKTUR CAPITAL Q","	# <font> 0051 latin capital letter q"},
/* 1D57D */ { "MATHEMATICAL BOLD FRAKTUR CAPITAL R","	# <font> 0052 latin capital letter r"},
/* 1D57E */ { "MATHEMATICAL BOLD FRAKTUR CAPITAL S","	# <font> 0053 latin capital letter s"},
/* 1D57F */ { "MATHEMATICAL BOLD FRAKTUR CAPITAL T","	# <font> 0054 latin capital letter t"},
/* 1D580 */ { "MATHEMATICAL BOLD FRAKTUR CAPITAL U","	# <font> 0055 latin capital letter u"},
/* 1D581 */ { "MATHEMATICAL BOLD FRAKTUR CAPITAL V","	# <font> 0056 latin capital letter v"},
/* 1D582 */ { "MATHEMATICAL BOLD FRAKTUR CAPITAL W","	# <font> 0057 latin capital letter w"},
/* 1D583 */ { "MATHEMATICAL BOLD FRAKTUR CAPITAL X","	# <font> 0058 latin capital letter x"},
/* 1D584 */ { "MATHEMATICAL BOLD FRAKTUR CAPITAL Y","	# <font> 0059 latin capital letter y"},
/* 1D585 */ { "MATHEMATICAL BOLD FRAKTUR CAPITAL Z","	# <font> 005A latin capital letter z"},
/* 1D586 */ { "MATHEMATICAL BOLD FRAKTUR SMALL A","	# <font> 0061 latin small letter a"},
/* 1D587 */ { "MATHEMATICAL BOLD FRAKTUR SMALL B","	# <font> 0062 latin small letter b"},
/* 1D588 */ { "MATHEMATICAL BOLD FRAKTUR SMALL C","	# <font> 0063 latin small letter c"},
/* 1D589 */ { "MATHEMATICAL BOLD FRAKTUR SMALL D","	# <font> 0064 latin small letter d"},
/* 1D58A */ { "MATHEMATICAL BOLD FRAKTUR SMALL E","	# <font> 0065 latin small letter e"},
/* 1D58B */ { "MATHEMATICAL BOLD FRAKTUR SMALL F","	# <font> 0066 latin small letter f"},
/* 1D58C */ { "MATHEMATICAL BOLD FRAKTUR SMALL G","	# <font> 0067 latin small letter g"},
/* 1D58D */ { "MATHEMATICAL BOLD FRAKTUR SMALL H","	# <font> 0068 latin small letter h"},
/* 1D58E */ { "MATHEMATICAL BOLD FRAKTUR SMALL I","	# <font> 0069 latin small letter i"},
/* 1D58F */ { "MATHEMATICAL BOLD FRAKTUR SMALL J","	# <font> 006A latin small letter j"},
/* 1D590 */ { "MATHEMATICAL BOLD FRAKTUR SMALL K","	# <font> 006B latin small letter k"},
/* 1D591 */ { "MATHEMATICAL BOLD FRAKTUR SMALL L","	# <font> 006C latin small letter l"},
/* 1D592 */ { "MATHEMATICAL BOLD FRAKTUR SMALL M","	# <font> 006D latin small letter m"},
/* 1D593 */ { "MATHEMATICAL BOLD FRAKTUR SMALL N","	# <font> 006E latin small letter n"},
/* 1D594 */ { "MATHEMATICAL BOLD FRAKTUR SMALL O","	# <font> 006F latin small letter o"},
/* 1D595 */ { "MATHEMATICAL BOLD FRAKTUR SMALL P","	# <font> 0070 latin small letter p"},
/* 1D596 */ { "MATHEMATICAL BOLD FRAKTUR SMALL Q","	# <font> 0071 latin small letter q"},
/* 1D597 */ { "MATHEMATICAL BOLD FRAKTUR SMALL R","	# <font> 0072 latin small letter r"},
/* 1D598 */ { "MATHEMATICAL BOLD FRAKTUR SMALL S","	# <font> 0073 latin small letter s"},
/* 1D599 */ { "MATHEMATICAL BOLD FRAKTUR SMALL T","	# <font> 0074 latin small letter t"},
/* 1D59A */ { "MATHEMATICAL BOLD FRAKTUR SMALL U","	# <font> 0075 latin small letter u"},
/* 1D59B */ { "MATHEMATICAL BOLD FRAKTUR SMALL V","	# <font> 0076 latin small letter v"},
/* 1D59C */ { "MATHEMATICAL BOLD FRAKTUR SMALL W","	# <font> 0077 latin small letter w"},
/* 1D59D */ { "MATHEMATICAL BOLD FRAKTUR SMALL X","	# <font> 0078 latin small letter x"},
/* 1D59E */ { "MATHEMATICAL BOLD FRAKTUR SMALL Y","	# <font> 0079 latin small letter y"},
/* 1D59F */ { "MATHEMATICAL BOLD FRAKTUR SMALL Z","	# <font> 007A latin small letter z"},
/* 1D5A0 */ { "MATHEMATICAL SANS-SERIF CAPITAL A","	# <font> 0041 latin capital letter a"},
/* 1D5A1 */ { "MATHEMATICAL SANS-SERIF CAPITAL B","	# <font> 0042 latin capital letter b"},
/* 1D5A2 */ { "MATHEMATICAL SANS-SERIF CAPITAL C","	# <font> 0043 latin capital letter c"},
/* 1D5A3 */ { "MATHEMATICAL SANS-SERIF CAPITAL D","	# <font> 0044 latin capital letter d"},
/* 1D5A4 */ { "MATHEMATICAL SANS-SERIF CAPITAL E","	# <font> 0045 latin capital letter e"},
/* 1D5A5 */ { "MATHEMATICAL SANS-SERIF CAPITAL F","	# <font> 0046 latin capital letter f"},
/* 1D5A6 */ { "MATHEMATICAL SANS-SERIF CAPITAL G","	# <font> 0047 latin capital letter g"},
/* 1D5A7 */ { "MATHEMATICAL SANS-SERIF CAPITAL H","	# <font> 0048 latin capital letter h"},
/* 1D5A8 */ { "MATHEMATICAL SANS-SERIF CAPITAL I","	# <font> 0049 latin capital letter i"},
/* 1D5A9 */ { "MATHEMATICAL SANS-SERIF CAPITAL J","	# <font> 004A latin capital letter j"},
/* 1D5AA */ { "MATHEMATICAL SANS-SERIF CAPITAL K","	# <font> 004B latin capital letter k"},
/* 1D5AB */ { "MATHEMATICAL SANS-SERIF CAPITAL L","	# <font> 004C latin capital letter l"},
/* 1D5AC */ { "MATHEMATICAL SANS-SERIF CAPITAL M","	# <font> 004D latin capital letter m"},
/* 1D5AD */ { "MATHEMATICAL SANS-SERIF CAPITAL N","	# <font> 004E latin capital letter n"},
/* 1D5AE */ { "MATHEMATICAL SANS-SERIF CAPITAL O","	# <font> 004F latin capital letter o"},
/* 1D5AF */ { "MATHEMATICAL SANS-SERIF CAPITAL P","	# <font> 0050 latin capital letter p"},
/* 1D5B0 */ { "MATHEMATICAL SANS-SERIF CAPITAL Q","	# <font> 0051 latin capital letter q"},
/* 1D5B1 */ { "MATHEMATICAL SANS-SERIF CAPITAL R","	# <font> 0052 latin capital letter r"},
/* 1D5B2 */ { "MATHEMATICAL SANS-SERIF CAPITAL S","	# <font> 0053 latin capital letter s"},
/* 1D5B3 */ { "MATHEMATICAL SANS-SERIF CAPITAL T","	# <font> 0054 latin capital letter t"},
/* 1D5B4 */ { "MATHEMATICAL SANS-SERIF CAPITAL U","	# <font> 0055 latin capital letter u"},
/* 1D5B5 */ { "MATHEMATICAL SANS-SERIF CAPITAL V","	# <font> 0056 latin capital letter v"},
/* 1D5B6 */ { "MATHEMATICAL SANS-SERIF CAPITAL W","	# <font> 0057 latin capital letter w"},
/* 1D5B7 */ { "MATHEMATICAL SANS-SERIF CAPITAL X","	# <font> 0058 latin capital letter x"},
/* 1D5B8 */ { "MATHEMATICAL SANS-SERIF CAPITAL Y","	# <font> 0059 latin capital letter y"},
/* 1D5B9 */ { "MATHEMATICAL SANS-SERIF CAPITAL Z","	# <font> 005A latin capital letter z"},
/* 1D5BA */ { "MATHEMATICAL SANS-SERIF SMALL A","	# <font> 0061 latin small letter a"},
/* 1D5BB */ { "MATHEMATICAL SANS-SERIF SMALL B","	# <font> 0062 latin small letter b"},
/* 1D5BC */ { "MATHEMATICAL SANS-SERIF SMALL C","	# <font> 0063 latin small letter c"},
/* 1D5BD */ { "MATHEMATICAL SANS-SERIF SMALL D","	# <font> 0064 latin small letter d"},
/* 1D5BE */ { "MATHEMATICAL SANS-SERIF SMALL E","	# <font> 0065 latin small letter e"},
/* 1D5BF */ { "MATHEMATICAL SANS-SERIF SMALL F","	# <font> 0066 latin small letter f"},
/* 1D5C0 */ { "MATHEMATICAL SANS-SERIF SMALL G","	# <font> 0067 latin small letter g"},
/* 1D5C1 */ { "MATHEMATICAL SANS-SERIF SMALL H","	# <font> 0068 latin small letter h"},
/* 1D5C2 */ { "MATHEMATICAL SANS-SERIF SMALL I","	# <font> 0069 latin small letter i"},
/* 1D5C3 */ { "MATHEMATICAL SANS-SERIF SMALL J","	# <font> 006A latin small letter j"},
/* 1D5C4 */ { "MATHEMATICAL SANS-SERIF SMALL K","	# <font> 006B latin small letter k"},
/* 1D5C5 */ { "MATHEMATICAL SANS-SERIF SMALL L","	# <font> 006C latin small letter l"},
/* 1D5C6 */ { "MATHEMATICAL SANS-SERIF SMALL M","	# <font> 006D latin small letter m"},
/* 1D5C7 */ { "MATHEMATICAL SANS-SERIF SMALL N","	# <font> 006E latin small letter n"},
/* 1D5C8 */ { "MATHEMATICAL SANS-SERIF SMALL O","	# <font> 006F latin small letter o"},
/* 1D5C9 */ { "MATHEMATICAL SANS-SERIF SMALL P","	# <font> 0070 latin small letter p"},
/* 1D5CA */ { "MATHEMATICAL SANS-SERIF SMALL Q","	# <font> 0071 latin small letter q"},
/* 1D5CB */ { "MATHEMATICAL SANS-SERIF SMALL R","	# <font> 0072 latin small letter r"},
/* 1D5CC */ { "MATHEMATICAL SANS-SERIF SMALL S","	# <font> 0073 latin small letter s"},
/* 1D5CD */ { "MATHEMATICAL SANS-SERIF SMALL T","	# <font> 0074 latin small letter t"},
/* 1D5CE */ { "MATHEMATICAL SANS-SERIF SMALL U","	# <font> 0075 latin small letter u"},
/* 1D5CF */ { "MATHEMATICAL SANS-SERIF SMALL V","	# <font> 0076 latin small letter v"},
/* 1D5D0 */ { "MATHEMATICAL SANS-SERIF SMALL W","	# <font> 0077 latin small letter w"},
/* 1D5D1 */ { "MATHEMATICAL SANS-SERIF SMALL X","	# <font> 0078 latin small letter x"},
/* 1D5D2 */ { "MATHEMATICAL SANS-SERIF SMALL Y","	# <font> 0079 latin small letter y"},
/* 1D5D3 */ { "MATHEMATICAL SANS-SERIF SMALL Z","	# <font> 007A latin small letter z"},
/* 1D5D4 */ { "MATHEMATICAL SANS-SERIF BOLD CAPITAL A","	# <font> 0041 latin capital letter a"},
/* 1D5D5 */ { "MATHEMATICAL SANS-SERIF BOLD CAPITAL B","	# <font> 0042 latin capital letter b"},
/* 1D5D6 */ { "MATHEMATICAL SANS-SERIF BOLD CAPITAL C","	# <font> 0043 latin capital letter c"},
/* 1D5D7 */ { "MATHEMATICAL SANS-SERIF BOLD CAPITAL D","	# <font> 0044 latin capital letter d"},
/* 1D5D8 */ { "MATHEMATICAL SANS-SERIF BOLD CAPITAL E","	# <font> 0045 latin capital letter e"},
/* 1D5D9 */ { "MATHEMATICAL SANS-SERIF BOLD CAPITAL F","	# <font> 0046 latin capital letter f"},
/* 1D5DA */ { "MATHEMATICAL SANS-SERIF BOLD CAPITAL G","	# <font> 0047 latin capital letter g"},
/* 1D5DB */ { "MATHEMATICAL SANS-SERIF BOLD CAPITAL H","	# <font> 0048 latin capital letter h"},
/* 1D5DC */ { "MATHEMATICAL SANS-SERIF BOLD CAPITAL I","	# <font> 0049 latin capital letter i"},
/* 1D5DD */ { "MATHEMATICAL SANS-SERIF BOLD CAPITAL J","	# <font> 004A latin capital letter j"},
/* 1D5DE */ { "MATHEMATICAL SANS-SERIF BOLD CAPITAL K","	# <font> 004B latin capital letter k"},
/* 1D5DF */ { "MATHEMATICAL SANS-SERIF BOLD CAPITAL L","	# <font> 004C latin capital letter l"},
/* 1D5E0 */ { "MATHEMATICAL SANS-SERIF BOLD CAPITAL M","	# <font> 004D latin capital letter m"},
/* 1D5E1 */ { "MATHEMATICAL SANS-SERIF BOLD CAPITAL N","	# <font> 004E latin capital letter n"},
/* 1D5E2 */ { "MATHEMATICAL SANS-SERIF BOLD CAPITAL O","	# <font> 004F latin capital letter o"},
/* 1D5E3 */ { "MATHEMATICAL SANS-SERIF BOLD CAPITAL P","	# <font> 0050 latin capital letter p"},
/* 1D5E4 */ { "MATHEMATICAL SANS-SERIF BOLD CAPITAL Q","	# <font> 0051 latin capital letter q"},
/* 1D5E5 */ { "MATHEMATICAL SANS-SERIF BOLD CAPITAL R","	# <font> 0052 latin capital letter r"},
/* 1D5E6 */ { "MATHEMATICAL SANS-SERIF BOLD CAPITAL S","	# <font> 0053 latin capital letter s"},
/* 1D5E7 */ { "MATHEMATICAL SANS-SERIF BOLD CAPITAL T","	# <font> 0054 latin capital letter t"},
/* 1D5E8 */ { "MATHEMATICAL SANS-SERIF BOLD CAPITAL U","	# <font> 0055 latin capital letter u"},
/* 1D5E9 */ { "MATHEMATICAL SANS-SERIF BOLD CAPITAL V","	# <font> 0056 latin capital letter v"},
/* 1D5EA */ { "MATHEMATICAL SANS-SERIF BOLD CAPITAL W","	# <font> 0057 latin capital letter w"},
/* 1D5EB */ { "MATHEMATICAL SANS-SERIF BOLD CAPITAL X","	# <font> 0058 latin capital letter x"},
/* 1D5EC */ { "MATHEMATICAL SANS-SERIF BOLD CAPITAL Y","	# <font> 0059 latin capital letter y"},
/* 1D5ED */ { "MATHEMATICAL SANS-SERIF BOLD CAPITAL Z","	# <font> 005A latin capital letter z"},
/* 1D5EE */ { "MATHEMATICAL SANS-SERIF BOLD SMALL A","	# <font> 0061 latin small letter a"},
/* 1D5EF */ { "MATHEMATICAL SANS-SERIF BOLD SMALL B","	# <font> 0062 latin small letter b"},
/* 1D5F0 */ { "MATHEMATICAL SANS-SERIF BOLD SMALL C","	# <font> 0063 latin small letter c"},
/* 1D5F1 */ { "MATHEMATICAL SANS-SERIF BOLD SMALL D","	# <font> 0064 latin small letter d"},
/* 1D5F2 */ { "MATHEMATICAL SANS-SERIF BOLD SMALL E","	# <font> 0065 latin small letter e"},
/* 1D5F3 */ { "MATHEMATICAL SANS-SERIF BOLD SMALL F","	# <font> 0066 latin small letter f"},
/* 1D5F4 */ { "MATHEMATICAL SANS-SERIF BOLD SMALL G","	# <font> 0067 latin small letter g"},
/* 1D5F5 */ { "MATHEMATICAL SANS-SERIF BOLD SMALL H","	# <font> 0068 latin small letter h"},
/* 1D5F6 */ { "MATHEMATICAL SANS-SERIF BOLD SMALL I","	# <font> 0069 latin small letter i"},
/* 1D5F7 */ { "MATHEMATICAL SANS-SERIF BOLD SMALL J","	# <font> 006A latin small letter j"},
/* 1D5F8 */ { "MATHEMATICAL SANS-SERIF BOLD SMALL K","	# <font> 006B latin small letter k"},
/* 1D5F9 */ { "MATHEMATICAL SANS-SERIF BOLD SMALL L","	# <font> 006C latin small letter l"},
/* 1D5FA */ { "MATHEMATICAL SANS-SERIF BOLD SMALL M","	# <font> 006D latin small letter m"},
/* 1D5FB */ { "MATHEMATICAL SANS-SERIF BOLD SMALL N","	# <font> 006E latin small letter n"},
/* 1D5FC */ { "MATHEMATICAL SANS-SERIF BOLD SMALL O","	# <font> 006F latin small letter o"},
/* 1D5FD */ { "MATHEMATICAL SANS-SERIF BOLD SMALL P","	# <font> 0070 latin small letter p"},
/* 1D5FE */ { "MATHEMATICAL SANS-SERIF BOLD SMALL Q","	# <font> 0071 latin small letter q"},
/* 1D5FF */ { "MATHEMATICAL SANS-SERIF BOLD SMALL R","	# <font> 0072 latin small letter r"}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_D6[] = {
/* 1D600 */ { "MATHEMATICAL SANS-SERIF BOLD SMALL S","	# <font> 0073 latin small letter s"},
/* 1D601 */ { "MATHEMATICAL SANS-SERIF BOLD SMALL T","	# <font> 0074 latin small letter t"},
/* 1D602 */ { "MATHEMATICAL SANS-SERIF BOLD SMALL U","	# <font> 0075 latin small letter u"},
/* 1D603 */ { "MATHEMATICAL SANS-SERIF BOLD SMALL V","	# <font> 0076 latin small letter v"},
/* 1D604 */ { "MATHEMATICAL SANS-SERIF BOLD SMALL W","	# <font> 0077 latin small letter w"},
/* 1D605 */ { "MATHEMATICAL SANS-SERIF BOLD SMALL X","	# <font> 0078 latin small letter x"},
/* 1D606 */ { "MATHEMATICAL SANS-SERIF BOLD SMALL Y","	# <font> 0079 latin small letter y"},
/* 1D607 */ { "MATHEMATICAL SANS-SERIF BOLD SMALL Z","	# <font> 007A latin small letter z"},
/* 1D608 */ { "MATHEMATICAL SANS-SERIF ITALIC CAPITAL A","	# <font> 0041 latin capital letter a"},
/* 1D609 */ { "MATHEMATICAL SANS-SERIF ITALIC CAPITAL B","	# <font> 0042 latin capital letter b"},
/* 1D60A */ { "MATHEMATICAL SANS-SERIF ITALIC CAPITAL C","	# <font> 0043 latin capital letter c"},
/* 1D60B */ { "MATHEMATICAL SANS-SERIF ITALIC CAPITAL D","	# <font> 0044 latin capital letter d"},
/* 1D60C */ { "MATHEMATICAL SANS-SERIF ITALIC CAPITAL E","	# <font> 0045 latin capital letter e"},
/* 1D60D */ { "MATHEMATICAL SANS-SERIF ITALIC CAPITAL F","	# <font> 0046 latin capital letter f"},
/* 1D60E */ { "MATHEMATICAL SANS-SERIF ITALIC CAPITAL G","	# <font> 0047 latin capital letter g"},
/* 1D60F */ { "MATHEMATICAL SANS-SERIF ITALIC CAPITAL H","	# <font> 0048 latin capital letter h"},
/* 1D610 */ { "MATHEMATICAL SANS-SERIF ITALIC CAPITAL I","	# <font> 0049 latin capital letter i"},
/* 1D611 */ { "MATHEMATICAL SANS-SERIF ITALIC CAPITAL J","	# <font> 004A latin capital letter j"},
/* 1D612 */ { "MATHEMATICAL SANS-SERIF ITALIC CAPITAL K","	# <font> 004B latin capital letter k"},
/* 1D613 */ { "MATHEMATICAL SANS-SERIF ITALIC CAPITAL L","	# <font> 004C latin capital letter l"},
/* 1D614 */ { "MATHEMATICAL SANS-SERIF ITALIC CAPITAL M","	# <font> 004D latin capital letter m"},
/* 1D615 */ { "MATHEMATICAL SANS-SERIF ITALIC CAPITAL N","	# <font> 004E latin capital letter n"},
/* 1D616 */ { "MATHEMATICAL SANS-SERIF ITALIC CAPITAL O","	# <font> 004F latin capital letter o"},
/* 1D617 */ { "MATHEMATICAL SANS-SERIF ITALIC CAPITAL P","	# <font> 0050 latin capital letter p"},
/* 1D618 */ { "MATHEMATICAL SANS-SERIF ITALIC CAPITAL Q","	# <font> 0051 latin capital letter q"},
/* 1D619 */ { "MATHEMATICAL SANS-SERIF ITALIC CAPITAL R","	# <font> 0052 latin capital letter r"},
/* 1D61A */ { "MATHEMATICAL SANS-SERIF ITALIC CAPITAL S","	# <font> 0053 latin capital letter s"},
/* 1D61B */ { "MATHEMATICAL SANS-SERIF ITALIC CAPITAL T","	# <font> 0054 latin capital letter t"},
/* 1D61C */ { "MATHEMATICAL SANS-SERIF ITALIC CAPITAL U","	# <font> 0055 latin capital letter u"},
/* 1D61D */ { "MATHEMATICAL SANS-SERIF ITALIC CAPITAL V","	# <font> 0056 latin capital letter v"},
/* 1D61E */ { "MATHEMATICAL SANS-SERIF ITALIC CAPITAL W","	# <font> 0057 latin capital letter w"},
/* 1D61F */ { "MATHEMATICAL SANS-SERIF ITALIC CAPITAL X","	# <font> 0058 latin capital letter x"},
/* 1D620 */ { "MATHEMATICAL SANS-SERIF ITALIC CAPITAL Y","	# <font> 0059 latin capital letter y"},
/* 1D621 */ { "MATHEMATICAL SANS-SERIF ITALIC CAPITAL Z","	# <font> 005A latin capital letter z"},
/* 1D622 */ { "MATHEMATICAL SANS-SERIF ITALIC SMALL A","	# <font> 0061 latin small letter a"},
/* 1D623 */ { "MATHEMATICAL SANS-SERIF ITALIC SMALL B","	# <font> 0062 latin small letter b"},
/* 1D624 */ { "MATHEMATICAL SANS-SERIF ITALIC SMALL C","	# <font> 0063 latin small letter c"},
/* 1D625 */ { "MATHEMATICAL SANS-SERIF ITALIC SMALL D","	# <font> 0064 latin small letter d"},
/* 1D626 */ { "MATHEMATICAL SANS-SERIF ITALIC SMALL E","	# <font> 0065 latin small letter e"},
/* 1D627 */ { "MATHEMATICAL SANS-SERIF ITALIC SMALL F","	# <font> 0066 latin small letter f"},
/* 1D628 */ { "MATHEMATICAL SANS-SERIF ITALIC SMALL G","	# <font> 0067 latin small letter g"},
/* 1D629 */ { "MATHEMATICAL SANS-SERIF ITALIC SMALL H","	# <font> 0068 latin small letter h"},
/* 1D62A */ { "MATHEMATICAL SANS-SERIF ITALIC SMALL I","	# <font> 0069 latin small letter i"},
/* 1D62B */ { "MATHEMATICAL SANS-SERIF ITALIC SMALL J","	# <font> 006A latin small letter j"},
/* 1D62C */ { "MATHEMATICAL SANS-SERIF ITALIC SMALL K","	# <font> 006B latin small letter k"},
/* 1D62D */ { "MATHEMATICAL SANS-SERIF ITALIC SMALL L","	# <font> 006C latin small letter l"},
/* 1D62E */ { "MATHEMATICAL SANS-SERIF ITALIC SMALL M","	# <font> 006D latin small letter m"},
/* 1D62F */ { "MATHEMATICAL SANS-SERIF ITALIC SMALL N","	# <font> 006E latin small letter n"},
/* 1D630 */ { "MATHEMATICAL SANS-SERIF ITALIC SMALL O","	# <font> 006F latin small letter o"},
/* 1D631 */ { "MATHEMATICAL SANS-SERIF ITALIC SMALL P","	# <font> 0070 latin small letter p"},
/* 1D632 */ { "MATHEMATICAL SANS-SERIF ITALIC SMALL Q","	# <font> 0071 latin small letter q"},
/* 1D633 */ { "MATHEMATICAL SANS-SERIF ITALIC SMALL R","	# <font> 0072 latin small letter r"},
/* 1D634 */ { "MATHEMATICAL SANS-SERIF ITALIC SMALL S","	# <font> 0073 latin small letter s"},
/* 1D635 */ { "MATHEMATICAL SANS-SERIF ITALIC SMALL T","	# <font> 0074 latin small letter t"},
/* 1D636 */ { "MATHEMATICAL SANS-SERIF ITALIC SMALL U","	# <font> 0075 latin small letter u"},
/* 1D637 */ { "MATHEMATICAL SANS-SERIF ITALIC SMALL V","	# <font> 0076 latin small letter v"},
/* 1D638 */ { "MATHEMATICAL SANS-SERIF ITALIC SMALL W","	# <font> 0077 latin small letter w"},
/* 1D639 */ { "MATHEMATICAL SANS-SERIF ITALIC SMALL X","	# <font> 0078 latin small letter x"},
/* 1D63A */ { "MATHEMATICAL SANS-SERIF ITALIC SMALL Y","	# <font> 0079 latin small letter y"},
/* 1D63B */ { "MATHEMATICAL SANS-SERIF ITALIC SMALL Z","	# <font> 007A latin small letter z"},
/* 1D63C */ { "MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL A","	# <font> 0041 latin capital letter a"},
/* 1D63D */ { "MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL B","	# <font> 0042 latin capital letter b"},
/* 1D63E */ { "MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL C","	# <font> 0043 latin capital letter c"},
/* 1D63F */ { "MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL D","	# <font> 0044 latin capital letter d"},
/* 1D640 */ { "MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL E","	# <font> 0045 latin capital letter e"},
/* 1D641 */ { "MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL F","	# <font> 0046 latin capital letter f"},
/* 1D642 */ { "MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL G","	# <font> 0047 latin capital letter g"},
/* 1D643 */ { "MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL H","	# <font> 0048 latin capital letter h"},
/* 1D644 */ { "MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL I","	# <font> 0049 latin capital letter i"},
/* 1D645 */ { "MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL J","	# <font> 004A latin capital letter j"},
/* 1D646 */ { "MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL K","	# <font> 004B latin capital letter k"},
/* 1D647 */ { "MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL L","	# <font> 004C latin capital letter l"},
/* 1D648 */ { "MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL M","	# <font> 004D latin capital letter m"},
/* 1D649 */ { "MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL N","	# <font> 004E latin capital letter n"},
/* 1D64A */ { "MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL O","	# <font> 004F latin capital letter o"},
/* 1D64B */ { "MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL P","	# <font> 0050 latin capital letter p"},
/* 1D64C */ { "MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL Q","	# <font> 0051 latin capital letter q"},
/* 1D64D */ { "MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL R","	# <font> 0052 latin capital letter r"},
/* 1D64E */ { "MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL S","	# <font> 0053 latin capital letter s"},
/* 1D64F */ { "MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL T","	# <font> 0054 latin capital letter t"},
/* 1D650 */ { "MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL U","	# <font> 0055 latin capital letter u"},
/* 1D651 */ { "MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL V","	# <font> 0056 latin capital letter v"},
/* 1D652 */ { "MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL W","	# <font> 0057 latin capital letter w"},
/* 1D653 */ { "MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL X","	# <font> 0058 latin capital letter x"},
/* 1D654 */ { "MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL Y","	# <font> 0059 latin capital letter y"},
/* 1D655 */ { "MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL Z","	# <font> 005A latin capital letter z"},
/* 1D656 */ { "MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL A","	# <font> 0061 latin small letter a"},
/* 1D657 */ { "MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL B","	# <font> 0062 latin small letter b"},
/* 1D658 */ { "MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL C","	# <font> 0063 latin small letter c"},
/* 1D659 */ { "MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL D","	# <font> 0064 latin small letter d"},
/* 1D65A */ { "MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL E","	# <font> 0065 latin small letter e"},
/* 1D65B */ { "MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL F","	# <font> 0066 latin small letter f"},
/* 1D65C */ { "MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL G","	# <font> 0067 latin small letter g"},
/* 1D65D */ { "MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL H","	# <font> 0068 latin small letter h"},
/* 1D65E */ { "MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL I","	# <font> 0069 latin small letter i"},
/* 1D65F */ { "MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL J","	# <font> 006A latin small letter j"},
/* 1D660 */ { "MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL K","	# <font> 006B latin small letter k"},
/* 1D661 */ { "MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL L","	# <font> 006C latin small letter l"},
/* 1D662 */ { "MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL M","	# <font> 006D latin small letter m"},
/* 1D663 */ { "MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL N","	# <font> 006E latin small letter n"},
/* 1D664 */ { "MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL O","	# <font> 006F latin small letter o"},
/* 1D665 */ { "MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL P","	# <font> 0070 latin small letter p"},
/* 1D666 */ { "MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL Q","	# <font> 0071 latin small letter q"},
/* 1D667 */ { "MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL R","	# <font> 0072 latin small letter r"},
/* 1D668 */ { "MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL S","	# <font> 0073 latin small letter s"},
/* 1D669 */ { "MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL T","	# <font> 0074 latin small letter t"},
/* 1D66A */ { "MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL U","	# <font> 0075 latin small letter u"},
/* 1D66B */ { "MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL V","	# <font> 0076 latin small letter v"},
/* 1D66C */ { "MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL W","	# <font> 0077 latin small letter w"},
/* 1D66D */ { "MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL X","	# <font> 0078 latin small letter x"},
/* 1D66E */ { "MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL Y","	# <font> 0079 latin small letter y"},
/* 1D66F */ { "MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL Z","	# <font> 007A latin small letter z"},
/* 1D670 */ { "MATHEMATICAL MONOSPACE CAPITAL A","	# <font> 0041 latin capital letter a"},
/* 1D671 */ { "MATHEMATICAL MONOSPACE CAPITAL B","	# <font> 0042 latin capital letter b"},
/* 1D672 */ { "MATHEMATICAL MONOSPACE CAPITAL C","	# <font> 0043 latin capital letter c"},
/* 1D673 */ { "MATHEMATICAL MONOSPACE CAPITAL D","	# <font> 0044 latin capital letter d"},
/* 1D674 */ { "MATHEMATICAL MONOSPACE CAPITAL E","	# <font> 0045 latin capital letter e"},
/* 1D675 */ { "MATHEMATICAL MONOSPACE CAPITAL F","	# <font> 0046 latin capital letter f"},
/* 1D676 */ { "MATHEMATICAL MONOSPACE CAPITAL G","	# <font> 0047 latin capital letter g"},
/* 1D677 */ { "MATHEMATICAL MONOSPACE CAPITAL H","	# <font> 0048 latin capital letter h"},
/* 1D678 */ { "MATHEMATICAL MONOSPACE CAPITAL I","	# <font> 0049 latin capital letter i"},
/* 1D679 */ { "MATHEMATICAL MONOSPACE CAPITAL J","	# <font> 004A latin capital letter j"},
/* 1D67A */ { "MATHEMATICAL MONOSPACE CAPITAL K","	# <font> 004B latin capital letter k"},
/* 1D67B */ { "MATHEMATICAL MONOSPACE CAPITAL L","	# <font> 004C latin capital letter l"},
/* 1D67C */ { "MATHEMATICAL MONOSPACE CAPITAL M","	# <font> 004D latin capital letter m"},
/* 1D67D */ { "MATHEMATICAL MONOSPACE CAPITAL N","	# <font> 004E latin capital letter n"},
/* 1D67E */ { "MATHEMATICAL MONOSPACE CAPITAL O","	# <font> 004F latin capital letter o"},
/* 1D67F */ { "MATHEMATICAL MONOSPACE CAPITAL P","	# <font> 0050 latin capital letter p"},
/* 1D680 */ { "MATHEMATICAL MONOSPACE CAPITAL Q","	# <font> 0051 latin capital letter q"},
/* 1D681 */ { "MATHEMATICAL MONOSPACE CAPITAL R","	# <font> 0052 latin capital letter r"},
/* 1D682 */ { "MATHEMATICAL MONOSPACE CAPITAL S","	# <font> 0053 latin capital letter s"},
/* 1D683 */ { "MATHEMATICAL MONOSPACE CAPITAL T","	# <font> 0054 latin capital letter t"},
/* 1D684 */ { "MATHEMATICAL MONOSPACE CAPITAL U","	# <font> 0055 latin capital letter u"},
/* 1D685 */ { "MATHEMATICAL MONOSPACE CAPITAL V","	# <font> 0056 latin capital letter v"},
/* 1D686 */ { "MATHEMATICAL MONOSPACE CAPITAL W","	# <font> 0057 latin capital letter w"},
/* 1D687 */ { "MATHEMATICAL MONOSPACE CAPITAL X","	# <font> 0058 latin capital letter x"},
/* 1D688 */ { "MATHEMATICAL MONOSPACE CAPITAL Y","	# <font> 0059 latin capital letter y"},
/* 1D689 */ { "MATHEMATICAL MONOSPACE CAPITAL Z","	# <font> 005A latin capital letter z"},
/* 1D68A */ { "MATHEMATICAL MONOSPACE SMALL A","	# <font> 0061 latin small letter a"},
/* 1D68B */ { "MATHEMATICAL MONOSPACE SMALL B","	# <font> 0062 latin small letter b"},
/* 1D68C */ { "MATHEMATICAL MONOSPACE SMALL C","	# <font> 0063 latin small letter c"},
/* 1D68D */ { "MATHEMATICAL MONOSPACE SMALL D","	# <font> 0064 latin small letter d"},
/* 1D68E */ { "MATHEMATICAL MONOSPACE SMALL E","	# <font> 0065 latin small letter e"},
/* 1D68F */ { "MATHEMATICAL MONOSPACE SMALL F","	# <font> 0066 latin small letter f"},
/* 1D690 */ { "MATHEMATICAL MONOSPACE SMALL G","	# <font> 0067 latin small letter g"},
/* 1D691 */ { "MATHEMATICAL MONOSPACE SMALL H","	# <font> 0068 latin small letter h"},
/* 1D692 */ { "MATHEMATICAL MONOSPACE SMALL I","	# <font> 0069 latin small letter i"},
/* 1D693 */ { "MATHEMATICAL MONOSPACE SMALL J","	# <font> 006A latin small letter j"},
/* 1D694 */ { "MATHEMATICAL MONOSPACE SMALL K","	# <font> 006B latin small letter k"},
/* 1D695 */ { "MATHEMATICAL MONOSPACE SMALL L","	# <font> 006C latin small letter l"},
/* 1D696 */ { "MATHEMATICAL MONOSPACE SMALL M","	# <font> 006D latin small letter m"},
/* 1D697 */ { "MATHEMATICAL MONOSPACE SMALL N","	# <font> 006E latin small letter n"},
/* 1D698 */ { "MATHEMATICAL MONOSPACE SMALL O","	# <font> 006F latin small letter o"},
/* 1D699 */ { "MATHEMATICAL MONOSPACE SMALL P","	# <font> 0070 latin small letter p"},
/* 1D69A */ { "MATHEMATICAL MONOSPACE SMALL Q","	# <font> 0071 latin small letter q"},
/* 1D69B */ { "MATHEMATICAL MONOSPACE SMALL R","	# <font> 0072 latin small letter r"},
/* 1D69C */ { "MATHEMATICAL MONOSPACE SMALL S","	# <font> 0073 latin small letter s"},
/* 1D69D */ { "MATHEMATICAL MONOSPACE SMALL T","	# <font> 0074 latin small letter t"},
/* 1D69E */ { "MATHEMATICAL MONOSPACE SMALL U","	# <font> 0075 latin small letter u"},
/* 1D69F */ { "MATHEMATICAL MONOSPACE SMALL V","	# <font> 0076 latin small letter v"},
/* 1D6A0 */ { "MATHEMATICAL MONOSPACE SMALL W","	# <font> 0077 latin small letter w"},
/* 1D6A1 */ { "MATHEMATICAL MONOSPACE SMALL X","	# <font> 0078 latin small letter x"},
/* 1D6A2 */ { "MATHEMATICAL MONOSPACE SMALL Y","	# <font> 0079 latin small letter y"},
/* 1D6A3 */ { "MATHEMATICAL MONOSPACE SMALL Z","	# <font> 007A latin small letter z"},
/* 1D6A4 */ { "MATHEMATICAL ITALIC SMALL DOTLESS I","	= \\imath\n"
	"	x (latin small letter dotless i - 0131)\n"
	"	x (mathematical italic small i - 1D456)\n"
	"	# <font> 0131 latin small letter dotless i"},
/* 1D6A5 */ { "MATHEMATICAL ITALIC SMALL DOTLESS J","	= \\jmath\n"
	"	x (latin small letter dotless j - 0237)\n"
	"	x (mathematical italic small j - 1D457)\n"
	"	# <font> 0237 latin small letter dotless j"},
/* 1D6A6 */ { NULL,NULL},
/* 1D6A7 */ { NULL,NULL},
/* 1D6A8 */ { "MATHEMATICAL BOLD CAPITAL ALPHA","	# <font> 0391 greek capital letter alpha"},
/* 1D6A9 */ { "MATHEMATICAL BOLD CAPITAL BETA","	# <font> 0392 greek capital letter beta"},
/* 1D6AA */ { "MATHEMATICAL BOLD CAPITAL GAMMA","	# <font> 0393 greek capital letter gamma"},
/* 1D6AB */ { "MATHEMATICAL BOLD CAPITAL DELTA","	# <font> 0394 greek capital letter delta"},
/* 1D6AC */ { "MATHEMATICAL BOLD CAPITAL EPSILON","	# <font> 0395 greek capital letter epsilon"},
/* 1D6AD */ { "MATHEMATICAL BOLD CAPITAL ZETA","	# <font> 0396 greek capital letter zeta"},
/* 1D6AE */ { "MATHEMATICAL BOLD CAPITAL ETA","	# <font> 0397 greek capital letter eta"},
/* 1D6AF */ { "MATHEMATICAL BOLD CAPITAL THETA","	# <font> 0398 greek capital letter theta"},
/* 1D6B0 */ { "MATHEMATICAL BOLD CAPITAL IOTA","	# <font> 0399 greek capital letter iota"},
/* 1D6B1 */ { "MATHEMATICAL BOLD CAPITAL KAPPA","	# <font> 039A greek capital letter kappa"},
/* 1D6B2 */ { "MATHEMATICAL BOLD CAPITAL LAMDA","	# <font> 039B greek capital letter lamda"},
/* 1D6B3 */ { "MATHEMATICAL BOLD CAPITAL MU","	# <font> 039C greek capital letter mu"},
/* 1D6B4 */ { "MATHEMATICAL BOLD CAPITAL NU","	# <font> 039D greek capital letter nu"},
/* 1D6B5 */ { "MATHEMATICAL BOLD CAPITAL XI","	# <font> 039E greek capital letter xi"},
/* 1D6B6 */ { "MATHEMATICAL BOLD CAPITAL OMICRON","	# <font> 039F greek capital letter omicron"},
/* 1D6B7 */ { "MATHEMATICAL BOLD CAPITAL PI","	# <font> 03A0 greek capital letter pi"},
/* 1D6B8 */ { "MATHEMATICAL BOLD CAPITAL RHO","	# <font> 03A1 greek capital letter rho"},
/* 1D6B9 */ { "MATHEMATICAL BOLD CAPITAL THETA SYMBOL","	# <font> 03F4 greek capital theta symbol"},
/* 1D6BA */ { "MATHEMATICAL BOLD CAPITAL SIGMA","	# <font> 03A3 greek capital letter sigma"},
/* 1D6BB */ { "MATHEMATICAL BOLD CAPITAL TAU","	# <font> 03A4 greek capital letter tau"},
/* 1D6BC */ { "MATHEMATICAL BOLD CAPITAL UPSILON","	# <font> 03A5 greek capital letter upsilon"},
/* 1D6BD */ { "MATHEMATICAL BOLD CAPITAL PHI","	# <font> 03A6 greek capital letter phi"},
/* 1D6BE */ { "MATHEMATICAL BOLD CAPITAL CHI","	# <font> 03A7 greek capital letter chi"},
/* 1D6BF */ { "MATHEMATICAL BOLD CAPITAL PSI","	# <font> 03A8 greek capital letter psi"},
/* 1D6C0 */ { "MATHEMATICAL BOLD CAPITAL OMEGA","	# <font> 03A9 greek capital letter omega"},
/* 1D6C1 */ { "MATHEMATICAL BOLD NABLA","	# <font> 2207 nabla"},
/* 1D6C2 */ { "MATHEMATICAL BOLD SMALL ALPHA","	# <font> 03B1 greek small letter alpha"},
/* 1D6C3 */ { "MATHEMATICAL BOLD SMALL BETA","	# <font> 03B2 greek small letter beta"},
/* 1D6C4 */ { "MATHEMATICAL BOLD SMALL GAMMA","	# <font> 03B3 greek small letter gamma"},
/* 1D6C5 */ { "MATHEMATICAL BOLD SMALL DELTA","	# <font> 03B4 greek small letter delta"},
/* 1D6C6 */ { "MATHEMATICAL BOLD SMALL EPSILON","	# <font> 03B5 greek small letter epsilon"},
/* 1D6C7 */ { "MATHEMATICAL BOLD SMALL ZETA","	# <font> 03B6 greek small letter zeta"},
/* 1D6C8 */ { "MATHEMATICAL BOLD SMALL ETA","	# <font> 03B7 greek small letter eta"},
/* 1D6C9 */ { "MATHEMATICAL BOLD SMALL THETA","	# <font> 03B8 greek small letter theta"},
/* 1D6CA */ { "MATHEMATICAL BOLD SMALL IOTA","	# <font> 03B9 greek small letter iota"},
/* 1D6CB */ { "MATHEMATICAL BOLD SMALL KAPPA","	# <font> 03BA greek small letter kappa"},
/* 1D6CC */ { "MATHEMATICAL BOLD SMALL LAMDA","	# <font> 03BB greek small letter lamda"},
/* 1D6CD */ { "MATHEMATICAL BOLD SMALL MU","	# <font> 03BC greek small letter mu"},
/* 1D6CE */ { "MATHEMATICAL BOLD SMALL NU","	# <font> 03BD greek small letter nu"},
/* 1D6CF */ { "MATHEMATICAL BOLD SMALL XI","	# <font> 03BE greek small letter xi"},
/* 1D6D0 */ { "MATHEMATICAL BOLD SMALL OMICRON","	# <font> 03BF greek small letter omicron"},
/* 1D6D1 */ { "MATHEMATICAL BOLD SMALL PI","	# <font> 03C0 greek small letter pi"},
/* 1D6D2 */ { "MATHEMATICAL BOLD SMALL RHO","	# <font> 03C1 greek small letter rho"},
/* 1D6D3 */ { "MATHEMATICAL BOLD SMALL FINAL SIGMA","	# <font> 03C2 greek small letter final sigma"},
/* 1D6D4 */ { "MATHEMATICAL BOLD SMALL SIGMA","	# <font> 03C3 greek small letter sigma"},
/* 1D6D5 */ { "MATHEMATICAL BOLD SMALL TAU","	# <font> 03C4 greek small letter tau"},
/* 1D6D6 */ { "MATHEMATICAL BOLD SMALL UPSILON","	# <font> 03C5 greek small letter upsilon"},
/* 1D6D7 */ { "MATHEMATICAL BOLD SMALL PHI","	# <font> 03C6 greek small letter phi"},
/* 1D6D8 */ { "MATHEMATICAL BOLD SMALL CHI","	# <font> 03C7 greek small letter chi"},
/* 1D6D9 */ { "MATHEMATICAL BOLD SMALL PSI","	# <font> 03C8 greek small letter psi"},
/* 1D6DA */ { "MATHEMATICAL BOLD SMALL OMEGA","	# <font> 03C9 greek small letter omega"},
/* 1D6DB */ { "MATHEMATICAL BOLD PARTIAL DIFFERENTIAL","	# <font> 2202 partial differential"},
/* 1D6DC */ { "MATHEMATICAL BOLD EPSILON SYMBOL","	# <font> 03F5 greek lunate epsilon symbol"},
/* 1D6DD */ { "MATHEMATICAL BOLD THETA SYMBOL","	# <font> 03D1 greek theta symbol"},
/* 1D6DE */ { "MATHEMATICAL BOLD KAPPA SYMBOL","	# <font> 03F0 greek kappa symbol"},
/* 1D6DF */ { "MATHEMATICAL BOLD PHI SYMBOL","	# <font> 03D5 greek phi symbol"},
/* 1D6E0 */ { "MATHEMATICAL BOLD RHO SYMBOL","	# <font> 03F1 greek rho symbol"},
/* 1D6E1 */ { "MATHEMATICAL BOLD PI SYMBOL","	# <font> 03D6 greek pi symbol"},
/* 1D6E2 */ { "MATHEMATICAL ITALIC CAPITAL ALPHA","	# <font> 0391 greek capital letter alpha"},
/* 1D6E3 */ { "MATHEMATICAL ITALIC CAPITAL BETA","	# <font> 0392 greek capital letter beta"},
/* 1D6E4 */ { "MATHEMATICAL ITALIC CAPITAL GAMMA","	# <font> 0393 greek capital letter gamma"},
/* 1D6E5 */ { "MATHEMATICAL ITALIC CAPITAL DELTA","	# <font> 0394 greek capital letter delta"},
/* 1D6E6 */ { "MATHEMATICAL ITALIC CAPITAL EPSILON","	# <font> 0395 greek capital letter epsilon"},
/* 1D6E7 */ { "MATHEMATICAL ITALIC CAPITAL ZETA","	# <font> 0396 greek capital letter zeta"},
/* 1D6E8 */ { "MATHEMATICAL ITALIC CAPITAL ETA","	# <font> 0397 greek capital letter eta"},
/* 1D6E9 */ { "MATHEMATICAL ITALIC CAPITAL THETA","	# <font> 0398 greek capital letter theta"},
/* 1D6EA */ { "MATHEMATICAL ITALIC CAPITAL IOTA","	# <font> 0399 greek capital letter iota"},
/* 1D6EB */ { "MATHEMATICAL ITALIC CAPITAL KAPPA","	# <font> 039A greek capital letter kappa"},
/* 1D6EC */ { "MATHEMATICAL ITALIC CAPITAL LAMDA","	# <font> 039B greek capital letter lamda"},
/* 1D6ED */ { "MATHEMATICAL ITALIC CAPITAL MU","	# <font> 039C greek capital letter mu"},
/* 1D6EE */ { "MATHEMATICAL ITALIC CAPITAL NU","	# <font> 039D greek capital letter nu"},
/* 1D6EF */ { "MATHEMATICAL ITALIC CAPITAL XI","	# <font> 039E greek capital letter xi"},
/* 1D6F0 */ { "MATHEMATICAL ITALIC CAPITAL OMICRON","	# <font> 039F greek capital letter omicron"},
/* 1D6F1 */ { "MATHEMATICAL ITALIC CAPITAL PI","	# <font> 03A0 greek capital letter pi"},
/* 1D6F2 */ { "MATHEMATICAL ITALIC CAPITAL RHO","	# <font> 03A1 greek capital letter rho"},
/* 1D6F3 */ { "MATHEMATICAL ITALIC CAPITAL THETA SYMBOL","	# <font> 03F4 greek capital theta symbol"},
/* 1D6F4 */ { "MATHEMATICAL ITALIC CAPITAL SIGMA","	# <font> 03A3 greek capital letter sigma"},
/* 1D6F5 */ { "MATHEMATICAL ITALIC CAPITAL TAU","	# <font> 03A4 greek capital letter tau"},
/* 1D6F6 */ { "MATHEMATICAL ITALIC CAPITAL UPSILON","	# <font> 03A5 greek capital letter upsilon"},
/* 1D6F7 */ { "MATHEMATICAL ITALIC CAPITAL PHI","	# <font> 03A6 greek capital letter phi"},
/* 1D6F8 */ { "MATHEMATICAL ITALIC CAPITAL CHI","	# <font> 03A7 greek capital letter chi"},
/* 1D6F9 */ { "MATHEMATICAL ITALIC CAPITAL PSI","	# <font> 03A8 greek capital letter psi"},
/* 1D6FA */ { "MATHEMATICAL ITALIC CAPITAL OMEGA","	# <font> 03A9 greek capital letter omega"},
/* 1D6FB */ { "MATHEMATICAL ITALIC NABLA","	# <font> 2207 nabla"},
/* 1D6FC */ { "MATHEMATICAL ITALIC SMALL ALPHA","	# <font> 03B1 greek small letter alpha"},
/* 1D6FD */ { "MATHEMATICAL ITALIC SMALL BETA","	# <font> 03B2 greek small letter beta"},
/* 1D6FE */ { "MATHEMATICAL ITALIC SMALL GAMMA","	# <font> 03B3 greek small letter gamma"},
/* 1D6FF */ { "MATHEMATICAL ITALIC SMALL DELTA","	# <font> 03B4 greek small letter delta"}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_D7[] = {
/* 1D700 */ { "MATHEMATICAL ITALIC SMALL EPSILON","	# <font> 03B5 greek small letter epsilon"},
/* 1D701 */ { "MATHEMATICAL ITALIC SMALL ZETA","	# <font> 03B6 greek small letter zeta"},
/* 1D702 */ { "MATHEMATICAL ITALIC SMALL ETA","	# <font> 03B7 greek small letter eta"},
/* 1D703 */ { "MATHEMATICAL ITALIC SMALL THETA","	# <font> 03B8 greek small letter theta"},
/* 1D704 */ { "MATHEMATICAL ITALIC SMALL IOTA","	# <font> 03B9 greek small letter iota"},
/* 1D705 */ { "MATHEMATICAL ITALIC SMALL KAPPA","	# <font> 03BA greek small letter kappa"},
/* 1D706 */ { "MATHEMATICAL ITALIC SMALL LAMDA","	# <font> 03BB greek small letter lamda"},
/* 1D707 */ { "MATHEMATICAL ITALIC SMALL MU","	# <font> 03BC greek small letter mu"},
/* 1D708 */ { "MATHEMATICAL ITALIC SMALL NU","	# <font> 03BD greek small letter nu"},
/* 1D709 */ { "MATHEMATICAL ITALIC SMALL XI","	# <font> 03BE greek small letter xi"},
/* 1D70A */ { "MATHEMATICAL ITALIC SMALL OMICRON","	# <font> 03BF greek small letter omicron"},
/* 1D70B */ { "MATHEMATICAL ITALIC SMALL PI","	# <font> 03C0 greek small letter pi"},
/* 1D70C */ { "MATHEMATICAL ITALIC SMALL RHO","	# <font> 03C1 greek small letter rho"},
/* 1D70D */ { "MATHEMATICAL ITALIC SMALL FINAL SIGMA","	# <font> 03C2 greek small letter final sigma"},
/* 1D70E */ { "MATHEMATICAL ITALIC SMALL SIGMA","	# <font> 03C3 greek small letter sigma"},
/* 1D70F */ { "MATHEMATICAL ITALIC SMALL TAU","	# <font> 03C4 greek small letter tau"},
/* 1D710 */ { "MATHEMATICAL ITALIC SMALL UPSILON","	# <font> 03C5 greek small letter upsilon"},
/* 1D711 */ { "MATHEMATICAL ITALIC SMALL PHI","	# <font> 03C6 greek small letter phi"},
/* 1D712 */ { "MATHEMATICAL ITALIC SMALL CHI","	# <font> 03C7 greek small letter chi"},
/* 1D713 */ { "MATHEMATICAL ITALIC SMALL PSI","	# <font> 03C8 greek small letter psi"},
/* 1D714 */ { "MATHEMATICAL ITALIC SMALL OMEGA","	# <font> 03C9 greek small letter omega"},
/* 1D715 */ { "MATHEMATICAL ITALIC PARTIAL DIFFERENTIAL","	# <font> 2202 partial differential"},
/* 1D716 */ { "MATHEMATICAL ITALIC EPSILON SYMBOL","	# <font> 03F5 greek lunate epsilon symbol"},
/* 1D717 */ { "MATHEMATICAL ITALIC THETA SYMBOL","	# <font> 03D1 greek theta symbol"},
/* 1D718 */ { "MATHEMATICAL ITALIC KAPPA SYMBOL","	# <font> 03F0 greek kappa symbol"},
/* 1D719 */ { "MATHEMATICAL ITALIC PHI SYMBOL","	# <font> 03D5 greek phi symbol"},
/* 1D71A */ { "MATHEMATICAL ITALIC RHO SYMBOL","	# <font> 03F1 greek rho symbol"},
/* 1D71B */ { "MATHEMATICAL ITALIC PI SYMBOL","	# <font> 03D6 greek pi symbol"},
/* 1D71C */ { "MATHEMATICAL BOLD ITALIC CAPITAL ALPHA","	# <font> 0391 greek capital letter alpha"},
/* 1D71D */ { "MATHEMATICAL BOLD ITALIC CAPITAL BETA","	# <font> 0392 greek capital letter beta"},
/* 1D71E */ { "MATHEMATICAL BOLD ITALIC CAPITAL GAMMA","	# <font> 0393 greek capital letter gamma"},
/* 1D71F */ { "MATHEMATICAL BOLD ITALIC CAPITAL DELTA","	# <font> 0394 greek capital letter delta"},
/* 1D720 */ { "MATHEMATICAL BOLD ITALIC CAPITAL EPSILON","	# <font> 0395 greek capital letter epsilon"},
/* 1D721 */ { "MATHEMATICAL BOLD ITALIC CAPITAL ZETA","	# <font> 0396 greek capital letter zeta"},
/* 1D722 */ { "MATHEMATICAL BOLD ITALIC CAPITAL ETA","	# <font> 0397 greek capital letter eta"},
/* 1D723 */ { "MATHEMATICAL BOLD ITALIC CAPITAL THETA","	# <font> 0398 greek capital letter theta"},
/* 1D724 */ { "MATHEMATICAL BOLD ITALIC CAPITAL IOTA","	# <font> 0399 greek capital letter iota"},
/* 1D725 */ { "MATHEMATICAL BOLD ITALIC CAPITAL KAPPA","	# <font> 039A greek capital letter kappa"},
/* 1D726 */ { "MATHEMATICAL BOLD ITALIC CAPITAL LAMDA","	# <font> 039B greek capital letter lamda"},
/* 1D727 */ { "MATHEMATICAL BOLD ITALIC CAPITAL MU","	# <font> 039C greek capital letter mu"},
/* 1D728 */ { "MATHEMATICAL BOLD ITALIC CAPITAL NU","	# <font> 039D greek capital letter nu"},
/* 1D729 */ { "MATHEMATICAL BOLD ITALIC CAPITAL XI","	# <font> 039E greek capital letter xi"},
/* 1D72A */ { "MATHEMATICAL BOLD ITALIC CAPITAL OMICRON","	# <font> 039F greek capital letter omicron"},
/* 1D72B */ { "MATHEMATICAL BOLD ITALIC CAPITAL PI","	# <font> 03A0 greek capital letter pi"},
/* 1D72C */ { "MATHEMATICAL BOLD ITALIC CAPITAL RHO","	# <font> 03A1 greek capital letter rho"},
/* 1D72D */ { "MATHEMATICAL BOLD ITALIC CAPITAL THETA SYMBOL","	# <font> 03F4 greek capital theta symbol"},
/* 1D72E */ { "MATHEMATICAL BOLD ITALIC CAPITAL SIGMA","	# <font> 03A3 greek capital letter sigma"},
/* 1D72F */ { "MATHEMATICAL BOLD ITALIC CAPITAL TAU","	# <font> 03A4 greek capital letter tau"},
/* 1D730 */ { "MATHEMATICAL BOLD ITALIC CAPITAL UPSILON","	# <font> 03A5 greek capital letter upsilon"},
/* 1D731 */ { "MATHEMATICAL BOLD ITALIC CAPITAL PHI","	# <font> 03A6 greek capital letter phi"},
/* 1D732 */ { "MATHEMATICAL BOLD ITALIC CAPITAL CHI","	# <font> 03A7 greek capital letter chi"},
/* 1D733 */ { "MATHEMATICAL BOLD ITALIC CAPITAL PSI","	# <font> 03A8 greek capital letter psi"},
/* 1D734 */ { "MATHEMATICAL BOLD ITALIC CAPITAL OMEGA","	# <font> 03A9 greek capital letter omega"},
/* 1D735 */ { "MATHEMATICAL BOLD ITALIC NABLA","	# <font> 2207 nabla"},
/* 1D736 */ { "MATHEMATICAL BOLD ITALIC SMALL ALPHA","	# <font> 03B1 greek small letter alpha"},
/* 1D737 */ { "MATHEMATICAL BOLD ITALIC SMALL BETA","	# <font> 03B2 greek small letter beta"},
/* 1D738 */ { "MATHEMATICAL BOLD ITALIC SMALL GAMMA","	# <font> 03B3 greek small letter gamma"},
/* 1D739 */ { "MATHEMATICAL BOLD ITALIC SMALL DELTA","	# <font> 03B4 greek small letter delta"},
/* 1D73A */ { "MATHEMATICAL BOLD ITALIC SMALL EPSILON","	# <font> 03B5 greek small letter epsilon"},
/* 1D73B */ { "MATHEMATICAL BOLD ITALIC SMALL ZETA","	# <font> 03B6 greek small letter zeta"},
/* 1D73C */ { "MATHEMATICAL BOLD ITALIC SMALL ETA","	# <font> 03B7 greek small letter eta"},
/* 1D73D */ { "MATHEMATICAL BOLD ITALIC SMALL THETA","	# <font> 03B8 greek small letter theta"},
/* 1D73E */ { "MATHEMATICAL BOLD ITALIC SMALL IOTA","	# <font> 03B9 greek small letter iota"},
/* 1D73F */ { "MATHEMATICAL BOLD ITALIC SMALL KAPPA","	# <font> 03BA greek small letter kappa"},
/* 1D740 */ { "MATHEMATICAL BOLD ITALIC SMALL LAMDA","	# <font> 03BB greek small letter lamda"},
/* 1D741 */ { "MATHEMATICAL BOLD ITALIC SMALL MU","	# <font> 03BC greek small letter mu"},
/* 1D742 */ { "MATHEMATICAL BOLD ITALIC SMALL NU","	# <font> 03BD greek small letter nu"},
/* 1D743 */ { "MATHEMATICAL BOLD ITALIC SMALL XI","	# <font> 03BE greek small letter xi"},
/* 1D744 */ { "MATHEMATICAL BOLD ITALIC SMALL OMICRON","	# <font> 03BF greek small letter omicron"},
/* 1D745 */ { "MATHEMATICAL BOLD ITALIC SMALL PI","	# <font> 03C0 greek small letter pi"},
/* 1D746 */ { "MATHEMATICAL BOLD ITALIC SMALL RHO","	# <font> 03C1 greek small letter rho"},
/* 1D747 */ { "MATHEMATICAL BOLD ITALIC SMALL FINAL SIGMA","	# <font> 03C2 greek small letter final sigma"},
/* 1D748 */ { "MATHEMATICAL BOLD ITALIC SMALL SIGMA","	# <font> 03C3 greek small letter sigma"},
/* 1D749 */ { "MATHEMATICAL BOLD ITALIC SMALL TAU","	# <font> 03C4 greek small letter tau"},
/* 1D74A */ { "MATHEMATICAL BOLD ITALIC SMALL UPSILON","	# <font> 03C5 greek small letter upsilon"},
/* 1D74B */ { "MATHEMATICAL BOLD ITALIC SMALL PHI","	# <font> 03C6 greek small letter phi"},
/* 1D74C */ { "MATHEMATICAL BOLD ITALIC SMALL CHI","	# <font> 03C7 greek small letter chi"},
/* 1D74D */ { "MATHEMATICAL BOLD ITALIC SMALL PSI","	# <font> 03C8 greek small letter psi"},
/* 1D74E */ { "MATHEMATICAL BOLD ITALIC SMALL OMEGA","	# <font> 03C9 greek small letter omega"},
/* 1D74F */ { "MATHEMATICAL BOLD ITALIC PARTIAL DIFFERENTIAL","	# <font> 2202 partial differential"},
/* 1D750 */ { "MATHEMATICAL BOLD ITALIC EPSILON SYMBOL","	# <font> 03F5 greek lunate epsilon symbol"},
/* 1D751 */ { "MATHEMATICAL BOLD ITALIC THETA SYMBOL","	# <font> 03D1 greek theta symbol"},
/* 1D752 */ { "MATHEMATICAL BOLD ITALIC KAPPA SYMBOL","	# <font> 03F0 greek kappa symbol"},
/* 1D753 */ { "MATHEMATICAL BOLD ITALIC PHI SYMBOL","	# <font> 03D5 greek phi symbol"},
/* 1D754 */ { "MATHEMATICAL BOLD ITALIC RHO SYMBOL","	# <font> 03F1 greek rho symbol"},
/* 1D755 */ { "MATHEMATICAL BOLD ITALIC PI SYMBOL","	# <font> 03D6 greek pi symbol"},
/* 1D756 */ { "MATHEMATICAL SANS-SERIF BOLD CAPITAL ALPHA","	# <font> 0391 greek capital letter alpha"},
/* 1D757 */ { "MATHEMATICAL SANS-SERIF BOLD CAPITAL BETA","	# <font> 0392 greek capital letter beta"},
/* 1D758 */ { "MATHEMATICAL SANS-SERIF BOLD CAPITAL GAMMA","	# <font> 0393 greek capital letter gamma"},
/* 1D759 */ { "MATHEMATICAL SANS-SERIF BOLD CAPITAL DELTA","	# <font> 0394 greek capital letter delta"},
/* 1D75A */ { "MATHEMATICAL SANS-SERIF BOLD CAPITAL EPSILON","	# <font> 0395 greek capital letter epsilon"},
/* 1D75B */ { "MATHEMATICAL SANS-SERIF BOLD CAPITAL ZETA","	# <font> 0396 greek capital letter zeta"},
/* 1D75C */ { "MATHEMATICAL SANS-SERIF BOLD CAPITAL ETA","	# <font> 0397 greek capital letter eta"},
/* 1D75D */ { "MATHEMATICAL SANS-SERIF BOLD CAPITAL THETA","	# <font> 0398 greek capital letter theta"},
/* 1D75E */ { "MATHEMATICAL SANS-SERIF BOLD CAPITAL IOTA","	# <font> 0399 greek capital letter iota"},
/* 1D75F */ { "MATHEMATICAL SANS-SERIF BOLD CAPITAL KAPPA","	# <font> 039A greek capital letter kappa"},
/* 1D760 */ { "MATHEMATICAL SANS-SERIF BOLD CAPITAL LAMDA","	# <font> 039B greek capital letter lamda"},
/* 1D761 */ { "MATHEMATICAL SANS-SERIF BOLD CAPITAL MU","	# <font> 039C greek capital letter mu"},
/* 1D762 */ { "MATHEMATICAL SANS-SERIF BOLD CAPITAL NU","	# <font> 039D greek capital letter nu"},
/* 1D763 */ { "MATHEMATICAL SANS-SERIF BOLD CAPITAL XI","	# <font> 039E greek capital letter xi"},
/* 1D764 */ { "MATHEMATICAL SANS-SERIF BOLD CAPITAL OMICRON","	# <font> 039F greek capital letter omicron"},
/* 1D765 */ { "MATHEMATICAL SANS-SERIF BOLD CAPITAL PI","	# <font> 03A0 greek capital letter pi"},
/* 1D766 */ { "MATHEMATICAL SANS-SERIF BOLD CAPITAL RHO","	# <font> 03A1 greek capital letter rho"},
/* 1D767 */ { "MATHEMATICAL SANS-SERIF BOLD CAPITAL THETA SYMBOL","	# <font> 03F4 greek capital theta symbol"},
/* 1D768 */ { "MATHEMATICAL SANS-SERIF BOLD CAPITAL SIGMA","	# <font> 03A3 greek capital letter sigma"},
/* 1D769 */ { "MATHEMATICAL SANS-SERIF BOLD CAPITAL TAU","	# <font> 03A4 greek capital letter tau"},
/* 1D76A */ { "MATHEMATICAL SANS-SERIF BOLD CAPITAL UPSILON","	# <font> 03A5 greek capital letter upsilon"},
/* 1D76B */ { "MATHEMATICAL SANS-SERIF BOLD CAPITAL PHI","	# <font> 03A6 greek capital letter phi"},
/* 1D76C */ { "MATHEMATICAL SANS-SERIF BOLD CAPITAL CHI","	# <font> 03A7 greek capital letter chi"},
/* 1D76D */ { "MATHEMATICAL SANS-SERIF BOLD CAPITAL PSI","	# <font> 03A8 greek capital letter psi"},
/* 1D76E */ { "MATHEMATICAL SANS-SERIF BOLD CAPITAL OMEGA","	# <font> 03A9 greek capital letter omega"},
/* 1D76F */ { "MATHEMATICAL SANS-SERIF BOLD NABLA","	# <font> 2207 nabla"},
/* 1D770 */ { "MATHEMATICAL SANS-SERIF BOLD SMALL ALPHA","	# <font> 03B1 greek small letter alpha"},
/* 1D771 */ { "MATHEMATICAL SANS-SERIF BOLD SMALL BETA","	# <font> 03B2 greek small letter beta"},
/* 1D772 */ { "MATHEMATICAL SANS-SERIF BOLD SMALL GAMMA","	# <font> 03B3 greek small letter gamma"},
/* 1D773 */ { "MATHEMATICAL SANS-SERIF BOLD SMALL DELTA","	# <font> 03B4 greek small letter delta"},
/* 1D774 */ { "MATHEMATICAL SANS-SERIF BOLD SMALL EPSILON","	# <font> 03B5 greek small letter epsilon"},
/* 1D775 */ { "MATHEMATICAL SANS-SERIF BOLD SMALL ZETA","	# <font> 03B6 greek small letter zeta"},
/* 1D776 */ { "MATHEMATICAL SANS-SERIF BOLD SMALL ETA","	# <font> 03B7 greek small letter eta"},
/* 1D777 */ { "MATHEMATICAL SANS-SERIF BOLD SMALL THETA","	# <font> 03B8 greek small letter theta"},
/* 1D778 */ { "MATHEMATICAL SANS-SERIF BOLD SMALL IOTA","	# <font> 03B9 greek small letter iota"},
/* 1D779 */ { "MATHEMATICAL SANS-SERIF BOLD SMALL KAPPA","	# <font> 03BA greek small letter kappa"},
/* 1D77A */ { "MATHEMATICAL SANS-SERIF BOLD SMALL LAMDA","	# <font> 03BB greek small letter lamda"},
/* 1D77B */ { "MATHEMATICAL SANS-SERIF BOLD SMALL MU","	# <font> 03BC greek small letter mu"},
/* 1D77C */ { "MATHEMATICAL SANS-SERIF BOLD SMALL NU","	# <font> 03BD greek small letter nu"},
/* 1D77D */ { "MATHEMATICAL SANS-SERIF BOLD SMALL XI","	# <font> 03BE greek small letter xi"},
/* 1D77E */ { "MATHEMATICAL SANS-SERIF BOLD SMALL OMICRON","	# <font> 03BF greek small letter omicron"},
/* 1D77F */ { "MATHEMATICAL SANS-SERIF BOLD SMALL PI","	# <font> 03C0 greek small letter pi"},
/* 1D780 */ { "MATHEMATICAL SANS-SERIF BOLD SMALL RHO","	# <font> 03C1 greek small letter rho"},
/* 1D781 */ { "MATHEMATICAL SANS-SERIF BOLD SMALL FINAL SIGMA","	# <font> 03C2 greek small letter final sigma"},
/* 1D782 */ { "MATHEMATICAL SANS-SERIF BOLD SMALL SIGMA","	# <font> 03C3 greek small letter sigma"},
/* 1D783 */ { "MATHEMATICAL SANS-SERIF BOLD SMALL TAU","	# <font> 03C4 greek small letter tau"},
/* 1D784 */ { "MATHEMATICAL SANS-SERIF BOLD SMALL UPSILON","	# <font> 03C5 greek small letter upsilon"},
/* 1D785 */ { "MATHEMATICAL SANS-SERIF BOLD SMALL PHI","	# <font> 03C6 greek small letter phi"},
/* 1D786 */ { "MATHEMATICAL SANS-SERIF BOLD SMALL CHI","	# <font> 03C7 greek small letter chi"},
/* 1D787 */ { "MATHEMATICAL SANS-SERIF BOLD SMALL PSI","	# <font> 03C8 greek small letter psi"},
/* 1D788 */ { "MATHEMATICAL SANS-SERIF BOLD SMALL OMEGA","	# <font> 03C9 greek small letter omega"},
/* 1D789 */ { "MATHEMATICAL SANS-SERIF BOLD PARTIAL DIFFERENTIAL","	# <font> 2202 partial differential"},
/* 1D78A */ { "MATHEMATICAL SANS-SERIF BOLD EPSILON SYMBOL","	# <font> 03F5 greek lunate epsilon symbol"},
/* 1D78B */ { "MATHEMATICAL SANS-SERIF BOLD THETA SYMBOL","	# <font> 03D1 greek theta symbol"},
/* 1D78C */ { "MATHEMATICAL SANS-SERIF BOLD KAPPA SYMBOL","	# <font> 03F0 greek kappa symbol"},
/* 1D78D */ { "MATHEMATICAL SANS-SERIF BOLD PHI SYMBOL","	# <font> 03D5 greek phi symbol"},
/* 1D78E */ { "MATHEMATICAL SANS-SERIF BOLD RHO SYMBOL","	# <font> 03F1 greek rho symbol"},
/* 1D78F */ { "MATHEMATICAL SANS-SERIF BOLD PI SYMBOL","	# <font> 03D6 greek pi symbol"},
/* 1D790 */ { "MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL ALPHA","	# <font> 0391 greek capital letter alpha"},
/* 1D791 */ { "MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL BETA","	# <font> 0392 greek capital letter beta"},
/* 1D792 */ { "MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL GAMMA","	# <font> 0393 greek capital letter gamma"},
/* 1D793 */ { "MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL DELTA","	# <font> 0394 greek capital letter delta"},
/* 1D794 */ { "MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL EPSILON","	# <font> 0395 greek capital letter epsilon"},
/* 1D795 */ { "MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL ZETA","	# <font> 0396 greek capital letter zeta"},
/* 1D796 */ { "MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL ETA","	# <font> 0397 greek capital letter eta"},
/* 1D797 */ { "MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL THETA","	# <font> 0398 greek capital letter theta"},
/* 1D798 */ { "MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL IOTA","	# <font> 0399 greek capital letter iota"},
/* 1D799 */ { "MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL KAPPA","	# <font> 039A greek capital letter kappa"},
/* 1D79A */ { "MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL LAMDA","	# <font> 039B greek capital letter lamda"},
/* 1D79B */ { "MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL MU","	# <font> 039C greek capital letter mu"},
/* 1D79C */ { "MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL NU","	# <font> 039D greek capital letter nu"},
/* 1D79D */ { "MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL XI","	# <font> 039E greek capital letter xi"},
/* 1D79E */ { "MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL OMICRON","	# <font> 039F greek capital letter omicron"},
/* 1D79F */ { "MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL PI","	# <font> 03A0 greek capital letter pi"},
/* 1D7A0 */ { "MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL RHO","	# <font> 03A1 greek capital letter rho"},
/* 1D7A1 */ { "MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL THETA SYMBOL","	# <font> 03F4 greek capital theta symbol"},
/* 1D7A2 */ { "MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL SIGMA","	# <font> 03A3 greek capital letter sigma"},
/* 1D7A3 */ { "MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL TAU","	# <font> 03A4 greek capital letter tau"},
/* 1D7A4 */ { "MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL UPSILON","	# <font> 03A5 greek capital letter upsilon"},
/* 1D7A5 */ { "MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL PHI","	# <font> 03A6 greek capital letter phi"},
/* 1D7A6 */ { "MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL CHI","	# <font> 03A7 greek capital letter chi"},
/* 1D7A7 */ { "MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL PSI","	# <font> 03A8 greek capital letter psi"},
/* 1D7A8 */ { "MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL OMEGA","	# <font> 03A9 greek capital letter omega"},
/* 1D7A9 */ { "MATHEMATICAL SANS-SERIF BOLD ITALIC NABLA","	# <font> 2207 nabla"},
/* 1D7AA */ { "MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL ALPHA","	# <font> 03B1 greek small letter alpha"},
/* 1D7AB */ { "MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL BETA","	# <font> 03B2 greek small letter beta"},
/* 1D7AC */ { "MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL GAMMA","	# <font> 03B3 greek small letter gamma"},
/* 1D7AD */ { "MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL DELTA","	# <font> 03B4 greek small letter delta"},
/* 1D7AE */ { "MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL EPSILON","	# <font> 03B5 greek small letter epsilon"},
/* 1D7AF */ { "MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL ZETA","	# <font> 03B6 greek small letter zeta"},
/* 1D7B0 */ { "MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL ETA","	# <font> 03B7 greek small letter eta"},
/* 1D7B1 */ { "MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL THETA","	# <font> 03B8 greek small letter theta"},
/* 1D7B2 */ { "MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL IOTA","	# <font> 03B9 greek small letter iota"},
/* 1D7B3 */ { "MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL KAPPA","	# <font> 03BA greek small letter kappa"},
/* 1D7B4 */ { "MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL LAMDA","	# <font> 03BB greek small letter lamda"},
/* 1D7B5 */ { "MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL MU","	# <font> 03BC greek small letter mu"},
/* 1D7B6 */ { "MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL NU","	# <font> 03BD greek small letter nu"},
/* 1D7B7 */ { "MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL XI","	# <font> 03BE greek small letter xi"},
/* 1D7B8 */ { "MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL OMICRON","	# <font> 03BF greek small letter omicron"},
/* 1D7B9 */ { "MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL PI","	# <font> 03C0 greek small letter pi"},
/* 1D7BA */ { "MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL RHO","	# <font> 03C1 greek small letter rho"},
/* 1D7BB */ { "MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL FINAL SIGMA","	# <font> 03C2 greek small letter final sigma"},
/* 1D7BC */ { "MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL SIGMA","	# <font> 03C3 greek small letter sigma"},
/* 1D7BD */ { "MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL TAU","	# <font> 03C4 greek small letter tau"},
/* 1D7BE */ { "MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL UPSILON","	# <font> 03C5 greek small letter upsilon"},
/* 1D7BF */ { "MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL PHI","	# <font> 03C6 greek small letter phi"},
/* 1D7C0 */ { "MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL CHI","	# <font> 03C7 greek small letter chi"},
/* 1D7C1 */ { "MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL PSI","	# <font> 03C8 greek small letter psi"},
/* 1D7C2 */ { "MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL OMEGA","	# <font> 03C9 greek small letter omega"},
/* 1D7C3 */ { "MATHEMATICAL SANS-SERIF BOLD ITALIC PARTIAL DIFFERENTIAL","	# <font> 2202 partial differential"},
/* 1D7C4 */ { "MATHEMATICAL SANS-SERIF BOLD ITALIC EPSILON SYMBOL","	# <font> 03F5 greek lunate epsilon symbol"},
/* 1D7C5 */ { "MATHEMATICAL SANS-SERIF BOLD ITALIC THETA SYMBOL","	# <font> 03D1 greek theta symbol"},
/* 1D7C6 */ { "MATHEMATICAL SANS-SERIF BOLD ITALIC KAPPA SYMBOL","	# <font> 03F0 greek kappa symbol"},
/* 1D7C7 */ { "MATHEMATICAL SANS-SERIF BOLD ITALIC PHI SYMBOL","	# <font> 03D5 greek phi symbol"},
/* 1D7C8 */ { "MATHEMATICAL SANS-SERIF BOLD ITALIC RHO SYMBOL","	# <font> 03F1 greek rho symbol"},
/* 1D7C9 */ { "MATHEMATICAL SANS-SERIF BOLD ITALIC PI SYMBOL","	# <font> 03D6 greek pi symbol"},
/* 1D7CA */ { "MATHEMATICAL BOLD CAPITAL DIGAMMA","	# <font> 03DC greek letter digamma"},
/* 1D7CB */ { "MATHEMATICAL BOLD SMALL DIGAMMA","	# <font> 03DD greek small letter digamma"},
/* 1D7CC */ { NULL,NULL},
/* 1D7CD */ { NULL,NULL},
/* 1D7CE */ { "MATHEMATICAL BOLD DIGIT ZERO","	# <font> 0030 digit zero"},
/* 1D7CF */ { "MATHEMATICAL BOLD DIGIT ONE","	# <font> 0031 digit one"},
/* 1D7D0 */ { "MATHEMATICAL BOLD DIGIT TWO","	# <font> 0032 digit two"},
/* 1D7D1 */ { "MATHEMATICAL BOLD DIGIT THREE","	# <font> 0033 digit three"},
/* 1D7D2 */ { "MATHEMATICAL BOLD DIGIT FOUR","	# <font> 0034 digit four"},
/* 1D7D3 */ { "MATHEMATICAL BOLD DIGIT FIVE","	# <font> 0035 digit five"},
/* 1D7D4 */ { "MATHEMATICAL BOLD DIGIT SIX","	# <font> 0036 digit six"},
/* 1D7D5 */ { "MATHEMATICAL BOLD DIGIT SEVEN","	# <font> 0037 digit seven"},
/* 1D7D6 */ { "MATHEMATICAL BOLD DIGIT EIGHT","	# <font> 0038 digit eight"},
/* 1D7D7 */ { "MATHEMATICAL BOLD DIGIT NINE","	# <font> 0039 digit nine"},
/* 1D7D8 */ { "MATHEMATICAL DOUBLE-STRUCK DIGIT ZERO","	# <font> 0030 digit zero"},
/* 1D7D9 */ { "MATHEMATICAL DOUBLE-STRUCK DIGIT ONE","	# <font> 0031 digit one"},
/* 1D7DA */ { "MATHEMATICAL DOUBLE-STRUCK DIGIT TWO","	# <font> 0032 digit two"},
/* 1D7DB */ { "MATHEMATICAL DOUBLE-STRUCK DIGIT THREE","	# <font> 0033 digit three"},
/* 1D7DC */ { "MATHEMATICAL DOUBLE-STRUCK DIGIT FOUR","	# <font> 0034 digit four"},
/* 1D7DD */ { "MATHEMATICAL DOUBLE-STRUCK DIGIT FIVE","	# <font> 0035 digit five"},
/* 1D7DE */ { "MATHEMATICAL DOUBLE-STRUCK DIGIT SIX","	# <font> 0036 digit six"},
/* 1D7DF */ { "MATHEMATICAL DOUBLE-STRUCK DIGIT SEVEN","	# <font> 0037 digit seven"},
/* 1D7E0 */ { "MATHEMATICAL DOUBLE-STRUCK DIGIT EIGHT","	# <font> 0038 digit eight"},
/* 1D7E1 */ { "MATHEMATICAL DOUBLE-STRUCK DIGIT NINE","	# <font> 0039 digit nine"},
/* 1D7E2 */ { "MATHEMATICAL SANS-SERIF DIGIT ZERO","	# <font> 0030 digit zero"},
/* 1D7E3 */ { "MATHEMATICAL SANS-SERIF DIGIT ONE","	# <font> 0031 digit one"},
/* 1D7E4 */ { "MATHEMATICAL SANS-SERIF DIGIT TWO","	# <font> 0032 digit two"},
/* 1D7E5 */ { "MATHEMATICAL SANS-SERIF DIGIT THREE","	# <font> 0033 digit three"},
/* 1D7E6 */ { "MATHEMATICAL SANS-SERIF DIGIT FOUR","	# <font> 0034 digit four"},
/* 1D7E7 */ { "MATHEMATICAL SANS-SERIF DIGIT FIVE","	# <font> 0035 digit five"},
/* 1D7E8 */ { "MATHEMATICAL SANS-SERIF DIGIT SIX","	# <font> 0036 digit six"},
/* 1D7E9 */ { "MATHEMATICAL SANS-SERIF DIGIT SEVEN","	# <font> 0037 digit seven"},
/* 1D7EA */ { "MATHEMATICAL SANS-SERIF DIGIT EIGHT","	# <font> 0038 digit eight"},
/* 1D7EB */ { "MATHEMATICAL SANS-SERIF DIGIT NINE","	# <font> 0039 digit nine"},
/* 1D7EC */ { "MATHEMATICAL SANS-SERIF BOLD DIGIT ZERO","	# <font> 0030 digit zero"},
/* 1D7ED */ { "MATHEMATICAL SANS-SERIF BOLD DIGIT ONE","	# <font> 0031 digit one"},
/* 1D7EE */ { "MATHEMATICAL SANS-SERIF BOLD DIGIT TWO","	# <font> 0032 digit two"},
/* 1D7EF */ { "MATHEMATICAL SANS-SERIF BOLD DIGIT THREE","	# <font> 0033 digit three"},
/* 1D7F0 */ { "MATHEMATICAL SANS-SERIF BOLD DIGIT FOUR","	# <font> 0034 digit four"},
/* 1D7F1 */ { "MATHEMATICAL SANS-SERIF BOLD DIGIT FIVE","	# <font> 0035 digit five"},
/* 1D7F2 */ { "MATHEMATICAL SANS-SERIF BOLD DIGIT SIX","	# <font> 0036 digit six"},
/* 1D7F3 */ { "MATHEMATICAL SANS-SERIF BOLD DIGIT SEVEN","	# <font> 0037 digit seven"},
/* 1D7F4 */ { "MATHEMATICAL SANS-SERIF BOLD DIGIT EIGHT","	# <font> 0038 digit eight"},
/* 1D7F5 */ { "MATHEMATICAL SANS-SERIF BOLD DIGIT NINE","	# <font> 0039 digit nine"},
/* 1D7F6 */ { "MATHEMATICAL MONOSPACE DIGIT ZERO","	# <font> 0030 digit zero"},
/* 1D7F7 */ { "MATHEMATICAL MONOSPACE DIGIT ONE","	# <font> 0031 digit one"},
/* 1D7F8 */ { "MATHEMATICAL MONOSPACE DIGIT TWO","	# <font> 0032 digit two"},
/* 1D7F9 */ { "MATHEMATICAL MONOSPACE DIGIT THREE","	# <font> 0033 digit three"},
/* 1D7FA */ { "MATHEMATICAL MONOSPACE DIGIT FOUR","	# <font> 0034 digit four"},
/* 1D7FB */ { "MATHEMATICAL MONOSPACE DIGIT FIVE","	# <font> 0035 digit five"},
/* 1D7FC */ { "MATHEMATICAL MONOSPACE DIGIT SIX","	# <font> 0036 digit six"},
/* 1D7FD */ { "MATHEMATICAL MONOSPACE DIGIT SEVEN","	# <font> 0037 digit seven"},
/* 1D7FE */ { "MATHEMATICAL MONOSPACE DIGIT EIGHT","	# <font> 0038 digit eight"},
/* 1D7FF */ { "MATHEMATICAL MONOSPACE DIGIT NINE","	# <font> 0039 digit nine"}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_D8[] = {
/* 1D800 */ { "SIGNWRITING HAND-FIST INDEX",NULL},
/* 1D801 */ { "SIGNWRITING HAND-CIRCLE INDEX",NULL},
/* 1D802 */ { "SIGNWRITING HAND-CUP INDEX",NULL},
/* 1D803 */ { "SIGNWRITING HAND-OVAL INDEX",NULL},
/* 1D804 */ { "SIGNWRITING HAND-HINGE INDEX",NULL},
/* 1D805 */ { "SIGNWRITING HAND-ANGLE INDEX",NULL},
/* 1D806 */ { "SIGNWRITING HAND-FIST INDEX BENT",NULL},
/* 1D807 */ { "SIGNWRITING HAND-CIRCLE INDEX BENT",NULL},
/* 1D808 */ { "SIGNWRITING HAND-FIST THUMB UNDER INDEX BENT",NULL},
/* 1D809 */ { "SIGNWRITING HAND-FIST INDEX RAISED KNUCKLE",NULL},
/* 1D80A */ { "SIGNWRITING HAND-FIST INDEX CUPPED",NULL},
/* 1D80B */ { "SIGNWRITING HAND-FIST INDEX HINGED",NULL},
/* 1D80C */ { "SIGNWRITING HAND-FIST INDEX HINGED LOW",NULL},
/* 1D80D */ { "SIGNWRITING HAND-CIRCLE INDEX HINGE",NULL},
/* 1D80E */ { "SIGNWRITING HAND-FIST INDEX MIDDLE",NULL},
/* 1D80F */ { "SIGNWRITING HAND-CIRCLE INDEX MIDDLE",NULL},
/* 1D810 */ { "SIGNWRITING HAND-FIST INDEX MIDDLE BENT",NULL},
/* 1D811 */ { "SIGNWRITING HAND-FIST INDEX MIDDLE RAISED KNUCKLES",NULL},
/* 1D812 */ { "SIGNWRITING HAND-FIST INDEX MIDDLE HINGED",NULL},
/* 1D813 */ { "SIGNWRITING HAND-FIST INDEX UP MIDDLE HINGED",NULL},
/* 1D814 */ { "SIGNWRITING HAND-FIST INDEX HINGED MIDDLE UP",NULL},
/* 1D815 */ { "SIGNWRITING HAND-FIST INDEX MIDDLE CONJOINED",NULL},
/* 1D816 */ { "SIGNWRITING HAND-FIST INDEX MIDDLE CONJOINED INDEX BENT",NULL},
/* 1D817 */ { "SIGNWRITING HAND-FIST INDEX MIDDLE CONJOINED MIDDLE BENT",NULL},
/* 1D818 */ { "SIGNWRITING HAND-FIST INDEX MIDDLE CONJOINED CUPPED",NULL},
/* 1D819 */ { "SIGNWRITING HAND-FIST INDEX MIDDLE CONJOINED HINGED",NULL},
/* 1D81A */ { "SIGNWRITING HAND-FIST INDEX MIDDLE CROSSED",NULL},
/* 1D81B */ { "SIGNWRITING HAND-CIRCLE INDEX MIDDLE CROSSED",NULL},
/* 1D81C */ { "SIGNWRITING HAND-FIST MIDDLE BENT OVER INDEX",NULL},
/* 1D81D */ { "SIGNWRITING HAND-FIST INDEX BENT OVER MIDDLE",NULL},
/* 1D81E */ { "SIGNWRITING HAND-FIST INDEX MIDDLE THUMB",NULL},
/* 1D81F */ { "SIGNWRITING HAND-CIRCLE INDEX MIDDLE THUMB",NULL},
/* 1D820 */ { "SIGNWRITING HAND-FIST INDEX MIDDLE STRAIGHT THUMB BENT",NULL},
/* 1D821 */ { "SIGNWRITING HAND-FIST INDEX MIDDLE BENT THUMB STRAIGHT",NULL},
/* 1D822 */ { "SIGNWRITING HAND-FIST INDEX MIDDLE THUMB BENT",NULL},
/* 1D823 */ { "SIGNWRITING HAND-FIST INDEX MIDDLE HINGED SPREAD THUMB SIDE",NULL},
/* 1D824 */ { "SIGNWRITING HAND-FIST INDEX UP MIDDLE HINGED THUMB SIDE",NULL},
/* 1D825 */ { "SIGNWRITING HAND-FIST INDEX UP MIDDLE HINGED THUMB CONJOINED",NULL},
/* 1D826 */ { "SIGNWRITING HAND-FIST INDEX HINGED MIDDLE UP THUMB SIDE",NULL},
/* 1D827 */ { "SIGNWRITING HAND-FIST INDEX MIDDLE UP SPREAD THUMB FORWARD",NULL},
/* 1D828 */ { "SIGNWRITING HAND-FIST INDEX MIDDLE THUMB CUPPED",NULL},
/* 1D829 */ { "SIGNWRITING HAND-FIST INDEX MIDDLE THUMB CIRCLED",NULL},
/* 1D82A */ { "SIGNWRITING HAND-FIST INDEX MIDDLE THUMB HOOKED",NULL},
/* 1D82B */ { "SIGNWRITING HAND-FIST INDEX MIDDLE THUMB HINGED",NULL},
/* 1D82C */ { "SIGNWRITING HAND-FIST THUMB BETWEEN INDEX MIDDLE STRAIGHT",NULL},
/* 1D82D */ { "SIGNWRITING HAND-FIST INDEX MIDDLE CONJOINED THUMB SIDE",NULL},
/* 1D82E */ { "SIGNWRITING HAND-FIST INDEX MIDDLE CONJOINED THUMB SIDE CONJOINED",NULL},
/* 1D82F */ { "SIGNWRITING HAND-FIST INDEX MIDDLE CONJOINED THUMB SIDE BENT",NULL},
/* 1D830 */ { "SIGNWRITING HAND-FIST MIDDLE THUMB HOOKED INDEX UP",NULL},
/* 1D831 */ { "SIGNWRITING HAND-FIST INDEX THUMB HOOKED MIDDLE UP",NULL},
/* 1D832 */ { "SIGNWRITING HAND-FIST INDEX MIDDLE CONJOINED HINGED THUMB SIDE",NULL},
/* 1D833 */ { "SIGNWRITING HAND-FIST INDEX MIDDLE CROSSED THUMB SIDE",NULL},
/* 1D834 */ { "SIGNWRITING HAND-FIST INDEX MIDDLE CONJOINED THUMB FORWARD",NULL},
/* 1D835 */ { "SIGNWRITING HAND-FIST INDEX MIDDLE CONJOINED CUPPED THUMB FORWARD",NULL},
/* 1D836 */ { "SIGNWRITING HAND-FIST MIDDLE THUMB CUPPED INDEX UP",NULL},
/* 1D837 */ { "SIGNWRITING HAND-FIST INDEX THUMB CUPPED MIDDLE UP",NULL},
/* 1D838 */ { "SIGNWRITING HAND-FIST MIDDLE THUMB CIRCLED INDEX UP",NULL},
/* 1D839 */ { "SIGNWRITING HAND-FIST MIDDLE THUMB CIRCLED INDEX HINGED",NULL},
/* 1D83A */ { "SIGNWRITING HAND-FIST INDEX THUMB ANGLED OUT MIDDLE UP",NULL},
/* 1D83B */ { "SIGNWRITING HAND-FIST INDEX THUMB ANGLED IN MIDDLE UP",NULL},
/* 1D83C */ { "SIGNWRITING HAND-FIST INDEX THUMB CIRCLED MIDDLE UP",NULL},
/* 1D83D */ { "SIGNWRITING HAND-FIST INDEX MIDDLE THUMB CONJOINED HINGED",NULL},
/* 1D83E */ { "SIGNWRITING HAND-FIST INDEX MIDDLE THUMB ANGLED OUT",NULL},
/* 1D83F */ { "SIGNWRITING HAND-FIST INDEX MIDDLE THUMB ANGLED",NULL},
/* 1D840 */ { "SIGNWRITING HAND-FIST MIDDLE THUMB ANGLED OUT INDEX UP",NULL},
/* 1D841 */ { "SIGNWRITING HAND-FIST MIDDLE THUMB ANGLED OUT INDEX CROSSED",NULL},
/* 1D842 */ { "SIGNWRITING HAND-FIST MIDDLE THUMB ANGLED INDEX UP",NULL},
/* 1D843 */ { "SIGNWRITING HAND-FIST INDEX THUMB HOOKED MIDDLE HINGED",NULL},
/* 1D844 */ { "SIGNWRITING HAND-FLAT FOUR FINGERS",NULL},
/* 1D845 */ { "SIGNWRITING HAND-FLAT FOUR FINGERS BENT",NULL},
/* 1D846 */ { "SIGNWRITING HAND-FLAT FOUR FINGERS HINGED",NULL},
/* 1D847 */ { "SIGNWRITING HAND-FLAT FOUR FINGERS CONJOINED",NULL},
/* 1D848 */ { "SIGNWRITING HAND-FLAT FOUR FINGERS CONJOINED SPLIT",NULL},
/* 1D849 */ { "SIGNWRITING HAND-CLAW FOUR FINGERS CONJOINED",NULL},
/* 1D84A */ { "SIGNWRITING HAND-FIST FOUR FINGERS CONJOINED BENT",NULL},
/* 1D84B */ { "SIGNWRITING HAND-HINGE FOUR FINGERS CONJOINED",NULL},
/* 1D84C */ { "SIGNWRITING HAND-FLAT FIVE FINGERS SPREAD",NULL},
/* 1D84D */ { "SIGNWRITING HAND-FLAT HEEL FIVE FINGERS SPREAD",NULL},
/* 1D84E */ { "SIGNWRITING HAND-FLAT FIVE FINGERS SPREAD FOUR BENT",NULL},
/* 1D84F */ { "SIGNWRITING HAND-FLAT HEEL FIVE FINGERS SPREAD FOUR BENT",NULL},
/* 1D850 */ { "SIGNWRITING HAND-FLAT FIVE FINGERS SPREAD BENT",NULL},
/* 1D851 */ { "SIGNWRITING HAND-FLAT HEEL FIVE FINGERS SPREAD BENT",NULL},
/* 1D852 */ { "SIGNWRITING HAND-FLAT FIVE FINGERS SPREAD THUMB FORWARD",NULL},
/* 1D853 */ { "SIGNWRITING HAND-CUP FIVE FINGERS SPREAD",NULL},
/* 1D854 */ { "SIGNWRITING HAND-CUP FIVE FINGERS SPREAD OPEN",NULL},
/* 1D855 */ { "SIGNWRITING HAND-HINGE FIVE FINGERS SPREAD OPEN",NULL},
/* 1D856 */ { "SIGNWRITING HAND-OVAL FIVE FINGERS SPREAD",NULL},
/* 1D857 */ { "SIGNWRITING HAND-FLAT FIVE FINGERS SPREAD HINGED",NULL},
/* 1D858 */ { "SIGNWRITING HAND-FLAT FIVE FINGERS SPREAD HINGED THUMB SIDE",NULL},
/* 1D859 */ { "SIGNWRITING HAND-FLAT FIVE FINGERS SPREAD HINGED NO THUMB",NULL},
/* 1D85A */ { "SIGNWRITING HAND-FLAT",NULL},
/* 1D85B */ { "SIGNWRITING HAND-FLAT BETWEEN PALM FACINGS",NULL},
/* 1D85C */ { "SIGNWRITING HAND-FLAT HEEL",NULL},
/* 1D85D */ { "SIGNWRITING HAND-FLAT THUMB SIDE",NULL},
/* 1D85E */ { "SIGNWRITING HAND-FLAT HEEL THUMB SIDE",NULL},
/* 1D85F */ { "SIGNWRITING HAND-FLAT THUMB BENT",NULL},
/* 1D860 */ { "SIGNWRITING HAND-FLAT THUMB FORWARD",NULL},
/* 1D861 */ { "SIGNWRITING HAND-FLAT SPLIT INDEX THUMB SIDE",NULL},
/* 1D862 */ { "SIGNWRITING HAND-FLAT SPLIT CENTRE",NULL},
/* 1D863 */ { "SIGNWRITING HAND-FLAT SPLIT CENTRE THUMB SIDE",NULL},
/* 1D864 */ { "SIGNWRITING HAND-FLAT SPLIT CENTRE THUMB SIDE BENT",NULL},
/* 1D865 */ { "SIGNWRITING HAND-FLAT SPLIT LITTLE",NULL},
/* 1D866 */ { "SIGNWRITING HAND-CLAW",NULL},
/* 1D867 */ { "SIGNWRITING HAND-CLAW THUMB SIDE",NULL},
/* 1D868 */ { "SIGNWRITING HAND-CLAW NO THUMB",NULL},
/* 1D869 */ { "SIGNWRITING HAND-CLAW THUMB FORWARD",NULL},
/* 1D86A */ { "SIGNWRITING HAND-HOOK CURLICUE",NULL},
/* 1D86B */ { "SIGNWRITING HAND-HOOK",NULL},
/* 1D86C */ { "SIGNWRITING HAND-CUP OPEN",NULL},
/* 1D86D */ { "SIGNWRITING HAND-CUP",NULL},
/* 1D86E */ { "SIGNWRITING HAND-CUP OPEN THUMB SIDE",NULL},
/* 1D86F */ { "SIGNWRITING HAND-CUP THUMB SIDE",NULL},
/* 1D870 */ { "SIGNWRITING HAND-CUP OPEN NO THUMB",NULL},
/* 1D871 */ { "SIGNWRITING HAND-CUP NO THUMB",NULL},
/* 1D872 */ { "SIGNWRITING HAND-CUP OPEN THUMB FORWARD",NULL},
/* 1D873 */ { "SIGNWRITING HAND-CUP THUMB FORWARD",NULL},
/* 1D874 */ { "SIGNWRITING HAND-CURLICUE OPEN",NULL},
/* 1D875 */ { "SIGNWRITING HAND-CURLICUE",NULL},
/* 1D876 */ { "SIGNWRITING HAND-CIRCLE",NULL},
/* 1D877 */ { "SIGNWRITING HAND-OVAL",NULL},
/* 1D878 */ { "SIGNWRITING HAND-OVAL THUMB SIDE",NULL},
/* 1D879 */ { "SIGNWRITING HAND-OVAL NO THUMB",NULL},
/* 1D87A */ { "SIGNWRITING HAND-OVAL THUMB FORWARD",NULL},
/* 1D87B */ { "SIGNWRITING HAND-HINGE OPEN",NULL},
/* 1D87C */ { "SIGNWRITING HAND-HINGE OPEN THUMB FORWARD",NULL},
/* 1D87D */ { "SIGNWRITING HAND-HINGE",NULL},
/* 1D87E */ { "SIGNWRITING HAND-HINGE SMALL",NULL},
/* 1D87F */ { "SIGNWRITING HAND-HINGE OPEN THUMB SIDE",NULL},
/* 1D880 */ { "SIGNWRITING HAND-HINGE THUMB SIDE",NULL},
/* 1D881 */ { "SIGNWRITING HAND-HINGE OPEN NO THUMB",NULL},
/* 1D882 */ { "SIGNWRITING HAND-HINGE NO THUMB",NULL},
/* 1D883 */ { "SIGNWRITING HAND-HINGE THUMB SIDE TOUCHING INDEX",NULL},
/* 1D884 */ { "SIGNWRITING HAND-HINGE THUMB BETWEEN MIDDLE RING",NULL},
/* 1D885 */ { "SIGNWRITING HAND-ANGLE",NULL},
/* 1D886 */ { "SIGNWRITING HAND-FIST INDEX MIDDLE RING",NULL},
/* 1D887 */ { "SIGNWRITING HAND-CIRCLE INDEX MIDDLE RING",NULL},
/* 1D888 */ { "SIGNWRITING HAND-HINGE INDEX MIDDLE RING",NULL},
/* 1D889 */ { "SIGNWRITING HAND-ANGLE INDEX MIDDLE RING",NULL},
/* 1D88A */ { "SIGNWRITING HAND-HINGE LITTLE",NULL},
/* 1D88B */ { "SIGNWRITING HAND-FIST INDEX MIDDLE RING BENT",NULL},
/* 1D88C */ { "SIGNWRITING HAND-FIST INDEX MIDDLE RING CONJOINED",NULL},
/* 1D88D */ { "SIGNWRITING HAND-HINGE INDEX MIDDLE RING CONJOINED",NULL},
/* 1D88E */ { "SIGNWRITING HAND-FIST LITTLE DOWN",NULL},
/* 1D88F */ { "SIGNWRITING HAND-FIST LITTLE DOWN RIPPLE STRAIGHT",NULL},
/* 1D890 */ { "SIGNWRITING HAND-FIST LITTLE DOWN RIPPLE CURVED",NULL},
/* 1D891 */ { "SIGNWRITING HAND-FIST LITTLE DOWN OTHERS CIRCLED",NULL},
/* 1D892 */ { "SIGNWRITING HAND-FIST LITTLE UP",NULL},
/* 1D893 */ { "SIGNWRITING HAND-FIST THUMB UNDER LITTLE UP",NULL},
/* 1D894 */ { "SIGNWRITING HAND-CIRCLE LITTLE UP",NULL},
/* 1D895 */ { "SIGNWRITING HAND-OVAL LITTLE UP",NULL},
/* 1D896 */ { "SIGNWRITING HAND-ANGLE LITTLE UP",NULL},
/* 1D897 */ { "SIGNWRITING HAND-FIST LITTLE RAISED KNUCKLE",NULL},
/* 1D898 */ { "SIGNWRITING HAND-FIST LITTLE BENT",NULL},
/* 1D899 */ { "SIGNWRITING HAND-FIST LITTLE TOUCHES THUMB",NULL},
/* 1D89A */ { "SIGNWRITING HAND-FIST LITTLE THUMB",NULL},
/* 1D89B */ { "SIGNWRITING HAND-HINGE LITTLE THUMB",NULL},
/* 1D89C */ { "SIGNWRITING HAND-FIST LITTLE INDEX THUMB",NULL},
/* 1D89D */ { "SIGNWRITING HAND-HINGE LITTLE INDEX THUMB",NULL},
/* 1D89E */ { "SIGNWRITING HAND-ANGLE LITTLE INDEX THUMB INDEX THUMB OUT",NULL},
/* 1D89F */ { "SIGNWRITING HAND-ANGLE LITTLE INDEX THUMB INDEX THUMB",NULL},
/* 1D8A0 */ { "SIGNWRITING HAND-FIST LITTLE INDEX",NULL},
/* 1D8A1 */ { "SIGNWRITING HAND-CIRCLE LITTLE INDEX",NULL},
/* 1D8A2 */ { "SIGNWRITING HAND-HINGE LITTLE INDEX",NULL},
/* 1D8A3 */ { "SIGNWRITING HAND-ANGLE LITTLE INDEX",NULL},
/* 1D8A4 */ { "SIGNWRITING HAND-FIST INDEX MIDDLE LITTLE",NULL},
/* 1D8A5 */ { "SIGNWRITING HAND-CIRCLE INDEX MIDDLE LITTLE",NULL},
/* 1D8A6 */ { "SIGNWRITING HAND-HINGE INDEX MIDDLE LITTLE",NULL},
/* 1D8A7 */ { "SIGNWRITING HAND-HINGE RING",NULL},
/* 1D8A8 */ { "SIGNWRITING HAND-ANGLE INDEX MIDDLE LITTLE",NULL},
/* 1D8A9 */ { "SIGNWRITING HAND-FIST INDEX MIDDLE CROSS LITTLE",NULL},
/* 1D8AA */ { "SIGNWRITING HAND-CIRCLE INDEX MIDDLE CROSS LITTLE",NULL},
/* 1D8AB */ { "SIGNWRITING HAND-FIST RING DOWN",NULL},
/* 1D8AC */ { "SIGNWRITING HAND-HINGE RING DOWN INDEX THUMB HOOK MIDDLE",NULL},
/* 1D8AD */ { "SIGNWRITING HAND-ANGLE RING DOWN MIDDLE THUMB INDEX CROSS",NULL},
/* 1D8AE */ { "SIGNWRITING HAND-FIST RING UP",NULL},
/* 1D8AF */ { "SIGNWRITING HAND-FIST RING RAISED KNUCKLE",NULL},
/* 1D8B0 */ { "SIGNWRITING HAND-FIST RING LITTLE",NULL},
/* 1D8B1 */ { "SIGNWRITING HAND-CIRCLE RING LITTLE",NULL},
/* 1D8B2 */ { "SIGNWRITING HAND-OVAL RING LITTLE",NULL},
/* 1D8B3 */ { "SIGNWRITING HAND-ANGLE RING LITTLE",NULL},
/* 1D8B4 */ { "SIGNWRITING HAND-FIST RING MIDDLE",NULL},
/* 1D8B5 */ { "SIGNWRITING HAND-FIST RING MIDDLE CONJOINED",NULL},
/* 1D8B6 */ { "SIGNWRITING HAND-FIST RING MIDDLE RAISED KNUCKLES",NULL},
/* 1D8B7 */ { "SIGNWRITING HAND-FIST RING INDEX",NULL},
/* 1D8B8 */ { "SIGNWRITING HAND-FIST RING THUMB",NULL},
/* 1D8B9 */ { "SIGNWRITING HAND-HOOK RING THUMB",NULL},
/* 1D8BA */ { "SIGNWRITING HAND-FIST INDEX RING LITTLE",NULL},
/* 1D8BB */ { "SIGNWRITING HAND-CIRCLE INDEX RING LITTLE",NULL},
/* 1D8BC */ { "SIGNWRITING HAND-CURLICUE INDEX RING LITTLE ON",NULL},
/* 1D8BD */ { "SIGNWRITING HAND-HOOK INDEX RING LITTLE OUT",NULL},
/* 1D8BE */ { "SIGNWRITING HAND-HOOK INDEX RING LITTLE IN",NULL},
/* 1D8BF */ { "SIGNWRITING HAND-HOOK INDEX RING LITTLE UNDER",NULL},
/* 1D8C0 */ { "SIGNWRITING HAND-CUP INDEX RING LITTLE",NULL},
/* 1D8C1 */ { "SIGNWRITING HAND-HINGE INDEX RING LITTLE",NULL},
/* 1D8C2 */ { "SIGNWRITING HAND-ANGLE INDEX RING LITTLE OUT",NULL},
/* 1D8C3 */ { "SIGNWRITING HAND-ANGLE INDEX RING LITTLE",NULL},
/* 1D8C4 */ { "SIGNWRITING HAND-FIST MIDDLE DOWN",NULL},
/* 1D8C5 */ { "SIGNWRITING HAND-HINGE MIDDLE",NULL},
/* 1D8C6 */ { "SIGNWRITING HAND-FIST MIDDLE UP",NULL},
/* 1D8C7 */ { "SIGNWRITING HAND-CIRCLE MIDDLE UP",NULL},
/* 1D8C8 */ { "SIGNWRITING HAND-FIST MIDDLE RAISED KNUCKLE",NULL},
/* 1D8C9 */ { "SIGNWRITING HAND-FIST MIDDLE UP THUMB SIDE",NULL},
/* 1D8CA */ { "SIGNWRITING HAND-HOOK MIDDLE THUMB",NULL},
/* 1D8CB */ { "SIGNWRITING HAND-FIST MIDDLE THUMB LITTLE",NULL},
/* 1D8CC */ { "SIGNWRITING HAND-FIST MIDDLE LITTLE",NULL},
/* 1D8CD */ { "SIGNWRITING HAND-FIST MIDDLE RING LITTLE",NULL},
/* 1D8CE */ { "SIGNWRITING HAND-CIRCLE MIDDLE RING LITTLE",NULL},
/* 1D8CF */ { "SIGNWRITING HAND-CURLICUE MIDDLE RING LITTLE ON",NULL},
/* 1D8D0 */ { "SIGNWRITING HAND-CUP MIDDLE RING LITTLE",NULL},
/* 1D8D1 */ { "SIGNWRITING HAND-HINGE MIDDLE RING LITTLE",NULL},
/* 1D8D2 */ { "SIGNWRITING HAND-ANGLE MIDDLE RING LITTLE OUT",NULL},
/* 1D8D3 */ { "SIGNWRITING HAND-ANGLE MIDDLE RING LITTLE IN",NULL},
/* 1D8D4 */ { "SIGNWRITING HAND-ANGLE MIDDLE RING LITTLE",NULL},
/* 1D8D5 */ { "SIGNWRITING HAND-CIRCLE MIDDLE RING LITTLE BENT",NULL},
/* 1D8D6 */ { "SIGNWRITING HAND-CLAW MIDDLE RING LITTLE CONJOINED",NULL},
/* 1D8D7 */ { "SIGNWRITING HAND-CLAW MIDDLE RING LITTLE CONJOINED SIDE",NULL},
/* 1D8D8 */ { "SIGNWRITING HAND-HOOK MIDDLE RING LITTLE CONJOINED OUT",NULL},
/* 1D8D9 */ { "SIGNWRITING HAND-HOOK MIDDLE RING LITTLE CONJOINED IN",NULL},
/* 1D8DA */ { "SIGNWRITING HAND-HOOK MIDDLE RING LITTLE CONJOINED",NULL},
/* 1D8DB */ { "SIGNWRITING HAND-HINGE INDEX HINGED",NULL},
/* 1D8DC */ { "SIGNWRITING HAND-FIST INDEX THUMB SIDE",NULL},
/* 1D8DD */ { "SIGNWRITING HAND-HINGE INDEX THUMB SIDE",NULL},
/* 1D8DE */ { "SIGNWRITING HAND-FIST INDEX THUMB SIDE THUMB DIAGONAL",NULL},
/* 1D8DF */ { "SIGNWRITING HAND-FIST INDEX THUMB SIDE THUMB CONJOINED",NULL},
/* 1D8E0 */ { "SIGNWRITING HAND-FIST INDEX THUMB SIDE THUMB BENT",NULL},
/* 1D8E1 */ { "SIGNWRITING HAND-FIST INDEX THUMB SIDE INDEX BENT",NULL},
/* 1D8E2 */ { "SIGNWRITING HAND-FIST INDEX THUMB SIDE BOTH BENT",NULL},
/* 1D8E3 */ { "SIGNWRITING HAND-FIST INDEX THUMB SIDE INDEX HINGE",NULL},
/* 1D8E4 */ { "SIGNWRITING HAND-FIST INDEX THUMB FORWARD INDEX STRAIGHT",NULL},
/* 1D8E5 */ { "SIGNWRITING HAND-FIST INDEX THUMB FORWARD INDEX BENT",NULL},
/* 1D8E6 */ { "SIGNWRITING HAND-FIST INDEX THUMB HOOK",NULL},
/* 1D8E7 */ { "SIGNWRITING HAND-FIST INDEX THUMB CURLICUE",NULL},
/* 1D8E8 */ { "SIGNWRITING HAND-FIST INDEX THUMB CURVE THUMB INSIDE",NULL},
/* 1D8E9 */ { "SIGNWRITING HAND-CLAW INDEX THUMB CURVE THUMB INSIDE",NULL},
/* 1D8EA */ { "SIGNWRITING HAND-FIST INDEX THUMB CURVE THUMB UNDER",NULL},
/* 1D8EB */ { "SIGNWRITING HAND-FIST INDEX THUMB CIRCLE",NULL},
/* 1D8EC */ { "SIGNWRITING HAND-CUP INDEX THUMB",NULL},
/* 1D8ED */ { "SIGNWRITING HAND-CUP INDEX THUMB OPEN",NULL},
/* 1D8EE */ { "SIGNWRITING HAND-HINGE INDEX THUMB OPEN",NULL},
/* 1D8EF */ { "SIGNWRITING HAND-HINGE INDEX THUMB LARGE",NULL},
/* 1D8F0 */ { "SIGNWRITING HAND-HINGE INDEX THUMB",NULL},
/* 1D8F1 */ { "SIGNWRITING HAND-HINGE INDEX THUMB SMALL",NULL},
/* 1D8F2 */ { "SIGNWRITING HAND-ANGLE INDEX THUMB OUT",NULL},
/* 1D8F3 */ { "SIGNWRITING HAND-ANGLE INDEX THUMB IN",NULL},
/* 1D8F4 */ { "SIGNWRITING HAND-ANGLE INDEX THUMB",NULL},
/* 1D8F5 */ { "SIGNWRITING HAND-FIST THUMB",NULL},
/* 1D8F6 */ { "SIGNWRITING HAND-FIST THUMB HEEL",NULL},
/* 1D8F7 */ { "SIGNWRITING HAND-FIST THUMB SIDE DIAGONAL",NULL},
/* 1D8F8 */ { "SIGNWRITING HAND-FIST THUMB SIDE CONJOINED",NULL},
/* 1D8F9 */ { "SIGNWRITING HAND-FIST THUMB SIDE BENT",NULL},
/* 1D8FA */ { "SIGNWRITING HAND-FIST THUMB FORWARD",NULL},
/* 1D8FB */ { "SIGNWRITING HAND-FIST THUMB BETWEEN INDEX MIDDLE",NULL},
/* 1D8FC */ { "SIGNWRITING HAND-FIST THUMB BETWEEN MIDDLE RING",NULL},
/* 1D8FD */ { "SIGNWRITING HAND-FIST THUMB BETWEEN RING LITTLE",NULL},
/* 1D8FE */ { "SIGNWRITING HAND-FIST THUMB UNDER TWO FINGERS",NULL},
/* 1D8FF */ { "SIGNWRITING HAND-FIST THUMB OVER TWO FINGERS",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_D9[] = {
/* 1D900 */ { "SIGNWRITING HAND-FIST THUMB UNDER THREE FINGERS",NULL},
/* 1D901 */ { "SIGNWRITING HAND-FIST THUMB UNDER FOUR FINGERS",NULL},
/* 1D902 */ { "SIGNWRITING HAND-FIST THUMB OVER FOUR RAISED KNUCKLES",NULL},
/* 1D903 */ { "SIGNWRITING HAND-FIST",NULL},
/* 1D904 */ { "SIGNWRITING HAND-FIST HEEL",NULL},
/* 1D905 */ { "SIGNWRITING TOUCH SINGLE",NULL},
/* 1D906 */ { "SIGNWRITING TOUCH MULTIPLE",NULL},
/* 1D907 */ { "SIGNWRITING TOUCH BETWEEN",NULL},
/* 1D908 */ { "SIGNWRITING GRASP SINGLE",NULL},
/* 1D909 */ { "SIGNWRITING GRASP MULTIPLE",NULL},
/* 1D90A */ { "SIGNWRITING GRASP BETWEEN",NULL},
/* 1D90B */ { "SIGNWRITING STRIKE SINGLE",NULL},
/* 1D90C */ { "SIGNWRITING STRIKE MULTIPLE",NULL},
/* 1D90D */ { "SIGNWRITING STRIKE BETWEEN",NULL},
/* 1D90E */ { "SIGNWRITING BRUSH SINGLE",NULL},
/* 1D90F */ { "SIGNWRITING BRUSH MULTIPLE",NULL},
/* 1D910 */ { "SIGNWRITING BRUSH BETWEEN",NULL},
/* 1D911 */ { "SIGNWRITING RUB SINGLE",NULL},
/* 1D912 */ { "SIGNWRITING RUB MULTIPLE",NULL},
/* 1D913 */ { "SIGNWRITING RUB BETWEEN",NULL},
/* 1D914 */ { "SIGNWRITING SURFACE SYMBOLS",NULL},
/* 1D915 */ { "SIGNWRITING SURFACE BETWEEN",NULL},
/* 1D916 */ { "SIGNWRITING SQUEEZE LARGE SINGLE",NULL},
/* 1D917 */ { "SIGNWRITING SQUEEZE SMALL SINGLE",NULL},
/* 1D918 */ { "SIGNWRITING SQUEEZE LARGE MULTIPLE",NULL},
/* 1D919 */ { "SIGNWRITING SQUEEZE SMALL MULTIPLE",NULL},
/* 1D91A */ { "SIGNWRITING SQUEEZE SEQUENTIAL",NULL},
/* 1D91B */ { "SIGNWRITING FLICK LARGE SINGLE",NULL},
/* 1D91C */ { "SIGNWRITING FLICK SMALL SINGLE",NULL},
/* 1D91D */ { "SIGNWRITING FLICK LARGE MULTIPLE",NULL},
/* 1D91E */ { "SIGNWRITING FLICK SMALL MULTIPLE",NULL},
/* 1D91F */ { "SIGNWRITING FLICK SEQUENTIAL",NULL},
/* 1D920 */ { "SIGNWRITING SQUEEZE FLICK ALTERNATING",NULL},
/* 1D921 */ { "SIGNWRITING MOVEMENT-HINGE UP DOWN LARGE",NULL},
/* 1D922 */ { "SIGNWRITING MOVEMENT-HINGE UP DOWN SMALL",NULL},
/* 1D923 */ { "SIGNWRITING MOVEMENT-HINGE UP SEQUENTIAL",NULL},
/* 1D924 */ { "SIGNWRITING MOVEMENT-HINGE DOWN SEQUENTIAL",NULL},
/* 1D925 */ { "SIGNWRITING MOVEMENT-HINGE UP DOWN ALTERNATING LARGE",NULL},
/* 1D926 */ { "SIGNWRITING MOVEMENT-HINGE UP DOWN ALTERNATING SMALL",NULL},
/* 1D927 */ { "SIGNWRITING MOVEMENT-HINGE SIDE TO SIDE SCISSORS",NULL},
/* 1D928 */ { "SIGNWRITING MOVEMENT-WALLPLANE FINGER CONTACT",NULL},
/* 1D929 */ { "SIGNWRITING MOVEMENT-FLOORPLANE FINGER CONTACT",NULL},
/* 1D92A */ { "SIGNWRITING MOVEMENT-WALLPLANE SINGLE STRAIGHT SMALL",NULL},
/* 1D92B */ { "SIGNWRITING MOVEMENT-WALLPLANE SINGLE STRAIGHT MEDIUM",NULL},
/* 1D92C */ { "SIGNWRITING MOVEMENT-WALLPLANE SINGLE STRAIGHT LARGE",NULL},
/* 1D92D */ { "SIGNWRITING MOVEMENT-WALLPLANE SINGLE STRAIGHT LARGEST",NULL},
/* 1D92E */ { "SIGNWRITING MOVEMENT-WALLPLANE SINGLE WRIST FLEX",NULL},
/* 1D92F */ { "SIGNWRITING MOVEMENT-WALLPLANE DOUBLE STRAIGHT",NULL},
/* 1D930 */ { "SIGNWRITING MOVEMENT-WALLPLANE DOUBLE WRIST FLEX",NULL},
/* 1D931 */ { "SIGNWRITING MOVEMENT-WALLPLANE DOUBLE ALTERNATING",NULL},
/* 1D932 */ { "SIGNWRITING MOVEMENT-WALLPLANE DOUBLE ALTERNATING WRIST FLEX",NULL},
/* 1D933 */ { "SIGNWRITING MOVEMENT-WALLPLANE CROSS",NULL},
/* 1D934 */ { "SIGNWRITING MOVEMENT-WALLPLANE TRIPLE STRAIGHT MOVEMENT",NULL},
/* 1D935 */ { "SIGNWRITING MOVEMENT-WALLPLANE TRIPLE WRIST FLEX",NULL},
/* 1D936 */ { "SIGNWRITING MOVEMENT-WALLPLANE TRIPLE ALTERNATING",NULL},
/* 1D937 */ { "SIGNWRITING MOVEMENT-WALLPLANE TRIPLE ALTERNATING WRIST FLEX",NULL},
/* 1D938 */ { "SIGNWRITING MOVEMENT-WALLPLANE BEND SMALL",NULL},
/* 1D939 */ { "SIGNWRITING MOVEMENT-WALLPLANE BEND MEDIUM",NULL},
/* 1D93A */ { "SIGNWRITING MOVEMENT-WALLPLANE BEND LARGE",NULL},
/* 1D93B */ { "SIGNWRITING MOVEMENT-WALLPLANE CORNER SMALL",NULL},
/* 1D93C */ { "SIGNWRITING MOVEMENT-WALLPLANE CORNER MEDIUM",NULL},
/* 1D93D */ { "SIGNWRITING MOVEMENT-WALLPLANE CORNER LARGE",NULL},
/* 1D93E */ { "SIGNWRITING MOVEMENT-WALLPLANE CORNER ROTATION",NULL},
/* 1D93F */ { "SIGNWRITING MOVEMENT-WALLPLANE CHECK SMALL",NULL},
/* 1D940 */ { "SIGNWRITING MOVEMENT-WALLPLANE CHECK MEDIUM",NULL},
/* 1D941 */ { "SIGNWRITING MOVEMENT-WALLPLANE CHECK LARGE",NULL},
/* 1D942 */ { "SIGNWRITING MOVEMENT-WALLPLANE BOX SMALL",NULL},
/* 1D943 */ { "SIGNWRITING MOVEMENT-WALLPLANE BOX MEDIUM",NULL},
/* 1D944 */ { "SIGNWRITING MOVEMENT-WALLPLANE BOX LARGE",NULL},
/* 1D945 */ { "SIGNWRITING MOVEMENT-WALLPLANE ZIGZAG SMALL",NULL},
/* 1D946 */ { "SIGNWRITING MOVEMENT-WALLPLANE ZIGZAG MEDIUM",NULL},
/* 1D947 */ { "SIGNWRITING MOVEMENT-WALLPLANE ZIGZAG LARGE",NULL},
/* 1D948 */ { "SIGNWRITING MOVEMENT-WALLPLANE PEAKS SMALL",NULL},
/* 1D949 */ { "SIGNWRITING MOVEMENT-WALLPLANE PEAKS MEDIUM",NULL},
/* 1D94A */ { "SIGNWRITING MOVEMENT-WALLPLANE PEAKS LARGE",NULL},
/* 1D94B */ { "SIGNWRITING TRAVEL-WALLPLANE ROTATION-WALLPLANE SINGLE",NULL},
/* 1D94C */ { "SIGNWRITING TRAVEL-WALLPLANE ROTATION-WALLPLANE DOUBLE",NULL},
/* 1D94D */ { "SIGNWRITING TRAVEL-WALLPLANE ROTATION-WALLPLANE ALTERNATING",NULL},
/* 1D94E */ { "SIGNWRITING TRAVEL-WALLPLANE ROTATION-FLOORPLANE SINGLE",NULL},
/* 1D94F */ { "SIGNWRITING TRAVEL-WALLPLANE ROTATION-FLOORPLANE DOUBLE",NULL},
/* 1D950 */ { "SIGNWRITING TRAVEL-WALLPLANE ROTATION-FLOORPLANE ALTERNATING",NULL},
/* 1D951 */ { "SIGNWRITING TRAVEL-WALLPLANE SHAKING",NULL},
/* 1D952 */ { "SIGNWRITING TRAVEL-WALLPLANE ARM SPIRAL SINGLE",NULL},
/* 1D953 */ { "SIGNWRITING TRAVEL-WALLPLANE ARM SPIRAL DOUBLE",NULL},
/* 1D954 */ { "SIGNWRITING TRAVEL-WALLPLANE ARM SPIRAL TRIPLE",NULL},
/* 1D955 */ { "SIGNWRITING MOVEMENT-DIAGONAL AWAY SMALL",NULL},
/* 1D956 */ { "SIGNWRITING MOVEMENT-DIAGONAL AWAY MEDIUM",NULL},
/* 1D957 */ { "SIGNWRITING MOVEMENT-DIAGONAL AWAY LARGE",NULL},
/* 1D958 */ { "SIGNWRITING MOVEMENT-DIAGONAL AWAY LARGEST",NULL},
/* 1D959 */ { "SIGNWRITING MOVEMENT-DIAGONAL TOWARDS SMALL",NULL},
/* 1D95A */ { "SIGNWRITING MOVEMENT-DIAGONAL TOWARDS MEDIUM",NULL},
/* 1D95B */ { "SIGNWRITING MOVEMENT-DIAGONAL TOWARDS LARGE",NULL},
/* 1D95C */ { "SIGNWRITING MOVEMENT-DIAGONAL TOWARDS LARGEST",NULL},
/* 1D95D */ { "SIGNWRITING MOVEMENT-DIAGONAL BETWEEN AWAY SMALL",NULL},
/* 1D95E */ { "SIGNWRITING MOVEMENT-DIAGONAL BETWEEN AWAY MEDIUM",NULL},
/* 1D95F */ { "SIGNWRITING MOVEMENT-DIAGONAL BETWEEN AWAY LARGE",NULL},
/* 1D960 */ { "SIGNWRITING MOVEMENT-DIAGONAL BETWEEN AWAY LARGEST",NULL},
/* 1D961 */ { "SIGNWRITING MOVEMENT-DIAGONAL BETWEEN TOWARDS SMALL",NULL},
/* 1D962 */ { "SIGNWRITING MOVEMENT-DIAGONAL BETWEEN TOWARDS MEDIUM",NULL},
/* 1D963 */ { "SIGNWRITING MOVEMENT-DIAGONAL BETWEEN TOWARDS LARGE",NULL},
/* 1D964 */ { "SIGNWRITING MOVEMENT-DIAGONAL BETWEEN TOWARDS LARGEST",NULL},
/* 1D965 */ { "SIGNWRITING MOVEMENT-FLOORPLANE SINGLE STRAIGHT SMALL",NULL},
/* 1D966 */ { "SIGNWRITING MOVEMENT-FLOORPLANE SINGLE STRAIGHT MEDIUM",NULL},
/* 1D967 */ { "SIGNWRITING MOVEMENT-FLOORPLANE SINGLE STRAIGHT LARGE",NULL},
/* 1D968 */ { "SIGNWRITING MOVEMENT-FLOORPLANE SINGLE STRAIGHT LARGEST",NULL},
/* 1D969 */ { "SIGNWRITING MOVEMENT-FLOORPLANE SINGLE WRIST FLEX",NULL},
/* 1D96A */ { "SIGNWRITING MOVEMENT-FLOORPLANE DOUBLE STRAIGHT",NULL},
/* 1D96B */ { "SIGNWRITING MOVEMENT-FLOORPLANE DOUBLE WRIST FLEX",NULL},
/* 1D96C */ { "SIGNWRITING MOVEMENT-FLOORPLANE DOUBLE ALTERNATING",NULL},
/* 1D96D */ { "SIGNWRITING MOVEMENT-FLOORPLANE DOUBLE ALTERNATING WRIST FLEX",NULL},
/* 1D96E */ { "SIGNWRITING MOVEMENT-FLOORPLANE CROSS",NULL},
/* 1D96F */ { "SIGNWRITING MOVEMENT-FLOORPLANE TRIPLE STRAIGHT MOVEMENT",NULL},
/* 1D970 */ { "SIGNWRITING MOVEMENT-FLOORPLANE TRIPLE WRIST FLEX",NULL},
/* 1D971 */ { "SIGNWRITING MOVEMENT-FLOORPLANE TRIPLE ALTERNATING MOVEMENT",NULL},
/* 1D972 */ { "SIGNWRITING MOVEMENT-FLOORPLANE TRIPLE ALTERNATING WRIST FLEX",NULL},
/* 1D973 */ { "SIGNWRITING MOVEMENT-FLOORPLANE BEND",NULL},
/* 1D974 */ { "SIGNWRITING MOVEMENT-FLOORPLANE CORNER SMALL",NULL},
/* 1D975 */ { "SIGNWRITING MOVEMENT-FLOORPLANE CORNER MEDIUM",NULL},
/* 1D976 */ { "SIGNWRITING MOVEMENT-FLOORPLANE CORNER LARGE",NULL},
/* 1D977 */ { "SIGNWRITING MOVEMENT-FLOORPLANE CHECK",NULL},
/* 1D978 */ { "SIGNWRITING MOVEMENT-FLOORPLANE BOX SMALL",NULL},
/* 1D979 */ { "SIGNWRITING MOVEMENT-FLOORPLANE BOX MEDIUM",NULL},
/* 1D97A */ { "SIGNWRITING MOVEMENT-FLOORPLANE BOX LARGE",NULL},
/* 1D97B */ { "SIGNWRITING MOVEMENT-FLOORPLANE ZIGZAG SMALL",NULL},
/* 1D97C */ { "SIGNWRITING MOVEMENT-FLOORPLANE ZIGZAG MEDIUM",NULL},
/* 1D97D */ { "SIGNWRITING MOVEMENT-FLOORPLANE ZIGZAG LARGE",NULL},
/* 1D97E */ { "SIGNWRITING MOVEMENT-FLOORPLANE PEAKS SMALL",NULL},
/* 1D97F */ { "SIGNWRITING MOVEMENT-FLOORPLANE PEAKS MEDIUM",NULL},
/* 1D980 */ { "SIGNWRITING MOVEMENT-FLOORPLANE PEAKS LARGE",NULL},
/* 1D981 */ { "SIGNWRITING TRAVEL-FLOORPLANE ROTATION-FLOORPLANE SINGLE",NULL},
/* 1D982 */ { "SIGNWRITING TRAVEL-FLOORPLANE ROTATION-FLOORPLANE DOUBLE",NULL},
/* 1D983 */ { "SIGNWRITING TRAVEL-FLOORPLANE ROTATION-FLOORPLANE ALTERNATING",NULL},
/* 1D984 */ { "SIGNWRITING TRAVEL-FLOORPLANE ROTATION-WALLPLANE SINGLE",NULL},
/* 1D985 */ { "SIGNWRITING TRAVEL-FLOORPLANE ROTATION-WALLPLANE DOUBLE",NULL},
/* 1D986 */ { "SIGNWRITING TRAVEL-FLOORPLANE ROTATION-WALLPLANE ALTERNATING",NULL},
/* 1D987 */ { "SIGNWRITING TRAVEL-FLOORPLANE SHAKING",NULL},
/* 1D988 */ { "SIGNWRITING MOVEMENT-WALLPLANE CURVE QUARTER SMALL",NULL},
/* 1D989 */ { "SIGNWRITING MOVEMENT-WALLPLANE CURVE QUARTER MEDIUM",NULL},
/* 1D98A */ { "SIGNWRITING MOVEMENT-WALLPLANE CURVE QUARTER LARGE",NULL},
/* 1D98B */ { "SIGNWRITING MOVEMENT-WALLPLANE CURVE QUARTER LARGEST",NULL},
/* 1D98C */ { "SIGNWRITING MOVEMENT-WALLPLANE CURVE HALF-CIRCLE SMALL",NULL},
/* 1D98D */ { "SIGNWRITING MOVEMENT-WALLPLANE CURVE HALF-CIRCLE MEDIUM",NULL},
/* 1D98E */ { "SIGNWRITING MOVEMENT-WALLPLANE CURVE HALF-CIRCLE LARGE",NULL},
/* 1D98F */ { "SIGNWRITING MOVEMENT-WALLPLANE CURVE HALF-CIRCLE LARGEST",NULL},
/* 1D990 */ { "SIGNWRITING MOVEMENT-WALLPLANE CURVE THREE-QUARTER CIRCLE SMALL",NULL},
/* 1D991 */ { "SIGNWRITING MOVEMENT-WALLPLANE CURVE THREE-QUARTER CIRCLE MEDIUM",NULL},
/* 1D992 */ { "SIGNWRITING MOVEMENT-WALLPLANE HUMP SMALL",NULL},
/* 1D993 */ { "SIGNWRITING MOVEMENT-WALLPLANE HUMP MEDIUM",NULL},
/* 1D994 */ { "SIGNWRITING MOVEMENT-WALLPLANE HUMP LARGE",NULL},
/* 1D995 */ { "SIGNWRITING MOVEMENT-WALLPLANE LOOP SMALL",NULL},
/* 1D996 */ { "SIGNWRITING MOVEMENT-WALLPLANE LOOP MEDIUM",NULL},
/* 1D997 */ { "SIGNWRITING MOVEMENT-WALLPLANE LOOP LARGE",NULL},
/* 1D998 */ { "SIGNWRITING MOVEMENT-WALLPLANE LOOP SMALL DOUBLE",NULL},
/* 1D999 */ { "SIGNWRITING MOVEMENT-WALLPLANE WAVE CURVE DOUBLE SMALL",NULL},
/* 1D99A */ { "SIGNWRITING MOVEMENT-WALLPLANE WAVE CURVE DOUBLE MEDIUM",NULL},
/* 1D99B */ { "SIGNWRITING MOVEMENT-WALLPLANE WAVE CURVE DOUBLE LARGE",NULL},
/* 1D99C */ { "SIGNWRITING MOVEMENT-WALLPLANE WAVE CURVE TRIPLE SMALL",NULL},
/* 1D99D */ { "SIGNWRITING MOVEMENT-WALLPLANE WAVE CURVE TRIPLE MEDIUM",NULL},
/* 1D99E */ { "SIGNWRITING MOVEMENT-WALLPLANE WAVE CURVE TRIPLE LARGE",NULL},
/* 1D99F */ { "SIGNWRITING MOVEMENT-WALLPLANE CURVE THEN STRAIGHT",NULL},
/* 1D9A0 */ { "SIGNWRITING MOVEMENT-WALLPLANE CURVED CROSS SMALL",NULL},
/* 1D9A1 */ { "SIGNWRITING MOVEMENT-WALLPLANE CURVED CROSS MEDIUM",NULL},
/* 1D9A2 */ { "SIGNWRITING ROTATION-WALLPLANE SINGLE",NULL},
/* 1D9A3 */ { "SIGNWRITING ROTATION-WALLPLANE DOUBLE",NULL},
/* 1D9A4 */ { "SIGNWRITING ROTATION-WALLPLANE ALTERNATE",NULL},
/* 1D9A5 */ { "SIGNWRITING MOVEMENT-WALLPLANE SHAKING",NULL},
/* 1D9A6 */ { "SIGNWRITING MOVEMENT-WALLPLANE CURVE HITTING FRONT WALL",NULL},
/* 1D9A7 */ { "SIGNWRITING MOVEMENT-WALLPLANE HUMP HITTING FRONT WALL",NULL},
/* 1D9A8 */ { "SIGNWRITING MOVEMENT-WALLPLANE LOOP HITTING FRONT WALL",NULL},
/* 1D9A9 */ { "SIGNWRITING MOVEMENT-WALLPLANE WAVE HITTING FRONT WALL",NULL},
/* 1D9AA */ { "SIGNWRITING ROTATION-WALLPLANE SINGLE HITTING FRONT WALL",NULL},
/* 1D9AB */ { "SIGNWRITING ROTATION-WALLPLANE DOUBLE HITTING FRONT WALL",NULL},
/* 1D9AC */ { "SIGNWRITING ROTATION-WALLPLANE ALTERNATING HITTING FRONT WALL",NULL},
/* 1D9AD */ { "SIGNWRITING MOVEMENT-WALLPLANE CURVE HITTING CHEST",NULL},
/* 1D9AE */ { "SIGNWRITING MOVEMENT-WALLPLANE HUMP HITTING CHEST",NULL},
/* 1D9AF */ { "SIGNWRITING MOVEMENT-WALLPLANE LOOP HITTING CHEST",NULL},
/* 1D9B0 */ { "SIGNWRITING MOVEMENT-WALLPLANE WAVE HITTING CHEST",NULL},
/* 1D9B1 */ { "SIGNWRITING ROTATION-WALLPLANE SINGLE HITTING CHEST",NULL},
/* 1D9B2 */ { "SIGNWRITING ROTATION-WALLPLANE DOUBLE HITTING CHEST",NULL},
/* 1D9B3 */ { "SIGNWRITING ROTATION-WALLPLANE ALTERNATING HITTING CHEST",NULL},
/* 1D9B4 */ { "SIGNWRITING MOVEMENT-WALLPLANE WAVE DIAGONAL PATH SMALL",NULL},
/* 1D9B5 */ { "SIGNWRITING MOVEMENT-WALLPLANE WAVE DIAGONAL PATH MEDIUM",NULL},
/* 1D9B6 */ { "SIGNWRITING MOVEMENT-WALLPLANE WAVE DIAGONAL PATH LARGE",NULL},
/* 1D9B7 */ { "SIGNWRITING MOVEMENT-FLOORPLANE CURVE HITTING CEILING SMALL",NULL},
/* 1D9B8 */ { "SIGNWRITING MOVEMENT-FLOORPLANE CURVE HITTING CEILING LARGE",NULL},
/* 1D9B9 */ { "SIGNWRITING MOVEMENT-FLOORPLANE HUMP HITTING CEILING SMALL DOUBLE",NULL},
/* 1D9BA */ { "SIGNWRITING MOVEMENT-FLOORPLANE HUMP HITTING CEILING LARGE DOUBLE",NULL},
/* 1D9BB */ { "SIGNWRITING MOVEMENT-FLOORPLANE HUMP HITTING CEILING SMALL TRIPLE",NULL},
/* 1D9BC */ { "SIGNWRITING MOVEMENT-FLOORPLANE HUMP HITTING CEILING LARGE TRIPLE",NULL},
/* 1D9BD */ { "SIGNWRITING MOVEMENT-FLOORPLANE LOOP HITTING CEILING SMALL SINGLE",NULL},
/* 1D9BE */ { "SIGNWRITING MOVEMENT-FLOORPLANE LOOP HITTING CEILING LARGE SINGLE",NULL},
/* 1D9BF */ { "SIGNWRITING MOVEMENT-FLOORPLANE LOOP HITTING CEILING SMALL DOUBLE",NULL},
/* 1D9C0 */ { "SIGNWRITING MOVEMENT-FLOORPLANE LOOP HITTING CEILING LARGE DOUBLE",NULL},
/* 1D9C1 */ { "SIGNWRITING MOVEMENT-FLOORPLANE WAVE HITTING CEILING SMALL",NULL},
/* 1D9C2 */ { "SIGNWRITING MOVEMENT-FLOORPLANE WAVE HITTING CEILING LARGE",NULL},
/* 1D9C3 */ { "SIGNWRITING ROTATION-FLOORPLANE SINGLE HITTING CEILING",NULL},
/* 1D9C4 */ { "SIGNWRITING ROTATION-FLOORPLANE DOUBLE HITTING CEILING",NULL},
/* 1D9C5 */ { "SIGNWRITING ROTATION-FLOORPLANE ALTERNATING HITTING CEILING",NULL},
/* 1D9C6 */ { "SIGNWRITING MOVEMENT-FLOORPLANE CURVE HITTING FLOOR SMALL",NULL},
/* 1D9C7 */ { "SIGNWRITING MOVEMENT-FLOORPLANE CURVE HITTING FLOOR LARGE",NULL},
/* 1D9C8 */ { "SIGNWRITING MOVEMENT-FLOORPLANE HUMP HITTING FLOOR SMALL DOUBLE",NULL},
/* 1D9C9 */ { "SIGNWRITING MOVEMENT-FLOORPLANE HUMP HITTING FLOOR LARGE DOUBLE",NULL},
/* 1D9CA */ { "SIGNWRITING MOVEMENT-FLOORPLANE HUMP HITTING FLOOR TRIPLE SMALL TRIPLE",NULL},
/* 1D9CB */ { "SIGNWRITING MOVEMENT-FLOORPLANE HUMP HITTING FLOOR TRIPLE LARGE TRIPLE",NULL},
/* 1D9CC */ { "SIGNWRITING MOVEMENT-FLOORPLANE LOOP HITTING FLOOR SMALL SINGLE",NULL},
/* 1D9CD */ { "SIGNWRITING MOVEMENT-FLOORPLANE LOOP HITTING FLOOR LARGE SINGLE",NULL},
/* 1D9CE */ { "SIGNWRITING MOVEMENT-FLOORPLANE LOOP HITTING FLOOR SMALL DOUBLE",NULL},
/* 1D9CF */ { "SIGNWRITING MOVEMENT-FLOORPLANE LOOP HITTING FLOOR LARGE DOUBLE",NULL},
/* 1D9D0 */ { "SIGNWRITING MOVEMENT-FLOORPLANE WAVE HITTING FLOOR SMALL",NULL},
/* 1D9D1 */ { "SIGNWRITING MOVEMENT-FLOORPLANE WAVE HITTING FLOOR LARGE",NULL},
/* 1D9D2 */ { "SIGNWRITING ROTATION-FLOORPLANE SINGLE HITTING FLOOR",NULL},
/* 1D9D3 */ { "SIGNWRITING ROTATION-FLOORPLANE DOUBLE HITTING FLOOR",NULL},
/* 1D9D4 */ { "SIGNWRITING ROTATION-FLOORPLANE ALTERNATING HITTING FLOOR",NULL},
/* 1D9D5 */ { "SIGNWRITING MOVEMENT-FLOORPLANE CURVE SMALL",NULL},
/* 1D9D6 */ { "SIGNWRITING MOVEMENT-FLOORPLANE CURVE MEDIUM",NULL},
/* 1D9D7 */ { "SIGNWRITING MOVEMENT-FLOORPLANE CURVE LARGE",NULL},
/* 1D9D8 */ { "SIGNWRITING MOVEMENT-FLOORPLANE CURVE LARGEST",NULL},
/* 1D9D9 */ { "SIGNWRITING MOVEMENT-FLOORPLANE CURVE COMBINED",NULL},
/* 1D9DA */ { "SIGNWRITING MOVEMENT-FLOORPLANE HUMP SMALL",NULL},
/* 1D9DB */ { "SIGNWRITING MOVEMENT-FLOORPLANE LOOP SMALL",NULL},
/* 1D9DC */ { "SIGNWRITING MOVEMENT-FLOORPLANE WAVE SNAKE",NULL},
/* 1D9DD */ { "SIGNWRITING MOVEMENT-FLOORPLANE WAVE SMALL",NULL},
/* 1D9DE */ { "SIGNWRITING MOVEMENT-FLOORPLANE WAVE LARGE",NULL},
/* 1D9DF */ { "SIGNWRITING ROTATION-FLOORPLANE SINGLE",NULL},
/* 1D9E0 */ { "SIGNWRITING ROTATION-FLOORPLANE DOUBLE",NULL},
/* 1D9E1 */ { "SIGNWRITING ROTATION-FLOORPLANE ALTERNATING",NULL},
/* 1D9E2 */ { "SIGNWRITING MOVEMENT-FLOORPLANE SHAKING PARALLEL",NULL},
/* 1D9E3 */ { "SIGNWRITING MOVEMENT-WALLPLANE ARM CIRCLE SMALL SINGLE",NULL},
/* 1D9E4 */ { "SIGNWRITING MOVEMENT-WALLPLANE ARM CIRCLE MEDIUM SINGLE",NULL},
/* 1D9E5 */ { "SIGNWRITING MOVEMENT-WALLPLANE ARM CIRCLE SMALL DOUBLE",NULL},
/* 1D9E6 */ { "SIGNWRITING MOVEMENT-WALLPLANE ARM CIRCLE MEDIUM DOUBLE",NULL},
/* 1D9E7 */ { "SIGNWRITING MOVEMENT-FLOORPLANE ARM CIRCLE HITTING WALL SMALL SINGLE",NULL},
/* 1D9E8 */ { "SIGNWRITING MOVEMENT-FLOORPLANE ARM CIRCLE HITTING WALL MEDIUM SINGLE",NULL},
/* 1D9E9 */ { "SIGNWRITING MOVEMENT-FLOORPLANE ARM CIRCLE HITTING WALL LARGE SINGLE",NULL},
/* 1D9EA */ { "SIGNWRITING MOVEMENT-FLOORPLANE ARM CIRCLE HITTING WALL SMALL DOUBLE",NULL},
/* 1D9EB */ { "SIGNWRITING MOVEMENT-FLOORPLANE ARM CIRCLE HITTING WALL MEDIUM DOUBLE",NULL},
/* 1D9EC */ { "SIGNWRITING MOVEMENT-FLOORPLANE ARM CIRCLE HITTING WALL LARGE DOUBLE",NULL},
/* 1D9ED */ { "SIGNWRITING MOVEMENT-WALLPLANE WRIST CIRCLE FRONT SINGLE",NULL},
/* 1D9EE */ { "SIGNWRITING MOVEMENT-WALLPLANE WRIST CIRCLE FRONT DOUBLE",NULL},
/* 1D9EF */ { "SIGNWRITING MOVEMENT-FLOORPLANE WRIST CIRCLE HITTING WALL SINGLE",NULL},
/* 1D9F0 */ { "SIGNWRITING MOVEMENT-FLOORPLANE WRIST CIRCLE HITTING WALL DOUBLE",NULL},
/* 1D9F1 */ { "SIGNWRITING MOVEMENT-WALLPLANE FINGER CIRCLES SINGLE",NULL},
/* 1D9F2 */ { "SIGNWRITING MOVEMENT-WALLPLANE FINGER CIRCLES DOUBLE",NULL},
/* 1D9F3 */ { "SIGNWRITING MOVEMENT-FLOORPLANE FINGER CIRCLES HITTING WALL SINGLE",NULL},
/* 1D9F4 */ { "SIGNWRITING MOVEMENT-FLOORPLANE FINGER CIRCLES HITTING WALL DOUBLE",NULL},
/* 1D9F5 */ { "SIGNWRITING DYNAMIC ARROWHEAD SMALL",NULL},
/* 1D9F6 */ { "SIGNWRITING DYNAMIC ARROWHEAD LARGE",NULL},
/* 1D9F7 */ { "SIGNWRITING DYNAMIC FAST",NULL},
/* 1D9F8 */ { "SIGNWRITING DYNAMIC SLOW",NULL},
/* 1D9F9 */ { "SIGNWRITING DYNAMIC TENSE",NULL},
/* 1D9FA */ { "SIGNWRITING DYNAMIC RELAXED",NULL},
/* 1D9FB */ { "SIGNWRITING DYNAMIC SIMULTANEOUS",NULL},
/* 1D9FC */ { "SIGNWRITING DYNAMIC SIMULTANEOUS ALTERNATING",NULL},
/* 1D9FD */ { "SIGNWRITING DYNAMIC EVERY OTHER TIME",NULL},
/* 1D9FE */ { "SIGNWRITING DYNAMIC GRADUAL",NULL},
/* 1D9FF */ { "SIGNWRITING HEAD",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_DA[] = {
/* 1DA00 */ { "SIGNWRITING HEAD RIM",NULL},
/* 1DA01 */ { "SIGNWRITING HEAD MOVEMENT-WALLPLANE STRAIGHT",NULL},
/* 1DA02 */ { "SIGNWRITING HEAD MOVEMENT-WALLPLANE TILT",NULL},
/* 1DA03 */ { "SIGNWRITING HEAD MOVEMENT-FLOORPLANE STRAIGHT",NULL},
/* 1DA04 */ { "SIGNWRITING HEAD MOVEMENT-WALLPLANE CURVE",NULL},
/* 1DA05 */ { "SIGNWRITING HEAD MOVEMENT-FLOORPLANE CURVE",NULL},
/* 1DA06 */ { "SIGNWRITING HEAD MOVEMENT CIRCLE",NULL},
/* 1DA07 */ { "SIGNWRITING FACE DIRECTION POSITION NOSE FORWARD TILTING",NULL},
/* 1DA08 */ { "SIGNWRITING FACE DIRECTION POSITION NOSE UP OR DOWN",NULL},
/* 1DA09 */ { "SIGNWRITING FACE DIRECTION POSITION NOSE UP OR DOWN TILTING",NULL},
/* 1DA0A */ { "SIGNWRITING EYEBROWS STRAIGHT UP",NULL},
/* 1DA0B */ { "SIGNWRITING EYEBROWS STRAIGHT NEUTRAL",NULL},
/* 1DA0C */ { "SIGNWRITING EYEBROWS STRAIGHT DOWN",NULL},
/* 1DA0D */ { "SIGNWRITING DREAMY EYEBROWS NEUTRAL DOWN",NULL},
/* 1DA0E */ { "SIGNWRITING DREAMY EYEBROWS DOWN NEUTRAL",NULL},
/* 1DA0F */ { "SIGNWRITING DREAMY EYEBROWS UP NEUTRAL",NULL},
/* 1DA10 */ { "SIGNWRITING DREAMY EYEBROWS NEUTRAL UP",NULL},
/* 1DA11 */ { "SIGNWRITING FOREHEAD NEUTRAL",NULL},
/* 1DA12 */ { "SIGNWRITING FOREHEAD CONTACT",NULL},
/* 1DA13 */ { "SIGNWRITING FOREHEAD WRINKLED",NULL},
/* 1DA14 */ { "SIGNWRITING EYES OPEN",NULL},
/* 1DA15 */ { "SIGNWRITING EYES SQUEEZED",NULL},
/* 1DA16 */ { "SIGNWRITING EYES CLOSED",NULL},
/* 1DA17 */ { "SIGNWRITING EYE BLINK SINGLE",NULL},
/* 1DA18 */ { "SIGNWRITING EYE BLINK MULTIPLE",NULL},
/* 1DA19 */ { "SIGNWRITING EYES HALF OPEN",NULL},
/* 1DA1A */ { "SIGNWRITING EYES WIDE OPEN",NULL},
/* 1DA1B */ { "SIGNWRITING EYES HALF CLOSED",NULL},
/* 1DA1C */ { "SIGNWRITING EYES WIDENING MOVEMENT",NULL},
/* 1DA1D */ { "SIGNWRITING EYE WINK","	* squeezed eye blink"},
/* 1DA1E */ { "SIGNWRITING EYELASHES UP",NULL},
/* 1DA1F */ { "SIGNWRITING EYELASHES DOWN",NULL},
/* 1DA20 */ { "SIGNWRITING EYELASHES FLUTTERING",NULL},
/* 1DA21 */ { "SIGNWRITING EYEGAZE-WALLPLANE STRAIGHT",NULL},
/* 1DA22 */ { "SIGNWRITING EYEGAZE-WALLPLANE STRAIGHT DOUBLE",NULL},
/* 1DA23 */ { "SIGNWRITING EYEGAZE-WALLPLANE STRAIGHT ALTERNATING",NULL},
/* 1DA24 */ { "SIGNWRITING EYEGAZE-FLOORPLANE STRAIGHT",NULL},
/* 1DA25 */ { "SIGNWRITING EYEGAZE-FLOORPLANE STRAIGHT DOUBLE",NULL},
/* 1DA26 */ { "SIGNWRITING EYEGAZE-FLOORPLANE STRAIGHT ALTERNATING",NULL},
/* 1DA27 */ { "SIGNWRITING EYEGAZE-WALLPLANE CURVED",NULL},
/* 1DA28 */ { "SIGNWRITING EYEGAZE-FLOORPLANE CURVED",NULL},
/* 1DA29 */ { "SIGNWRITING EYEGAZE-WALLPLANE CIRCLING",NULL},
/* 1DA2A */ { "SIGNWRITING CHEEKS PUFFED",NULL},
/* 1DA2B */ { "SIGNWRITING CHEEKS NEUTRAL",NULL},
/* 1DA2C */ { "SIGNWRITING CHEEKS SUCKED",NULL},
/* 1DA2D */ { "SIGNWRITING TENSE CHEEKS HIGH",NULL},
/* 1DA2E */ { "SIGNWRITING TENSE CHEEKS MIDDLE",NULL},
/* 1DA2F */ { "SIGNWRITING TENSE CHEEKS LOW",NULL},
/* 1DA30 */ { "SIGNWRITING EARS",NULL},
/* 1DA31 */ { "SIGNWRITING NOSE NEUTRAL",NULL},
/* 1DA32 */ { "SIGNWRITING NOSE CONTACT",NULL},
/* 1DA33 */ { "SIGNWRITING NOSE WRINKLES",NULL},
/* 1DA34 */ { "SIGNWRITING NOSE WIGGLES",NULL},
/* 1DA35 */ { "SIGNWRITING AIR BLOWING OUT",NULL},
/* 1DA36 */ { "SIGNWRITING AIR SUCKING IN",NULL},
/* 1DA37 */ { "SIGNWRITING AIR BLOW SMALL ROTATIONS",NULL},
/* 1DA38 */ { "SIGNWRITING AIR SUCK SMALL ROTATIONS",NULL},
/* 1DA39 */ { "SIGNWRITING BREATH INHALE",NULL},
/* 1DA3A */ { "SIGNWRITING BREATH EXHALE",NULL},
/* 1DA3B */ { "SIGNWRITING MOUTH CLOSED NEUTRAL",NULL},
/* 1DA3C */ { "SIGNWRITING MOUTH CLOSED FORWARD",NULL},
/* 1DA3D */ { "SIGNWRITING MOUTH CLOSED CONTACT",NULL},
/* 1DA3E */ { "SIGNWRITING MOUTH SMILE",NULL},
/* 1DA3F */ { "SIGNWRITING MOUTH SMILE WRINKLED",NULL},
/* 1DA40 */ { "SIGNWRITING MOUTH SMILE OPEN",NULL},
/* 1DA41 */ { "SIGNWRITING MOUTH FROWN",NULL},
/* 1DA42 */ { "SIGNWRITING MOUTH FROWN WRINKLED",NULL},
/* 1DA43 */ { "SIGNWRITING MOUTH FROWN OPEN",NULL},
/* 1DA44 */ { "SIGNWRITING MOUTH OPEN CIRCLE",NULL},
/* 1DA45 */ { "SIGNWRITING MOUTH OPEN FORWARD",NULL},
/* 1DA46 */ { "SIGNWRITING MOUTH OPEN WRINKLED",NULL},
/* 1DA47 */ { "SIGNWRITING MOUTH OPEN OVAL",NULL},
/* 1DA48 */ { "SIGNWRITING MOUTH OPEN OVAL WRINKLED",NULL},
/* 1DA49 */ { "SIGNWRITING MOUTH OPEN OVAL YAWN",NULL},
/* 1DA4A */ { "SIGNWRITING MOUTH OPEN RECTANGLE",NULL},
/* 1DA4B */ { "SIGNWRITING MOUTH OPEN RECTANGLE WRINKLED",NULL},
/* 1DA4C */ { "SIGNWRITING MOUTH OPEN RECTANGLE YAWN",NULL},
/* 1DA4D */ { "SIGNWRITING MOUTH KISS",NULL},
/* 1DA4E */ { "SIGNWRITING MOUTH KISS FORWARD",NULL},
/* 1DA4F */ { "SIGNWRITING MOUTH KISS WRINKLED",NULL},
/* 1DA50 */ { "SIGNWRITING MOUTH TENSE",NULL},
/* 1DA51 */ { "SIGNWRITING MOUTH TENSE FORWARD",NULL},
/* 1DA52 */ { "SIGNWRITING MOUTH TENSE SUCKED",NULL},
/* 1DA53 */ { "SIGNWRITING LIPS PRESSED TOGETHER",NULL},
/* 1DA54 */ { "SIGNWRITING LIP LOWER OVER UPPER",NULL},
/* 1DA55 */ { "SIGNWRITING LIP UPPER OVER LOWER",NULL},
/* 1DA56 */ { "SIGNWRITING MOUTH CORNERS",NULL},
/* 1DA57 */ { "SIGNWRITING MOUTH WRINKLES SINGLE",NULL},
/* 1DA58 */ { "SIGNWRITING MOUTH WRINKLES DOUBLE",NULL},
/* 1DA59 */ { "SIGNWRITING TONGUE STICKING OUT FAR",NULL},
/* 1DA5A */ { "SIGNWRITING TONGUE LICKING LIPS",NULL},
/* 1DA5B */ { "SIGNWRITING TONGUE TIP BETWEEN LIPS",NULL},
/* 1DA5C */ { "SIGNWRITING TONGUE TIP TOUCHING INSIDE MOUTH",NULL},
/* 1DA5D */ { "SIGNWRITING TONGUE INSIDE MOUTH RELAXED",NULL},
/* 1DA5E */ { "SIGNWRITING TONGUE MOVES AGAINST CHEEK",NULL},
/* 1DA5F */ { "SIGNWRITING TONGUE CENTRE STICKING OUT",NULL},
/* 1DA60 */ { "SIGNWRITING TONGUE CENTRE INSIDE MOUTH",NULL},
/* 1DA61 */ { "SIGNWRITING TEETH",NULL},
/* 1DA62 */ { "SIGNWRITING TEETH MOVEMENT",NULL},
/* 1DA63 */ { "SIGNWRITING TEETH ON TONGUE",NULL},
/* 1DA64 */ { "SIGNWRITING TEETH ON TONGUE MOVEMENT",NULL},
/* 1DA65 */ { "SIGNWRITING TEETH ON LIPS",NULL},
/* 1DA66 */ { "SIGNWRITING TEETH ON LIPS MOVEMENT",NULL},
/* 1DA67 */ { "SIGNWRITING TEETH BITE LIPS",NULL},
/* 1DA68 */ { "SIGNWRITING MOVEMENT-WALLPLANE JAW",NULL},
/* 1DA69 */ { "SIGNWRITING MOVEMENT-FLOORPLANE JAW",NULL},
/* 1DA6A */ { "SIGNWRITING NECK",NULL},
/* 1DA6B */ { "SIGNWRITING HAIR",NULL},
/* 1DA6C */ { "SIGNWRITING EXCITEMENT",NULL},
/* 1DA6D */ { "SIGNWRITING SHOULDER HIP SPINE",NULL},
/* 1DA6E */ { "SIGNWRITING SHOULDER HIP POSITIONS",NULL},
/* 1DA6F */ { "SIGNWRITING WALLPLANE SHOULDER HIP MOVE",NULL},
/* 1DA70 */ { "SIGNWRITING FLOORPLANE SHOULDER HIP MOVE",NULL},
/* 1DA71 */ { "SIGNWRITING SHOULDER TILTING FROM WAIST",NULL},
/* 1DA72 */ { "SIGNWRITING TORSO-WALLPLANE STRAIGHT STRETCH",NULL},
/* 1DA73 */ { "SIGNWRITING TORSO-WALLPLANE CURVED BEND",NULL},
/* 1DA74 */ { "SIGNWRITING TORSO-FLOORPLANE TWISTING",NULL},
/* 1DA75 */ { "SIGNWRITING UPPER BODY TILTING FROM HIP JOINTS",NULL},
/* 1DA76 */ { "SIGNWRITING LIMB COMBINATION",NULL},
/* 1DA77 */ { "SIGNWRITING LIMB LENGTH-1",NULL},
/* 1DA78 */ { "SIGNWRITING LIMB LENGTH-2",NULL},
/* 1DA79 */ { "SIGNWRITING LIMB LENGTH-3",NULL},
/* 1DA7A */ { "SIGNWRITING LIMB LENGTH-4",NULL},
/* 1DA7B */ { "SIGNWRITING LIMB LENGTH-5",NULL},
/* 1DA7C */ { "SIGNWRITING LIMB LENGTH-6",NULL},
/* 1DA7D */ { "SIGNWRITING LIMB LENGTH-7",NULL},
/* 1DA7E */ { "SIGNWRITING FINGER",NULL},
/* 1DA7F */ { "SIGNWRITING LOCATION-WALLPLANE SPACE",NULL},
/* 1DA80 */ { "SIGNWRITING LOCATION-FLOORPLANE SPACE",NULL},
/* 1DA81 */ { "SIGNWRITING LOCATION HEIGHT",NULL},
/* 1DA82 */ { "SIGNWRITING LOCATION WIDTH",NULL},
/* 1DA83 */ { "SIGNWRITING LOCATION DEPTH",NULL},
/* 1DA84 */ { "SIGNWRITING LOCATION HEAD NECK",NULL},
/* 1DA85 */ { "SIGNWRITING LOCATION TORSO",NULL},
/* 1DA86 */ { "SIGNWRITING LOCATION LIMBS DIGITS",NULL},
/* 1DA87 */ { "SIGNWRITING COMMA",NULL},
/* 1DA88 */ { "SIGNWRITING FULL STOP",NULL},
/* 1DA89 */ { "SIGNWRITING SEMICOLON",NULL},
/* 1DA8A */ { "SIGNWRITING COLON",NULL},
/* 1DA8B */ { "SIGNWRITING PARENTHESIS","	* is a closing parenthesis when used with 1DAA4 signwriting rotation modifier-5"},
/* 1DA8C */ { NULL,NULL},
/* 1DA8D */ { NULL,NULL},
/* 1DA8E */ { NULL,NULL},
/* 1DA8F */ { NULL,NULL},
/* 1DA90 */ { NULL,NULL},
/* 1DA91 */ { NULL,NULL},
/* 1DA92 */ { NULL,NULL},
/* 1DA93 */ { NULL,NULL},
/* 1DA94 */ { NULL,NULL},
/* 1DA95 */ { NULL,NULL},
/* 1DA96 */ { NULL,NULL},
/* 1DA97 */ { NULL,NULL},
/* 1DA98 */ { NULL,NULL},
/* 1DA99 */ { NULL,NULL},
/* 1DA9A */ { NULL,NULL},
/* 1DA9B */ { "SIGNWRITING FILL MODIFIER-2",NULL},
/* 1DA9C */ { "SIGNWRITING FILL MODIFIER-3",NULL},
/* 1DA9D */ { "SIGNWRITING FILL MODIFIER-4",NULL},
/* 1DA9E */ { "SIGNWRITING FILL MODIFIER-5",NULL},
/* 1DA9F */ { "SIGNWRITING FILL MODIFIER-6",NULL},
/* 1DAA0 */ { NULL,NULL},
/* 1DAA1 */ { "SIGNWRITING ROTATION MODIFIER-2",NULL},
/* 1DAA2 */ { "SIGNWRITING ROTATION MODIFIER-3",NULL},
/* 1DAA3 */ { "SIGNWRITING ROTATION MODIFIER-4",NULL},
/* 1DAA4 */ { "SIGNWRITING ROTATION MODIFIER-5",NULL},
/* 1DAA5 */ { "SIGNWRITING ROTATION MODIFIER-6",NULL},
/* 1DAA6 */ { "SIGNWRITING ROTATION MODIFIER-7",NULL},
/* 1DAA7 */ { "SIGNWRITING ROTATION MODIFIER-8",NULL},
/* 1DAA8 */ { "SIGNWRITING ROTATION MODIFIER-9",NULL},
/* 1DAA9 */ { "SIGNWRITING ROTATION MODIFIER-10",NULL},
/* 1DAAA */ { "SIGNWRITING ROTATION MODIFIER-11",NULL},
/* 1DAAB */ { "SIGNWRITING ROTATION MODIFIER-12",NULL},
/* 1DAAC */ { "SIGNWRITING ROTATION MODIFIER-13",NULL},
/* 1DAAD */ { "SIGNWRITING ROTATION MODIFIER-14",NULL},
/* 1DAAE */ { "SIGNWRITING ROTATION MODIFIER-15",NULL},
/* 1DAAF */ { "SIGNWRITING ROTATION MODIFIER-16",NULL},
/* 1DAB0 */ { NULL,NULL},
/* 1DAB1 */ { NULL,NULL},
/* 1DAB2 */ { NULL,NULL},
/* 1DAB3 */ { NULL,NULL},
/* 1DAB4 */ { NULL,NULL},
/* 1DAB5 */ { NULL,NULL},
/* 1DAB6 */ { NULL,NULL},
/* 1DAB7 */ { NULL,NULL},
/* 1DAB8 */ { NULL,NULL},
/* 1DAB9 */ { NULL,NULL},
/* 1DABA */ { NULL,NULL},
/* 1DABB */ { NULL,NULL},
/* 1DABC */ { NULL,NULL},
/* 1DABD */ { NULL,NULL},
/* 1DABE */ { NULL,NULL},
/* 1DABF */ { NULL,NULL},
/* 1DAC0 */ { NULL,NULL},
/* 1DAC1 */ { NULL,NULL},
/* 1DAC2 */ { NULL,NULL},
/* 1DAC3 */ { NULL,NULL},
/* 1DAC4 */ { NULL,NULL},
/* 1DAC5 */ { NULL,NULL},
/* 1DAC6 */ { NULL,NULL},
/* 1DAC7 */ { NULL,NULL},
/* 1DAC8 */ { NULL,NULL},
/* 1DAC9 */ { NULL,NULL},
/* 1DACA */ { NULL,NULL},
/* 1DACB */ { NULL,NULL},
/* 1DACC */ { NULL,NULL},
/* 1DACD */ { NULL,NULL},
/* 1DACE */ { NULL,NULL},
/* 1DACF */ { NULL,NULL},
/* 1DAD0 */ { NULL,NULL},
/* 1DAD1 */ { NULL,NULL},
/* 1DAD2 */ { NULL,NULL},
/* 1DAD3 */ { NULL,NULL},
/* 1DAD4 */ { NULL,NULL},
/* 1DAD5 */ { NULL,NULL},
/* 1DAD6 */ { NULL,NULL},
/* 1DAD7 */ { NULL,NULL},
/* 1DAD8 */ { NULL,NULL},
/* 1DAD9 */ { NULL,NULL},
/* 1DADA */ { NULL,NULL},
/* 1DADB */ { NULL,NULL},
/* 1DADC */ { NULL,NULL},
/* 1DADD */ { NULL,NULL},
/* 1DADE */ { NULL,NULL},
/* 1DADF */ { NULL,NULL},
/* 1DAE0 */ { NULL,NULL},
/* 1DAE1 */ { NULL,NULL},
/* 1DAE2 */ { NULL,NULL},
/* 1DAE3 */ { NULL,NULL},
/* 1DAE4 */ { NULL,NULL},
/* 1DAE5 */ { NULL,NULL},
/* 1DAE6 */ { NULL,NULL},
/* 1DAE7 */ { NULL,NULL},
/* 1DAE8 */ { NULL,NULL},
/* 1DAE9 */ { NULL,NULL},
/* 1DAEA */ { NULL,NULL},
/* 1DAEB */ { NULL,NULL},
/* 1DAEC */ { NULL,NULL},
/* 1DAED */ { NULL,NULL},
/* 1DAEE */ { NULL,NULL},
/* 1DAEF */ { NULL,NULL},
/* 1DAF0 */ { NULL,NULL},
/* 1DAF1 */ { NULL,NULL},
/* 1DAF2 */ { NULL,NULL},
/* 1DAF3 */ { NULL,NULL},
/* 1DAF4 */ { NULL,NULL},
/* 1DAF5 */ { NULL,NULL},
/* 1DAF6 */ { NULL,NULL},
/* 1DAF7 */ { NULL,NULL},
/* 1DAF8 */ { NULL,NULL},
/* 1DAF9 */ { NULL,NULL},
/* 1DAFA */ { NULL,NULL},
/* 1DAFB */ { NULL,NULL},
/* 1DAFC */ { NULL,NULL},
/* 1DAFD */ { NULL,NULL},
/* 1DAFE */ { NULL,NULL},
/* 1DAFF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_DF[] = {
/* 1DF00 */ { "LATIN SMALL LETTER FENG DIGRAPH WITH TRILL","	x (latin small letter feng digraph - 02A9)"},
/* 1DF01 */ { "LATIN SMALL LETTER REVERSED SCRIPT G",NULL},
/* 1DF02 */ { "LATIN LETTER SMALL CAPITAL TURNED G","	x (latin small letter turned g - 1D77)"},
/* 1DF03 */ { "LATIN SMALL LETTER REVERSED K",NULL},
/* 1DF04 */ { "LATIN LETTER SMALL CAPITAL L WITH BELT","	x (latin capital letter l with belt - A7AD)"},
/* 1DF05 */ { "LATIN SMALL LETTER LEZH WITH RETROFLEX HOOK",NULL},
/* 1DF06 */ { "LATIN SMALL LETTER TURNED Y WITH BELT",NULL},
/* 1DF07 */ { "LATIN SMALL LETTER REVERSED ENG",NULL},
/* 1DF08 */ { "LATIN SMALL LETTER TURNED R WITH LONG LEG AND RETROFLEX HOOK",NULL},
/* 1DF09 */ { "LATIN SMALL LETTER T WITH HOOK AND RETROFLEX HOOK","	x (latin small letter t with hook - 01AD)"},
/* 1DF0A */ { "LATIN LETTER RETROFLEX CLICK WITH RETROFLEX HOOK","	x (modifier letter raised exclamation mark - A71D)\n"
	"	x (modifier letter retroflex click with retroflex hook - 107B9)"},
/* 1DF0B */ { "LATIN SMALL LETTER ESH WITH DOUBLE BAR","	x (integral with double stroke - 2A0E)"},
/* 1DF0C */ { "LATIN SMALL LETTER ESH WITH DOUBLE BAR AND CURL",NULL},
/* 1DF0D */ { "LATIN SMALL LETTER TURNED T WITH CURL",NULL},
/* 1DF0E */ { "LATIN LETTER INVERTED GLOTTAL STOP WITH CURL",NULL},
/* 1DF0F */ { "LATIN LETTER STRETCHED C WITH CURL",NULL},
/* 1DF10 */ { "LATIN LETTER SMALL CAPITAL TURNED K","	x (latin small letter turned k - 029E)\n"
	"	x (latin capital letter turned k - A7B0)"},
/* 1DF11 */ { "LATIN SMALL LETTER L WITH FISHHOOK",NULL},
/* 1DF12 */ { "LATIN SMALL LETTER DEZH DIGRAPH WITH PALATAL HOOK",NULL},
/* 1DF13 */ { "LATIN SMALL LETTER L WITH BELT AND PALATAL HOOK",NULL},
/* 1DF14 */ { "LATIN SMALL LETTER ENG WITH PALATAL HOOK",NULL},
/* 1DF15 */ { "LATIN SMALL LETTER TURNED R WITH PALATAL HOOK",NULL},
/* 1DF16 */ { "LATIN SMALL LETTER R WITH FISHHOOK AND PALATAL HOOK",NULL},
/* 1DF17 */ { "LATIN SMALL LETTER TESH DIGRAPH WITH PALATAL HOOK",NULL},
/* 1DF18 */ { "LATIN SMALL LETTER EZH WITH PALATAL HOOK",NULL},
/* 1DF19 */ { "LATIN SMALL LETTER DEZH DIGRAPH WITH RETROFLEX HOOK",NULL},
/* 1DF1A */ { "LATIN SMALL LETTER I WITH STROKE AND RETROFLEX HOOK",NULL},
/* 1DF1B */ { "LATIN SMALL LETTER O WITH RETROFLEX HOOK",NULL},
/* 1DF1C */ { "LATIN SMALL LETTER TESH DIGRAPH WITH RETROFLEX HOOK",NULL},
/* 1DF1D */ { "LATIN SMALL LETTER C WITH RETROFLEX HOOK",NULL},
/* 1DF1E */ { "LATIN SMALL LETTER S WITH CURL",NULL},
/* 1DF1F */ { NULL,NULL},
/* 1DF20 */ { NULL,NULL},
/* 1DF21 */ { NULL,NULL},
/* 1DF22 */ { NULL,NULL},
/* 1DF23 */ { NULL,NULL},
/* 1DF24 */ { NULL,NULL},
/* 1DF25 */ { "LATIN SMALL LETTER D WITH MID-HEIGHT LEFT HOOK",NULL},
/* 1DF26 */ { "LATIN SMALL LETTER L WITH MID-HEIGHT LEFT HOOK",NULL},
/* 1DF27 */ { "LATIN SMALL LETTER N WITH MID-HEIGHT LEFT HOOK",NULL},
/* 1DF28 */ { "LATIN SMALL LETTER R WITH MID-HEIGHT LEFT HOOK",NULL},
/* 1DF29 */ { "LATIN SMALL LETTER S WITH MID-HEIGHT LEFT HOOK",NULL},
/* 1DF2A */ { "LATIN SMALL LETTER T WITH MID-HEIGHT LEFT HOOK",NULL},
/* 1DF2B */ { NULL,NULL},
/* 1DF2C */ { NULL,NULL},
/* 1DF2D */ { NULL,NULL},
/* 1DF2E */ { NULL,NULL},
/* 1DF2F */ { NULL,NULL},
/* 1DF30 */ { NULL,NULL},
/* 1DF31 */ { NULL,NULL},
/* 1DF32 */ { NULL,NULL},
/* 1DF33 */ { NULL,NULL},
/* 1DF34 */ { NULL,NULL},
/* 1DF35 */ { NULL,NULL},
/* 1DF36 */ { NULL,NULL},
/* 1DF37 */ { NULL,NULL},
/* 1DF38 */ { NULL,NULL},
/* 1DF39 */ { NULL,NULL},
/* 1DF3A */ { NULL,NULL},
/* 1DF3B */ { NULL,NULL},
/* 1DF3C */ { NULL,NULL},
/* 1DF3D */ { NULL,NULL},
/* 1DF3E */ { NULL,NULL},
/* 1DF3F */ { NULL,NULL},
/* 1DF40 */ { NULL,NULL},
/* 1DF41 */ { NULL,NULL},
/* 1DF42 */ { NULL,NULL},
/* 1DF43 */ { NULL,NULL},
/* 1DF44 */ { NULL,NULL},
/* 1DF45 */ { NULL,NULL},
/* 1DF46 */ { NULL,NULL},
/* 1DF47 */ { NULL,NULL},
/* 1DF48 */ { NULL,NULL},
/* 1DF49 */ { NULL,NULL},
/* 1DF4A */ { NULL,NULL},
/* 1DF4B */ { NULL,NULL},
/* 1DF4C */ { NULL,NULL},
/* 1DF4D */ { NULL,NULL},
/* 1DF4E */ { NULL,NULL},
/* 1DF4F */ { NULL,NULL},
/* 1DF50 */ { NULL,NULL},
/* 1DF51 */ { NULL,NULL},
/* 1DF52 */ { NULL,NULL},
/* 1DF53 */ { NULL,NULL},
/* 1DF54 */ { NULL,NULL},
/* 1DF55 */ { NULL,NULL},
/* 1DF56 */ { NULL,NULL},
/* 1DF57 */ { NULL,NULL},
/* 1DF58 */ { NULL,NULL},
/* 1DF59 */ { NULL,NULL},
/* 1DF5A */ { NULL,NULL},
/* 1DF5B */ { NULL,NULL},
/* 1DF5C */ { NULL,NULL},
/* 1DF5D */ { NULL,NULL},
/* 1DF5E */ { NULL,NULL},
/* 1DF5F */ { NULL,NULL},
/* 1DF60 */ { NULL,NULL},
/* 1DF61 */ { NULL,NULL},
/* 1DF62 */ { NULL,NULL},
/* 1DF63 */ { NULL,NULL},
/* 1DF64 */ { NULL,NULL},
/* 1DF65 */ { NULL,NULL},
/* 1DF66 */ { NULL,NULL},
/* 1DF67 */ { NULL,NULL},
/* 1DF68 */ { NULL,NULL},
/* 1DF69 */ { NULL,NULL},
/* 1DF6A */ { NULL,NULL},
/* 1DF6B */ { NULL,NULL},
/* 1DF6C */ { NULL,NULL},
/* 1DF6D */ { NULL,NULL},
/* 1DF6E */ { NULL,NULL},
/* 1DF6F */ { NULL,NULL},
/* 1DF70 */ { NULL,NULL},
/* 1DF71 */ { NULL,NULL},
/* 1DF72 */ { NULL,NULL},
/* 1DF73 */ { NULL,NULL},
/* 1DF74 */ { NULL,NULL},
/* 1DF75 */ { NULL,NULL},
/* 1DF76 */ { NULL,NULL},
/* 1DF77 */ { NULL,NULL},
/* 1DF78 */ { NULL,NULL},
/* 1DF79 */ { NULL,NULL},
/* 1DF7A */ { NULL,NULL},
/* 1DF7B */ { NULL,NULL},
/* 1DF7C */ { NULL,NULL},
/* 1DF7D */ { NULL,NULL},
/* 1DF7E */ { NULL,NULL},
/* 1DF7F */ { NULL,NULL},
/* 1DF80 */ { NULL,NULL},
/* 1DF81 */ { NULL,NULL},
/* 1DF82 */ { NULL,NULL},
/* 1DF83 */ { NULL,NULL},
/* 1DF84 */ { NULL,NULL},
/* 1DF85 */ { NULL,NULL},
/* 1DF86 */ { NULL,NULL},
/* 1DF87 */ { NULL,NULL},
/* 1DF88 */ { NULL,NULL},
/* 1DF89 */ { NULL,NULL},
/* 1DF8A */ { NULL,NULL},
/* 1DF8B */ { NULL,NULL},
/* 1DF8C */ { NULL,NULL},
/* 1DF8D */ { NULL,NULL},
/* 1DF8E */ { NULL,NULL},
/* 1DF8F */ { NULL,NULL},
/* 1DF90 */ { NULL,NULL},
/* 1DF91 */ { NULL,NULL},
/* 1DF92 */ { NULL,NULL},
/* 1DF93 */ { NULL,NULL},
/* 1DF94 */ { NULL,NULL},
/* 1DF95 */ { NULL,NULL},
/* 1DF96 */ { NULL,NULL},
/* 1DF97 */ { NULL,NULL},
/* 1DF98 */ { NULL,NULL},
/* 1DF99 */ { NULL,NULL},
/* 1DF9A */ { NULL,NULL},
/* 1DF9B */ { NULL,NULL},
/* 1DF9C */ { NULL,NULL},
/* 1DF9D */ { NULL,NULL},
/* 1DF9E */ { NULL,NULL},
/* 1DF9F */ { NULL,NULL},
/* 1DFA0 */ { NULL,NULL},
/* 1DFA1 */ { NULL,NULL},
/* 1DFA2 */ { NULL,NULL},
/* 1DFA3 */ { NULL,NULL},
/* 1DFA4 */ { NULL,NULL},
/* 1DFA5 */ { NULL,NULL},
/* 1DFA6 */ { NULL,NULL},
/* 1DFA7 */ { NULL,NULL},
/* 1DFA8 */ { NULL,NULL},
/* 1DFA9 */ { NULL,NULL},
/* 1DFAA */ { NULL,NULL},
/* 1DFAB */ { NULL,NULL},
/* 1DFAC */ { NULL,NULL},
/* 1DFAD */ { NULL,NULL},
/* 1DFAE */ { NULL,NULL},
/* 1DFAF */ { NULL,NULL},
/* 1DFB0 */ { NULL,NULL},
/* 1DFB1 */ { NULL,NULL},
/* 1DFB2 */ { NULL,NULL},
/* 1DFB3 */ { NULL,NULL},
/* 1DFB4 */ { NULL,NULL},
/* 1DFB5 */ { NULL,NULL},
/* 1DFB6 */ { NULL,NULL},
/* 1DFB7 */ { NULL,NULL},
/* 1DFB8 */ { NULL,NULL},
/* 1DFB9 */ { NULL,NULL},
/* 1DFBA */ { NULL,NULL},
/* 1DFBB */ { NULL,NULL},
/* 1DFBC */ { NULL,NULL},
/* 1DFBD */ { NULL,NULL},
/* 1DFBE */ { NULL,NULL},
/* 1DFBF */ { NULL,NULL},
/* 1DFC0 */ { NULL,NULL},
/* 1DFC1 */ { NULL,NULL},
/* 1DFC2 */ { NULL,NULL},
/* 1DFC3 */ { NULL,NULL},
/* 1DFC4 */ { NULL,NULL},
/* 1DFC5 */ { NULL,NULL},
/* 1DFC6 */ { NULL,NULL},
/* 1DFC7 */ { NULL,NULL},
/* 1DFC8 */ { NULL,NULL},
/* 1DFC9 */ { NULL,NULL},
/* 1DFCA */ { NULL,NULL},
/* 1DFCB */ { NULL,NULL},
/* 1DFCC */ { NULL,NULL},
/* 1DFCD */ { NULL,NULL},
/* 1DFCE */ { NULL,NULL},
/* 1DFCF */ { NULL,NULL},
/* 1DFD0 */ { NULL,NULL},
/* 1DFD1 */ { NULL,NULL},
/* 1DFD2 */ { NULL,NULL},
/* 1DFD3 */ { NULL,NULL},
/* 1DFD4 */ { NULL,NULL},
/* 1DFD5 */ { NULL,NULL},
/* 1DFD6 */ { NULL,NULL},
/* 1DFD7 */ { NULL,NULL},
/* 1DFD8 */ { NULL,NULL},
/* 1DFD9 */ { NULL,NULL},
/* 1DFDA */ { NULL,NULL},
/* 1DFDB */ { NULL,NULL},
/* 1DFDC */ { NULL,NULL},
/* 1DFDD */ { NULL,NULL},
/* 1DFDE */ { NULL,NULL},
/* 1DFDF */ { NULL,NULL},
/* 1DFE0 */ { NULL,NULL},
/* 1DFE1 */ { NULL,NULL},
/* 1DFE2 */ { NULL,NULL},
/* 1DFE3 */ { NULL,NULL},
/* 1DFE4 */ { NULL,NULL},
/* 1DFE5 */ { NULL,NULL},
/* 1DFE6 */ { NULL,NULL},
/* 1DFE7 */ { NULL,NULL},
/* 1DFE8 */ { NULL,NULL},
/* 1DFE9 */ { NULL,NULL},
/* 1DFEA */ { NULL,NULL},
/* 1DFEB */ { NULL,NULL},
/* 1DFEC */ { NULL,NULL},
/* 1DFED */ { NULL,NULL},
/* 1DFEE */ { NULL,NULL},
/* 1DFEF */ { NULL,NULL},
/* 1DFF0 */ { NULL,NULL},
/* 1DFF1 */ { NULL,NULL},
/* 1DFF2 */ { NULL,NULL},
/* 1DFF3 */ { NULL,NULL},
/* 1DFF4 */ { NULL,NULL},
/* 1DFF5 */ { NULL,NULL},
/* 1DFF6 */ { NULL,NULL},
/* 1DFF7 */ { NULL,NULL},
/* 1DFF8 */ { NULL,NULL},
/* 1DFF9 */ { NULL,NULL},
/* 1DFFA */ { NULL,NULL},
/* 1DFFB */ { NULL,NULL},
/* 1DFFC */ { NULL,NULL},
/* 1DFFD */ { NULL,NULL},
/* 1DFFE */ { NULL,NULL},
/* 1DFFF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_E0[] = {
/* 1E000 */ { "COMBINING GLAGOLITIC LETTER AZU",NULL},
/* 1E001 */ { "COMBINING GLAGOLITIC LETTER BUKY",NULL},
/* 1E002 */ { "COMBINING GLAGOLITIC LETTER VEDE",NULL},
/* 1E003 */ { "COMBINING GLAGOLITIC LETTER GLAGOLI",NULL},
/* 1E004 */ { "COMBINING GLAGOLITIC LETTER DOBRO",NULL},
/* 1E005 */ { "COMBINING GLAGOLITIC LETTER YESTU",NULL},
/* 1E006 */ { "COMBINING GLAGOLITIC LETTER ZHIVETE",NULL},
/* 1E007 */ { NULL,NULL},
/* 1E008 */ { "COMBINING GLAGOLITIC LETTER ZEMLJA",NULL},
/* 1E009 */ { "COMBINING GLAGOLITIC LETTER IZHE",NULL},
/* 1E00A */ { "COMBINING GLAGOLITIC LETTER INITIAL IZHE",NULL},
/* 1E00B */ { "COMBINING GLAGOLITIC LETTER I",NULL},
/* 1E00C */ { "COMBINING GLAGOLITIC LETTER DJERVI",NULL},
/* 1E00D */ { "COMBINING GLAGOLITIC LETTER KAKO",NULL},
/* 1E00E */ { "COMBINING GLAGOLITIC LETTER LJUDIJE",NULL},
/* 1E00F */ { "COMBINING GLAGOLITIC LETTER MYSLITE",NULL},
/* 1E010 */ { "COMBINING GLAGOLITIC LETTER NASHI",NULL},
/* 1E011 */ { "COMBINING GLAGOLITIC LETTER ONU",NULL},
/* 1E012 */ { "COMBINING GLAGOLITIC LETTER POKOJI",NULL},
/* 1E013 */ { "COMBINING GLAGOLITIC LETTER RITSI",NULL},
/* 1E014 */ { "COMBINING GLAGOLITIC LETTER SLOVO",NULL},
/* 1E015 */ { "COMBINING GLAGOLITIC LETTER TVRIDO",NULL},
/* 1E016 */ { "COMBINING GLAGOLITIC LETTER UKU",NULL},
/* 1E017 */ { "COMBINING GLAGOLITIC LETTER FRITU",NULL},
/* 1E018 */ { "COMBINING GLAGOLITIC LETTER HERU",NULL},
/* 1E019 */ { NULL,NULL},
/* 1E01A */ { NULL,NULL},
/* 1E01B */ { "COMBINING GLAGOLITIC LETTER SHTA",NULL},
/* 1E01C */ { "COMBINING GLAGOLITIC LETTER TSI",NULL},
/* 1E01D */ { "COMBINING GLAGOLITIC LETTER CHRIVI",NULL},
/* 1E01E */ { "COMBINING GLAGOLITIC LETTER SHA",NULL},
/* 1E01F */ { "COMBINING GLAGOLITIC LETTER YERU",NULL},
/* 1E020 */ { "COMBINING GLAGOLITIC LETTER YERI",NULL},
/* 1E021 */ { "COMBINING GLAGOLITIC LETTER YATI",NULL},
/* 1E022 */ { NULL,NULL},
/* 1E023 */ { "COMBINING GLAGOLITIC LETTER YU",NULL},
/* 1E024 */ { "COMBINING GLAGOLITIC LETTER SMALL YUS",NULL},
/* 1E025 */ { NULL,NULL},
/* 1E026 */ { "COMBINING GLAGOLITIC LETTER YO",NULL},
/* 1E027 */ { "COMBINING GLAGOLITIC LETTER IOTATED SMALL YUS",NULL},
/* 1E028 */ { "COMBINING GLAGOLITIC LETTER BIG YUS",NULL},
/* 1E029 */ { "COMBINING GLAGOLITIC LETTER IOTATED BIG YUS",NULL},
/* 1E02A */ { "COMBINING GLAGOLITIC LETTER FITA",NULL},
/* 1E02B */ { NULL,NULL},
/* 1E02C */ { NULL,NULL},
/* 1E02D */ { NULL,NULL},
/* 1E02E */ { NULL,NULL},
/* 1E02F */ { NULL,NULL},
/* 1E030 */ { "MODIFIER LETTER CYRILLIC SMALL A","	# <super> 0430"},
/* 1E031 */ { "MODIFIER LETTER CYRILLIC SMALL BE","	# <super> 0431"},
/* 1E032 */ { "MODIFIER LETTER CYRILLIC SMALL VE","	# <super> 0432"},
/* 1E033 */ { "MODIFIER LETTER CYRILLIC SMALL GHE","	# <super> 0433"},
/* 1E034 */ { "MODIFIER LETTER CYRILLIC SMALL DE","	# <super> 0434"},
/* 1E035 */ { "MODIFIER LETTER CYRILLIC SMALL IE","	# <super> 0435"},
/* 1E036 */ { "MODIFIER LETTER CYRILLIC SMALL ZHE","	# <super> 0436"},
/* 1E037 */ { "MODIFIER LETTER CYRILLIC SMALL ZE","	# <super> 0437"},
/* 1E038 */ { "MODIFIER LETTER CYRILLIC SMALL I","	# <super> 0438"},
/* 1E039 */ { "MODIFIER LETTER CYRILLIC SMALL KA","	# <super> 043A"},
/* 1E03A */ { "MODIFIER LETTER CYRILLIC SMALL EL","	# <super> 043B"},
/* 1E03B */ { "MODIFIER LETTER CYRILLIC SMALL EM","	# <super> 043C"},
/* 1E03C */ { "MODIFIER LETTER CYRILLIC SMALL O","	# <super> 043E"},
/* 1E03D */ { "MODIFIER LETTER CYRILLIC SMALL PE","	# <super> 043F"},
/* 1E03E */ { "MODIFIER LETTER CYRILLIC SMALL ER","	# <super> 0440"},
/* 1E03F */ { "MODIFIER LETTER CYRILLIC SMALL ES","	# <super> 0441"},
/* 1E040 */ { "MODIFIER LETTER CYRILLIC SMALL TE","	# <super> 0442"},
/* 1E041 */ { "MODIFIER LETTER CYRILLIC SMALL U","	# <super> 0443"},
/* 1E042 */ { "MODIFIER LETTER CYRILLIC SMALL EF","	# <super> 0444"},
/* 1E043 */ { "MODIFIER LETTER CYRILLIC SMALL HA","	# <super> 0445"},
/* 1E044 */ { "MODIFIER LETTER CYRILLIC SMALL TSE","	# <super> 0446"},
/* 1E045 */ { "MODIFIER LETTER CYRILLIC SMALL CHE","	# <super> 0447"},
/* 1E046 */ { "MODIFIER LETTER CYRILLIC SMALL SHA","	# <super> 0448"},
/* 1E047 */ { "MODIFIER LETTER CYRILLIC SMALL YERU","	# <super> 044B"},
/* 1E048 */ { "MODIFIER LETTER CYRILLIC SMALL E","	# <super> 044D"},
/* 1E049 */ { "MODIFIER LETTER CYRILLIC SMALL YU","	# <super> 044E"},
/* 1E04A */ { "MODIFIER LETTER CYRILLIC SMALL DZZE","	# <super> A689"},
/* 1E04B */ { "MODIFIER LETTER CYRILLIC SMALL SCHWA","	# <super> 04D9"},
/* 1E04C */ { "MODIFIER LETTER CYRILLIC SMALL BYELORUSSIAN-UKRAINIAN I","	# <super> 0456"},
/* 1E04D */ { "MODIFIER LETTER CYRILLIC SMALL JE","	# <super> 0458"},
/* 1E04E */ { "MODIFIER LETTER CYRILLIC SMALL BARRED O","	# <super> 04E9"},
/* 1E04F */ { "MODIFIER LETTER CYRILLIC SMALL STRAIGHT U","	# <super> 04AF"},
/* 1E050 */ { "MODIFIER LETTER CYRILLIC SMALL PALOCHKA","	# <super> 04CF"},
/* 1E051 */ { "CYRILLIC SUBSCRIPT SMALL LETTER A","	# <sub> 0430"},
/* 1E052 */ { "CYRILLIC SUBSCRIPT SMALL LETTER BE","	# <sub> 0431"},
/* 1E053 */ { "CYRILLIC SUBSCRIPT SMALL LETTER VE","	# <sub> 0432"},
/* 1E054 */ { "CYRILLIC SUBSCRIPT SMALL LETTER GHE","	# <sub> 0433"},
/* 1E055 */ { "CYRILLIC SUBSCRIPT SMALL LETTER DE","	# <sub> 0434"},
/* 1E056 */ { "CYRILLIC SUBSCRIPT SMALL LETTER IE","	# <sub> 0435"},
/* 1E057 */ { "CYRILLIC SUBSCRIPT SMALL LETTER ZHE","	# <sub> 0436"},
/* 1E058 */ { "CYRILLIC SUBSCRIPT SMALL LETTER ZE","	# <sub> 0437"},
/* 1E059 */ { "CYRILLIC SUBSCRIPT SMALL LETTER I","	# <sub> 0438"},
/* 1E05A */ { "CYRILLIC SUBSCRIPT SMALL LETTER KA","	# <sub> 043A"},
/* 1E05B */ { "CYRILLIC SUBSCRIPT SMALL LETTER EL","	# <sub> 043B"},
/* 1E05C */ { "CYRILLIC SUBSCRIPT SMALL LETTER O","	# <sub> 043E"},
/* 1E05D */ { "CYRILLIC SUBSCRIPT SMALL LETTER PE","	# <sub> 043F"},
/* 1E05E */ { "CYRILLIC SUBSCRIPT SMALL LETTER ES","	# <sub> 0441"},
/* 1E05F */ { "CYRILLIC SUBSCRIPT SMALL LETTER U","	# <sub> 0443"},
/* 1E060 */ { "CYRILLIC SUBSCRIPT SMALL LETTER EF","	# <sub> 0444"},
/* 1E061 */ { "CYRILLIC SUBSCRIPT SMALL LETTER HA","	# <sub> 0445"},
/* 1E062 */ { "CYRILLIC SUBSCRIPT SMALL LETTER TSE","	# <sub> 0446"},
/* 1E063 */ { "CYRILLIC SUBSCRIPT SMALL LETTER CHE","	# <sub> 0447"},
/* 1E064 */ { "CYRILLIC SUBSCRIPT SMALL LETTER SHA","	# <sub> 0448"},
/* 1E065 */ { "CYRILLIC SUBSCRIPT SMALL LETTER HARD SIGN","	# <sub> 044A"},
/* 1E066 */ { "CYRILLIC SUBSCRIPT SMALL LETTER YERU","	# <sub> 044B"},
/* 1E067 */ { "CYRILLIC SUBSCRIPT SMALL LETTER GHE WITH UPTURN","	# <sub> 0491"},
/* 1E068 */ { "CYRILLIC SUBSCRIPT SMALL LETTER BYELORUSSIAN-UKRAINIAN I","	# <sub> 0456"},
/* 1E069 */ { "CYRILLIC SUBSCRIPT SMALL LETTER DZE","	# <sub> 0455"},
/* 1E06A */ { "CYRILLIC SUBSCRIPT SMALL LETTER DZHE","	# <sub> 045F"},
/* 1E06B */ { "MODIFIER LETTER CYRILLIC SMALL ES WITH DESCENDER","	# <super> 04AB"},
/* 1E06C */ { "MODIFIER LETTER CYRILLIC SMALL YERU WITH BACK YER","	# <super> A651"},
/* 1E06D */ { "MODIFIER LETTER CYRILLIC SMALL STRAIGHT U WITH STROKE","	# <super> 04B1"},
/* 1E06E */ { NULL,NULL},
/* 1E06F */ { NULL,NULL},
/* 1E070 */ { NULL,NULL},
/* 1E071 */ { NULL,NULL},
/* 1E072 */ { NULL,NULL},
/* 1E073 */ { NULL,NULL},
/* 1E074 */ { NULL,NULL},
/* 1E075 */ { NULL,NULL},
/* 1E076 */ { NULL,NULL},
/* 1E077 */ { NULL,NULL},
/* 1E078 */ { NULL,NULL},
/* 1E079 */ { NULL,NULL},
/* 1E07A */ { NULL,NULL},
/* 1E07B */ { NULL,NULL},
/* 1E07C */ { NULL,NULL},
/* 1E07D */ { NULL,NULL},
/* 1E07E */ { NULL,NULL},
/* 1E07F */ { NULL,NULL},
/* 1E080 */ { NULL,NULL},
/* 1E081 */ { NULL,NULL},
/* 1E082 */ { NULL,NULL},
/* 1E083 */ { NULL,NULL},
/* 1E084 */ { NULL,NULL},
/* 1E085 */ { NULL,NULL},
/* 1E086 */ { NULL,NULL},
/* 1E087 */ { NULL,NULL},
/* 1E088 */ { NULL,NULL},
/* 1E089 */ { NULL,NULL},
/* 1E08A */ { NULL,NULL},
/* 1E08B */ { NULL,NULL},
/* 1E08C */ { NULL,NULL},
/* 1E08D */ { NULL,NULL},
/* 1E08E */ { NULL,NULL},
/* 1E08F */ { "COMBINING CYRILLIC SMALL LETTER BYELORUSSIAN-UKRAINIAN I",NULL},
/* 1E090 */ { NULL,NULL},
/* 1E091 */ { NULL,NULL},
/* 1E092 */ { NULL,NULL},
/* 1E093 */ { NULL,NULL},
/* 1E094 */ { NULL,NULL},
/* 1E095 */ { NULL,NULL},
/* 1E096 */ { NULL,NULL},
/* 1E097 */ { NULL,NULL},
/* 1E098 */ { NULL,NULL},
/* 1E099 */ { NULL,NULL},
/* 1E09A */ { NULL,NULL},
/* 1E09B */ { NULL,NULL},
/* 1E09C */ { NULL,NULL},
/* 1E09D */ { NULL,NULL},
/* 1E09E */ { NULL,NULL},
/* 1E09F */ { NULL,NULL},
/* 1E0A0 */ { NULL,NULL},
/* 1E0A1 */ { NULL,NULL},
/* 1E0A2 */ { NULL,NULL},
/* 1E0A3 */ { NULL,NULL},
/* 1E0A4 */ { NULL,NULL},
/* 1E0A5 */ { NULL,NULL},
/* 1E0A6 */ { NULL,NULL},
/* 1E0A7 */ { NULL,NULL},
/* 1E0A8 */ { NULL,NULL},
/* 1E0A9 */ { NULL,NULL},
/* 1E0AA */ { NULL,NULL},
/* 1E0AB */ { NULL,NULL},
/* 1E0AC */ { NULL,NULL},
/* 1E0AD */ { NULL,NULL},
/* 1E0AE */ { NULL,NULL},
/* 1E0AF */ { NULL,NULL},
/* 1E0B0 */ { NULL,NULL},
/* 1E0B1 */ { NULL,NULL},
/* 1E0B2 */ { NULL,NULL},
/* 1E0B3 */ { NULL,NULL},
/* 1E0B4 */ { NULL,NULL},
/* 1E0B5 */ { NULL,NULL},
/* 1E0B6 */ { NULL,NULL},
/* 1E0B7 */ { NULL,NULL},
/* 1E0B8 */ { NULL,NULL},
/* 1E0B9 */ { NULL,NULL},
/* 1E0BA */ { NULL,NULL},
/* 1E0BB */ { NULL,NULL},
/* 1E0BC */ { NULL,NULL},
/* 1E0BD */ { NULL,NULL},
/* 1E0BE */ { NULL,NULL},
/* 1E0BF */ { NULL,NULL},
/* 1E0C0 */ { NULL,NULL},
/* 1E0C1 */ { NULL,NULL},
/* 1E0C2 */ { NULL,NULL},
/* 1E0C3 */ { NULL,NULL},
/* 1E0C4 */ { NULL,NULL},
/* 1E0C5 */ { NULL,NULL},
/* 1E0C6 */ { NULL,NULL},
/* 1E0C7 */ { NULL,NULL},
/* 1E0C8 */ { NULL,NULL},
/* 1E0C9 */ { NULL,NULL},
/* 1E0CA */ { NULL,NULL},
/* 1E0CB */ { NULL,NULL},
/* 1E0CC */ { NULL,NULL},
/* 1E0CD */ { NULL,NULL},
/* 1E0CE */ { NULL,NULL},
/* 1E0CF */ { NULL,NULL},
/* 1E0D0 */ { NULL,NULL},
/* 1E0D1 */ { NULL,NULL},
/* 1E0D2 */ { NULL,NULL},
/* 1E0D3 */ { NULL,NULL},
/* 1E0D4 */ { NULL,NULL},
/* 1E0D5 */ { NULL,NULL},
/* 1E0D6 */ { NULL,NULL},
/* 1E0D7 */ { NULL,NULL},
/* 1E0D8 */ { NULL,NULL},
/* 1E0D9 */ { NULL,NULL},
/* 1E0DA */ { NULL,NULL},
/* 1E0DB */ { NULL,NULL},
/* 1E0DC */ { NULL,NULL},
/* 1E0DD */ { NULL,NULL},
/* 1E0DE */ { NULL,NULL},
/* 1E0DF */ { NULL,NULL},
/* 1E0E0 */ { NULL,NULL},
/* 1E0E1 */ { NULL,NULL},
/* 1E0E2 */ { NULL,NULL},
/* 1E0E3 */ { NULL,NULL},
/* 1E0E4 */ { NULL,NULL},
/* 1E0E5 */ { NULL,NULL},
/* 1E0E6 */ { NULL,NULL},
/* 1E0E7 */ { NULL,NULL},
/* 1E0E8 */ { NULL,NULL},
/* 1E0E9 */ { NULL,NULL},
/* 1E0EA */ { NULL,NULL},
/* 1E0EB */ { NULL,NULL},
/* 1E0EC */ { NULL,NULL},
/* 1E0ED */ { NULL,NULL},
/* 1E0EE */ { NULL,NULL},
/* 1E0EF */ { NULL,NULL},
/* 1E0F0 */ { NULL,NULL},
/* 1E0F1 */ { NULL,NULL},
/* 1E0F2 */ { NULL,NULL},
/* 1E0F3 */ { NULL,NULL},
/* 1E0F4 */ { NULL,NULL},
/* 1E0F5 */ { NULL,NULL},
/* 1E0F6 */ { NULL,NULL},
/* 1E0F7 */ { NULL,NULL},
/* 1E0F8 */ { NULL,NULL},
/* 1E0F9 */ { NULL,NULL},
/* 1E0FA */ { NULL,NULL},
/* 1E0FB */ { NULL,NULL},
/* 1E0FC */ { NULL,NULL},
/* 1E0FD */ { NULL,NULL},
/* 1E0FE */ { NULL,NULL},
/* 1E0FF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_E1[] = {
/* 1E100 */ { "NYIAKENG PUACHUE HMONG LETTER MA","	x (hebrew letter mem - 05DE)"},
/* 1E101 */ { "NYIAKENG PUACHUE HMONG LETTER TSA",NULL},
/* 1E102 */ { "NYIAKENG PUACHUE HMONG LETTER NTA",NULL},
/* 1E103 */ { "NYIAKENG PUACHUE HMONG LETTER TA","	x (hebrew letter tet - 05D8)"},
/* 1E104 */ { "NYIAKENG PUACHUE HMONG LETTER HA",NULL},
/* 1E105 */ { "NYIAKENG PUACHUE HMONG LETTER NA",NULL},
/* 1E106 */ { "NYIAKENG PUACHUE HMONG LETTER XA",NULL},
/* 1E107 */ { "NYIAKENG PUACHUE HMONG LETTER NKA",NULL},
/* 1E108 */ { "NYIAKENG PUACHUE HMONG LETTER CA",NULL},
/* 1E109 */ { "NYIAKENG PUACHUE HMONG LETTER LA",NULL},
/* 1E10A */ { "NYIAKENG PUACHUE HMONG LETTER SA","	x (hebrew letter shin - 05E9)"},
/* 1E10B */ { "NYIAKENG PUACHUE HMONG LETTER ZA",NULL},
/* 1E10C */ { "NYIAKENG PUACHUE HMONG LETTER NCA",NULL},
/* 1E10D */ { "NYIAKENG PUACHUE HMONG LETTER NTSA",NULL},
/* 1E10E */ { "NYIAKENG PUACHUE HMONG LETTER KA","	x (hebrew letter kaf - 05DB)"},
/* 1E10F */ { "NYIAKENG PUACHUE HMONG LETTER DA",NULL},
/* 1E110 */ { "NYIAKENG PUACHUE HMONG LETTER NYA",NULL},
/* 1E111 */ { "NYIAKENG PUACHUE HMONG LETTER NRA",NULL},
/* 1E112 */ { "NYIAKENG PUACHUE HMONG LETTER VA",NULL},
/* 1E113 */ { "NYIAKENG PUACHUE HMONG LETTER NTXA",NULL},
/* 1E114 */ { "NYIAKENG PUACHUE HMONG LETTER TXA",NULL},
/* 1E115 */ { "NYIAKENG PUACHUE HMONG LETTER FA",NULL},
/* 1E116 */ { "NYIAKENG PUACHUE HMONG LETTER RA",NULL},
/* 1E117 */ { "NYIAKENG PUACHUE HMONG LETTER QA","	x (hebrew letter qof - 05E7)"},
/* 1E118 */ { "NYIAKENG PUACHUE HMONG LETTER YA",NULL},
/* 1E119 */ { "NYIAKENG PUACHUE HMONG LETTER NQA",NULL},
/* 1E11A */ { "NYIAKENG PUACHUE HMONG LETTER PA","	x (hebrew letter pe - 05E4)"},
/* 1E11B */ { "NYIAKENG PUACHUE HMONG LETTER XYA",NULL},
/* 1E11C */ { "NYIAKENG PUACHUE HMONG LETTER NPA",NULL},
/* 1E11D */ { "NYIAKENG PUACHUE HMONG LETTER DLA",NULL},
/* 1E11E */ { "NYIAKENG PUACHUE HMONG LETTER NPLA",NULL},
/* 1E11F */ { "NYIAKENG PUACHUE HMONG LETTER HAH","	* also used for a vowel o"},
/* 1E120 */ { "NYIAKENG PUACHUE HMONG LETTER MLA",NULL},
/* 1E121 */ { "NYIAKENG PUACHUE HMONG LETTER PLA",NULL},
/* 1E122 */ { "NYIAKENG PUACHUE HMONG LETTER GA",NULL},
/* 1E123 */ { "NYIAKENG PUACHUE HMONG LETTER RRA","	* also used for a diphthong ai"},
/* 1E124 */ { "NYIAKENG PUACHUE HMONG LETTER A",NULL},
/* 1E125 */ { "NYIAKENG PUACHUE HMONG LETTER AA",NULL},
/* 1E126 */ { "NYIAKENG PUACHUE HMONG LETTER I",NULL},
/* 1E127 */ { "NYIAKENG PUACHUE HMONG LETTER U",NULL},
/* 1E128 */ { "NYIAKENG PUACHUE HMONG LETTER O",NULL},
/* 1E129 */ { "NYIAKENG PUACHUE HMONG LETTER OO",NULL},
/* 1E12A */ { "NYIAKENG PUACHUE HMONG LETTER E",NULL},
/* 1E12B */ { "NYIAKENG PUACHUE HMONG LETTER EE",NULL},
/* 1E12C */ { "NYIAKENG PUACHUE HMONG LETTER W",NULL},
/* 1E12D */ { NULL,NULL},
/* 1E12E */ { NULL,NULL},
/* 1E12F */ { NULL,NULL},
/* 1E130 */ { "NYIAKENG PUACHUE HMONG TONE-B","	= som thwb\n"
	"	* RPA -b high-level tone"},
/* 1E131 */ { "NYIAKENG PUACHUE HMONG TONE-M","	= som thwm\n"
	"	* RPA -m low-glottalized tone"},
/* 1E132 */ { "NYIAKENG PUACHUE HMONG TONE-J","	= som thwj\n"
	"	* RPA -j high-falling tone"},
/* 1E133 */ { "NYIAKENG PUACHUE HMONG TONE-V","	= som thwv\n"
	"	* RPA -v mid-rising tone"},
/* 1E134 */ { "NYIAKENG PUACHUE HMONG TONE-S","	= som thws\n"
	"	* RPA -s low-level tone"},
/* 1E135 */ { "NYIAKENG PUACHUE HMONG TONE-G","	= som thwg\n"
	"	* RPA -g falling-breathy tone"},
/* 1E136 */ { "NYIAKENG PUACHUE HMONG TONE-D","	= som thwd\n"
	"	* RPA -d low-rising tone"},
/* 1E137 */ { "NYIAKENG PUACHUE HMONG SIGN FOR PERSON","	= oov"},
/* 1E138 */ { "NYIAKENG PUACHUE HMONG SIGN FOR THING","	= pes"},
/* 1E139 */ { "NYIAKENG PUACHUE HMONG SIGN FOR LOCATION","	= khab theeb"},
/* 1E13A */ { "NYIAKENG PUACHUE HMONG SIGN FOR ANIMAL","	= khuam luas"},
/* 1E13B */ { "NYIAKENG PUACHUE HMONG SIGN FOR INVERTEBRATE","	= poos"},
/* 1E13C */ { "NYIAKENG PUACHUE HMONG SIGN XW XW","	* indicates repetition of a short word or syllable\n"
	"	* indicates repetition of a whole phrase or sentence when preceded by a space\n"
	"	x (thai character maiyamok - 0E46)\n"
	"	x (lao ko la - 0EC6)"},
/* 1E13D */ { "NYIAKENG PUACHUE HMONG SYLLABLE LENGTHENER","	= khu saim"},
/* 1E13E */ { NULL,NULL},
/* 1E13F */ { NULL,NULL},
/* 1E140 */ { "NYIAKENG PUACHUE HMONG DIGIT ZERO",NULL},
/* 1E141 */ { "NYIAKENG PUACHUE HMONG DIGIT ONE",NULL},
/* 1E142 */ { "NYIAKENG PUACHUE HMONG DIGIT TWO",NULL},
/* 1E143 */ { "NYIAKENG PUACHUE HMONG DIGIT THREE",NULL},
/* 1E144 */ { "NYIAKENG PUACHUE HMONG DIGIT FOUR",NULL},
/* 1E145 */ { "NYIAKENG PUACHUE HMONG DIGIT FIVE",NULL},
/* 1E146 */ { "NYIAKENG PUACHUE HMONG DIGIT SIX",NULL},
/* 1E147 */ { "NYIAKENG PUACHUE HMONG DIGIT SEVEN",NULL},
/* 1E148 */ { "NYIAKENG PUACHUE HMONG DIGIT EIGHT",NULL},
/* 1E149 */ { "NYIAKENG PUACHUE HMONG DIGIT NINE",NULL},
/* 1E14A */ { NULL,NULL},
/* 1E14B */ { NULL,NULL},
/* 1E14C */ { NULL,NULL},
/* 1E14D */ { NULL,NULL},
/* 1E14E */ { "NYIAKENG PUACHUE HMONG LOGOGRAM NYAJ","	* used to represent the word for money or currency"},
/* 1E14F */ { "NYIAKENG PUACHUE HMONG CIRCLED CA","	* used to indicate ownership\n"
	"	x (nyiakeng puachue hmong letter ca - 1E108)"},
/* 1E150 */ { NULL,NULL},
/* 1E151 */ { NULL,NULL},
/* 1E152 */ { NULL,NULL},
/* 1E153 */ { NULL,NULL},
/* 1E154 */ { NULL,NULL},
/* 1E155 */ { NULL,NULL},
/* 1E156 */ { NULL,NULL},
/* 1E157 */ { NULL,NULL},
/* 1E158 */ { NULL,NULL},
/* 1E159 */ { NULL,NULL},
/* 1E15A */ { NULL,NULL},
/* 1E15B */ { NULL,NULL},
/* 1E15C */ { NULL,NULL},
/* 1E15D */ { NULL,NULL},
/* 1E15E */ { NULL,NULL},
/* 1E15F */ { NULL,NULL},
/* 1E160 */ { NULL,NULL},
/* 1E161 */ { NULL,NULL},
/* 1E162 */ { NULL,NULL},
/* 1E163 */ { NULL,NULL},
/* 1E164 */ { NULL,NULL},
/* 1E165 */ { NULL,NULL},
/* 1E166 */ { NULL,NULL},
/* 1E167 */ { NULL,NULL},
/* 1E168 */ { NULL,NULL},
/* 1E169 */ { NULL,NULL},
/* 1E16A */ { NULL,NULL},
/* 1E16B */ { NULL,NULL},
/* 1E16C */ { NULL,NULL},
/* 1E16D */ { NULL,NULL},
/* 1E16E */ { NULL,NULL},
/* 1E16F */ { NULL,NULL},
/* 1E170 */ { NULL,NULL},
/* 1E171 */ { NULL,NULL},
/* 1E172 */ { NULL,NULL},
/* 1E173 */ { NULL,NULL},
/* 1E174 */ { NULL,NULL},
/* 1E175 */ { NULL,NULL},
/* 1E176 */ { NULL,NULL},
/* 1E177 */ { NULL,NULL},
/* 1E178 */ { NULL,NULL},
/* 1E179 */ { NULL,NULL},
/* 1E17A */ { NULL,NULL},
/* 1E17B */ { NULL,NULL},
/* 1E17C */ { NULL,NULL},
/* 1E17D */ { NULL,NULL},
/* 1E17E */ { NULL,NULL},
/* 1E17F */ { NULL,NULL},
/* 1E180 */ { NULL,NULL},
/* 1E181 */ { NULL,NULL},
/* 1E182 */ { NULL,NULL},
/* 1E183 */ { NULL,NULL},
/* 1E184 */ { NULL,NULL},
/* 1E185 */ { NULL,NULL},
/* 1E186 */ { NULL,NULL},
/* 1E187 */ { NULL,NULL},
/* 1E188 */ { NULL,NULL},
/* 1E189 */ { NULL,NULL},
/* 1E18A */ { NULL,NULL},
/* 1E18B */ { NULL,NULL},
/* 1E18C */ { NULL,NULL},
/* 1E18D */ { NULL,NULL},
/* 1E18E */ { NULL,NULL},
/* 1E18F */ { NULL,NULL},
/* 1E190 */ { NULL,NULL},
/* 1E191 */ { NULL,NULL},
/* 1E192 */ { NULL,NULL},
/* 1E193 */ { NULL,NULL},
/* 1E194 */ { NULL,NULL},
/* 1E195 */ { NULL,NULL},
/* 1E196 */ { NULL,NULL},
/* 1E197 */ { NULL,NULL},
/* 1E198 */ { NULL,NULL},
/* 1E199 */ { NULL,NULL},
/* 1E19A */ { NULL,NULL},
/* 1E19B */ { NULL,NULL},
/* 1E19C */ { NULL,NULL},
/* 1E19D */ { NULL,NULL},
/* 1E19E */ { NULL,NULL},
/* 1E19F */ { NULL,NULL},
/* 1E1A0 */ { NULL,NULL},
/* 1E1A1 */ { NULL,NULL},
/* 1E1A2 */ { NULL,NULL},
/* 1E1A3 */ { NULL,NULL},
/* 1E1A4 */ { NULL,NULL},
/* 1E1A5 */ { NULL,NULL},
/* 1E1A6 */ { NULL,NULL},
/* 1E1A7 */ { NULL,NULL},
/* 1E1A8 */ { NULL,NULL},
/* 1E1A9 */ { NULL,NULL},
/* 1E1AA */ { NULL,NULL},
/* 1E1AB */ { NULL,NULL},
/* 1E1AC */ { NULL,NULL},
/* 1E1AD */ { NULL,NULL},
/* 1E1AE */ { NULL,NULL},
/* 1E1AF */ { NULL,NULL},
/* 1E1B0 */ { NULL,NULL},
/* 1E1B1 */ { NULL,NULL},
/* 1E1B2 */ { NULL,NULL},
/* 1E1B3 */ { NULL,NULL},
/* 1E1B4 */ { NULL,NULL},
/* 1E1B5 */ { NULL,NULL},
/* 1E1B6 */ { NULL,NULL},
/* 1E1B7 */ { NULL,NULL},
/* 1E1B8 */ { NULL,NULL},
/* 1E1B9 */ { NULL,NULL},
/* 1E1BA */ { NULL,NULL},
/* 1E1BB */ { NULL,NULL},
/* 1E1BC */ { NULL,NULL},
/* 1E1BD */ { NULL,NULL},
/* 1E1BE */ { NULL,NULL},
/* 1E1BF */ { NULL,NULL},
/* 1E1C0 */ { NULL,NULL},
/* 1E1C1 */ { NULL,NULL},
/* 1E1C2 */ { NULL,NULL},
/* 1E1C3 */ { NULL,NULL},
/* 1E1C4 */ { NULL,NULL},
/* 1E1C5 */ { NULL,NULL},
/* 1E1C6 */ { NULL,NULL},
/* 1E1C7 */ { NULL,NULL},
/* 1E1C8 */ { NULL,NULL},
/* 1E1C9 */ { NULL,NULL},
/* 1E1CA */ { NULL,NULL},
/* 1E1CB */ { NULL,NULL},
/* 1E1CC */ { NULL,NULL},
/* 1E1CD */ { NULL,NULL},
/* 1E1CE */ { NULL,NULL},
/* 1E1CF */ { NULL,NULL},
/* 1E1D0 */ { NULL,NULL},
/* 1E1D1 */ { NULL,NULL},
/* 1E1D2 */ { NULL,NULL},
/* 1E1D3 */ { NULL,NULL},
/* 1E1D4 */ { NULL,NULL},
/* 1E1D5 */ { NULL,NULL},
/* 1E1D6 */ { NULL,NULL},
/* 1E1D7 */ { NULL,NULL},
/* 1E1D8 */ { NULL,NULL},
/* 1E1D9 */ { NULL,NULL},
/* 1E1DA */ { NULL,NULL},
/* 1E1DB */ { NULL,NULL},
/* 1E1DC */ { NULL,NULL},
/* 1E1DD */ { NULL,NULL},
/* 1E1DE */ { NULL,NULL},
/* 1E1DF */ { NULL,NULL},
/* 1E1E0 */ { NULL,NULL},
/* 1E1E1 */ { NULL,NULL},
/* 1E1E2 */ { NULL,NULL},
/* 1E1E3 */ { NULL,NULL},
/* 1E1E4 */ { NULL,NULL},
/* 1E1E5 */ { NULL,NULL},
/* 1E1E6 */ { NULL,NULL},
/* 1E1E7 */ { NULL,NULL},
/* 1E1E8 */ { NULL,NULL},
/* 1E1E9 */ { NULL,NULL},
/* 1E1EA */ { NULL,NULL},
/* 1E1EB */ { NULL,NULL},
/* 1E1EC */ { NULL,NULL},
/* 1E1ED */ { NULL,NULL},
/* 1E1EE */ { NULL,NULL},
/* 1E1EF */ { NULL,NULL},
/* 1E1F0 */ { NULL,NULL},
/* 1E1F1 */ { NULL,NULL},
/* 1E1F2 */ { NULL,NULL},
/* 1E1F3 */ { NULL,NULL},
/* 1E1F4 */ { NULL,NULL},
/* 1E1F5 */ { NULL,NULL},
/* 1E1F6 */ { NULL,NULL},
/* 1E1F7 */ { NULL,NULL},
/* 1E1F8 */ { NULL,NULL},
/* 1E1F9 */ { NULL,NULL},
/* 1E1FA */ { NULL,NULL},
/* 1E1FB */ { NULL,NULL},
/* 1E1FC */ { NULL,NULL},
/* 1E1FD */ { NULL,NULL},
/* 1E1FE */ { NULL,NULL},
/* 1E1FF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_E2[] = {
/* 1E200 */ { NULL,NULL},
/* 1E201 */ { NULL,NULL},
/* 1E202 */ { NULL,NULL},
/* 1E203 */ { NULL,NULL},
/* 1E204 */ { NULL,NULL},
/* 1E205 */ { NULL,NULL},
/* 1E206 */ { NULL,NULL},
/* 1E207 */ { NULL,NULL},
/* 1E208 */ { NULL,NULL},
/* 1E209 */ { NULL,NULL},
/* 1E20A */ { NULL,NULL},
/* 1E20B */ { NULL,NULL},
/* 1E20C */ { NULL,NULL},
/* 1E20D */ { NULL,NULL},
/* 1E20E */ { NULL,NULL},
/* 1E20F */ { NULL,NULL},
/* 1E210 */ { NULL,NULL},
/* 1E211 */ { NULL,NULL},
/* 1E212 */ { NULL,NULL},
/* 1E213 */ { NULL,NULL},
/* 1E214 */ { NULL,NULL},
/* 1E215 */ { NULL,NULL},
/* 1E216 */ { NULL,NULL},
/* 1E217 */ { NULL,NULL},
/* 1E218 */ { NULL,NULL},
/* 1E219 */ { NULL,NULL},
/* 1E21A */ { NULL,NULL},
/* 1E21B */ { NULL,NULL},
/* 1E21C */ { NULL,NULL},
/* 1E21D */ { NULL,NULL},
/* 1E21E */ { NULL,NULL},
/* 1E21F */ { NULL,NULL},
/* 1E220 */ { NULL,NULL},
/* 1E221 */ { NULL,NULL},
/* 1E222 */ { NULL,NULL},
/* 1E223 */ { NULL,NULL},
/* 1E224 */ { NULL,NULL},
/* 1E225 */ { NULL,NULL},
/* 1E226 */ { NULL,NULL},
/* 1E227 */ { NULL,NULL},
/* 1E228 */ { NULL,NULL},
/* 1E229 */ { NULL,NULL},
/* 1E22A */ { NULL,NULL},
/* 1E22B */ { NULL,NULL},
/* 1E22C */ { NULL,NULL},
/* 1E22D */ { NULL,NULL},
/* 1E22E */ { NULL,NULL},
/* 1E22F */ { NULL,NULL},
/* 1E230 */ { NULL,NULL},
/* 1E231 */ { NULL,NULL},
/* 1E232 */ { NULL,NULL},
/* 1E233 */ { NULL,NULL},
/* 1E234 */ { NULL,NULL},
/* 1E235 */ { NULL,NULL},
/* 1E236 */ { NULL,NULL},
/* 1E237 */ { NULL,NULL},
/* 1E238 */ { NULL,NULL},
/* 1E239 */ { NULL,NULL},
/* 1E23A */ { NULL,NULL},
/* 1E23B */ { NULL,NULL},
/* 1E23C */ { NULL,NULL},
/* 1E23D */ { NULL,NULL},
/* 1E23E */ { NULL,NULL},
/* 1E23F */ { NULL,NULL},
/* 1E240 */ { NULL,NULL},
/* 1E241 */ { NULL,NULL},
/* 1E242 */ { NULL,NULL},
/* 1E243 */ { NULL,NULL},
/* 1E244 */ { NULL,NULL},
/* 1E245 */ { NULL,NULL},
/* 1E246 */ { NULL,NULL},
/* 1E247 */ { NULL,NULL},
/* 1E248 */ { NULL,NULL},
/* 1E249 */ { NULL,NULL},
/* 1E24A */ { NULL,NULL},
/* 1E24B */ { NULL,NULL},
/* 1E24C */ { NULL,NULL},
/* 1E24D */ { NULL,NULL},
/* 1E24E */ { NULL,NULL},
/* 1E24F */ { NULL,NULL},
/* 1E250 */ { NULL,NULL},
/* 1E251 */ { NULL,NULL},
/* 1E252 */ { NULL,NULL},
/* 1E253 */ { NULL,NULL},
/* 1E254 */ { NULL,NULL},
/* 1E255 */ { NULL,NULL},
/* 1E256 */ { NULL,NULL},
/* 1E257 */ { NULL,NULL},
/* 1E258 */ { NULL,NULL},
/* 1E259 */ { NULL,NULL},
/* 1E25A */ { NULL,NULL},
/* 1E25B */ { NULL,NULL},
/* 1E25C */ { NULL,NULL},
/* 1E25D */ { NULL,NULL},
/* 1E25E */ { NULL,NULL},
/* 1E25F */ { NULL,NULL},
/* 1E260 */ { NULL,NULL},
/* 1E261 */ { NULL,NULL},
/* 1E262 */ { NULL,NULL},
/* 1E263 */ { NULL,NULL},
/* 1E264 */ { NULL,NULL},
/* 1E265 */ { NULL,NULL},
/* 1E266 */ { NULL,NULL},
/* 1E267 */ { NULL,NULL},
/* 1E268 */ { NULL,NULL},
/* 1E269 */ { NULL,NULL},
/* 1E26A */ { NULL,NULL},
/* 1E26B */ { NULL,NULL},
/* 1E26C */ { NULL,NULL},
/* 1E26D */ { NULL,NULL},
/* 1E26E */ { NULL,NULL},
/* 1E26F */ { NULL,NULL},
/* 1E270 */ { NULL,NULL},
/* 1E271 */ { NULL,NULL},
/* 1E272 */ { NULL,NULL},
/* 1E273 */ { NULL,NULL},
/* 1E274 */ { NULL,NULL},
/* 1E275 */ { NULL,NULL},
/* 1E276 */ { NULL,NULL},
/* 1E277 */ { NULL,NULL},
/* 1E278 */ { NULL,NULL},
/* 1E279 */ { NULL,NULL},
/* 1E27A */ { NULL,NULL},
/* 1E27B */ { NULL,NULL},
/* 1E27C */ { NULL,NULL},
/* 1E27D */ { NULL,NULL},
/* 1E27E */ { NULL,NULL},
/* 1E27F */ { NULL,NULL},
/* 1E280 */ { NULL,NULL},
/* 1E281 */ { NULL,NULL},
/* 1E282 */ { NULL,NULL},
/* 1E283 */ { NULL,NULL},
/* 1E284 */ { NULL,NULL},
/* 1E285 */ { NULL,NULL},
/* 1E286 */ { NULL,NULL},
/* 1E287 */ { NULL,NULL},
/* 1E288 */ { NULL,NULL},
/* 1E289 */ { NULL,NULL},
/* 1E28A */ { NULL,NULL},
/* 1E28B */ { NULL,NULL},
/* 1E28C */ { NULL,NULL},
/* 1E28D */ { NULL,NULL},
/* 1E28E */ { NULL,NULL},
/* 1E28F */ { NULL,NULL},
/* 1E290 */ { "TOTO LETTER PA",NULL},
/* 1E291 */ { "TOTO LETTER BA",NULL},
/* 1E292 */ { "TOTO LETTER TA",NULL},
/* 1E293 */ { "TOTO LETTER DA",NULL},
/* 1E294 */ { "TOTO LETTER KA",NULL},
/* 1E295 */ { "TOTO LETTER GA",NULL},
/* 1E296 */ { "TOTO LETTER MA",NULL},
/* 1E297 */ { "TOTO LETTER NA",NULL},
/* 1E298 */ { "TOTO LETTER NGA",NULL},
/* 1E299 */ { "TOTO LETTER SA",NULL},
/* 1E29A */ { "TOTO LETTER CHA",NULL},
/* 1E29B */ { "TOTO LETTER YA",NULL},
/* 1E29C */ { "TOTO LETTER WA",NULL},
/* 1E29D */ { "TOTO LETTER JA",NULL},
/* 1E29E */ { "TOTO LETTER HA",NULL},
/* 1E29F */ { "TOTO LETTER RA",NULL},
/* 1E2A0 */ { "TOTO LETTER LA",NULL},
/* 1E2A1 */ { "TOTO LETTER I",NULL},
/* 1E2A2 */ { "TOTO LETTER BREATHY I",NULL},
/* 1E2A3 */ { "TOTO LETTER IU",NULL},
/* 1E2A4 */ { "TOTO LETTER BREATHY IU",NULL},
/* 1E2A5 */ { "TOTO LETTER U",NULL},
/* 1E2A6 */ { "TOTO LETTER E",NULL},
/* 1E2A7 */ { "TOTO LETTER BREATHY E",NULL},
/* 1E2A8 */ { "TOTO LETTER EO",NULL},
/* 1E2A9 */ { "TOTO LETTER BREATHY EO",NULL},
/* 1E2AA */ { "TOTO LETTER O",NULL},
/* 1E2AB */ { "TOTO LETTER AE",NULL},
/* 1E2AC */ { "TOTO LETTER BREATHY AE",NULL},
/* 1E2AD */ { "TOTO LETTER A",NULL},
/* 1E2AE */ { "TOTO SIGN RISING TONE",NULL},
/* 1E2AF */ { NULL,NULL},
/* 1E2B0 */ { NULL,NULL},
/* 1E2B1 */ { NULL,NULL},
/* 1E2B2 */ { NULL,NULL},
/* 1E2B3 */ { NULL,NULL},
/* 1E2B4 */ { NULL,NULL},
/* 1E2B5 */ { NULL,NULL},
/* 1E2B6 */ { NULL,NULL},
/* 1E2B7 */ { NULL,NULL},
/* 1E2B8 */ { NULL,NULL},
/* 1E2B9 */ { NULL,NULL},
/* 1E2BA */ { NULL,NULL},
/* 1E2BB */ { NULL,NULL},
/* 1E2BC */ { NULL,NULL},
/* 1E2BD */ { NULL,NULL},
/* 1E2BE */ { NULL,NULL},
/* 1E2BF */ { NULL,NULL},
/* 1E2C0 */ { "WANCHO LETTER AA",NULL},
/* 1E2C1 */ { "WANCHO LETTER A",NULL},
/* 1E2C2 */ { "WANCHO LETTER BA",NULL},
/* 1E2C3 */ { "WANCHO LETTER CA",NULL},
/* 1E2C4 */ { "WANCHO LETTER DA",NULL},
/* 1E2C5 */ { "WANCHO LETTER GA",NULL},
/* 1E2C6 */ { "WANCHO LETTER YA",NULL},
/* 1E2C7 */ { "WANCHO LETTER PHA",NULL},
/* 1E2C8 */ { "WANCHO LETTER LA",NULL},
/* 1E2C9 */ { "WANCHO LETTER NA",NULL},
/* 1E2CA */ { "WANCHO LETTER PA",NULL},
/* 1E2CB */ { "WANCHO LETTER TA",NULL},
/* 1E2CC */ { "WANCHO LETTER THA",NULL},
/* 1E2CD */ { "WANCHO LETTER FA",NULL},
/* 1E2CE */ { "WANCHO LETTER SA",NULL},
/* 1E2CF */ { "WANCHO LETTER SHA",NULL},
/* 1E2D0 */ { "WANCHO LETTER JA",NULL},
/* 1E2D1 */ { "WANCHO LETTER ZA",NULL},
/* 1E2D2 */ { "WANCHO LETTER WA",NULL},
/* 1E2D3 */ { "WANCHO LETTER VA",NULL},
/* 1E2D4 */ { "WANCHO LETTER KA",NULL},
/* 1E2D5 */ { "WANCHO LETTER O",NULL},
/* 1E2D6 */ { "WANCHO LETTER AU",NULL},
/* 1E2D7 */ { "WANCHO LETTER RA",NULL},
/* 1E2D8 */ { "WANCHO LETTER MA",NULL},
/* 1E2D9 */ { "WANCHO LETTER KHA",NULL},
/* 1E2DA */ { "WANCHO LETTER HA",NULL},
/* 1E2DB */ { "WANCHO LETTER E",NULL},
/* 1E2DC */ { "WANCHO LETTER I",NULL},
/* 1E2DD */ { "WANCHO LETTER NGA",NULL},
/* 1E2DE */ { "WANCHO LETTER U",NULL},
/* 1E2DF */ { "WANCHO LETTER LLHA",NULL},
/* 1E2E0 */ { "WANCHO LETTER TSA",NULL},
/* 1E2E1 */ { "WANCHO LETTER TRA",NULL},
/* 1E2E2 */ { "WANCHO LETTER ONG",NULL},
/* 1E2E3 */ { "WANCHO LETTER AANG",NULL},
/* 1E2E4 */ { "WANCHO LETTER ANG",NULL},
/* 1E2E5 */ { "WANCHO LETTER ING",NULL},
/* 1E2E6 */ { "WANCHO LETTER ON",NULL},
/* 1E2E7 */ { "WANCHO LETTER EN",NULL},
/* 1E2E8 */ { "WANCHO LETTER AAN",NULL},
/* 1E2E9 */ { "WANCHO LETTER NYA",NULL},
/* 1E2EA */ { "WANCHO LETTER UEN",NULL},
/* 1E2EB */ { "WANCHO LETTER YIH",NULL},
/* 1E2EC */ { "WANCHO TONE TUP",NULL},
/* 1E2ED */ { "WANCHO TONE TUPNI",NULL},
/* 1E2EE */ { "WANCHO TONE KOI",NULL},
/* 1E2EF */ { "WANCHO TONE KOINI",NULL},
/* 1E2F0 */ { "WANCHO DIGIT ZERO",NULL},
/* 1E2F1 */ { "WANCHO DIGIT ONE",NULL},
/* 1E2F2 */ { "WANCHO DIGIT TWO",NULL},
/* 1E2F3 */ { "WANCHO DIGIT THREE",NULL},
/* 1E2F4 */ { "WANCHO DIGIT FOUR",NULL},
/* 1E2F5 */ { "WANCHO DIGIT FIVE",NULL},
/* 1E2F6 */ { "WANCHO DIGIT SIX",NULL},
/* 1E2F7 */ { "WANCHO DIGIT SEVEN",NULL},
/* 1E2F8 */ { "WANCHO DIGIT EIGHT",NULL},
/* 1E2F9 */ { "WANCHO DIGIT NINE",NULL},
/* 1E2FA */ { NULL,NULL},
/* 1E2FB */ { NULL,NULL},
/* 1E2FC */ { NULL,NULL},
/* 1E2FD */ { NULL,NULL},
/* 1E2FE */ { NULL,NULL},
/* 1E2FF */ { "WANCHO NGUN SIGN","	= rupee\n"
	"	x (indian rupee sign - 20B9)"}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_E4[] = {
/* 1E400 */ { NULL,NULL},
/* 1E401 */ { NULL,NULL},
/* 1E402 */ { NULL,NULL},
/* 1E403 */ { NULL,NULL},
/* 1E404 */ { NULL,NULL},
/* 1E405 */ { NULL,NULL},
/* 1E406 */ { NULL,NULL},
/* 1E407 */ { NULL,NULL},
/* 1E408 */ { NULL,NULL},
/* 1E409 */ { NULL,NULL},
/* 1E40A */ { NULL,NULL},
/* 1E40B */ { NULL,NULL},
/* 1E40C */ { NULL,NULL},
/* 1E40D */ { NULL,NULL},
/* 1E40E */ { NULL,NULL},
/* 1E40F */ { NULL,NULL},
/* 1E410 */ { NULL,NULL},
/* 1E411 */ { NULL,NULL},
/* 1E412 */ { NULL,NULL},
/* 1E413 */ { NULL,NULL},
/* 1E414 */ { NULL,NULL},
/* 1E415 */ { NULL,NULL},
/* 1E416 */ { NULL,NULL},
/* 1E417 */ { NULL,NULL},
/* 1E418 */ { NULL,NULL},
/* 1E419 */ { NULL,NULL},
/* 1E41A */ { NULL,NULL},
/* 1E41B */ { NULL,NULL},
/* 1E41C */ { NULL,NULL},
/* 1E41D */ { NULL,NULL},
/* 1E41E */ { NULL,NULL},
/* 1E41F */ { NULL,NULL},
/* 1E420 */ { NULL,NULL},
/* 1E421 */ { NULL,NULL},
/* 1E422 */ { NULL,NULL},
/* 1E423 */ { NULL,NULL},
/* 1E424 */ { NULL,NULL},
/* 1E425 */ { NULL,NULL},
/* 1E426 */ { NULL,NULL},
/* 1E427 */ { NULL,NULL},
/* 1E428 */ { NULL,NULL},
/* 1E429 */ { NULL,NULL},
/* 1E42A */ { NULL,NULL},
/* 1E42B */ { NULL,NULL},
/* 1E42C */ { NULL,NULL},
/* 1E42D */ { NULL,NULL},
/* 1E42E */ { NULL,NULL},
/* 1E42F */ { NULL,NULL},
/* 1E430 */ { NULL,NULL},
/* 1E431 */ { NULL,NULL},
/* 1E432 */ { NULL,NULL},
/* 1E433 */ { NULL,NULL},
/* 1E434 */ { NULL,NULL},
/* 1E435 */ { NULL,NULL},
/* 1E436 */ { NULL,NULL},
/* 1E437 */ { NULL,NULL},
/* 1E438 */ { NULL,NULL},
/* 1E439 */ { NULL,NULL},
/* 1E43A */ { NULL,NULL},
/* 1E43B */ { NULL,NULL},
/* 1E43C */ { NULL,NULL},
/* 1E43D */ { NULL,NULL},
/* 1E43E */ { NULL,NULL},
/* 1E43F */ { NULL,NULL},
/* 1E440 */ { NULL,NULL},
/* 1E441 */ { NULL,NULL},
/* 1E442 */ { NULL,NULL},
/* 1E443 */ { NULL,NULL},
/* 1E444 */ { NULL,NULL},
/* 1E445 */ { NULL,NULL},
/* 1E446 */ { NULL,NULL},
/* 1E447 */ { NULL,NULL},
/* 1E448 */ { NULL,NULL},
/* 1E449 */ { NULL,NULL},
/* 1E44A */ { NULL,NULL},
/* 1E44B */ { NULL,NULL},
/* 1E44C */ { NULL,NULL},
/* 1E44D */ { NULL,NULL},
/* 1E44E */ { NULL,NULL},
/* 1E44F */ { NULL,NULL},
/* 1E450 */ { NULL,NULL},
/* 1E451 */ { NULL,NULL},
/* 1E452 */ { NULL,NULL},
/* 1E453 */ { NULL,NULL},
/* 1E454 */ { NULL,NULL},
/* 1E455 */ { NULL,NULL},
/* 1E456 */ { NULL,NULL},
/* 1E457 */ { NULL,NULL},
/* 1E458 */ { NULL,NULL},
/* 1E459 */ { NULL,NULL},
/* 1E45A */ { NULL,NULL},
/* 1E45B */ { NULL,NULL},
/* 1E45C */ { NULL,NULL},
/* 1E45D */ { NULL,NULL},
/* 1E45E */ { NULL,NULL},
/* 1E45F */ { NULL,NULL},
/* 1E460 */ { NULL,NULL},
/* 1E461 */ { NULL,NULL},
/* 1E462 */ { NULL,NULL},
/* 1E463 */ { NULL,NULL},
/* 1E464 */ { NULL,NULL},
/* 1E465 */ { NULL,NULL},
/* 1E466 */ { NULL,NULL},
/* 1E467 */ { NULL,NULL},
/* 1E468 */ { NULL,NULL},
/* 1E469 */ { NULL,NULL},
/* 1E46A */ { NULL,NULL},
/* 1E46B */ { NULL,NULL},
/* 1E46C */ { NULL,NULL},
/* 1E46D */ { NULL,NULL},
/* 1E46E */ { NULL,NULL},
/* 1E46F */ { NULL,NULL},
/* 1E470 */ { NULL,NULL},
/* 1E471 */ { NULL,NULL},
/* 1E472 */ { NULL,NULL},
/* 1E473 */ { NULL,NULL},
/* 1E474 */ { NULL,NULL},
/* 1E475 */ { NULL,NULL},
/* 1E476 */ { NULL,NULL},
/* 1E477 */ { NULL,NULL},
/* 1E478 */ { NULL,NULL},
/* 1E479 */ { NULL,NULL},
/* 1E47A */ { NULL,NULL},
/* 1E47B */ { NULL,NULL},
/* 1E47C */ { NULL,NULL},
/* 1E47D */ { NULL,NULL},
/* 1E47E */ { NULL,NULL},
/* 1E47F */ { NULL,NULL},
/* 1E480 */ { NULL,NULL},
/* 1E481 */ { NULL,NULL},
/* 1E482 */ { NULL,NULL},
/* 1E483 */ { NULL,NULL},
/* 1E484 */ { NULL,NULL},
/* 1E485 */ { NULL,NULL},
/* 1E486 */ { NULL,NULL},
/* 1E487 */ { NULL,NULL},
/* 1E488 */ { NULL,NULL},
/* 1E489 */ { NULL,NULL},
/* 1E48A */ { NULL,NULL},
/* 1E48B */ { NULL,NULL},
/* 1E48C */ { NULL,NULL},
/* 1E48D */ { NULL,NULL},
/* 1E48E */ { NULL,NULL},
/* 1E48F */ { NULL,NULL},
/* 1E490 */ { NULL,NULL},
/* 1E491 */ { NULL,NULL},
/* 1E492 */ { NULL,NULL},
/* 1E493 */ { NULL,NULL},
/* 1E494 */ { NULL,NULL},
/* 1E495 */ { NULL,NULL},
/* 1E496 */ { NULL,NULL},
/* 1E497 */ { NULL,NULL},
/* 1E498 */ { NULL,NULL},
/* 1E499 */ { NULL,NULL},
/* 1E49A */ { NULL,NULL},
/* 1E49B */ { NULL,NULL},
/* 1E49C */ { NULL,NULL},
/* 1E49D */ { NULL,NULL},
/* 1E49E */ { NULL,NULL},
/* 1E49F */ { NULL,NULL},
/* 1E4A0 */ { NULL,NULL},
/* 1E4A1 */ { NULL,NULL},
/* 1E4A2 */ { NULL,NULL},
/* 1E4A3 */ { NULL,NULL},
/* 1E4A4 */ { NULL,NULL},
/* 1E4A5 */ { NULL,NULL},
/* 1E4A6 */ { NULL,NULL},
/* 1E4A7 */ { NULL,NULL},
/* 1E4A8 */ { NULL,NULL},
/* 1E4A9 */ { NULL,NULL},
/* 1E4AA */ { NULL,NULL},
/* 1E4AB */ { NULL,NULL},
/* 1E4AC */ { NULL,NULL},
/* 1E4AD */ { NULL,NULL},
/* 1E4AE */ { NULL,NULL},
/* 1E4AF */ { NULL,NULL},
/* 1E4B0 */ { NULL,NULL},
/* 1E4B1 */ { NULL,NULL},
/* 1E4B2 */ { NULL,NULL},
/* 1E4B3 */ { NULL,NULL},
/* 1E4B4 */ { NULL,NULL},
/* 1E4B5 */ { NULL,NULL},
/* 1E4B6 */ { NULL,NULL},
/* 1E4B7 */ { NULL,NULL},
/* 1E4B8 */ { NULL,NULL},
/* 1E4B9 */ { NULL,NULL},
/* 1E4BA */ { NULL,NULL},
/* 1E4BB */ { NULL,NULL},
/* 1E4BC */ { NULL,NULL},
/* 1E4BD */ { NULL,NULL},
/* 1E4BE */ { NULL,NULL},
/* 1E4BF */ { NULL,NULL},
/* 1E4C0 */ { NULL,NULL},
/* 1E4C1 */ { NULL,NULL},
/* 1E4C2 */ { NULL,NULL},
/* 1E4C3 */ { NULL,NULL},
/* 1E4C4 */ { NULL,NULL},
/* 1E4C5 */ { NULL,NULL},
/* 1E4C6 */ { NULL,NULL},
/* 1E4C7 */ { NULL,NULL},
/* 1E4C8 */ { NULL,NULL},
/* 1E4C9 */ { NULL,NULL},
/* 1E4CA */ { NULL,NULL},
/* 1E4CB */ { NULL,NULL},
/* 1E4CC */ { NULL,NULL},
/* 1E4CD */ { NULL,NULL},
/* 1E4CE */ { NULL,NULL},
/* 1E4CF */ { NULL,NULL},
/* 1E4D0 */ { "NAG MUNDARI LETTER O",NULL},
/* 1E4D1 */ { "NAG MUNDARI LETTER OP",NULL},
/* 1E4D2 */ { "NAG MUNDARI LETTER OL",NULL},
/* 1E4D3 */ { "NAG MUNDARI LETTER OY",NULL},
/* 1E4D4 */ { "NAG MUNDARI LETTER ONG",NULL},
/* 1E4D5 */ { "NAG MUNDARI LETTER A",NULL},
/* 1E4D6 */ { "NAG MUNDARI LETTER AJ",NULL},
/* 1E4D7 */ { "NAG MUNDARI LETTER AB",NULL},
/* 1E4D8 */ { "NAG MUNDARI LETTER ANY",NULL},
/* 1E4D9 */ { "NAG MUNDARI LETTER AH",NULL},
/* 1E4DA */ { "NAG MUNDARI LETTER I",NULL},
/* 1E4DB */ { "NAG MUNDARI LETTER IS",NULL},
/* 1E4DC */ { "NAG MUNDARI LETTER IDD",NULL},
/* 1E4DD */ { "NAG MUNDARI LETTER IT",NULL},
/* 1E4DE */ { "NAG MUNDARI LETTER IH",NULL},
/* 1E4DF */ { "NAG MUNDARI LETTER U",NULL},
/* 1E4E0 */ { "NAG MUNDARI LETTER UC",NULL},
/* 1E4E1 */ { "NAG MUNDARI LETTER UD",NULL},
/* 1E4E2 */ { "NAG MUNDARI LETTER UK",NULL},
/* 1E4E3 */ { "NAG MUNDARI LETTER UR",NULL},
/* 1E4E4 */ { "NAG MUNDARI LETTER E",NULL},
/* 1E4E5 */ { "NAG MUNDARI LETTER ENN",NULL},
/* 1E4E6 */ { "NAG MUNDARI LETTER EG",NULL},
/* 1E4E7 */ { "NAG MUNDARI LETTER EM",NULL},
/* 1E4E8 */ { "NAG MUNDARI LETTER EN",NULL},
/* 1E4E9 */ { "NAG MUNDARI LETTER ETT",NULL},
/* 1E4EA */ { "NAG MUNDARI LETTER ELL",NULL},
/* 1E4EB */ { "NAG MUNDARI SIGN OJOD","	* precedes modified letters such as AB or UD\n"
	"	* may indicate consonant gemination"},
/* 1E4EC */ { "NAG MUNDARI SIGN MUHOR","	* vowel nasalization"},
/* 1E4ED */ { "NAG MUNDARI SIGN TOYOR","	* indicates a long vowel"},
/* 1E4EE */ { "NAG MUNDARI SIGN IKIR","	* vowel preceded by the 'w' sound"},
/* 1E4EF */ { "NAG MUNDARI SIGN SUTUH","	* mostly used for close transliteration of other languages"},
/* 1E4F0 */ { "NAG MUNDARI DIGIT ZERO",NULL},
/* 1E4F1 */ { "NAG MUNDARI DIGIT ONE",NULL},
/* 1E4F2 */ { "NAG MUNDARI DIGIT TWO",NULL},
/* 1E4F3 */ { "NAG MUNDARI DIGIT THREE",NULL},
/* 1E4F4 */ { "NAG MUNDARI DIGIT FOUR",NULL},
/* 1E4F5 */ { "NAG MUNDARI DIGIT FIVE",NULL},
/* 1E4F6 */ { "NAG MUNDARI DIGIT SIX",NULL},
/* 1E4F7 */ { "NAG MUNDARI DIGIT SEVEN",NULL},
/* 1E4F8 */ { "NAG MUNDARI DIGIT EIGHT",NULL},
/* 1E4F9 */ { "NAG MUNDARI DIGIT NINE",NULL},
/* 1E4FA */ { NULL,NULL},
/* 1E4FB */ { NULL,NULL},
/* 1E4FC */ { NULL,NULL},
/* 1E4FD */ { NULL,NULL},
/* 1E4FE */ { NULL,NULL},
/* 1E4FF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_E5[] = {
/* 1E500 */ { NULL,NULL},
/* 1E501 */ { NULL,NULL},
/* 1E502 */ { NULL,NULL},
/* 1E503 */ { NULL,NULL},
/* 1E504 */ { NULL,NULL},
/* 1E505 */ { NULL,NULL},
/* 1E506 */ { NULL,NULL},
/* 1E507 */ { NULL,NULL},
/* 1E508 */ { NULL,NULL},
/* 1E509 */ { NULL,NULL},
/* 1E50A */ { NULL,NULL},
/* 1E50B */ { NULL,NULL},
/* 1E50C */ { NULL,NULL},
/* 1E50D */ { NULL,NULL},
/* 1E50E */ { NULL,NULL},
/* 1E50F */ { NULL,NULL},
/* 1E510 */ { NULL,NULL},
/* 1E511 */ { NULL,NULL},
/* 1E512 */ { NULL,NULL},
/* 1E513 */ { NULL,NULL},
/* 1E514 */ { NULL,NULL},
/* 1E515 */ { NULL,NULL},
/* 1E516 */ { NULL,NULL},
/* 1E517 */ { NULL,NULL},
/* 1E518 */ { NULL,NULL},
/* 1E519 */ { NULL,NULL},
/* 1E51A */ { NULL,NULL},
/* 1E51B */ { NULL,NULL},
/* 1E51C */ { NULL,NULL},
/* 1E51D */ { NULL,NULL},
/* 1E51E */ { NULL,NULL},
/* 1E51F */ { NULL,NULL},
/* 1E520 */ { NULL,NULL},
/* 1E521 */ { NULL,NULL},
/* 1E522 */ { NULL,NULL},
/* 1E523 */ { NULL,NULL},
/* 1E524 */ { NULL,NULL},
/* 1E525 */ { NULL,NULL},
/* 1E526 */ { NULL,NULL},
/* 1E527 */ { NULL,NULL},
/* 1E528 */ { NULL,NULL},
/* 1E529 */ { NULL,NULL},
/* 1E52A */ { NULL,NULL},
/* 1E52B */ { NULL,NULL},
/* 1E52C */ { NULL,NULL},
/* 1E52D */ { NULL,NULL},
/* 1E52E */ { NULL,NULL},
/* 1E52F */ { NULL,NULL},
/* 1E530 */ { NULL,NULL},
/* 1E531 */ { NULL,NULL},
/* 1E532 */ { NULL,NULL},
/* 1E533 */ { NULL,NULL},
/* 1E534 */ { NULL,NULL},
/* 1E535 */ { NULL,NULL},
/* 1E536 */ { NULL,NULL},
/* 1E537 */ { NULL,NULL},
/* 1E538 */ { NULL,NULL},
/* 1E539 */ { NULL,NULL},
/* 1E53A */ { NULL,NULL},
/* 1E53B */ { NULL,NULL},
/* 1E53C */ { NULL,NULL},
/* 1E53D */ { NULL,NULL},
/* 1E53E */ { NULL,NULL},
/* 1E53F */ { NULL,NULL},
/* 1E540 */ { NULL,NULL},
/* 1E541 */ { NULL,NULL},
/* 1E542 */ { NULL,NULL},
/* 1E543 */ { NULL,NULL},
/* 1E544 */ { NULL,NULL},
/* 1E545 */ { NULL,NULL},
/* 1E546 */ { NULL,NULL},
/* 1E547 */ { NULL,NULL},
/* 1E548 */ { NULL,NULL},
/* 1E549 */ { NULL,NULL},
/* 1E54A */ { NULL,NULL},
/* 1E54B */ { NULL,NULL},
/* 1E54C */ { NULL,NULL},
/* 1E54D */ { NULL,NULL},
/* 1E54E */ { NULL,NULL},
/* 1E54F */ { NULL,NULL},
/* 1E550 */ { NULL,NULL},
/* 1E551 */ { NULL,NULL},
/* 1E552 */ { NULL,NULL},
/* 1E553 */ { NULL,NULL},
/* 1E554 */ { NULL,NULL},
/* 1E555 */ { NULL,NULL},
/* 1E556 */ { NULL,NULL},
/* 1E557 */ { NULL,NULL},
/* 1E558 */ { NULL,NULL},
/* 1E559 */ { NULL,NULL},
/* 1E55A */ { NULL,NULL},
/* 1E55B */ { NULL,NULL},
/* 1E55C */ { NULL,NULL},
/* 1E55D */ { NULL,NULL},
/* 1E55E */ { NULL,NULL},
/* 1E55F */ { NULL,NULL},
/* 1E560 */ { NULL,NULL},
/* 1E561 */ { NULL,NULL},
/* 1E562 */ { NULL,NULL},
/* 1E563 */ { NULL,NULL},
/* 1E564 */ { NULL,NULL},
/* 1E565 */ { NULL,NULL},
/* 1E566 */ { NULL,NULL},
/* 1E567 */ { NULL,NULL},
/* 1E568 */ { NULL,NULL},
/* 1E569 */ { NULL,NULL},
/* 1E56A */ { NULL,NULL},
/* 1E56B */ { NULL,NULL},
/* 1E56C */ { NULL,NULL},
/* 1E56D */ { NULL,NULL},
/* 1E56E */ { NULL,NULL},
/* 1E56F */ { NULL,NULL},
/* 1E570 */ { NULL,NULL},
/* 1E571 */ { NULL,NULL},
/* 1E572 */ { NULL,NULL},
/* 1E573 */ { NULL,NULL},
/* 1E574 */ { NULL,NULL},
/* 1E575 */ { NULL,NULL},
/* 1E576 */ { NULL,NULL},
/* 1E577 */ { NULL,NULL},
/* 1E578 */ { NULL,NULL},
/* 1E579 */ { NULL,NULL},
/* 1E57A */ { NULL,NULL},
/* 1E57B */ { NULL,NULL},
/* 1E57C */ { NULL,NULL},
/* 1E57D */ { NULL,NULL},
/* 1E57E */ { NULL,NULL},
/* 1E57F */ { NULL,NULL},
/* 1E580 */ { NULL,NULL},
/* 1E581 */ { NULL,NULL},
/* 1E582 */ { NULL,NULL},
/* 1E583 */ { NULL,NULL},
/* 1E584 */ { NULL,NULL},
/* 1E585 */ { NULL,NULL},
/* 1E586 */ { NULL,NULL},
/* 1E587 */ { NULL,NULL},
/* 1E588 */ { NULL,NULL},
/* 1E589 */ { NULL,NULL},
/* 1E58A */ { NULL,NULL},
/* 1E58B */ { NULL,NULL},
/* 1E58C */ { NULL,NULL},
/* 1E58D */ { NULL,NULL},
/* 1E58E */ { NULL,NULL},
/* 1E58F */ { NULL,NULL},
/* 1E590 */ { NULL,NULL},
/* 1E591 */ { NULL,NULL},
/* 1E592 */ { NULL,NULL},
/* 1E593 */ { NULL,NULL},
/* 1E594 */ { NULL,NULL},
/* 1E595 */ { NULL,NULL},
/* 1E596 */ { NULL,NULL},
/* 1E597 */ { NULL,NULL},
/* 1E598 */ { NULL,NULL},
/* 1E599 */ { NULL,NULL},
/* 1E59A */ { NULL,NULL},
/* 1E59B */ { NULL,NULL},
/* 1E59C */ { NULL,NULL},
/* 1E59D */ { NULL,NULL},
/* 1E59E */ { NULL,NULL},
/* 1E59F */ { NULL,NULL},
/* 1E5A0 */ { NULL,NULL},
/* 1E5A1 */ { NULL,NULL},
/* 1E5A2 */ { NULL,NULL},
/* 1E5A3 */ { NULL,NULL},
/* 1E5A4 */ { NULL,NULL},
/* 1E5A5 */ { NULL,NULL},
/* 1E5A6 */ { NULL,NULL},
/* 1E5A7 */ { NULL,NULL},
/* 1E5A8 */ { NULL,NULL},
/* 1E5A9 */ { NULL,NULL},
/* 1E5AA */ { NULL,NULL},
/* 1E5AB */ { NULL,NULL},
/* 1E5AC */ { NULL,NULL},
/* 1E5AD */ { NULL,NULL},
/* 1E5AE */ { NULL,NULL},
/* 1E5AF */ { NULL,NULL},
/* 1E5B0 */ { NULL,NULL},
/* 1E5B1 */ { NULL,NULL},
/* 1E5B2 */ { NULL,NULL},
/* 1E5B3 */ { NULL,NULL},
/* 1E5B4 */ { NULL,NULL},
/* 1E5B5 */ { NULL,NULL},
/* 1E5B6 */ { NULL,NULL},
/* 1E5B7 */ { NULL,NULL},
/* 1E5B8 */ { NULL,NULL},
/* 1E5B9 */ { NULL,NULL},
/* 1E5BA */ { NULL,NULL},
/* 1E5BB */ { NULL,NULL},
/* 1E5BC */ { NULL,NULL},
/* 1E5BD */ { NULL,NULL},
/* 1E5BE */ { NULL,NULL},
/* 1E5BF */ { NULL,NULL},
/* 1E5C0 */ { NULL,NULL},
/* 1E5C1 */ { NULL,NULL},
/* 1E5C2 */ { NULL,NULL},
/* 1E5C3 */ { NULL,NULL},
/* 1E5C4 */ { NULL,NULL},
/* 1E5C5 */ { NULL,NULL},
/* 1E5C6 */ { NULL,NULL},
/* 1E5C7 */ { NULL,NULL},
/* 1E5C8 */ { NULL,NULL},
/* 1E5C9 */ { NULL,NULL},
/* 1E5CA */ { NULL,NULL},
/* 1E5CB */ { NULL,NULL},
/* 1E5CC */ { NULL,NULL},
/* 1E5CD */ { NULL,NULL},
/* 1E5CE */ { NULL,NULL},
/* 1E5CF */ { NULL,NULL},
/* 1E5D0 */ { "OL ONAL LETTER O",NULL},
/* 1E5D1 */ { "OL ONAL LETTER OM",NULL},
/* 1E5D2 */ { "OL ONAL LETTER ONG",NULL},
/* 1E5D3 */ { "OL ONAL LETTER ORR",NULL},
/* 1E5D4 */ { "OL ONAL LETTER OO",NULL},
/* 1E5D5 */ { "OL ONAL LETTER OY",NULL},
/* 1E5D6 */ { "OL ONAL LETTER A",NULL},
/* 1E5D7 */ { "OL ONAL LETTER AD",NULL},
/* 1E5D8 */ { "OL ONAL LETTER AB",NULL},
/* 1E5D9 */ { "OL ONAL LETTER AH",NULL},
/* 1E5DA */ { "OL ONAL LETTER AL",NULL},
/* 1E5DB */ { "OL ONAL LETTER AW",NULL},
/* 1E5DC */ { "OL ONAL LETTER I",NULL},
/* 1E5DD */ { "OL ONAL LETTER IT",NULL},
/* 1E5DE */ { "OL ONAL LETTER IP",NULL},
/* 1E5DF */ { "OL ONAL LETTER ITT",NULL},
/* 1E5E0 */ { "OL ONAL LETTER ID",NULL},
/* 1E5E1 */ { "OL ONAL LETTER IN",NULL},
/* 1E5E2 */ { "OL ONAL LETTER U",NULL},
/* 1E5E3 */ { "OL ONAL LETTER UK",NULL},
/* 1E5E4 */ { "OL ONAL LETTER UDD",NULL},
/* 1E5E5 */ { "OL ONAL LETTER UJ",NULL},
/* 1E5E6 */ { "OL ONAL LETTER UNY",NULL},
/* 1E5E7 */ { "OL ONAL LETTER UR",NULL},
/* 1E5E8 */ { "OL ONAL LETTER E",NULL},
/* 1E5E9 */ { "OL ONAL LETTER ES",NULL},
/* 1E5EA */ { "OL ONAL LETTER EH",NULL},
/* 1E5EB */ { "OL ONAL LETTER EC",NULL},
/* 1E5EC */ { "OL ONAL LETTER ENN",NULL},
/* 1E5ED */ { "OL ONAL LETTER EG",NULL},
/* 1E5EE */ { "OL ONAL SIGN MU",NULL},
/* 1E5EF */ { "OL ONAL SIGN IKIR",NULL},
/* 1E5F0 */ { "OL ONAL SIGN HODDOND",NULL},
/* 1E5F1 */ { "OL ONAL DIGIT ZERO",NULL},
/* 1E5F2 */ { "OL ONAL DIGIT ONE",NULL},
/* 1E5F3 */ { "OL ONAL DIGIT TWO",NULL},
/* 1E5F4 */ { "OL ONAL DIGIT THREE",NULL},
/* 1E5F5 */ { "OL ONAL DIGIT FOUR",NULL},
/* 1E5F6 */ { "OL ONAL DIGIT FIVE",NULL},
/* 1E5F7 */ { "OL ONAL DIGIT SIX",NULL},
/* 1E5F8 */ { "OL ONAL DIGIT SEVEN",NULL},
/* 1E5F9 */ { "OL ONAL DIGIT EIGHT",NULL},
/* 1E5FA */ { "OL ONAL DIGIT NINE",NULL},
/* 1E5FB */ { NULL,NULL},
/* 1E5FC */ { NULL,NULL},
/* 1E5FD */ { NULL,NULL},
/* 1E5FE */ { NULL,NULL},
/* 1E5FF */ { "OL ONAL ABBREVIATION SIGN",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_E6[] = {
/* 1E600 */ { NULL,NULL},
/* 1E601 */ { NULL,NULL},
/* 1E602 */ { NULL,NULL},
/* 1E603 */ { NULL,NULL},
/* 1E604 */ { NULL,NULL},
/* 1E605 */ { NULL,NULL},
/* 1E606 */ { NULL,NULL},
/* 1E607 */ { NULL,NULL},
/* 1E608 */ { NULL,NULL},
/* 1E609 */ { NULL,NULL},
/* 1E60A */ { NULL,NULL},
/* 1E60B */ { NULL,NULL},
/* 1E60C */ { NULL,NULL},
/* 1E60D */ { NULL,NULL},
/* 1E60E */ { NULL,NULL},
/* 1E60F */ { NULL,NULL},
/* 1E610 */ { NULL,NULL},
/* 1E611 */ { NULL,NULL},
/* 1E612 */ { NULL,NULL},
/* 1E613 */ { NULL,NULL},
/* 1E614 */ { NULL,NULL},
/* 1E615 */ { NULL,NULL},
/* 1E616 */ { NULL,NULL},
/* 1E617 */ { NULL,NULL},
/* 1E618 */ { NULL,NULL},
/* 1E619 */ { NULL,NULL},
/* 1E61A */ { NULL,NULL},
/* 1E61B */ { NULL,NULL},
/* 1E61C */ { NULL,NULL},
/* 1E61D */ { NULL,NULL},
/* 1E61E */ { NULL,NULL},
/* 1E61F */ { NULL,NULL},
/* 1E620 */ { NULL,NULL},
/* 1E621 */ { NULL,NULL},
/* 1E622 */ { NULL,NULL},
/* 1E623 */ { NULL,NULL},
/* 1E624 */ { NULL,NULL},
/* 1E625 */ { NULL,NULL},
/* 1E626 */ { NULL,NULL},
/* 1E627 */ { NULL,NULL},
/* 1E628 */ { NULL,NULL},
/* 1E629 */ { NULL,NULL},
/* 1E62A */ { NULL,NULL},
/* 1E62B */ { NULL,NULL},
/* 1E62C */ { NULL,NULL},
/* 1E62D */ { NULL,NULL},
/* 1E62E */ { NULL,NULL},
/* 1E62F */ { NULL,NULL},
/* 1E630 */ { NULL,NULL},
/* 1E631 */ { NULL,NULL},
/* 1E632 */ { NULL,NULL},
/* 1E633 */ { NULL,NULL},
/* 1E634 */ { NULL,NULL},
/* 1E635 */ { NULL,NULL},
/* 1E636 */ { NULL,NULL},
/* 1E637 */ { NULL,NULL},
/* 1E638 */ { NULL,NULL},
/* 1E639 */ { NULL,NULL},
/* 1E63A */ { NULL,NULL},
/* 1E63B */ { NULL,NULL},
/* 1E63C */ { NULL,NULL},
/* 1E63D */ { NULL,NULL},
/* 1E63E */ { NULL,NULL},
/* 1E63F */ { NULL,NULL},
/* 1E640 */ { NULL,NULL},
/* 1E641 */ { NULL,NULL},
/* 1E642 */ { NULL,NULL},
/* 1E643 */ { NULL,NULL},
/* 1E644 */ { NULL,NULL},
/* 1E645 */ { NULL,NULL},
/* 1E646 */ { NULL,NULL},
/* 1E647 */ { NULL,NULL},
/* 1E648 */ { NULL,NULL},
/* 1E649 */ { NULL,NULL},
/* 1E64A */ { NULL,NULL},
/* 1E64B */ { NULL,NULL},
/* 1E64C */ { NULL,NULL},
/* 1E64D */ { NULL,NULL},
/* 1E64E */ { NULL,NULL},
/* 1E64F */ { NULL,NULL},
/* 1E650 */ { NULL,NULL},
/* 1E651 */ { NULL,NULL},
/* 1E652 */ { NULL,NULL},
/* 1E653 */ { NULL,NULL},
/* 1E654 */ { NULL,NULL},
/* 1E655 */ { NULL,NULL},
/* 1E656 */ { NULL,NULL},
/* 1E657 */ { NULL,NULL},
/* 1E658 */ { NULL,NULL},
/* 1E659 */ { NULL,NULL},
/* 1E65A */ { NULL,NULL},
/* 1E65B */ { NULL,NULL},
/* 1E65C */ { NULL,NULL},
/* 1E65D */ { NULL,NULL},
/* 1E65E */ { NULL,NULL},
/* 1E65F */ { NULL,NULL},
/* 1E660 */ { NULL,NULL},
/* 1E661 */ { NULL,NULL},
/* 1E662 */ { NULL,NULL},
/* 1E663 */ { NULL,NULL},
/* 1E664 */ { NULL,NULL},
/* 1E665 */ { NULL,NULL},
/* 1E666 */ { NULL,NULL},
/* 1E667 */ { NULL,NULL},
/* 1E668 */ { NULL,NULL},
/* 1E669 */ { NULL,NULL},
/* 1E66A */ { NULL,NULL},
/* 1E66B */ { NULL,NULL},
/* 1E66C */ { NULL,NULL},
/* 1E66D */ { NULL,NULL},
/* 1E66E */ { NULL,NULL},
/* 1E66F */ { NULL,NULL},
/* 1E670 */ { NULL,NULL},
/* 1E671 */ { NULL,NULL},
/* 1E672 */ { NULL,NULL},
/* 1E673 */ { NULL,NULL},
/* 1E674 */ { NULL,NULL},
/* 1E675 */ { NULL,NULL},
/* 1E676 */ { NULL,NULL},
/* 1E677 */ { NULL,NULL},
/* 1E678 */ { NULL,NULL},
/* 1E679 */ { NULL,NULL},
/* 1E67A */ { NULL,NULL},
/* 1E67B */ { NULL,NULL},
/* 1E67C */ { NULL,NULL},
/* 1E67D */ { NULL,NULL},
/* 1E67E */ { NULL,NULL},
/* 1E67F */ { NULL,NULL},
/* 1E680 */ { NULL,NULL},
/* 1E681 */ { NULL,NULL},
/* 1E682 */ { NULL,NULL},
/* 1E683 */ { NULL,NULL},
/* 1E684 */ { NULL,NULL},
/* 1E685 */ { NULL,NULL},
/* 1E686 */ { NULL,NULL},
/* 1E687 */ { NULL,NULL},
/* 1E688 */ { NULL,NULL},
/* 1E689 */ { NULL,NULL},
/* 1E68A */ { NULL,NULL},
/* 1E68B */ { NULL,NULL},
/* 1E68C */ { NULL,NULL},
/* 1E68D */ { NULL,NULL},
/* 1E68E */ { NULL,NULL},
/* 1E68F */ { NULL,NULL},
/* 1E690 */ { NULL,NULL},
/* 1E691 */ { NULL,NULL},
/* 1E692 */ { NULL,NULL},
/* 1E693 */ { NULL,NULL},
/* 1E694 */ { NULL,NULL},
/* 1E695 */ { NULL,NULL},
/* 1E696 */ { NULL,NULL},
/* 1E697 */ { NULL,NULL},
/* 1E698 */ { NULL,NULL},
/* 1E699 */ { NULL,NULL},
/* 1E69A */ { NULL,NULL},
/* 1E69B */ { NULL,NULL},
/* 1E69C */ { NULL,NULL},
/* 1E69D */ { NULL,NULL},
/* 1E69E */ { NULL,NULL},
/* 1E69F */ { NULL,NULL},
/* 1E6A0 */ { NULL,NULL},
/* 1E6A1 */ { NULL,NULL},
/* 1E6A2 */ { NULL,NULL},
/* 1E6A3 */ { NULL,NULL},
/* 1E6A4 */ { NULL,NULL},
/* 1E6A5 */ { NULL,NULL},
/* 1E6A6 */ { NULL,NULL},
/* 1E6A7 */ { NULL,NULL},
/* 1E6A8 */ { NULL,NULL},
/* 1E6A9 */ { NULL,NULL},
/* 1E6AA */ { NULL,NULL},
/* 1E6AB */ { NULL,NULL},
/* 1E6AC */ { NULL,NULL},
/* 1E6AD */ { NULL,NULL},
/* 1E6AE */ { NULL,NULL},
/* 1E6AF */ { NULL,NULL},
/* 1E6B0 */ { NULL,NULL},
/* 1E6B1 */ { NULL,NULL},
/* 1E6B2 */ { NULL,NULL},
/* 1E6B3 */ { NULL,NULL},
/* 1E6B4 */ { NULL,NULL},
/* 1E6B5 */ { NULL,NULL},
/* 1E6B6 */ { NULL,NULL},
/* 1E6B7 */ { NULL,NULL},
/* 1E6B8 */ { NULL,NULL},
/* 1E6B9 */ { NULL,NULL},
/* 1E6BA */ { NULL,NULL},
/* 1E6BB */ { NULL,NULL},
/* 1E6BC */ { NULL,NULL},
/* 1E6BD */ { NULL,NULL},
/* 1E6BE */ { NULL,NULL},
/* 1E6BF */ { NULL,NULL},
/* 1E6C0 */ { "TAI YO LETTER LOW KO",NULL},
/* 1E6C1 */ { "TAI YO LETTER HIGH KO",NULL},
/* 1E6C2 */ { "TAI YO LETTER LOW KHO",NULL},
/* 1E6C3 */ { "TAI YO LETTER HIGH KHO",NULL},
/* 1E6C4 */ { "TAI YO LETTER GO",NULL},
/* 1E6C5 */ { "TAI YO LETTER NGO",NULL},
/* 1E6C6 */ { "TAI YO LETTER CO",NULL},
/* 1E6C7 */ { "TAI YO LETTER LOW XO",NULL},
/* 1E6C8 */ { "TAI YO LETTER HIGH XO",NULL},
/* 1E6C9 */ { "TAI YO LETTER LOW NYO",NULL},
/* 1E6CA */ { "TAI YO LETTER HIGH NYO",NULL},
/* 1E6CB */ { "TAI YO LETTER DO",NULL},
/* 1E6CC */ { "TAI YO LETTER LOW TO",NULL},
/* 1E6CD */ { "TAI YO LETTER HIGH TO",NULL},
/* 1E6CE */ { "TAI YO LETTER THO",NULL},
/* 1E6CF */ { "TAI YO LETTER NO",NULL},
/* 1E6D0 */ { "TAI YO LETTER BO",NULL},
/* 1E6D1 */ { "TAI YO LETTER LOW PO",NULL},
/* 1E6D2 */ { "TAI YO LETTER HIGH PO",NULL},
/* 1E6D3 */ { "TAI YO LETTER PHO",NULL},
/* 1E6D4 */ { "TAI YO LETTER LOW FO",NULL},
/* 1E6D5 */ { "TAI YO LETTER HIGH FO",NULL},
/* 1E6D6 */ { "TAI YO LETTER MO",NULL},
/* 1E6D7 */ { "TAI YO LETTER YO",NULL},
/* 1E6D8 */ { "TAI YO LETTER LO",NULL},
/* 1E6D9 */ { "TAI YO LETTER VO",NULL},
/* 1E6DA */ { "TAI YO LETTER LOW HO",NULL},
/* 1E6DB */ { "TAI YO LETTER HIGH HO",NULL},
/* 1E6DC */ { "TAI YO LETTER QO",NULL},
/* 1E6DD */ { "TAI YO LETTER LOW KVO",NULL},
/* 1E6DE */ { "TAI YO LETTER HIGH KVO",NULL},
/* 1E6DF */ { NULL,NULL},
/* 1E6E0 */ { "TAI YO LETTER AA",NULL},
/* 1E6E1 */ { "TAI YO LETTER I",NULL},
/* 1E6E2 */ { "TAI YO LETTER UE",NULL},
/* 1E6E3 */ { "TAI YO SIGN UE",NULL},
/* 1E6E4 */ { "TAI YO LETTER U",NULL},
/* 1E6E5 */ { "TAI YO LETTER AE",NULL},
/* 1E6E6 */ { "TAI YO SIGN AU",NULL},
/* 1E6E7 */ { "TAI YO LETTER O",NULL},
/* 1E6E8 */ { "TAI YO LETTER E",NULL},
/* 1E6E9 */ { "TAI YO LETTER IA",NULL},
/* 1E6EA */ { "TAI YO LETTER UEA",NULL},
/* 1E6EB */ { "TAI YO LETTER UA",NULL},
/* 1E6EC */ { "TAI YO LETTER OO",NULL},
/* 1E6ED */ { "TAI YO LETTER AUE",NULL},
/* 1E6EE */ { "TAI YO SIGN AY",NULL},
/* 1E6EF */ { "TAI YO SIGN ANG",NULL},
/* 1E6F0 */ { "TAI YO LETTER AN",NULL},
/* 1E6F1 */ { "TAI YO LETTER AM",NULL},
/* 1E6F2 */ { "TAI YO LETTER AK",NULL},
/* 1E6F3 */ { "TAI YO LETTER AT",NULL},
/* 1E6F4 */ { "TAI YO LETTER AP",NULL},
/* 1E6F5 */ { "TAI YO SIGN OM",NULL},
/* 1E6F6 */ { NULL,NULL},
/* 1E6F7 */ { NULL,NULL},
/* 1E6F8 */ { NULL,NULL},
/* 1E6F9 */ { NULL,NULL},
/* 1E6FA */ { NULL,NULL},
/* 1E6FB */ { NULL,NULL},
/* 1E6FC */ { NULL,NULL},
/* 1E6FD */ { NULL,NULL},
/* 1E6FE */ { "TAI YO SYMBOL MUEANG",NULL},
/* 1E6FF */ { "TAI YO XAM LAI",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_E7[] = {
/* 1E700 */ { NULL,NULL},
/* 1E701 */ { NULL,NULL},
/* 1E702 */ { NULL,NULL},
/* 1E703 */ { NULL,NULL},
/* 1E704 */ { NULL,NULL},
/* 1E705 */ { NULL,NULL},
/* 1E706 */ { NULL,NULL},
/* 1E707 */ { NULL,NULL},
/* 1E708 */ { NULL,NULL},
/* 1E709 */ { NULL,NULL},
/* 1E70A */ { NULL,NULL},
/* 1E70B */ { NULL,NULL},
/* 1E70C */ { NULL,NULL},
/* 1E70D */ { NULL,NULL},
/* 1E70E */ { NULL,NULL},
/* 1E70F */ { NULL,NULL},
/* 1E710 */ { NULL,NULL},
/* 1E711 */ { NULL,NULL},
/* 1E712 */ { NULL,NULL},
/* 1E713 */ { NULL,NULL},
/* 1E714 */ { NULL,NULL},
/* 1E715 */ { NULL,NULL},
/* 1E716 */ { NULL,NULL},
/* 1E717 */ { NULL,NULL},
/* 1E718 */ { NULL,NULL},
/* 1E719 */ { NULL,NULL},
/* 1E71A */ { NULL,NULL},
/* 1E71B */ { NULL,NULL},
/* 1E71C */ { NULL,NULL},
/* 1E71D */ { NULL,NULL},
/* 1E71E */ { NULL,NULL},
/* 1E71F */ { NULL,NULL},
/* 1E720 */ { NULL,NULL},
/* 1E721 */ { NULL,NULL},
/* 1E722 */ { NULL,NULL},
/* 1E723 */ { NULL,NULL},
/* 1E724 */ { NULL,NULL},
/* 1E725 */ { NULL,NULL},
/* 1E726 */ { NULL,NULL},
/* 1E727 */ { NULL,NULL},
/* 1E728 */ { NULL,NULL},
/* 1E729 */ { NULL,NULL},
/* 1E72A */ { NULL,NULL},
/* 1E72B */ { NULL,NULL},
/* 1E72C */ { NULL,NULL},
/* 1E72D */ { NULL,NULL},
/* 1E72E */ { NULL,NULL},
/* 1E72F */ { NULL,NULL},
/* 1E730 */ { NULL,NULL},
/* 1E731 */ { NULL,NULL},
/* 1E732 */ { NULL,NULL},
/* 1E733 */ { NULL,NULL},
/* 1E734 */ { NULL,NULL},
/* 1E735 */ { NULL,NULL},
/* 1E736 */ { NULL,NULL},
/* 1E737 */ { NULL,NULL},
/* 1E738 */ { NULL,NULL},
/* 1E739 */ { NULL,NULL},
/* 1E73A */ { NULL,NULL},
/* 1E73B */ { NULL,NULL},
/* 1E73C */ { NULL,NULL},
/* 1E73D */ { NULL,NULL},
/* 1E73E */ { NULL,NULL},
/* 1E73F */ { NULL,NULL},
/* 1E740 */ { NULL,NULL},
/* 1E741 */ { NULL,NULL},
/* 1E742 */ { NULL,NULL},
/* 1E743 */ { NULL,NULL},
/* 1E744 */ { NULL,NULL},
/* 1E745 */ { NULL,NULL},
/* 1E746 */ { NULL,NULL},
/* 1E747 */ { NULL,NULL},
/* 1E748 */ { NULL,NULL},
/* 1E749 */ { NULL,NULL},
/* 1E74A */ { NULL,NULL},
/* 1E74B */ { NULL,NULL},
/* 1E74C */ { NULL,NULL},
/* 1E74D */ { NULL,NULL},
/* 1E74E */ { NULL,NULL},
/* 1E74F */ { NULL,NULL},
/* 1E750 */ { NULL,NULL},
/* 1E751 */ { NULL,NULL},
/* 1E752 */ { NULL,NULL},
/* 1E753 */ { NULL,NULL},
/* 1E754 */ { NULL,NULL},
/* 1E755 */ { NULL,NULL},
/* 1E756 */ { NULL,NULL},
/* 1E757 */ { NULL,NULL},
/* 1E758 */ { NULL,NULL},
/* 1E759 */ { NULL,NULL},
/* 1E75A */ { NULL,NULL},
/* 1E75B */ { NULL,NULL},
/* 1E75C */ { NULL,NULL},
/* 1E75D */ { NULL,NULL},
/* 1E75E */ { NULL,NULL},
/* 1E75F */ { NULL,NULL},
/* 1E760 */ { NULL,NULL},
/* 1E761 */ { NULL,NULL},
/* 1E762 */ { NULL,NULL},
/* 1E763 */ { NULL,NULL},
/* 1E764 */ { NULL,NULL},
/* 1E765 */ { NULL,NULL},
/* 1E766 */ { NULL,NULL},
/* 1E767 */ { NULL,NULL},
/* 1E768 */ { NULL,NULL},
/* 1E769 */ { NULL,NULL},
/* 1E76A */ { NULL,NULL},
/* 1E76B */ { NULL,NULL},
/* 1E76C */ { NULL,NULL},
/* 1E76D */ { NULL,NULL},
/* 1E76E */ { NULL,NULL},
/* 1E76F */ { NULL,NULL},
/* 1E770 */ { NULL,NULL},
/* 1E771 */ { NULL,NULL},
/* 1E772 */ { NULL,NULL},
/* 1E773 */ { NULL,NULL},
/* 1E774 */ { NULL,NULL},
/* 1E775 */ { NULL,NULL},
/* 1E776 */ { NULL,NULL},
/* 1E777 */ { NULL,NULL},
/* 1E778 */ { NULL,NULL},
/* 1E779 */ { NULL,NULL},
/* 1E77A */ { NULL,NULL},
/* 1E77B */ { NULL,NULL},
/* 1E77C */ { NULL,NULL},
/* 1E77D */ { NULL,NULL},
/* 1E77E */ { NULL,NULL},
/* 1E77F */ { NULL,NULL},
/* 1E780 */ { NULL,NULL},
/* 1E781 */ { NULL,NULL},
/* 1E782 */ { NULL,NULL},
/* 1E783 */ { NULL,NULL},
/* 1E784 */ { NULL,NULL},
/* 1E785 */ { NULL,NULL},
/* 1E786 */ { NULL,NULL},
/* 1E787 */ { NULL,NULL},
/* 1E788 */ { NULL,NULL},
/* 1E789 */ { NULL,NULL},
/* 1E78A */ { NULL,NULL},
/* 1E78B */ { NULL,NULL},
/* 1E78C */ { NULL,NULL},
/* 1E78D */ { NULL,NULL},
/* 1E78E */ { NULL,NULL},
/* 1E78F */ { NULL,NULL},
/* 1E790 */ { NULL,NULL},
/* 1E791 */ { NULL,NULL},
/* 1E792 */ { NULL,NULL},
/* 1E793 */ { NULL,NULL},
/* 1E794 */ { NULL,NULL},
/* 1E795 */ { NULL,NULL},
/* 1E796 */ { NULL,NULL},
/* 1E797 */ { NULL,NULL},
/* 1E798 */ { NULL,NULL},
/* 1E799 */ { NULL,NULL},
/* 1E79A */ { NULL,NULL},
/* 1E79B */ { NULL,NULL},
/* 1E79C */ { NULL,NULL},
/* 1E79D */ { NULL,NULL},
/* 1E79E */ { NULL,NULL},
/* 1E79F */ { NULL,NULL},
/* 1E7A0 */ { NULL,NULL},
/* 1E7A1 */ { NULL,NULL},
/* 1E7A2 */ { NULL,NULL},
/* 1E7A3 */ { NULL,NULL},
/* 1E7A4 */ { NULL,NULL},
/* 1E7A5 */ { NULL,NULL},
/* 1E7A6 */ { NULL,NULL},
/* 1E7A7 */ { NULL,NULL},
/* 1E7A8 */ { NULL,NULL},
/* 1E7A9 */ { NULL,NULL},
/* 1E7AA */ { NULL,NULL},
/* 1E7AB */ { NULL,NULL},
/* 1E7AC */ { NULL,NULL},
/* 1E7AD */ { NULL,NULL},
/* 1E7AE */ { NULL,NULL},
/* 1E7AF */ { NULL,NULL},
/* 1E7B0 */ { NULL,NULL},
/* 1E7B1 */ { NULL,NULL},
/* 1E7B2 */ { NULL,NULL},
/* 1E7B3 */ { NULL,NULL},
/* 1E7B4 */ { NULL,NULL},
/* 1E7B5 */ { NULL,NULL},
/* 1E7B6 */ { NULL,NULL},
/* 1E7B7 */ { NULL,NULL},
/* 1E7B8 */ { NULL,NULL},
/* 1E7B9 */ { NULL,NULL},
/* 1E7BA */ { NULL,NULL},
/* 1E7BB */ { NULL,NULL},
/* 1E7BC */ { NULL,NULL},
/* 1E7BD */ { NULL,NULL},
/* 1E7BE */ { NULL,NULL},
/* 1E7BF */ { NULL,NULL},
/* 1E7C0 */ { NULL,NULL},
/* 1E7C1 */ { NULL,NULL},
/* 1E7C2 */ { NULL,NULL},
/* 1E7C3 */ { NULL,NULL},
/* 1E7C4 */ { NULL,NULL},
/* 1E7C5 */ { NULL,NULL},
/* 1E7C6 */ { NULL,NULL},
/* 1E7C7 */ { NULL,NULL},
/* 1E7C8 */ { NULL,NULL},
/* 1E7C9 */ { NULL,NULL},
/* 1E7CA */ { NULL,NULL},
/* 1E7CB */ { NULL,NULL},
/* 1E7CC */ { NULL,NULL},
/* 1E7CD */ { NULL,NULL},
/* 1E7CE */ { NULL,NULL},
/* 1E7CF */ { NULL,NULL},
/* 1E7D0 */ { NULL,NULL},
/* 1E7D1 */ { NULL,NULL},
/* 1E7D2 */ { NULL,NULL},
/* 1E7D3 */ { NULL,NULL},
/* 1E7D4 */ { NULL,NULL},
/* 1E7D5 */ { NULL,NULL},
/* 1E7D6 */ { NULL,NULL},
/* 1E7D7 */ { NULL,NULL},
/* 1E7D8 */ { NULL,NULL},
/* 1E7D9 */ { NULL,NULL},
/* 1E7DA */ { NULL,NULL},
/* 1E7DB */ { NULL,NULL},
/* 1E7DC */ { NULL,NULL},
/* 1E7DD */ { NULL,NULL},
/* 1E7DE */ { NULL,NULL},
/* 1E7DF */ { NULL,NULL},
/* 1E7E0 */ { "ETHIOPIC SYLLABLE HHYA","	x (ethiopic syllable xya - 2DD0)"},
/* 1E7E1 */ { "ETHIOPIC SYLLABLE HHYU","	x (ethiopic syllable xyu - 2DD1)"},
/* 1E7E2 */ { "ETHIOPIC SYLLABLE HHYI","	x (ethiopic syllable xyi - 2DD2)"},
/* 1E7E3 */ { "ETHIOPIC SYLLABLE HHYAA","	x (ethiopic syllable xyaa - 2DD3)"},
/* 1E7E4 */ { "ETHIOPIC SYLLABLE HHYEE","	x (ethiopic syllable xyee - 2DD4)"},
/* 1E7E5 */ { "ETHIOPIC SYLLABLE HHYE","	x (ethiopic syllable xye - 2DD5)"},
/* 1E7E6 */ { "ETHIOPIC SYLLABLE HHYO","	x (ethiopic syllable xyo - 2DD6)"},
/* 1E7E7 */ { NULL,NULL},
/* 1E7E8 */ { "ETHIOPIC SYLLABLE GURAGE HHWA","	x (ethiopic syllable kxwa - 12C0)"},
/* 1E7E9 */ { "ETHIOPIC SYLLABLE HHWI","	x (ethiopic syllable kxwi - 12C2)"},
/* 1E7EA */ { "ETHIOPIC SYLLABLE HHWEE","	x (ethiopic syllable kxwee - 12C4)"},
/* 1E7EB */ { "ETHIOPIC SYLLABLE HHWE","	x (ethiopic syllable kxwe - 12C5)"},
/* 1E7EC */ { NULL,NULL},
/* 1E7ED */ { "ETHIOPIC SYLLABLE GURAGE MWI","	x (ethiopic syllable mwi - 1381)"},
/* 1E7EE */ { "ETHIOPIC SYLLABLE GURAGE MWEE","	x (ethiopic syllable mwee - 1382)"},
/* 1E7EF */ { NULL,NULL},
/* 1E7F0 */ { "ETHIOPIC SYLLABLE GURAGE QWI","	x (ethiopic syllable qwi - 124A)"},
/* 1E7F1 */ { "ETHIOPIC SYLLABLE GURAGE QWEE","	x (ethiopic syllable qwee - 124C)"},
/* 1E7F2 */ { "ETHIOPIC SYLLABLE GURAGE QWE","	x (ethiopic syllable qwe - 124D)"},
/* 1E7F3 */ { "ETHIOPIC SYLLABLE GURAGE BWI","	x (ethiopic syllable bwi - 1385)"},
/* 1E7F4 */ { "ETHIOPIC SYLLABLE GURAGE BWEE","	x (ethiopic syllable bwee - 1386)"},
/* 1E7F5 */ { "ETHIOPIC SYLLABLE GURAGE KWI","	x (ethiopic syllable kwi - 12B2)"},
/* 1E7F6 */ { "ETHIOPIC SYLLABLE GURAGE KWEE","	x (ethiopic syllable kwee - 12B4)"},
/* 1E7F7 */ { "ETHIOPIC SYLLABLE GURAGE KWE","	x (ethiopic syllable kwe - 12B5)"},
/* 1E7F8 */ { "ETHIOPIC SYLLABLE GURAGE GWI","	x (ethiopic syllable gwi - 1312)"},
/* 1E7F9 */ { "ETHIOPIC SYLLABLE GURAGE GWEE","	x (ethiopic syllable gwee - 1314)"},
/* 1E7FA */ { "ETHIOPIC SYLLABLE GURAGE GWE","	x (ethiopic syllable gwe - 1315)"},
/* 1E7FB */ { "ETHIOPIC SYLLABLE GURAGE FWI","	x (ethiopic syllable fwi - 1389)"},
/* 1E7FC */ { "ETHIOPIC SYLLABLE GURAGE FWEE","	x (ethiopic syllable fwee - 138A)"},
/* 1E7FD */ { "ETHIOPIC SYLLABLE GURAGE PWI","	x (ethiopic syllable pwi - 138D)"},
/* 1E7FE */ { "ETHIOPIC SYLLABLE GURAGE PWEE","	x (ethiopic syllable pwee - 138E)"},
/* 1E7FF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_E8[] = {
/* 1E800 */ { "MENDE KIKAKUI SYLLABLE M001 KI",NULL},
/* 1E801 */ { "MENDE KIKAKUI SYLLABLE M002 KA",NULL},
/* 1E802 */ { "MENDE KIKAKUI SYLLABLE M003 KU",NULL},
/* 1E803 */ { "MENDE KIKAKUI SYLLABLE M065 KEE",NULL},
/* 1E804 */ { "MENDE KIKAKUI SYLLABLE M095 KE",NULL},
/* 1E805 */ { "MENDE KIKAKUI SYLLABLE M076 KOO",NULL},
/* 1E806 */ { "MENDE KIKAKUI SYLLABLE M048 KO",NULL},
/* 1E807 */ { "MENDE KIKAKUI SYLLABLE M179 KUA","	* equivalent to Dalby M177"},
/* 1E808 */ { "MENDE KIKAKUI SYLLABLE M004 WI",NULL},
/* 1E809 */ { "MENDE KIKAKUI SYLLABLE M005 WA",NULL},
/* 1E80A */ { "MENDE KIKAKUI SYLLABLE M006 WU",NULL},
/* 1E80B */ { "MENDE KIKAKUI SYLLABLE M126 WEE",NULL},
/* 1E80C */ { "MENDE KIKAKUI SYLLABLE M118 WE",NULL},
/* 1E80D */ { "MENDE KIKAKUI SYLLABLE M114 WOO",NULL},
/* 1E80E */ { "MENDE KIKAKUI SYLLABLE M045 WO",NULL},
/* 1E80F */ { "MENDE KIKAKUI SYLLABLE M194 WUI",NULL},
/* 1E810 */ { "MENDE KIKAKUI SYLLABLE M143 WEI",NULL},
/* 1E811 */ { "MENDE KIKAKUI SYLLABLE M061 WVI",NULL},
/* 1E812 */ { "MENDE KIKAKUI SYLLABLE M049 WVA",NULL},
/* 1E813 */ { "MENDE KIKAKUI SYLLABLE M139 WVE",NULL},
/* 1E814 */ { "MENDE KIKAKUI SYLLABLE M007 MIN",NULL},
/* 1E815 */ { "MENDE KIKAKUI SYLLABLE M008 MAN",NULL},
/* 1E816 */ { "MENDE KIKAKUI SYLLABLE M009 MUN",NULL},
/* 1E817 */ { "MENDE KIKAKUI SYLLABLE M059 MEN",NULL},
/* 1E818 */ { "MENDE KIKAKUI SYLLABLE M094 MON",NULL},
/* 1E819 */ { "MENDE KIKAKUI SYLLABLE M154 MUAN",NULL},
/* 1E81A */ { "MENDE KIKAKUI SYLLABLE M189 MUEN",NULL},
/* 1E81B */ { "MENDE KIKAKUI SYLLABLE M010 BI",NULL},
/* 1E81C */ { "MENDE KIKAKUI SYLLABLE M011 BA",NULL},
/* 1E81D */ { "MENDE KIKAKUI SYLLABLE M012 BU",NULL},
/* 1E81E */ { "MENDE KIKAKUI SYLLABLE M150 BEE",NULL},
/* 1E81F */ { "MENDE KIKAKUI SYLLABLE M097 BE",NULL},
/* 1E820 */ { "MENDE KIKAKUI SYLLABLE M103 BOO",NULL},
/* 1E821 */ { "MENDE KIKAKUI SYLLABLE M138 BO",NULL},
/* 1E822 */ { "MENDE KIKAKUI SYLLABLE M013 I",NULL},
/* 1E823 */ { "MENDE KIKAKUI SYLLABLE M014 A",NULL},
/* 1E824 */ { "MENDE KIKAKUI SYLLABLE M015 U",NULL},
/* 1E825 */ { "MENDE KIKAKUI SYLLABLE M163 EE",NULL},
/* 1E826 */ { "MENDE KIKAKUI SYLLABLE M100 E",NULL},
/* 1E827 */ { "MENDE KIKAKUI SYLLABLE M165 OO",NULL},
/* 1E828 */ { "MENDE KIKAKUI SYLLABLE M147 O",NULL},
/* 1E829 */ { "MENDE KIKAKUI SYLLABLE M137 EI",NULL},
/* 1E82A */ { "MENDE KIKAKUI SYLLABLE M131 IN",NULL},
/* 1E82B */ { "MENDE KIKAKUI SYLLABLE M135 IN","	* used for the negative particle"},
/* 1E82C */ { "MENDE KIKAKUI SYLLABLE M195 AN","	* Dalby's M195 HO has different shape and value"},
/* 1E82D */ { "MENDE KIKAKUI SYLLABLE M178 EN","	* equivalent to Dalby M182"},
/* 1E82E */ { "MENDE KIKAKUI SYLLABLE M019 SI",NULL},
/* 1E82F */ { "MENDE KIKAKUI SYLLABLE M020 SA",NULL},
/* 1E830 */ { "MENDE KIKAKUI SYLLABLE M021 SU",NULL},
/* 1E831 */ { "MENDE KIKAKUI SYLLABLE M162 SEE",NULL},
/* 1E832 */ { "MENDE KIKAKUI SYLLABLE M116 SE",NULL},
/* 1E833 */ { "MENDE KIKAKUI SYLLABLE M136 SOO",NULL},
/* 1E834 */ { "MENDE KIKAKUI SYLLABLE M079 SO",NULL},
/* 1E835 */ { "MENDE KIKAKUI SYLLABLE M196 SIA","	* not in Dalby or in Mansaray"},
/* 1E836 */ { "MENDE KIKAKUI SYLLABLE M025 LI","	* equivalent to Dalby and Mansaray M022"},
/* 1E837 */ { "MENDE KIKAKUI SYLLABLE M026 LA","	* equivalent to Dalby and Mansaray M023"},
/* 1E838 */ { "MENDE KIKAKUI SYLLABLE M027 LU","	* equivalent to Dalby and Mansaray M024"},
/* 1E839 */ { "MENDE KIKAKUI SYLLABLE M084 LEE",NULL},
/* 1E83A */ { "MENDE KIKAKUI SYLLABLE M073 LE",NULL},
/* 1E83B */ { "MENDE KIKAKUI SYLLABLE M054 LOO",NULL},
/* 1E83C */ { "MENDE KIKAKUI SYLLABLE M153 LO",NULL},
/* 1E83D */ { "MENDE KIKAKUI SYLLABLE M110 LONG LE",NULL},
/* 1E83E */ { "MENDE KIKAKUI SYLLABLE M016 DI",NULL},
/* 1E83F */ { "MENDE KIKAKUI SYLLABLE M017 DA",NULL},
/* 1E840 */ { "MENDE KIKAKUI SYLLABLE M018 DU",NULL},
/* 1E841 */ { "MENDE KIKAKUI SYLLABLE M089 DEE",NULL},
/* 1E842 */ { "MENDE KIKAKUI SYLLABLE M180 DOO","	* equivalent to Dalby M178"},
/* 1E843 */ { "MENDE KIKAKUI SYLLABLE M181 DO","	* equivalent to Dalby M179"},
/* 1E844 */ { "MENDE KIKAKUI SYLLABLE M022 TI","	* equivalent to Dalby and Mansaray M025"},
/* 1E845 */ { "MENDE KIKAKUI SYLLABLE M023 TA","	* equivalent to Dalby and Mansaray M026"},
/* 1E846 */ { "MENDE KIKAKUI SYLLABLE M024 TU","	* equivalent to Dalby and Mansaray M027"},
/* 1E847 */ { "MENDE KIKAKUI SYLLABLE M091 TEE",NULL},
/* 1E848 */ { "MENDE KIKAKUI SYLLABLE M055 TE",NULL},
/* 1E849 */ { "MENDE KIKAKUI SYLLABLE M104 TOO",NULL},
/* 1E84A */ { "MENDE KIKAKUI SYLLABLE M069 TO",NULL},
/* 1E84B */ { "MENDE KIKAKUI SYLLABLE M028 JI","	* equivalent to Mansaray M034"},
/* 1E84C */ { "MENDE KIKAKUI SYLLABLE M029 JA","	* equivalent to Mansaray M035"},
/* 1E84D */ { "MENDE KIKAKUI SYLLABLE M030 JU","	* equivalent to Mansaray M036"},
/* 1E84E */ { "MENDE KIKAKUI SYLLABLE M157 JEE",NULL},
/* 1E84F */ { "MENDE KIKAKUI SYLLABLE M113 JE",NULL},
/* 1E850 */ { "MENDE KIKAKUI SYLLABLE M160 JOO",NULL},
/* 1E851 */ { "MENDE KIKAKUI SYLLABLE M063 JO",NULL},
/* 1E852 */ { "MENDE KIKAKUI SYLLABLE M175 LONG JO",NULL},
/* 1E853 */ { "MENDE KIKAKUI SYLLABLE M031 YI",NULL},
/* 1E854 */ { "MENDE KIKAKUI SYLLABLE M032 YA",NULL},
/* 1E855 */ { "MENDE KIKAKUI SYLLABLE M033 YU",NULL},
/* 1E856 */ { "MENDE KIKAKUI SYLLABLE M109 YEE",NULL},
/* 1E857 */ { "MENDE KIKAKUI SYLLABLE M080 YE",NULL},
/* 1E858 */ { "MENDE KIKAKUI SYLLABLE M141 YOO",NULL},
/* 1E859 */ { "MENDE KIKAKUI SYLLABLE M121 YO",NULL},
/* 1E85A */ { "MENDE KIKAKUI SYLLABLE M034 FI","	* equivalent to Mansaray M028"},
/* 1E85B */ { "MENDE KIKAKUI SYLLABLE M035 FA","	* equivalent to Mansaray M029"},
/* 1E85C */ { "MENDE KIKAKUI SYLLABLE M036 FU","	* equivalent to Mansaray M030"},
/* 1E85D */ { "MENDE KIKAKUI SYLLABLE M078 FEE",NULL},
/* 1E85E */ { "MENDE KIKAKUI SYLLABLE M075 FE",NULL},
/* 1E85F */ { "MENDE KIKAKUI SYLLABLE M133 FOO",NULL},
/* 1E860 */ { "MENDE KIKAKUI SYLLABLE M088 FO",NULL},
/* 1E861 */ { "MENDE KIKAKUI SYLLABLE M197 FUA","	* not in Dalby or in Mansaray"},
/* 1E862 */ { "MENDE KIKAKUI SYLLABLE M101 FAN",NULL},
/* 1E863 */ { "MENDE KIKAKUI SYLLABLE M037 NIN",NULL},
/* 1E864 */ { "MENDE KIKAKUI SYLLABLE M038 NAN",NULL},
/* 1E865 */ { "MENDE KIKAKUI SYLLABLE M039 NUN",NULL},
/* 1E866 */ { "MENDE KIKAKUI SYLLABLE M117 NEN",NULL},
/* 1E867 */ { "MENDE KIKAKUI SYLLABLE M169 NON",NULL},
/* 1E868 */ { "MENDE KIKAKUI SYLLABLE M176 HI",NULL},
/* 1E869 */ { "MENDE KIKAKUI SYLLABLE M041 HA",NULL},
/* 1E86A */ { "MENDE KIKAKUI SYLLABLE M186 HU",NULL},
/* 1E86B */ { "MENDE KIKAKUI SYLLABLE M040 HEE",NULL},
/* 1E86C */ { "MENDE KIKAKUI SYLLABLE M096 HE",NULL},
/* 1E86D */ { "MENDE KIKAKUI SYLLABLE M042 HOO",NULL},
/* 1E86E */ { "MENDE KIKAKUI SYLLABLE M140 HO",NULL},
/* 1E86F */ { "MENDE KIKAKUI SYLLABLE M083 HEEI",NULL},
/* 1E870 */ { "MENDE KIKAKUI SYLLABLE M128 HOOU",NULL},
/* 1E871 */ { "MENDE KIKAKUI SYLLABLE M053 HIN",NULL},
/* 1E872 */ { "MENDE KIKAKUI SYLLABLE M130 HAN",NULL},
/* 1E873 */ { "MENDE KIKAKUI SYLLABLE M087 HUN",NULL},
/* 1E874 */ { "MENDE KIKAKUI SYLLABLE M052 HEN",NULL},
/* 1E875 */ { "MENDE KIKAKUI SYLLABLE M193 HON","	* Dalby's M193 NGGEE has different shape and value"},
/* 1E876 */ { "MENDE KIKAKUI SYLLABLE M046 HUAN",NULL},
/* 1E877 */ { "MENDE KIKAKUI SYLLABLE M090 NGGI",NULL},
/* 1E878 */ { "MENDE KIKAKUI SYLLABLE M043 NGGA",NULL},
/* 1E879 */ { "MENDE KIKAKUI SYLLABLE M082 NGGU",NULL},
/* 1E87A */ { "MENDE KIKAKUI SYLLABLE M115 NGGEE",NULL},
/* 1E87B */ { "MENDE KIKAKUI SYLLABLE M146 NGGE",NULL},
/* 1E87C */ { "MENDE KIKAKUI SYLLABLE M156 NGGOO",NULL},
/* 1E87D */ { "MENDE KIKAKUI SYLLABLE M120 NGGO",NULL},
/* 1E87E */ { "MENDE KIKAKUI SYLLABLE M159 NGGAA",NULL},
/* 1E87F */ { "MENDE KIKAKUI SYLLABLE M127 NGGUA",NULL},
/* 1E880 */ { "MENDE KIKAKUI SYLLABLE M086 LONG NGGE",NULL},
/* 1E881 */ { "MENDE KIKAKUI SYLLABLE M106 LONG NGGOO",NULL},
/* 1E882 */ { "MENDE KIKAKUI SYLLABLE M183 LONG NGGO",NULL},
/* 1E883 */ { "MENDE KIKAKUI SYLLABLE M155 GI",NULL},
/* 1E884 */ { "MENDE KIKAKUI SYLLABLE M111 GA",NULL},
/* 1E885 */ { "MENDE KIKAKUI SYLLABLE M168 GU",NULL},
/* 1E886 */ { "MENDE KIKAKUI SYLLABLE M190 GEE",NULL},
/* 1E887 */ { "MENDE KIKAKUI SYLLABLE M166 GUEI",NULL},
/* 1E888 */ { "MENDE KIKAKUI SYLLABLE M167 GUAN",NULL},
/* 1E889 */ { "MENDE KIKAKUI SYLLABLE M184 NGEN",NULL},
/* 1E88A */ { "MENDE KIKAKUI SYLLABLE M057 NGON",NULL},
/* 1E88B */ { "MENDE KIKAKUI SYLLABLE M177 NGUAN","	* equivalent to Dalby M181"},
/* 1E88C */ { "MENDE KIKAKUI SYLLABLE M068 PI",NULL},
/* 1E88D */ { "MENDE KIKAKUI SYLLABLE M099 PA",NULL},
/* 1E88E */ { "MENDE KIKAKUI SYLLABLE M050 PU",NULL},
/* 1E88F */ { "MENDE KIKAKUI SYLLABLE M081 PEE",NULL},
/* 1E890 */ { "MENDE KIKAKUI SYLLABLE M051 PE",NULL},
/* 1E891 */ { "MENDE KIKAKUI SYLLABLE M102 POO",NULL},
/* 1E892 */ { "MENDE KIKAKUI SYLLABLE M066 PO",NULL},
/* 1E893 */ { "MENDE KIKAKUI SYLLABLE M145 MBI",NULL},
/* 1E894 */ { "MENDE KIKAKUI SYLLABLE M062 MBA",NULL},
/* 1E895 */ { "MENDE KIKAKUI SYLLABLE M122 MBU",NULL},
/* 1E896 */ { "MENDE KIKAKUI SYLLABLE M047 MBEE",NULL},
/* 1E897 */ { "MENDE KIKAKUI SYLLABLE M188 MBEE",NULL},
/* 1E898 */ { "MENDE KIKAKUI SYLLABLE M072 MBE",NULL},
/* 1E899 */ { "MENDE KIKAKUI SYLLABLE M172 MBOO","	% MENDE KIKAKUI SYLLABLE M172 MBO\n"
	"	* this and the following character had swapped transliterations of the vowels in their names"},
/* 1E89A */ { "MENDE KIKAKUI SYLLABLE M174 MBO","	% MENDE KIKAKUI SYLLABLE M174 MBOO"},
/* 1E89B */ { "MENDE KIKAKUI SYLLABLE M187 MBUU",NULL},
/* 1E89C */ { "MENDE KIKAKUI SYLLABLE M161 LONG MBE",NULL},
/* 1E89D */ { "MENDE KIKAKUI SYLLABLE M105 LONG MBOO",NULL},
/* 1E89E */ { "MENDE KIKAKUI SYLLABLE M142 LONG MBO",NULL},
/* 1E89F */ { "MENDE KIKAKUI SYLLABLE M132 KPI",NULL},
/* 1E8A0 */ { "MENDE KIKAKUI SYLLABLE M092 KPA",NULL},
/* 1E8A1 */ { "MENDE KIKAKUI SYLLABLE M074 KPU",NULL},
/* 1E8A2 */ { "MENDE KIKAKUI SYLLABLE M044 KPEE",NULL},
/* 1E8A3 */ { "MENDE KIKAKUI SYLLABLE M108 KPE",NULL},
/* 1E8A4 */ { "MENDE KIKAKUI SYLLABLE M112 KPOO",NULL},
/* 1E8A5 */ { "MENDE KIKAKUI SYLLABLE M158 KPO",NULL},
/* 1E8A6 */ { "MENDE KIKAKUI SYLLABLE M124 GBI",NULL},
/* 1E8A7 */ { "MENDE KIKAKUI SYLLABLE M056 GBA",NULL},
/* 1E8A8 */ { "MENDE KIKAKUI SYLLABLE M148 GBU",NULL},
/* 1E8A9 */ { "MENDE KIKAKUI SYLLABLE M093 GBEE",NULL},
/* 1E8AA */ { "MENDE KIKAKUI SYLLABLE M107 GBE",NULL},
/* 1E8AB */ { "MENDE KIKAKUI SYLLABLE M071 GBOO",NULL},
/* 1E8AC */ { "MENDE KIKAKUI SYLLABLE M070 GBO",NULL},
/* 1E8AD */ { "MENDE KIKAKUI SYLLABLE M171 RA",NULL},
/* 1E8AE */ { "MENDE KIKAKUI SYLLABLE M123 NDI",NULL},
/* 1E8AF */ { "MENDE KIKAKUI SYLLABLE M129 NDA",NULL},
/* 1E8B0 */ { "MENDE KIKAKUI SYLLABLE M125 NDU",NULL},
/* 1E8B1 */ { "MENDE KIKAKUI SYLLABLE M191 NDEE",NULL},
/* 1E8B2 */ { "MENDE KIKAKUI SYLLABLE M119 NDE",NULL},
/* 1E8B3 */ { "MENDE KIKAKUI SYLLABLE M067 NDOO",NULL},
/* 1E8B4 */ { "MENDE KIKAKUI SYLLABLE M064 NDO",NULL},
/* 1E8B5 */ { "MENDE KIKAKUI SYLLABLE M152 NJA",NULL},
/* 1E8B6 */ { "MENDE KIKAKUI SYLLABLE M192 NJU",NULL},
/* 1E8B7 */ { "MENDE KIKAKUI SYLLABLE M149 NJEE",NULL},
/* 1E8B8 */ { "MENDE KIKAKUI SYLLABLE M134 NJOO",NULL},
/* 1E8B9 */ { "MENDE KIKAKUI SYLLABLE M182 VI","	* equivalent to Dalby M180"},
/* 1E8BA */ { "MENDE KIKAKUI SYLLABLE M185 VA",NULL},
/* 1E8BB */ { "MENDE KIKAKUI SYLLABLE M151 VU",NULL},
/* 1E8BC */ { "MENDE KIKAKUI SYLLABLE M173 VEE",NULL},
/* 1E8BD */ { "MENDE KIKAKUI SYLLABLE M085 VE",NULL},
/* 1E8BE */ { "MENDE KIKAKUI SYLLABLE M144 VOO",NULL},
/* 1E8BF */ { "MENDE KIKAKUI SYLLABLE M077 VO",NULL},
/* 1E8C0 */ { "MENDE KIKAKUI SYLLABLE M164 NYIN",NULL},
/* 1E8C1 */ { "MENDE KIKAKUI SYLLABLE M058 NYAN",NULL},
/* 1E8C2 */ { "MENDE KIKAKUI SYLLABLE M170 NYUN",NULL},
/* 1E8C3 */ { "MENDE KIKAKUI SYLLABLE M098 NYEN",NULL},
/* 1E8C4 */ { "MENDE KIKAKUI SYLLABLE M060 NYON",NULL},
/* 1E8C5 */ { NULL,NULL},
/* 1E8C6 */ { NULL,NULL},
/* 1E8C7 */ { "MENDE KIKAKUI DIGIT ONE",NULL},
/* 1E8C8 */ { "MENDE KIKAKUI DIGIT TWO",NULL},
/* 1E8C9 */ { "MENDE KIKAKUI DIGIT THREE",NULL},
/* 1E8CA */ { "MENDE KIKAKUI DIGIT FOUR",NULL},
/* 1E8CB */ { "MENDE KIKAKUI DIGIT FIVE",NULL},
/* 1E8CC */ { "MENDE KIKAKUI DIGIT SIX",NULL},
/* 1E8CD */ { "MENDE KIKAKUI DIGIT SEVEN",NULL},
/* 1E8CE */ { "MENDE KIKAKUI DIGIT EIGHT",NULL},
/* 1E8CF */ { "MENDE KIKAKUI DIGIT NINE",NULL},
/* 1E8D0 */ { "MENDE KIKAKUI COMBINING NUMBER TEENS",NULL},
/* 1E8D1 */ { "MENDE KIKAKUI COMBINING NUMBER TENS",NULL},
/* 1E8D2 */ { "MENDE KIKAKUI COMBINING NUMBER HUNDREDS",NULL},
/* 1E8D3 */ { "MENDE KIKAKUI COMBINING NUMBER THOUSANDS",NULL},
/* 1E8D4 */ { "MENDE KIKAKUI COMBINING NUMBER TEN THOUSANDS",NULL},
/* 1E8D5 */ { "MENDE KIKAKUI COMBINING NUMBER HUNDRED THOUSANDS",NULL},
/* 1E8D6 */ { "MENDE KIKAKUI COMBINING NUMBER MILLIONS",NULL},
/* 1E8D7 */ { NULL,NULL},
/* 1E8D8 */ { NULL,NULL},
/* 1E8D9 */ { NULL,NULL},
/* 1E8DA */ { NULL,NULL},
/* 1E8DB */ { NULL,NULL},
/* 1E8DC */ { NULL,NULL},
/* 1E8DD */ { NULL,NULL},
/* 1E8DE */ { NULL,NULL},
/* 1E8DF */ { NULL,NULL},
/* 1E8E0 */ { NULL,NULL},
/* 1E8E1 */ { NULL,NULL},
/* 1E8E2 */ { NULL,NULL},
/* 1E8E3 */ { NULL,NULL},
/* 1E8E4 */ { NULL,NULL},
/* 1E8E5 */ { NULL,NULL},
/* 1E8E6 */ { NULL,NULL},
/* 1E8E7 */ { NULL,NULL},
/* 1E8E8 */ { NULL,NULL},
/* 1E8E9 */ { NULL,NULL},
/* 1E8EA */ { NULL,NULL},
/* 1E8EB */ { NULL,NULL},
/* 1E8EC */ { NULL,NULL},
/* 1E8ED */ { NULL,NULL},
/* 1E8EE */ { NULL,NULL},
/* 1E8EF */ { NULL,NULL},
/* 1E8F0 */ { NULL,NULL},
/* 1E8F1 */ { NULL,NULL},
/* 1E8F2 */ { NULL,NULL},
/* 1E8F3 */ { NULL,NULL},
/* 1E8F4 */ { NULL,NULL},
/* 1E8F5 */ { NULL,NULL},
/* 1E8F6 */ { NULL,NULL},
/* 1E8F7 */ { NULL,NULL},
/* 1E8F8 */ { NULL,NULL},
/* 1E8F9 */ { NULL,NULL},
/* 1E8FA */ { NULL,NULL},
/* 1E8FB */ { NULL,NULL},
/* 1E8FC */ { NULL,NULL},
/* 1E8FD */ { NULL,NULL},
/* 1E8FE */ { NULL,NULL},
/* 1E8FF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_E9[] = {
/* 1E900 */ { "ADLAM CAPITAL LETTER ALIF","	= a"},
/* 1E901 */ { "ADLAM CAPITAL LETTER DAALI","	= da"},
/* 1E902 */ { "ADLAM CAPITAL LETTER LAAM","	= la"},
/* 1E903 */ { "ADLAM CAPITAL LETTER MIIM","	= ma"},
/* 1E904 */ { "ADLAM CAPITAL LETTER BA",NULL},
/* 1E905 */ { "ADLAM CAPITAL LETTER SINNYIIYHE","	= sa"},
/* 1E906 */ { "ADLAM CAPITAL LETTER PE","	= pa"},
/* 1E907 */ { "ADLAM CAPITAL LETTER BHE","	= bha"},
/* 1E908 */ { "ADLAM CAPITAL LETTER RA",NULL},
/* 1E909 */ { "ADLAM CAPITAL LETTER E",NULL},
/* 1E90A */ { "ADLAM CAPITAL LETTER FA",NULL},
/* 1E90B */ { "ADLAM CAPITAL LETTER I",NULL},
/* 1E90C */ { "ADLAM CAPITAL LETTER O",NULL},
/* 1E90D */ { "ADLAM CAPITAL LETTER DHA",NULL},
/* 1E90E */ { "ADLAM CAPITAL LETTER YHE","	= yha"},
/* 1E90F */ { "ADLAM CAPITAL LETTER WAW","	= wa"},
/* 1E910 */ { "ADLAM CAPITAL LETTER NUN","	= na"},
/* 1E911 */ { "ADLAM CAPITAL LETTER KAF","	= ka"},
/* 1E912 */ { "ADLAM CAPITAL LETTER YA",NULL},
/* 1E913 */ { "ADLAM CAPITAL LETTER U",NULL},
/* 1E914 */ { "ADLAM CAPITAL LETTER JIIM","	= ja"},
/* 1E915 */ { "ADLAM CAPITAL LETTER CHI","	= tcha"},
/* 1E916 */ { "ADLAM CAPITAL LETTER HA",NULL},
/* 1E917 */ { "ADLAM CAPITAL LETTER QAAF","	= qa"},
/* 1E918 */ { "ADLAM CAPITAL LETTER GA",NULL},
/* 1E919 */ { "ADLAM CAPITAL LETTER NYA",NULL},
/* 1E91A */ { "ADLAM CAPITAL LETTER TU","	= ta"},
/* 1E91B */ { "ADLAM CAPITAL LETTER NHA",NULL},
/* 1E91C */ { "ADLAM CAPITAL LETTER VA",NULL},
/* 1E91D */ { "ADLAM CAPITAL LETTER KHA",NULL},
/* 1E91E */ { "ADLAM CAPITAL LETTER GBE","	= gba"},
/* 1E91F */ { "ADLAM CAPITAL LETTER ZAL","	= za"},
/* 1E920 */ { "ADLAM CAPITAL LETTER KPO","	= kpa"},
/* 1E921 */ { "ADLAM CAPITAL LETTER SHA",NULL},
/* 1E922 */ { "ADLAM SMALL LETTER ALIF",NULL},
/* 1E923 */ { "ADLAM SMALL LETTER DAALI",NULL},
/* 1E924 */ { "ADLAM SMALL LETTER LAAM",NULL},
/* 1E925 */ { "ADLAM SMALL LETTER MIIM",NULL},
/* 1E926 */ { "ADLAM SMALL LETTER BA",NULL},
/* 1E927 */ { "ADLAM SMALL LETTER SINNYIIYHE",NULL},
/* 1E928 */ { "ADLAM SMALL LETTER PE",NULL},
/* 1E929 */ { "ADLAM SMALL LETTER BHE",NULL},
/* 1E92A */ { "ADLAM SMALL LETTER RA",NULL},
/* 1E92B */ { "ADLAM SMALL LETTER E",NULL},
/* 1E92C */ { "ADLAM SMALL LETTER FA",NULL},
/* 1E92D */ { "ADLAM SMALL LETTER I",NULL},
/* 1E92E */ { "ADLAM SMALL LETTER O",NULL},
/* 1E92F */ { "ADLAM SMALL LETTER DHA",NULL},
/* 1E930 */ { "ADLAM SMALL LETTER YHE",NULL},
/* 1E931 */ { "ADLAM SMALL LETTER WAW",NULL},
/* 1E932 */ { "ADLAM SMALL LETTER NUN",NULL},
/* 1E933 */ { "ADLAM SMALL LETTER KAF",NULL},
/* 1E934 */ { "ADLAM SMALL LETTER YA",NULL},
/* 1E935 */ { "ADLAM SMALL LETTER U",NULL},
/* 1E936 */ { "ADLAM SMALL LETTER JIIM",NULL},
/* 1E937 */ { "ADLAM SMALL LETTER CHI",NULL},
/* 1E938 */ { "ADLAM SMALL LETTER HA",NULL},
/* 1E939 */ { "ADLAM SMALL LETTER QAAF",NULL},
/* 1E93A */ { "ADLAM SMALL LETTER GA",NULL},
/* 1E93B */ { "ADLAM SMALL LETTER NYA",NULL},
/* 1E93C */ { "ADLAM SMALL LETTER TU",NULL},
/* 1E93D */ { "ADLAM SMALL LETTER NHA",NULL},
/* 1E93E */ { "ADLAM SMALL LETTER VA",NULL},
/* 1E93F */ { "ADLAM SMALL LETTER KHA",NULL},
/* 1E940 */ { "ADLAM SMALL LETTER GBE",NULL},
/* 1E941 */ { "ADLAM SMALL LETTER ZAL",NULL},
/* 1E942 */ { "ADLAM SMALL LETTER KPO",NULL},
/* 1E943 */ { "ADLAM SMALL LETTER SHA",NULL},
/* 1E944 */ { "ADLAM ALIF LENGTHENER",NULL},
/* 1E945 */ { "ADLAM VOWEL LENGTHENER",NULL},
/* 1E946 */ { "ADLAM GEMINATION MARK",NULL},
/* 1E947 */ { "ADLAM HAMZA",NULL},
/* 1E948 */ { "ADLAM CONSONANT MODIFIER",NULL},
/* 1E949 */ { "ADLAM GEMINATE CONSONANT MODIFIER",NULL},
/* 1E94A */ { "ADLAM NUKTA","	* called hoortobbhere when drawn above and lestobbhere when drawn below the base character"},
/* 1E94B */ { "ADLAM NASALIZATION MARK","	* indicates preceding nasal consonant prenasalizes subsequent consonant letter"},
/* 1E94C */ { NULL,NULL},
/* 1E94D */ { NULL,NULL},
/* 1E94E */ { NULL,NULL},
/* 1E94F */ { NULL,NULL},
/* 1E950 */ { "ADLAM DIGIT ZERO",NULL},
/* 1E951 */ { "ADLAM DIGIT ONE",NULL},
/* 1E952 */ { "ADLAM DIGIT TWO",NULL},
/* 1E953 */ { "ADLAM DIGIT THREE",NULL},
/* 1E954 */ { "ADLAM DIGIT FOUR",NULL},
/* 1E955 */ { "ADLAM DIGIT FIVE",NULL},
/* 1E956 */ { "ADLAM DIGIT SIX",NULL},
/* 1E957 */ { "ADLAM DIGIT SEVEN",NULL},
/* 1E958 */ { "ADLAM DIGIT EIGHT",NULL},
/* 1E959 */ { "ADLAM DIGIT NINE",NULL},
/* 1E95A */ { NULL,NULL},
/* 1E95B */ { NULL,NULL},
/* 1E95C */ { NULL,NULL},
/* 1E95D */ { NULL,NULL},
/* 1E95E */ { "ADLAM INITIAL EXCLAMATION MARK",NULL},
/* 1E95F */ { "ADLAM INITIAL QUESTION MARK",NULL},
/* 1E960 */ { NULL,NULL},
/* 1E961 */ { NULL,NULL},
/* 1E962 */ { NULL,NULL},
/* 1E963 */ { NULL,NULL},
/* 1E964 */ { NULL,NULL},
/* 1E965 */ { NULL,NULL},
/* 1E966 */ { NULL,NULL},
/* 1E967 */ { NULL,NULL},
/* 1E968 */ { NULL,NULL},
/* 1E969 */ { NULL,NULL},
/* 1E96A */ { NULL,NULL},
/* 1E96B */ { NULL,NULL},
/* 1E96C */ { NULL,NULL},
/* 1E96D */ { NULL,NULL},
/* 1E96E */ { NULL,NULL},
/* 1E96F */ { NULL,NULL},
/* 1E970 */ { NULL,NULL},
/* 1E971 */ { NULL,NULL},
/* 1E972 */ { NULL,NULL},
/* 1E973 */ { NULL,NULL},
/* 1E974 */ { NULL,NULL},
/* 1E975 */ { NULL,NULL},
/* 1E976 */ { NULL,NULL},
/* 1E977 */ { NULL,NULL},
/* 1E978 */ { NULL,NULL},
/* 1E979 */ { NULL,NULL},
/* 1E97A */ { NULL,NULL},
/* 1E97B */ { NULL,NULL},
/* 1E97C */ { NULL,NULL},
/* 1E97D */ { NULL,NULL},
/* 1E97E */ { NULL,NULL},
/* 1E97F */ { NULL,NULL},
/* 1E980 */ { NULL,NULL},
/* 1E981 */ { NULL,NULL},
/* 1E982 */ { NULL,NULL},
/* 1E983 */ { NULL,NULL},
/* 1E984 */ { NULL,NULL},
/* 1E985 */ { NULL,NULL},
/* 1E986 */ { NULL,NULL},
/* 1E987 */ { NULL,NULL},
/* 1E988 */ { NULL,NULL},
/* 1E989 */ { NULL,NULL},
/* 1E98A */ { NULL,NULL},
/* 1E98B */ { NULL,NULL},
/* 1E98C */ { NULL,NULL},
/* 1E98D */ { NULL,NULL},
/* 1E98E */ { NULL,NULL},
/* 1E98F */ { NULL,NULL},
/* 1E990 */ { NULL,NULL},
/* 1E991 */ { NULL,NULL},
/* 1E992 */ { NULL,NULL},
/* 1E993 */ { NULL,NULL},
/* 1E994 */ { NULL,NULL},
/* 1E995 */ { NULL,NULL},
/* 1E996 */ { NULL,NULL},
/* 1E997 */ { NULL,NULL},
/* 1E998 */ { NULL,NULL},
/* 1E999 */ { NULL,NULL},
/* 1E99A */ { NULL,NULL},
/* 1E99B */ { NULL,NULL},
/* 1E99C */ { NULL,NULL},
/* 1E99D */ { NULL,NULL},
/* 1E99E */ { NULL,NULL},
/* 1E99F */ { NULL,NULL},
/* 1E9A0 */ { NULL,NULL},
/* 1E9A1 */ { NULL,NULL},
/* 1E9A2 */ { NULL,NULL},
/* 1E9A3 */ { NULL,NULL},
/* 1E9A4 */ { NULL,NULL},
/* 1E9A5 */ { NULL,NULL},
/* 1E9A6 */ { NULL,NULL},
/* 1E9A7 */ { NULL,NULL},
/* 1E9A8 */ { NULL,NULL},
/* 1E9A9 */ { NULL,NULL},
/* 1E9AA */ { NULL,NULL},
/* 1E9AB */ { NULL,NULL},
/* 1E9AC */ { NULL,NULL},
/* 1E9AD */ { NULL,NULL},
/* 1E9AE */ { NULL,NULL},
/* 1E9AF */ { NULL,NULL},
/* 1E9B0 */ { NULL,NULL},
/* 1E9B1 */ { NULL,NULL},
/* 1E9B2 */ { NULL,NULL},
/* 1E9B3 */ { NULL,NULL},
/* 1E9B4 */ { NULL,NULL},
/* 1E9B5 */ { NULL,NULL},
/* 1E9B6 */ { NULL,NULL},
/* 1E9B7 */ { NULL,NULL},
/* 1E9B8 */ { NULL,NULL},
/* 1E9B9 */ { NULL,NULL},
/* 1E9BA */ { NULL,NULL},
/* 1E9BB */ { NULL,NULL},
/* 1E9BC */ { NULL,NULL},
/* 1E9BD */ { NULL,NULL},
/* 1E9BE */ { NULL,NULL},
/* 1E9BF */ { NULL,NULL},
/* 1E9C0 */ { NULL,NULL},
/* 1E9C1 */ { NULL,NULL},
/* 1E9C2 */ { NULL,NULL},
/* 1E9C3 */ { NULL,NULL},
/* 1E9C4 */ { NULL,NULL},
/* 1E9C5 */ { NULL,NULL},
/* 1E9C6 */ { NULL,NULL},
/* 1E9C7 */ { NULL,NULL},
/* 1E9C8 */ { NULL,NULL},
/* 1E9C9 */ { NULL,NULL},
/* 1E9CA */ { NULL,NULL},
/* 1E9CB */ { NULL,NULL},
/* 1E9CC */ { NULL,NULL},
/* 1E9CD */ { NULL,NULL},
/* 1E9CE */ { NULL,NULL},
/* 1E9CF */ { NULL,NULL},
/* 1E9D0 */ { NULL,NULL},
/* 1E9D1 */ { NULL,NULL},
/* 1E9D2 */ { NULL,NULL},
/* 1E9D3 */ { NULL,NULL},
/* 1E9D4 */ { NULL,NULL},
/* 1E9D5 */ { NULL,NULL},
/* 1E9D6 */ { NULL,NULL},
/* 1E9D7 */ { NULL,NULL},
/* 1E9D8 */ { NULL,NULL},
/* 1E9D9 */ { NULL,NULL},
/* 1E9DA */ { NULL,NULL},
/* 1E9DB */ { NULL,NULL},
/* 1E9DC */ { NULL,NULL},
/* 1E9DD */ { NULL,NULL},
/* 1E9DE */ { NULL,NULL},
/* 1E9DF */ { NULL,NULL},
/* 1E9E0 */ { NULL,NULL},
/* 1E9E1 */ { NULL,NULL},
/* 1E9E2 */ { NULL,NULL},
/* 1E9E3 */ { NULL,NULL},
/* 1E9E4 */ { NULL,NULL},
/* 1E9E5 */ { NULL,NULL},
/* 1E9E6 */ { NULL,NULL},
/* 1E9E7 */ { NULL,NULL},
/* 1E9E8 */ { NULL,NULL},
/* 1E9E9 */ { NULL,NULL},
/* 1E9EA */ { NULL,NULL},
/* 1E9EB */ { NULL,NULL},
/* 1E9EC */ { NULL,NULL},
/* 1E9ED */ { NULL,NULL},
/* 1E9EE */ { NULL,NULL},
/* 1E9EF */ { NULL,NULL},
/* 1E9F0 */ { NULL,NULL},
/* 1E9F1 */ { NULL,NULL},
/* 1E9F2 */ { NULL,NULL},
/* 1E9F3 */ { NULL,NULL},
/* 1E9F4 */ { NULL,NULL},
/* 1E9F5 */ { NULL,NULL},
/* 1E9F6 */ { NULL,NULL},
/* 1E9F7 */ { NULL,NULL},
/* 1E9F8 */ { NULL,NULL},
/* 1E9F9 */ { NULL,NULL},
/* 1E9FA */ { NULL,NULL},
/* 1E9FB */ { NULL,NULL},
/* 1E9FC */ { NULL,NULL},
/* 1E9FD */ { NULL,NULL},
/* 1E9FE */ { NULL,NULL},
/* 1E9FF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_EC[] = {
/* 1EC00 */ { NULL,NULL},
/* 1EC01 */ { NULL,NULL},
/* 1EC02 */ { NULL,NULL},
/* 1EC03 */ { NULL,NULL},
/* 1EC04 */ { NULL,NULL},
/* 1EC05 */ { NULL,NULL},
/* 1EC06 */ { NULL,NULL},
/* 1EC07 */ { NULL,NULL},
/* 1EC08 */ { NULL,NULL},
/* 1EC09 */ { NULL,NULL},
/* 1EC0A */ { NULL,NULL},
/* 1EC0B */ { NULL,NULL},
/* 1EC0C */ { NULL,NULL},
/* 1EC0D */ { NULL,NULL},
/* 1EC0E */ { NULL,NULL},
/* 1EC0F */ { NULL,NULL},
/* 1EC10 */ { NULL,NULL},
/* 1EC11 */ { NULL,NULL},
/* 1EC12 */ { NULL,NULL},
/* 1EC13 */ { NULL,NULL},
/* 1EC14 */ { NULL,NULL},
/* 1EC15 */ { NULL,NULL},
/* 1EC16 */ { NULL,NULL},
/* 1EC17 */ { NULL,NULL},
/* 1EC18 */ { NULL,NULL},
/* 1EC19 */ { NULL,NULL},
/* 1EC1A */ { NULL,NULL},
/* 1EC1B */ { NULL,NULL},
/* 1EC1C */ { NULL,NULL},
/* 1EC1D */ { NULL,NULL},
/* 1EC1E */ { NULL,NULL},
/* 1EC1F */ { NULL,NULL},
/* 1EC20 */ { NULL,NULL},
/* 1EC21 */ { NULL,NULL},
/* 1EC22 */ { NULL,NULL},
/* 1EC23 */ { NULL,NULL},
/* 1EC24 */ { NULL,NULL},
/* 1EC25 */ { NULL,NULL},
/* 1EC26 */ { NULL,NULL},
/* 1EC27 */ { NULL,NULL},
/* 1EC28 */ { NULL,NULL},
/* 1EC29 */ { NULL,NULL},
/* 1EC2A */ { NULL,NULL},
/* 1EC2B */ { NULL,NULL},
/* 1EC2C */ { NULL,NULL},
/* 1EC2D */ { NULL,NULL},
/* 1EC2E */ { NULL,NULL},
/* 1EC2F */ { NULL,NULL},
/* 1EC30 */ { NULL,NULL},
/* 1EC31 */ { NULL,NULL},
/* 1EC32 */ { NULL,NULL},
/* 1EC33 */ { NULL,NULL},
/* 1EC34 */ { NULL,NULL},
/* 1EC35 */ { NULL,NULL},
/* 1EC36 */ { NULL,NULL},
/* 1EC37 */ { NULL,NULL},
/* 1EC38 */ { NULL,NULL},
/* 1EC39 */ { NULL,NULL},
/* 1EC3A */ { NULL,NULL},
/* 1EC3B */ { NULL,NULL},
/* 1EC3C */ { NULL,NULL},
/* 1EC3D */ { NULL,NULL},
/* 1EC3E */ { NULL,NULL},
/* 1EC3F */ { NULL,NULL},
/* 1EC40 */ { NULL,NULL},
/* 1EC41 */ { NULL,NULL},
/* 1EC42 */ { NULL,NULL},
/* 1EC43 */ { NULL,NULL},
/* 1EC44 */ { NULL,NULL},
/* 1EC45 */ { NULL,NULL},
/* 1EC46 */ { NULL,NULL},
/* 1EC47 */ { NULL,NULL},
/* 1EC48 */ { NULL,NULL},
/* 1EC49 */ { NULL,NULL},
/* 1EC4A */ { NULL,NULL},
/* 1EC4B */ { NULL,NULL},
/* 1EC4C */ { NULL,NULL},
/* 1EC4D */ { NULL,NULL},
/* 1EC4E */ { NULL,NULL},
/* 1EC4F */ { NULL,NULL},
/* 1EC50 */ { NULL,NULL},
/* 1EC51 */ { NULL,NULL},
/* 1EC52 */ { NULL,NULL},
/* 1EC53 */ { NULL,NULL},
/* 1EC54 */ { NULL,NULL},
/* 1EC55 */ { NULL,NULL},
/* 1EC56 */ { NULL,NULL},
/* 1EC57 */ { NULL,NULL},
/* 1EC58 */ { NULL,NULL},
/* 1EC59 */ { NULL,NULL},
/* 1EC5A */ { NULL,NULL},
/* 1EC5B */ { NULL,NULL},
/* 1EC5C */ { NULL,NULL},
/* 1EC5D */ { NULL,NULL},
/* 1EC5E */ { NULL,NULL},
/* 1EC5F */ { NULL,NULL},
/* 1EC60 */ { NULL,NULL},
/* 1EC61 */ { NULL,NULL},
/* 1EC62 */ { NULL,NULL},
/* 1EC63 */ { NULL,NULL},
/* 1EC64 */ { NULL,NULL},
/* 1EC65 */ { NULL,NULL},
/* 1EC66 */ { NULL,NULL},
/* 1EC67 */ { NULL,NULL},
/* 1EC68 */ { NULL,NULL},
/* 1EC69 */ { NULL,NULL},
/* 1EC6A */ { NULL,NULL},
/* 1EC6B */ { NULL,NULL},
/* 1EC6C */ { NULL,NULL},
/* 1EC6D */ { NULL,NULL},
/* 1EC6E */ { NULL,NULL},
/* 1EC6F */ { NULL,NULL},
/* 1EC70 */ { NULL,NULL},
/* 1EC71 */ { "INDIC SIYAQ NUMBER ONE",NULL},
/* 1EC72 */ { "INDIC SIYAQ NUMBER TWO",NULL},
/* 1EC73 */ { "INDIC SIYAQ NUMBER THREE",NULL},
/* 1EC74 */ { "INDIC SIYAQ NUMBER FOUR",NULL},
/* 1EC75 */ { "INDIC SIYAQ NUMBER FIVE",NULL},
/* 1EC76 */ { "INDIC SIYAQ NUMBER SIX",NULL},
/* 1EC77 */ { "INDIC SIYAQ NUMBER SEVEN",NULL},
/* 1EC78 */ { "INDIC SIYAQ NUMBER EIGHT",NULL},
/* 1EC79 */ { "INDIC SIYAQ NUMBER NINE",NULL},
/* 1EC7A */ { "INDIC SIYAQ NUMBER TEN",NULL},
/* 1EC7B */ { "INDIC SIYAQ NUMBER TWENTY",NULL},
/* 1EC7C */ { "INDIC SIYAQ NUMBER THIRTY",NULL},
/* 1EC7D */ { "INDIC SIYAQ NUMBER FORTY",NULL},
/* 1EC7E */ { "INDIC SIYAQ NUMBER FIFTY",NULL},
/* 1EC7F */ { "INDIC SIYAQ NUMBER SIXTY",NULL},
/* 1EC80 */ { "INDIC SIYAQ NUMBER SEVENTY",NULL},
/* 1EC81 */ { "INDIC SIYAQ NUMBER EIGHTY",NULL},
/* 1EC82 */ { "INDIC SIYAQ NUMBER NINETY",NULL},
/* 1EC83 */ { "INDIC SIYAQ NUMBER ONE HUNDRED",NULL},
/* 1EC84 */ { "INDIC SIYAQ NUMBER TWO HUNDRED",NULL},
/* 1EC85 */ { "INDIC SIYAQ NUMBER THREE HUNDRED",NULL},
/* 1EC86 */ { "INDIC SIYAQ NUMBER FOUR HUNDRED",NULL},
/* 1EC87 */ { "INDIC SIYAQ NUMBER FIVE HUNDRED",NULL},
/* 1EC88 */ { "INDIC SIYAQ NUMBER SIX HUNDRED",NULL},
/* 1EC89 */ { "INDIC SIYAQ NUMBER SEVEN HUNDRED",NULL},
/* 1EC8A */ { "INDIC SIYAQ NUMBER EIGHT HUNDRED",NULL},
/* 1EC8B */ { "INDIC SIYAQ NUMBER NINE HUNDRED",NULL},
/* 1EC8C */ { "INDIC SIYAQ NUMBER ONE THOUSAND",NULL},
/* 1EC8D */ { "INDIC SIYAQ NUMBER TWO THOUSAND",NULL},
/* 1EC8E */ { "INDIC SIYAQ NUMBER THREE THOUSAND",NULL},
/* 1EC8F */ { "INDIC SIYAQ NUMBER FOUR THOUSAND",NULL},
/* 1EC90 */ { "INDIC SIYAQ NUMBER FIVE THOUSAND",NULL},
/* 1EC91 */ { "INDIC SIYAQ NUMBER SIX THOUSAND",NULL},
/* 1EC92 */ { "INDIC SIYAQ NUMBER SEVEN THOUSAND",NULL},
/* 1EC93 */ { "INDIC SIYAQ NUMBER EIGHT THOUSAND",NULL},
/* 1EC94 */ { "INDIC SIYAQ NUMBER NINE THOUSAND",NULL},
/* 1EC95 */ { "INDIC SIYAQ NUMBER TEN THOUSAND",NULL},
/* 1EC96 */ { "INDIC SIYAQ NUMBER TWENTY THOUSAND",NULL},
/* 1EC97 */ { "INDIC SIYAQ NUMBER THIRTY THOUSAND",NULL},
/* 1EC98 */ { "INDIC SIYAQ NUMBER FORTY THOUSAND",NULL},
/* 1EC99 */ { "INDIC SIYAQ NUMBER FIFTY THOUSAND",NULL},
/* 1EC9A */ { "INDIC SIYAQ NUMBER SIXTY THOUSAND",NULL},
/* 1EC9B */ { "INDIC SIYAQ NUMBER SEVENTY THOUSAND",NULL},
/* 1EC9C */ { "INDIC SIYAQ NUMBER EIGHTY THOUSAND",NULL},
/* 1EC9D */ { "INDIC SIYAQ NUMBER NINETY THOUSAND",NULL},
/* 1EC9E */ { "INDIC SIYAQ NUMBER LAKH","	= 1 lakh\n"
	"	= 100,000"},
/* 1EC9F */ { "INDIC SIYAQ NUMBER LAKHAN","	= 2 lakh\n"
	"	= 200,000"},
/* 1ECA0 */ { "INDIC SIYAQ LAKH MARK","	* used as a mark for denoting other lakh values"},
/* 1ECA1 */ { "INDIC SIYAQ NUMBER KAROR","	= 1 crore\n"
	"	= 10 million\n"
	"	= 100 lakh\n"
	"	* used as a mark for denoting crores"},
/* 1ECA2 */ { "INDIC SIYAQ NUMBER KARORAN","	= 2 crore\n"
	"	= 20 million\n"
	"	= 200 lakh"},
/* 1ECA3 */ { "INDIC SIYAQ NUMBER PREFIXED ONE",NULL},
/* 1ECA4 */ { "INDIC SIYAQ NUMBER PREFIXED TWO",NULL},
/* 1ECA5 */ { "INDIC SIYAQ NUMBER PREFIXED THREE",NULL},
/* 1ECA6 */ { "INDIC SIYAQ NUMBER PREFIXED FOUR",NULL},
/* 1ECA7 */ { "INDIC SIYAQ NUMBER PREFIXED FIVE",NULL},
/* 1ECA8 */ { "INDIC SIYAQ NUMBER PREFIXED SIX",NULL},
/* 1ECA9 */ { "INDIC SIYAQ NUMBER PREFIXED SEVEN",NULL},
/* 1ECAA */ { "INDIC SIYAQ NUMBER PREFIXED EIGHT",NULL},
/* 1ECAB */ { "INDIC SIYAQ NUMBER PREFIXED NINE",NULL},
/* 1ECAC */ { "INDIC SIYAQ PLACEHOLDER",NULL},
/* 1ECAD */ { "INDIC SIYAQ FRACTION ONE QUARTER",NULL},
/* 1ECAE */ { "INDIC SIYAQ FRACTION ONE HALF",NULL},
/* 1ECAF */ { "INDIC SIYAQ FRACTION THREE QUARTERS",NULL},
/* 1ECB0 */ { "INDIC SIYAQ RUPEE MARK",NULL},
/* 1ECB1 */ { "INDIC SIYAQ NUMBER ALTERNATE ONE",NULL},
/* 1ECB2 */ { "INDIC SIYAQ NUMBER ALTERNATE TWO",NULL},
/* 1ECB3 */ { "INDIC SIYAQ NUMBER ALTERNATE TEN THOUSAND",NULL},
/* 1ECB4 */ { "INDIC SIYAQ ALTERNATE LAKH MARK",NULL},
/* 1ECB5 */ { NULL,NULL},
/* 1ECB6 */ { NULL,NULL},
/* 1ECB7 */ { NULL,NULL},
/* 1ECB8 */ { NULL,NULL},
/* 1ECB9 */ { NULL,NULL},
/* 1ECBA */ { NULL,NULL},
/* 1ECBB */ { NULL,NULL},
/* 1ECBC */ { NULL,NULL},
/* 1ECBD */ { NULL,NULL},
/* 1ECBE */ { NULL,NULL},
/* 1ECBF */ { NULL,NULL},
/* 1ECC0 */ { NULL,NULL},
/* 1ECC1 */ { NULL,NULL},
/* 1ECC2 */ { NULL,NULL},
/* 1ECC3 */ { NULL,NULL},
/* 1ECC4 */ { NULL,NULL},
/* 1ECC5 */ { NULL,NULL},
/* 1ECC6 */ { NULL,NULL},
/* 1ECC7 */ { NULL,NULL},
/* 1ECC8 */ { NULL,NULL},
/* 1ECC9 */ { NULL,NULL},
/* 1ECCA */ { NULL,NULL},
/* 1ECCB */ { NULL,NULL},
/* 1ECCC */ { NULL,NULL},
/* 1ECCD */ { NULL,NULL},
/* 1ECCE */ { NULL,NULL},
/* 1ECCF */ { NULL,NULL},
/* 1ECD0 */ { NULL,NULL},
/* 1ECD1 */ { NULL,NULL},
/* 1ECD2 */ { NULL,NULL},
/* 1ECD3 */ { NULL,NULL},
/* 1ECD4 */ { NULL,NULL},
/* 1ECD5 */ { NULL,NULL},
/* 1ECD6 */ { NULL,NULL},
/* 1ECD7 */ { NULL,NULL},
/* 1ECD8 */ { NULL,NULL},
/* 1ECD9 */ { NULL,NULL},
/* 1ECDA */ { NULL,NULL},
/* 1ECDB */ { NULL,NULL},
/* 1ECDC */ { NULL,NULL},
/* 1ECDD */ { NULL,NULL},
/* 1ECDE */ { NULL,NULL},
/* 1ECDF */ { NULL,NULL},
/* 1ECE0 */ { NULL,NULL},
/* 1ECE1 */ { NULL,NULL},
/* 1ECE2 */ { NULL,NULL},
/* 1ECE3 */ { NULL,NULL},
/* 1ECE4 */ { NULL,NULL},
/* 1ECE5 */ { NULL,NULL},
/* 1ECE6 */ { NULL,NULL},
/* 1ECE7 */ { NULL,NULL},
/* 1ECE8 */ { NULL,NULL},
/* 1ECE9 */ { NULL,NULL},
/* 1ECEA */ { NULL,NULL},
/* 1ECEB */ { NULL,NULL},
/* 1ECEC */ { NULL,NULL},
/* 1ECED */ { NULL,NULL},
/* 1ECEE */ { NULL,NULL},
/* 1ECEF */ { NULL,NULL},
/* 1ECF0 */ { NULL,NULL},
/* 1ECF1 */ { NULL,NULL},
/* 1ECF2 */ { NULL,NULL},
/* 1ECF3 */ { NULL,NULL},
/* 1ECF4 */ { NULL,NULL},
/* 1ECF5 */ { NULL,NULL},
/* 1ECF6 */ { NULL,NULL},
/* 1ECF7 */ { NULL,NULL},
/* 1ECF8 */ { NULL,NULL},
/* 1ECF9 */ { NULL,NULL},
/* 1ECFA */ { NULL,NULL},
/* 1ECFB */ { NULL,NULL},
/* 1ECFC */ { NULL,NULL},
/* 1ECFD */ { NULL,NULL},
/* 1ECFE */ { NULL,NULL},
/* 1ECFF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_ED[] = {
/* 1ED00 */ { NULL,NULL},
/* 1ED01 */ { "OTTOMAN SIYAQ NUMBER ONE",NULL},
/* 1ED02 */ { "OTTOMAN SIYAQ NUMBER TWO",NULL},
/* 1ED03 */ { "OTTOMAN SIYAQ NUMBER THREE",NULL},
/* 1ED04 */ { "OTTOMAN SIYAQ NUMBER FOUR",NULL},
/* 1ED05 */ { "OTTOMAN SIYAQ NUMBER FIVE",NULL},
/* 1ED06 */ { "OTTOMAN SIYAQ NUMBER SIX",NULL},
/* 1ED07 */ { "OTTOMAN SIYAQ NUMBER SEVEN",NULL},
/* 1ED08 */ { "OTTOMAN SIYAQ NUMBER EIGHT",NULL},
/* 1ED09 */ { "OTTOMAN SIYAQ NUMBER NINE",NULL},
/* 1ED0A */ { "OTTOMAN SIYAQ NUMBER TEN",NULL},
/* 1ED0B */ { "OTTOMAN SIYAQ NUMBER TWENTY",NULL},
/* 1ED0C */ { "OTTOMAN SIYAQ NUMBER THIRTY",NULL},
/* 1ED0D */ { "OTTOMAN SIYAQ NUMBER FORTY",NULL},
/* 1ED0E */ { "OTTOMAN SIYAQ NUMBER FIFTY",NULL},
/* 1ED0F */ { "OTTOMAN SIYAQ NUMBER SIXTY",NULL},
/* 1ED10 */ { "OTTOMAN SIYAQ NUMBER SEVENTY",NULL},
/* 1ED11 */ { "OTTOMAN SIYAQ NUMBER EIGHTY",NULL},
/* 1ED12 */ { "OTTOMAN SIYAQ NUMBER NINETY",NULL},
/* 1ED13 */ { "OTTOMAN SIYAQ NUMBER ONE HUNDRED",NULL},
/* 1ED14 */ { "OTTOMAN SIYAQ NUMBER TWO HUNDRED",NULL},
/* 1ED15 */ { "OTTOMAN SIYAQ NUMBER THREE HUNDRED",NULL},
/* 1ED16 */ { "OTTOMAN SIYAQ NUMBER FOUR HUNDRED",NULL},
/* 1ED17 */ { "OTTOMAN SIYAQ NUMBER FIVE HUNDRED",NULL},
/* 1ED18 */ { "OTTOMAN SIYAQ NUMBER SIX HUNDRED",NULL},
/* 1ED19 */ { "OTTOMAN SIYAQ NUMBER SEVEN HUNDRED",NULL},
/* 1ED1A */ { "OTTOMAN SIYAQ NUMBER EIGHT HUNDRED",NULL},
/* 1ED1B */ { "OTTOMAN SIYAQ NUMBER NINE HUNDRED",NULL},
/* 1ED1C */ { "OTTOMAN SIYAQ NUMBER ONE THOUSAND","	= thousands multiplier"},
/* 1ED1D */ { "OTTOMAN SIYAQ NUMBER TWO THOUSAND",NULL},
/* 1ED1E */ { "OTTOMAN SIYAQ NUMBER THREE THOUSAND",NULL},
/* 1ED1F */ { "OTTOMAN SIYAQ NUMBER FOUR THOUSAND",NULL},
/* 1ED20 */ { "OTTOMAN SIYAQ NUMBER FIVE THOUSAND",NULL},
/* 1ED21 */ { "OTTOMAN SIYAQ NUMBER SIX THOUSAND",NULL},
/* 1ED22 */ { "OTTOMAN SIYAQ NUMBER SEVEN THOUSAND",NULL},
/* 1ED23 */ { "OTTOMAN SIYAQ NUMBER EIGHT THOUSAND",NULL},
/* 1ED24 */ { "OTTOMAN SIYAQ NUMBER NINE THOUSAND",NULL},
/* 1ED25 */ { "OTTOMAN SIYAQ NUMBER TEN THOUSAND",NULL},
/* 1ED26 */ { "OTTOMAN SIYAQ NUMBER TWENTY THOUSAND",NULL},
/* 1ED27 */ { "OTTOMAN SIYAQ NUMBER THIRTY THOUSAND",NULL},
/* 1ED28 */ { "OTTOMAN SIYAQ NUMBER FORTY THOUSAND",NULL},
/* 1ED29 */ { "OTTOMAN SIYAQ NUMBER FIFTY THOUSAND",NULL},
/* 1ED2A */ { "OTTOMAN SIYAQ NUMBER SIXTY THOUSAND",NULL},
/* 1ED2B */ { "OTTOMAN SIYAQ NUMBER SEVENTY THOUSAND",NULL},
/* 1ED2C */ { "OTTOMAN SIYAQ NUMBER EIGHTY THOUSAND",NULL},
/* 1ED2D */ { "OTTOMAN SIYAQ NUMBER NINETY THOUSAND",NULL},
/* 1ED2E */ { "OTTOMAN SIYAQ MARRATAN","	= meretten, merre\n"
	"	* used with one thousand for representing millions"},
/* 1ED2F */ { "OTTOMAN SIYAQ ALTERNATE NUMBER TWO",NULL},
/* 1ED30 */ { "OTTOMAN SIYAQ ALTERNATE NUMBER THREE",NULL},
/* 1ED31 */ { "OTTOMAN SIYAQ ALTERNATE NUMBER FOUR",NULL},
/* 1ED32 */ { "OTTOMAN SIYAQ ALTERNATE NUMBER FIVE",NULL},
/* 1ED33 */ { "OTTOMAN SIYAQ ALTERNATE NUMBER SIX",NULL},
/* 1ED34 */ { "OTTOMAN SIYAQ ALTERNATE NUMBER SEVEN",NULL},
/* 1ED35 */ { "OTTOMAN SIYAQ ALTERNATE NUMBER EIGHT",NULL},
/* 1ED36 */ { "OTTOMAN SIYAQ ALTERNATE NUMBER NINE",NULL},
/* 1ED37 */ { "OTTOMAN SIYAQ ALTERNATE NUMBER TEN",NULL},
/* 1ED38 */ { "OTTOMAN SIYAQ ALTERNATE NUMBER FOUR HUNDRED",NULL},
/* 1ED39 */ { "OTTOMAN SIYAQ ALTERNATE NUMBER SIX HUNDRED",NULL},
/* 1ED3A */ { "OTTOMAN SIYAQ ALTERNATE NUMBER TWO THOUSAND",NULL},
/* 1ED3B */ { "OTTOMAN SIYAQ ALTERNATE NUMBER TEN THOUSAND",NULL},
/* 1ED3C */ { "OTTOMAN SIYAQ FRACTION ONE HALF",NULL},
/* 1ED3D */ { "OTTOMAN SIYAQ FRACTION ONE SIXTH",NULL},
/* 1ED3E */ { NULL,NULL},
/* 1ED3F */ { NULL,NULL},
/* 1ED40 */ { NULL,NULL},
/* 1ED41 */ { NULL,NULL},
/* 1ED42 */ { NULL,NULL},
/* 1ED43 */ { NULL,NULL},
/* 1ED44 */ { NULL,NULL},
/* 1ED45 */ { NULL,NULL},
/* 1ED46 */ { NULL,NULL},
/* 1ED47 */ { NULL,NULL},
/* 1ED48 */ { NULL,NULL},
/* 1ED49 */ { NULL,NULL},
/* 1ED4A */ { NULL,NULL},
/* 1ED4B */ { NULL,NULL},
/* 1ED4C */ { NULL,NULL},
/* 1ED4D */ { NULL,NULL},
/* 1ED4E */ { NULL,NULL},
/* 1ED4F */ { NULL,NULL},
/* 1ED50 */ { NULL,NULL},
/* 1ED51 */ { NULL,NULL},
/* 1ED52 */ { NULL,NULL},
/* 1ED53 */ { NULL,NULL},
/* 1ED54 */ { NULL,NULL},
/* 1ED55 */ { NULL,NULL},
/* 1ED56 */ { NULL,NULL},
/* 1ED57 */ { NULL,NULL},
/* 1ED58 */ { NULL,NULL},
/* 1ED59 */ { NULL,NULL},
/* 1ED5A */ { NULL,NULL},
/* 1ED5B */ { NULL,NULL},
/* 1ED5C */ { NULL,NULL},
/* 1ED5D */ { NULL,NULL},
/* 1ED5E */ { NULL,NULL},
/* 1ED5F */ { NULL,NULL},
/* 1ED60 */ { NULL,NULL},
/* 1ED61 */ { NULL,NULL},
/* 1ED62 */ { NULL,NULL},
/* 1ED63 */ { NULL,NULL},
/* 1ED64 */ { NULL,NULL},
/* 1ED65 */ { NULL,NULL},
/* 1ED66 */ { NULL,NULL},
/* 1ED67 */ { NULL,NULL},
/* 1ED68 */ { NULL,NULL},
/* 1ED69 */ { NULL,NULL},
/* 1ED6A */ { NULL,NULL},
/* 1ED6B */ { NULL,NULL},
/* 1ED6C */ { NULL,NULL},
/* 1ED6D */ { NULL,NULL},
/* 1ED6E */ { NULL,NULL},
/* 1ED6F */ { NULL,NULL},
/* 1ED70 */ { NULL,NULL},
/* 1ED71 */ { NULL,NULL},
/* 1ED72 */ { NULL,NULL},
/* 1ED73 */ { NULL,NULL},
/* 1ED74 */ { NULL,NULL},
/* 1ED75 */ { NULL,NULL},
/* 1ED76 */ { NULL,NULL},
/* 1ED77 */ { NULL,NULL},
/* 1ED78 */ { NULL,NULL},
/* 1ED79 */ { NULL,NULL},
/* 1ED7A */ { NULL,NULL},
/* 1ED7B */ { NULL,NULL},
/* 1ED7C */ { NULL,NULL},
/* 1ED7D */ { NULL,NULL},
/* 1ED7E */ { NULL,NULL},
/* 1ED7F */ { NULL,NULL},
/* 1ED80 */ { NULL,NULL},
/* 1ED81 */ { NULL,NULL},
/* 1ED82 */ { NULL,NULL},
/* 1ED83 */ { NULL,NULL},
/* 1ED84 */ { NULL,NULL},
/* 1ED85 */ { NULL,NULL},
/* 1ED86 */ { NULL,NULL},
/* 1ED87 */ { NULL,NULL},
/* 1ED88 */ { NULL,NULL},
/* 1ED89 */ { NULL,NULL},
/* 1ED8A */ { NULL,NULL},
/* 1ED8B */ { NULL,NULL},
/* 1ED8C */ { NULL,NULL},
/* 1ED8D */ { NULL,NULL},
/* 1ED8E */ { NULL,NULL},
/* 1ED8F */ { NULL,NULL},
/* 1ED90 */ { NULL,NULL},
/* 1ED91 */ { NULL,NULL},
/* 1ED92 */ { NULL,NULL},
/* 1ED93 */ { NULL,NULL},
/* 1ED94 */ { NULL,NULL},
/* 1ED95 */ { NULL,NULL},
/* 1ED96 */ { NULL,NULL},
/* 1ED97 */ { NULL,NULL},
/* 1ED98 */ { NULL,NULL},
/* 1ED99 */ { NULL,NULL},
/* 1ED9A */ { NULL,NULL},
/* 1ED9B */ { NULL,NULL},
/* 1ED9C */ { NULL,NULL},
/* 1ED9D */ { NULL,NULL},
/* 1ED9E */ { NULL,NULL},
/* 1ED9F */ { NULL,NULL},
/* 1EDA0 */ { NULL,NULL},
/* 1EDA1 */ { NULL,NULL},
/* 1EDA2 */ { NULL,NULL},
/* 1EDA3 */ { NULL,NULL},
/* 1EDA4 */ { NULL,NULL},
/* 1EDA5 */ { NULL,NULL},
/* 1EDA6 */ { NULL,NULL},
/* 1EDA7 */ { NULL,NULL},
/* 1EDA8 */ { NULL,NULL},
/* 1EDA9 */ { NULL,NULL},
/* 1EDAA */ { NULL,NULL},
/* 1EDAB */ { NULL,NULL},
/* 1EDAC */ { NULL,NULL},
/* 1EDAD */ { NULL,NULL},
/* 1EDAE */ { NULL,NULL},
/* 1EDAF */ { NULL,NULL},
/* 1EDB0 */ { NULL,NULL},
/* 1EDB1 */ { NULL,NULL},
/* 1EDB2 */ { NULL,NULL},
/* 1EDB3 */ { NULL,NULL},
/* 1EDB4 */ { NULL,NULL},
/* 1EDB5 */ { NULL,NULL},
/* 1EDB6 */ { NULL,NULL},
/* 1EDB7 */ { NULL,NULL},
/* 1EDB8 */ { NULL,NULL},
/* 1EDB9 */ { NULL,NULL},
/* 1EDBA */ { NULL,NULL},
/* 1EDBB */ { NULL,NULL},
/* 1EDBC */ { NULL,NULL},
/* 1EDBD */ { NULL,NULL},
/* 1EDBE */ { NULL,NULL},
/* 1EDBF */ { NULL,NULL},
/* 1EDC0 */ { NULL,NULL},
/* 1EDC1 */ { NULL,NULL},
/* 1EDC2 */ { NULL,NULL},
/* 1EDC3 */ { NULL,NULL},
/* 1EDC4 */ { NULL,NULL},
/* 1EDC5 */ { NULL,NULL},
/* 1EDC6 */ { NULL,NULL},
/* 1EDC7 */ { NULL,NULL},
/* 1EDC8 */ { NULL,NULL},
/* 1EDC9 */ { NULL,NULL},
/* 1EDCA */ { NULL,NULL},
/* 1EDCB */ { NULL,NULL},
/* 1EDCC */ { NULL,NULL},
/* 1EDCD */ { NULL,NULL},
/* 1EDCE */ { NULL,NULL},
/* 1EDCF */ { NULL,NULL},
/* 1EDD0 */ { NULL,NULL},
/* 1EDD1 */ { NULL,NULL},
/* 1EDD2 */ { NULL,NULL},
/* 1EDD3 */ { NULL,NULL},
/* 1EDD4 */ { NULL,NULL},
/* 1EDD5 */ { NULL,NULL},
/* 1EDD6 */ { NULL,NULL},
/* 1EDD7 */ { NULL,NULL},
/* 1EDD8 */ { NULL,NULL},
/* 1EDD9 */ { NULL,NULL},
/* 1EDDA */ { NULL,NULL},
/* 1EDDB */ { NULL,NULL},
/* 1EDDC */ { NULL,NULL},
/* 1EDDD */ { NULL,NULL},
/* 1EDDE */ { NULL,NULL},
/* 1EDDF */ { NULL,NULL},
/* 1EDE0 */ { NULL,NULL},
/* 1EDE1 */ { NULL,NULL},
/* 1EDE2 */ { NULL,NULL},
/* 1EDE3 */ { NULL,NULL},
/* 1EDE4 */ { NULL,NULL},
/* 1EDE5 */ { NULL,NULL},
/* 1EDE6 */ { NULL,NULL},
/* 1EDE7 */ { NULL,NULL},
/* 1EDE8 */ { NULL,NULL},
/* 1EDE9 */ { NULL,NULL},
/* 1EDEA */ { NULL,NULL},
/* 1EDEB */ { NULL,NULL},
/* 1EDEC */ { NULL,NULL},
/* 1EDED */ { NULL,NULL},
/* 1EDEE */ { NULL,NULL},
/* 1EDEF */ { NULL,NULL},
/* 1EDF0 */ { NULL,NULL},
/* 1EDF1 */ { NULL,NULL},
/* 1EDF2 */ { NULL,NULL},
/* 1EDF3 */ { NULL,NULL},
/* 1EDF4 */ { NULL,NULL},
/* 1EDF5 */ { NULL,NULL},
/* 1EDF6 */ { NULL,NULL},
/* 1EDF7 */ { NULL,NULL},
/* 1EDF8 */ { NULL,NULL},
/* 1EDF9 */ { NULL,NULL},
/* 1EDFA */ { NULL,NULL},
/* 1EDFB */ { NULL,NULL},
/* 1EDFC */ { NULL,NULL},
/* 1EDFD */ { NULL,NULL},
/* 1EDFE */ { NULL,NULL},
/* 1EDFF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_EE[] = {
/* 1EE00 */ { "ARABIC MATHEMATICAL ALEF","	x (arabic letter alef isolated form - FE8D)\n"
	"	# <font> 0627 arabic letter alef"},
/* 1EE01 */ { "ARABIC MATHEMATICAL BEH","	x (arabic letter beh isolated form - FE8F)\n"
	"	# <font> 0628 arabic letter beh"},
/* 1EE02 */ { "ARABIC MATHEMATICAL JEEM","	x (arabic letter jeem isolated form - FE9D)\n"
	"	# <font> 062C arabic letter jeem"},
/* 1EE03 */ { "ARABIC MATHEMATICAL DAL","	x (arabic letter dal isolated form - FEA9)\n"
	"	# <font> 062F arabic letter dal"},
/* 1EE04 */ { NULL,NULL},
/* 1EE05 */ { "ARABIC MATHEMATICAL WAW","	x (arabic letter waw isolated form - FEED)\n"
	"	# <font> 0648 arabic letter waw"},
/* 1EE06 */ { "ARABIC MATHEMATICAL ZAIN","	x (arabic letter zain isolated form - FEAF)\n"
	"	# <font> 0632 arabic letter zain"},
/* 1EE07 */ { "ARABIC MATHEMATICAL HAH","	x (arabic letter hah isolated form - FEA1)\n"
	"	# <font> 062D arabic letter hah"},
/* 1EE08 */ { "ARABIC MATHEMATICAL TAH","	x (arabic letter tah isolated form - FEC1)\n"
	"	# <font> 0637 arabic letter tah"},
/* 1EE09 */ { "ARABIC MATHEMATICAL YEH","	x (arabic letter yeh isolated form - FEF1)\n"
	"	# <font> 064A arabic letter yeh"},
/* 1EE0A */ { "ARABIC MATHEMATICAL KAF","	x (arabic letter kaf isolated form - FED9)\n"
	"	# <font> 0643 arabic letter kaf"},
/* 1EE0B */ { "ARABIC MATHEMATICAL LAM","	x (arabic letter lam isolated form - FEDD)\n"
	"	# <font> 0644 arabic letter lam"},
/* 1EE0C */ { "ARABIC MATHEMATICAL MEEM","	x (arabic letter meem isolated form - FEE1)\n"
	"	# <font> 0645 arabic letter meem"},
/* 1EE0D */ { "ARABIC MATHEMATICAL NOON","	x (arabic letter noon isolated form - FEE5)\n"
	"	# <font> 0646 arabic letter noon"},
/* 1EE0E */ { "ARABIC MATHEMATICAL SEEN","	x (arabic letter seen isolated form - FEB1)\n"
	"	# <font> 0633 arabic letter seen"},
/* 1EE0F */ { "ARABIC MATHEMATICAL AIN","	x (arabic letter ain isolated form - FEC9)\n"
	"	# <font> 0639 arabic letter ain"},
/* 1EE10 */ { "ARABIC MATHEMATICAL FEH","	x (arabic letter feh isolated form - FED1)\n"
	"	# <font> 0641 arabic letter feh"},
/* 1EE11 */ { "ARABIC MATHEMATICAL SAD","	x (arabic letter sad isolated form - FEB9)\n"
	"	# <font> 0635 arabic letter sad"},
/* 1EE12 */ { "ARABIC MATHEMATICAL QAF","	x (arabic letter qaf isolated form - FED5)\n"
	"	# <font> 0642 arabic letter qaf"},
/* 1EE13 */ { "ARABIC MATHEMATICAL REH","	x (arabic letter reh isolated form - FEAD)\n"
	"	# <font> 0631 arabic letter reh"},
/* 1EE14 */ { "ARABIC MATHEMATICAL SHEEN","	x (arabic letter sheen isolated form - FEB5)\n"
	"	# <font> 0634 arabic letter sheen"},
/* 1EE15 */ { "ARABIC MATHEMATICAL TEH","	x (arabic letter teh isolated form - FE95)\n"
	"	# <font> 062A arabic letter teh"},
/* 1EE16 */ { "ARABIC MATHEMATICAL THEH","	x (arabic letter theh isolated form - FE99)\n"
	"	# <font> 062B arabic letter theh"},
/* 1EE17 */ { "ARABIC MATHEMATICAL KHAH","	x (arabic letter khah isolated form - FEA5)\n"
	"	# <font> 062E arabic letter khah"},
/* 1EE18 */ { "ARABIC MATHEMATICAL THAL","	x (arabic letter thal isolated form - FEAB)\n"
	"	# <font> 0630 arabic letter thal"},
/* 1EE19 */ { "ARABIC MATHEMATICAL DAD","	x (arabic letter dad isolated form - FEBD)\n"
	"	# <font> 0636 arabic letter dad"},
/* 1EE1A */ { "ARABIC MATHEMATICAL ZAH","	x (arabic letter zah isolated form - FEC5)\n"
	"	# <font> 0638 arabic letter zah"},
/* 1EE1B */ { "ARABIC MATHEMATICAL GHAIN","	x (arabic letter ghain isolated form - FECD)\n"
	"	# <font> 063A arabic letter ghain"},
/* 1EE1C */ { "ARABIC MATHEMATICAL DOTLESS BEH","	x (arabic letter dotless beh - 066E)\n"
	"	# <font> 066E arabic letter dotless beh"},
/* 1EE1D */ { "ARABIC MATHEMATICAL DOTLESS NOON","	x (arabic letter noon ghunna isolated form - FB9E)\n"
	"	# <font> 06BA arabic letter noon ghunna"},
/* 1EE1E */ { "ARABIC MATHEMATICAL DOTLESS FEH","	x (arabic letter dotless feh - 06A1)\n"
	"	# <font> 06A1 arabic letter dotless feh"},
/* 1EE1F */ { "ARABIC MATHEMATICAL DOTLESS QAF","	x (arabic letter dotless qaf - 066F)\n"
	"	# <font> 066F arabic letter dotless qaf"},
/* 1EE20 */ { NULL,NULL},
/* 1EE21 */ { "ARABIC MATHEMATICAL INITIAL BEH","	x (arabic letter beh initial form - FE91)\n"
	"	# <font> 0628 arabic letter beh"},
/* 1EE22 */ { "ARABIC MATHEMATICAL INITIAL JEEM","	x (arabic letter jeem initial form - FE9F)\n"
	"	# <font> 062C arabic letter jeem"},
/* 1EE23 */ { NULL,NULL},
/* 1EE24 */ { "ARABIC MATHEMATICAL INITIAL HEH","	x (arabic letter heh initial form - FEEB)\n"
	"	# <font> 0647 arabic letter heh"},
/* 1EE25 */ { NULL,NULL},
/* 1EE26 */ { NULL,NULL},
/* 1EE27 */ { "ARABIC MATHEMATICAL INITIAL HAH","	x (arabic letter hah initial form - FEA3)\n"
	"	# <font> 062D arabic letter hah"},
/* 1EE28 */ { NULL,NULL},
/* 1EE29 */ { "ARABIC MATHEMATICAL INITIAL YEH","	x (arabic letter yeh initial form - FEF3)\n"
	"	# <font> 064A arabic letter yeh"},
/* 1EE2A */ { "ARABIC MATHEMATICAL INITIAL KAF","	x (arabic letter kaf initial form - FEDB)\n"
	"	# <font> 0643 arabic letter kaf"},
/* 1EE2B */ { "ARABIC MATHEMATICAL INITIAL LAM","	x (arabic letter lam initial form - FEDF)\n"
	"	# <font> 0644 arabic letter lam"},
/* 1EE2C */ { "ARABIC MATHEMATICAL INITIAL MEEM","	x (arabic letter meem initial form - FEE3)\n"
	"	# <font> 0645 arabic letter meem"},
/* 1EE2D */ { "ARABIC MATHEMATICAL INITIAL NOON","	x (arabic letter noon initial form - FEE7)\n"
	"	# <font> 0646 arabic letter noon"},
/* 1EE2E */ { "ARABIC MATHEMATICAL INITIAL SEEN","	x (arabic letter seen initial form - FEB3)\n"
	"	# <font> 0633 arabic letter seen"},
/* 1EE2F */ { "ARABIC MATHEMATICAL INITIAL AIN","	x (arabic letter ain initial form - FECB)\n"
	"	# <font> 0639 arabic letter ain"},
/* 1EE30 */ { "ARABIC MATHEMATICAL INITIAL FEH","	x (arabic letter feh initial form - FED3)\n"
	"	# <font> 0641 arabic letter feh"},
/* 1EE31 */ { "ARABIC MATHEMATICAL INITIAL SAD","	x (arabic letter sad initial form - FEBB)\n"
	"	# <font> 0635 arabic letter sad"},
/* 1EE32 */ { "ARABIC MATHEMATICAL INITIAL QAF","	x (arabic letter qaf initial form - FED7)\n"
	"	# <font> 0642 arabic letter qaf"},
/* 1EE33 */ { NULL,NULL},
/* 1EE34 */ { "ARABIC MATHEMATICAL INITIAL SHEEN","	x (arabic letter sheen initial form - FEB7)\n"
	"	# <font> 0634 arabic letter sheen"},
/* 1EE35 */ { "ARABIC MATHEMATICAL INITIAL TEH","	x (arabic letter teh initial form - FE97)\n"
	"	# <font> 062A arabic letter teh"},
/* 1EE36 */ { "ARABIC MATHEMATICAL INITIAL THEH","	x (arabic letter theh initial form - FE9B)\n"
	"	# <font> 062B arabic letter theh"},
/* 1EE37 */ { "ARABIC MATHEMATICAL INITIAL KHAH","	x (arabic letter khah initial form - FEA7)\n"
	"	# <font> 062E arabic letter khah"},
/* 1EE38 */ { NULL,NULL},
/* 1EE39 */ { "ARABIC MATHEMATICAL INITIAL DAD","	x (arabic letter dad initial form - FEBF)\n"
	"	# <font> 0636 arabic letter dad"},
/* 1EE3A */ { NULL,NULL},
/* 1EE3B */ { "ARABIC MATHEMATICAL INITIAL GHAIN","	x (arabic letter ghain initial form - FECF)\n"
	"	# <font> 063A arabic letter ghain"},
/* 1EE3C */ { NULL,NULL},
/* 1EE3D */ { NULL,NULL},
/* 1EE3E */ { NULL,NULL},
/* 1EE3F */ { NULL,NULL},
/* 1EE40 */ { NULL,NULL},
/* 1EE41 */ { NULL,NULL},
/* 1EE42 */ { "ARABIC MATHEMATICAL TAILED JEEM","	# <font> 062C arabic letter jeem"},
/* 1EE43 */ { NULL,NULL},
/* 1EE44 */ { NULL,NULL},
/* 1EE45 */ { NULL,NULL},
/* 1EE46 */ { NULL,NULL},
/* 1EE47 */ { "ARABIC MATHEMATICAL TAILED HAH","	# <font> 062D arabic letter hah"},
/* 1EE48 */ { NULL,NULL},
/* 1EE49 */ { "ARABIC MATHEMATICAL TAILED YEH","	# <font> 064A arabic letter yeh"},
/* 1EE4A */ { NULL,NULL},
/* 1EE4B */ { "ARABIC MATHEMATICAL TAILED LAM","	# <font> 0644 arabic letter lam"},
/* 1EE4C */ { NULL,NULL},
/* 1EE4D */ { "ARABIC MATHEMATICAL TAILED NOON","	# <font> 0646 arabic letter noon"},
/* 1EE4E */ { "ARABIC MATHEMATICAL TAILED SEEN","	# <font> 0633 arabic letter seen"},
/* 1EE4F */ { "ARABIC MATHEMATICAL TAILED AIN","	# <font> 0639 arabic letter ain"},
/* 1EE50 */ { NULL,NULL},
/* 1EE51 */ { "ARABIC MATHEMATICAL TAILED SAD","	# <font> 0635 arabic letter sad"},
/* 1EE52 */ { "ARABIC MATHEMATICAL TAILED QAF","	# <font> 0642 arabic letter qaf"},
/* 1EE53 */ { NULL,NULL},
/* 1EE54 */ { "ARABIC MATHEMATICAL TAILED SHEEN","	# <font> 0634 arabic letter sheen"},
/* 1EE55 */ { NULL,NULL},
/* 1EE56 */ { NULL,NULL},
/* 1EE57 */ { "ARABIC MATHEMATICAL TAILED KHAH","	# <font> 062E arabic letter khah"},
/* 1EE58 */ { NULL,NULL},
/* 1EE59 */ { "ARABIC MATHEMATICAL TAILED DAD","	# <font> 0636 arabic letter dad"},
/* 1EE5A */ { NULL,NULL},
/* 1EE5B */ { "ARABIC MATHEMATICAL TAILED GHAIN","	# <font> 063A arabic letter ghain"},
/* 1EE5C */ { NULL,NULL},
/* 1EE5D */ { "ARABIC MATHEMATICAL TAILED DOTLESS NOON","	# <font> 06BA arabic letter noon ghunna"},
/* 1EE5E */ { NULL,NULL},
/* 1EE5F */ { "ARABIC MATHEMATICAL TAILED DOTLESS QAF","	# <font> 066F arabic letter dotless qaf"},
/* 1EE60 */ { NULL,NULL},
/* 1EE61 */ { "ARABIC MATHEMATICAL STRETCHED BEH","	# <font> 0628 arabic letter beh"},
/* 1EE62 */ { "ARABIC MATHEMATICAL STRETCHED JEEM","	# <font> 062C arabic letter jeem"},
/* 1EE63 */ { NULL,NULL},
/* 1EE64 */ { "ARABIC MATHEMATICAL STRETCHED HEH","	# <font> 0647 arabic letter heh"},
/* 1EE65 */ { NULL,NULL},
/* 1EE66 */ { NULL,NULL},
/* 1EE67 */ { "ARABIC MATHEMATICAL STRETCHED HAH","	# <font> 062D arabic letter hah"},
/* 1EE68 */ { "ARABIC MATHEMATICAL STRETCHED TAH","	# <font> 0637 arabic letter tah"},
/* 1EE69 */ { "ARABIC MATHEMATICAL STRETCHED YEH","	# <font> 064A arabic letter yeh"},
/* 1EE6A */ { "ARABIC MATHEMATICAL STRETCHED KAF","	# <font> 0643 arabic letter kaf"},
/* 1EE6B */ { NULL,NULL},
/* 1EE6C */ { "ARABIC MATHEMATICAL STRETCHED MEEM","	# <font> 0645 arabic letter meem"},
/* 1EE6D */ { "ARABIC MATHEMATICAL STRETCHED NOON","	# <font> 0646 arabic letter noon"},
/* 1EE6E */ { "ARABIC MATHEMATICAL STRETCHED SEEN","	# <font> 0633 arabic letter seen"},
/* 1EE6F */ { "ARABIC MATHEMATICAL STRETCHED AIN","	# <font> 0639 arabic letter ain"},
/* 1EE70 */ { "ARABIC MATHEMATICAL STRETCHED FEH","	# <font> 0641 arabic letter feh"},
/* 1EE71 */ { "ARABIC MATHEMATICAL STRETCHED SAD","	# <font> 0635 arabic letter sad"},
/* 1EE72 */ { "ARABIC MATHEMATICAL STRETCHED QAF","	# <font> 0642 arabic letter qaf"},
/* 1EE73 */ { NULL,NULL},
/* 1EE74 */ { "ARABIC MATHEMATICAL STRETCHED SHEEN","	# <font> 0634 arabic letter sheen"},
/* 1EE75 */ { "ARABIC MATHEMATICAL STRETCHED TEH","	# <font> 062A arabic letter teh"},
/* 1EE76 */ { "ARABIC MATHEMATICAL STRETCHED THEH","	# <font> 062B arabic letter theh"},
/* 1EE77 */ { "ARABIC MATHEMATICAL STRETCHED KHAH","	# <font> 062E arabic letter khah"},
/* 1EE78 */ { NULL,NULL},
/* 1EE79 */ { "ARABIC MATHEMATICAL STRETCHED DAD","	# <font> 0636 arabic letter dad"},
/* 1EE7A */ { "ARABIC MATHEMATICAL STRETCHED ZAH","	# <font> 0638 arabic letter zah"},
/* 1EE7B */ { "ARABIC MATHEMATICAL STRETCHED GHAIN","	# <font> 063A arabic letter ghain"},
/* 1EE7C */ { "ARABIC MATHEMATICAL STRETCHED DOTLESS BEH","	# <font> 066E arabic letter dotless beh"},
/* 1EE7D */ { NULL,NULL},
/* 1EE7E */ { "ARABIC MATHEMATICAL STRETCHED DOTLESS FEH","	# <font> 06A1 arabic letter dotless feh"},
/* 1EE7F */ { NULL,NULL},
/* 1EE80 */ { "ARABIC MATHEMATICAL LOOPED ALEF","	# <font> 0627 arabic letter alef"},
/* 1EE81 */ { "ARABIC MATHEMATICAL LOOPED BEH","	# <font> 0628 arabic letter beh"},
/* 1EE82 */ { "ARABIC MATHEMATICAL LOOPED JEEM","	# <font> 062C arabic letter jeem"},
/* 1EE83 */ { "ARABIC MATHEMATICAL LOOPED DAL","	# <font> 062F arabic letter dal"},
/* 1EE84 */ { "ARABIC MATHEMATICAL LOOPED HEH","	# <font> 0647 arabic letter heh"},
/* 1EE85 */ { "ARABIC MATHEMATICAL LOOPED WAW","	# <font> 0648 arabic letter waw"},
/* 1EE86 */ { "ARABIC MATHEMATICAL LOOPED ZAIN","	# <font> 0632 arabic letter zain"},
/* 1EE87 */ { "ARABIC MATHEMATICAL LOOPED HAH","	# <font> 062D arabic letter hah"},
/* 1EE88 */ { "ARABIC MATHEMATICAL LOOPED TAH","	# <font> 0637 arabic letter tah"},
/* 1EE89 */ { "ARABIC MATHEMATICAL LOOPED YEH","	# <font> 064A arabic letter yeh"},
/* 1EE8A */ { NULL,NULL},
/* 1EE8B */ { "ARABIC MATHEMATICAL LOOPED LAM","	# <font> 0644 arabic letter lam"},
/* 1EE8C */ { "ARABIC MATHEMATICAL LOOPED MEEM","	# <font> 0645 arabic letter meem"},
/* 1EE8D */ { "ARABIC MATHEMATICAL LOOPED NOON","	# <font> 0646 arabic letter noon"},
/* 1EE8E */ { "ARABIC MATHEMATICAL LOOPED SEEN","	# <font> 0633 arabic letter seen"},
/* 1EE8F */ { "ARABIC MATHEMATICAL LOOPED AIN","	# <font> 0639 arabic letter ain"},
/* 1EE90 */ { "ARABIC MATHEMATICAL LOOPED FEH","	# <font> 0641 arabic letter feh"},
/* 1EE91 */ { "ARABIC MATHEMATICAL LOOPED SAD","	# <font> 0635 arabic letter sad"},
/* 1EE92 */ { "ARABIC MATHEMATICAL LOOPED QAF","	# <font> 0642 arabic letter qaf"},
/* 1EE93 */ { "ARABIC MATHEMATICAL LOOPED REH","	# <font> 0631 arabic letter reh"},
/* 1EE94 */ { "ARABIC MATHEMATICAL LOOPED SHEEN","	# <font> 0634 arabic letter sheen"},
/* 1EE95 */ { "ARABIC MATHEMATICAL LOOPED TEH","	# <font> 062A arabic letter teh"},
/* 1EE96 */ { "ARABIC MATHEMATICAL LOOPED THEH","	# <font> 062B arabic letter theh"},
/* 1EE97 */ { "ARABIC MATHEMATICAL LOOPED KHAH","	# <font> 062E arabic letter khah"},
/* 1EE98 */ { "ARABIC MATHEMATICAL LOOPED THAL","	# <font> 0630 arabic letter thal"},
/* 1EE99 */ { "ARABIC MATHEMATICAL LOOPED DAD","	# <font> 0636 arabic letter dad"},
/* 1EE9A */ { "ARABIC MATHEMATICAL LOOPED ZAH","	# <font> 0638 arabic letter zah"},
/* 1EE9B */ { "ARABIC MATHEMATICAL LOOPED GHAIN","	# <font> 063A arabic letter ghain"},
/* 1EE9C */ { NULL,NULL},
/* 1EE9D */ { NULL,NULL},
/* 1EE9E */ { NULL,NULL},
/* 1EE9F */ { NULL,NULL},
/* 1EEA0 */ { NULL,NULL},
/* 1EEA1 */ { "ARABIC MATHEMATICAL DOUBLE-STRUCK BEH","	# <font> 0628 arabic letter beh"},
/* 1EEA2 */ { "ARABIC MATHEMATICAL DOUBLE-STRUCK JEEM","	# <font> 062C arabic letter jeem"},
/* 1EEA3 */ { "ARABIC MATHEMATICAL DOUBLE-STRUCK DAL","	# <font> 062F arabic letter dal"},
/* 1EEA4 */ { NULL,NULL},
/* 1EEA5 */ { "ARABIC MATHEMATICAL DOUBLE-STRUCK WAW","	# <font> 0648 arabic letter waw"},
/* 1EEA6 */ { "ARABIC MATHEMATICAL DOUBLE-STRUCK ZAIN","	# <font> 0632 arabic letter zain"},
/* 1EEA7 */ { "ARABIC MATHEMATICAL DOUBLE-STRUCK HAH","	# <font> 062D arabic letter hah"},
/* 1EEA8 */ { "ARABIC MATHEMATICAL DOUBLE-STRUCK TAH","	# <font> 0637 arabic letter tah"},
/* 1EEA9 */ { "ARABIC MATHEMATICAL DOUBLE-STRUCK YEH","	# <font> 064A arabic letter yeh"},
/* 1EEAA */ { NULL,NULL},
/* 1EEAB */ { "ARABIC MATHEMATICAL DOUBLE-STRUCK LAM","	# <font> 0644 arabic letter lam"},
/* 1EEAC */ { "ARABIC MATHEMATICAL DOUBLE-STRUCK MEEM","	# <font> 0645 arabic letter meem"},
/* 1EEAD */ { "ARABIC MATHEMATICAL DOUBLE-STRUCK NOON","	# <font> 0646 arabic letter noon"},
/* 1EEAE */ { "ARABIC MATHEMATICAL DOUBLE-STRUCK SEEN","	# <font> 0633 arabic letter seen"},
/* 1EEAF */ { "ARABIC MATHEMATICAL DOUBLE-STRUCK AIN","	# <font> 0639 arabic letter ain"},
/* 1EEB0 */ { "ARABIC MATHEMATICAL DOUBLE-STRUCK FEH","	# <font> 0641 arabic letter feh"},
/* 1EEB1 */ { "ARABIC MATHEMATICAL DOUBLE-STRUCK SAD","	# <font> 0635 arabic letter sad"},
/* 1EEB2 */ { "ARABIC MATHEMATICAL DOUBLE-STRUCK QAF","	# <font> 0642 arabic letter qaf"},
/* 1EEB3 */ { "ARABIC MATHEMATICAL DOUBLE-STRUCK REH","	# <font> 0631 arabic letter reh"},
/* 1EEB4 */ { "ARABIC MATHEMATICAL DOUBLE-STRUCK SHEEN","	# <font> 0634 arabic letter sheen"},
/* 1EEB5 */ { "ARABIC MATHEMATICAL DOUBLE-STRUCK TEH","	# <font> 062A arabic letter teh"},
/* 1EEB6 */ { "ARABIC MATHEMATICAL DOUBLE-STRUCK THEH","	# <font> 062B arabic letter theh"},
/* 1EEB7 */ { "ARABIC MATHEMATICAL DOUBLE-STRUCK KHAH","	# <font> 062E arabic letter khah"},
/* 1EEB8 */ { "ARABIC MATHEMATICAL DOUBLE-STRUCK THAL","	# <font> 0630 arabic letter thal"},
/* 1EEB9 */ { "ARABIC MATHEMATICAL DOUBLE-STRUCK DAD","	# <font> 0636 arabic letter dad"},
/* 1EEBA */ { "ARABIC MATHEMATICAL DOUBLE-STRUCK ZAH","	# <font> 0638 arabic letter zah"},
/* 1EEBB */ { "ARABIC MATHEMATICAL DOUBLE-STRUCK GHAIN","	# <font> 063A arabic letter ghain"},
/* 1EEBC */ { NULL,NULL},
/* 1EEBD */ { NULL,NULL},
/* 1EEBE */ { NULL,NULL},
/* 1EEBF */ { NULL,NULL},
/* 1EEC0 */ { NULL,NULL},
/* 1EEC1 */ { NULL,NULL},
/* 1EEC2 */ { NULL,NULL},
/* 1EEC3 */ { NULL,NULL},
/* 1EEC4 */ { NULL,NULL},
/* 1EEC5 */ { NULL,NULL},
/* 1EEC6 */ { NULL,NULL},
/* 1EEC7 */ { NULL,NULL},
/* 1EEC8 */ { NULL,NULL},
/* 1EEC9 */ { NULL,NULL},
/* 1EECA */ { NULL,NULL},
/* 1EECB */ { NULL,NULL},
/* 1EECC */ { NULL,NULL},
/* 1EECD */ { NULL,NULL},
/* 1EECE */ { NULL,NULL},
/* 1EECF */ { NULL,NULL},
/* 1EED0 */ { NULL,NULL},
/* 1EED1 */ { NULL,NULL},
/* 1EED2 */ { NULL,NULL},
/* 1EED3 */ { NULL,NULL},
/* 1EED4 */ { NULL,NULL},
/* 1EED5 */ { NULL,NULL},
/* 1EED6 */ { NULL,NULL},
/* 1EED7 */ { NULL,NULL},
/* 1EED8 */ { NULL,NULL},
/* 1EED9 */ { NULL,NULL},
/* 1EEDA */ { NULL,NULL},
/* 1EEDB */ { NULL,NULL},
/* 1EEDC */ { NULL,NULL},
/* 1EEDD */ { NULL,NULL},
/* 1EEDE */ { NULL,NULL},
/* 1EEDF */ { NULL,NULL},
/* 1EEE0 */ { NULL,NULL},
/* 1EEE1 */ { NULL,NULL},
/* 1EEE2 */ { NULL,NULL},
/* 1EEE3 */ { NULL,NULL},
/* 1EEE4 */ { NULL,NULL},
/* 1EEE5 */ { NULL,NULL},
/* 1EEE6 */ { NULL,NULL},
/* 1EEE7 */ { NULL,NULL},
/* 1EEE8 */ { NULL,NULL},
/* 1EEE9 */ { NULL,NULL},
/* 1EEEA */ { NULL,NULL},
/* 1EEEB */ { NULL,NULL},
/* 1EEEC */ { NULL,NULL},
/* 1EEED */ { NULL,NULL},
/* 1EEEE */ { NULL,NULL},
/* 1EEEF */ { NULL,NULL},
/* 1EEF0 */ { "ARABIC MATHEMATICAL OPERATOR MEEM WITH HAH WITH TATWEEL","	* used in Arabic mathematics to denote summation\n"
	"	* stretched at the tatweel\n"
	"	x (n-ary summation - 2211)"},
/* 1EEF1 */ { "ARABIC MATHEMATICAL OPERATOR HAH WITH DAL","	* used in Persian mathematics to denote limits\n"
	"	* stretched between the hah and the dal"},
/* 1EEF2 */ { NULL,NULL},
/* 1EEF3 */ { NULL,NULL},
/* 1EEF4 */ { NULL,NULL},
/* 1EEF5 */ { NULL,NULL},
/* 1EEF6 */ { NULL,NULL},
/* 1EEF7 */ { NULL,NULL},
/* 1EEF8 */ { NULL,NULL},
/* 1EEF9 */ { NULL,NULL},
/* 1EEFA */ { NULL,NULL},
/* 1EEFB */ { NULL,NULL},
/* 1EEFC */ { NULL,NULL},
/* 1EEFD */ { NULL,NULL},
/* 1EEFE */ { NULL,NULL},
/* 1EEFF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_F0[] = {
/* 1F000 */ { "MAHJONG TILE EAST WIND",NULL},
/* 1F001 */ { "MAHJONG TILE SOUTH WIND",NULL},
/* 1F002 */ { "MAHJONG TILE WEST WIND",NULL},
/* 1F003 */ { "MAHJONG TILE NORTH WIND",NULL},
/* 1F004 */ { "MAHJONG TILE RED DRAGON","	= hongzhong"},
/* 1F005 */ { "MAHJONG TILE GREEN DRAGON","	= qingfa"},
/* 1F006 */ { "MAHJONG TILE WHITE DRAGON","	= baiban"},
/* 1F007 */ { "MAHJONG TILE ONE OF CHARACTERS","	= wan"},
/* 1F008 */ { "MAHJONG TILE TWO OF CHARACTERS",NULL},
/* 1F009 */ { "MAHJONG TILE THREE OF CHARACTERS",NULL},
/* 1F00A */ { "MAHJONG TILE FOUR OF CHARACTERS",NULL},
/* 1F00B */ { "MAHJONG TILE FIVE OF CHARACTERS",NULL},
/* 1F00C */ { "MAHJONG TILE SIX OF CHARACTERS",NULL},
/* 1F00D */ { "MAHJONG TILE SEVEN OF CHARACTERS",NULL},
/* 1F00E */ { "MAHJONG TILE EIGHT OF CHARACTERS",NULL},
/* 1F00F */ { "MAHJONG TILE NINE OF CHARACTERS",NULL},
/* 1F010 */ { "MAHJONG TILE ONE OF BAMBOOS","	= tiao"},
/* 1F011 */ { "MAHJONG TILE TWO OF BAMBOOS",NULL},
/* 1F012 */ { "MAHJONG TILE THREE OF BAMBOOS",NULL},
/* 1F013 */ { "MAHJONG TILE FOUR OF BAMBOOS",NULL},
/* 1F014 */ { "MAHJONG TILE FIVE OF BAMBOOS",NULL},
/* 1F015 */ { "MAHJONG TILE SIX OF BAMBOOS",NULL},
/* 1F016 */ { "MAHJONG TILE SEVEN OF BAMBOOS",NULL},
/* 1F017 */ { "MAHJONG TILE EIGHT OF BAMBOOS",NULL},
/* 1F018 */ { "MAHJONG TILE NINE OF BAMBOOS",NULL},
/* 1F019 */ { "MAHJONG TILE ONE OF CIRCLES","	= bing"},
/* 1F01A */ { "MAHJONG TILE TWO OF CIRCLES",NULL},
/* 1F01B */ { "MAHJONG TILE THREE OF CIRCLES",NULL},
/* 1F01C */ { "MAHJONG TILE FOUR OF CIRCLES",NULL},
/* 1F01D */ { "MAHJONG TILE FIVE OF CIRCLES",NULL},
/* 1F01E */ { "MAHJONG TILE SIX OF CIRCLES",NULL},
/* 1F01F */ { "MAHJONG TILE SEVEN OF CIRCLES",NULL},
/* 1F020 */ { "MAHJONG TILE EIGHT OF CIRCLES",NULL},
/* 1F021 */ { "MAHJONG TILE NINE OF CIRCLES",NULL},
/* 1F022 */ { "MAHJONG TILE PLUM","	= mei"},
/* 1F023 */ { "MAHJONG TILE ORCHID","	= lan"},
/* 1F024 */ { "MAHJONG TILE BAMBOO","	= zhu"},
/* 1F025 */ { "MAHJONG TILE CHRYSANTHEMUM","	= ju"},
/* 1F026 */ { "MAHJONG TILE SPRING",NULL},
/* 1F027 */ { "MAHJONG TILE SUMMER",NULL},
/* 1F028 */ { "MAHJONG TILE AUTUMN",NULL},
/* 1F029 */ { "MAHJONG TILE WINTER",NULL},
/* 1F02A */ { "MAHJONG TILE JOKER","	= baida"},
/* 1F02B */ { "MAHJONG TILE BACK",NULL},
/* 1F02C */ { NULL,NULL},
/* 1F02D */ { NULL,NULL},
/* 1F02E */ { NULL,NULL},
/* 1F02F */ { NULL,NULL},
/* 1F030 */ { "DOMINO TILE HORIZONTAL BACK",NULL},
/* 1F031 */ { "DOMINO TILE HORIZONTAL-00-00",NULL},
/* 1F032 */ { "DOMINO TILE HORIZONTAL-00-01",NULL},
/* 1F033 */ { "DOMINO TILE HORIZONTAL-00-02",NULL},
/* 1F034 */ { "DOMINO TILE HORIZONTAL-00-03",NULL},
/* 1F035 */ { "DOMINO TILE HORIZONTAL-00-04",NULL},
/* 1F036 */ { "DOMINO TILE HORIZONTAL-00-05",NULL},
/* 1F037 */ { "DOMINO TILE HORIZONTAL-00-06",NULL},
/* 1F038 */ { "DOMINO TILE HORIZONTAL-01-00",NULL},
/* 1F039 */ { "DOMINO TILE HORIZONTAL-01-01",NULL},
/* 1F03A */ { "DOMINO TILE HORIZONTAL-01-02",NULL},
/* 1F03B */ { "DOMINO TILE HORIZONTAL-01-03",NULL},
/* 1F03C */ { "DOMINO TILE HORIZONTAL-01-04",NULL},
/* 1F03D */ { "DOMINO TILE HORIZONTAL-01-05",NULL},
/* 1F03E */ { "DOMINO TILE HORIZONTAL-01-06",NULL},
/* 1F03F */ { "DOMINO TILE HORIZONTAL-02-00",NULL},
/* 1F040 */ { "DOMINO TILE HORIZONTAL-02-01",NULL},
/* 1F041 */ { "DOMINO TILE HORIZONTAL-02-02",NULL},
/* 1F042 */ { "DOMINO TILE HORIZONTAL-02-03",NULL},
/* 1F043 */ { "DOMINO TILE HORIZONTAL-02-04",NULL},
/* 1F044 */ { "DOMINO TILE HORIZONTAL-02-05",NULL},
/* 1F045 */ { "DOMINO TILE HORIZONTAL-02-06",NULL},
/* 1F046 */ { "DOMINO TILE HORIZONTAL-03-00",NULL},
/* 1F047 */ { "DOMINO TILE HORIZONTAL-03-01",NULL},
/* 1F048 */ { "DOMINO TILE HORIZONTAL-03-02",NULL},
/* 1F049 */ { "DOMINO TILE HORIZONTAL-03-03",NULL},
/* 1F04A */ { "DOMINO TILE HORIZONTAL-03-04",NULL},
/* 1F04B */ { "DOMINO TILE HORIZONTAL-03-05",NULL},
/* 1F04C */ { "DOMINO TILE HORIZONTAL-03-06",NULL},
/* 1F04D */ { "DOMINO TILE HORIZONTAL-04-00",NULL},
/* 1F04E */ { "DOMINO TILE HORIZONTAL-04-01",NULL},
/* 1F04F */ { "DOMINO TILE HORIZONTAL-04-02",NULL},
/* 1F050 */ { "DOMINO TILE HORIZONTAL-04-03",NULL},
/* 1F051 */ { "DOMINO TILE HORIZONTAL-04-04",NULL},
/* 1F052 */ { "DOMINO TILE HORIZONTAL-04-05",NULL},
/* 1F053 */ { "DOMINO TILE HORIZONTAL-04-06",NULL},
/* 1F054 */ { "DOMINO TILE HORIZONTAL-05-00",NULL},
/* 1F055 */ { "DOMINO TILE HORIZONTAL-05-01",NULL},
/* 1F056 */ { "DOMINO TILE HORIZONTAL-05-02",NULL},
/* 1F057 */ { "DOMINO TILE HORIZONTAL-05-03",NULL},
/* 1F058 */ { "DOMINO TILE HORIZONTAL-05-04",NULL},
/* 1F059 */ { "DOMINO TILE HORIZONTAL-05-05",NULL},
/* 1F05A */ { "DOMINO TILE HORIZONTAL-05-06",NULL},
/* 1F05B */ { "DOMINO TILE HORIZONTAL-06-00",NULL},
/* 1F05C */ { "DOMINO TILE HORIZONTAL-06-01",NULL},
/* 1F05D */ { "DOMINO TILE HORIZONTAL-06-02",NULL},
/* 1F05E */ { "DOMINO TILE HORIZONTAL-06-03",NULL},
/* 1F05F */ { "DOMINO TILE HORIZONTAL-06-04",NULL},
/* 1F060 */ { "DOMINO TILE HORIZONTAL-06-05",NULL},
/* 1F061 */ { "DOMINO TILE HORIZONTAL-06-06",NULL},
/* 1F062 */ { "DOMINO TILE VERTICAL BACK",NULL},
/* 1F063 */ { "DOMINO TILE VERTICAL-00-00",NULL},
/* 1F064 */ { "DOMINO TILE VERTICAL-00-01",NULL},
/* 1F065 */ { "DOMINO TILE VERTICAL-00-02",NULL},
/* 1F066 */ { "DOMINO TILE VERTICAL-00-03",NULL},
/* 1F067 */ { "DOMINO TILE VERTICAL-00-04",NULL},
/* 1F068 */ { "DOMINO TILE VERTICAL-00-05",NULL},
/* 1F069 */ { "DOMINO TILE VERTICAL-00-06",NULL},
/* 1F06A */ { "DOMINO TILE VERTICAL-01-00",NULL},
/* 1F06B */ { "DOMINO TILE VERTICAL-01-01",NULL},
/* 1F06C */ { "DOMINO TILE VERTICAL-01-02",NULL},
/* 1F06D */ { "DOMINO TILE VERTICAL-01-03",NULL},
/* 1F06E */ { "DOMINO TILE VERTICAL-01-04",NULL},
/* 1F06F */ { "DOMINO TILE VERTICAL-01-05",NULL},
/* 1F070 */ { "DOMINO TILE VERTICAL-01-06",NULL},
/* 1F071 */ { "DOMINO TILE VERTICAL-02-00",NULL},
/* 1F072 */ { "DOMINO TILE VERTICAL-02-01",NULL},
/* 1F073 */ { "DOMINO TILE VERTICAL-02-02",NULL},
/* 1F074 */ { "DOMINO TILE VERTICAL-02-03",NULL},
/* 1F075 */ { "DOMINO TILE VERTICAL-02-04",NULL},
/* 1F076 */ { "DOMINO TILE VERTICAL-02-05",NULL},
/* 1F077 */ { "DOMINO TILE VERTICAL-02-06",NULL},
/* 1F078 */ { "DOMINO TILE VERTICAL-03-00",NULL},
/* 1F079 */ { "DOMINO TILE VERTICAL-03-01",NULL},
/* 1F07A */ { "DOMINO TILE VERTICAL-03-02",NULL},
/* 1F07B */ { "DOMINO TILE VERTICAL-03-03",NULL},
/* 1F07C */ { "DOMINO TILE VERTICAL-03-04",NULL},
/* 1F07D */ { "DOMINO TILE VERTICAL-03-05",NULL},
/* 1F07E */ { "DOMINO TILE VERTICAL-03-06",NULL},
/* 1F07F */ { "DOMINO TILE VERTICAL-04-00",NULL},
/* 1F080 */ { "DOMINO TILE VERTICAL-04-01",NULL},
/* 1F081 */ { "DOMINO TILE VERTICAL-04-02",NULL},
/* 1F082 */ { "DOMINO TILE VERTICAL-04-03",NULL},
/* 1F083 */ { "DOMINO TILE VERTICAL-04-04",NULL},
/* 1F084 */ { "DOMINO TILE VERTICAL-04-05",NULL},
/* 1F085 */ { "DOMINO TILE VERTICAL-04-06",NULL},
/* 1F086 */ { "DOMINO TILE VERTICAL-05-00",NULL},
/* 1F087 */ { "DOMINO TILE VERTICAL-05-01",NULL},
/* 1F088 */ { "DOMINO TILE VERTICAL-05-02",NULL},
/* 1F089 */ { "DOMINO TILE VERTICAL-05-03",NULL},
/* 1F08A */ { "DOMINO TILE VERTICAL-05-04",NULL},
/* 1F08B */ { "DOMINO TILE VERTICAL-05-05",NULL},
/* 1F08C */ { "DOMINO TILE VERTICAL-05-06",NULL},
/* 1F08D */ { "DOMINO TILE VERTICAL-06-00",NULL},
/* 1F08E */ { "DOMINO TILE VERTICAL-06-01",NULL},
/* 1F08F */ { "DOMINO TILE VERTICAL-06-02",NULL},
/* 1F090 */ { "DOMINO TILE VERTICAL-06-03",NULL},
/* 1F091 */ { "DOMINO TILE VERTICAL-06-04",NULL},
/* 1F092 */ { "DOMINO TILE VERTICAL-06-05",NULL},
/* 1F093 */ { "DOMINO TILE VERTICAL-06-06",NULL},
/* 1F094 */ { NULL,NULL},
/* 1F095 */ { NULL,NULL},
/* 1F096 */ { NULL,NULL},
/* 1F097 */ { NULL,NULL},
/* 1F098 */ { NULL,NULL},
/* 1F099 */ { NULL,NULL},
/* 1F09A */ { NULL,NULL},
/* 1F09B */ { NULL,NULL},
/* 1F09C */ { NULL,NULL},
/* 1F09D */ { NULL,NULL},
/* 1F09E */ { NULL,NULL},
/* 1F09F */ { NULL,NULL},
/* 1F0A0 */ { "PLAYING CARD BACK",NULL},
/* 1F0A1 */ { "PLAYING CARD ACE OF SPADES",NULL},
/* 1F0A2 */ { "PLAYING CARD TWO OF SPADES",NULL},
/* 1F0A3 */ { "PLAYING CARD THREE OF SPADES",NULL},
/* 1F0A4 */ { "PLAYING CARD FOUR OF SPADES",NULL},
/* 1F0A5 */ { "PLAYING CARD FIVE OF SPADES",NULL},
/* 1F0A6 */ { "PLAYING CARD SIX OF SPADES",NULL},
/* 1F0A7 */ { "PLAYING CARD SEVEN OF SPADES",NULL},
/* 1F0A8 */ { "PLAYING CARD EIGHT OF SPADES",NULL},
/* 1F0A9 */ { "PLAYING CARD NINE OF SPADES",NULL},
/* 1F0AA */ { "PLAYING CARD TEN OF SPADES",NULL},
/* 1F0AB */ { "PLAYING CARD JACK OF SPADES","	= valet, Bube, Unter, Page, fante\n"
	"	= page of swords"},
/* 1F0AC */ { "PLAYING CARD KNIGHT OF SPADES","	= chevalier, Ober, Ritter, cavall, cavaliere\n"
	"	= knight of swords"},
/* 1F0AD */ { "PLAYING CARD QUEEN OF SPADES","	= dame, Dame, Königin, regina\n"
	"	= queen of swords"},
/* 1F0AE */ { "PLAYING CARD KING OF SPADES","	= roi, König, re\n"
	"	= king of swords"},
/* 1F0AF */ { NULL,NULL},
/* 1F0B0 */ { NULL,NULL},
/* 1F0B1 */ { "PLAYING CARD ACE OF HEARTS",NULL},
/* 1F0B2 */ { "PLAYING CARD TWO OF HEARTS",NULL},
/* 1F0B3 */ { "PLAYING CARD THREE OF HEARTS",NULL},
/* 1F0B4 */ { "PLAYING CARD FOUR OF HEARTS",NULL},
/* 1F0B5 */ { "PLAYING CARD FIVE OF HEARTS",NULL},
/* 1F0B6 */ { "PLAYING CARD SIX OF HEARTS",NULL},
/* 1F0B7 */ { "PLAYING CARD SEVEN OF HEARTS",NULL},
/* 1F0B8 */ { "PLAYING CARD EIGHT OF HEARTS",NULL},
/* 1F0B9 */ { "PLAYING CARD NINE OF HEARTS",NULL},
/* 1F0BA */ { "PLAYING CARD TEN OF HEARTS",NULL},
/* 1F0BB */ { "PLAYING CARD JACK OF HEARTS",NULL},
/* 1F0BC */ { "PLAYING CARD KNIGHT OF HEARTS",NULL},
/* 1F0BD */ { "PLAYING CARD QUEEN OF HEARTS",NULL},
/* 1F0BE */ { "PLAYING CARD KING OF HEARTS",NULL},
/* 1F0BF */ { "PLAYING CARD RED JOKER","	* used as the third joker"},
/* 1F0C0 */ { NULL,NULL},
/* 1F0C1 */ { "PLAYING CARD ACE OF DIAMONDS",NULL},
/* 1F0C2 */ { "PLAYING CARD TWO OF DIAMONDS",NULL},
/* 1F0C3 */ { "PLAYING CARD THREE OF DIAMONDS",NULL},
/* 1F0C4 */ { "PLAYING CARD FOUR OF DIAMONDS",NULL},
/* 1F0C5 */ { "PLAYING CARD FIVE OF DIAMONDS",NULL},
/* 1F0C6 */ { "PLAYING CARD SIX OF DIAMONDS",NULL},
/* 1F0C7 */ { "PLAYING CARD SEVEN OF DIAMONDS",NULL},
/* 1F0C8 */ { "PLAYING CARD EIGHT OF DIAMONDS",NULL},
/* 1F0C9 */ { "PLAYING CARD NINE OF DIAMONDS",NULL},
/* 1F0CA */ { "PLAYING CARD TEN OF DIAMONDS",NULL},
/* 1F0CB */ { "PLAYING CARD JACK OF DIAMONDS",NULL},
/* 1F0CC */ { "PLAYING CARD KNIGHT OF DIAMONDS",NULL},
/* 1F0CD */ { "PLAYING CARD QUEEN OF DIAMONDS",NULL},
/* 1F0CE */ { "PLAYING CARD KING OF DIAMONDS",NULL},
/* 1F0CF */ { "PLAYING CARD BLACK JOKER",NULL},
/* 1F0D0 */ { NULL,NULL},
/* 1F0D1 */ { "PLAYING CARD ACE OF CLUBS",NULL},
/* 1F0D2 */ { "PLAYING CARD TWO OF CLUBS",NULL},
/* 1F0D3 */ { "PLAYING CARD THREE OF CLUBS",NULL},
/* 1F0D4 */ { "PLAYING CARD FOUR OF CLUBS",NULL},
/* 1F0D5 */ { "PLAYING CARD FIVE OF CLUBS",NULL},
/* 1F0D6 */ { "PLAYING CARD SIX OF CLUBS",NULL},
/* 1F0D7 */ { "PLAYING CARD SEVEN OF CLUBS",NULL},
/* 1F0D8 */ { "PLAYING CARD EIGHT OF CLUBS",NULL},
/* 1F0D9 */ { "PLAYING CARD NINE OF CLUBS",NULL},
/* 1F0DA */ { "PLAYING CARD TEN OF CLUBS",NULL},
/* 1F0DB */ { "PLAYING CARD JACK OF CLUBS",NULL},
/* 1F0DC */ { "PLAYING CARD KNIGHT OF CLUBS",NULL},
/* 1F0DD */ { "PLAYING CARD QUEEN OF CLUBS",NULL},
/* 1F0DE */ { "PLAYING CARD KING OF CLUBS",NULL},
/* 1F0DF */ { "PLAYING CARD WHITE JOKER","	* may also be red"},
/* 1F0E0 */ { "PLAYING CARD FOOL",NULL},
/* 1F0E1 */ { "PLAYING CARD TRUMP-1","	* individual"},
/* 1F0E2 */ { "PLAYING CARD TRUMP-2","	* childhood"},
/* 1F0E3 */ { "PLAYING CARD TRUMP-3","	* youth"},
/* 1F0E4 */ { "PLAYING CARD TRUMP-4","	* maturity"},
/* 1F0E5 */ { "PLAYING CARD TRUMP-5","	* old age"},
/* 1F0E6 */ { "PLAYING CARD TRUMP-6","	* morning"},
/* 1F0E7 */ { "PLAYING CARD TRUMP-7","	* afternoon"},
/* 1F0E8 */ { "PLAYING CARD TRUMP-8","	* evening"},
/* 1F0E9 */ { "PLAYING CARD TRUMP-9","	* night"},
/* 1F0EA */ { "PLAYING CARD TRUMP-10","	* earth and air"},
/* 1F0EB */ { "PLAYING CARD TRUMP-11","	* water and fire"},
/* 1F0EC */ { "PLAYING CARD TRUMP-12","	* dance"},
/* 1F0ED */ { "PLAYING CARD TRUMP-13","	* shopping"},
/* 1F0EE */ { "PLAYING CARD TRUMP-14","	* open air"},
/* 1F0EF */ { "PLAYING CARD TRUMP-15","	* visual arts"},
/* 1F0F0 */ { "PLAYING CARD TRUMP-16","	* spring"},
/* 1F0F1 */ { "PLAYING CARD TRUMP-17","	* summer"},
/* 1F0F2 */ { "PLAYING CARD TRUMP-18","	* autumn"},
/* 1F0F3 */ { "PLAYING CARD TRUMP-19","	* winter"},
/* 1F0F4 */ { "PLAYING CARD TRUMP-20","	* the game"},
/* 1F0F5 */ { "PLAYING CARD TRUMP-21","	* collective"},
/* 1F0F6 */ { NULL,NULL},
/* 1F0F7 */ { NULL,NULL},
/* 1F0F8 */ { NULL,NULL},
/* 1F0F9 */ { NULL,NULL},
/* 1F0FA */ { NULL,NULL},
/* 1F0FB */ { NULL,NULL},
/* 1F0FC */ { NULL,NULL},
/* 1F0FD */ { NULL,NULL},
/* 1F0FE */ { NULL,NULL},
/* 1F0FF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_F1[] = {
/* 1F100 */ { "DIGIT ZERO FULL STOP","	# 0030 002E"},
/* 1F101 */ { "DIGIT ZERO COMMA","	# 0030 002C"},
/* 1F102 */ { "DIGIT ONE COMMA","	# 0031 002C"},
/* 1F103 */ { "DIGIT TWO COMMA","	# 0032 002C"},
/* 1F104 */ { "DIGIT THREE COMMA","	# 0033 002C"},
/* 1F105 */ { "DIGIT FOUR COMMA","	# 0034 002C"},
/* 1F106 */ { "DIGIT FIVE COMMA","	# 0035 002C"},
/* 1F107 */ { "DIGIT SIX COMMA","	# 0036 002C"},
/* 1F108 */ { "DIGIT SEVEN COMMA","	# 0037 002C"},
/* 1F109 */ { "DIGIT EIGHT COMMA","	# 0038 002C"},
/* 1F10A */ { "DIGIT NINE COMMA","	# 0039 002C"},
/* 1F10B */ { "DINGBAT CIRCLED SANS-SERIF DIGIT ZERO",NULL},
/* 1F10C */ { "DINGBAT NEGATIVE CIRCLED SANS-SERIF DIGIT ZERO",NULL},
/* 1F10D */ { "CIRCLED ZERO WITH SLASH","	= no rights reserved"},
/* 1F10E */ { "CIRCLED ANTICLOCKWISE ARROW","	= share alike"},
/* 1F10F */ { "CIRCLED DOLLAR SIGN WITH OVERLAID BACKSLASH","	= non commercial"},
/* 1F110 */ { "PARENTHESIZED LATIN CAPITAL LETTER A","	# 0028 0041 0029"},
/* 1F111 */ { "PARENTHESIZED LATIN CAPITAL LETTER B","	# 0028 0042 0029"},
/* 1F112 */ { "PARENTHESIZED LATIN CAPITAL LETTER C","	# 0028 0043 0029"},
/* 1F113 */ { "PARENTHESIZED LATIN CAPITAL LETTER D","	# 0028 0044 0029"},
/* 1F114 */ { "PARENTHESIZED LATIN CAPITAL LETTER E","	# 0028 0045 0029"},
/* 1F115 */ { "PARENTHESIZED LATIN CAPITAL LETTER F","	# 0028 0046 0029"},
/* 1F116 */ { "PARENTHESIZED LATIN CAPITAL LETTER G","	# 0028 0047 0029"},
/* 1F117 */ { "PARENTHESIZED LATIN CAPITAL LETTER H","	# 0028 0048 0029"},
/* 1F118 */ { "PARENTHESIZED LATIN CAPITAL LETTER I","	# 0028 0049 0029"},
/* 1F119 */ { "PARENTHESIZED LATIN CAPITAL LETTER J","	# 0028 004A 0029"},
/* 1F11A */ { "PARENTHESIZED LATIN CAPITAL LETTER K","	# 0028 004B 0029"},
/* 1F11B */ { "PARENTHESIZED LATIN CAPITAL LETTER L","	# 0028 004C 0029"},
/* 1F11C */ { "PARENTHESIZED LATIN CAPITAL LETTER M","	# 0028 004D 0029"},
/* 1F11D */ { "PARENTHESIZED LATIN CAPITAL LETTER N","	# 0028 004E 0029"},
/* 1F11E */ { "PARENTHESIZED LATIN CAPITAL LETTER O","	# 0028 004F 0029"},
/* 1F11F */ { "PARENTHESIZED LATIN CAPITAL LETTER P","	# 0028 0050 0029"},
/* 1F120 */ { "PARENTHESIZED LATIN CAPITAL LETTER Q","	# 0028 0051 0029"},
/* 1F121 */ { "PARENTHESIZED LATIN CAPITAL LETTER R","	# 0028 0052 0029"},
/* 1F122 */ { "PARENTHESIZED LATIN CAPITAL LETTER S","	# 0028 0053 0029"},
/* 1F123 */ { "PARENTHESIZED LATIN CAPITAL LETTER T","	# 0028 0054 0029"},
/* 1F124 */ { "PARENTHESIZED LATIN CAPITAL LETTER U","	# 0028 0055 0029"},
/* 1F125 */ { "PARENTHESIZED LATIN CAPITAL LETTER V","	# 0028 0056 0029"},
/* 1F126 */ { "PARENTHESIZED LATIN CAPITAL LETTER W","	# 0028 0057 0029"},
/* 1F127 */ { "PARENTHESIZED LATIN CAPITAL LETTER X","	# 0028 0058 0029"},
/* 1F128 */ { "PARENTHESIZED LATIN CAPITAL LETTER Y","	# 0028 0059 0029"},
/* 1F129 */ { "PARENTHESIZED LATIN CAPITAL LETTER Z","	# 0028 005A 0029"},
/* 1F12A */ { "TORTOISE SHELL BRACKETED LATIN CAPITAL LETTER S","	* used in baseball scoring\n"
	"	# 3014 0053 3015"},
/* 1F12B */ { "CIRCLED ITALIC LATIN CAPITAL LETTER C","	= compact disc, single disc record\n"
	"	# <circle> 0043"},
/* 1F12C */ { "CIRCLED ITALIC LATIN CAPITAL LETTER R","	= disc record\n"
	"	# <circle> 0052"},
/* 1F12D */ { "CIRCLED CD","	x (square cd - 33C5)\n"
	"	# <circle> 0043 0044"},
/* 1F12E */ { "CIRCLED WZ","	* from the German term \"Warenzeichen\"\n"
	"	* indicate a trademarked term without making a legal claim of trademark status\n"
	"	* decomposition is anomalous, as the usual glyph shows a capital W and a small z\n"
	"	x (trade mark sign - 2122)\n"
	"	# <circle> 0057 005A"},
/* 1F12F */ { "COPYLEFT SYMBOL","	x (copyright sign - 00A9)\n"
	"	x (roman numeral reversed one hundred - 2183)"},
/* 1F130 */ { "SQUARED LATIN CAPITAL LETTER A","	= Anreisetag (day of arrival)\n"
	"	# <square> 0041"},
/* 1F131 */ { "SQUARED LATIN CAPITAL LETTER B","	= bank\n"
	"	= b-mode stereo compression broadcasting service (ARIB STD B24)\n"
	"	# <square> 0042"},
/* 1F132 */ { "SQUARED LATIN CAPITAL LETTER C","	# <square> 0043"},
/* 1F133 */ { "SQUARED LATIN CAPITAL LETTER D","	# <square> 0044"},
/* 1F134 */ { "SQUARED LATIN CAPITAL LETTER E","	# <square> 0045"},
/* 1F135 */ { "SQUARED LATIN CAPITAL LETTER F","	# <square> 0046"},
/* 1F136 */ { "SQUARED LATIN CAPITAL LETTER G","	# <square> 0047"},
/* 1F137 */ { "SQUARED LATIN CAPITAL LETTER H","	# <square> 0048"},
/* 1F138 */ { "SQUARED LATIN CAPITAL LETTER I","	# <square> 0049"},
/* 1F139 */ { "SQUARED LATIN CAPITAL LETTER J","	# <square> 004A"},
/* 1F13A */ { "SQUARED LATIN CAPITAL LETTER K","	# <square> 004B"},
/* 1F13B */ { "SQUARED LATIN CAPITAL LETTER L","	# <square> 004C"},
/* 1F13C */ { "SQUARED LATIN CAPITAL LETTER M","	# <square> 004D"},
/* 1F13D */ { "SQUARED LATIN CAPITAL LETTER N","	= news (ARIB STD B24)\n"
	"	# <square> 004E"},
/* 1F13E */ { "SQUARED LATIN CAPITAL LETTER O","	# <square> 004F"},
/* 1F13F */ { "SQUARED LATIN CAPITAL LETTER P","	= progressive broadcasting (ARIB STD B24)\n"
	"	# <square> 0050"},
/* 1F140 */ { "SQUARED LATIN CAPITAL LETTER Q","	# <square> 0051"},
/* 1F141 */ { "SQUARED LATIN CAPITAL LETTER R","	# <square> 0052"},
/* 1F142 */ { "SQUARED LATIN CAPITAL LETTER S","	= stereo broadcasting service (ARIB STD B24)\n"
	"	# <square> 0053"},
/* 1F143 */ { "SQUARED LATIN CAPITAL LETTER T","	= tobacconist\n"
	"	# <square> 0054"},
/* 1F144 */ { "SQUARED LATIN CAPITAL LETTER U","	# <square> 0055"},
/* 1F145 */ { "SQUARED LATIN CAPITAL LETTER V","	# <square> 0056"},
/* 1F146 */ { "SQUARED LATIN CAPITAL LETTER W","	= wide-format 16:9 broadcasting service (ARIB STD B24)\n"
	"	# <square> 0057"},
/* 1F147 */ { "SQUARED LATIN CAPITAL LETTER X","	# <square> 0058"},
/* 1F148 */ { "SQUARED LATIN CAPITAL LETTER Y","	# <square> 0059"},
/* 1F149 */ { "SQUARED LATIN CAPITAL LETTER Z","	# <square> 005A"},
/* 1F14A */ { "SQUARED HV","	= hdtv\n"
	"	# <square> 0048 0056"},
/* 1F14B */ { "SQUARED MV","	= multi-view television\n"
	"	# <square> 004D 0056"},
/* 1F14C */ { "SQUARED SD","	= sdtv\n"
	"	# <square> 0053 0044"},
/* 1F14D */ { "SQUARED SS","	= surround stereo broadcasting service\n"
	"	# <square> 0053 0053"},
/* 1F14E */ { "SQUARED PPV","	= pay-per-view\n"
	"	# <square> 0050 0050 0056"},
/* 1F14F */ { "SQUARED WC","	= water closet, public toilet\n"
	"	x (water closet - 1F6BE)\n"
	"	# <square> 0057 0043"},
/* 1F150 */ { "NEGATIVE CIRCLED LATIN CAPITAL LETTER A","	= airport"},
/* 1F151 */ { "NEGATIVE CIRCLED LATIN CAPITAL LETTER B",NULL},
/* 1F152 */ { "NEGATIVE CIRCLED LATIN CAPITAL LETTER C",NULL},
/* 1F153 */ { "NEGATIVE CIRCLED LATIN CAPITAL LETTER D",NULL},
/* 1F154 */ { "NEGATIVE CIRCLED LATIN CAPITAL LETTER E",NULL},
/* 1F155 */ { "NEGATIVE CIRCLED LATIN CAPITAL LETTER F","	= ferry"},
/* 1F156 */ { "NEGATIVE CIRCLED LATIN CAPITAL LETTER G",NULL},
/* 1F157 */ { "NEGATIVE CIRCLED LATIN CAPITAL LETTER H","	= hotel (ARIB STD B24)"},
/* 1F158 */ { "NEGATIVE CIRCLED LATIN CAPITAL LETTER I",NULL},
/* 1F159 */ { "NEGATIVE CIRCLED LATIN CAPITAL LETTER J",NULL},
/* 1F15A */ { "NEGATIVE CIRCLED LATIN CAPITAL LETTER K","	= Kurort (spa)\n"
	"	x (hot springs - 2668)"},
/* 1F15B */ { "NEGATIVE CIRCLED LATIN CAPITAL LETTER L","	= light rail\n"
	"	x (light rail - 1F688)"},
/* 1F15C */ { "NEGATIVE CIRCLED LATIN CAPITAL LETTER M","	= metro\n"
	"	x (metro - 1F687)"},
/* 1F15D */ { "NEGATIVE CIRCLED LATIN CAPITAL LETTER N",NULL},
/* 1F15E */ { "NEGATIVE CIRCLED LATIN CAPITAL LETTER O",NULL},
/* 1F15F */ { "NEGATIVE CIRCLED LATIN CAPITAL LETTER P","	= parking space (ARIB STD B24)"},
/* 1F160 */ { "NEGATIVE CIRCLED LATIN CAPITAL LETTER Q",NULL},
/* 1F161 */ { "NEGATIVE CIRCLED LATIN CAPITAL LETTER R","	= Raststätte (rest stop)"},
/* 1F162 */ { "NEGATIVE CIRCLED LATIN CAPITAL LETTER S","	= Stadtbahn (metropolitan railway)"},
/* 1F163 */ { "NEGATIVE CIRCLED LATIN CAPITAL LETTER T","	= Tankstelle (petrol station)\n"
	"	x (fuel pump - 26FD)"},
/* 1F164 */ { "NEGATIVE CIRCLED LATIN CAPITAL LETTER U","	= underground rail\n"
	"	x (metro - 1F687)"},
/* 1F165 */ { "NEGATIVE CIRCLED LATIN CAPITAL LETTER V",NULL},
/* 1F166 */ { "NEGATIVE CIRCLED LATIN CAPITAL LETTER W",NULL},
/* 1F167 */ { "NEGATIVE CIRCLED LATIN CAPITAL LETTER X",NULL},
/* 1F168 */ { "NEGATIVE CIRCLED LATIN CAPITAL LETTER Y",NULL},
/* 1F169 */ { "NEGATIVE CIRCLED LATIN CAPITAL LETTER Z",NULL},
/* 1F16A */ { "RAISED MC SIGN","	= marque de commerce\n"
	"	* used in Canada\n"
	"	x (trade mark sign - 2122)\n"
	"	# <super> 004D 0043"},
/* 1F16B */ { "RAISED MD SIGN","	= marque déposée\n"
	"	* used in Canada\n"
	"	x (registered sign - 00AE)\n"
	"	# <super> 004D 0044"},
/* 1F16C */ { "RAISED MR SIGN","	= marca registrada\n"
	"	* used primarily in Spanish and Portuguese speaking communities to indicate a registered trademark\n"
	"	x (registered sign - 00AE)\n"
	"	# <super> 004D 0052"},
/* 1F16D */ { "CIRCLED CC","	= Creative Commons license\n"
	"	x (circled equals - 229C)"},
/* 1F16E */ { "CIRCLED C WITH OVERLAID BACKSLASH","	= public domain"},
/* 1F16F */ { "CIRCLED HUMAN FIGURE","	= attribution, credit"},
/* 1F170 */ { "NEGATIVE SQUARED LATIN CAPITAL LETTER A","	= blood type A"},
/* 1F171 */ { "NEGATIVE SQUARED LATIN CAPITAL LETTER B","	= blood type B"},
/* 1F172 */ { "NEGATIVE SQUARED LATIN CAPITAL LETTER C","	= centre, city centre"},
/* 1F173 */ { "NEGATIVE SQUARED LATIN CAPITAL LETTER D",NULL},
/* 1F174 */ { "NEGATIVE SQUARED LATIN CAPITAL LETTER E",NULL},
/* 1F175 */ { "NEGATIVE SQUARED LATIN CAPITAL LETTER F","	= Feuerwache (fire department)"},
/* 1F176 */ { "NEGATIVE SQUARED LATIN CAPITAL LETTER G",NULL},
/* 1F177 */ { "NEGATIVE SQUARED LATIN CAPITAL LETTER H","	= Haltestelle (bus stop)\n"
	"	x (bus stop - 1F68F)"},
/* 1F178 */ { "NEGATIVE SQUARED LATIN CAPITAL LETTER I",NULL},
/* 1F179 */ { "NEGATIVE SQUARED LATIN CAPITAL LETTER J","	= junction (ARIB STD B24)"},
/* 1F17A */ { "NEGATIVE SQUARED LATIN CAPITAL LETTER K",NULL},
/* 1F17B */ { "NEGATIVE SQUARED LATIN CAPITAL LETTER L","	= leisure center (ARIB STD B24)"},
/* 1F17C */ { "NEGATIVE SQUARED LATIN CAPITAL LETTER M","	= museum, cultural center (ARIB STD B24)"},
/* 1F17D */ { "NEGATIVE SQUARED LATIN CAPITAL LETTER N",NULL},
/* 1F17E */ { "NEGATIVE SQUARED LATIN CAPITAL LETTER O","	= blood type O"},
/* 1F17F */ { "NEGATIVE SQUARED LATIN CAPITAL LETTER P","	= parking space empty-full (ARIB STD B24)"},
/* 1F180 */ { "NEGATIVE SQUARED LATIN CAPITAL LETTER Q",NULL},
/* 1F181 */ { "NEGATIVE SQUARED LATIN CAPITAL LETTER R",NULL},
/* 1F182 */ { "NEGATIVE SQUARED LATIN CAPITAL LETTER S",NULL},
/* 1F183 */ { "NEGATIVE SQUARED LATIN CAPITAL LETTER T",NULL},
/* 1F184 */ { "NEGATIVE SQUARED LATIN CAPITAL LETTER U",NULL},
/* 1F185 */ { "NEGATIVE SQUARED LATIN CAPITAL LETTER V",NULL},
/* 1F186 */ { "NEGATIVE SQUARED LATIN CAPITAL LETTER W",NULL},
/* 1F187 */ { "NEGATIVE SQUARED LATIN CAPITAL LETTER X",NULL},
/* 1F188 */ { "NEGATIVE SQUARED LATIN CAPITAL LETTER Y",NULL},
/* 1F189 */ { "NEGATIVE SQUARED LATIN CAPITAL LETTER Z",NULL},
/* 1F18A */ { "CROSSED NEGATIVE SQUARED LATIN CAPITAL LETTER P","	= parking space closed"},
/* 1F18B */ { "NEGATIVE SQUARED IC","	= interchange, ramp"},
/* 1F18C */ { "NEGATIVE SQUARED PA","	= parking area"},
/* 1F18D */ { "NEGATIVE SQUARED SA","	= service area"},
/* 1F18E */ { "NEGATIVE SQUARED AB","	= blood type AB"},
/* 1F18F */ { "NEGATIVE SQUARED WC","	= water closet, public toilet\n"
	"	x (water closet - 1F6BE)"},
/* 1F190 */ { "SQUARE DJ","	= disc jockey\n"
	"	# <square> 0044 004A"},
/* 1F191 */ { "SQUARED CL","	= clear"},
/* 1F192 */ { "SQUARED COOL",NULL},
/* 1F193 */ { "SQUARED FREE","	= free postage"},
/* 1F194 */ { "SQUARED ID","	= identification, ID"},
/* 1F195 */ { "SQUARED NEW",NULL},
/* 1F196 */ { "SQUARED NG","	= no good"},
/* 1F197 */ { "SQUARED OK",NULL},
/* 1F198 */ { "SQUARED SOS","	= search, hunt for missing person"},
/* 1F199 */ { "SQUARED UP WITH EXCLAMATION MARK","	= new information, update"},
/* 1F19A */ { "SQUARED VS","	= versus"},
/* 1F19B */ { "SQUARED THREE D",NULL},
/* 1F19C */ { "SQUARED SECOND SCREEN",NULL},
/* 1F19D */ { "SQUARED TWO K",NULL},
/* 1F19E */ { "SQUARED FOUR K",NULL},
/* 1F19F */ { "SQUARED EIGHT K",NULL},
/* 1F1A0 */ { "SQUARED FIVE POINT ONE","	* denotes 5.1-channel surround sound"},
/* 1F1A1 */ { "SQUARED SEVEN POINT ONE","	* denotes 7.1-channel surround sound"},
/* 1F1A2 */ { "SQUARED TWENTY-TWO POINT TWO","	* denotes 22.2-channel surround sound"},
/* 1F1A3 */ { "SQUARED SIXTY P","	* denotes 60Hz frame rate with progressive scanning"},
/* 1F1A4 */ { "SQUARED ONE HUNDRED TWENTY P","	* denotes 120Hz frame rate with progressive scanning"},
/* 1F1A5 */ { "SQUARED LATIN SMALL LETTER D","	= data"},
/* 1F1A6 */ { "SQUARED HC","	= hybrid cast"},
/* 1F1A7 */ { "SQUARED HDR","	= high dynamic range"},
/* 1F1A8 */ { "SQUARED HI-RES","	= high resolution"},
/* 1F1A9 */ { "SQUARED LOSSLESS",NULL},
/* 1F1AA */ { "SQUARED SHV","	= super high vision"},
/* 1F1AB */ { "SQUARED UHD","	= ultra-high definition"},
/* 1F1AC */ { "SQUARED VOD","	= video on demand"},
/* 1F1AD */ { "MASK WORK SYMBOL","	* indicates intellectual property protection for integrated circuit layouts\n"
	"	x (copyright sign - 00A9)\n"
	"	x (circled latin capital letter m - 24C2)"},
/* 1F1AE */ { NULL,NULL},
/* 1F1AF */ { NULL,NULL},
/* 1F1B0 */ { NULL,NULL},
/* 1F1B1 */ { NULL,NULL},
/* 1F1B2 */ { NULL,NULL},
/* 1F1B3 */ { NULL,NULL},
/* 1F1B4 */ { NULL,NULL},
/* 1F1B5 */ { NULL,NULL},
/* 1F1B6 */ { NULL,NULL},
/* 1F1B7 */ { NULL,NULL},
/* 1F1B8 */ { NULL,NULL},
/* 1F1B9 */ { NULL,NULL},
/* 1F1BA */ { NULL,NULL},
/* 1F1BB */ { NULL,NULL},
/* 1F1BC */ { NULL,NULL},
/* 1F1BD */ { NULL,NULL},
/* 1F1BE */ { NULL,NULL},
/* 1F1BF */ { NULL,NULL},
/* 1F1C0 */ { NULL,NULL},
/* 1F1C1 */ { NULL,NULL},
/* 1F1C2 */ { NULL,NULL},
/* 1F1C3 */ { NULL,NULL},
/* 1F1C4 */ { NULL,NULL},
/* 1F1C5 */ { NULL,NULL},
/* 1F1C6 */ { NULL,NULL},
/* 1F1C7 */ { NULL,NULL},
/* 1F1C8 */ { NULL,NULL},
/* 1F1C9 */ { NULL,NULL},
/* 1F1CA */ { NULL,NULL},
/* 1F1CB */ { NULL,NULL},
/* 1F1CC */ { NULL,NULL},
/* 1F1CD */ { NULL,NULL},
/* 1F1CE */ { NULL,NULL},
/* 1F1CF */ { NULL,NULL},
/* 1F1D0 */ { NULL,NULL},
/* 1F1D1 */ { NULL,NULL},
/* 1F1D2 */ { NULL,NULL},
/* 1F1D3 */ { NULL,NULL},
/* 1F1D4 */ { NULL,NULL},
/* 1F1D5 */ { NULL,NULL},
/* 1F1D6 */ { NULL,NULL},
/* 1F1D7 */ { NULL,NULL},
/* 1F1D8 */ { NULL,NULL},
/* 1F1D9 */ { NULL,NULL},
/* 1F1DA */ { NULL,NULL},
/* 1F1DB */ { NULL,NULL},
/* 1F1DC */ { NULL,NULL},
/* 1F1DD */ { NULL,NULL},
/* 1F1DE */ { NULL,NULL},
/* 1F1DF */ { NULL,NULL},
/* 1F1E0 */ { NULL,NULL},
/* 1F1E1 */ { NULL,NULL},
/* 1F1E2 */ { NULL,NULL},
/* 1F1E3 */ { NULL,NULL},
/* 1F1E4 */ { NULL,NULL},
/* 1F1E5 */ { NULL,NULL},
/* 1F1E6 */ { "REGIONAL INDICATOR SYMBOL LETTER A",NULL},
/* 1F1E7 */ { "REGIONAL INDICATOR SYMBOL LETTER B",NULL},
/* 1F1E8 */ { "REGIONAL INDICATOR SYMBOL LETTER C",NULL},
/* 1F1E9 */ { "REGIONAL INDICATOR SYMBOL LETTER D",NULL},
/* 1F1EA */ { "REGIONAL INDICATOR SYMBOL LETTER E",NULL},
/* 1F1EB */ { "REGIONAL INDICATOR SYMBOL LETTER F",NULL},
/* 1F1EC */ { "REGIONAL INDICATOR SYMBOL LETTER G",NULL},
/* 1F1ED */ { "REGIONAL INDICATOR SYMBOL LETTER H",NULL},
/* 1F1EE */ { "REGIONAL INDICATOR SYMBOL LETTER I",NULL},
/* 1F1EF */ { "REGIONAL INDICATOR SYMBOL LETTER J",NULL},
/* 1F1F0 */ { "REGIONAL INDICATOR SYMBOL LETTER K",NULL},
/* 1F1F1 */ { "REGIONAL INDICATOR SYMBOL LETTER L",NULL},
/* 1F1F2 */ { "REGIONAL INDICATOR SYMBOL LETTER M",NULL},
/* 1F1F3 */ { "REGIONAL INDICATOR SYMBOL LETTER N",NULL},
/* 1F1F4 */ { "REGIONAL INDICATOR SYMBOL LETTER O",NULL},
/* 1F1F5 */ { "REGIONAL INDICATOR SYMBOL LETTER P",NULL},
/* 1F1F6 */ { "REGIONAL INDICATOR SYMBOL LETTER Q",NULL},
/* 1F1F7 */ { "REGIONAL INDICATOR SYMBOL LETTER R",NULL},
/* 1F1F8 */ { "REGIONAL INDICATOR SYMBOL LETTER S",NULL},
/* 1F1F9 */ { "REGIONAL INDICATOR SYMBOL LETTER T",NULL},
/* 1F1FA */ { "REGIONAL INDICATOR SYMBOL LETTER U",NULL},
/* 1F1FB */ { "REGIONAL INDICATOR SYMBOL LETTER V",NULL},
/* 1F1FC */ { "REGIONAL INDICATOR SYMBOL LETTER W",NULL},
/* 1F1FD */ { "REGIONAL INDICATOR SYMBOL LETTER X",NULL},
/* 1F1FE */ { "REGIONAL INDICATOR SYMBOL LETTER Y",NULL},
/* 1F1FF */ { "REGIONAL INDICATOR SYMBOL LETTER Z",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_F2[] = {
/* 1F200 */ { "SQUARE HIRAGANA HOKA","	= and others\n"
	"	# <square> 307B 304B"},
/* 1F201 */ { "SQUARED KATAKANA KOKO","	= here sign\n"
	"	# <square> 30B3 30B3"},
/* 1F202 */ { "SQUARED KATAKANA SA","	= service sign\n"
	"	x (circled katakana sa - 32DA)\n"
	"	# <square> 30B5"},
/* 1F203 */ { NULL,NULL},
/* 1F204 */ { NULL,NULL},
/* 1F205 */ { NULL,NULL},
/* 1F206 */ { NULL,NULL},
/* 1F207 */ { NULL,NULL},
/* 1F208 */ { NULL,NULL},
/* 1F209 */ { NULL,NULL},
/* 1F20A */ { NULL,NULL},
/* 1F20B */ { NULL,NULL},
/* 1F20C */ { NULL,NULL},
/* 1F20D */ { NULL,NULL},
/* 1F20E */ { NULL,NULL},
/* 1F20F */ { NULL,NULL},
/* 1F210 */ { "SQUARED CJK UNIFIED IDEOGRAPH-624B","	= broadcasting service with sign language interpretation\n"
	"	# <square> 624B"},
/* 1F211 */ { "SQUARED CJK UNIFIED IDEOGRAPH-5B57","	= close-captioned broadcasting\n"
	"	# <square> 5B57"},
/* 1F212 */ { "SQUARED CJK UNIFIED IDEOGRAPH-53CC","	= two-way broadcasting service\n"
	"	# <square> 53CC"},
/* 1F213 */ { "SQUARED KATAKANA DE","	= data broadcasting service linked with a main program\n"
	"	# <square> 30C7"},
/* 1F214 */ { "SQUARED CJK UNIFIED IDEOGRAPH-4E8C","	= bilingual broadcasting service\n"
	"	= second base\n"
	"	# <square> 4E8C"},
/* 1F215 */ { "SQUARED CJK UNIFIED IDEOGRAPH-591A","	= sound-multiplex broadcasting service\n"
	"	# <square> 591A"},
/* 1F216 */ { "SQUARED CJK UNIFIED IDEOGRAPH-89E3","	= commentary broadcasting\n"
	"	# <square> 89E3"},
/* 1F217 */ { "SQUARED CJK UNIFIED IDEOGRAPH-5929","	= weather forecast\n"
	"	# <square> 5929"},
/* 1F218 */ { "SQUARED CJK UNIFIED IDEOGRAPH-4EA4","	= traffic information\n"
	"	# <square> 4EA4"},
/* 1F219 */ { "SQUARED CJK UNIFIED IDEOGRAPH-6620","	= drama film\n"
	"	# <square> 6620"},
/* 1F21A */ { "SQUARED CJK UNIFIED IDEOGRAPH-7121","	= free broadcasting service\n"
	"	= non-existence sign\n"
	"	# <square> 7121"},
/* 1F21B */ { "SQUARED CJK UNIFIED IDEOGRAPH-6599","	= pay broadcasting service\n"
	"	# <square> 6599"},
/* 1F21C */ { "SQUARED CJK UNIFIED IDEOGRAPH-524D","	= the first part\n"
	"	# <square> 524D"},
/* 1F21D */ { "SQUARED CJK UNIFIED IDEOGRAPH-5F8C","	= the latter part\n"
	"	# <square> 5F8C"},
/* 1F21E */ { "SQUARED CJK UNIFIED IDEOGRAPH-518D","	= rebroadcast\n"
	"	# <square> 518D"},
/* 1F21F */ { "SQUARED CJK UNIFIED IDEOGRAPH-65B0","	= new series of programs\n"
	"	# <square> 65B0"},
/* 1F220 */ { "SQUARED CJK UNIFIED IDEOGRAPH-521D","	= first released program\n"
	"	# <square> 521D"},
/* 1F221 */ { "SQUARED CJK UNIFIED IDEOGRAPH-7D42","	= the last episode\n"
	"	# <square> 7D42"},
/* 1F222 */ { "SQUARED CJK UNIFIED IDEOGRAPH-751F","	= live broadcast\n"
	"	# <square> 751F"},
/* 1F223 */ { "SQUARED CJK UNIFIED IDEOGRAPH-8CA9","	= mail-order\n"
	"	# <square> 8CA9"},
/* 1F224 */ { "SQUARED CJK UNIFIED IDEOGRAPH-58F0","	= voice actors\n"
	"	# <square> 58F0"},
/* 1F225 */ { "SQUARED CJK UNIFIED IDEOGRAPH-5439","	= dubbed version\n"
	"	# <square> 5439"},
/* 1F226 */ { "SQUARED CJK UNIFIED IDEOGRAPH-6F14","	= performed by\n"
	"	# <square> 6F14"},
/* 1F227 */ { "SQUARED CJK UNIFIED IDEOGRAPH-6295","	= pitcher\n"
	"	# <square> 6295"},
/* 1F228 */ { "SQUARED CJK UNIFIED IDEOGRAPH-6355","	= catcher\n"
	"	# <square> 6355"},
/* 1F229 */ { "SQUARED CJK UNIFIED IDEOGRAPH-4E00","	= first base\n"
	"	# <square> 4E00"},
/* 1F22A */ { "SQUARED CJK UNIFIED IDEOGRAPH-4E09","	= third base\n"
	"	# <square> 4E09"},
/* 1F22B */ { "SQUARED CJK UNIFIED IDEOGRAPH-904A","	= short stop\n"
	"	# <square> 904A"},
/* 1F22C */ { "SQUARED CJK UNIFIED IDEOGRAPH-5DE6","	= left field\n"
	"	# <square> 5DE6"},
/* 1F22D */ { "SQUARED CJK UNIFIED IDEOGRAPH-4E2D","	= center field\n"
	"	# <square> 4E2D"},
/* 1F22E */ { "SQUARED CJK UNIFIED IDEOGRAPH-53F3","	= right field\n"
	"	# <square> 53F3"},
/* 1F22F */ { "SQUARED CJK UNIFIED IDEOGRAPH-6307","	= designated hitter\n"
	"	= reserved sign\n"
	"	# <square> 6307"},
/* 1F230 */ { "SQUARED CJK UNIFIED IDEOGRAPH-8D70","	= runner\n"
	"	# <square> 8D70"},
/* 1F231 */ { "SQUARED CJK UNIFIED IDEOGRAPH-6253","	= batter\n"
	"	# <square> 6253"},
/* 1F232 */ { "SQUARED CJK UNIFIED IDEOGRAPH-7981","	= prohibited sign\n"
	"	# <square> 7981"},
/* 1F233 */ { "SQUARED CJK UNIFIED IDEOGRAPH-7A7A","	= empty sign\n"
	"	# <square> 7A7A"},
/* 1F234 */ { "SQUARED CJK UNIFIED IDEOGRAPH-5408","	= passed sign\n"
	"	# <square> 5408"},
/* 1F235 */ { "SQUARED CJK UNIFIED IDEOGRAPH-6E80","	= full sign\n"
	"	# <square> 6E80"},
/* 1F236 */ { "SQUARED CJK UNIFIED IDEOGRAPH-6709","	= existence sign\n"
	"	x (circled ideograph have - 3292)\n"
	"	# <square> 6709"},
/* 1F237 */ { "SQUARED CJK UNIFIED IDEOGRAPH-6708","	= monthly sign\n"
	"	x (circled ideograph moon - 328A)\n"
	"	# <square> 6708"},
/* 1F238 */ { "SQUARED CJK UNIFIED IDEOGRAPH-7533","	= application sign\n"
	"	# <square> 7533"},
/* 1F239 */ { "SQUARED CJK UNIFIED IDEOGRAPH-5272","	= discount sign\n"
	"	# <square> 5272"},
/* 1F23A */ { "SQUARED CJK UNIFIED IDEOGRAPH-55B6","	= in business sign\n"
	"	# <square> 55B6"},
/* 1F23B */ { "SQUARED CJK UNIFIED IDEOGRAPH-914D","	= program delivery over network (ARIB STD B62)\n"
	"	# <square> 914D"},
/* 1F23C */ { NULL,NULL},
/* 1F23D */ { NULL,NULL},
/* 1F23E */ { NULL,NULL},
/* 1F23F */ { NULL,NULL},
/* 1F240 */ { "TORTOISE SHELL BRACKETED CJK UNIFIED IDEOGRAPH-672C","	= home run\n"
	"	# 3014 672C 3015"},
/* 1F241 */ { "TORTOISE SHELL BRACKETED CJK UNIFIED IDEOGRAPH-4E09","	= triple\n"
	"	# 3014 4E09 3015"},
/* 1F242 */ { "TORTOISE SHELL BRACKETED CJK UNIFIED IDEOGRAPH-4E8C","	= double\n"
	"	# 3014 4E8C 3015"},
/* 1F243 */ { "TORTOISE SHELL BRACKETED CJK UNIFIED IDEOGRAPH-5B89","	= safe\n"
	"	# 3014 5B89 3015"},
/* 1F244 */ { "TORTOISE SHELL BRACKETED CJK UNIFIED IDEOGRAPH-70B9","	= run\n"
	"	# 3014 70B9 3015"},
/* 1F245 */ { "TORTOISE SHELL BRACKETED CJK UNIFIED IDEOGRAPH-6253","	= hit\n"
	"	# 3014 6253 3015"},
/* 1F246 */ { "TORTOISE SHELL BRACKETED CJK UNIFIED IDEOGRAPH-76D7","	= steal\n"
	"	# 3014 76D7 3015"},
/* 1F247 */ { "TORTOISE SHELL BRACKETED CJK UNIFIED IDEOGRAPH-52DD","	= win\n"
	"	# 3014 52DD 3015"},
/* 1F248 */ { "TORTOISE SHELL BRACKETED CJK UNIFIED IDEOGRAPH-6557","	= loss\n"
	"	# 3014 6557 3015"},
/* 1F249 */ { NULL,NULL},
/* 1F24A */ { NULL,NULL},
/* 1F24B */ { NULL,NULL},
/* 1F24C */ { NULL,NULL},
/* 1F24D */ { NULL,NULL},
/* 1F24E */ { NULL,NULL},
/* 1F24F */ { NULL,NULL},
/* 1F250 */ { "CIRCLED IDEOGRAPH ADVANTAGE","	= advantage sign\n"
	"	# <circle> 5F97"},
/* 1F251 */ { "CIRCLED IDEOGRAPH ACCEPT","	= accept sign\n"
	"	# <circle> 53EF"},
/* 1F252 */ { NULL,NULL},
/* 1F253 */ { NULL,NULL},
/* 1F254 */ { NULL,NULL},
/* 1F255 */ { NULL,NULL},
/* 1F256 */ { NULL,NULL},
/* 1F257 */ { NULL,NULL},
/* 1F258 */ { NULL,NULL},
/* 1F259 */ { NULL,NULL},
/* 1F25A */ { NULL,NULL},
/* 1F25B */ { NULL,NULL},
/* 1F25C */ { NULL,NULL},
/* 1F25D */ { NULL,NULL},
/* 1F25E */ { NULL,NULL},
/* 1F25F */ { NULL,NULL},
/* 1F260 */ { "ROUNDED SYMBOL FOR FU","	* luck\n"
	"	x 798F"},
/* 1F261 */ { "ROUNDED SYMBOL FOR LU","	* prosperity\n"
	"	x 797F\n"
	"	x 7984"},
/* 1F262 */ { "ROUNDED SYMBOL FOR SHOU","	* longevity\n"
	"	x 58FD\n"
	"	x 5BFF"},
/* 1F263 */ { "ROUNDED SYMBOL FOR XI","	* happiness\n"
	"	x 559C"},
/* 1F264 */ { "ROUNDED SYMBOL FOR SHUANGXI","	* double happiness, love and marriage\n"
	"	x 56CD"},
/* 1F265 */ { "ROUNDED SYMBOL FOR CAI","	* wealth\n"
	"	x 8CA1\n"
	"	x 8D22"},
/* 1F266 */ { NULL,NULL},
/* 1F267 */ { NULL,NULL},
/* 1F268 */ { NULL,NULL},
/* 1F269 */ { NULL,NULL},
/* 1F26A */ { NULL,NULL},
/* 1F26B */ { NULL,NULL},
/* 1F26C */ { NULL,NULL},
/* 1F26D */ { NULL,NULL},
/* 1F26E */ { NULL,NULL},
/* 1F26F */ { NULL,NULL},
/* 1F270 */ { NULL,NULL},
/* 1F271 */ { NULL,NULL},
/* 1F272 */ { NULL,NULL},
/* 1F273 */ { NULL,NULL},
/* 1F274 */ { NULL,NULL},
/* 1F275 */ { NULL,NULL},
/* 1F276 */ { NULL,NULL},
/* 1F277 */ { NULL,NULL},
/* 1F278 */ { NULL,NULL},
/* 1F279 */ { NULL,NULL},
/* 1F27A */ { NULL,NULL},
/* 1F27B */ { NULL,NULL},
/* 1F27C */ { NULL,NULL},
/* 1F27D */ { NULL,NULL},
/* 1F27E */ { NULL,NULL},
/* 1F27F */ { NULL,NULL},
/* 1F280 */ { NULL,NULL},
/* 1F281 */ { NULL,NULL},
/* 1F282 */ { NULL,NULL},
/* 1F283 */ { NULL,NULL},
/* 1F284 */ { NULL,NULL},
/* 1F285 */ { NULL,NULL},
/* 1F286 */ { NULL,NULL},
/* 1F287 */ { NULL,NULL},
/* 1F288 */ { NULL,NULL},
/* 1F289 */ { NULL,NULL},
/* 1F28A */ { NULL,NULL},
/* 1F28B */ { NULL,NULL},
/* 1F28C */ { NULL,NULL},
/* 1F28D */ { NULL,NULL},
/* 1F28E */ { NULL,NULL},
/* 1F28F */ { NULL,NULL},
/* 1F290 */ { NULL,NULL},
/* 1F291 */ { NULL,NULL},
/* 1F292 */ { NULL,NULL},
/* 1F293 */ { NULL,NULL},
/* 1F294 */ { NULL,NULL},
/* 1F295 */ { NULL,NULL},
/* 1F296 */ { NULL,NULL},
/* 1F297 */ { NULL,NULL},
/* 1F298 */ { NULL,NULL},
/* 1F299 */ { NULL,NULL},
/* 1F29A */ { NULL,NULL},
/* 1F29B */ { NULL,NULL},
/* 1F29C */ { NULL,NULL},
/* 1F29D */ { NULL,NULL},
/* 1F29E */ { NULL,NULL},
/* 1F29F */ { NULL,NULL},
/* 1F2A0 */ { NULL,NULL},
/* 1F2A1 */ { NULL,NULL},
/* 1F2A2 */ { NULL,NULL},
/* 1F2A3 */ { NULL,NULL},
/* 1F2A4 */ { NULL,NULL},
/* 1F2A5 */ { NULL,NULL},
/* 1F2A6 */ { NULL,NULL},
/* 1F2A7 */ { NULL,NULL},
/* 1F2A8 */ { NULL,NULL},
/* 1F2A9 */ { NULL,NULL},
/* 1F2AA */ { NULL,NULL},
/* 1F2AB */ { NULL,NULL},
/* 1F2AC */ { NULL,NULL},
/* 1F2AD */ { NULL,NULL},
/* 1F2AE */ { NULL,NULL},
/* 1F2AF */ { NULL,NULL},
/* 1F2B0 */ { NULL,NULL},
/* 1F2B1 */ { NULL,NULL},
/* 1F2B2 */ { NULL,NULL},
/* 1F2B3 */ { NULL,NULL},
/* 1F2B4 */ { NULL,NULL},
/* 1F2B5 */ { NULL,NULL},
/* 1F2B6 */ { NULL,NULL},
/* 1F2B7 */ { NULL,NULL},
/* 1F2B8 */ { NULL,NULL},
/* 1F2B9 */ { NULL,NULL},
/* 1F2BA */ { NULL,NULL},
/* 1F2BB */ { NULL,NULL},
/* 1F2BC */ { NULL,NULL},
/* 1F2BD */ { NULL,NULL},
/* 1F2BE */ { NULL,NULL},
/* 1F2BF */ { NULL,NULL},
/* 1F2C0 */ { NULL,NULL},
/* 1F2C1 */ { NULL,NULL},
/* 1F2C2 */ { NULL,NULL},
/* 1F2C3 */ { NULL,NULL},
/* 1F2C4 */ { NULL,NULL},
/* 1F2C5 */ { NULL,NULL},
/* 1F2C6 */ { NULL,NULL},
/* 1F2C7 */ { NULL,NULL},
/* 1F2C8 */ { NULL,NULL},
/* 1F2C9 */ { NULL,NULL},
/* 1F2CA */ { NULL,NULL},
/* 1F2CB */ { NULL,NULL},
/* 1F2CC */ { NULL,NULL},
/* 1F2CD */ { NULL,NULL},
/* 1F2CE */ { NULL,NULL},
/* 1F2CF */ { NULL,NULL},
/* 1F2D0 */ { NULL,NULL},
/* 1F2D1 */ { NULL,NULL},
/* 1F2D2 */ { NULL,NULL},
/* 1F2D3 */ { NULL,NULL},
/* 1F2D4 */ { NULL,NULL},
/* 1F2D5 */ { NULL,NULL},
/* 1F2D6 */ { NULL,NULL},
/* 1F2D7 */ { NULL,NULL},
/* 1F2D8 */ { NULL,NULL},
/* 1F2D9 */ { NULL,NULL},
/* 1F2DA */ { NULL,NULL},
/* 1F2DB */ { NULL,NULL},
/* 1F2DC */ { NULL,NULL},
/* 1F2DD */ { NULL,NULL},
/* 1F2DE */ { NULL,NULL},
/* 1F2DF */ { NULL,NULL},
/* 1F2E0 */ { NULL,NULL},
/* 1F2E1 */ { NULL,NULL},
/* 1F2E2 */ { NULL,NULL},
/* 1F2E3 */ { NULL,NULL},
/* 1F2E4 */ { NULL,NULL},
/* 1F2E5 */ { NULL,NULL},
/* 1F2E6 */ { NULL,NULL},
/* 1F2E7 */ { NULL,NULL},
/* 1F2E8 */ { NULL,NULL},
/* 1F2E9 */ { NULL,NULL},
/* 1F2EA */ { NULL,NULL},
/* 1F2EB */ { NULL,NULL},
/* 1F2EC */ { NULL,NULL},
/* 1F2ED */ { NULL,NULL},
/* 1F2EE */ { NULL,NULL},
/* 1F2EF */ { NULL,NULL},
/* 1F2F0 */ { NULL,NULL},
/* 1F2F1 */ { NULL,NULL},
/* 1F2F2 */ { NULL,NULL},
/* 1F2F3 */ { NULL,NULL},
/* 1F2F4 */ { NULL,NULL},
/* 1F2F5 */ { NULL,NULL},
/* 1F2F6 */ { NULL,NULL},
/* 1F2F7 */ { NULL,NULL},
/* 1F2F8 */ { NULL,NULL},
/* 1F2F9 */ { NULL,NULL},
/* 1F2FA */ { NULL,NULL},
/* 1F2FB */ { NULL,NULL},
/* 1F2FC */ { NULL,NULL},
/* 1F2FD */ { NULL,NULL},
/* 1F2FE */ { NULL,NULL},
/* 1F2FF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_F3[] = {
/* 1F300 */ { "CYCLONE","	= typhoon, hurricane"},
/* 1F301 */ { "FOGGY","	x (fog - 1F32B)"},
/* 1F302 */ { "CLOSED UMBRELLA",NULL},
/* 1F303 */ { "NIGHT WITH STARS",NULL},
/* 1F304 */ { "SUNRISE OVER MOUNTAINS",NULL},
/* 1F305 */ { "SUNRISE",NULL},
/* 1F306 */ { "CITYSCAPE AT DUSK","	x (cityscape - 1F3D9)"},
/* 1F307 */ { "SUNSET OVER BUILDINGS",NULL},
/* 1F308 */ { "RAINBOW",NULL},
/* 1F309 */ { "BRIDGE AT NIGHT",NULL},
/* 1F30A */ { "WATER WAVE","	= tsunami, tidal wave"},
/* 1F30B */ { "VOLCANO",NULL},
/* 1F30C */ { "MILKY WAY",NULL},
/* 1F30D */ { "EARTH GLOBE EUROPE-AFRICA",NULL},
/* 1F30E */ { "EARTH GLOBE AMERICAS",NULL},
/* 1F30F */ { "EARTH GLOBE ASIA-AUSTRALIA",NULL},
/* 1F310 */ { "GLOBE WITH MERIDIANS","	* used to indicate international input source, world clocks with time zones, etc."},
/* 1F311 */ { "NEW MOON SYMBOL","	x (black circle - 25CF)"},
/* 1F312 */ { "WAXING CRESCENT MOON SYMBOL",NULL},
/* 1F313 */ { "FIRST QUARTER MOON SYMBOL","	= half moon\n"
	"	x (circle with left half black - 25D0)\n"
	"	x (first quarter moon - 263D)"},
/* 1F314 */ { "WAXING GIBBOUS MOON SYMBOL","	= waxing moon"},
/* 1F315 */ { "FULL MOON SYMBOL","	x (white circle - 25CB)"},
/* 1F316 */ { "WANING GIBBOUS MOON SYMBOL",NULL},
/* 1F317 */ { "LAST QUARTER MOON SYMBOL","	x (circle with right half black - 25D1)\n"
	"	x (last quarter moon - 263E)"},
/* 1F318 */ { "WANING CRESCENT MOON SYMBOL",NULL},
/* 1F319 */ { "CRESCENT MOON","	* may indicate either the first or last quarter moon\n"
	"	x (first quarter moon - 263D)\n"
	"	x (last quarter moon - 263E)"},
/* 1F31A */ { "NEW MOON WITH FACE",NULL},
/* 1F31B */ { "FIRST QUARTER MOON WITH FACE",NULL},
/* 1F31C */ { "LAST QUARTER MOON WITH FACE",NULL},
/* 1F31D */ { "FULL MOON WITH FACE",NULL},
/* 1F31E */ { "SUN WITH FACE",NULL},
/* 1F31F */ { "GLOWING STAR","	x (white star - 2606)"},
/* 1F320 */ { "SHOOTING STAR",NULL},
/* 1F321 */ { "THERMOMETER","	= temperature, warm"},
/* 1F322 */ { "BLACK DROPLET","	= droplet\n"
	"	x (droplet - 1F4A7)"},
/* 1F323 */ { "WHITE SUN","	= sunny\n"
	"	x (black sun with rays - 2600)\n"
	"	x (white sun with rays - 263C)"},
/* 1F324 */ { "WHITE SUN WITH SMALL CLOUD","	= mostly sunny\n"
	"	x (sun behind cloud - 26C5)"},
/* 1F325 */ { "WHITE SUN BEHIND CLOUD","	= mostly cloudy"},
/* 1F326 */ { "WHITE SUN BEHIND CLOUD WITH RAIN","	= showers"},
/* 1F327 */ { "CLOUD WITH RAIN","	= rain\n"
	"	x (umbrella - 2602)"},
/* 1F328 */ { "CLOUD WITH SNOW","	= snow, snow showers"},
/* 1F329 */ { "CLOUD WITH LIGHTNING","	= lightning, thunderstorm\n"
	"	x (thunder cloud and rain - 26C8)"},
/* 1F32A */ { "CLOUD WITH TORNADO","	= tornado, twister"},
/* 1F32B */ { "FOG","	x (foggy - 1F301)"},
/* 1F32C */ { "WIND BLOWING FACE","	= wind"},
/* 1F32D */ { "HOT DOG",NULL},
/* 1F32E */ { "TACO",NULL},
/* 1F32F */ { "BURRITO",NULL},
/* 1F330 */ { "CHESTNUT",NULL},
/* 1F331 */ { "SEEDLING",NULL},
/* 1F332 */ { "EVERGREEN TREE","	x (national park - 1F3DE)"},
/* 1F333 */ { "DECIDUOUS TREE","	x (tree symbol - 1CEBC)"},
/* 1F334 */ { "PALM TREE","	x (desert island - 1F3DD)"},
/* 1F335 */ { "CACTUS","	x (desert - 1F3DC)"},
/* 1F336 */ { "HOT PEPPER","	= hot, spicy"},
/* 1F337 */ { "TULIP","	x (flower - 2698)"},
/* 1F338 */ { "CHERRY BLOSSOM",NULL},
/* 1F339 */ { "ROSE","	x (wilted flower - 1F940)"},
/* 1F33A */ { "HIBISCUS",NULL},
/* 1F33B */ { "SUNFLOWER",NULL},
/* 1F33C */ { "BLOSSOM","	= daisy"},
/* 1F33D */ { "EAR OF MAIZE",NULL},
/* 1F33E */ { "EAR OF RICE",NULL},
/* 1F33F */ { "HERB",NULL},
/* 1F340 */ { "FOUR LEAF CLOVER","	x (shamrock - 2618)"},
/* 1F341 */ { "MAPLE LEAF",NULL},
/* 1F342 */ { "FALLEN LEAF",NULL},
/* 1F343 */ { "LEAF FLUTTERING IN WIND",NULL},
/* 1F344 */ { "MUSHROOM",NULL},
/* 1F345 */ { "TOMATO",NULL},
/* 1F346 */ { "AUBERGINE","	= eggplant"},
/* 1F347 */ { "GRAPES",NULL},
/* 1F348 */ { "MELON",NULL},
/* 1F349 */ { "WATERMELON",NULL},
/* 1F34A */ { "TANGERINE",NULL},
/* 1F34B */ { "LEMON",NULL},
/* 1F34C */ { "BANANA",NULL},
/* 1F34D */ { "PINEAPPLE",NULL},
/* 1F34E */ { "RED APPLE","	x (apple symbol - 1CEBD)"},
/* 1F34F */ { "GREEN APPLE",NULL},
/* 1F350 */ { "PEAR",NULL},
/* 1F351 */ { "PEACH",NULL},
/* 1F352 */ { "CHERRIES","	x (cherry symbol - 1CEBE)"},
/* 1F353 */ { "STRAWBERRY","	x (strawberry symbol - 1CEBF)"},
/* 1F354 */ { "HAMBURGER","	= fast food place"},
/* 1F355 */ { "SLICE OF PIZZA",NULL},
/* 1F356 */ { "MEAT ON BONE",NULL},
/* 1F357 */ { "POULTRY LEG",NULL},
/* 1F358 */ { "RICE CRACKER",NULL},
/* 1F359 */ { "RICE BALL",NULL},
/* 1F35A */ { "COOKED RICE","	= bowl of rice"},
/* 1F35B */ { "CURRY AND RICE","	= Japanese style curry"},
/* 1F35C */ { "STEAMING BOWL","	= ramen noodles"},
/* 1F35D */ { "SPAGHETTI",NULL},
/* 1F35E */ { "BREAD",NULL},
/* 1F35F */ { "FRENCH FRIES",NULL},
/* 1F360 */ { "ROASTED SWEET POTATO",NULL},
/* 1F361 */ { "DANGO","	= mochi balls on skewer"},
/* 1F362 */ { "ODEN","	= seafood on skewer"},
/* 1F363 */ { "SUSHI",NULL},
/* 1F364 */ { "FRIED SHRIMP",NULL},
/* 1F365 */ { "FISH CAKE WITH SWIRL DESIGN",NULL},
/* 1F366 */ { "SOFT ICE CREAM",NULL},
/* 1F367 */ { "SHAVED ICE",NULL},
/* 1F368 */ { "ICE CREAM",NULL},
/* 1F369 */ { "DOUGHNUT",NULL},
/* 1F36A */ { "COOKIE","	= biscuit"},
/* 1F36B */ { "CHOCOLATE BAR",NULL},
/* 1F36C */ { "CANDY",NULL},
/* 1F36D */ { "LOLLIPOP",NULL},
/* 1F36E */ { "CUSTARD",NULL},
/* 1F36F */ { "HONEY POT",NULL},
/* 1F370 */ { "SHORTCAKE",NULL},
/* 1F371 */ { "BENTO BOX",NULL},
/* 1F372 */ { "POT OF FOOD",NULL},
/* 1F373 */ { "COOKING","	= frying pan, cooking utensil"},
/* 1F374 */ { "FORK AND KNIFE","	= restaurant, meal\n"
	"	* glyph may show a fork and spoon\n"
	"	* glyph may show a crossed fork and knife\n"
	"	x (fork and knife with plate - 1F37D)\n"
	"	x (spoon - 1F944)"},
/* 1F375 */ { "TEACUP WITHOUT HANDLE","	x (hot beverage - 2615)\n"
	"	x (cup on black square - 26FE)"},
/* 1F376 */ { "SAKE BOTTLE AND CUP",NULL},
/* 1F377 */ { "WINE GLASS","	x (fragile symbol - 1CEBA)"},
/* 1F378 */ { "COCKTAIL GLASS","	= lounge\n"
	"	x (couch and lamp - 1F6CB)\n"
	"	x (tumbler glass - 1F943)"},
/* 1F379 */ { "TROPICAL DRINK",NULL},
/* 1F37A */ { "BEER MUG",NULL},
/* 1F37B */ { "CLINKING BEER MUGS","	= cheers\n"
	"	x (clinking glasses - 1F942)"},
/* 1F37C */ { "BABY BOTTLE",NULL},
/* 1F37D */ { "FORK AND KNIFE WITH PLATE","	= dining\n"
	"	x (fork and knife - 1F374)"},
/* 1F37E */ { "BOTTLE WITH POPPING CORK",NULL},
/* 1F37F */ { "POPCORN",NULL},
/* 1F380 */ { "RIBBON",NULL},
/* 1F381 */ { "WRAPPED PRESENT","	x (package - 1F4E6)"},
/* 1F382 */ { "BIRTHDAY CAKE",NULL},
/* 1F383 */ { "JACK-O-LANTERN","	= Halloween"},
/* 1F384 */ { "CHRISTMAS TREE",NULL},
/* 1F385 */ { "FATHER CHRISTMAS","	= Santa Claus\n"
	"	x (mother christmas - 1F936)"},
/* 1F386 */ { "FIREWORKS",NULL},
/* 1F387 */ { "FIREWORK SPARKLER","	* long, stick-like firework that looks like a burning incense stick"},
/* 1F388 */ { "BALLOON",NULL},
/* 1F389 */ { "PARTY POPPER",NULL},
/* 1F38A */ { "CONFETTI BALL","	= congratulations"},
/* 1F38B */ { "TANABATA TREE","	= tanabata tree with wishing papers"},
/* 1F38C */ { "CROSSED FLAGS","	* Japanese national holiday"},
/* 1F38D */ { "PINE DECORATION","	* Japanese new year's door decoration"},
/* 1F38E */ { "JAPANESE DOLLS","	* Japanese Hinamatsuri or girls' doll festival"},
/* 1F38F */ { "CARP STREAMER",NULL},
/* 1F390 */ { "WIND CHIME",NULL},
/* 1F391 */ { "MOON VIEWING CEREMONY","	* Japanese Otsukimi harvest celebration"},
/* 1F392 */ { "SCHOOL SATCHEL","	* Japanese school entrance ceremony"},
/* 1F393 */ { "GRADUATION CAP","	= mortarboard, education\n"
	"	* graduation ceremony"},
/* 1F394 */ { "HEART WITH TIP ON THE LEFT","	= favorite\n"
	"	x (black heart suit - 2665)"},
/* 1F395 */ { "BOUQUET OF FLOWERS","	= occasion\n"
	"	x (bouquet - 1F490)"},
/* 1F396 */ { "MILITARY MEDAL",NULL},
/* 1F397 */ { "REMINDER RIBBON",NULL},
/* 1F398 */ { "MUSICAL KEYBOARD WITH JACKS","	= midi, midi keyboard, master keyboard with plugs\n"
	"	x (musical keyboard - 1F3B9)"},
/* 1F399 */ { "STUDIO MICROPHONE","	= microphone\n"
	"	x (microphone - 1F3A4)"},
/* 1F39A */ { "LEVEL SLIDER","	= level control"},
/* 1F39B */ { "CONTROL KNOBS","	= audio control"},
/* 1F39C */ { "BEAMED ASCENDING MUSICAL NOTES","	= musical performance\n"
	"	= music, musical background\n"
	"	* always ascending, unlike 266C\n"
	"	x (beamed sixteenth notes - 266C)"},
/* 1F39D */ { "BEAMED DESCENDING MUSICAL NOTES","	* always descending, unlike 266C\n"
	"	x (beamed eighth notes - 266B)"},
/* 1F39E */ { "FILM FRAMES","	= film clip\n"
	"	x (movie camera - 1F3A5)"},
/* 1F39F */ { "ADMISSION TICKETS","	= ticket\n"
	"	x (ticket - 1F3AB)"},
/* 1F3A0 */ { "CAROUSEL HORSE","	= amusement park"},
/* 1F3A1 */ { "FERRIS WHEEL","	= amusement park"},
/* 1F3A2 */ { "ROLLER COASTER",NULL},
/* 1F3A3 */ { "FISHING POLE AND FISH","	= fishing"},
/* 1F3A4 */ { "MICROPHONE","	= karaoke\n"
	"	x (studio microphone - 1F399)"},
/* 1F3A5 */ { "MOVIE CAMERA","	= film, movies\n"
	"	x (film frames - 1F39E)"},
/* 1F3A6 */ { "CINEMA","	= movie theater, movie projector\n"
	"	x (film projector - 1F4FD)"},
/* 1F3A7 */ { "HEADPHONE","	= music"},
/* 1F3A8 */ { "ARTIST PALETTE","	= art"},
/* 1F3A9 */ { "TOP HAT","	= drama, performing arts, theater"},
/* 1F3AA */ { "CIRCUS TENT","	= event"},
/* 1F3AB */ { "TICKET","	* indicates an event\n"
	"	x (admission tickets - 1F39F)"},
/* 1F3AC */ { "CLAPPER BOARD","	= film"},
/* 1F3AD */ { "PERFORMING ARTS","	= theater masks, theater"},
/* 1F3AE */ { "VIDEO GAME","	= video game controller"},
/* 1F3AF */ { "DIRECT HIT","	= archery target, hitting the target\n"
	"	x (bullseye - 25CE)"},
/* 1F3B0 */ { "SLOT MACHINE",NULL},
/* 1F3B1 */ { "BILLIARDS","	= magic 8-ball"},
/* 1F3B2 */ { "GAME DIE",NULL},
/* 1F3B3 */ { "BOWLING",NULL},
/* 1F3B4 */ { "FLOWER PLAYING CARDS","	= flower cards"},
/* 1F3B5 */ { "MUSICAL NOTE","	= music, being in good mood\n"
	"	x (eighth note - 266A)"},
/* 1F3B6 */ { "MULTIPLE MUSICAL NOTES","	= dancing notes, mood, melody\n"
	"	x (beamed eighth notes - 266B)"},
/* 1F3B7 */ { "SAXOPHONE",NULL},
/* 1F3B8 */ { "GUITAR",NULL},
/* 1F3B9 */ { "MUSICAL KEYBOARD","	x (musical keyboard with jacks - 1F398)"},
/* 1F3BA */ { "TRUMPET",NULL},
/* 1F3BB */ { "VIOLIN",NULL},
/* 1F3BC */ { "MUSICAL SCORE","	x (musical symbol g clef - 1D11E)"},
/* 1F3BD */ { "RUNNING SHIRT WITH SASH","	= ekiden (Japanese)\n"
	"	* running shirt with separate sash signifies long-distance relay running\n"
	"	* symbol is generalized to represent athletics\n"
	"	* glyph may be shown with a sash, a stripe, or neither"},
/* 1F3BE */ { "TENNIS RACQUET AND BALL","	= tennis"},
/* 1F3BF */ { "SKI AND SKI BOOT","	= skiing\n"
	"	x (skier - 26F7)"},
/* 1F3C0 */ { "BASKETBALL AND HOOP","	= basketball"},
/* 1F3C1 */ { "CHEQUERED FLAG","	= motor sports"},
/* 1F3C2 */ { "SNOWBOARDER",NULL},
/* 1F3C3 */ { "RUNNER","	= running, marathon, track and fields\n"
	"	x (left half running man - 1FBB2)"},
/* 1F3C4 */ { "SURFER","	= surfing"},
/* 1F3C5 */ { "SPORTS MEDAL","	x (first place medal - 1F947)"},
/* 1F3C6 */ { "TROPHY",NULL},
/* 1F3C7 */ { "HORSE RACING",NULL},
/* 1F3C8 */ { "AMERICAN FOOTBALL",NULL},
/* 1F3C9 */ { "RUGBY FOOTBALL",NULL},
/* 1F3CA */ { "SWIMMER",NULL},
/* 1F3CB */ { "WEIGHT LIFTER","	= health"},
/* 1F3CC */ { "GOLFER",NULL},
/* 1F3CD */ { "RACING MOTORCYCLE","	= motorcycle\n"
	"	* may be depicted as an ordinary motorcycle, especially in emoji presentation"},
/* 1F3CE */ { "RACING CAR","	= race car"},
/* 1F3CF */ { "CRICKET BAT AND BALL",NULL},
/* 1F3D0 */ { "VOLLEYBALL",NULL},
/* 1F3D1 */ { "FIELD HOCKEY STICK AND BALL",NULL},
/* 1F3D2 */ { "ICE HOCKEY STICK AND PUCK",NULL},
/* 1F3D3 */ { "TABLE TENNIS PADDLE AND BALL",NULL},
/* 1F3D4 */ { "SNOW CAPPED MOUNTAIN","	x (mountain - 26F0)"},
/* 1F3D5 */ { "CAMPING","	= camping site\n"
	"	x (tent - 26FA)"},
/* 1F3D6 */ { "BEACH WITH UMBRELLA","	x (umbrella on ground - 26F1)"},
/* 1F3D7 */ { "BUILDING CONSTRUCTION","	= under construction\n"
	"	x (construction sign - 1F6A7)"},
/* 1F3D8 */ { "HOUSE BUILDINGS","	= town\n"
	"	x (house with garden - 1F3E1)"},
/* 1F3D9 */ { "CITYSCAPE","	= skyline, city\n"
	"	x (cityscape at dusk - 1F306)"},
/* 1F3DA */ { "DERELICT HOUSE BUILDING","	= derelict site"},
/* 1F3DB */ { "CLASSICAL BUILDING","	= public building"},
/* 1F3DC */ { "DESERT","	x (cactus - 1F335)"},
/* 1F3DD */ { "DESERT ISLAND","	= island\n"
	"	x (palm tree - 1F334)"},
/* 1F3DE */ { "NATIONAL PARK","	* by semantic extension has come to connote saving trees, and hence is also used as a symbol meaning \"do not print this (email, document)\"\n"
	"	x (evergreen tree - 1F332)"},
/* 1F3DF */ { "STADIUM",NULL},
/* 1F3E0 */ { "HOUSE BUILDING",NULL},
/* 1F3E1 */ { "HOUSE WITH GARDEN","	= home, house with yard\n"
	"	x (house buildings - 1F3D8)"},
/* 1F3E2 */ { "OFFICE BUILDING","	x (office building symbol - 1CEBB)"},
/* 1F3E3 */ { "JAPANESE POST OFFICE","	x (postal mark - 3012)"},
/* 1F3E4 */ { "EUROPEAN POST OFFICE",NULL},
/* 1F3E5 */ { "HOSPITAL","	x (black cross on shield - 26E8)"},
/* 1F3E6 */ { "BANK","	x (squared latin capital letter b - 1F131)"},
/* 1F3E7 */ { "AUTOMATED TELLER MACHINE","	= ATM"},
/* 1F3E8 */ { "HOTEL","	x (negative circled latin capital letter h - 1F157)\n"
	"	x (sleeping accommodation - 1F6CC)"},
/* 1F3E9 */ { "LOVE HOTEL",NULL},
/* 1F3EA */ { "CONVENIENCE STORE",NULL},
/* 1F3EB */ { "SCHOOL",NULL},
/* 1F3EC */ { "DEPARTMENT STORE",NULL},
/* 1F3ED */ { "FACTORY","	= industrial production site\n"
	"	= date of production\n"
	"	x (gear without hub - 26ED)"},
/* 1F3EE */ { "IZAKAYA LANTERN","	= japanese izakaya restaurant"},
/* 1F3EF */ { "JAPANESE CASTLE",NULL},
/* 1F3F0 */ { "EUROPEAN CASTLE","	x (castle - 26EB)"},
/* 1F3F1 */ { "WHITE PENNANT","	x (triangular flag on post - 1F6A9)"},
/* 1F3F2 */ { "BLACK PENNANT",NULL},
/* 1F3F3 */ { "WAVING WHITE FLAG","	= flag\n"
	"	x (white flag - 2690)"},
/* 1F3F4 */ { "WAVING BLACK FLAG",NULL},
/* 1F3F5 */ { "ROSETTE","	x (white florette - 2740)"},
/* 1F3F6 */ { "BLACK ROSETTE","	x (eight petalled outlined black florette - 2741)"},
/* 1F3F7 */ { "LABEL","	= price, price tag\n"
	"	x (bookmark - 1F516)"},
/* 1F3F8 */ { "BADMINTON RACQUET AND SHUTTLECOCK",NULL},
/* 1F3F9 */ { "BOW AND ARROW","	= archery\n"
	"	* also used for Sagittarius\n"
	"	x (sagittarius - 2650)"},
/* 1F3FA */ { "AMPHORA","	* used for Aquarius\n"
	"	x (aquarius - 2652)\n"
	"	x (linear b ideogram vessel b209 - 100E8)"},
/* 1F3FB */ { "EMOJI MODIFIER FITZPATRICK TYPE-1-2",NULL},
/* 1F3FC */ { "EMOJI MODIFIER FITZPATRICK TYPE-3",NULL},
/* 1F3FD */ { "EMOJI MODIFIER FITZPATRICK TYPE-4",NULL},
/* 1F3FE */ { "EMOJI MODIFIER FITZPATRICK TYPE-5",NULL},
/* 1F3FF */ { "EMOJI MODIFIER FITZPATRICK TYPE-6",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_F4[] = {
/* 1F400 */ { "RAT","	* first of the signs of the Asian zodiac"},
/* 1F401 */ { "MOUSE","	* first of the signs of the Asian zodiac, used in Persia"},
/* 1F402 */ { "OX","	* second of the signs of the Asian zodiac"},
/* 1F403 */ { "WATER BUFFALO","	* second of the signs of the Asian zodiac, used in Vietnam"},
/* 1F404 */ { "COW","	* second of the signs of the Asian zodiac, used in Persia\n"
	"	= beef (on menus)"},
/* 1F405 */ { "TIGER","	* third of the signs of the Asian zodiac"},
/* 1F406 */ { "LEOPARD","	* third of the signs of the Asian zodiac, used in Persia"},
/* 1F407 */ { "RABBIT","	* fourth of the signs of the Asian zodiac"},
/* 1F408 */ { "CAT","	* fourth of the signs of the Asian zodiac, used in Vietnam"},
/* 1F409 */ { "DRAGON","	* fifth of the signs of the Asian zodiac"},
/* 1F40A */ { "CROCODILE","	* fifth of the signs of the Asian zodiac, used in Persia"},
/* 1F40B */ { "WHALE","	* fifth of the signs of the Asian zodiac, used in Persia"},
/* 1F40C */ { "SNAIL","	* fifth of the signs of the Asian zodiac, used in Kazakhstan"},
/* 1F40D */ { "SNAKE","	* sixth of the signs of the Asian zodiac\n"
	"	x (snake symbol - 1CCFA)"},
/* 1F40E */ { "HORSE","	= equestrian sports\n"
	"	* seventh of the signs of the Asian zodiac"},
/* 1F40F */ { "RAM","	* eighth of the signs of the Asian zodiac\n"
	"	x (aries - 2648)"},
/* 1F410 */ { "GOAT","	* eighth of the signs of the Asian zodiac, used in Vietnam"},
/* 1F411 */ { "SHEEP","	* eighth of the signs of the Asian zodiac, used in Persia"},
/* 1F412 */ { "MONKEY","	* ninth of the signs of the Asian zodiac"},
/* 1F413 */ { "ROOSTER","	* tenth of the signs of the Asian zodiac\n"
	"	= cock"},
/* 1F414 */ { "CHICKEN","	* tenth of the signs of the Asian zodiac, used in Persia\n"
	"	= hen\n"
	"	= poultry (on menus)"},
/* 1F415 */ { "DOG","	* eleventh of the signs of the Asian zodiac"},
/* 1F416 */ { "PIG","	* twelfth of the signs of the Asian zodiac\n"
	"	= pork (on menus)"},
/* 1F417 */ { "BOAR","	* twelfth of the signs of the Asian zodiac, used in Japan"},
/* 1F418 */ { "ELEPHANT","	* twelfth of the signs of the Asian zodiac, used in Thailand"},
/* 1F419 */ { "OCTOPUS",NULL},
/* 1F41A */ { "SPIRAL SHELL",NULL},
/* 1F41B */ { "BUG",NULL},
/* 1F41C */ { "ANT",NULL},
/* 1F41D */ { "HONEYBEE",NULL},
/* 1F41E */ { "LADY BEETLE","	= ladybird, ladybug, coccinellids"},
/* 1F41F */ { "FISH",NULL},
/* 1F420 */ { "TROPICAL FISH",NULL},
/* 1F421 */ { "BLOWFISH",NULL},
/* 1F422 */ { "TURTLE","	= tortoise, terrapin"},
/* 1F423 */ { "HATCHING CHICK",NULL},
/* 1F424 */ { "BABY CHICK",NULL},
/* 1F425 */ { "FRONT-FACING BABY CHICK",NULL},
/* 1F426 */ { "BIRD",NULL},
/* 1F427 */ { "PENGUIN",NULL},
/* 1F428 */ { "KOALA",NULL},
/* 1F429 */ { "POODLE",NULL},
/* 1F42A */ { "DROMEDARY CAMEL","	* has a single hump"},
/* 1F42B */ { "BACTRIAN CAMEL","	* has two humps"},
/* 1F42C */ { "DOLPHIN",NULL},
/* 1F42D */ { "MOUSE FACE",NULL},
/* 1F42E */ { "COW FACE",NULL},
/* 1F42F */ { "TIGER FACE",NULL},
/* 1F430 */ { "RABBIT FACE",NULL},
/* 1F431 */ { "CAT FACE","	x (smiling cat face with open mouth - 1F63A)"},
/* 1F432 */ { "DRAGON FACE",NULL},
/* 1F433 */ { "SPOUTING WHALE",NULL},
/* 1F434 */ { "HORSE FACE",NULL},
/* 1F435 */ { "MONKEY FACE",NULL},
/* 1F436 */ { "DOG FACE",NULL},
/* 1F437 */ { "PIG FACE",NULL},
/* 1F438 */ { "FROG FACE",NULL},
/* 1F439 */ { "HAMSTER FACE",NULL},
/* 1F43A */ { "WOLF FACE",NULL},
/* 1F43B */ { "BEAR FACE",NULL},
/* 1F43C */ { "PANDA FACE",NULL},
/* 1F43D */ { "PIG NOSE",NULL},
/* 1F43E */ { "PAW PRINTS","	x (footprints - 1F463)"},
/* 1F43F */ { "CHIPMUNK","	= animal, critter\n"
	"	* also used to represent a squirrel"},
/* 1F440 */ { "EYES",NULL},
/* 1F441 */ { "EYE","	= sight"},
/* 1F442 */ { "EAR",NULL},
/* 1F443 */ { "NOSE","	x (nose symbol - 1CCFC)"},
/* 1F444 */ { "MOUTH",NULL},
/* 1F445 */ { "TONGUE",NULL},
/* 1F446 */ { "WHITE UP POINTING BACKHAND INDEX","	x (white up pointing index - 261D)\n"
	"	x (black up pointing backhand index - 1F5A2)"},
/* 1F447 */ { "WHITE DOWN POINTING BACKHAND INDEX","	x (white down pointing index - 261F)\n"
	"	x (white down pointing left hand index - 1F597)\n"
	"	x (black down pointing backhand index - 1F5A3)"},
/* 1F448 */ { "WHITE LEFT POINTING BACKHAND INDEX","	x (white left pointing index - 261C)\n"
	"	x (black left pointing backhand index - 1F59C)\n"
	"	x (leftwards hand - 1FAF2)"},
/* 1F449 */ { "WHITE RIGHT POINTING BACKHAND INDEX","	x (white right pointing index - 261E)\n"
	"	x (black right pointing backhand index - 1F59D)\n"
	"	x (rightwards hand - 1FAF1)"},
/* 1F44A */ { "FISTED HAND SIGN","	= punch\n"
	"	x (raised fist - 270A)"},
/* 1F44B */ { "WAVING HAND SIGN","	x (raised hand - 270B)"},
/* 1F44C */ { "OK HAND SIGN","	x (turned ok hand sign - 1F58F)"},
/* 1F44D */ { "THUMBS UP SIGN","	x (reversed thumbs up sign - 1F592)"},
/* 1F44E */ { "THUMBS DOWN SIGN","	x (reversed thumbs down sign - 1F593)"},
/* 1F44F */ { "CLAPPING HANDS SIGN",NULL},
/* 1F450 */ { "OPEN HANDS SIGN",NULL},
/* 1F451 */ { "CROWN",NULL},
/* 1F452 */ { "WOMANS HAT",NULL},
/* 1F453 */ { "EYEGLASSES",NULL},
/* 1F454 */ { "NECKTIE",NULL},
/* 1F455 */ { "T-SHIRT",NULL},
/* 1F456 */ { "JEANS",NULL},
/* 1F457 */ { "DRESS",NULL},
/* 1F458 */ { "KIMONO",NULL},
/* 1F459 */ { "BIKINI",NULL},
/* 1F45A */ { "WOMANS CLOTHES",NULL},
/* 1F45B */ { "PURSE",NULL},
/* 1F45C */ { "HANDBAG",NULL},
/* 1F45D */ { "POUCH",NULL},
/* 1F45E */ { "MANS SHOE",NULL},
/* 1F45F */ { "ATHLETIC SHOE","	= runner, sneaker, tennis shoe"},
/* 1F460 */ { "HIGH-HEELED SHOE",NULL},
/* 1F461 */ { "WOMANS SANDAL",NULL},
/* 1F462 */ { "WOMANS BOOTS",NULL},
/* 1F463 */ { "FOOTPRINTS","	x (paw prints - 1F43E)"},
/* 1F464 */ { "BUST IN SILHOUETTE","	= guest account"},
/* 1F465 */ { "BUSTS IN SILHOUETTE","	= accounts"},
/* 1F466 */ { "BOY",NULL},
/* 1F467 */ { "GIRL","	x (child - 1F9D2)"},
/* 1F468 */ { "MAN",NULL},
/* 1F469 */ { "WOMAN","	x (adult - 1F9D1)"},
/* 1F46A */ { "FAMILY","	= rated for family"},
/* 1F46B */ { "MAN AND WOMAN HOLDING HANDS","	x (restroom - 1F6BB)"},
/* 1F46C */ { "TWO MEN HOLDING HANDS",NULL},
/* 1F46D */ { "TWO WOMEN HOLDING HANDS",NULL},
/* 1F46E */ { "POLICE OFFICER",NULL},
/* 1F46F */ { "WOMAN WITH BUNNY EARS","	* most popularly depicted as two women dancing"},
/* 1F470 */ { "BRIDE WITH VEIL","	x (man in tuxedo - 1F935)"},
/* 1F471 */ { "PERSON WITH BLOND HAIR",NULL},
/* 1F472 */ { "MAN WITH GUA PI MAO",NULL},
/* 1F473 */ { "MAN WITH TURBAN","	* may be shown with or without a beard"},
/* 1F474 */ { "OLDER MAN",NULL},
/* 1F475 */ { "OLDER WOMAN","	x (older adult - 1F9D3)"},
/* 1F476 */ { "BABY",NULL},
/* 1F477 */ { "CONSTRUCTION WORKER","	* the helmet may show a green cross, used as a safety reminder in Japan\n"
	"	x (helmet with white cross - 26D1)"},
/* 1F478 */ { "PRINCESS","	x (prince - 1F934)\n"
	"	x (person with crown - 1FAC5)"},
/* 1F479 */ { "JAPANESE OGRE",NULL},
/* 1F47A */ { "JAPANESE GOBLIN",NULL},
/* 1F47B */ { "GHOST",NULL},
/* 1F47C */ { "BABY ANGEL",NULL},
/* 1F47D */ { "EXTRATERRESTRIAL ALIEN","	x (flying saucer - 1F6F8)"},
/* 1F47E */ { "ALIEN MONSTER","	x (robot face - 1F916)"},
/* 1F47F */ { "IMP","	* commonly depicted as a frowning/angry version of 1F608 smiling face with horns"},
/* 1F480 */ { "SKULL",NULL},
/* 1F481 */ { "INFORMATION DESK PERSON","	* often used to indicate \"sassy\" or \"carefree\""},
/* 1F482 */ { "GUARDSMAN",NULL},
/* 1F483 */ { "DANCER","	* also used for \"let's party\"\n"
	"	x (man dancing - 1F57A)"},
/* 1F484 */ { "LIPSTICK",NULL},
/* 1F485 */ { "NAIL POLISH","	= manicure, nail care"},
/* 1F486 */ { "FACE MASSAGE",NULL},
/* 1F487 */ { "HAIRCUT","	* usually indicates a beauty parlor"},
/* 1F488 */ { "BARBER POLE",NULL},
/* 1F489 */ { "SYRINGE",NULL},
/* 1F48A */ { "PILL",NULL},
/* 1F48B */ { "KISS MARK","	= lips\n"
	"	x (lips - 1F5E2)"},
/* 1F48C */ { "LOVE LETTER",NULL},
/* 1F48D */ { "RING","	= jewelry"},
/* 1F48E */ { "GEM STONE",NULL},
/* 1F48F */ { "KISS","	= two people kissing"},
/* 1F490 */ { "BOUQUET","	x (bouquet of flowers - 1F395)"},
/* 1F491 */ { "COUPLE WITH HEART",NULL},
/* 1F492 */ { "WEDDING","	= wedding chapel\n"
	"	x (marriage symbol - 26AD)"},
/* 1F493 */ { "BEATING HEART",NULL},
/* 1F494 */ { "BROKEN HEART",NULL},
/* 1F495 */ { "TWO HEARTS",NULL},
/* 1F496 */ { "SPARKLING HEART",NULL},
/* 1F497 */ { "GROWING HEART",NULL},
/* 1F498 */ { "HEART WITH ARROW",NULL},
/* 1F499 */ { "BLUE HEART","	x (white heart suit - 2661)\n"
	"	x (black heart suit - 2665)\n"
	"	x (heavy black heart - 2764)\n"
	"	x (white heart - 1F90D)\n"
	"	x (orange heart - 1F9E1)\n"
	"	x (light blue heart - 1FA75)"},
/* 1F49A */ { "GREEN HEART",NULL},
/* 1F49B */ { "YELLOW HEART",NULL},
/* 1F49C */ { "PURPLE HEART",NULL},
/* 1F49D */ { "HEART WITH RIBBON",NULL},
/* 1F49E */ { "REVOLVING HEARTS",NULL},
/* 1F49F */ { "HEART DECORATION",NULL},
/* 1F4A0 */ { "DIAMOND SHAPE WITH A DOT INSIDE","	= kawaii, cute\n"
	"	* meaning of cuteness is based on association of glyph with shape of a flower\n"
	"	x (white diamond with centred dot - 27D0)"},
/* 1F4A1 */ { "ELECTRIC LIGHT BULB","	= idea"},
/* 1F4A2 */ { "ANGER SYMBOL",NULL},
/* 1F4A3 */ { "BOMB",NULL},
/* 1F4A4 */ { "SLEEPING SYMBOL",NULL},
/* 1F4A5 */ { "COLLISION SYMBOL","	x (mood bubble - 1F5F0)"},
/* 1F4A6 */ { "SPLASHING SWEAT SYMBOL","	= plewds"},
/* 1F4A7 */ { "DROPLET","	* represents a drop of sweat or drop of water\n"
	"	x (black droplet - 1F322)\n"
	"	x (drop of blood - 1FA78)"},
/* 1F4A8 */ { "DASH SYMBOL","	= running dash, briffits"},
/* 1F4A9 */ { "PILE OF POO","	= dog dirt\n"
	"	* may be depicted with or without a friendly face"},
/* 1F4AA */ { "FLEXED BICEPS","	= strong, muscled"},
/* 1F4AB */ { "DIZZY SYMBOL","	= circling stars, squeans"},
/* 1F4AC */ { "SPEECH BALLOON","	= comic book conversation bubble"},
/* 1F4AD */ { "THOUGHT BALLOON","	x (right thought bubble - 1F5ED)"},
/* 1F4AE */ { "WHITE FLOWER","	= brilliant homework\n"
	"	x (white florette - 2740)"},
/* 1F4AF */ { "HUNDRED POINTS SYMBOL","	= perfect score"},
/* 1F4B0 */ { "MONEY BAG","	* glyph may show any currency symbol instead of a dollar sign"},
/* 1F4B1 */ { "CURRENCY EXCHANGE",NULL},
/* 1F4B2 */ { "HEAVY DOLLAR SIGN","	x (dollar sign - 0024)"},
/* 1F4B3 */ { "CREDIT CARD",NULL},
/* 1F4B4 */ { "BANKNOTE WITH YEN SIGN",NULL},
/* 1F4B5 */ { "BANKNOTE WITH DOLLAR SIGN",NULL},
/* 1F4B6 */ { "BANKNOTE WITH EURO SIGN",NULL},
/* 1F4B7 */ { "BANKNOTE WITH POUND SIGN",NULL},
/* 1F4B8 */ { "MONEY WITH WINGS",NULL},
/* 1F4B9 */ { "CHART WITH UPWARDS TREND AND YEN SIGN",NULL},
/* 1F4BA */ { "SEAT","	* intended to denote a reserved or ticketed seat, as for an airplane, train, or theater"},
/* 1F4BB */ { "PERSONAL COMPUTER","	x (old personal computer - 1F5B3)"},
/* 1F4BC */ { "BRIEFCASE",NULL},
/* 1F4BD */ { "MINIDISC",NULL},
/* 1F4BE */ { "FLOPPY DISK","	= flexible disk cartridge, floppy disc, floppy, diskette\n"
	"	x (black hard shell floppy disk - 1F5AA)"},
/* 1F4BF */ { "OPTICAL DISC","	x (optical disc icon - 1F5B8)"},
/* 1F4C0 */ { "DVD","	= digital video/versatile disc"},
/* 1F4C1 */ { "FILE FOLDER","	x (folder - 1F5C0)"},
/* 1F4C2 */ { "OPEN FILE FOLDER","	x (open folder - 1F5C1)"},
/* 1F4C3 */ { "PAGE WITH CURL","	x (page - 1F5CF)"},
/* 1F4C4 */ { "PAGE FACING UP","	x (document - 1F5CE)"},
/* 1F4C5 */ { "CALENDAR","	x (spiral note pad - 1F5D2)"},
/* 1F4C6 */ { "TEAR-OFF CALENDAR","	x (spiral calendar pad - 1F5D3)"},
/* 1F4C7 */ { "CARD INDEX","	x (card index dividers - 1F5C2)"},
/* 1F4C8 */ { "CHART WITH UPWARDS TREND","	x (stock chart - 1F5E0)"},
/* 1F4C9 */ { "CHART WITH DOWNWARDS TREND",NULL},
/* 1F4CA */ { "BAR CHART",NULL},
/* 1F4CB */ { "CLIPBOARD",NULL},
/* 1F4CC */ { "PUSHPIN","	x (black pushpin - 1F588)"},
/* 1F4CD */ { "ROUND PUSHPIN",NULL},
/* 1F4CE */ { "PAPERCLIP","	x (linked paperclips - 1F587)"},
/* 1F4CF */ { "STRAIGHT RULER",NULL},
/* 1F4D0 */ { "TRIANGULAR RULER",NULL},
/* 1F4D1 */ { "BOOKMARK TABS",NULL},
/* 1F4D2 */ { "LEDGER",NULL},
/* 1F4D3 */ { "NOTEBOOK",NULL},
/* 1F4D4 */ { "NOTEBOOK WITH DECORATIVE COVER",NULL},
/* 1F4D5 */ { "CLOSED BOOK",NULL},
/* 1F4D6 */ { "OPEN BOOK","	= read operator's manual\n"
	"	* similar to ISO/IEC 7000-0790 \"Read operator's manual\"\n"
	"	x (book - 1F56E)"},
/* 1F4D7 */ { "GREEN BOOK",NULL},
/* 1F4D8 */ { "BLUE BOOK",NULL},
/* 1F4D9 */ { "ORANGE BOOK",NULL},
/* 1F4DA */ { "BOOKS",NULL},
/* 1F4DB */ { "NAME BADGE",NULL},
/* 1F4DC */ { "SCROLL",NULL},
/* 1F4DD */ { "MEMO",NULL},
/* 1F4DE */ { "TELEPHONE RECEIVER","	* commonly oriented rightwards, so that a face emoticon can be positioned to the right\n"
	"	x (left hand telephone receiver - 1F57B)\n"
	"	x (right hand telephone receiver - 1F57D)"},
/* 1F4DF */ { "PAGER",NULL},
/* 1F4E0 */ { "FAX MACHINE","	x (facsimile sign - 213B)\n"
	"	x (telephone receiver with page - 1F57C)\n"
	"	x (printer - 1F5A8)\n"
	"	x (fax icon - 1F5B7)"},
/* 1F4E1 */ { "SATELLITE ANTENNA","	= position indicator, news"},
/* 1F4E2 */ { "PUBLIC ADDRESS LOUDSPEAKER",NULL},
/* 1F4E3 */ { "CHEERING MEGAPHONE","	x (bullhorn with sound waves - 1F56C)"},
/* 1F4E4 */ { "OUTBOX TRAY",NULL},
/* 1F4E5 */ { "INBOX TRAY",NULL},
/* 1F4E6 */ { "PACKAGE","	x (wrapped present - 1F381)"},
/* 1F4E7 */ { "E-MAIL SYMBOL","	* glyph may show an E instead of an @-sign\n"
	"	x (envelope with lightning - 1F584)"},
/* 1F4E8 */ { "INCOMING ENVELOPE","	x (envelope - 2709)"},
/* 1F4E9 */ { "ENVELOPE WITH DOWNWARDS ARROW ABOVE","	* sending mail\n"
	"	x (flying envelope - 1F585)"},
/* 1F4EA */ { "CLOSED MAILBOX WITH LOWERED FLAG","	= letter box, mail reception\n"
	"	= empty mailbox"},
/* 1F4EB */ { "CLOSED MAILBOX WITH RAISED FLAG","	= mailbox containing mail"},
/* 1F4EC */ { "OPEN MAILBOX WITH RAISED FLAG",NULL},
/* 1F4ED */ { "OPEN MAILBOX WITH LOWERED FLAG",NULL},
/* 1F4EE */ { "POSTBOX","	= mailbox for sending mail"},
/* 1F4EF */ { "POSTAL HORN",NULL},
/* 1F4F0 */ { "NEWSPAPER","	x (rolled-up newspaper - 1F5DE)"},
/* 1F4F1 */ { "MOBILE PHONE","	x (clamshell mobile phone - 1F581)"},
/* 1F4F2 */ { "MOBILE PHONE WITH RIGHTWARDS ARROW AT LEFT","	* making a phone call"},
/* 1F4F3 */ { "VIBRATION MODE",NULL},
/* 1F4F4 */ { "MOBILE PHONE OFF",NULL},
/* 1F4F5 */ { "NO MOBILE PHONES",NULL},
/* 1F4F6 */ { "ANTENNA WITH BARS","	= cellular reception"},
/* 1F4F7 */ { "CAMERA",NULL},
/* 1F4F8 */ { "CAMERA WITH FLASH",NULL},
/* 1F4F9 */ { "VIDEO CAMERA","	= video"},
/* 1F4FA */ { "TELEVISION",NULL},
/* 1F4FB */ { "RADIO",NULL},
/* 1F4FC */ { "VIDEOCASSETTE",NULL},
/* 1F4FD */ { "FILM PROJECTOR","	= movies\n"
	"	x (cinema - 1F3A6)"},
/* 1F4FE */ { "PORTABLE STEREO","	= stereo"},
/* 1F4FF */ { "PRAYER BEADS",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_F5[] = {
/* 1F500 */ { "TWISTED RIGHTWARDS ARROWS","	= shuffle"},
/* 1F501 */ { "CLOCKWISE RIGHTWARDS AND LEFTWARDS OPEN CIRCLE ARROWS","	= repeat\n"
	"	x (black universal recycling symbol - 267B)"},
/* 1F502 */ { "CLOCKWISE RIGHTWARDS AND LEFTWARDS OPEN CIRCLE ARROWS WITH CIRCLED ONE OVERLAY","	= repeat one item over"},
/* 1F503 */ { "CLOCKWISE DOWNWARDS AND UPWARDS OPEN CIRCLE ARROWS","	= reload\n"
	"	x (clockwise right and left semicircle arrows - 1F5D8)"},
/* 1F504 */ { "ANTICLOCKWISE DOWNWARDS AND UPWARDS OPEN CIRCLE ARROWS","	= reload"},
/* 1F505 */ { "LOW BRIGHTNESS SYMBOL",NULL},
/* 1F506 */ { "HIGH BRIGHTNESS SYMBOL","	x (black sun with rays - 2600)\n"
	"	x (white sun with rays - 263C)\n"
	"	x (gear without hub - 26ED)"},
/* 1F507 */ { "SPEAKER WITH CANCELLATION STROKE",NULL},
/* 1F508 */ { "SPEAKER","	= left speaker\n"
	"	x (right speaker - 1F568)\n"
	"	x (bullhorn - 1F56B)"},
/* 1F509 */ { "SPEAKER WITH ONE SOUND WAVE",NULL},
/* 1F50A */ { "SPEAKER WITH THREE SOUND WAVES","	= sound"},
/* 1F50B */ { "BATTERY","	x (low battery - 1FAAB)"},
/* 1F50C */ { "ELECTRIC PLUG",NULL},
/* 1F50D */ { "LEFT-POINTING MAGNIFYING GLASS","	= search\n"
	"	x (bullhorn with sound waves - 1F56C)"},
/* 1F50E */ { "RIGHT-POINTING MAGNIFYING GLASS","	= get more details"},
/* 1F50F */ { "LOCK WITH INK PEN","	= privacy"},
/* 1F510 */ { "CLOSED LOCK WITH KEY","	= secure"},
/* 1F511 */ { "KEY","	x (squared key - 26BF)\n"
	"	x (old key - 1F5DD)"},
/* 1F512 */ { "LOCK","	= padlock in locked position"},
/* 1F513 */ { "OPEN LOCK",NULL},
/* 1F514 */ { "BELL","	x (tibetan symbol dril bu - 0FC4)\n"
	"	x (bell symbol - 237E)\n"
	"	x (symbol for bell - 2407)\n"
	"	x (ringing bell - 1F56D)\n"
	"	x (alarm bell symbol - 1FBFA)"},
/* 1F515 */ { "BELL WITH CANCELLATION STROKE",NULL},
/* 1F516 */ { "BOOKMARK","	* indicates a bookmark, not a price tag\n"
	"	x (label - 1F3F7)"},
/* 1F517 */ { "LINK SYMBOL",NULL},
/* 1F518 */ { "RADIO BUTTON","	x (circled dot operator - 2299)\n"
	"	x (fisheye - 25C9)\n"
	"	x (bullseye - 25CE)"},
/* 1F519 */ { "BACK WITH LEFTWARDS ARROW ABOVE","	x (previous page - 2397)"},
/* 1F51A */ { "END WITH LEFTWARDS ARROW ABOVE",NULL},
/* 1F51B */ { "ON WITH EXCLAMATION MARK WITH LEFT RIGHT ARROW ABOVE",NULL},
/* 1F51C */ { "SOON WITH RIGHTWARDS ARROW ABOVE",NULL},
/* 1F51D */ { "TOP WITH UPWARDS ARROW ABOVE","	= top of page"},
/* 1F51E */ { "NO ONE UNDER EIGHTEEN SYMBOL",NULL},
/* 1F51F */ { "KEYCAP TEN","	x (combining enclosing keycap - 20E3)"},
/* 1F520 */ { "INPUT SYMBOL FOR LATIN CAPITAL LETTERS",NULL},
/* 1F521 */ { "INPUT SYMBOL FOR LATIN SMALL LETTERS",NULL},
/* 1F522 */ { "INPUT SYMBOL FOR NUMBERS",NULL},
/* 1F523 */ { "INPUT SYMBOL FOR SYMBOLS",NULL},
/* 1F524 */ { "INPUT SYMBOL FOR LATIN LETTERS","	= English input (ABC)"},
/* 1F525 */ { "FIRE",NULL},
/* 1F526 */ { "ELECTRIC TORCH","	= flashlight"},
/* 1F527 */ { "WRENCH",NULL},
/* 1F528 */ { "HAMMER",NULL},
/* 1F529 */ { "NUT AND BOLT",NULL},
/* 1F52A */ { "HOCHO","	= Japanese kitchen knife\n"
	"	x (dagger knife - 1F5E1)"},
/* 1F52B */ { "PISTOL","	= handgun, revolver"},
/* 1F52C */ { "MICROSCOPE",NULL},
/* 1F52D */ { "TELESCOPE",NULL},
/* 1F52E */ { "CRYSTAL BALL",NULL},
/* 1F52F */ { "SIX POINTED STAR WITH MIDDLE DOT","	x (star of david - 2721)"},
/* 1F530 */ { "JAPANESE SYMBOL FOR BEGINNER",NULL},
/* 1F531 */ { "TRIDENT EMBLEM",NULL},
/* 1F532 */ { "BLACK SQUARE BUTTON",NULL},
/* 1F533 */ { "WHITE SQUARE BUTTON",NULL},
/* 1F534 */ { "LARGE RED CIRCLE","	x (black circle for record - 23FA)\n"
	"	x (black circle - 25CF)\n"
	"	x (large circle - 25EF)\n"
	"	x (black large circle - 2B24)\n"
	"	x (heavy large circle - 2B55)\n"
	"	x (large orange circle - 1F7E0)"},
/* 1F535 */ { "LARGE BLUE CIRCLE",NULL},
/* 1F536 */ { "LARGE ORANGE DIAMOND","	x (black diamond - 25C6)"},
/* 1F537 */ { "LARGE BLUE DIAMOND",NULL},
/* 1F538 */ { "SMALL ORANGE DIAMOND","	x (black small diamond - 2B29)"},
/* 1F539 */ { "SMALL BLUE DIAMOND",NULL},
/* 1F53A */ { "UP-POINTING RED TRIANGLE","	x (black up-pointing triangle - 25B2)"},
/* 1F53B */ { "DOWN-POINTING RED TRIANGLE","	x (black down-pointing triangle - 25BC)"},
/* 1F53C */ { "UP-POINTING SMALL RED TRIANGLE","	= play arrow up\n"
	"	x (black up-pointing small triangle - 25B4)"},
/* 1F53D */ { "DOWN-POINTING SMALL RED TRIANGLE","	= play arrow down\n"
	"	x (black down-pointing small triangle - 25BE)"},
/* 1F53E */ { "LOWER RIGHT SHADOWED WHITE CIRCLE","	= circle shadow down\n"
	"	x (shadowed white circle - 274D)"},
/* 1F53F */ { "UPPER RIGHT SHADOWED WHITE CIRCLE",NULL},
/* 1F540 */ { "CIRCLED CROSS POMMEE","	* Orthodox typicon symbol for great feast service"},
/* 1F541 */ { "CROSS POMMEE WITH HALF-CIRCLE BELOW","	* Orthodox typicon symbol for vigil service"},
/* 1F542 */ { "CROSS POMMEE","	* Orthodox typicon symbol for Polyeleos\n"
	"	x (four teardrop-spoked asterisk - 2722)"},
/* 1F543 */ { "NOTCHED LEFT SEMICIRCLE WITH THREE DOTS","	* Orthodox typicon symbol for lower rank feast"},
/* 1F544 */ { "NOTCHED RIGHT SEMICIRCLE WITH THREE DOTS","	* Orthodox typicon symbol for lower rank feast"},
/* 1F545 */ { "SYMBOL FOR MARKS CHAPTER","	* Orthodox typicon symbol for difficult sections"},
/* 1F546 */ { "WHITE LATIN CROSS","	= cross outline\n"
	"	x (shadowed white latin cross - 271E)"},
/* 1F547 */ { "HEAVY LATIN CROSS",NULL},
/* 1F548 */ { "CELTIC CROSS",NULL},
/* 1F549 */ { "OM SYMBOL","	* generic symbol independent of Devanagari font\n"
	"	x (devanagari om - 0950)"},
/* 1F54A */ { "DOVE OF PEACE","	= peace"},
/* 1F54B */ { "KAABA",NULL},
/* 1F54C */ { "MOSQUE",NULL},
/* 1F54D */ { "SYNAGOGUE",NULL},
/* 1F54E */ { "MENORAH WITH NINE BRANCHES","	= hanukiah"},
/* 1F54F */ { "BOWL OF HYGIEIA","	x (staff of aesculapius - 2695)"},
/* 1F550 */ { "CLOCK FACE ONE OCLOCK","	x (watch - 231A)\n"
	"	x (alarm clock - 23F0)"},
/* 1F551 */ { "CLOCK FACE TWO OCLOCK",NULL},
/* 1F552 */ { "CLOCK FACE THREE OCLOCK",NULL},
/* 1F553 */ { "CLOCK FACE FOUR OCLOCK",NULL},
/* 1F554 */ { "CLOCK FACE FIVE OCLOCK",NULL},
/* 1F555 */ { "CLOCK FACE SIX OCLOCK",NULL},
/* 1F556 */ { "CLOCK FACE SEVEN OCLOCK",NULL},
/* 1F557 */ { "CLOCK FACE EIGHT OCLOCK",NULL},
/* 1F558 */ { "CLOCK FACE NINE OCLOCK",NULL},
/* 1F559 */ { "CLOCK FACE TEN OCLOCK",NULL},
/* 1F55A */ { "CLOCK FACE ELEVEN OCLOCK",NULL},
/* 1F55B */ { "CLOCK FACE TWELVE OCLOCK",NULL},
/* 1F55C */ { "CLOCK FACE ONE-THIRTY",NULL},
/* 1F55D */ { "CLOCK FACE TWO-THIRTY",NULL},
/* 1F55E */ { "CLOCK FACE THREE-THIRTY",NULL},
/* 1F55F */ { "CLOCK FACE FOUR-THIRTY",NULL},
/* 1F560 */ { "CLOCK FACE FIVE-THIRTY",NULL},
/* 1F561 */ { "CLOCK FACE SIX-THIRTY",NULL},
/* 1F562 */ { "CLOCK FACE SEVEN-THIRTY",NULL},
/* 1F563 */ { "CLOCK FACE EIGHT-THIRTY",NULL},
/* 1F564 */ { "CLOCK FACE NINE-THIRTY",NULL},
/* 1F565 */ { "CLOCK FACE TEN-THIRTY",NULL},
/* 1F566 */ { "CLOCK FACE ELEVEN-THIRTY",NULL},
/* 1F567 */ { "CLOCK FACE TWELVE-THIRTY",NULL},
/* 1F568 */ { "RIGHT SPEAKER","	x (speaker - 1F508)"},
/* 1F569 */ { "RIGHT SPEAKER WITH ONE SOUND WAVE",NULL},
/* 1F56A */ { "RIGHT SPEAKER WITH THREE SOUND WAVES",NULL},
/* 1F56B */ { "BULLHORN","	= sound off\n"
	"	x (speaker - 1F508)"},
/* 1F56C */ { "BULLHORN WITH SOUND WAVES","	= sound on\n"
	"	x (cheering megaphone - 1F4E3)\n"
	"	x (speaker with three sound waves - 1F50A)"},
/* 1F56D */ { "RINGING BELL","	x (bell - 1F514)"},
/* 1F56E */ { "BOOK","	x (open book - 1F4D6)"},
/* 1F56F */ { "CANDLE",NULL},
/* 1F570 */ { "MANTELPIECE CLOCK","	= clock\n"
	"	x (alarm clock - 23F0)"},
/* 1F571 */ { "BLACK SKULL AND CROSSBONES","	x (skull and crossbones - 2620)"},
/* 1F572 */ { "NO PIRACY",NULL},
/* 1F573 */ { "HOLE","	= portable hole"},
/* 1F574 */ { "MAN IN BUSINESS SUIT LEVITATING","	= jump"},
/* 1F575 */ { "SLEUTH OR SPY","	= investigate"},
/* 1F576 */ { "DARK SUNGLASSES","	= cool"},
/* 1F577 */ { "SPIDER",NULL},
/* 1F578 */ { "SPIDER WEB",NULL},
/* 1F579 */ { "JOYSTICK",NULL},
/* 1F57A */ { "MAN DANCING","	* forms a gender pair with 1F483\n"
	"	x (dancer - 1F483)"},
/* 1F57B */ { "LEFT HAND TELEPHONE RECEIVER","	x (telephone receiver - 1F4DE)"},
/* 1F57C */ { "TELEPHONE RECEIVER WITH PAGE","	= fax\n"
	"	x (fax machine - 1F4E0)"},
/* 1F57D */ { "RIGHT HAND TELEPHONE RECEIVER","	= telephone handset"},
/* 1F57E */ { "WHITE TOUCHTONE TELEPHONE","	x (white telephone - 260F)"},
/* 1F57F */ { "BLACK TOUCHTONE TELEPHONE","	x (black telephone - 260E)"},
/* 1F580 */ { "TELEPHONE ON TOP OF MODEM","	= modem"},
/* 1F581 */ { "CLAMSHELL MOBILE PHONE","	= cellular phone\n"
	"	x (mobile phone - 1F4F1)"},
/* 1F582 */ { "BACK OF ENVELOPE","	* contrasts with 2709, which shows a seal\n"
	"	x (envelope - 2709)"},
/* 1F583 */ { "STAMPED ENVELOPE","	= mail"},
/* 1F584 */ { "ENVELOPE WITH LIGHTNING","	= e-mail\n"
	"	x (e-mail symbol - 1F4E7)"},
/* 1F585 */ { "FLYING ENVELOPE","	= send message\n"
	"	x (envelope with downwards arrow above - 1F4E9)"},
/* 1F586 */ { "PEN OVER STAMPED ENVELOPE",NULL},
/* 1F587 */ { "LINKED PAPERCLIPS","	= links\n"
	"	x (paperclip - 1F4CE)"},
/* 1F588 */ { "BLACK PUSHPIN","	= marker\n"
	"	x (pushpin - 1F4CC)"},
/* 1F589 */ { "LOWER LEFT PENCIL","	= pencil\n"
	"	x (lower right pencil - 270E)"},
/* 1F58A */ { "LOWER LEFT BALLPOINT PEN","	= ballpoint pen"},
/* 1F58B */ { "LOWER LEFT FOUNTAIN PEN","	= fountain pen\n"
	"	x (white nib - 2711)"},
/* 1F58C */ { "LOWER LEFT PAINTBRUSH","	= brush"},
/* 1F58D */ { "LOWER LEFT CRAYON","	= crayon"},
/* 1F58E */ { "LEFT WRITING HAND","	x (writing hand - 270D)"},
/* 1F58F */ { "TURNED OK HAND SIGN","	x (ok hand sign - 1F44C)"},
/* 1F590 */ { "RAISED HAND WITH FINGERS SPLAYED","	= halt\n"
	"	x (raised hand - 270B)"},
/* 1F591 */ { "REVERSED RAISED HAND WITH FINGERS SPLAYED",NULL},
/* 1F592 */ { "REVERSED THUMBS UP SIGN","	x (thumbs up sign - 1F44D)"},
/* 1F593 */ { "REVERSED THUMBS DOWN SIGN","	x (thumbs down sign - 1F44E)"},
/* 1F594 */ { "REVERSED VICTORY HAND","	x (victory hand - 270C)"},
/* 1F595 */ { "REVERSED HAND WITH MIDDLE FINGER EXTENDED",NULL},
/* 1F596 */ { "RAISED HAND WITH PART BETWEEN MIDDLE AND RING FINGERS","	= Vulcan salute"},
/* 1F597 */ { "WHITE DOWN POINTING LEFT HAND INDEX","	x (white down pointing index - 261F)\n"
	"	x (white down pointing backhand index - 1F447)"},
/* 1F598 */ { "SIDEWAYS WHITE LEFT POINTING INDEX","	x (white left pointing index - 261C)"},
/* 1F599 */ { "SIDEWAYS WHITE RIGHT POINTING INDEX","	x (white right pointing index - 261E)"},
/* 1F59A */ { "SIDEWAYS BLACK LEFT POINTING INDEX",NULL},
/* 1F59B */ { "SIDEWAYS BLACK RIGHT POINTING INDEX",NULL},
/* 1F59C */ { "BLACK LEFT POINTING BACKHAND INDEX","	x (white left pointing backhand index - 1F448)"},
/* 1F59D */ { "BLACK RIGHT POINTING BACKHAND INDEX","	x (white right pointing backhand index - 1F449)"},
/* 1F59E */ { "SIDEWAYS WHITE UP POINTING INDEX","	x (white up pointing index - 261D)"},
/* 1F59F */ { "SIDEWAYS WHITE DOWN POINTING INDEX","	x (white down pointing index - 261F)"},
/* 1F5A0 */ { "SIDEWAYS BLACK UP POINTING INDEX",NULL},
/* 1F5A1 */ { "SIDEWAYS BLACK DOWN POINTING INDEX",NULL},
/* 1F5A2 */ { "BLACK UP POINTING BACKHAND INDEX","	x (white up pointing backhand index - 1F446)"},
/* 1F5A3 */ { "BLACK DOWN POINTING BACKHAND INDEX","	x (white down pointing backhand index - 1F447)"},
/* 1F5A4 */ { "BLACK HEART","	* unequivocally represented as black in all variants\n"
	"	x (black heart suit - 2665)\n"
	"	x (white heart - 1F90D)"},
/* 1F5A5 */ { "DESKTOP COMPUTER","	= tower computer"},
/* 1F5A6 */ { "KEYBOARD AND MOUSE","	x (keyboard - 2328)"},
/* 1F5A7 */ { "THREE NETWORKED COMPUTERS","	= computer network"},
/* 1F5A8 */ { "PRINTER","	x (fax machine - 1F4E0)"},
/* 1F5A9 */ { "POCKET CALCULATOR","	= calculator"},
/* 1F5AA */ { "BLACK HARD SHELL FLOPPY DISK","	= disk\n"
	"	x (floppy disk - 1F4BE)"},
/* 1F5AB */ { "WHITE HARD SHELL FLOPPY DISK",NULL},
/* 1F5AC */ { "SOFT SHELL FLOPPY DISK",NULL},
/* 1F5AD */ { "TAPE CARTRIDGE",NULL},
/* 1F5AE */ { "WIRED KEYBOARD","	= keyboard\n"
	"	x (keyboard - 2328)"},
/* 1F5AF */ { "ONE BUTTON MOUSE",NULL},
/* 1F5B0 */ { "TWO BUTTON MOUSE",NULL},
/* 1F5B1 */ { "THREE BUTTON MOUSE",NULL},
/* 1F5B2 */ { "TRACKBALL","	= ballpoint"},
/* 1F5B3 */ { "OLD PERSONAL COMPUTER","	= personal computer\n"
	"	x (personal computer - 1F4BB)"},
/* 1F5B4 */ { "HARD DISK",NULL},
/* 1F5B5 */ { "SCREEN","	= monitor\n"
	"	x (combining enclosing screen - 20E2)"},
/* 1F5B6 */ { "PRINTER ICON","	x (printer - 1F5A8)"},
/* 1F5B7 */ { "FAX ICON","	x (fax machine - 1F4E0)"},
/* 1F5B8 */ { "OPTICAL DISC ICON","	= compact disc\n"
	"	x (optical disc - 1F4BF)"},
/* 1F5B9 */ { "DOCUMENT WITH TEXT",NULL},
/* 1F5BA */ { "DOCUMENT WITH TEXT AND PICTURE",NULL},
/* 1F5BB */ { "DOCUMENT WITH PICTURE","	= graphic document"},
/* 1F5BC */ { "FRAME WITH PICTURE","	= art"},
/* 1F5BD */ { "FRAME WITH TILES","	= frames"},
/* 1F5BE */ { "FRAME WITH AN X","	= no frames, no picture"},
/* 1F5BF */ { "BLACK FOLDER",NULL},
/* 1F5C0 */ { "FOLDER","	= directory\n"
	"	x (file folder - 1F4C1)\n"
	"	x (left half folder - 1FBB9)"},
/* 1F5C1 */ { "OPEN FOLDER","	x (open file folder - 1F4C2)"},
/* 1F5C2 */ { "CARD INDEX DIVIDERS","	= index\n"
	"	x (card index - 1F4C7)"},
/* 1F5C3 */ { "CARD FILE BOX","	= archive"},
/* 1F5C4 */ { "FILE CABINET",NULL},
/* 1F5C5 */ { "EMPTY NOTE",NULL},
/* 1F5C6 */ { "EMPTY NOTE PAGE",NULL},
/* 1F5C7 */ { "EMPTY NOTE PAD",NULL},
/* 1F5C8 */ { "NOTE",NULL},
/* 1F5C9 */ { "NOTE PAGE",NULL},
/* 1F5CA */ { "NOTE PAD",NULL},
/* 1F5CB */ { "EMPTY DOCUMENT",NULL},
/* 1F5CC */ { "EMPTY PAGE",NULL},
/* 1F5CD */ { "EMPTY PAGES",NULL},
/* 1F5CE */ { "DOCUMENT","	x (page facing up - 1F4C4)"},
/* 1F5CF */ { "PAGE","	x (page with curl - 1F4C3)"},
/* 1F5D0 */ { "PAGES",NULL},
/* 1F5D1 */ { "WASTEBASKET","	= trashcan"},
/* 1F5D2 */ { "SPIRAL NOTE PAD","	= note, empty calendar\n"
	"	x (calendar - 1F4C5)"},
/* 1F5D3 */ { "SPIRAL CALENDAR PAD","	= calendar, day 1\n"
	"	x (tear-off calendar - 1F4C6)"},
/* 1F5D4 */ { "DESKTOP WINDOW",NULL},
/* 1F5D5 */ { "MINIMIZE",NULL},
/* 1F5D6 */ { "MAXIMIZE",NULL},
/* 1F5D7 */ { "OVERLAP","	= overlapping offset windows"},
/* 1F5D8 */ { "CLOCKWISE RIGHT AND LEFT SEMICIRCLE ARROWS","	= refresh\n"
	"	x (clockwise downwards and upwards open circle arrows - 1F503)"},
/* 1F5D9 */ { "CANCELLATION X","	= close\n"
	"	x (cross mark - 274C)"},
/* 1F5DA */ { "INCREASE FONT SIZE SYMBOL",NULL},
/* 1F5DB */ { "DECREASE FONT SIZE SYMBOL",NULL},
/* 1F5DC */ { "COMPRESSION","	* symbol depicts a hand press with a box inside"},
/* 1F5DD */ { "OLD KEY","	= encryption\n"
	"	x (key - 1F511)"},
/* 1F5DE */ { "ROLLED-UP NEWSPAPER","	= news\n"
	"	x (newspaper - 1F4F0)"},
/* 1F5DF */ { "PAGE WITH CIRCLED TEXT","	= classified"},
/* 1F5E0 */ { "STOCK CHART","	= finance\n"
	"	x (chart with upwards trend - 1F4C8)"},
/* 1F5E1 */ { "DAGGER KNIFE","	= rated for violence\n"
	"	= hate\n"
	"	x (hocho - 1F52A)"},
/* 1F5E2 */ { "LIPS","	= rated for sex\n"
	"	= kiss\n"
	"	x (kiss mark - 1F48B)\n"
	"	x (biting lip - 1FAE6)"},
/* 1F5E3 */ { "SPEAKING HEAD IN SILHOUETTE","	= rated for strong language"},
/* 1F5E4 */ { "THREE RAYS ABOVE",NULL},
/* 1F5E5 */ { "THREE RAYS BELOW",NULL},
/* 1F5E6 */ { "THREE RAYS LEFT","	x (three lines converging right - 269E)"},
/* 1F5E7 */ { "THREE RAYS RIGHT","	x (three lines converging left - 269F)"},
/* 1F5E8 */ { "LEFT SPEECH BUBBLE",NULL},
/* 1F5E9 */ { "RIGHT SPEECH BUBBLE",NULL},
/* 1F5EA */ { "TWO SPEECH BUBBLES","	= chat"},
/* 1F5EB */ { "THREE SPEECH BUBBLES","	= conference"},
/* 1F5EC */ { "LEFT THOUGHT BUBBLE",NULL},
/* 1F5ED */ { "RIGHT THOUGHT BUBBLE","	x (thought balloon - 1F4AD)"},
/* 1F5EE */ { "LEFT ANGER BUBBLE","	= shout left"},
/* 1F5EF */ { "RIGHT ANGER BUBBLE","	= shout right"},
/* 1F5F0 */ { "MOOD BUBBLE","	= new\n"
	"	x (collision symbol - 1F4A5)"},
/* 1F5F1 */ { "LIGHTNING MOOD BUBBLE","	= updated"},
/* 1F5F2 */ { "LIGHTNING MOOD","	= lightning bolt\n"
	"	x (high voltage sign - 26A1)"},
/* 1F5F3 */ { "BALLOT BOX WITH BALLOT","	= vote\n"
	"	x (ballot box with x - 2612)"},
/* 1F5F4 */ { "BALLOT SCRIPT X","	= x mark\n"
	"	x (ballot x - 2717)"},
/* 1F5F5 */ { "BALLOT BOX WITH SCRIPT X","	x (ballot box with x - 2612)"},
/* 1F5F6 */ { "BALLOT BOLD SCRIPT X","	x (heavy ballot x - 2718)"},
/* 1F5F7 */ { "BALLOT BOX WITH BOLD SCRIPT X",NULL},
/* 1F5F8 */ { "LIGHT CHECK MARK","	= check\n"
	"	x (check mark - 2713)"},
/* 1F5F9 */ { "BALLOT BOX WITH BOLD CHECK","	x (ballot box with check - 2611)"},
/* 1F5FA */ { "WORLD MAP",NULL},
/* 1F5FB */ { "MOUNT FUJI",NULL},
/* 1F5FC */ { "TOKYO TOWER",NULL},
/* 1F5FD */ { "STATUE OF LIBERTY",NULL},
/* 1F5FE */ { "SILHOUETTE OF JAPAN",NULL},
/* 1F5FF */ { "MOYAI","	* Japanese stone statue like Moai on Easter Island"}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_F6[] = {
/* 1F600 */ { "GRINNING FACE",NULL},
/* 1F601 */ { "GRINNING FACE WITH SMILING EYES",NULL},
/* 1F602 */ { "FACE WITH TEARS OF JOY",NULL},
/* 1F603 */ { "SMILING FACE WITH OPEN MOUTH","	x (white smiling face - 263A)"},
/* 1F604 */ { "SMILING FACE WITH OPEN MOUTH AND SMILING EYES",NULL},
/* 1F605 */ { "SMILING FACE WITH OPEN MOUTH AND COLD SWEAT",NULL},
/* 1F606 */ { "SMILING FACE WITH OPEN MOUTH AND TIGHTLY-CLOSED EYES",NULL},
/* 1F607 */ { "SMILING FACE WITH HALO",NULL},
/* 1F608 */ { "SMILING FACE WITH HORNS","	* commonly depicted as a (sinister) smiling version of 1F47F imp"},
/* 1F609 */ { "WINKING FACE",NULL},
/* 1F60A */ { "SMILING FACE WITH SMILING EYES",NULL},
/* 1F60B */ { "FACE SAVOURING DELICIOUS FOOD",NULL},
/* 1F60C */ { "RELIEVED FACE","	* indicates relief, not sleeping"},
/* 1F60D */ { "SMILING FACE WITH HEART-SHAPED EYES",NULL},
/* 1F60E */ { "SMILING FACE WITH SUNGLASSES",NULL},
/* 1F60F */ { "SMIRKING FACE",NULL},
/* 1F610 */ { "NEUTRAL FACE","	* used for the West Wind in some Mahjong annotation"},
/* 1F611 */ { "EXPRESSIONLESS FACE",NULL},
/* 1F612 */ { "UNAMUSED FACE",NULL},
/* 1F613 */ { "FACE WITH COLD SWEAT",NULL},
/* 1F614 */ { "PENSIVE FACE",NULL},
/* 1F615 */ { "CONFUSED FACE",NULL},
/* 1F616 */ { "CONFOUNDED FACE",NULL},
/* 1F617 */ { "KISSING FACE",NULL},
/* 1F618 */ { "FACE THROWING A KISS",NULL},
/* 1F619 */ { "KISSING FACE WITH SMILING EYES",NULL},
/* 1F61A */ { "KISSING FACE WITH CLOSED EYES",NULL},
/* 1F61B */ { "FACE WITH STUCK-OUT TONGUE",NULL},
/* 1F61C */ { "FACE WITH STUCK-OUT TONGUE AND WINKING EYE","	* kidding, not serious"},
/* 1F61D */ { "FACE WITH STUCK-OUT TONGUE AND TIGHTLY-CLOSED EYES","	* kidding, not serious"},
/* 1F61E */ { "DISAPPOINTED FACE","	x (white frowning face - 2639)"},
/* 1F61F */ { "WORRIED FACE",NULL},
/* 1F620 */ { "ANGRY FACE",NULL},
/* 1F621 */ { "POUTING FACE","	* intended to depict pouting rather than simply anger"},
/* 1F622 */ { "CRYING FACE",NULL},
/* 1F623 */ { "PERSEVERING FACE",NULL},
/* 1F624 */ { "FACE WITH LOOK OF TRIUMPH","	* indicates triumph, not anger"},
/* 1F625 */ { "DISAPPOINTED BUT RELIEVED FACE",NULL},
/* 1F626 */ { "FROWNING FACE WITH OPEN MOUTH","	* frowning, not shocked or surprised"},
/* 1F627 */ { "ANGUISHED FACE",NULL},
/* 1F628 */ { "FEARFUL FACE",NULL},
/* 1F629 */ { "WEARY FACE",NULL},
/* 1F62A */ { "SLEEPY FACE",NULL},
/* 1F62B */ { "TIRED FACE",NULL},
/* 1F62C */ { "GRIMACING FACE","	* should not be depicted with zipper mouth\n"
	"	x (zipper-mouth face - 1F910)"},
/* 1F62D */ { "LOUDLY CRYING FACE",NULL},
/* 1F62E */ { "FACE WITH OPEN MOUTH",NULL},
/* 1F62F */ { "HUSHED FACE",NULL},
/* 1F630 */ { "FACE WITH OPEN MOUTH AND COLD SWEAT",NULL},
/* 1F631 */ { "FACE SCREAMING IN FEAR",NULL},
/* 1F632 */ { "ASTONISHED FACE",NULL},
/* 1F633 */ { "FLUSHED FACE","	* embarrassed"},
/* 1F634 */ { "SLEEPING FACE",NULL},
/* 1F635 */ { "DIZZY FACE",NULL},
/* 1F636 */ { "FACE WITHOUT MOUTH","	x (white circle with two dots - 2687)"},
/* 1F637 */ { "FACE WITH MEDICAL MASK",NULL},
/* 1F638 */ { "GRINNING CAT FACE WITH SMILING EYES",NULL},
/* 1F639 */ { "CAT FACE WITH TEARS OF JOY",NULL},
/* 1F63A */ { "SMILING CAT FACE WITH OPEN MOUTH",NULL},
/* 1F63B */ { "SMILING CAT FACE WITH HEART-SHAPED EYES",NULL},
/* 1F63C */ { "CAT FACE WITH WRY SMILE",NULL},
/* 1F63D */ { "KISSING CAT FACE WITH CLOSED EYES",NULL},
/* 1F63E */ { "POUTING CAT FACE","	* intended to depict pouting rather than simply anger"},
/* 1F63F */ { "CRYING CAT FACE",NULL},
/* 1F640 */ { "WEARY CAT FACE","	* indicates tired, not horrified"},
/* 1F641 */ { "SLIGHTLY FROWNING FACE","	x (white frowning face - 2639)"},
/* 1F642 */ { "SLIGHTLY SMILING FACE","	x (white smiling face - 263A)"},
/* 1F643 */ { "UPSIDE-DOWN FACE",NULL},
/* 1F644 */ { "FACE WITH ROLLING EYES",NULL},
/* 1F645 */ { "FACE WITH NO GOOD GESTURE","	* conveys \"no deal\" or \"not ok\", not anger; the inverse of 1F646 face with ok gesture"},
/* 1F646 */ { "FACE WITH OK GESTURE",NULL},
/* 1F647 */ { "PERSON BOWING DEEPLY","	* most commonly depicted as Japanese-style bowing while seated (dogeza)"},
/* 1F648 */ { "SEE-NO-EVIL MONKEY",NULL},
/* 1F649 */ { "HEAR-NO-EVIL MONKEY",NULL},
/* 1F64A */ { "SPEAK-NO-EVIL MONKEY",NULL},
/* 1F64B */ { "HAPPY PERSON RAISING ONE HAND",NULL},
/* 1F64C */ { "PERSON RAISING BOTH HANDS IN CELEBRATION","	= banzai!"},
/* 1F64D */ { "PERSON FROWNING",NULL},
/* 1F64E */ { "PERSON WITH POUTING FACE","	* intended to depict pouting rather than simply anger"},
/* 1F64F */ { "PERSON WITH FOLDED HANDS","	* can indicate sorrow or regret\n"
	"	* can also indicate pleading, praying, bowing, or thanking"},
/* 1F650 */ { "NORTH WEST POINTING LEAF",NULL},
/* 1F651 */ { "SOUTH WEST POINTING LEAF",NULL},
/* 1F652 */ { "NORTH EAST POINTING LEAF",NULL},
/* 1F653 */ { "SOUTH EAST POINTING LEAF",NULL},
/* 1F654 */ { "TURNED NORTH WEST POINTING LEAF",NULL},
/* 1F655 */ { "TURNED SOUTH WEST POINTING LEAF",NULL},
/* 1F656 */ { "TURNED NORTH EAST POINTING LEAF",NULL},
/* 1F657 */ { "TURNED SOUTH EAST POINTING LEAF",NULL},
/* 1F658 */ { "NORTH WEST POINTING VINE LEAF",NULL},
/* 1F659 */ { "SOUTH WEST POINTING VINE LEAF","	x (reversed rotated floral heart bullet - 2619)"},
/* 1F65A */ { "NORTH EAST POINTING VINE LEAF",NULL},
/* 1F65B */ { "SOUTH EAST POINTING VINE LEAF","	x (rotated floral heart bullet - 2767)"},
/* 1F65C */ { "HEAVY NORTH WEST POINTING VINE LEAF",NULL},
/* 1F65D */ { "HEAVY SOUTH WEST POINTING VINE LEAF",NULL},
/* 1F65E */ { "HEAVY NORTH EAST POINTING VINE LEAF",NULL},
/* 1F65F */ { "HEAVY SOUTH EAST POINTING VINE LEAF",NULL},
/* 1F660 */ { "NORTH WEST POINTING BUD",NULL},
/* 1F661 */ { "SOUTH WEST POINTING BUD",NULL},
/* 1F662 */ { "NORTH EAST POINTING BUD",NULL},
/* 1F663 */ { "SOUTH EAST POINTING BUD",NULL},
/* 1F664 */ { "HEAVY NORTH WEST POINTING BUD",NULL},
/* 1F665 */ { "HEAVY SOUTH WEST POINTING BUD",NULL},
/* 1F666 */ { "HEAVY NORTH EAST POINTING BUD",NULL},
/* 1F667 */ { "HEAVY SOUTH EAST POINTING BUD",NULL},
/* 1F668 */ { "HOLLOW QUILT SQUARE ORNAMENT",NULL},
/* 1F669 */ { "HOLLOW QUILT SQUARE ORNAMENT IN BLACK SQUARE",NULL},
/* 1F66A */ { "SOLID QUILT SQUARE ORNAMENT","	= fourfold knot ornament"},
/* 1F66B */ { "SOLID QUILT SQUARE ORNAMENT IN BLACK SQUARE","	= inverse fourfold knot ornament"},
/* 1F66C */ { "LEFTWARDS ROCKET","	x (rocket - 1F680)"},
/* 1F66D */ { "UPWARDS ROCKET",NULL},
/* 1F66E */ { "RIGHTWARDS ROCKET",NULL},
/* 1F66F */ { "DOWNWARDS ROCKET",NULL},
/* 1F670 */ { "SCRIPT LIGATURE ET ORNAMENT","	= italic ampersand lowercase\n"
	"	x (tironian sign et - 204A)"},
/* 1F671 */ { "HEAVY SCRIPT LIGATURE ET ORNAMENT",NULL},
/* 1F672 */ { "LIGATURE OPEN ET ORNAMENT",NULL},
/* 1F673 */ { "HEAVY LIGATURE OPEN ET ORNAMENT",NULL},
/* 1F674 */ { "HEAVY AMPERSAND ORNAMENT","	x (ampersand - 0026)"},
/* 1F675 */ { "SWASH AMPERSAND ORNAMENT","	= italic ampersand"},
/* 1F676 */ { "SANS-SERIF HEAVY DOUBLE TURNED COMMA QUOTATION MARK ORNAMENT","	x (heavy double turned comma quotation mark ornament - 275D)"},
/* 1F677 */ { "SANS-SERIF HEAVY DOUBLE COMMA QUOTATION MARK ORNAMENT","	x (heavy double comma quotation mark ornament - 275E)"},
/* 1F678 */ { "SANS-SERIF HEAVY LOW DOUBLE COMMA QUOTATION MARK ORNAMENT","	x (heavy low double comma quotation mark ornament - 2760)"},
/* 1F679 */ { "HEAVY INTERROBANG ORNAMENT","	x (interrobang - 203D)"},
/* 1F67A */ { "SANS-SERIF INTERROBANG ORNAMENT",NULL},
/* 1F67B */ { "HEAVY SANS-SERIF INTERROBANG ORNAMENT",NULL},
/* 1F67C */ { "VERY HEAVY SOLIDUS",NULL},
/* 1F67D */ { "VERY HEAVY REVERSE SOLIDUS",NULL},
/* 1F67E */ { "CHECKER BOARD","	x (quadrant upper right and lower left - 259E)"},
/* 1F67F */ { "REVERSE CHECKER BOARD","	x (quadrant upper left and lower right - 259A)"},
/* 1F680 */ { "ROCKET","	x (leftwards rocket - 1F66C)"},
/* 1F681 */ { "HELICOPTER","	x (airplane - 2708)"},
/* 1F682 */ { "STEAM LOCOMOTIVE","	x (diesel locomotive - 1F6F2)"},
/* 1F683 */ { "RAILWAY CAR",NULL},
/* 1F684 */ { "HIGH-SPEED TRAIN",NULL},
/* 1F685 */ { "HIGH-SPEED TRAIN WITH BULLET NOSE",NULL},
/* 1F686 */ { "TRAIN","	= intercity train"},
/* 1F687 */ { "METRO","	= subway, underground train"},
/* 1F688 */ { "LIGHT RAIL",NULL},
/* 1F689 */ { "STATION","	= train, subway station"},
/* 1F68A */ { "TRAM",NULL},
/* 1F68B */ { "TRAM CAR",NULL},
/* 1F68C */ { "BUS",NULL},
/* 1F68D */ { "ONCOMING BUS",NULL},
/* 1F68E */ { "TROLLEYBUS",NULL},
/* 1F68F */ { "BUS STOP",NULL},
/* 1F690 */ { "MINIBUS",NULL},
/* 1F691 */ { "AMBULANCE",NULL},
/* 1F692 */ { "FIRE ENGINE","	x (oncoming fire engine - 1F6F1)"},
/* 1F693 */ { "POLICE CAR",NULL},
/* 1F694 */ { "ONCOMING POLICE CAR",NULL},
/* 1F695 */ { "TAXI",NULL},
/* 1F696 */ { "ONCOMING TAXI",NULL},
/* 1F697 */ { "AUTOMOBILE",NULL},
/* 1F698 */ { "ONCOMING AUTOMOBILE",NULL},
/* 1F699 */ { "RECREATIONAL VEHICLE",NULL},
/* 1F69A */ { "DELIVERY TRUCK","	x (black truck - 26DF)"},
/* 1F69B */ { "ARTICULATED LORRY",NULL},
/* 1F69C */ { "TRACTOR",NULL},
/* 1F69D */ { "MONORAIL",NULL},
/* 1F69E */ { "MOUNTAIN RAILWAY",NULL},
/* 1F69F */ { "SUSPENSION RAILWAY",NULL},
/* 1F6A0 */ { "MOUNTAIN CABLEWAY",NULL},
/* 1F6A1 */ { "AERIAL TRAMWAY",NULL},
/* 1F6A2 */ { "SHIP","	= cruise line vacation\n"
	"	x (ferry - 26F4)\n"
	"	x (passenger ship - 1F6F3)"},
/* 1F6A3 */ { "ROWBOAT","	x (sailboat - 26F5)"},
/* 1F6A4 */ { "SPEEDBOAT","	x (motor boat - 1F6E5)"},
/* 1F6A5 */ { "HORIZONTAL TRAFFIC LIGHT",NULL},
/* 1F6A6 */ { "VERTICAL TRAFFIC LIGHT",NULL},
/* 1F6A7 */ { "CONSTRUCTION SIGN","	x (pick - 26CF)\n"
	"	x (building construction - 1F3D7)"},
/* 1F6A8 */ { "POLICE CARS REVOLVING LIGHT","	= rotating beacon"},
/* 1F6A9 */ { "TRIANGULAR FLAG ON POST","	= location information\n"
	"	x (flag in hole - 26F3)\n"
	"	x (white pennant - 1F3F1)"},
/* 1F6AA */ { "DOOR",NULL},
/* 1F6AB */ { "NO ENTRY SIGN","	x (combining enclosing circle backslash - 20E0)\n"
	"	x (no entry - 26D4)\n"
	"	x (prohibited sign - 1F6C7)"},
/* 1F6AC */ { "SMOKING SYMBOL",NULL},
/* 1F6AD */ { "NO SMOKING SYMBOL",NULL},
/* 1F6AE */ { "PUT LITTER IN ITS PLACE SYMBOL",NULL},
/* 1F6AF */ { "DO NOT LITTER SYMBOL",NULL},
/* 1F6B0 */ { "POTABLE WATER SYMBOL",NULL},
/* 1F6B1 */ { "NON-POTABLE WATER SYMBOL",NULL},
/* 1F6B2 */ { "BICYCLE",NULL},
/* 1F6B3 */ { "NO BICYCLES",NULL},
/* 1F6B4 */ { "BICYCLIST",NULL},
/* 1F6B5 */ { "MOUNTAIN BICYCLIST",NULL},
/* 1F6B6 */ { "PEDESTRIAN","	= walking"},
/* 1F6B7 */ { "NO PEDESTRIANS",NULL},
/* 1F6B8 */ { "CHILDREN CROSSING",NULL},
/* 1F6B9 */ { "MENS SYMBOL","	= man symbol\n"
	"	= men's restroom\n"
	"	x (stick figure - 1FBC5)"},
/* 1F6BA */ { "WOMENS SYMBOL","	= woman symbol\n"
	"	= women's restroom\n"
	"	x (stick figure with dress - 1FBC9)"},
/* 1F6BB */ { "RESTROOM","	= man and woman symbol with divider\n"
	"	= unisex restroom\n"
	"	x (man and woman holding hands - 1F46B)"},
/* 1F6BC */ { "BABY SYMBOL","	= baby on board, baby changing station"},
/* 1F6BD */ { "TOILET",NULL},
/* 1F6BE */ { "WATER CLOSET","	x (squared wc - 1F14F)\n"
	"	x (negative squared wc - 1F18F)"},
/* 1F6BF */ { "SHOWER",NULL},
/* 1F6C0 */ { "BATH",NULL},
/* 1F6C1 */ { "BATHTUB",NULL},
/* 1F6C2 */ { "PASSPORT CONTROL",NULL},
/* 1F6C3 */ { "CUSTOMS",NULL},
/* 1F6C4 */ { "BAGGAGE CLAIM",NULL},
/* 1F6C5 */ { "LEFT LUGGAGE",NULL},
/* 1F6C6 */ { "TRIANGLE WITH ROUNDED CORNERS","	= caution\n"
	"	x (white up-pointing triangle - 25B3)"},
/* 1F6C7 */ { "PROHIBITED SIGN","	x (combining enclosing circle backslash - 20E0)\n"
	"	x (no entry sign - 1F6AB)"},
/* 1F6C8 */ { "CIRCLED INFORMATION SOURCE","	= information\n"
	"	x (information source - 2139)"},
/* 1F6C9 */ { "BOYS SYMBOL",NULL},
/* 1F6CA */ { "GIRLS SYMBOL",NULL},
/* 1F6CB */ { "COUCH AND LAMP","	= furniture, lifestyles"},
/* 1F6CC */ { "SLEEPING ACCOMMODATION","	= hotel, guestrooms\n"
	"	x (hotel - 1F3E8)"},
/* 1F6CD */ { "SHOPPING BAGS","	= shopping"},
/* 1F6CE */ { "BELLHOP BELL","	= reception, services"},
/* 1F6CF */ { "BED",NULL},
/* 1F6D0 */ { "PLACE OF WORSHIP",NULL},
/* 1F6D1 */ { "OCTAGONAL SIGN","	= stop sign\n"
	"	* may contain text indicating stop\n"
	"	x (warning sign - 26A0)\n"
	"	x (heavy white down-pointing triangle - 26DB)\n"
	"	x (horizontal black octagon - 2BC3)"},
/* 1F6D2 */ { "SHOPPING TROLLEY","	= shopping cart"},
/* 1F6D3 */ { "STUPA",NULL},
/* 1F6D4 */ { "PAGODA",NULL},
/* 1F6D5 */ { "HINDU TEMPLE",NULL},
/* 1F6D6 */ { "HUT",NULL},
/* 1F6D7 */ { "ELEVATOR",NULL},
/* 1F6D8 */ { "LANDSLIDE",NULL},
/* 1F6D9 */ { NULL,NULL},
/* 1F6DA */ { NULL,NULL},
/* 1F6DB */ { NULL,NULL},
/* 1F6DC */ { "WIRELESS",NULL},
/* 1F6DD */ { "PLAYGROUND SLIDE",NULL},
/* 1F6DE */ { "WHEEL",NULL},
/* 1F6DF */ { "RING BUOY",NULL},
/* 1F6E0 */ { "HAMMER AND WRENCH","	= tools, repair facility\n"
	"	x (hammer and pick - 2692)"},
/* 1F6E1 */ { "SHIELD","	= US road interstate highway"},
/* 1F6E2 */ { "OIL DRUM","	= commodities"},
/* 1F6E3 */ { "MOTORWAY",NULL},
/* 1F6E4 */ { "RAILWAY TRACK","	= railroad"},
/* 1F6E5 */ { "MOTOR BOAT","	= boat\n"
	"	x (speedboat - 1F6A4)"},
/* 1F6E6 */ { "UP-POINTING MILITARY AIRPLANE","	= military airport"},
/* 1F6E7 */ { "UP-POINTING AIRPLANE","	= commercial airport\n"
	"	x (airplane - 2708)"},
/* 1F6E8 */ { "UP-POINTING SMALL AIRPLANE","	= airfield"},
/* 1F6E9 */ { "SMALL AIRPLANE",NULL},
/* 1F6EA */ { "NORTHEAST-POINTING AIRPLANE",NULL},
/* 1F6EB */ { "AIRPLANE DEPARTURE","	= departures"},
/* 1F6EC */ { "AIRPLANE ARRIVING","	= arrivals"},
/* 1F6ED */ { NULL,NULL},
/* 1F6EE */ { NULL,NULL},
/* 1F6EF */ { NULL,NULL},
/* 1F6F0 */ { "SATELLITE",NULL},
/* 1F6F1 */ { "ONCOMING FIRE ENGINE","	= fire\n"
	"	x (fire engine - 1F692)"},
/* 1F6F2 */ { "DIESEL LOCOMOTIVE","	= train\n"
	"	x (steam locomotive - 1F682)\n"
	"	x (train - 1F686)"},
/* 1F6F3 */ { "PASSENGER SHIP","	= cruise line vacation\n"
	"	x (ship - 1F6A2)"},
/* 1F6F4 */ { "SCOOTER",NULL},
/* 1F6F5 */ { "MOTOR SCOOTER",NULL},
/* 1F6F6 */ { "CANOE",NULL},
/* 1F6F7 */ { "SLED","	= sledge, toboggan"},
/* 1F6F8 */ { "FLYING SAUCER","	= UFO\n"
	"	x (flying saucer symbol - 1CCFB)\n"
	"	x (extraterrestrial alien - 1F47D)"},
/* 1F6F9 */ { "SKATEBOARD",NULL},
/* 1F6FA */ { "AUTO RICKSHAW","	= tuk-tuk, remorque"},
/* 1F6FB */ { "PICKUP TRUCK",NULL},
/* 1F6FC */ { "ROLLER SKATE",NULL},
/* 1F6FD */ { NULL,NULL},
/* 1F6FE */ { NULL,NULL},
/* 1F6FF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_F7[] = {
/* 1F700 */ { "ALCHEMICAL SYMBOL FOR QUINTESSENCE",NULL},
/* 1F701 */ { "ALCHEMICAL SYMBOL FOR AIR",NULL},
/* 1F702 */ { "ALCHEMICAL SYMBOL FOR FIRE","	x (white up-pointing triangle - 25B3)"},
/* 1F703 */ { "ALCHEMICAL SYMBOL FOR EARTH","	x (earth - 2641)"},
/* 1F704 */ { "ALCHEMICAL SYMBOL FOR WATER","	x (white down-pointing triangle - 25BD)"},
/* 1F705 */ { "ALCHEMICAL SYMBOL FOR AQUAFORTIS",NULL},
/* 1F706 */ { "ALCHEMICAL SYMBOL FOR AQUA REGIA",NULL},
/* 1F707 */ { "ALCHEMICAL SYMBOL FOR AQUA REGIA-2","	= balneum arenae (sand bath), lapis armenus (Armenian stone)"},
/* 1F708 */ { "ALCHEMICAL SYMBOL FOR AQUA VITAE","	= spiritus vini"},
/* 1F709 */ { "ALCHEMICAL SYMBOL FOR AQUA VITAE-2",NULL},
/* 1F70A */ { "ALCHEMICAL SYMBOL FOR VINEGAR","	= crucible; acid; distill; atrament; vitriol; red sulfur; borax; wine; alkali salt; mercurius vivus, quick silver\n"
	"	x (cross of jerusalem - 2629)"},
/* 1F70B */ { "ALCHEMICAL SYMBOL FOR VINEGAR-2","	= distilled vinegar"},
/* 1F70C */ { "ALCHEMICAL SYMBOL FOR VINEGAR-3",NULL},
/* 1F70D */ { "ALCHEMICAL SYMBOL FOR SULFUR","	= brimstone"},
/* 1F70E */ { "ALCHEMICAL SYMBOL FOR PHILOSOPHERS SULFUR",NULL},
/* 1F70F */ { "ALCHEMICAL SYMBOL FOR BLACK SULFUR","	= sulfur nigra, dye"},
/* 1F710 */ { "ALCHEMICAL SYMBOL FOR MERCURY SUBLIMATE","	x (mercury - 263F)\n"
	"	x (alchemical symbol for sublimation - 1F75E)"},
/* 1F711 */ { "ALCHEMICAL SYMBOL FOR MERCURY SUBLIMATE-2",NULL},
/* 1F712 */ { "ALCHEMICAL SYMBOL FOR MERCURY SUBLIMATE-3",NULL},
/* 1F713 */ { "ALCHEMICAL SYMBOL FOR CINNABAR",NULL},
/* 1F714 */ { "ALCHEMICAL SYMBOL FOR SALT","	x (white square - 25A1)\n"
	"	x (circled minus - 2296)"},
/* 1F715 */ { "ALCHEMICAL SYMBOL FOR NITRE","	x (circled vertical bar - 29B6)"},
/* 1F716 */ { "ALCHEMICAL SYMBOL FOR VITRIOL",NULL},
/* 1F717 */ { "ALCHEMICAL SYMBOL FOR VITRIOL-2",NULL},
/* 1F718 */ { "ALCHEMICAL SYMBOL FOR ROCK SALT","	= sal gemmae"},
/* 1F719 */ { "ALCHEMICAL SYMBOL FOR ROCK SALT-2",NULL},
/* 1F71A */ { "ALCHEMICAL SYMBOL FOR GOLD","	x (sun - 2609)"},
/* 1F71B */ { "ALCHEMICAL SYMBOL FOR SILVER","	x (first quarter moon - 263D)\n"
	"	x (last quarter moon - 263E)"},
/* 1F71C */ { "ALCHEMICAL SYMBOL FOR IRON ORE","	x (male sign - 2642)"},
/* 1F71D */ { "ALCHEMICAL SYMBOL FOR IRON ORE-2",NULL},
/* 1F71E */ { "ALCHEMICAL SYMBOL FOR CROCUS OF IRON","	= crocus martis, red or yellow calcined powder of iron\n"
	"	x (male with stroke sign - 26A6)"},
/* 1F71F */ { "ALCHEMICAL SYMBOL FOR REGULUS OF IRON","	= regulus martis, scoria from refining stibnite/antimony with iron"},
/* 1F720 */ { "ALCHEMICAL SYMBOL FOR COPPER ORE","	x (female sign - 2640)"},
/* 1F721 */ { "ALCHEMICAL SYMBOL FOR IRON-COPPER ORE","	x (male and female sign - 26A5)"},
/* 1F722 */ { "ALCHEMICAL SYMBOL FOR SUBLIMATE OF COPPER","	x (alchemical symbol for sal-ammoniac - 1F739)"},
/* 1F723 */ { "ALCHEMICAL SYMBOL FOR CROCUS OF COPPER","	= crocus veneris, aes ustum"},
/* 1F724 */ { "ALCHEMICAL SYMBOL FOR CROCUS OF COPPER-2",NULL},
/* 1F725 */ { "ALCHEMICAL SYMBOL FOR COPPER ANTIMONIATE","	= crocus of copper, crocus veneris, lapis haematites\n"
	"	x (earth - 2641)"},
/* 1F726 */ { "ALCHEMICAL SYMBOL FOR SALT OF COPPER ANTIMONIATE","	x (alchemical symbol for salt - 1F714)"},
/* 1F727 */ { "ALCHEMICAL SYMBOL FOR SUBLIMATE OF SALT OF COPPER","	x (alchemical symbol for sal-ammoniac - 1F739)"},
/* 1F728 */ { "ALCHEMICAL SYMBOL FOR VERDIGRIS","	= aes viride, copper subacetate\n"
	"	= astronomical symbol for earth\n"
	"	x (circled plus - 2295)\n"
	"	x (earth - 2641)"},
/* 1F729 */ { "ALCHEMICAL SYMBOL FOR TIN ORE","	x (jupiter - 2643)"},
/* 1F72A */ { "ALCHEMICAL SYMBOL FOR LEAD ORE","	x (saturn - 2644)"},
/* 1F72B */ { "ALCHEMICAL SYMBOL FOR ANTIMONY ORE","	= stibnite\n"
	"	x (earth - 2641)"},
/* 1F72C */ { "ALCHEMICAL SYMBOL FOR SUBLIMATE OF ANTIMONY","	x (alchemical symbol for sal-ammoniac - 1F739)"},
/* 1F72D */ { "ALCHEMICAL SYMBOL FOR SALT OF ANTIMONY","	= cinnabar\n"
	"	x (alchemical symbol for salt - 1F714)"},
/* 1F72E */ { "ALCHEMICAL SYMBOL FOR SUBLIMATE OF SALT OF ANTIMONY",NULL},
/* 1F72F */ { "ALCHEMICAL SYMBOL FOR VINEGAR OF ANTIMONY",NULL},
/* 1F730 */ { "ALCHEMICAL SYMBOL FOR REGULUS OF ANTIMONY","	= antimony metal"},
/* 1F731 */ { "ALCHEMICAL SYMBOL FOR REGULUS OF ANTIMONY-2",NULL},
/* 1F732 */ { "ALCHEMICAL SYMBOL FOR REGULUS",NULL},
/* 1F733 */ { "ALCHEMICAL SYMBOL FOR REGULUS-2",NULL},
/* 1F734 */ { "ALCHEMICAL SYMBOL FOR REGULUS-3",NULL},
/* 1F735 */ { "ALCHEMICAL SYMBOL FOR REGULUS-4",NULL},
/* 1F736 */ { "ALCHEMICAL SYMBOL FOR ALKALI","	= sal alkali"},
/* 1F737 */ { "ALCHEMICAL SYMBOL FOR ALKALI-2",NULL},
/* 1F738 */ { "ALCHEMICAL SYMBOL FOR MARCASITE","	= iron pyrite, iron sulfide"},
/* 1F739 */ { "ALCHEMICAL SYMBOL FOR SAL-AMMONIAC","	= ammonium chloride\n"
	"	x (asterisk - 002A)\n"
	"	x (sextile - 26B9)\n"
	"	x (eight spoked asterisk - 2733)"},
/* 1F73A */ { "ALCHEMICAL SYMBOL FOR ARSENIC","	x (double-ended multimap - 29DF)"},
/* 1F73B */ { "ALCHEMICAL SYMBOL FOR REALGAR","	= arsenic sulfide"},
/* 1F73C */ { "ALCHEMICAL SYMBOL FOR REALGAR-2","	= arsenic sulfide"},
/* 1F73D */ { "ALCHEMICAL SYMBOL FOR AURIPIGMENT","	= orpiment\n"
	"	= arsenic trisulfide"},
/* 1F73E */ { "ALCHEMICAL SYMBOL FOR BISMUTH ORE","	= tinglass\n"
	"	x (neptune - 2646)"},
/* 1F73F */ { "ALCHEMICAL SYMBOL FOR TARTAR","	= impure potassium tartrate"},
/* 1F740 */ { "ALCHEMICAL SYMBOL FOR TARTAR-2","	= impure potassium tartrate"},
/* 1F741 */ { "ALCHEMICAL SYMBOL FOR QUICK LIME","	= calx viva\n"
	"	= calcium oxide"},
/* 1F742 */ { "ALCHEMICAL SYMBOL FOR BORAX",NULL},
/* 1F743 */ { "ALCHEMICAL SYMBOL FOR BORAX-2",NULL},
/* 1F744 */ { "ALCHEMICAL SYMBOL FOR BORAX-3",NULL},
/* 1F745 */ { "ALCHEMICAL SYMBOL FOR ALUM",NULL},
/* 1F746 */ { "ALCHEMICAL SYMBOL FOR OIL","	x (tibetan sign rdel dkar gsum - 0F1C)"},
/* 1F747 */ { "ALCHEMICAL SYMBOL FOR SPIRIT",NULL},
/* 1F748 */ { "ALCHEMICAL SYMBOL FOR TINCTURE",NULL},
/* 1F749 */ { "ALCHEMICAL SYMBOL FOR GUM",NULL},
/* 1F74A */ { "ALCHEMICAL SYMBOL FOR WAX","	= cera"},
/* 1F74B */ { "ALCHEMICAL SYMBOL FOR POWDER","	= pulvis"},
/* 1F74C */ { "ALCHEMICAL SYMBOL FOR CALX","	= calcinare\n"
	"	= oxide residue, calcium oxide"},
/* 1F74D */ { "ALCHEMICAL SYMBOL FOR TUTTY","	= tutia, crude zinc oxide sublimate\n"
	"	= aes viride"},
/* 1F74E */ { "ALCHEMICAL SYMBOL FOR CAPUT MORTUUM","	= worthless residue of sublimation or distillation"},
/* 1F74F */ { "ALCHEMICAL SYMBOL FOR SCEPTER OF JOVE",NULL},
/* 1F750 */ { "ALCHEMICAL SYMBOL FOR CADUCEUS","	x (caduceus - 2624)"},
/* 1F751 */ { "ALCHEMICAL SYMBOL FOR TRIDENT",NULL},
/* 1F752 */ { "ALCHEMICAL SYMBOL FOR STARRED TRIDENT",NULL},
/* 1F753 */ { "ALCHEMICAL SYMBOL FOR LODESTONE","	= magnes"},
/* 1F754 */ { "ALCHEMICAL SYMBOL FOR SOAP","	x (lozenge - 25CA)\n"
	"	x (white medium diamond - 2B26)"},
/* 1F755 */ { "ALCHEMICAL SYMBOL FOR URINE","	x (squared dot operator - 22A1)"},
/* 1F756 */ { "ALCHEMICAL SYMBOL FOR HORSE DUNG","	= fimus equinus"},
/* 1F757 */ { "ALCHEMICAL SYMBOL FOR ASHES","	= cineres"},
/* 1F758 */ { "ALCHEMICAL SYMBOL FOR POT ASHES","	= cineres clavellati, alumen"},
/* 1F759 */ { "ALCHEMICAL SYMBOL FOR BRICK",NULL},
/* 1F75A */ { "ALCHEMICAL SYMBOL FOR POWDERED BRICK","	= later cibratus, farina laterum"},
/* 1F75B */ { "ALCHEMICAL SYMBOL FOR AMALGAM",NULL},
/* 1F75C */ { "ALCHEMICAL SYMBOL FOR STRATUM SUPER STRATUM",NULL},
/* 1F75D */ { "ALCHEMICAL SYMBOL FOR STRATUM SUPER STRATUM-2",NULL},
/* 1F75E */ { "ALCHEMICAL SYMBOL FOR SUBLIMATION","	x (ascending node - 260A)\n"
	"	x (libra - 264E)"},
/* 1F75F */ { "ALCHEMICAL SYMBOL FOR PRECIPITATE",NULL},
/* 1F760 */ { "ALCHEMICAL SYMBOL FOR DISTILL","	= sublimate"},
/* 1F761 */ { "ALCHEMICAL SYMBOL FOR DISSOLVE","	x (latin small letter f with hook - 0192)\n"
	"	x (finite part integral - 2A0D)"},
/* 1F762 */ { "ALCHEMICAL SYMBOL FOR DISSOLVE-2","	= water, aqua"},
/* 1F763 */ { "ALCHEMICAL SYMBOL FOR PURIFY","	x (descending node - 260B)"},
/* 1F764 */ { "ALCHEMICAL SYMBOL FOR PUTREFACTION",NULL},
/* 1F765 */ { "ALCHEMICAL SYMBOL FOR CRUCIBLE","	= tigillum\n"
	"	x (alchemical symbol for vinegar - 1F70A)"},
/* 1F766 */ { "ALCHEMICAL SYMBOL FOR CRUCIBLE-2",NULL},
/* 1F767 */ { "ALCHEMICAL SYMBOL FOR CRUCIBLE-3",NULL},
/* 1F768 */ { "ALCHEMICAL SYMBOL FOR CRUCIBLE-4","	x (latin capital letter t with stroke - 0166)"},
/* 1F769 */ { "ALCHEMICAL SYMBOL FOR CRUCIBLE-5",NULL},
/* 1F76A */ { "ALCHEMICAL SYMBOL FOR ALEMBIC",NULL},
/* 1F76B */ { "ALCHEMICAL SYMBOL FOR BATH OF MARY","	= balneum mariae"},
/* 1F76C */ { "ALCHEMICAL SYMBOL FOR BATH OF VAPOURS","	= balneum vaporis"},
/* 1F76D */ { "ALCHEMICAL SYMBOL FOR RETORT","	x (alembic - 2697)"},
/* 1F76E */ { "ALCHEMICAL SYMBOL FOR HOUR","	x (hourglass - 231B)\n"
	"	x (white hourglass - 29D6)"},
/* 1F76F */ { "ALCHEMICAL SYMBOL FOR NIGHT",NULL},
/* 1F770 */ { "ALCHEMICAL SYMBOL FOR DAY-NIGHT",NULL},
/* 1F771 */ { "ALCHEMICAL SYMBOL FOR MONTH","	= mensis\n"
	"	x (squared times - 22A0)"},
/* 1F772 */ { "ALCHEMICAL SYMBOL FOR HALF DRAM","	= drachma semis\n"
	"	* handwritten ligature of 0292 + 00DF, typically spelled out as ʒss\n"
	"	x (latin small letter ezh - 0292)"},
/* 1F773 */ { "ALCHEMICAL SYMBOL FOR HALF OUNCE","	= uncia semis\n"
	"	* handwritten ligature of 2125 + 00DF, typically spelled out as 2125 ss\n"
	"	x (ounce sign - 2125)"},
/* 1F774 */ { "LOT OF FORTUNE","	= pars fortunae\n"
	"	x (circled times - 2297)"},
/* 1F775 */ { "OCCULTATION","	x (conjunction - 260C)"},
/* 1F776 */ { "LUNAR ECLIPSE","	x (opposition - 260D)"},
/* 1F777 */ { "VESTA FORM TWO","	x (vesta - 26B6)"},
/* 1F778 */ { "ASTRAEA FORM TWO","	x (astraea - 2BD9)"},
/* 1F779 */ { "HYGIEA FORM TWO","	x (hygiea - 2BDA)"},
/* 1F77A */ { "PARTHENOPE FORM TWO","	= Lyra\n"
	"	x (parthenope - 1CEC4)"},
/* 1F77B */ { "HAUMEA",NULL},
/* 1F77C */ { "MAKEMAKE",NULL},
/* 1F77D */ { "GONGGONG",NULL},
/* 1F77E */ { "QUAOAR",NULL},
/* 1F77F */ { "ORCUS",NULL},
/* 1F780 */ { "BLACK LEFT-POINTING ISOSCELES RIGHT TRIANGLE","	x (black medium left-pointing triangle - 23F4)"},
/* 1F781 */ { "BLACK UP-POINTING ISOSCELES RIGHT TRIANGLE","	x (black medium up-pointing triangle - 23F6)"},
/* 1F782 */ { "BLACK RIGHT-POINTING ISOSCELES RIGHT TRIANGLE","	x (black medium right-pointing triangle - 23F5)"},
/* 1F783 */ { "BLACK DOWN-POINTING ISOSCELES RIGHT TRIANGLE","	x (black medium down-pointing triangle - 23F7)"},
/* 1F784 */ { "BLACK SLIGHTLY SMALL CIRCLE",NULL},
/* 1F785 */ { "MEDIUM BOLD WHITE CIRCLE","	x (medium white circle - 26AA)"},
/* 1F786 */ { "BOLD WHITE CIRCLE",NULL},
/* 1F787 */ { "HEAVY WHITE CIRCLE",NULL},
/* 1F788 */ { "VERY HEAVY WHITE CIRCLE",NULL},
/* 1F789 */ { "EXTREMELY HEAVY WHITE CIRCLE",NULL},
/* 1F78A */ { "WHITE CIRCLE CONTAINING BLACK SMALL CIRCLE",NULL},
/* 1F78B */ { "ROUND TARGET","	x (bullseye - 25CE)\n"
	"	x (circled white bullet - 29BE)\n"
	"	x (heavy circle with circle inside - 2B57)"},
/* 1F78C */ { "BLACK TINY SQUARE",NULL},
/* 1F78D */ { "BLACK SLIGHTLY SMALL SQUARE",NULL},
/* 1F78E */ { "LIGHT WHITE SQUARE",NULL},
/* 1F78F */ { "MEDIUM WHITE SQUARE",NULL},
/* 1F790 */ { "BOLD WHITE SQUARE","	= heavy white square"},
/* 1F791 */ { "HEAVY WHITE SQUARE",NULL},
/* 1F792 */ { "VERY HEAVY WHITE SQUARE",NULL},
/* 1F793 */ { "EXTREMELY HEAVY WHITE SQUARE",NULL},
/* 1F794 */ { "WHITE SQUARE CONTAINING BLACK VERY SMALL SQUARE",NULL},
/* 1F795 */ { "WHITE SQUARE CONTAINING BLACK MEDIUM SQUARE",NULL},
/* 1F796 */ { "SQUARE TARGET",NULL},
/* 1F797 */ { "BLACK TINY DIAMOND",NULL},
/* 1F798 */ { "BLACK VERY SMALL DIAMOND",NULL},
/* 1F799 */ { "BLACK MEDIUM SMALL DIAMOND",NULL},
/* 1F79A */ { "WHITE DIAMOND CONTAINING BLACK VERY SMALL DIAMOND",NULL},
/* 1F79B */ { "WHITE DIAMOND CONTAINING BLACK MEDIUM DIAMOND",NULL},
/* 1F79C */ { "DIAMOND TARGET",NULL},
/* 1F79D */ { "BLACK TINY LOZENGE",NULL},
/* 1F79E */ { "BLACK VERY SMALL LOZENGE",NULL},
/* 1F79F */ { "BLACK MEDIUM SMALL LOZENGE",NULL},
/* 1F7A0 */ { "WHITE LOZENGE CONTAINING BLACK SMALL LOZENGE",NULL},
/* 1F7A1 */ { "THIN GREEK CROSS",NULL},
/* 1F7A2 */ { "LIGHT GREEK CROSS",NULL},
/* 1F7A3 */ { "MEDIUM GREEK CROSS",NULL},
/* 1F7A4 */ { "BOLD GREEK CROSS",NULL},
/* 1F7A5 */ { "VERY BOLD GREEK CROSS","	x (heavy greek cross - 271A)"},
/* 1F7A6 */ { "VERY HEAVY GREEK CROSS",NULL},
/* 1F7A7 */ { "EXTREMELY HEAVY GREEK CROSS",NULL},
/* 1F7A8 */ { "THIN SALTIRE","	x (multiplication x - 2715)"},
/* 1F7A9 */ { "LIGHT SALTIRE","	x (saltire - 2613)"},
/* 1F7AA */ { "MEDIUM SALTIRE",NULL},
/* 1F7AB */ { "BOLD SALTIRE",NULL},
/* 1F7AC */ { "HEAVY SALTIRE",NULL},
/* 1F7AD */ { "VERY HEAVY SALTIRE",NULL},
/* 1F7AE */ { "EXTREMELY HEAVY SALTIRE","	x (heavy multiplication x - 2716)"},
/* 1F7AF */ { "LIGHT FIVE SPOKED ASTERISK",NULL},
/* 1F7B0 */ { "MEDIUM FIVE SPOKED ASTERISK",NULL},
/* 1F7B1 */ { "BOLD FIVE SPOKED ASTERISK",NULL},
/* 1F7B2 */ { "HEAVY FIVE SPOKED ASTERISK",NULL},
/* 1F7B3 */ { "VERY HEAVY FIVE SPOKED ASTERISK",NULL},
/* 1F7B4 */ { "EXTREMELY HEAVY FIVE SPOKED ASTERISK",NULL},
/* 1F7B5 */ { "LIGHT SIX SPOKED ASTERISK",NULL},
/* 1F7B6 */ { "MEDIUM SIX SPOKED ASTERISK","	* may represent the \"star\" symbol devised in ITU-T E.161 for use on telephony devices"},
/* 1F7B7 */ { "BOLD SIX SPOKED ASTERISK",NULL},
/* 1F7B8 */ { "HEAVY SIX SPOKED ASTERISK","	x (heavy asterisk - 2731)"},
/* 1F7B9 */ { "VERY HEAVY SIX SPOKED ASTERISK",NULL},
/* 1F7BA */ { "EXTREMELY HEAVY SIX SPOKED ASTERISK",NULL},
/* 1F7BB */ { "LIGHT EIGHT SPOKED ASTERISK","	x (eight spoked asterisk - 2733)"},
/* 1F7BC */ { "MEDIUM EIGHT SPOKED ASTERISK",NULL},
/* 1F7BD */ { "BOLD EIGHT SPOKED ASTERISK",NULL},
/* 1F7BE */ { "HEAVY EIGHT SPOKED ASTERISK",NULL},
/* 1F7BF */ { "VERY HEAVY EIGHT SPOKED ASTERISK",NULL},
/* 1F7C0 */ { "LIGHT THREE POINTED BLACK STAR",NULL},
/* 1F7C1 */ { "MEDIUM THREE POINTED BLACK STAR",NULL},
/* 1F7C2 */ { "THREE POINTED BLACK STAR",NULL},
/* 1F7C3 */ { "MEDIUM THREE POINTED PINWHEEL STAR",NULL},
/* 1F7C4 */ { "LIGHT FOUR POINTED BLACK STAR",NULL},
/* 1F7C5 */ { "MEDIUM FOUR POINTED BLACK STAR",NULL},
/* 1F7C6 */ { "FOUR POINTED BLACK STAR","	* 2726 is a cusp\n"
	"	x (black four pointed star - 2726)"},
/* 1F7C7 */ { "MEDIUM FOUR POINTED PINWHEEL STAR",NULL},
/* 1F7C8 */ { "REVERSE LIGHT FOUR POINTED PINWHEEL STAR","	= navigate"},
/* 1F7C9 */ { "LIGHT FIVE POINTED BLACK STAR",NULL},
/* 1F7CA */ { "HEAVY FIVE POINTED BLACK STAR",NULL},
/* 1F7CB */ { "MEDIUM SIX POINTED BLACK STAR",NULL},
/* 1F7CC */ { "HEAVY SIX POINTED BLACK STAR",NULL},
/* 1F7CD */ { "SIX POINTED PINWHEEL STAR",NULL},
/* 1F7CE */ { "MEDIUM EIGHT POINTED BLACK STAR","	x (eight pointed rectilinear black star - 2737)"},
/* 1F7CF */ { "HEAVY EIGHT POINTED BLACK STAR","	x (heavy eight pointed rectilinear black star - 2738)"},
/* 1F7D0 */ { "VERY HEAVY EIGHT POINTED BLACK STAR",NULL},
/* 1F7D1 */ { "HEAVY EIGHT POINTED PINWHEEL STAR","	x (eight pointed pinwheel star - 2735)"},
/* 1F7D2 */ { "LIGHT TWELVE POINTED BLACK STAR",NULL},
/* 1F7D3 */ { "HEAVY TWELVE POINTED BLACK STAR",NULL},
/* 1F7D4 */ { "HEAVY TWELVE POINTED PINWHEEL STAR",NULL},
/* 1F7D5 */ { "CIRCLED TRIANGLE",NULL},
/* 1F7D6 */ { "NEGATIVE CIRCLED TRIANGLE",NULL},
/* 1F7D7 */ { "CIRCLED SQUARE",NULL},
/* 1F7D8 */ { "NEGATIVE CIRCLED SQUARE",NULL},
/* 1F7D9 */ { "NINE POINTED WHITE STAR","	* commonly used by members of the Bahá'í faith"},
/* 1F7DA */ { NULL,NULL},
/* 1F7DB */ { NULL,NULL},
/* 1F7DC */ { NULL,NULL},
/* 1F7DD */ { NULL,NULL},
/* 1F7DE */ { NULL,NULL},
/* 1F7DF */ { NULL,NULL},
/* 1F7E0 */ { "LARGE ORANGE CIRCLE",NULL},
/* 1F7E1 */ { "LARGE YELLOW CIRCLE",NULL},
/* 1F7E2 */ { "LARGE GREEN CIRCLE",NULL},
/* 1F7E3 */ { "LARGE PURPLE CIRCLE",NULL},
/* 1F7E4 */ { "LARGE BROWN CIRCLE",NULL},
/* 1F7E5 */ { "LARGE RED SQUARE",NULL},
/* 1F7E6 */ { "LARGE BLUE SQUARE",NULL},
/* 1F7E7 */ { "LARGE ORANGE SQUARE",NULL},
/* 1F7E8 */ { "LARGE YELLOW SQUARE",NULL},
/* 1F7E9 */ { "LARGE GREEN SQUARE",NULL},
/* 1F7EA */ { "LARGE PURPLE SQUARE",NULL},
/* 1F7EB */ { "LARGE BROWN SQUARE",NULL},
/* 1F7EC */ { NULL,NULL},
/* 1F7ED */ { NULL,NULL},
/* 1F7EE */ { NULL,NULL},
/* 1F7EF */ { NULL,NULL},
/* 1F7F0 */ { "HEAVY EQUALS SIGN","	* symbol of equality\n"
	"	x (equals sign - 003D)\n"
	"	x (heavy multiplication x - 2716)\n"
	"	x (heavy plus sign - 2795)\n"
	"	x (geta mark - 3013)\n"
	"	x (roman sextans sign - 10190)"},
/* 1F7F1 */ { NULL,NULL},
/* 1F7F2 */ { NULL,NULL},
/* 1F7F3 */ { NULL,NULL},
/* 1F7F4 */ { NULL,NULL},
/* 1F7F5 */ { NULL,NULL},
/* 1F7F6 */ { NULL,NULL},
/* 1F7F7 */ { NULL,NULL},
/* 1F7F8 */ { NULL,NULL},
/* 1F7F9 */ { NULL,NULL},
/* 1F7FA */ { NULL,NULL},
/* 1F7FB */ { NULL,NULL},
/* 1F7FC */ { NULL,NULL},
/* 1F7FD */ { NULL,NULL},
/* 1F7FE */ { NULL,NULL},
/* 1F7FF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_F8[] = {
/* 1F800 */ { "LEFTWARDS ARROW WITH SMALL TRIANGLE ARROWHEAD",NULL},
/* 1F801 */ { "UPWARDS ARROW WITH SMALL TRIANGLE ARROWHEAD",NULL},
/* 1F802 */ { "RIGHTWARDS ARROW WITH SMALL TRIANGLE ARROWHEAD",NULL},
/* 1F803 */ { "DOWNWARDS ARROW WITH SMALL TRIANGLE ARROWHEAD",NULL},
/* 1F804 */ { "LEFTWARDS ARROW WITH MEDIUM TRIANGLE ARROWHEAD",NULL},
/* 1F805 */ { "UPWARDS ARROW WITH MEDIUM TRIANGLE ARROWHEAD",NULL},
/* 1F806 */ { "RIGHTWARDS ARROW WITH MEDIUM TRIANGLE ARROWHEAD",NULL},
/* 1F807 */ { "DOWNWARDS ARROW WITH MEDIUM TRIANGLE ARROWHEAD",NULL},
/* 1F808 */ { "LEFTWARDS ARROW WITH LARGE TRIANGLE ARROWHEAD",NULL},
/* 1F809 */ { "UPWARDS ARROW WITH LARGE TRIANGLE ARROWHEAD",NULL},
/* 1F80A */ { "RIGHTWARDS ARROW WITH LARGE TRIANGLE ARROWHEAD",NULL},
/* 1F80B */ { "DOWNWARDS ARROW WITH LARGE TRIANGLE ARROWHEAD",NULL},
/* 1F80C */ { NULL,NULL},
/* 1F80D */ { NULL,NULL},
/* 1F80E */ { NULL,NULL},
/* 1F80F */ { NULL,NULL},
/* 1F810 */ { "LEFTWARDS ARROW WITH SMALL EQUILATERAL ARROWHEAD",NULL},
/* 1F811 */ { "UPWARDS ARROW WITH SMALL EQUILATERAL ARROWHEAD",NULL},
/* 1F812 */ { "RIGHTWARDS ARROW WITH SMALL EQUILATERAL ARROWHEAD",NULL},
/* 1F813 */ { "DOWNWARDS ARROW WITH SMALL EQUILATERAL ARROWHEAD",NULL},
/* 1F814 */ { "LEFTWARDS ARROW WITH EQUILATERAL ARROWHEAD",NULL},
/* 1F815 */ { "UPWARDS ARROW WITH EQUILATERAL ARROWHEAD",NULL},
/* 1F816 */ { "RIGHTWARDS ARROW WITH EQUILATERAL ARROWHEAD",NULL},
/* 1F817 */ { "DOWNWARDS ARROW WITH EQUILATERAL ARROWHEAD",NULL},
/* 1F818 */ { "HEAVY LEFTWARDS ARROW WITH EQUILATERAL ARROWHEAD",NULL},
/* 1F819 */ { "HEAVY UPWARDS ARROW WITH EQUILATERAL ARROWHEAD",NULL},
/* 1F81A */ { "HEAVY RIGHTWARDS ARROW WITH EQUILATERAL ARROWHEAD",NULL},
/* 1F81B */ { "HEAVY DOWNWARDS ARROW WITH EQUILATERAL ARROWHEAD",NULL},
/* 1F81C */ { "HEAVY LEFTWARDS ARROW WITH LARGE EQUILATERAL ARROWHEAD",NULL},
/* 1F81D */ { "HEAVY UPWARDS ARROW WITH LARGE EQUILATERAL ARROWHEAD",NULL},
/* 1F81E */ { "HEAVY RIGHTWARDS ARROW WITH LARGE EQUILATERAL ARROWHEAD",NULL},
/* 1F81F */ { "HEAVY DOWNWARDS ARROW WITH LARGE EQUILATERAL ARROWHEAD",NULL},
/* 1F820 */ { "LEFTWARDS TRIANGLE-HEADED ARROW WITH NARROW SHAFT",NULL},
/* 1F821 */ { "UPWARDS TRIANGLE-HEADED ARROW WITH NARROW SHAFT",NULL},
/* 1F822 */ { "RIGHTWARDS TRIANGLE-HEADED ARROW WITH NARROW SHAFT",NULL},
/* 1F823 */ { "DOWNWARDS TRIANGLE-HEADED ARROW WITH NARROW SHAFT",NULL},
/* 1F824 */ { "LEFTWARDS TRIANGLE-HEADED ARROW WITH MEDIUM SHAFT",NULL},
/* 1F825 */ { "UPWARDS TRIANGLE-HEADED ARROW WITH MEDIUM SHAFT",NULL},
/* 1F826 */ { "RIGHTWARDS TRIANGLE-HEADED ARROW WITH MEDIUM SHAFT",NULL},
/* 1F827 */ { "DOWNWARDS TRIANGLE-HEADED ARROW WITH MEDIUM SHAFT",NULL},
/* 1F828 */ { "LEFTWARDS TRIANGLE-HEADED ARROW WITH BOLD SHAFT",NULL},
/* 1F829 */ { "UPWARDS TRIANGLE-HEADED ARROW WITH BOLD SHAFT",NULL},
/* 1F82A */ { "RIGHTWARDS TRIANGLE-HEADED ARROW WITH BOLD SHAFT",NULL},
/* 1F82B */ { "DOWNWARDS TRIANGLE-HEADED ARROW WITH BOLD SHAFT",NULL},
/* 1F82C */ { "LEFTWARDS TRIANGLE-HEADED ARROW WITH HEAVY SHAFT",NULL},
/* 1F82D */ { "UPWARDS TRIANGLE-HEADED ARROW WITH HEAVY SHAFT",NULL},
/* 1F82E */ { "RIGHTWARDS TRIANGLE-HEADED ARROW WITH HEAVY SHAFT",NULL},
/* 1F82F */ { "DOWNWARDS TRIANGLE-HEADED ARROW WITH HEAVY SHAFT",NULL},
/* 1F830 */ { "LEFTWARDS TRIANGLE-HEADED ARROW WITH VERY HEAVY SHAFT",NULL},
/* 1F831 */ { "UPWARDS TRIANGLE-HEADED ARROW WITH VERY HEAVY SHAFT",NULL},
/* 1F832 */ { "RIGHTWARDS TRIANGLE-HEADED ARROW WITH VERY HEAVY SHAFT",NULL},
/* 1F833 */ { "DOWNWARDS TRIANGLE-HEADED ARROW WITH VERY HEAVY SHAFT",NULL},
/* 1F834 */ { "LEFTWARDS FINGER-POST ARROW",NULL},
/* 1F835 */ { "UPWARDS FINGER-POST ARROW",NULL},
/* 1F836 */ { "RIGHTWARDS FINGER-POST ARROW",NULL},
/* 1F837 */ { "DOWNWARDS FINGER-POST ARROW",NULL},
/* 1F838 */ { "LEFTWARDS SQUARED ARROW",NULL},
/* 1F839 */ { "UPWARDS SQUARED ARROW",NULL},
/* 1F83A */ { "RIGHTWARDS SQUARED ARROW",NULL},
/* 1F83B */ { "DOWNWARDS SQUARED ARROW",NULL},
/* 1F83C */ { "LEFTWARDS COMPRESSED ARROW",NULL},
/* 1F83D */ { "UPWARDS COMPRESSED ARROW",NULL},
/* 1F83E */ { "RIGHTWARDS COMPRESSED ARROW",NULL},
/* 1F83F */ { "DOWNWARDS COMPRESSED ARROW",NULL},
/* 1F840 */ { "LEFTWARDS HEAVY COMPRESSED ARROW",NULL},
/* 1F841 */ { "UPWARDS HEAVY COMPRESSED ARROW",NULL},
/* 1F842 */ { "RIGHTWARDS HEAVY COMPRESSED ARROW","	x (squat black rightwards arrow - 27A7)"},
/* 1F843 */ { "DOWNWARDS HEAVY COMPRESSED ARROW",NULL},
/* 1F844 */ { "LEFTWARDS HEAVY ARROW",NULL},
/* 1F845 */ { "UPWARDS HEAVY ARROW",NULL},
/* 1F846 */ { "RIGHTWARDS HEAVY ARROW",NULL},
/* 1F847 */ { "DOWNWARDS HEAVY ARROW",NULL},
/* 1F848 */ { NULL,NULL},
/* 1F849 */ { NULL,NULL},
/* 1F84A */ { NULL,NULL},
/* 1F84B */ { NULL,NULL},
/* 1F84C */ { NULL,NULL},
/* 1F84D */ { NULL,NULL},
/* 1F84E */ { NULL,NULL},
/* 1F84F */ { NULL,NULL},
/* 1F850 */ { "LEFTWARDS SANS-SERIF ARROW","	x (leftwards arrow - 2190)"},
/* 1F851 */ { "UPWARDS SANS-SERIF ARROW","	x (upwards arrow - 2191)"},
/* 1F852 */ { "RIGHTWARDS SANS-SERIF ARROW","	x (rightwards arrow - 2192)"},
/* 1F853 */ { "DOWNWARDS SANS-SERIF ARROW","	x (downwards arrow - 2193)"},
/* 1F854 */ { "NORTH WEST SANS-SERIF ARROW","	x (north west arrow - 2196)"},
/* 1F855 */ { "NORTH EAST SANS-SERIF ARROW","	x (north east arrow - 2197)"},
/* 1F856 */ { "SOUTH EAST SANS-SERIF ARROW","	x (south east arrow - 2198)"},
/* 1F857 */ { "SOUTH WEST SANS-SERIF ARROW","	x (south west arrow - 2199)"},
/* 1F858 */ { "LEFT RIGHT SANS-SERIF ARROW","	x (left right arrow - 2194)"},
/* 1F859 */ { "UP DOWN SANS-SERIF ARROW","	x (up down arrow - 2195)"},
/* 1F85A */ { NULL,NULL},
/* 1F85B */ { NULL,NULL},
/* 1F85C */ { NULL,NULL},
/* 1F85D */ { NULL,NULL},
/* 1F85E */ { NULL,NULL},
/* 1F85F */ { NULL,NULL},
/* 1F860 */ { "WIDE-HEADED LEFTWARDS LIGHT BARB ARROW",NULL},
/* 1F861 */ { "WIDE-HEADED UPWARDS LIGHT BARB ARROW",NULL},
/* 1F862 */ { "WIDE-HEADED RIGHTWARDS LIGHT BARB ARROW",NULL},
/* 1F863 */ { "WIDE-HEADED DOWNWARDS LIGHT BARB ARROW",NULL},
/* 1F864 */ { "WIDE-HEADED NORTH WEST LIGHT BARB ARROW",NULL},
/* 1F865 */ { "WIDE-HEADED NORTH EAST LIGHT BARB ARROW",NULL},
/* 1F866 */ { "WIDE-HEADED SOUTH EAST LIGHT BARB ARROW",NULL},
/* 1F867 */ { "WIDE-HEADED SOUTH WEST LIGHT BARB ARROW",NULL},
/* 1F868 */ { "WIDE-HEADED LEFTWARDS BARB ARROW",NULL},
/* 1F869 */ { "WIDE-HEADED UPWARDS BARB ARROW",NULL},
/* 1F86A */ { "WIDE-HEADED RIGHTWARDS BARB ARROW",NULL},
/* 1F86B */ { "WIDE-HEADED DOWNWARDS BARB ARROW",NULL},
/* 1F86C */ { "WIDE-HEADED NORTH WEST BARB ARROW",NULL},
/* 1F86D */ { "WIDE-HEADED NORTH EAST BARB ARROW",NULL},
/* 1F86E */ { "WIDE-HEADED SOUTH EAST BARB ARROW",NULL},
/* 1F86F */ { "WIDE-HEADED SOUTH WEST BARB ARROW",NULL},
/* 1F870 */ { "WIDE-HEADED LEFTWARDS MEDIUM BARB ARROW",NULL},
/* 1F871 */ { "WIDE-HEADED UPWARDS MEDIUM BARB ARROW",NULL},
/* 1F872 */ { "WIDE-HEADED RIGHTWARDS MEDIUM BARB ARROW","	x (heavy wide-headed rightwards arrow - 2794)"},
/* 1F873 */ { "WIDE-HEADED DOWNWARDS MEDIUM BARB ARROW",NULL},
/* 1F874 */ { "WIDE-HEADED NORTH WEST MEDIUM BARB ARROW",NULL},
/* 1F875 */ { "WIDE-HEADED NORTH EAST MEDIUM BARB ARROW",NULL},
/* 1F876 */ { "WIDE-HEADED SOUTH EAST MEDIUM BARB ARROW",NULL},
/* 1F877 */ { "WIDE-HEADED SOUTH WEST MEDIUM BARB ARROW",NULL},
/* 1F878 */ { "WIDE-HEADED LEFTWARDS HEAVY BARB ARROW",NULL},
/* 1F879 */ { "WIDE-HEADED UPWARDS HEAVY BARB ARROW",NULL},
/* 1F87A */ { "WIDE-HEADED RIGHTWARDS HEAVY BARB ARROW",NULL},
/* 1F87B */ { "WIDE-HEADED DOWNWARDS HEAVY BARB ARROW",NULL},
/* 1F87C */ { "WIDE-HEADED NORTH WEST HEAVY BARB ARROW",NULL},
/* 1F87D */ { "WIDE-HEADED NORTH EAST HEAVY BARB ARROW",NULL},
/* 1F87E */ { "WIDE-HEADED SOUTH EAST HEAVY BARB ARROW",NULL},
/* 1F87F */ { "WIDE-HEADED SOUTH WEST HEAVY BARB ARROW",NULL},
/* 1F880 */ { "WIDE-HEADED LEFTWARDS VERY HEAVY BARB ARROW",NULL},
/* 1F881 */ { "WIDE-HEADED UPWARDS VERY HEAVY BARB ARROW",NULL},
/* 1F882 */ { "WIDE-HEADED RIGHTWARDS VERY HEAVY BARB ARROW",NULL},
/* 1F883 */ { "WIDE-HEADED DOWNWARDS VERY HEAVY BARB ARROW",NULL},
/* 1F884 */ { "WIDE-HEADED NORTH WEST VERY HEAVY BARB ARROW",NULL},
/* 1F885 */ { "WIDE-HEADED NORTH EAST VERY HEAVY BARB ARROW",NULL},
/* 1F886 */ { "WIDE-HEADED SOUTH EAST VERY HEAVY BARB ARROW",NULL},
/* 1F887 */ { "WIDE-HEADED SOUTH WEST VERY HEAVY BARB ARROW",NULL},
/* 1F888 */ { NULL,NULL},
/* 1F889 */ { NULL,NULL},
/* 1F88A */ { NULL,NULL},
/* 1F88B */ { NULL,NULL},
/* 1F88C */ { NULL,NULL},
/* 1F88D */ { NULL,NULL},
/* 1F88E */ { NULL,NULL},
/* 1F88F */ { NULL,NULL},
/* 1F890 */ { "LEFTWARDS TRIANGLE ARROWHEAD",NULL},
/* 1F891 */ { "UPWARDS TRIANGLE ARROWHEAD",NULL},
/* 1F892 */ { "RIGHTWARDS TRIANGLE ARROWHEAD",NULL},
/* 1F893 */ { "DOWNWARDS TRIANGLE ARROWHEAD",NULL},
/* 1F894 */ { "LEFTWARDS WHITE ARROW WITHIN TRIANGLE ARROWHEAD",NULL},
/* 1F895 */ { "UPWARDS WHITE ARROW WITHIN TRIANGLE ARROWHEAD",NULL},
/* 1F896 */ { "RIGHTWARDS WHITE ARROW WITHIN TRIANGLE ARROWHEAD",NULL},
/* 1F897 */ { "DOWNWARDS WHITE ARROW WITHIN TRIANGLE ARROWHEAD",NULL},
/* 1F898 */ { "LEFTWARDS ARROW WITH NOTCHED TAIL",NULL},
/* 1F899 */ { "UPWARDS ARROW WITH NOTCHED TAIL",NULL},
/* 1F89A */ { "RIGHTWARDS ARROW WITH NOTCHED TAIL","	x (notched lower right-shadowed white rightwards arrow - 27AF)"},
/* 1F89B */ { "DOWNWARDS ARROW WITH NOTCHED TAIL",NULL},
/* 1F89C */ { "HEAVY ARROW SHAFT WIDTH ONE",NULL},
/* 1F89D */ { "HEAVY ARROW SHAFT WIDTH TWO THIRDS",NULL},
/* 1F89E */ { "HEAVY ARROW SHAFT WIDTH ONE HALF",NULL},
/* 1F89F */ { "HEAVY ARROW SHAFT WIDTH ONE THIRD",NULL},
/* 1F8A0 */ { "LEFTWARDS BOTTOM-SHADED WHITE ARROW",NULL},
/* 1F8A1 */ { "RIGHTWARDS BOTTOM SHADED WHITE ARROW",NULL},
/* 1F8A2 */ { "LEFTWARDS TOP SHADED WHITE ARROW",NULL},
/* 1F8A3 */ { "RIGHTWARDS TOP SHADED WHITE ARROW",NULL},
/* 1F8A4 */ { "LEFTWARDS LEFT-SHADED WHITE ARROW",NULL},
/* 1F8A5 */ { "RIGHTWARDS RIGHT-SHADED WHITE ARROW","	x (right-shaded white rightwards arrow - 27A9)"},
/* 1F8A6 */ { "LEFTWARDS RIGHT-SHADED WHITE ARROW",NULL},
/* 1F8A7 */ { "RIGHTWARDS LEFT-SHADED WHITE ARROW","	x (left-shaded white rightwards arrow - 27AA)"},
/* 1F8A8 */ { "LEFTWARDS BACK-TILTED SHADOWED WHITE ARROW",NULL},
/* 1F8A9 */ { "RIGHTWARDS BACK-TILTED SHADOWED WHITE ARROW","	x (back-tilted shadowed white rightwards arrow - 27AB)"},
/* 1F8AA */ { "LEFTWARDS FRONT-TILTED SHADOWED WHITE ARROW",NULL},
/* 1F8AB */ { "RIGHTWARDS FRONT-TILTED SHADOWED WHITE ARROW","	x (front-tilted shadowed white rightwards arrow - 27AC)"},
/* 1F8AC */ { "WHITE ARROW SHAFT WIDTH ONE",NULL},
/* 1F8AD */ { "WHITE ARROW SHAFT WIDTH TWO THIRDS",NULL},
/* 1F8AE */ { NULL,NULL},
/* 1F8AF */ { NULL,NULL},
/* 1F8B0 */ { "ARROW POINTING UPWARDS THEN NORTH WEST",NULL},
/* 1F8B1 */ { "ARROW POINTING RIGHTWARDS THEN CURVING SOUTH WEST",NULL},
/* 1F8B2 */ { "RIGHTWARDS ARROW WITH LOWER HOOK",NULL},
/* 1F8B3 */ { "DOWNWARDS BLACK ARROW TO BAR",NULL},
/* 1F8B4 */ { "NEGATIVE SQUARED LEFTWARDS ARROW",NULL},
/* 1F8B5 */ { "NEGATIVE SQUARED UPWARDS ARROW",NULL},
/* 1F8B6 */ { "NEGATIVE SQUARED RIGHTWARDS ARROW",NULL},
/* 1F8B7 */ { "NEGATIVE SQUARED DOWNWARDS ARROW",NULL},
/* 1F8B8 */ { "NORTH WEST ARROW FROM BAR",NULL},
/* 1F8B9 */ { "NORTH EAST ARROW FROM BAR",NULL},
/* 1F8BA */ { "SOUTH EAST ARROW FROM BAR",NULL},
/* 1F8BB */ { "SOUTH WEST ARROW FROM BAR",NULL},
/* 1F8BC */ { NULL,NULL},
/* 1F8BD */ { NULL,NULL},
/* 1F8BE */ { NULL,NULL},
/* 1F8BF */ { NULL,NULL},
/* 1F8C0 */ { "LEFTWARDS ARROW FROM DOWNWARDS ARROW","	* indicates writing in columns, hieroglyphs facing left (reading direction LTR)"},
/* 1F8C1 */ { "RIGHTWARDS ARROW FROM DOWNWARDS ARROW","	* indicates writing in columns, hieroglyphs facing right (reading direction RTL)"},
/* 1F8C2 */ { NULL,NULL},
/* 1F8C3 */ { NULL,NULL},
/* 1F8C4 */ { NULL,NULL},
/* 1F8C5 */ { NULL,NULL},
/* 1F8C6 */ { NULL,NULL},
/* 1F8C7 */ { NULL,NULL},
/* 1F8C8 */ { NULL,NULL},
/* 1F8C9 */ { NULL,NULL},
/* 1F8CA */ { NULL,NULL},
/* 1F8CB */ { NULL,NULL},
/* 1F8CC */ { NULL,NULL},
/* 1F8CD */ { NULL,NULL},
/* 1F8CE */ { NULL,NULL},
/* 1F8CF */ { NULL,NULL},
/* 1F8D0 */ { "LONG RIGHTWARDS ARROW OVER LONG LEFTWARDS ARROW","	x (rightwards arrow over leftwards arrow - 21C4)"},
/* 1F8D1 */ { "LONG RIGHTWARDS HARPOON OVER LONG LEFTWARDS HARPOON","	x (rightwards harpoon over leftwards harpoon - 21CC)"},
/* 1F8D2 */ { "LONG RIGHTWARDS HARPOON ABOVE SHORT LEFTWARDS HARPOON",NULL},
/* 1F8D3 */ { "SHORT RIGHTWARDS HARPOON ABOVE LONG LEFTWARDS HARPOON",NULL},
/* 1F8D4 */ { "LONG LEFTWARDS HARPOON ABOVE SHORT RIGHTWARDS HARPOON","	x (leftwards harpoon over rightwards harpoon - 21CB)"},
/* 1F8D5 */ { "SHORT LEFTWARDS HARPOON ABOVE LONG RIGHTWARDS HARPOON",NULL},
/* 1F8D6 */ { "LONG RIGHTWARDS ARROW THROUGH X",NULL},
/* 1F8D7 */ { "LONG RIGHTWARDS ARROW WITH DOUBLE SLASH",NULL},
/* 1F8D8 */ { "LONG LEFT RIGHT ARROW WITH DEPENDENT LOBE","	* indicates that the two sides have the same arrangement of electron lobes"},
/* 1F8D9 */ { NULL,NULL},
/* 1F8DA */ { NULL,NULL},
/* 1F8DB */ { NULL,NULL},
/* 1F8DC */ { NULL,NULL},
/* 1F8DD */ { NULL,NULL},
/* 1F8DE */ { NULL,NULL},
/* 1F8DF */ { NULL,NULL},
/* 1F8E0 */ { NULL,NULL},
/* 1F8E1 */ { NULL,NULL},
/* 1F8E2 */ { NULL,NULL},
/* 1F8E3 */ { NULL,NULL},
/* 1F8E4 */ { NULL,NULL},
/* 1F8E5 */ { NULL,NULL},
/* 1F8E6 */ { NULL,NULL},
/* 1F8E7 */ { NULL,NULL},
/* 1F8E8 */ { NULL,NULL},
/* 1F8E9 */ { NULL,NULL},
/* 1F8EA */ { NULL,NULL},
/* 1F8EB */ { NULL,NULL},
/* 1F8EC */ { NULL,NULL},
/* 1F8ED */ { NULL,NULL},
/* 1F8EE */ { NULL,NULL},
/* 1F8EF */ { NULL,NULL},
/* 1F8F0 */ { NULL,NULL},
/* 1F8F1 */ { NULL,NULL},
/* 1F8F2 */ { NULL,NULL},
/* 1F8F3 */ { NULL,NULL},
/* 1F8F4 */ { NULL,NULL},
/* 1F8F5 */ { NULL,NULL},
/* 1F8F6 */ { NULL,NULL},
/* 1F8F7 */ { NULL,NULL},
/* 1F8F8 */ { NULL,NULL},
/* 1F8F9 */ { NULL,NULL},
/* 1F8FA */ { NULL,NULL},
/* 1F8FB */ { NULL,NULL},
/* 1F8FC */ { NULL,NULL},
/* 1F8FD */ { NULL,NULL},
/* 1F8FE */ { NULL,NULL},
/* 1F8FF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_F9[] = {
/* 1F900 */ { "CIRCLED CROSS FORMEE WITH FOUR DOTS",NULL},
/* 1F901 */ { "CIRCLED CROSS FORMEE WITH TWO DOTS",NULL},
/* 1F902 */ { "CIRCLED CROSS FORMEE","	x (maltese cross - 2720)"},
/* 1F903 */ { "LEFT HALF CIRCLE WITH FOUR DOTS",NULL},
/* 1F904 */ { "LEFT HALF CIRCLE WITH THREE DOTS",NULL},
/* 1F905 */ { "LEFT HALF CIRCLE WITH TWO DOTS",NULL},
/* 1F906 */ { "LEFT HALF CIRCLE WITH DOT",NULL},
/* 1F907 */ { "LEFT HALF CIRCLE",NULL},
/* 1F908 */ { "DOWNWARD FACING HOOK",NULL},
/* 1F909 */ { "DOWNWARD FACING NOTCHED HOOK",NULL},
/* 1F90A */ { "DOWNWARD FACING HOOK WITH DOT",NULL},
/* 1F90B */ { "DOWNWARD FACING NOTCHED HOOK WITH DOT",NULL},
/* 1F90C */ { "PINCHED FINGERS",NULL},
/* 1F90D */ { "WHITE HEART",NULL},
/* 1F90E */ { "BROWN HEART",NULL},
/* 1F90F */ { "PINCHING HAND",NULL},
/* 1F910 */ { "ZIPPER-MOUTH FACE",NULL},
/* 1F911 */ { "MONEY-MOUTH FACE",NULL},
/* 1F912 */ { "FACE WITH THERMOMETER",NULL},
/* 1F913 */ { "NERD FACE",NULL},
/* 1F914 */ { "THINKING FACE",NULL},
/* 1F915 */ { "FACE WITH HEAD-BANDAGE",NULL},
/* 1F916 */ { "ROBOT FACE","	x (alien monster - 1F47E)"},
/* 1F917 */ { "HUGGING FACE",NULL},
/* 1F918 */ { "SIGN OF THE HORNS",NULL},
/* 1F919 */ { "CALL ME HAND",NULL},
/* 1F91A */ { "RAISED BACK OF HAND",NULL},
/* 1F91B */ { "LEFT-FACING FIST","	x (leftwards hand - 1FAF2)"},
/* 1F91C */ { "RIGHT-FACING FIST","	x (rightwards hand - 1FAF1)"},
/* 1F91D */ { "HANDSHAKE",NULL},
/* 1F91E */ { "HAND WITH INDEX AND MIDDLE FINGERS CROSSED","	x (hand with index finger and thumb crossed - 1FAF0)"},
/* 1F91F */ { "I LOVE YOU HAND SIGN","	* can be abbreviated ILY"},
/* 1F920 */ { "FACE WITH COWBOY HAT",NULL},
/* 1F921 */ { "CLOWN FACE",NULL},
/* 1F922 */ { "NAUSEATED FACE",NULL},
/* 1F923 */ { "ROLLING ON THE FLOOR LAUGHING","	= rofl, rotfl"},
/* 1F924 */ { "DROOLING FACE",NULL},
/* 1F925 */ { "LYING FACE",NULL},
/* 1F926 */ { "FACE PALM","	= frustration, disbelief"},
/* 1F927 */ { "SNEEZING FACE","	= Gesundheit"},
/* 1F928 */ { "FACE WITH ONE EYEBROW RAISED",NULL},
/* 1F929 */ { "GRINNING FACE WITH STAR EYES",NULL},
/* 1F92A */ { "GRINNING FACE WITH ONE LARGE AND ONE SMALL EYE",NULL},
/* 1F92B */ { "FACE WITH FINGER COVERING CLOSED LIPS",NULL},
/* 1F92C */ { "SERIOUS FACE WITH SYMBOLS COVERING MOUTH",NULL},
/* 1F92D */ { "SMILING FACE WITH SMILING EYES AND HAND COVERING MOUTH",NULL},
/* 1F92E */ { "FACE WITH OPEN MOUTH VOMITING",NULL},
/* 1F92F */ { "SHOCKED FACE WITH EXPLODING HEAD",NULL},
/* 1F930 */ { "PREGNANT WOMAN","	x (pregnant person - 1FAC4)"},
/* 1F931 */ { "BREAST-FEEDING",NULL},
/* 1F932 */ { "PALMS UP TOGETHER","	* used for prayer in some cultures"},
/* 1F933 */ { "SELFIE","	* typically used with face or human figure on the left"},
/* 1F934 */ { "PRINCE","	x (princess - 1F478)"},
/* 1F935 */ { "MAN IN TUXEDO","	* appearance for groom, may be paired with 1F470\n"
	"	x (bride with veil - 1F470)"},
/* 1F936 */ { "MOTHER CHRISTMAS","	= Mrs. Claus\n"
	"	x (father christmas - 1F385)"},
/* 1F937 */ { "SHRUG",NULL},
/* 1F938 */ { "PERSON DOING CARTWHEEL","	= gymnastics"},
/* 1F939 */ { "JUGGLING",NULL},
/* 1F93A */ { "FENCER","	= fencing\n"
	"	x (crossed swords - 2694)"},
/* 1F93B */ { "MODERN PENTATHLON",NULL},
/* 1F93C */ { "WRESTLERS","	= wrestling"},
/* 1F93D */ { "WATER POLO",NULL},
/* 1F93E */ { "HANDBALL",NULL},
/* 1F93F */ { "DIVING MASK",NULL},
/* 1F940 */ { "WILTED FLOWER","	x (rose - 1F339)"},
/* 1F941 */ { "DRUM WITH DRUMSTICKS",NULL},
/* 1F942 */ { "CLINKING GLASSES","	= celebration, formal toasting\n"
	"	x (clinking beer mugs - 1F37B)"},
/* 1F943 */ { "TUMBLER GLASS","	= whisky\n"
	"	* typically shown with ice\n"
	"	x (cocktail glass - 1F378)"},
/* 1F944 */ { "SPOON","	x (fork and knife - 1F374)"},
/* 1F945 */ { "GOAL NET",NULL},
/* 1F946 */ { "RIFLE","	= marksmanship, shooting, hunting"},
/* 1F947 */ { "FIRST PLACE MEDAL","	= gold medal\n"
	"	x (sports medal - 1F3C5)"},
/* 1F948 */ { "SECOND PLACE MEDAL","	= silver medal"},
/* 1F949 */ { "THIRD PLACE MEDAL","	= bronze medal"},
/* 1F94A */ { "BOXING GLOVE","	= boxing"},
/* 1F94B */ { "MARTIAL ARTS UNIFORM","	= judo, karate, taekwondo"},
/* 1F94C */ { "CURLING STONE",NULL},
/* 1F94D */ { "LACROSSE STICK AND BALL",NULL},
/* 1F94E */ { "SOFTBALL",NULL},
/* 1F94F */ { "FLYING DISC",NULL},
/* 1F950 */ { "CROISSANT",NULL},
/* 1F951 */ { "AVOCADO",NULL},
/* 1F952 */ { "CUCUMBER","	= pickle"},
/* 1F953 */ { "BACON",NULL},
/* 1F954 */ { "POTATO",NULL},
/* 1F955 */ { "CARROT",NULL},
/* 1F956 */ { "BAGUETTE BREAD","	= French bread"},
/* 1F957 */ { "GREEN SALAD",NULL},
/* 1F958 */ { "SHALLOW PAN OF FOOD","	= paella, casserole"},
/* 1F959 */ { "STUFFED FLATBREAD","	= döner kebab, falafel, gyro, shawarma"},
/* 1F95A */ { "EGG","	= chicken egg"},
/* 1F95B */ { "GLASS OF MILK","	= milk\n"
	"	x (pouring liquid - 1FAD7)"},
/* 1F95C */ { "PEANUTS",NULL},
/* 1F95D */ { "KIWIFRUIT",NULL},
/* 1F95E */ { "PANCAKES","	= hotcakes, crêpes, blini\n"
	"	* sweet or savory"},
/* 1F95F */ { "DUMPLING","	= potsticker, gyooza, jiaozi, pierogi, empanada"},
/* 1F960 */ { "FORTUNE COOKIE",NULL},
/* 1F961 */ { "TAKEOUT BOX","	= take-away box, oyster pail"},
/* 1F962 */ { "CHOPSTICKS","	= kuaizi, hashi, jeotgarak"},
/* 1F963 */ { "BOWL WITH SPOON","	* can indicate breakfast, cereal, congee, etc."},
/* 1F964 */ { "CUP WITH STRAW","	* can indicate soda, juice, etc."},
/* 1F965 */ { "COCONUT",NULL},
/* 1F966 */ { "BROCCOLI",NULL},
/* 1F967 */ { "PIE","	* may be sweet or savory"},
/* 1F968 */ { "PRETZEL","	* can indicate twistiness, intricacy"},
/* 1F969 */ { "CUT OF MEAT","	= porkchop, chop, steak"},
/* 1F96A */ { "SANDWICH",NULL},
/* 1F96B */ { "CANNED FOOD",NULL},
/* 1F96C */ { "LEAFY GREEN","	* intended to represent cooked green vegetables such as bok choy, kale, etc."},
/* 1F96D */ { "MANGO",NULL},
/* 1F96E */ { "MOON CAKE",NULL},
/* 1F96F */ { "BAGEL",NULL},
/* 1F970 */ { "SMILING FACE WITH SMILING EYES AND THREE HEARTS",NULL},
/* 1F971 */ { "YAWNING FACE",NULL},
/* 1F972 */ { "SMILING FACE WITH TEAR",NULL},
/* 1F973 */ { "FACE WITH PARTY HORN AND PARTY HAT",NULL},
/* 1F974 */ { "FACE WITH UNEVEN EYES AND WAVY MOUTH",NULL},
/* 1F975 */ { "OVERHEATED FACE",NULL},
/* 1F976 */ { "FREEZING FACE",NULL},
/* 1F977 */ { "NINJA",NULL},
/* 1F978 */ { "DISGUISED FACE",NULL},
/* 1F979 */ { "FACE HOLDING BACK TEARS",NULL},
/* 1F97A */ { "FACE WITH PLEADING EYES",NULL},
/* 1F97B */ { "SARI",NULL},
/* 1F97C */ { "LAB COAT",NULL},
/* 1F97D */ { "GOGGLES",NULL},
/* 1F97E */ { "HIKING BOOT",NULL},
/* 1F97F */ { "FLAT SHOE",NULL},
/* 1F980 */ { "CRAB","	* used for Cancer\n"
	"	x (cancer - 264B)"},
/* 1F981 */ { "LION FACE","	* used for Leo\n"
	"	x (leo - 264C)"},
/* 1F982 */ { "SCORPION","	* used for Scorpio\n"
	"	x (scorpius - 264F)"},
/* 1F983 */ { "TURKEY",NULL},
/* 1F984 */ { "UNICORN FACE",NULL},
/* 1F985 */ { "EAGLE",NULL},
/* 1F986 */ { "DUCK",NULL},
/* 1F987 */ { "BAT",NULL},
/* 1F988 */ { "SHARK",NULL},
/* 1F989 */ { "OWL",NULL},
/* 1F98A */ { "FOX FACE",NULL},
/* 1F98B */ { "BUTTERFLY",NULL},
/* 1F98C */ { "DEER",NULL},
/* 1F98D */ { "GORILLA",NULL},
/* 1F98E */ { "LIZARD",NULL},
/* 1F98F */ { "RHINOCEROS",NULL},
/* 1F990 */ { "SHRIMP",NULL},
/* 1F991 */ { "SQUID",NULL},
/* 1F992 */ { "GIRAFFE FACE",NULL},
/* 1F993 */ { "ZEBRA FACE",NULL},
/* 1F994 */ { "HEDGEHOG",NULL},
/* 1F995 */ { "SAUROPOD","	* includes Brontosaurus, Diplodocus, Brachiosaurus"},
/* 1F996 */ { "T-REX","	= Tyrannosaurus rex"},
/* 1F997 */ { "CRICKET",NULL},
/* 1F998 */ { "KANGAROO",NULL},
/* 1F999 */ { "LLAMA",NULL},
/* 1F99A */ { "PEACOCK",NULL},
/* 1F99B */ { "HIPPOPOTAMUS",NULL},
/* 1F99C */ { "PARROT",NULL},
/* 1F99D */ { "RACCOON",NULL},
/* 1F99E */ { "LOBSTER",NULL},
/* 1F99F */ { "MOSQUITO",NULL},
/* 1F9A0 */ { "MICROBE","	* microorganism, intended to cover bacteria, viruses, amoebas, etc."},
/* 1F9A1 */ { "BADGER",NULL},
/* 1F9A2 */ { "SWAN",NULL},
/* 1F9A3 */ { "MAMMOTH","	* indicates great size"},
/* 1F9A4 */ { "DODO","	* indicates extinction"},
/* 1F9A5 */ { "SLOTH",NULL},
/* 1F9A6 */ { "OTTER",NULL},
/* 1F9A7 */ { "ORANGUTAN",NULL},
/* 1F9A8 */ { "SKUNK",NULL},
/* 1F9A9 */ { "FLAMINGO",NULL},
/* 1F9AA */ { "OYSTER",NULL},
/* 1F9AB */ { "BEAVER",NULL},
/* 1F9AC */ { "BISON",NULL},
/* 1F9AD */ { "SEAL",NULL},
/* 1F9AE */ { "GUIDE DOG",NULL},
/* 1F9AF */ { "PROBING CANE",NULL},
/* 1F9B0 */ { "EMOJI COMPONENT RED HAIR",NULL},
/* 1F9B1 */ { "EMOJI COMPONENT CURLY HAIR",NULL},
/* 1F9B2 */ { "EMOJI COMPONENT BALD",NULL},
/* 1F9B3 */ { "EMOJI COMPONENT WHITE HAIR",NULL},
/* 1F9B4 */ { "BONE",NULL},
/* 1F9B5 */ { "LEG",NULL},
/* 1F9B6 */ { "FOOT",NULL},
/* 1F9B7 */ { "TOOTH",NULL},
/* 1F9B8 */ { "SUPERHERO",NULL},
/* 1F9B9 */ { "SUPERVILLAIN",NULL},
/* 1F9BA */ { "SAFETY VEST",NULL},
/* 1F9BB */ { "EAR WITH HEARING AID",NULL},
/* 1F9BC */ { "MOTORIZED WHEELCHAIR",NULL},
/* 1F9BD */ { "MANUAL WHEELCHAIR",NULL},
/* 1F9BE */ { "MECHANICAL ARM",NULL},
/* 1F9BF */ { "MECHANICAL LEG",NULL},
/* 1F9C0 */ { "CHEESE WEDGE",NULL},
/* 1F9C1 */ { "CUPCAKE",NULL},
/* 1F9C2 */ { "SALT SHAKER",NULL},
/* 1F9C3 */ { "BEVERAGE BOX",NULL},
/* 1F9C4 */ { "GARLIC",NULL},
/* 1F9C5 */ { "ONION",NULL},
/* 1F9C6 */ { "FALAFEL",NULL},
/* 1F9C7 */ { "WAFFLE",NULL},
/* 1F9C8 */ { "BUTTER",NULL},
/* 1F9C9 */ { "MATE DRINK",NULL},
/* 1F9CA */ { "ICE CUBE",NULL},
/* 1F9CB */ { "BUBBLE TEA",NULL},
/* 1F9CC */ { "TROLL",NULL},
/* 1F9CD */ { "STANDING PERSON",NULL},
/* 1F9CE */ { "KNEELING PERSON",NULL},
/* 1F9CF */ { "DEAF PERSON",NULL},
/* 1F9D0 */ { "FACE WITH MONOCLE",NULL},
/* 1F9D1 */ { "ADULT","	* no specified gender\n"
	"	x (man - 1F468)\n"
	"	x (woman - 1F469)"},
/* 1F9D2 */ { "CHILD","	* no specified gender\n"
	"	x (boy - 1F466)\n"
	"	x (girl - 1F467)"},
/* 1F9D3 */ { "OLDER ADULT","	* no specified gender\n"
	"	x (older man - 1F474)\n"
	"	x (older woman - 1F475)"},
/* 1F9D4 */ { "BEARDED PERSON",NULL},
/* 1F9D5 */ { "PERSON WITH HEADSCARF","	= woman's headscarf, hijab"},
/* 1F9D6 */ { "PERSON IN STEAMY ROOM","	= sauna, steam room"},
/* 1F9D7 */ { "PERSON CLIMBING",NULL},
/* 1F9D8 */ { "PERSON IN LOTUS POSITION","	= yoga, meditation"},
/* 1F9D9 */ { "MAGE","	= wizard, witch, sorcerer, sorceress"},
/* 1F9DA */ { "FAIRY",NULL},
/* 1F9DB */ { "VAMPIRE",NULL},
/* 1F9DC */ { "MERPERSON","	= mermaid, merman"},
/* 1F9DD */ { "ELF",NULL},
/* 1F9DE */ { "GENIE",NULL},
/* 1F9DF */ { "ZOMBIE",NULL},
/* 1F9E0 */ { "BRAIN",NULL},
/* 1F9E1 */ { "ORANGE HEART","	x (blue heart - 1F499)\n"
	"	x (white heart - 1F90D)"},
/* 1F9E2 */ { "BILLED CAP","	= baseball cap"},
/* 1F9E3 */ { "SCARF",NULL},
/* 1F9E4 */ { "GLOVES",NULL},
/* 1F9E5 */ { "COAT",NULL},
/* 1F9E6 */ { "SOCKS",NULL},
/* 1F9E7 */ { "RED GIFT ENVELOPE","	* contains a monetary gift in East and Southeast Asia"},
/* 1F9E8 */ { "FIRECRACKER",NULL},
/* 1F9E9 */ { "JIGSAW PUZZLE PIECE",NULL},
/* 1F9EA */ { "TEST TUBE",NULL},
/* 1F9EB */ { "PETRI DISH",NULL},
/* 1F9EC */ { "DNA DOUBLE HELIX",NULL},
/* 1F9ED */ { "COMPASS",NULL},
/* 1F9EE */ { "ABACUS",NULL},
/* 1F9EF */ { "FIRE EXTINGUISHER",NULL},
/* 1F9F0 */ { "TOOLBOX",NULL},
/* 1F9F1 */ { "BRICK",NULL},
/* 1F9F2 */ { "MAGNET",NULL},
/* 1F9F3 */ { "LUGGAGE",NULL},
/* 1F9F4 */ { "LOTION BOTTLE",NULL},
/* 1F9F5 */ { "SPOOL OF THREAD",NULL},
/* 1F9F6 */ { "BALL OF YARN",NULL},
/* 1F9F7 */ { "SAFETY PIN",NULL},
/* 1F9F8 */ { "TEDDY BEAR",NULL},
/* 1F9F9 */ { "BROOM",NULL},
/* 1F9FA */ { "BASKET",NULL},
/* 1F9FB */ { "ROLL OF PAPER",NULL},
/* 1F9FC */ { "BAR OF SOAP",NULL},
/* 1F9FD */ { "SPONGE",NULL},
/* 1F9FE */ { "RECEIPT",NULL},
/* 1F9FF */ { "NAZAR AMULET",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_FA[] = {
/* 1FA00 */ { "NEUTRAL CHESS KING","	x (white chess king - 2654)"},
/* 1FA01 */ { "NEUTRAL CHESS QUEEN",NULL},
/* 1FA02 */ { "NEUTRAL CHESS ROOK",NULL},
/* 1FA03 */ { "NEUTRAL CHESS BISHOP",NULL},
/* 1FA04 */ { "NEUTRAL CHESS KNIGHT",NULL},
/* 1FA05 */ { "NEUTRAL CHESS PAWN",NULL},
/* 1FA06 */ { "WHITE CHESS KNIGHT ROTATED FORTY-FIVE DEGREES",NULL},
/* 1FA07 */ { "BLACK CHESS KNIGHT ROTATED FORTY-FIVE DEGREES",NULL},
/* 1FA08 */ { "NEUTRAL CHESS KNIGHT ROTATED FORTY-FIVE DEGREES",NULL},
/* 1FA09 */ { "WHITE CHESS KING ROTATED NINETY DEGREES",NULL},
/* 1FA0A */ { "WHITE CHESS QUEEN ROTATED NINETY DEGREES",NULL},
/* 1FA0B */ { "WHITE CHESS ROOK ROTATED NINETY DEGREES",NULL},
/* 1FA0C */ { "WHITE CHESS BISHOP ROTATED NINETY DEGREES",NULL},
/* 1FA0D */ { "WHITE CHESS KNIGHT ROTATED NINETY DEGREES",NULL},
/* 1FA0E */ { "WHITE CHESS PAWN ROTATED NINETY DEGREES",NULL},
/* 1FA0F */ { "BLACK CHESS KING ROTATED NINETY DEGREES",NULL},
/* 1FA10 */ { "BLACK CHESS QUEEN ROTATED NINETY DEGREES",NULL},
/* 1FA11 */ { "BLACK CHESS ROOK ROTATED NINETY DEGREES",NULL},
/* 1FA12 */ { "BLACK CHESS BISHOP ROTATED NINETY DEGREES",NULL},
/* 1FA13 */ { "BLACK CHESS KNIGHT ROTATED NINETY DEGREES",NULL},
/* 1FA14 */ { "BLACK CHESS PAWN ROTATED NINETY DEGREES",NULL},
/* 1FA15 */ { "NEUTRAL CHESS KING ROTATED NINETY DEGREES",NULL},
/* 1FA16 */ { "NEUTRAL CHESS QUEEN ROTATED NINETY DEGREES",NULL},
/* 1FA17 */ { "NEUTRAL CHESS ROOK ROTATED NINETY DEGREES",NULL},
/* 1FA18 */ { "NEUTRAL CHESS BISHOP ROTATED NINETY DEGREES",NULL},
/* 1FA19 */ { "NEUTRAL CHESS KNIGHT ROTATED NINETY DEGREES",NULL},
/* 1FA1A */ { "NEUTRAL CHESS PAWN ROTATED NINETY DEGREES",NULL},
/* 1FA1B */ { "WHITE CHESS KNIGHT ROTATED ONE HUNDRED THIRTY-FIVE DEGREES",NULL},
/* 1FA1C */ { "BLACK CHESS KNIGHT ROTATED ONE HUNDRED THIRTY-FIVE DEGREES",NULL},
/* 1FA1D */ { "NEUTRAL CHESS KNIGHT ROTATED ONE HUNDRED THIRTY-FIVE DEGREES",NULL},
/* 1FA1E */ { "WHITE CHESS TURNED KING",NULL},
/* 1FA1F */ { "WHITE CHESS TURNED QUEEN","	= white grasshopper"},
/* 1FA20 */ { "WHITE CHESS TURNED ROOK",NULL},
/* 1FA21 */ { "WHITE CHESS TURNED BISHOP",NULL},
/* 1FA22 */ { "WHITE CHESS TURNED KNIGHT","	= white nightrider"},
/* 1FA23 */ { "WHITE CHESS TURNED PAWN",NULL},
/* 1FA24 */ { "BLACK CHESS TURNED KING",NULL},
/* 1FA25 */ { "BLACK CHESS TURNED QUEEN","	= black grasshopper"},
/* 1FA26 */ { "BLACK CHESS TURNED ROOK",NULL},
/* 1FA27 */ { "BLACK CHESS TURNED BISHOP",NULL},
/* 1FA28 */ { "BLACK CHESS TURNED KNIGHT","	= black nightrider"},
/* 1FA29 */ { "BLACK CHESS TURNED PAWN",NULL},
/* 1FA2A */ { "NEUTRAL CHESS TURNED KING",NULL},
/* 1FA2B */ { "NEUTRAL CHESS TURNED QUEEN","	= neutral grasshopper"},
/* 1FA2C */ { "NEUTRAL CHESS TURNED ROOK",NULL},
/* 1FA2D */ { "NEUTRAL CHESS TURNED BISHOP",NULL},
/* 1FA2E */ { "NEUTRAL CHESS TURNED KNIGHT","	= neutral nightrider"},
/* 1FA2F */ { "NEUTRAL CHESS TURNED PAWN",NULL},
/* 1FA30 */ { "WHITE CHESS KNIGHT ROTATED TWO HUNDRED TWENTY-FIVE DEGREES",NULL},
/* 1FA31 */ { "BLACK CHESS KNIGHT ROTATED TWO HUNDRED TWENTY-FIVE DEGREES",NULL},
/* 1FA32 */ { "NEUTRAL CHESS KNIGHT ROTATED TWO HUNDRED TWENTY-FIVE DEGREES",NULL},
/* 1FA33 */ { "WHITE CHESS KING ROTATED TWO HUNDRED SEVENTY DEGREES",NULL},
/* 1FA34 */ { "WHITE CHESS QUEEN ROTATED TWO HUNDRED SEVENTY DEGREES",NULL},
/* 1FA35 */ { "WHITE CHESS ROOK ROTATED TWO HUNDRED SEVENTY DEGREES",NULL},
/* 1FA36 */ { "WHITE CHESS BISHOP ROTATED TWO HUNDRED SEVENTY DEGREES",NULL},
/* 1FA37 */ { "WHITE CHESS KNIGHT ROTATED TWO HUNDRED SEVENTY DEGREES",NULL},
/* 1FA38 */ { "WHITE CHESS PAWN ROTATED TWO HUNDRED SEVENTY DEGREES",NULL},
/* 1FA39 */ { "BLACK CHESS KING ROTATED TWO HUNDRED SEVENTY DEGREES",NULL},
/* 1FA3A */ { "BLACK CHESS QUEEN ROTATED TWO HUNDRED SEVENTY DEGREES",NULL},
/* 1FA3B */ { "BLACK CHESS ROOK ROTATED TWO HUNDRED SEVENTY DEGREES",NULL},
/* 1FA3C */ { "BLACK CHESS BISHOP ROTATED TWO HUNDRED SEVENTY DEGREES",NULL},
/* 1FA3D */ { "BLACK CHESS KNIGHT ROTATED TWO HUNDRED SEVENTY DEGREES",NULL},
/* 1FA3E */ { "BLACK CHESS PAWN ROTATED TWO HUNDRED SEVENTY DEGREES",NULL},
/* 1FA3F */ { "NEUTRAL CHESS KING ROTATED TWO HUNDRED SEVENTY DEGREES",NULL},
/* 1FA40 */ { "NEUTRAL CHESS QUEEN ROTATED TWO HUNDRED SEVENTY DEGREES",NULL},
/* 1FA41 */ { "NEUTRAL CHESS ROOK ROTATED TWO HUNDRED SEVENTY DEGREES",NULL},
/* 1FA42 */ { "NEUTRAL CHESS BISHOP ROTATED TWO HUNDRED SEVENTY DEGREES",NULL},
/* 1FA43 */ { "NEUTRAL CHESS KNIGHT ROTATED TWO HUNDRED SEVENTY DEGREES",NULL},
/* 1FA44 */ { "NEUTRAL CHESS PAWN ROTATED TWO HUNDRED SEVENTY DEGREES",NULL},
/* 1FA45 */ { "WHITE CHESS KNIGHT ROTATED THREE HUNDRED FIFTEEN DEGREES",NULL},
/* 1FA46 */ { "BLACK CHESS KNIGHT ROTATED THREE HUNDRED FIFTEEN DEGREES",NULL},
/* 1FA47 */ { "NEUTRAL CHESS KNIGHT ROTATED THREE HUNDRED FIFTEEN DEGREES",NULL},
/* 1FA48 */ { "WHITE CHESS EQUIHOPPER",NULL},
/* 1FA49 */ { "BLACK CHESS EQUIHOPPER",NULL},
/* 1FA4A */ { "NEUTRAL CHESS EQUIHOPPER",NULL},
/* 1FA4B */ { "WHITE CHESS EQUIHOPPER ROTATED NINETY DEGREES","	x (hourglass - 231B)"},
/* 1FA4C */ { "BLACK CHESS EQUIHOPPER ROTATED NINETY DEGREES",NULL},
/* 1FA4D */ { "NEUTRAL CHESS EQUIHOPPER ROTATED NINETY DEGREES",NULL},
/* 1FA4E */ { "WHITE CHESS KNIGHT-QUEEN","	= amazon, terror, omnipotent queen, superqueen"},
/* 1FA4F */ { "WHITE CHESS KNIGHT-ROOK","	= chancellor, marshall, empress"},
/* 1FA50 */ { "WHITE CHESS KNIGHT-BISHOP","	= cardinal, princess\n"
	"	* may have the form of a mitre or biretta"},
/* 1FA51 */ { "BLACK CHESS KNIGHT-QUEEN",NULL},
/* 1FA52 */ { "BLACK CHESS KNIGHT-ROOK",NULL},
/* 1FA53 */ { "BLACK CHESS KNIGHT-BISHOP",NULL},
/* 1FA54 */ { "WHITE CHESS FERZ",NULL},
/* 1FA55 */ { "WHITE CHESS ALFIL","	= white elephant"},
/* 1FA56 */ { "BLACK CHESS FERZ",NULL},
/* 1FA57 */ { "BLACK CHESS ALFIL","	= black elephant"},
/* 1FA58 */ { NULL,NULL},
/* 1FA59 */ { NULL,NULL},
/* 1FA5A */ { NULL,NULL},
/* 1FA5B */ { NULL,NULL},
/* 1FA5C */ { NULL,NULL},
/* 1FA5D */ { NULL,NULL},
/* 1FA5E */ { NULL,NULL},
/* 1FA5F */ { NULL,NULL},
/* 1FA60 */ { "XIANGQI RED GENERAL","	= hóng shuài\n"
	"	* design typically shows 5E25 or 5E05\n"
	"	* design sometimes shows 5C07 (Yuan dynasty)"},
/* 1FA61 */ { "XIANGQI RED MANDARIN","	= hóng shì\n"
	"	* design typically shows 4ED5\n"
	"	* design sometimes shows 58EB"},
/* 1FA62 */ { "XIANGQI RED ELEPHANT","	= hóng xiàng\n"
	"	* design typically shows 76F8\n"
	"	* design sometimes shows 8C61 (Yuan dynasty)"},
/* 1FA63 */ { "XIANGQI RED HORSE","	= hóng mǎ\n"
	"	* design typically shows 99AC or 9A6C\n"
	"	* design sometimes shows 508C"},
/* 1FA64 */ { "XIANGQI RED CHARIOT","	= hóng jū\n"
	"	* design typically shows 8ECA or 8F66\n"
	"	* design sometimes shows 4FE5"},
/* 1FA65 */ { "XIANGQI RED CANNON","	= hóng pào\n"
	"	* design typically shows 70AE or 792E\n"
	"	* design sometimes shows 7832\n"
	"	* design sometimes shows 5305 (Ming dynasty)"},
/* 1FA66 */ { "XIANGQI RED SOLDIER","	= hóng bīng\n"
	"	* design typically shows 5175\n"
	"	* design sometimes shows 5352 (Yuan and Ming dynasties)"},
/* 1FA67 */ { "XIANGQI BLACK GENERAL","	= hēi jiàng\n"
	"	* design typically shows 5C07 or 5C06"},
/* 1FA68 */ { "XIANGQI BLACK MANDARIN","	= hēi shì\n"
	"	* design typically shows 58EB"},
/* 1FA69 */ { "XIANGQI BLACK ELEPHANT","	= hēi xiàng\n"
	"	* design typically shows 8C61"},
/* 1FA6A */ { "XIANGQI BLACK HORSE","	= hēi mǎ\n"
	"	* design typically shows 99AC or 9A6C"},
/* 1FA6B */ { "XIANGQI BLACK CHARIOT","	= hēi jū\n"
	"	* design typically shows 8ECA or 8F66"},
/* 1FA6C */ { "XIANGQI BLACK CANNON","	= hēi pào\n"
	"	* design typically shows 7832\n"
	"	* design sometimes shows 70AE"},
/* 1FA6D */ { "XIANGQI BLACK SOLDIER","	= hēi zú\n"
	"	* design typically shows 5352\n"
	"	* design sometimes shows 5175 (Yuan and Ming dynasties)"},
/* 1FA6E */ { NULL,NULL},
/* 1FA6F */ { NULL,NULL},
/* 1FA70 */ { "BALLET SHOES",NULL},
/* 1FA71 */ { "ONE-PIECE SWIMSUIT",NULL},
/* 1FA72 */ { "BRIEFS",NULL},
/* 1FA73 */ { "SHORTS",NULL},
/* 1FA74 */ { "THONG SANDAL","	= flip flop"},
/* 1FA75 */ { "LIGHT BLUE HEART",NULL},
/* 1FA76 */ { "GREY HEART",NULL},
/* 1FA77 */ { "PINK HEART",NULL},
/* 1FA78 */ { "DROP OF BLOOD","	x (droplet - 1F4A7)"},
/* 1FA79 */ { "ADHESIVE BANDAGE",NULL},
/* 1FA7A */ { "STETHOSCOPE",NULL},
/* 1FA7B */ { "X-RAY",NULL},
/* 1FA7C */ { "CRUTCH",NULL},
/* 1FA7D */ { NULL,NULL},
/* 1FA7E */ { NULL,NULL},
/* 1FA7F */ { NULL,NULL},
/* 1FA80 */ { "YO-YO",NULL},
/* 1FA81 */ { "KITE",NULL},
/* 1FA82 */ { "PARACHUTE",NULL},
/* 1FA83 */ { "BOOMERANG",NULL},
/* 1FA84 */ { "MAGIC WAND",NULL},
/* 1FA85 */ { "PINATA",NULL},
/* 1FA86 */ { "NESTING DOLLS",NULL},
/* 1FA87 */ { "MARACAS",NULL},
/* 1FA88 */ { "FLUTE",NULL},
/* 1FA89 */ { "HARP",NULL},
/* 1FA8A */ { "TROMBONE",NULL},
/* 1FA8B */ { NULL,NULL},
/* 1FA8C */ { NULL,NULL},
/* 1FA8D */ { NULL,NULL},
/* 1FA8E */ { "TREASURE CHEST",NULL},
/* 1FA8F */ { "SHOVEL",NULL},
/* 1FA90 */ { "RINGED PLANET",NULL},
/* 1FA91 */ { "CHAIR",NULL},
/* 1FA92 */ { "RAZOR",NULL},
/* 1FA93 */ { "AXE",NULL},
/* 1FA94 */ { "DIYA LAMP",NULL},
/* 1FA95 */ { "BANJO",NULL},
/* 1FA96 */ { "MILITARY HELMET",NULL},
/* 1FA97 */ { "ACCORDION",NULL},
/* 1FA98 */ { "LONG DRUM",NULL},
/* 1FA99 */ { "COIN",NULL},
/* 1FA9A */ { "CARPENTRY SAW",NULL},
/* 1FA9B */ { "SCREWDRIVER",NULL},
/* 1FA9C */ { "LADDER",NULL},
/* 1FA9D */ { "HOOK",NULL},
/* 1FA9E */ { "MIRROR",NULL},
/* 1FA9F */ { "WINDOW",NULL},
/* 1FAA0 */ { "PLUNGER",NULL},
/* 1FAA1 */ { "SEWING NEEDLE",NULL},
/* 1FAA2 */ { "KNOT",NULL},
/* 1FAA3 */ { "BUCKET",NULL},
/* 1FAA4 */ { "MOUSE TRAP",NULL},
/* 1FAA5 */ { "TOOTHBRUSH",NULL},
/* 1FAA6 */ { "HEADSTONE",NULL},
/* 1FAA7 */ { "PLACARD",NULL},
/* 1FAA8 */ { "ROCK",NULL},
/* 1FAA9 */ { "MIRROR BALL",NULL},
/* 1FAAA */ { "IDENTIFICATION CARD","	= ID"},
/* 1FAAB */ { "LOW BATTERY","	x (battery - 1F50B)"},
/* 1FAAC */ { "HAMSA",NULL},
/* 1FAAD */ { "FOLDING HAND FAN",NULL},
/* 1FAAE */ { "HAIR PICK",NULL},
/* 1FAAF */ { "KHANDA","	x (adi shakti - 262C)"},
/* 1FAB0 */ { "FLY",NULL},
/* 1FAB1 */ { "WORM",NULL},
/* 1FAB2 */ { "BEETLE",NULL},
/* 1FAB3 */ { "COCKROACH",NULL},
/* 1FAB4 */ { "POTTED PLANT",NULL},
/* 1FAB5 */ { "WOOD",NULL},
/* 1FAB6 */ { "FEATHER",NULL},
/* 1FAB7 */ { "LOTUS",NULL},
/* 1FAB8 */ { "CORAL",NULL},
/* 1FAB9 */ { "EMPTY NEST",NULL},
/* 1FABA */ { "NEST WITH EGGS",NULL},
/* 1FABB */ { "HYACINTH",NULL},
/* 1FABC */ { "JELLYFISH",NULL},
/* 1FABD */ { "WING",NULL},
/* 1FABE */ { "LEAFLESS TREE",NULL},
/* 1FABF */ { "GOOSE",NULL},
/* 1FAC0 */ { "ANATOMICAL HEART",NULL},
/* 1FAC1 */ { "LUNGS",NULL},
/* 1FAC2 */ { "PEOPLE HUGGING",NULL},
/* 1FAC3 */ { "PREGNANT MAN",NULL},
/* 1FAC4 */ { "PREGNANT PERSON","	x (pregnant woman - 1F930)"},
/* 1FAC5 */ { "PERSON WITH CROWN","	x (princess - 1F478)"},
/* 1FAC6 */ { "FINGERPRINT",NULL},
/* 1FAC7 */ { NULL,NULL},
/* 1FAC8 */ { "HAIRY CREATURE",NULL},
/* 1FAC9 */ { NULL,NULL},
/* 1FACA */ { NULL,NULL},
/* 1FACB */ { NULL,NULL},
/* 1FACC */ { NULL,NULL},
/* 1FACD */ { "ORCA",NULL},
/* 1FACE */ { "MOOSE",NULL},
/* 1FACF */ { "DONKEY",NULL},
/* 1FAD0 */ { "BLUEBERRIES",NULL},
/* 1FAD1 */ { "BELL PEPPER",NULL},
/* 1FAD2 */ { "OLIVE",NULL},
/* 1FAD3 */ { "FLATBREAD",NULL},
/* 1FAD4 */ { "TAMALE",NULL},
/* 1FAD5 */ { "FONDUE",NULL},
/* 1FAD6 */ { "TEAPOT",NULL},
/* 1FAD7 */ { "POURING LIQUID","	x (glass of milk - 1F95B)"},
/* 1FAD8 */ { "BEANS",NULL},
/* 1FAD9 */ { "JAR",NULL},
/* 1FADA */ { "GINGER ROOT",NULL},
/* 1FADB */ { "PEA POD",NULL},
/* 1FADC */ { "ROOT VEGETABLE",NULL},
/* 1FADD */ { NULL,NULL},
/* 1FADE */ { NULL,NULL},
/* 1FADF */ { "SPLATTER",NULL},
/* 1FAE0 */ { "MELTING FACE",NULL},
/* 1FAE1 */ { "SALUTING FACE",NULL},
/* 1FAE2 */ { "FACE WITH OPEN EYES AND HAND OVER MOUTH",NULL},
/* 1FAE3 */ { "FACE WITH PEEKING EYE",NULL},
/* 1FAE4 */ { "FACE WITH DIAGONAL MOUTH",NULL},
/* 1FAE5 */ { "DOTTED LINE FACE",NULL},
/* 1FAE6 */ { "BITING LIP","	x (lips - 1F5E2)"},
/* 1FAE7 */ { "BUBBLES",NULL},
/* 1FAE8 */ { "SHAKING FACE",NULL},
/* 1FAE9 */ { "FACE WITH BAGS UNDER EYES",NULL},
/* 1FAEA */ { "DISTORTED FACE",NULL},
/* 1FAEB */ { NULL,NULL},
/* 1FAEC */ { NULL,NULL},
/* 1FAED */ { NULL,NULL},
/* 1FAEE */ { NULL,NULL},
/* 1FAEF */ { "FIGHT CLOUD",NULL},
/* 1FAF0 */ { "HAND WITH INDEX FINGER AND THUMB CROSSED","	x (hand with index and middle fingers crossed - 1F91E)"},
/* 1FAF1 */ { "RIGHTWARDS HAND",NULL},
/* 1FAF2 */ { "LEFTWARDS HAND",NULL},
/* 1FAF3 */ { "PALM DOWN HAND",NULL},
/* 1FAF4 */ { "PALM UP HAND",NULL},
/* 1FAF5 */ { "INDEX POINTING AT THE VIEWER",NULL},
/* 1FAF6 */ { "HEART HANDS",NULL},
/* 1FAF7 */ { "LEFTWARDS PUSHING HAND",NULL},
/* 1FAF8 */ { "RIGHTWARDS PUSHING HAND",NULL},
/* 1FAF9 */ { NULL,NULL},
/* 1FAFA */ { NULL,NULL},
/* 1FAFB */ { NULL,NULL},
/* 1FAFC */ { NULL,NULL},
/* 1FAFD */ { NULL,NULL},
/* 1FAFE */ { NULL,NULL},
/* 1FAFF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_01_FB[] = {
/* 1FB00 */ { "BLOCK SEXTANT-1",NULL},
/* 1FB01 */ { "BLOCK SEXTANT-2",NULL},
/* 1FB02 */ { "BLOCK SEXTANT-12","	* upper one third block"},
/* 1FB03 */ { "BLOCK SEXTANT-3",NULL},
/* 1FB04 */ { "BLOCK SEXTANT-13",NULL},
/* 1FB05 */ { "BLOCK SEXTANT-23",NULL},
/* 1FB06 */ { "BLOCK SEXTANT-123",NULL},
/* 1FB07 */ { "BLOCK SEXTANT-4",NULL},
/* 1FB08 */ { "BLOCK SEXTANT-14",NULL},
/* 1FB09 */ { "BLOCK SEXTANT-24",NULL},
/* 1FB0A */ { "BLOCK SEXTANT-124",NULL},
/* 1FB0B */ { "BLOCK SEXTANT-34","	* middle one third block"},
/* 1FB0C */ { "BLOCK SEXTANT-134",NULL},
/* 1FB0D */ { "BLOCK SEXTANT-234",NULL},
/* 1FB0E */ { "BLOCK SEXTANT-1234","	* upper two thirds block"},
/* 1FB0F */ { "BLOCK SEXTANT-5",NULL},
/* 1FB10 */ { "BLOCK SEXTANT-15",NULL},
/* 1FB11 */ { "BLOCK SEXTANT-25",NULL},
/* 1FB12 */ { "BLOCK SEXTANT-125",NULL},
/* 1FB13 */ { "BLOCK SEXTANT-35",NULL},
/* 1FB14 */ { "BLOCK SEXTANT-235",NULL},
/* 1FB15 */ { "BLOCK SEXTANT-1235",NULL},
/* 1FB16 */ { "BLOCK SEXTANT-45",NULL},
/* 1FB17 */ { "BLOCK SEXTANT-145",NULL},
/* 1FB18 */ { "BLOCK SEXTANT-245",NULL},
/* 1FB19 */ { "BLOCK SEXTANT-1245",NULL},
/* 1FB1A */ { "BLOCK SEXTANT-345",NULL},
/* 1FB1B */ { "BLOCK SEXTANT-1345",NULL},
/* 1FB1C */ { "BLOCK SEXTANT-2345",NULL},
/* 1FB1D */ { "BLOCK SEXTANT-12345",NULL},
/* 1FB1E */ { "BLOCK SEXTANT-6",NULL},
/* 1FB1F */ { "BLOCK SEXTANT-16",NULL},
/* 1FB20 */ { "BLOCK SEXTANT-26",NULL},
/* 1FB21 */ { "BLOCK SEXTANT-126",NULL},
/* 1FB22 */ { "BLOCK SEXTANT-36",NULL},
/* 1FB23 */ { "BLOCK SEXTANT-136",NULL},
/* 1FB24 */ { "BLOCK SEXTANT-236",NULL},
/* 1FB25 */ { "BLOCK SEXTANT-1236",NULL},
/* 1FB26 */ { "BLOCK SEXTANT-46",NULL},
/* 1FB27 */ { "BLOCK SEXTANT-146",NULL},
/* 1FB28 */ { "BLOCK SEXTANT-1246",NULL},
/* 1FB29 */ { "BLOCK SEXTANT-346",NULL},
/* 1FB2A */ { "BLOCK SEXTANT-1346",NULL},
/* 1FB2B */ { "BLOCK SEXTANT-2346",NULL},
/* 1FB2C */ { "BLOCK SEXTANT-12346",NULL},
/* 1FB2D */ { "BLOCK SEXTANT-56","	* lower one third block"},
/* 1FB2E */ { "BLOCK SEXTANT-156",NULL},
/* 1FB2F */ { "BLOCK SEXTANT-256",NULL},
/* 1FB30 */ { "BLOCK SEXTANT-1256","	* upper and lower one third block"},
/* 1FB31 */ { "BLOCK SEXTANT-356",NULL},
/* 1FB32 */ { "BLOCK SEXTANT-1356",NULL},
/* 1FB33 */ { "BLOCK SEXTANT-2356",NULL},
/* 1FB34 */ { "BLOCK SEXTANT-12356",NULL},
/* 1FB35 */ { "BLOCK SEXTANT-456",NULL},
/* 1FB36 */ { "BLOCK SEXTANT-1456",NULL},
/* 1FB37 */ { "BLOCK SEXTANT-2456",NULL},
/* 1FB38 */ { "BLOCK SEXTANT-12456",NULL},
/* 1FB39 */ { "BLOCK SEXTANT-3456","	* lower two thirds block"},
/* 1FB3A */ { "BLOCK SEXTANT-13456",NULL},
/* 1FB3B */ { "BLOCK SEXTANT-23456",NULL},
/* 1FB3C */ { "LOWER LEFT BLOCK DIAGONAL LOWER MIDDLE LEFT TO LOWER CENTRE",NULL},
/* 1FB3D */ { "LOWER LEFT BLOCK DIAGONAL LOWER MIDDLE LEFT TO LOWER RIGHT",NULL},
/* 1FB3E */ { "LOWER LEFT BLOCK DIAGONAL UPPER MIDDLE LEFT TO LOWER CENTRE",NULL},
/* 1FB3F */ { "LOWER LEFT BLOCK DIAGONAL UPPER MIDDLE LEFT TO LOWER RIGHT",NULL},
/* 1FB40 */ { "LOWER LEFT BLOCK DIAGONAL UPPER LEFT TO LOWER CENTRE",NULL},
/* 1FB41 */ { "LOWER RIGHT BLOCK DIAGONAL UPPER MIDDLE LEFT TO UPPER CENTRE",NULL},
/* 1FB42 */ { "LOWER RIGHT BLOCK DIAGONAL UPPER MIDDLE LEFT TO UPPER RIGHT",NULL},
/* 1FB43 */ { "LOWER RIGHT BLOCK DIAGONAL LOWER MIDDLE LEFT TO UPPER CENTRE",NULL},
/* 1FB44 */ { "LOWER RIGHT BLOCK DIAGONAL LOWER MIDDLE LEFT TO UPPER RIGHT",NULL},
/* 1FB45 */ { "LOWER RIGHT BLOCK DIAGONAL LOWER LEFT TO UPPER CENTRE",NULL},
/* 1FB46 */ { "LOWER RIGHT BLOCK DIAGONAL LOWER MIDDLE LEFT TO UPPER MIDDLE RIGHT",NULL},
/* 1FB47 */ { "LOWER RIGHT BLOCK DIAGONAL LOWER CENTRE TO LOWER MIDDLE RIGHT",NULL},
/* 1FB48 */ { "LOWER RIGHT BLOCK DIAGONAL LOWER LEFT TO LOWER MIDDLE RIGHT",NULL},
/* 1FB49 */ { "LOWER RIGHT BLOCK DIAGONAL LOWER CENTRE TO UPPER MIDDLE RIGHT",NULL},
/* 1FB4A */ { "LOWER RIGHT BLOCK DIAGONAL LOWER LEFT TO UPPER MIDDLE RIGHT",NULL},
/* 1FB4B */ { "LOWER RIGHT BLOCK DIAGONAL LOWER CENTRE TO UPPER RIGHT",NULL},
/* 1FB4C */ { "LOWER LEFT BLOCK DIAGONAL UPPER CENTRE TO UPPER MIDDLE RIGHT",NULL},
/* 1FB4D */ { "LOWER LEFT BLOCK DIAGONAL UPPER LEFT TO UPPER MIDDLE RIGHT",NULL},
/* 1FB4E */ { "LOWER LEFT BLOCK DIAGONAL UPPER CENTRE TO LOWER MIDDLE RIGHT",NULL},
/* 1FB4F */ { "LOWER LEFT BLOCK DIAGONAL UPPER LEFT TO LOWER MIDDLE RIGHT",NULL},
/* 1FB50 */ { "LOWER LEFT BLOCK DIAGONAL UPPER CENTRE TO LOWER RIGHT",NULL},
/* 1FB51 */ { "LOWER LEFT BLOCK DIAGONAL UPPER MIDDLE LEFT TO LOWER MIDDLE RIGHT",NULL},
/* 1FB52 */ { "UPPER RIGHT BLOCK DIAGONAL LOWER MIDDLE LEFT TO LOWER CENTRE",NULL},
/* 1FB53 */ { "UPPER RIGHT BLOCK DIAGONAL LOWER MIDDLE LEFT TO LOWER RIGHT",NULL},
/* 1FB54 */ { "UPPER RIGHT BLOCK DIAGONAL UPPER MIDDLE LEFT TO LOWER CENTRE",NULL},
/* 1FB55 */ { "UPPER RIGHT BLOCK DIAGONAL UPPER MIDDLE LEFT TO LOWER RIGHT",NULL},
/* 1FB56 */ { "UPPER RIGHT BLOCK DIAGONAL UPPER LEFT TO LOWER CENTRE",NULL},
/* 1FB57 */ { "UPPER LEFT BLOCK DIAGONAL UPPER MIDDLE LEFT TO UPPER CENTRE",NULL},
/* 1FB58 */ { "UPPER LEFT BLOCK DIAGONAL UPPER MIDDLE LEFT TO UPPER RIGHT",NULL},
/* 1FB59 */ { "UPPER LEFT BLOCK DIAGONAL LOWER MIDDLE LEFT TO UPPER CENTRE",NULL},
/* 1FB5A */ { "UPPER LEFT BLOCK DIAGONAL LOWER MIDDLE LEFT TO UPPER RIGHT",NULL},
/* 1FB5B */ { "UPPER LEFT BLOCK DIAGONAL LOWER LEFT TO UPPER CENTRE",NULL},
/* 1FB5C */ { "UPPER LEFT BLOCK DIAGONAL LOWER MIDDLE LEFT TO UPPER MIDDLE RIGHT",NULL},
/* 1FB5D */ { "UPPER LEFT BLOCK DIAGONAL LOWER CENTRE TO LOWER MIDDLE RIGHT",NULL},
/* 1FB5E */ { "UPPER LEFT BLOCK DIAGONAL LOWER LEFT TO LOWER MIDDLE RIGHT",NULL},
/* 1FB5F */ { "UPPER LEFT BLOCK DIAGONAL LOWER CENTRE TO UPPER MIDDLE RIGHT",NULL},
/* 1FB60 */ { "UPPER LEFT BLOCK DIAGONAL LOWER LEFT TO UPPER MIDDLE RIGHT",NULL},
/* 1FB61 */ { "UPPER LEFT BLOCK DIAGONAL LOWER CENTRE TO UPPER RIGHT",NULL},
/* 1FB62 */ { "UPPER RIGHT BLOCK DIAGONAL UPPER CENTRE TO UPPER MIDDLE RIGHT",NULL},
/* 1FB63 */ { "UPPER RIGHT BLOCK DIAGONAL UPPER LEFT TO UPPER MIDDLE RIGHT",NULL},
/* 1FB64 */ { "UPPER RIGHT BLOCK DIAGONAL UPPER CENTRE TO LOWER MIDDLE RIGHT",NULL},
/* 1FB65 */ { "UPPER RIGHT BLOCK DIAGONAL UPPER LEFT TO LOWER MIDDLE RIGHT",NULL},
/* 1FB66 */ { "UPPER RIGHT BLOCK DIAGONAL UPPER CENTRE TO LOWER RIGHT",NULL},
/* 1FB67 */ { "UPPER RIGHT BLOCK DIAGONAL UPPER MIDDLE LEFT TO LOWER MIDDLE RIGHT",NULL},
/* 1FB68 */ { "UPPER AND RIGHT AND LOWER TRIANGULAR THREE QUARTERS BLOCK",NULL},
/* 1FB69 */ { "LEFT AND LOWER AND RIGHT TRIANGULAR THREE QUARTERS BLOCK",NULL},
/* 1FB6A */ { "UPPER AND LEFT AND LOWER TRIANGULAR THREE QUARTERS BLOCK",NULL},
/* 1FB6B */ { "LEFT AND UPPER AND RIGHT TRIANGULAR THREE QUARTERS BLOCK",NULL},
/* 1FB6C */ { "LEFT TRIANGULAR ONE QUARTER BLOCK",NULL},
/* 1FB6D */ { "UPPER TRIANGULAR ONE QUARTER BLOCK",NULL},
/* 1FB6E */ { "RIGHT TRIANGULAR ONE QUARTER BLOCK",NULL},
/* 1FB6F */ { "LOWER TRIANGULAR ONE QUARTER BLOCK",NULL},
/* 1FB70 */ { "VERTICAL ONE EIGHTH BLOCK-2","	x (left one eighth block - 258F)"},
/* 1FB71 */ { "VERTICAL ONE EIGHTH BLOCK-3",NULL},
/* 1FB72 */ { "VERTICAL ONE EIGHTH BLOCK-4",NULL},
/* 1FB73 */ { "VERTICAL ONE EIGHTH BLOCK-5",NULL},
/* 1FB74 */ { "VERTICAL ONE EIGHTH BLOCK-6",NULL},
/* 1FB75 */ { "VERTICAL ONE EIGHTH BLOCK-7","	x (right one eighth block - 2595)"},
/* 1FB76 */ { "HORIZONTAL ONE EIGHTH BLOCK-2","	x (upper one eighth block - 2594)"},
/* 1FB77 */ { "HORIZONTAL ONE EIGHTH BLOCK-3",NULL},
/* 1FB78 */ { "HORIZONTAL ONE EIGHTH BLOCK-4",NULL},
/* 1FB79 */ { "HORIZONTAL ONE EIGHTH BLOCK-5",NULL},
/* 1FB7A */ { "HORIZONTAL ONE EIGHTH BLOCK-6",NULL},
/* 1FB7B */ { "HORIZONTAL ONE EIGHTH BLOCK-7","	x (lower one eighth block - 2581)"},
/* 1FB7C */ { "LEFT AND LOWER ONE EIGHTH BLOCK",NULL},
/* 1FB7D */ { "LEFT AND UPPER ONE EIGHTH BLOCK",NULL},
/* 1FB7E */ { "RIGHT AND UPPER ONE EIGHTH BLOCK",NULL},
/* 1FB7F */ { "RIGHT AND LOWER ONE EIGHTH BLOCK",NULL},
/* 1FB80 */ { "UPPER AND LOWER ONE EIGHTH BLOCK",NULL},
/* 1FB81 */ { "HORIZONTAL ONE EIGHTH BLOCK-1358",NULL},
/* 1FB82 */ { "UPPER ONE QUARTER BLOCK","	x (lower one quarter block - 2582)"},
/* 1FB83 */ { "UPPER THREE EIGHTHS BLOCK","	x (lower three eighths block - 2583)"},
/* 1FB84 */ { "UPPER FIVE EIGHTHS BLOCK","	x (lower five eighths block - 2585)"},
/* 1FB85 */ { "UPPER THREE QUARTERS BLOCK","	x (lower three quarters block - 2586)"},
/* 1FB86 */ { "UPPER SEVEN EIGHTHS BLOCK","	x (lower seven eighths block - 2587)"},
/* 1FB87 */ { "RIGHT ONE QUARTER BLOCK","	x (left one quarter block - 258E)"},
/* 1FB88 */ { "RIGHT THREE EIGHTHS BLOCK","	x (left three eighths block - 258D)"},
/* 1FB89 */ { "RIGHT FIVE EIGHTHS BLOCK","	x (left five eighths block - 258B)"},
/* 1FB8A */ { "RIGHT THREE QUARTERS BLOCK","	x (left three quarters block - 258A)"},
/* 1FB8B */ { "RIGHT SEVEN EIGHTHS BLOCK","	x (left seven eighths block - 2589)"},
/* 1FB8C */ { "LEFT HALF MEDIUM SHADE",NULL},
/* 1FB8D */ { "RIGHT HALF MEDIUM SHADE",NULL},
/* 1FB8E */ { "UPPER HALF MEDIUM SHADE",NULL},
/* 1FB8F */ { "LOWER HALF MEDIUM SHADE",NULL},
/* 1FB90 */ { "INVERSE MEDIUM SHADE","	x (medium shade - 2592)"},
/* 1FB91 */ { "UPPER HALF BLOCK AND LOWER HALF INVERSE MEDIUM SHADE",NULL},
/* 1FB92 */ { "UPPER HALF INVERSE MEDIUM SHADE AND LOWER HALF BLOCK",NULL},
/* 1FB93 */ { NULL,NULL},
/* 1FB94 */ { "LEFT HALF INVERSE MEDIUM SHADE AND RIGHT HALF BLOCK",NULL},
/* 1FB95 */ { "CHECKER BOARD FILL","	x (quadrant upper left and lower right - 259A)\n"
	"	x (reverse checker board - 1F67F)"},
/* 1FB96 */ { "INVERSE CHECKER BOARD FILL","	x (quadrant upper right and lower left - 259E)\n"
	"	x (checker board - 1F67E)"},
/* 1FB97 */ { "HEAVY HORIZONTAL FILL","	* upper middle and lower one quarter block\n"
	"	x (geta mark - 3013)\n"
	"	x (block octant-3478 - 1CDB7)"},
/* 1FB98 */ { "UPPER LEFT TO LOWER RIGHT FILL","	x (square with upper left to lower right fill - 25A7)"},
/* 1FB99 */ { "UPPER RIGHT TO LOWER LEFT FILL","	x (square with upper right to lower left fill - 25A8)"},
/* 1FB9A */ { "UPPER AND LOWER TRIANGULAR HALF BLOCK","	x (black hourglass - 29D7)"},
/* 1FB9B */ { "LEFT AND RIGHT TRIANGULAR HALF BLOCK","	x (black bowtie - 29D3)"},
/* 1FB9C */ { "UPPER LEFT TRIANGULAR MEDIUM SHADE","	x (black upper left triangle - 25E4)"},
/* 1FB9D */ { "UPPER RIGHT TRIANGULAR MEDIUM SHADE","	x (black upper right triangle - 25E5)"},
/* 1FB9E */ { "LOWER RIGHT TRIANGULAR MEDIUM SHADE","	x (black lower right triangle - 25E2)"},
/* 1FB9F */ { "LOWER LEFT TRIANGULAR MEDIUM SHADE","	x (black lower left triangle - 25E3)"},
/* 1FBA0 */ { "BOX DRAWINGS LIGHT DIAGONAL UPPER CENTRE TO MIDDLE LEFT",NULL},
/* 1FBA1 */ { "BOX DRAWINGS LIGHT DIAGONAL UPPER CENTRE TO MIDDLE RIGHT",NULL},
/* 1FBA2 */ { "BOX DRAWINGS LIGHT DIAGONAL MIDDLE LEFT TO LOWER CENTRE",NULL},
/* 1FBA3 */ { "BOX DRAWINGS LIGHT DIAGONAL MIDDLE RIGHT TO LOWER CENTRE",NULL},
/* 1FBA4 */ { "BOX DRAWINGS LIGHT DIAGONAL UPPER CENTRE TO MIDDLE LEFT TO LOWER CENTRE",NULL},
/* 1FBA5 */ { "BOX DRAWINGS LIGHT DIAGONAL UPPER CENTRE TO MIDDLE RIGHT TO LOWER CENTRE",NULL},
/* 1FBA6 */ { "BOX DRAWINGS LIGHT DIAGONAL MIDDLE LEFT TO LOWER CENTRE TO MIDDLE RIGHT",NULL},
/* 1FBA7 */ { "BOX DRAWINGS LIGHT DIAGONAL MIDDLE LEFT TO UPPER CENTRE TO MIDDLE RIGHT",NULL},
/* 1FBA8 */ { "BOX DRAWINGS LIGHT DIAGONAL UPPER CENTRE TO MIDDLE LEFT AND MIDDLE RIGHT TO LOWER CENTRE",NULL},
/* 1FBA9 */ { "BOX DRAWINGS LIGHT DIAGONAL UPPER CENTRE TO MIDDLE RIGHT AND MIDDLE LEFT TO LOWER CENTRE",NULL},
/* 1FBAA */ { "BOX DRAWINGS LIGHT DIAGONAL UPPER CENTRE TO MIDDLE RIGHT TO LOWER CENTRE TO MIDDLE LEFT",NULL},
/* 1FBAB */ { "BOX DRAWINGS LIGHT DIAGONAL UPPER CENTRE TO MIDDLE LEFT TO LOWER CENTRE TO MIDDLE RIGHT",NULL},
/* 1FBAC */ { "BOX DRAWINGS LIGHT DIAGONAL MIDDLE LEFT TO UPPER CENTRE TO MIDDLE RIGHT TO LOWER CENTRE",NULL},
/* 1FBAD */ { "BOX DRAWINGS LIGHT DIAGONAL MIDDLE RIGHT TO UPPER CENTRE TO MIDDLE LEFT TO LOWER CENTRE",NULL},
/* 1FBAE */ { "BOX DRAWINGS LIGHT DIAGONAL DIAMOND","	x (white diamond - 25C7)"},
/* 1FBAF */ { "BOX DRAWINGS LIGHT HORIZONTAL WITH VERTICAL STROKE","	x (box drawings light horizontal - 2500)"},
/* 1FBB0 */ { "ARROWHEAD-SHAPED POINTER","	x (black rightwards arrowhead - 27A4)"},
/* 1FBB1 */ { "INVERSE CHECK MARK","	x (check mark - 2713)"},
/* 1FBB2 */ { "LEFT HALF RUNNING MAN","	* paired with 1FBB3, faces to the right\n"
	"	* the Apple II documentation refers to these characters as \"Running Man\"\n"
	"	x (runner - 1F3C3)"},
/* 1FBB3 */ { "RIGHT HALF RUNNING MAN",NULL},
/* 1FBB4 */ { "INVERSE DOWNWARDS ARROW WITH TIP LEFTWARDS","	x (downwards arrow with tip leftwards - 21B2)\n"
	"	x (downwards arrow with corner leftwards - 21B5)"},
/* 1FBB5 */ { "LEFTWARDS ARROW AND UPPER AND LOWER ONE EIGHTH BLOCK",NULL},
/* 1FBB6 */ { "RIGHTWARDS ARROW AND UPPER AND LOWER ONE EIGHTH BLOCK",NULL},
/* 1FBB7 */ { "DOWNWARDS ARROW AND RIGHT ONE EIGHTH BLOCK",NULL},
/* 1FBB8 */ { "UPWARDS ARROW AND RIGHT ONE EIGHTH BLOCK",NULL},
/* 1FBB9 */ { "LEFT HALF FOLDER","	* paired with 1FBBA\n"
	"	x (file folder - 1F4C1)\n"
	"	x (folder - 1F5C0)"},
/* 1FBBA */ { "RIGHT HALF FOLDER",NULL},
/* 1FBBB */ { "VOIDED GREEK CROSS","	x (number sign - 0023)\n"
	"	x (box drawings double vertical and horizontal - 256C)\n"
	"	x (outlined greek cross - 2719)\n"
	"	x (heavy greek cross - 271A)\n"
	"	x (medium greek cross - 1F7A3)"},
/* 1FBBC */ { "RIGHT OPEN SQUARED DOT","	x (squared dot operator - 22A1)"},
/* 1FBBD */ { "NEGATIVE DIAGONAL CROSS","	* diagonals extend past the corners of the box, unlike in 274E\n"
	"	x (box drawings light diagonal cross - 2573)\n"
	"	x (negative squared cross mark - 274E)"},
/* 1FBBE */ { "NEGATIVE DIAGONAL MIDDLE RIGHT TO LOWER CENTRE",NULL},
/* 1FBBF */ { "NEGATIVE DIAGONAL DIAMOND",NULL},
/* 1FBC0 */ { "WHITE HEAVY SALTIRE WITH ROUNDED CORNERS","	x (cross mark - 274C)\n"
	"	x (cancellation x - 1F5D9)\n"
	"	x (heavy saltire - 1F7AC)"},
/* 1FBC1 */ { "LEFT THIRD WHITE RIGHT POINTING INDEX","	* glyph part, combined with 1FBC2 and 1FBC3\n"
	"	x (white right pointing index - 261E)"},
/* 1FBC2 */ { "MIDDLE THIRD WHITE RIGHT POINTING INDEX",NULL},
/* 1FBC3 */ { "RIGHT THIRD WHITE RIGHT POINTING INDEX",NULL},
/* 1FBC4 */ { "NEGATIVE SQUARED QUESTION MARK","	* glyph does not necessarily extend to the edges of the character cell\n"
	"	x (question mark - 003F)\n"
	"	x (uncertainty sign - 2BD1)\n"
	"	x (replacement character - FFFD)"},
/* 1FBC5 */ { "STICK FIGURE","	x (mens symbol - 1F6B9)"},
/* 1FBC6 */ { "STICK FIGURE WITH ARMS RAISED",NULL},
/* 1FBC7 */ { "STICK FIGURE LEANING LEFT",NULL},
/* 1FBC8 */ { "STICK FIGURE LEANING RIGHT",NULL},
/* 1FBC9 */ { "STICK FIGURE WITH DRESS","	x (womens symbol - 1F6BA)"},
/* 1FBCA */ { "WHITE UP-POINTING CHEVRON","	x (upwards white arrow - 21E7)\n"
	"	x (house - 2302)\n"
	"	x (upwards finger-post arrow - 1F835)"},
/* 1FBCB */ { "WHITE CROSS MARK",NULL},
/* 1FBCC */ { "RAISED SMALL LEFT SQUARE BRACKET",NULL},
/* 1FBCD */ { "BLACK SMALL UP-POINTING CHEVRON",NULL},
/* 1FBCE */ { "LEFT TWO THIRDS BLOCK",NULL},
/* 1FBCF */ { "LEFT ONE THIRD BLOCK",NULL},
/* 1FBD0 */ { "BOX DRAWINGS LIGHT DIAGONAL MIDDLE RIGHT TO LOWER LEFT",NULL},
/* 1FBD1 */ { "BOX DRAWINGS LIGHT DIAGONAL UPPER RIGHT TO MIDDLE LEFT",NULL},
/* 1FBD2 */ { "BOX DRAWINGS LIGHT DIAGONAL UPPER LEFT TO MIDDLE RIGHT",NULL},
/* 1FBD3 */ { "BOX DRAWINGS LIGHT DIAGONAL MIDDLE LEFT TO LOWER RIGHT",NULL},
/* 1FBD4 */ { "BOX DRAWINGS LIGHT DIAGONAL UPPER LEFT TO LOWER CENTRE",NULL},
/* 1FBD5 */ { "BOX DRAWINGS LIGHT DIAGONAL UPPER CENTRE TO LOWER RIGHT",NULL},
/* 1FBD6 */ { "BOX DRAWINGS LIGHT DIAGONAL UPPER RIGHT TO LOWER CENTRE",NULL},
/* 1FBD7 */ { "BOX DRAWINGS LIGHT DIAGONAL UPPER CENTRE TO LOWER LEFT",NULL},
/* 1FBD8 */ { "BOX DRAWINGS LIGHT DIAGONAL UPPER LEFT TO MIDDLE CENTRE TO UPPER RIGHT",NULL},
/* 1FBD9 */ { "BOX DRAWINGS LIGHT DIAGONAL UPPER RIGHT TO MIDDLE CENTRE TO LOWER RIGHT",NULL},
/* 1FBDA */ { "BOX DRAWINGS LIGHT DIAGONAL LOWER LEFT TO MIDDLE CENTRE TO LOWER RIGHT",NULL},
/* 1FBDB */ { "BOX DRAWINGS LIGHT DIAGONAL UPPER LEFT TO MIDDLE CENTRE TO LOWER LEFT",NULL},
/* 1FBDC */ { "BOX DRAWINGS LIGHT DIAGONAL UPPER LEFT TO LOWER CENTRE TO UPPER RIGHT",NULL},
/* 1FBDD */ { "BOX DRAWINGS LIGHT DIAGONAL UPPER RIGHT TO MIDDLE LEFT TO LOWER RIGHT",NULL},
/* 1FBDE */ { "BOX DRAWINGS LIGHT DIAGONAL LOWER LEFT TO UPPER CENTRE TO LOWER RIGHT",NULL},
/* 1FBDF */ { "BOX DRAWINGS LIGHT DIAGONAL UPPER LEFT TO MIDDLE RIGHT TO LOWER LEFT",NULL},
/* 1FBE0 */ { "TOP JUSTIFIED LOWER HALF WHITE CIRCLE",NULL},
/* 1FBE1 */ { "RIGHT JUSTIFIED LEFT HALF WHITE CIRCLE",NULL},
/* 1FBE2 */ { "BOTTOM JUSTIFIED UPPER HALF WHITE CIRCLE",NULL},
/* 1FBE3 */ { "LEFT JUSTIFIED RIGHT HALF WHITE CIRCLE",NULL},
/* 1FBE4 */ { "UPPER CENTRE ONE QUARTER BLOCK",NULL},
/* 1FBE5 */ { "LOWER CENTRE ONE QUARTER BLOCK",NULL},
/* 1FBE6 */ { "MIDDLE LEFT ONE QUARTER BLOCK",NULL},
/* 1FBE7 */ { "MIDDLE RIGHT ONE QUARTER BLOCK",NULL},
/* 1FBE8 */ { "TOP JUSTIFIED LOWER HALF BLACK CIRCLE",NULL},
/* 1FBE9 */ { "RIGHT JUSTIFIED LEFT HALF BLACK CIRCLE",NULL},
/* 1FBEA */ { "BOTTOM JUSTIFIED UPPER HALF BLACK CIRCLE",NULL},
/* 1FBEB */ { "LEFT JUSTIFIED RIGHT HALF BLACK CIRCLE",NULL},
/* 1FBEC */ { "TOP RIGHT JUSTIFIED LOWER LEFT QUARTER BLACK CIRCLE",NULL},
/* 1FBED */ { "BOTTOM LEFT JUSTIFIED UPPER RIGHT QUARTER BLACK CIRCLE",NULL},
/* 1FBEE */ { "BOTTOM RIGHT JUSTIFIED UPPER LEFT QUARTER BLACK CIRCLE",NULL},
/* 1FBEF */ { "TOP LEFT JUSTIFIED LOWER RIGHT QUARTER BLACK CIRCLE",NULL},
/* 1FBF0 */ { "SEGMENTED DIGIT ZERO","	# <font> 0030 digit zero"},
/* 1FBF1 */ { "SEGMENTED DIGIT ONE","	# <font> 0031 digit one"},
/* 1FBF2 */ { "SEGMENTED DIGIT TWO","	# <font> 0032 digit two"},
/* 1FBF3 */ { "SEGMENTED DIGIT THREE","	# <font> 0033 digit three"},
/* 1FBF4 */ { "SEGMENTED DIGIT FOUR","	# <font> 0034 digit four"},
/* 1FBF5 */ { "SEGMENTED DIGIT FIVE","	# <font> 0035 digit five"},
/* 1FBF6 */ { "SEGMENTED DIGIT SIX","	# <font> 0036 digit six"},
/* 1FBF7 */ { "SEGMENTED DIGIT SEVEN","	# <font> 0037 digit seven"},
/* 1FBF8 */ { "SEGMENTED DIGIT EIGHT","	# <font> 0038 digit eight"},
/* 1FBF9 */ { "SEGMENTED DIGIT NINE","	# <font> 0039 digit nine"},
/* 1FBFA */ { "ALARM BELL SYMBOL","	x (bell symbol - 237E)\n"
	"	x (bell - 1F514)"},
/* 1FBFB */ { NULL,NULL},
/* 1FBFC */ { NULL,NULL},
/* 1FBFD */ { NULL,NULL},
/* 1FBFE */ { NULL,NULL},
/* 1FBFF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_02_F8[] = {
/* 2F800 */ { "CJK COMPATIBILITY IDEOGRAPH-2F800","	: 4E3D"},
/* 2F801 */ { "CJK COMPATIBILITY IDEOGRAPH-2F801","	: 4E38"},
/* 2F802 */ { "CJK COMPATIBILITY IDEOGRAPH-2F802","	: 4E41"},
/* 2F803 */ { "CJK COMPATIBILITY IDEOGRAPH-2F803","	: 20122"},
/* 2F804 */ { "CJK COMPATIBILITY IDEOGRAPH-2F804","	: 4F60"},
/* 2F805 */ { "CJK COMPATIBILITY IDEOGRAPH-2F805","	: 4FAE"},
/* 2F806 */ { "CJK COMPATIBILITY IDEOGRAPH-2F806","	: 4FBB"},
/* 2F807 */ { "CJK COMPATIBILITY IDEOGRAPH-2F807","	: 5002"},
/* 2F808 */ { "CJK COMPATIBILITY IDEOGRAPH-2F808","	: 507A"},
/* 2F809 */ { "CJK COMPATIBILITY IDEOGRAPH-2F809","	: 5099"},
/* 2F80A */ { "CJK COMPATIBILITY IDEOGRAPH-2F80A","	: 50E7"},
/* 2F80B */ { "CJK COMPATIBILITY IDEOGRAPH-2F80B","	: 50CF"},
/* 2F80C */ { "CJK COMPATIBILITY IDEOGRAPH-2F80C","	: 349E"},
/* 2F80D */ { "CJK COMPATIBILITY IDEOGRAPH-2F80D","	x 5145\n"
	"	: 2063A"},
/* 2F80E */ { "CJK COMPATIBILITY IDEOGRAPH-2F80E","	: 514D"},
/* 2F80F */ { "CJK COMPATIBILITY IDEOGRAPH-2F80F","	: 5154"},
/* 2F810 */ { "CJK COMPATIBILITY IDEOGRAPH-2F810","	: 5164"},
/* 2F811 */ { "CJK COMPATIBILITY IDEOGRAPH-2F811","	: 5177"},
/* 2F812 */ { "CJK COMPATIBILITY IDEOGRAPH-2F812","	: 2051C"},
/* 2F813 */ { "CJK COMPATIBILITY IDEOGRAPH-2F813","	: 34B9"},
/* 2F814 */ { "CJK COMPATIBILITY IDEOGRAPH-2F814","	x 5185\n"
	"	: 5167"},
/* 2F815 */ { "CJK COMPATIBILITY IDEOGRAPH-2F815","	: 518D"},
/* 2F816 */ { "CJK COMPATIBILITY IDEOGRAPH-2F816","	: 2054B"},
/* 2F817 */ { "CJK COMPATIBILITY IDEOGRAPH-2F817","	: 5197"},
/* 2F818 */ { "CJK COMPATIBILITY IDEOGRAPH-2F818","	: 51A4"},
/* 2F819 */ { "CJK COMPATIBILITY IDEOGRAPH-2F819","	: 4ECC"},
/* 2F81A */ { "CJK COMPATIBILITY IDEOGRAPH-2F81A","	: 51AC"},
/* 2F81B */ { "CJK COMPATIBILITY IDEOGRAPH-2F81B","	: 51B5"},
/* 2F81C */ { "CJK COMPATIBILITY IDEOGRAPH-2F81C","	: 291DF"},
/* 2F81D */ { "CJK COMPATIBILITY IDEOGRAPH-2F81D","	: 51F5"},
/* 2F81E */ { "CJK COMPATIBILITY IDEOGRAPH-2F81E","	: 5203"},
/* 2F81F */ { "CJK COMPATIBILITY IDEOGRAPH-2F81F","	: 34DF"},
/* 2F820 */ { "CJK COMPATIBILITY IDEOGRAPH-2F820","	: 523B"},
/* 2F821 */ { "CJK COMPATIBILITY IDEOGRAPH-2F821","	: 5246"},
/* 2F822 */ { "CJK COMPATIBILITY IDEOGRAPH-2F822","	: 5272"},
/* 2F823 */ { "CJK COMPATIBILITY IDEOGRAPH-2F823","	: 5277"},
/* 2F824 */ { "CJK COMPATIBILITY IDEOGRAPH-2F824","	: 3515"},
/* 2F825 */ { "CJK COMPATIBILITY IDEOGRAPH-2F825","	: 52C7"},
/* 2F826 */ { "CJK COMPATIBILITY IDEOGRAPH-2F826","	: 52C9"},
/* 2F827 */ { "CJK COMPATIBILITY IDEOGRAPH-2F827","	: 52E4"},
/* 2F828 */ { "CJK COMPATIBILITY IDEOGRAPH-2F828","	: 52FA"},
/* 2F829 */ { "CJK COMPATIBILITY IDEOGRAPH-2F829","	: 5305"},
/* 2F82A */ { "CJK COMPATIBILITY IDEOGRAPH-2F82A","	: 5306"},
/* 2F82B */ { "CJK COMPATIBILITY IDEOGRAPH-2F82B","	: 5317"},
/* 2F82C */ { "CJK COMPATIBILITY IDEOGRAPH-2F82C","	x 20984\n"
	"	: 5349"},
/* 2F82D */ { "CJK COMPATIBILITY IDEOGRAPH-2F82D","	: 5351"},
/* 2F82E */ { "CJK COMPATIBILITY IDEOGRAPH-2F82E","	: 535A"},
/* 2F82F */ { "CJK COMPATIBILITY IDEOGRAPH-2F82F","	: 5373"},
/* 2F830 */ { "CJK COMPATIBILITY IDEOGRAPH-2F830","	: 537D"},
/* 2F831 */ { "CJK COMPATIBILITY IDEOGRAPH-2F831","	: 537F"},
/* 2F832 */ { "CJK COMPATIBILITY IDEOGRAPH-2F832","	: 537F"},
/* 2F833 */ { "CJK COMPATIBILITY IDEOGRAPH-2F833","	: 537F"},
/* 2F834 */ { "CJK COMPATIBILITY IDEOGRAPH-2F834","	: 20A2C"},
/* 2F835 */ { "CJK COMPATIBILITY IDEOGRAPH-2F835","	: 7070"},
/* 2F836 */ { "CJK COMPATIBILITY IDEOGRAPH-2F836","	: 53CA"},
/* 2F837 */ { "CJK COMPATIBILITY IDEOGRAPH-2F837","	: 53DF"},
/* 2F838 */ { "CJK COMPATIBILITY IDEOGRAPH-2F838","	: 20B63"},
/* 2F839 */ { "CJK COMPATIBILITY IDEOGRAPH-2F839","	: 53EB"},
/* 2F83A */ { "CJK COMPATIBILITY IDEOGRAPH-2F83A","	: 53F1"},
/* 2F83B */ { "CJK COMPATIBILITY IDEOGRAPH-2F83B","	x 4DB8\n"
	"	: 5406"},
/* 2F83C */ { "CJK COMPATIBILITY IDEOGRAPH-2F83C","	: 549E"},
/* 2F83D */ { "CJK COMPATIBILITY IDEOGRAPH-2F83D","	: 5438"},
/* 2F83E */ { "CJK COMPATIBILITY IDEOGRAPH-2F83E","	: 5448"},
/* 2F83F */ { "CJK COMPATIBILITY IDEOGRAPH-2F83F","	: 5468"},
/* 2F840 */ { "CJK COMPATIBILITY IDEOGRAPH-2F840","	: 54A2"},
/* 2F841 */ { "CJK COMPATIBILITY IDEOGRAPH-2F841","	: 54F6"},
/* 2F842 */ { "CJK COMPATIBILITY IDEOGRAPH-2F842","	: 5510"},
/* 2F843 */ { "CJK COMPATIBILITY IDEOGRAPH-2F843","	: 5553"},
/* 2F844 */ { "CJK COMPATIBILITY IDEOGRAPH-2F844","	: 5563"},
/* 2F845 */ { "CJK COMPATIBILITY IDEOGRAPH-2F845","	: 5584"},
/* 2F846 */ { "CJK COMPATIBILITY IDEOGRAPH-2F846","	: 5584"},
/* 2F847 */ { "CJK COMPATIBILITY IDEOGRAPH-2F847","	: 5599"},
/* 2F848 */ { "CJK COMPATIBILITY IDEOGRAPH-2F848","	: 55AB"},
/* 2F849 */ { "CJK COMPATIBILITY IDEOGRAPH-2F849","	: 55B3"},
/* 2F84A */ { "CJK COMPATIBILITY IDEOGRAPH-2F84A","	: 55C2"},
/* 2F84B */ { "CJK COMPATIBILITY IDEOGRAPH-2F84B","	: 5716"},
/* 2F84C */ { "CJK COMPATIBILITY IDEOGRAPH-2F84C","	: 5606"},
/* 2F84D */ { "CJK COMPATIBILITY IDEOGRAPH-2F84D","	: 5717"},
/* 2F84E */ { "CJK COMPATIBILITY IDEOGRAPH-2F84E","	: 5651"},
/* 2F84F */ { "CJK COMPATIBILITY IDEOGRAPH-2F84F","	: 5674"},
/* 2F850 */ { "CJK COMPATIBILITY IDEOGRAPH-2F850","	: 5207"},
/* 2F851 */ { "CJK COMPATIBILITY IDEOGRAPH-2F851","	: 58EE"},
/* 2F852 */ { "CJK COMPATIBILITY IDEOGRAPH-2F852","	: 57CE"},
/* 2F853 */ { "CJK COMPATIBILITY IDEOGRAPH-2F853","	: 57F4"},
/* 2F854 */ { "CJK COMPATIBILITY IDEOGRAPH-2F854","	: 580D"},
/* 2F855 */ { "CJK COMPATIBILITY IDEOGRAPH-2F855","	: 578B"},
/* 2F856 */ { "CJK COMPATIBILITY IDEOGRAPH-2F856","	: 5832"},
/* 2F857 */ { "CJK COMPATIBILITY IDEOGRAPH-2F857","	: 5831"},
/* 2F858 */ { "CJK COMPATIBILITY IDEOGRAPH-2F858","	: 58AC"},
/* 2F859 */ { "CJK COMPATIBILITY IDEOGRAPH-2F859","	: 214E4"},
/* 2F85A */ { "CJK COMPATIBILITY IDEOGRAPH-2F85A","	x 58F3\n"
	"	: 58F2"},
/* 2F85B */ { "CJK COMPATIBILITY IDEOGRAPH-2F85B","	x 21533\n"
	"	: 58F7"},
/* 2F85C */ { "CJK COMPATIBILITY IDEOGRAPH-2F85C","	: 5906"},
/* 2F85D */ { "CJK COMPATIBILITY IDEOGRAPH-2F85D","	: 591A"},
/* 2F85E */ { "CJK COMPATIBILITY IDEOGRAPH-2F85E","	: 5922"},
/* 2F85F */ { "CJK COMPATIBILITY IDEOGRAPH-2F85F","	: 5962"},
/* 2F860 */ { "CJK COMPATIBILITY IDEOGRAPH-2F860","	x 216A7\n"
	"	: 216A8"},
/* 2F861 */ { "CJK COMPATIBILITY IDEOGRAPH-2F861","	: 216EA"},
/* 2F862 */ { "CJK COMPATIBILITY IDEOGRAPH-2F862","	: 59EC"},
/* 2F863 */ { "CJK COMPATIBILITY IDEOGRAPH-2F863","	: 5A1B"},
/* 2F864 */ { "CJK COMPATIBILITY IDEOGRAPH-2F864","	: 5A27"},
/* 2F865 */ { "CJK COMPATIBILITY IDEOGRAPH-2F865","	: 59D8"},
/* 2F866 */ { "CJK COMPATIBILITY IDEOGRAPH-2F866","	: 5A66"},
/* 2F867 */ { "CJK COMPATIBILITY IDEOGRAPH-2F867","	: 36EE"},
/* 2F868 */ { "CJK COMPATIBILITY IDEOGRAPH-2F868","	: 36FC"},
/* 2F869 */ { "CJK COMPATIBILITY IDEOGRAPH-2F869","	: 5B08"},
/* 2F86A */ { "CJK COMPATIBILITY IDEOGRAPH-2F86A","	: 5B3E"},
/* 2F86B */ { "CJK COMPATIBILITY IDEOGRAPH-2F86B","	: 5B3E"},
/* 2F86C */ { "CJK COMPATIBILITY IDEOGRAPH-2F86C","	: 219C8"},
/* 2F86D */ { "CJK COMPATIBILITY IDEOGRAPH-2F86D","	: 5BC3"},
/* 2F86E */ { "CJK COMPATIBILITY IDEOGRAPH-2F86E","	: 5BD8"},
/* 2F86F */ { "CJK COMPATIBILITY IDEOGRAPH-2F86F","	: 5BE7"},
/* 2F870 */ { "CJK COMPATIBILITY IDEOGRAPH-2F870","	: 5BF3"},
/* 2F871 */ { "CJK COMPATIBILITY IDEOGRAPH-2F871","	: 21B18"},
/* 2F872 */ { "CJK COMPATIBILITY IDEOGRAPH-2F872","	: 5BFF"},
/* 2F873 */ { "CJK COMPATIBILITY IDEOGRAPH-2F873","	: 5C06"},
/* 2F874 */ { "CJK COMPATIBILITY IDEOGRAPH-2F874","	x 22450\n"
	"	: 5F53"},
/* 2F875 */ { "CJK COMPATIBILITY IDEOGRAPH-2F875","	: 5C22"},
/* 2F876 */ { "CJK COMPATIBILITY IDEOGRAPH-2F876","	: 3781"},
/* 2F877 */ { "CJK COMPATIBILITY IDEOGRAPH-2F877","	: 5C60"},
/* 2F878 */ { "CJK COMPATIBILITY IDEOGRAPH-2F878","	x 4DB9\n"
	"	: 5C6E"},
/* 2F879 */ { "CJK COMPATIBILITY IDEOGRAPH-2F879","	: 5CC0"},
/* 2F87A */ { "CJK COMPATIBILITY IDEOGRAPH-2F87A","	: 5C8D"},
/* 2F87B */ { "CJK COMPATIBILITY IDEOGRAPH-2F87B","	: 21DE4"},
/* 2F87C */ { "CJK COMPATIBILITY IDEOGRAPH-2F87C","	: 5D43"},
/* 2F87D */ { "CJK COMPATIBILITY IDEOGRAPH-2F87D","	: 21DE6"},
/* 2F87E */ { "CJK COMPATIBILITY IDEOGRAPH-2F87E","	: 5D6E"},
/* 2F87F */ { "CJK COMPATIBILITY IDEOGRAPH-2F87F","	: 5D6B"},
/* 2F880 */ { "CJK COMPATIBILITY IDEOGRAPH-2F880","	: 5D7C"},
/* 2F881 */ { "CJK COMPATIBILITY IDEOGRAPH-2F881","	: 5DE1"},
/* 2F882 */ { "CJK COMPATIBILITY IDEOGRAPH-2F882","	: 5DE2"},
/* 2F883 */ { "CJK COMPATIBILITY IDEOGRAPH-2F883","	: 382F"},
/* 2F884 */ { "CJK COMPATIBILITY IDEOGRAPH-2F884","	: 5DFD"},
/* 2F885 */ { "CJK COMPATIBILITY IDEOGRAPH-2F885","	: 5E28"},
/* 2F886 */ { "CJK COMPATIBILITY IDEOGRAPH-2F886","	: 5E3D"},
/* 2F887 */ { "CJK COMPATIBILITY IDEOGRAPH-2F887","	: 5E69"},
/* 2F888 */ { "CJK COMPATIBILITY IDEOGRAPH-2F888","	: 3862"},
/* 2F889 */ { "CJK COMPATIBILITY IDEOGRAPH-2F889","	: 22183"},
/* 2F88A */ { "CJK COMPATIBILITY IDEOGRAPH-2F88A","	: 387C"},
/* 2F88B */ { "CJK COMPATIBILITY IDEOGRAPH-2F88B","	: 5EB0"},
/* 2F88C */ { "CJK COMPATIBILITY IDEOGRAPH-2F88C","	: 5EB3"},
/* 2F88D */ { "CJK COMPATIBILITY IDEOGRAPH-2F88D","	: 5EB6"},
/* 2F88E */ { "CJK COMPATIBILITY IDEOGRAPH-2F88E","	: 5ECA"},
/* 2F88F */ { "CJK COMPATIBILITY IDEOGRAPH-2F88F","	: 2A392"},
/* 2F890 */ { "CJK COMPATIBILITY IDEOGRAPH-2F890","	: 5EFE"},
/* 2F891 */ { "CJK COMPATIBILITY IDEOGRAPH-2F891","	: 22331"},
/* 2F892 */ { "CJK COMPATIBILITY IDEOGRAPH-2F892","	: 22331"},
/* 2F893 */ { "CJK COMPATIBILITY IDEOGRAPH-2F893","	: 8201"},
/* 2F894 */ { "CJK COMPATIBILITY IDEOGRAPH-2F894","	: 5F22"},
/* 2F895 */ { "CJK COMPATIBILITY IDEOGRAPH-2F895","	: 5F22"},
/* 2F896 */ { "CJK COMPATIBILITY IDEOGRAPH-2F896","	: 38C7"},
/* 2F897 */ { "CJK COMPATIBILITY IDEOGRAPH-2F897","	: 232B8"},
/* 2F898 */ { "CJK COMPATIBILITY IDEOGRAPH-2F898","	: 261DA"},
/* 2F899 */ { "CJK COMPATIBILITY IDEOGRAPH-2F899","	: 5F62"},
/* 2F89A */ { "CJK COMPATIBILITY IDEOGRAPH-2F89A","	: 5F6B"},
/* 2F89B */ { "CJK COMPATIBILITY IDEOGRAPH-2F89B","	: 38E3"},
/* 2F89C */ { "CJK COMPATIBILITY IDEOGRAPH-2F89C","	x 22505\n"
	"	: 5F9A"},
/* 2F89D */ { "CJK COMPATIBILITY IDEOGRAPH-2F89D","	: 5FCD"},
/* 2F89E */ { "CJK COMPATIBILITY IDEOGRAPH-2F89E","	: 5FD7"},
/* 2F89F */ { "CJK COMPATIBILITY IDEOGRAPH-2F89F","	: 5FF9"},
/* 2F8A0 */ { "CJK COMPATIBILITY IDEOGRAPH-2F8A0","	: 6081"},
/* 2F8A1 */ { "CJK COMPATIBILITY IDEOGRAPH-2F8A1","	: 393A"},
/* 2F8A2 */ { "CJK COMPATIBILITY IDEOGRAPH-2F8A2","	: 391C"},
/* 2F8A3 */ { "CJK COMPATIBILITY IDEOGRAPH-2F8A3","	: 6094"},
/* 2F8A4 */ { "CJK COMPATIBILITY IDEOGRAPH-2F8A4","	: 226D4"},
/* 2F8A5 */ { "CJK COMPATIBILITY IDEOGRAPH-2F8A5","	: 60C7"},
/* 2F8A6 */ { "CJK COMPATIBILITY IDEOGRAPH-2F8A6","	: 6148"},
/* 2F8A7 */ { "CJK COMPATIBILITY IDEOGRAPH-2F8A7","	: 614C"},
/* 2F8A8 */ { "CJK COMPATIBILITY IDEOGRAPH-2F8A8","	: 614E"},
/* 2F8A9 */ { "CJK COMPATIBILITY IDEOGRAPH-2F8A9","	: 614C"},
/* 2F8AA */ { "CJK COMPATIBILITY IDEOGRAPH-2F8AA","	: 617A"},
/* 2F8AB */ { "CJK COMPATIBILITY IDEOGRAPH-2F8AB","	: 618E"},
/* 2F8AC */ { "CJK COMPATIBILITY IDEOGRAPH-2F8AC","	: 61B2"},
/* 2F8AD */ { "CJK COMPATIBILITY IDEOGRAPH-2F8AD","	: 61A4"},
/* 2F8AE */ { "CJK COMPATIBILITY IDEOGRAPH-2F8AE","	: 61AF"},
/* 2F8AF */ { "CJK COMPATIBILITY IDEOGRAPH-2F8AF","	: 61DE"},
/* 2F8B0 */ { "CJK COMPATIBILITY IDEOGRAPH-2F8B0","	: 61F2"},
/* 2F8B1 */ { "CJK COMPATIBILITY IDEOGRAPH-2F8B1","	: 61F6"},
/* 2F8B2 */ { "CJK COMPATIBILITY IDEOGRAPH-2F8B2","	: 6210"},
/* 2F8B3 */ { "CJK COMPATIBILITY IDEOGRAPH-2F8B3","	: 621B"},
/* 2F8B4 */ { "CJK COMPATIBILITY IDEOGRAPH-2F8B4","	: 625D"},
/* 2F8B5 */ { "CJK COMPATIBILITY IDEOGRAPH-2F8B5","	: 62B1"},
/* 2F8B6 */ { "CJK COMPATIBILITY IDEOGRAPH-2F8B6","	: 62D4"},
/* 2F8B7 */ { "CJK COMPATIBILITY IDEOGRAPH-2F8B7","	: 6350"},
/* 2F8B8 */ { "CJK COMPATIBILITY IDEOGRAPH-2F8B8","	: 22B0C"},
/* 2F8B9 */ { "CJK COMPATIBILITY IDEOGRAPH-2F8B9","	: 633D"},
/* 2F8BA */ { "CJK COMPATIBILITY IDEOGRAPH-2F8BA","	: 62FC"},
/* 2F8BB */ { "CJK COMPATIBILITY IDEOGRAPH-2F8BB","	: 6368"},
/* 2F8BC */ { "CJK COMPATIBILITY IDEOGRAPH-2F8BC","	: 6383"},
/* 2F8BD */ { "CJK COMPATIBILITY IDEOGRAPH-2F8BD","	: 63E4"},
/* 2F8BE */ { "CJK COMPATIBILITY IDEOGRAPH-2F8BE","	: 22BF1"},
/* 2F8BF */ { "CJK COMPATIBILITY IDEOGRAPH-2F8BF","	: 6422"},
/* 2F8C0 */ { "CJK COMPATIBILITY IDEOGRAPH-2F8C0","	: 63C5"},
/* 2F8C1 */ { "CJK COMPATIBILITY IDEOGRAPH-2F8C1","	: 63A9"},
/* 2F8C2 */ { "CJK COMPATIBILITY IDEOGRAPH-2F8C2","	: 3A2E"},
/* 2F8C3 */ { "CJK COMPATIBILITY IDEOGRAPH-2F8C3","	: 6469"},
/* 2F8C4 */ { "CJK COMPATIBILITY IDEOGRAPH-2F8C4","	: 647E"},
/* 2F8C5 */ { "CJK COMPATIBILITY IDEOGRAPH-2F8C5","	: 649D"},
/* 2F8C6 */ { "CJK COMPATIBILITY IDEOGRAPH-2F8C6","	: 6477"},
/* 2F8C7 */ { "CJK COMPATIBILITY IDEOGRAPH-2F8C7","	: 3A6C"},
/* 2F8C8 */ { "CJK COMPATIBILITY IDEOGRAPH-2F8C8","	: 654F"},
/* 2F8C9 */ { "CJK COMPATIBILITY IDEOGRAPH-2F8C9","	: 656C"},
/* 2F8CA */ { "CJK COMPATIBILITY IDEOGRAPH-2F8CA","	: 2300A"},
/* 2F8CB */ { "CJK COMPATIBILITY IDEOGRAPH-2F8CB","	: 65E3"},
/* 2F8CC */ { "CJK COMPATIBILITY IDEOGRAPH-2F8CC","	: 66F8"},
/* 2F8CD */ { "CJK COMPATIBILITY IDEOGRAPH-2F8CD","	: 6649"},
/* 2F8CE */ { "CJK COMPATIBILITY IDEOGRAPH-2F8CE","	: 3B19"},
/* 2F8CF */ { "CJK COMPATIBILITY IDEOGRAPH-2F8CF","	: 6691"},
/* 2F8D0 */ { "CJK COMPATIBILITY IDEOGRAPH-2F8D0","	: 3B08"},
/* 2F8D1 */ { "CJK COMPATIBILITY IDEOGRAPH-2F8D1","	: 3AE4"},
/* 2F8D2 */ { "CJK COMPATIBILITY IDEOGRAPH-2F8D2","	: 5192"},
/* 2F8D3 */ { "CJK COMPATIBILITY IDEOGRAPH-2F8D3","	: 5195"},
/* 2F8D4 */ { "CJK COMPATIBILITY IDEOGRAPH-2F8D4","	: 6700"},
/* 2F8D5 */ { "CJK COMPATIBILITY IDEOGRAPH-2F8D5","	: 669C"},
/* 2F8D6 */ { "CJK COMPATIBILITY IDEOGRAPH-2F8D6","	: 80AD"},
/* 2F8D7 */ { "CJK COMPATIBILITY IDEOGRAPH-2F8D7","	: 43D9"},
/* 2F8D8 */ { "CJK COMPATIBILITY IDEOGRAPH-2F8D8","	: 6717"},
/* 2F8D9 */ { "CJK COMPATIBILITY IDEOGRAPH-2F8D9","	: 671B"},
/* 2F8DA */ { "CJK COMPATIBILITY IDEOGRAPH-2F8DA","	: 6721"},
/* 2F8DB */ { "CJK COMPATIBILITY IDEOGRAPH-2F8DB","	: 675E"},
/* 2F8DC */ { "CJK COMPATIBILITY IDEOGRAPH-2F8DC","	: 6753"},
/* 2F8DD */ { "CJK COMPATIBILITY IDEOGRAPH-2F8DD","	: 233C3"},
/* 2F8DE */ { "CJK COMPATIBILITY IDEOGRAPH-2F8DE","	: 3B49"},
/* 2F8DF */ { "CJK COMPATIBILITY IDEOGRAPH-2F8DF","	: 67FA"},
/* 2F8E0 */ { "CJK COMPATIBILITY IDEOGRAPH-2F8E0","	: 6785"},
/* 2F8E1 */ { "CJK COMPATIBILITY IDEOGRAPH-2F8E1","	: 6852"},
/* 2F8E2 */ { "CJK COMPATIBILITY IDEOGRAPH-2F8E2","	: 6885"},
/* 2F8E3 */ { "CJK COMPATIBILITY IDEOGRAPH-2F8E3","	: 2346D"},
/* 2F8E4 */ { "CJK COMPATIBILITY IDEOGRAPH-2F8E4","	: 688E"},
/* 2F8E5 */ { "CJK COMPATIBILITY IDEOGRAPH-2F8E5","	: 681F"},
/* 2F8E6 */ { "CJK COMPATIBILITY IDEOGRAPH-2F8E6","	: 6914"},
/* 2F8E7 */ { "CJK COMPATIBILITY IDEOGRAPH-2F8E7","	: 3B9D"},
/* 2F8E8 */ { "CJK COMPATIBILITY IDEOGRAPH-2F8E8","	: 6942"},
/* 2F8E9 */ { "CJK COMPATIBILITY IDEOGRAPH-2F8E9","	: 69A3"},
/* 2F8EA */ { "CJK COMPATIBILITY IDEOGRAPH-2F8EA","	: 69EA"},
/* 2F8EB */ { "CJK COMPATIBILITY IDEOGRAPH-2F8EB","	: 6AA8"},
/* 2F8EC */ { "CJK COMPATIBILITY IDEOGRAPH-2F8EC","	: 236A3"},
/* 2F8ED */ { "CJK COMPATIBILITY IDEOGRAPH-2F8ED","	: 6ADB"},
/* 2F8EE */ { "CJK COMPATIBILITY IDEOGRAPH-2F8EE","	: 3C18"},
/* 2F8EF */ { "CJK COMPATIBILITY IDEOGRAPH-2F8EF","	: 6B21"},
/* 2F8F0 */ { "CJK COMPATIBILITY IDEOGRAPH-2F8F0","	x 4DBE\n"
	"	: 238A7"},
/* 2F8F1 */ { "CJK COMPATIBILITY IDEOGRAPH-2F8F1","	: 6B54"},
/* 2F8F2 */ { "CJK COMPATIBILITY IDEOGRAPH-2F8F2","	: 3C4E"},
/* 2F8F3 */ { "CJK COMPATIBILITY IDEOGRAPH-2F8F3","	: 6B72"},
/* 2F8F4 */ { "CJK COMPATIBILITY IDEOGRAPH-2F8F4","	: 6B9F"},
/* 2F8F5 */ { "CJK COMPATIBILITY IDEOGRAPH-2F8F5","	: 6BBA"},
/* 2F8F6 */ { "CJK COMPATIBILITY IDEOGRAPH-2F8F6","	: 6BBB"},
/* 2F8F7 */ { "CJK COMPATIBILITY IDEOGRAPH-2F8F7","	: 23A8D"},
/* 2F8F8 */ { "CJK COMPATIBILITY IDEOGRAPH-2F8F8","	: 21D0B"},
/* 2F8F9 */ { "CJK COMPATIBILITY IDEOGRAPH-2F8F9","	: 23AFA"},
/* 2F8FA */ { "CJK COMPATIBILITY IDEOGRAPH-2F8FA","	: 6C4E"},
/* 2F8FB */ { "CJK COMPATIBILITY IDEOGRAPH-2F8FB","	: 23CBC"},
/* 2F8FC */ { "CJK COMPATIBILITY IDEOGRAPH-2F8FC","	: 6CBF"},
/* 2F8FD */ { "CJK COMPATIBILITY IDEOGRAPH-2F8FD","	x 2DC09\n"
	"	: 6CCD"},
/* 2F8FE */ { "CJK COMPATIBILITY IDEOGRAPH-2F8FE","	: 6C67"},
/* 2F8FF */ { "CJK COMPATIBILITY IDEOGRAPH-2F8FF","	: 6D16"}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_02_F9[] = {
/* 2F900 */ { "CJK COMPATIBILITY IDEOGRAPH-2F900","	: 6D3E"},
/* 2F901 */ { "CJK COMPATIBILITY IDEOGRAPH-2F901","	: 6D77"},
/* 2F902 */ { "CJK COMPATIBILITY IDEOGRAPH-2F902","	: 6D41"},
/* 2F903 */ { "CJK COMPATIBILITY IDEOGRAPH-2F903","	: 6D69"},
/* 2F904 */ { "CJK COMPATIBILITY IDEOGRAPH-2F904","	: 6D78"},
/* 2F905 */ { "CJK COMPATIBILITY IDEOGRAPH-2F905","	x 23D40\n"
	"	: 6D85"},
/* 2F906 */ { "CJK COMPATIBILITY IDEOGRAPH-2F906","	: 23D1E"},
/* 2F907 */ { "CJK COMPATIBILITY IDEOGRAPH-2F907","	: 6D34"},
/* 2F908 */ { "CJK COMPATIBILITY IDEOGRAPH-2F908","	: 6E2F"},
/* 2F909 */ { "CJK COMPATIBILITY IDEOGRAPH-2F909","	: 6E6E"},
/* 2F90A */ { "CJK COMPATIBILITY IDEOGRAPH-2F90A","	: 3D33"},
/* 2F90B */ { "CJK COMPATIBILITY IDEOGRAPH-2F90B","	: 6ECB"},
/* 2F90C */ { "CJK COMPATIBILITY IDEOGRAPH-2F90C","	: 6EC7"},
/* 2F90D */ { "CJK COMPATIBILITY IDEOGRAPH-2F90D","	: 23ED1"},
/* 2F90E */ { "CJK COMPATIBILITY IDEOGRAPH-2F90E","	x 23F1C\n"
	"	: 6DF9"},
/* 2F90F */ { "CJK COMPATIBILITY IDEOGRAPH-2F90F","	: 6F6E"},
/* 2F910 */ { "CJK COMPATIBILITY IDEOGRAPH-2F910","	: 23F5E"},
/* 2F911 */ { "CJK COMPATIBILITY IDEOGRAPH-2F911","	: 23F8E"},
/* 2F912 */ { "CJK COMPATIBILITY IDEOGRAPH-2F912","	: 6FC6"},
/* 2F913 */ { "CJK COMPATIBILITY IDEOGRAPH-2F913","	: 7039"},
/* 2F914 */ { "CJK COMPATIBILITY IDEOGRAPH-2F914","	: 701E"},
/* 2F915 */ { "CJK COMPATIBILITY IDEOGRAPH-2F915","	: 701B"},
/* 2F916 */ { "CJK COMPATIBILITY IDEOGRAPH-2F916","	: 3D96"},
/* 2F917 */ { "CJK COMPATIBILITY IDEOGRAPH-2F917","	: 704A"},
/* 2F918 */ { "CJK COMPATIBILITY IDEOGRAPH-2F918","	: 707D"},
/* 2F919 */ { "CJK COMPATIBILITY IDEOGRAPH-2F919","	: 7077"},
/* 2F91A */ { "CJK COMPATIBILITY IDEOGRAPH-2F91A","	: 70AD"},
/* 2F91B */ { "CJK COMPATIBILITY IDEOGRAPH-2F91B","	: 20525"},
/* 2F91C */ { "CJK COMPATIBILITY IDEOGRAPH-2F91C","	x 242B3\n"
	"	: 7145"},
/* 2F91D */ { "CJK COMPATIBILITY IDEOGRAPH-2F91D","	: 24263"},
/* 2F91E */ { "CJK COMPATIBILITY IDEOGRAPH-2F91E","	: 719C"},
/* 2F91F */ { "CJK COMPATIBILITY IDEOGRAPH-2F91F","	: 243AB"},
/* 2F920 */ { "CJK COMPATIBILITY IDEOGRAPH-2F920","	: 7228"},
/* 2F921 */ { "CJK COMPATIBILITY IDEOGRAPH-2F921","	: 7235"},
/* 2F922 */ { "CJK COMPATIBILITY IDEOGRAPH-2F922","	: 7250"},
/* 2F923 */ { "CJK COMPATIBILITY IDEOGRAPH-2F923","	: 24608"},
/* 2F924 */ { "CJK COMPATIBILITY IDEOGRAPH-2F924","	: 7280"},
/* 2F925 */ { "CJK COMPATIBILITY IDEOGRAPH-2F925","	: 7295"},
/* 2F926 */ { "CJK COMPATIBILITY IDEOGRAPH-2F926","	: 24735"},
/* 2F927 */ { "CJK COMPATIBILITY IDEOGRAPH-2F927","	x 2AEC5\n"
	"	: 24814"},
/* 2F928 */ { "CJK COMPATIBILITY IDEOGRAPH-2F928","	: 737A"},
/* 2F929 */ { "CJK COMPATIBILITY IDEOGRAPH-2F929","	: 738B"},
/* 2F92A */ { "CJK COMPATIBILITY IDEOGRAPH-2F92A","	: 3EAC"},
/* 2F92B */ { "CJK COMPATIBILITY IDEOGRAPH-2F92B","	: 73A5"},
/* 2F92C */ { "CJK COMPATIBILITY IDEOGRAPH-2F92C","	: 3EB8"},
/* 2F92D */ { "CJK COMPATIBILITY IDEOGRAPH-2F92D","	: 3EB8"},
/* 2F92E */ { "CJK COMPATIBILITY IDEOGRAPH-2F92E","	: 7447"},
/* 2F92F */ { "CJK COMPATIBILITY IDEOGRAPH-2F92F","	: 745C"},
/* 2F930 */ { "CJK COMPATIBILITY IDEOGRAPH-2F930","	: 7471"},
/* 2F931 */ { "CJK COMPATIBILITY IDEOGRAPH-2F931","	: 7485"},
/* 2F932 */ { "CJK COMPATIBILITY IDEOGRAPH-2F932","	: 74CA"},
/* 2F933 */ { "CJK COMPATIBILITY IDEOGRAPH-2F933","	: 3F1B"},
/* 2F934 */ { "CJK COMPATIBILITY IDEOGRAPH-2F934","	: 7524"},
/* 2F935 */ { "CJK COMPATIBILITY IDEOGRAPH-2F935","	: 24C36"},
/* 2F936 */ { "CJK COMPATIBILITY IDEOGRAPH-2F936","	: 753E"},
/* 2F937 */ { "CJK COMPATIBILITY IDEOGRAPH-2F937","	: 24C92"},
/* 2F938 */ { "CJK COMPATIBILITY IDEOGRAPH-2F938","	: 7570"},
/* 2F939 */ { "CJK COMPATIBILITY IDEOGRAPH-2F939","	: 2219F"},
/* 2F93A */ { "CJK COMPATIBILITY IDEOGRAPH-2F93A","	: 7610"},
/* 2F93B */ { "CJK COMPATIBILITY IDEOGRAPH-2F93B","	: 24FA1"},
/* 2F93C */ { "CJK COMPATIBILITY IDEOGRAPH-2F93C","	: 24FB8"},
/* 2F93D */ { "CJK COMPATIBILITY IDEOGRAPH-2F93D","	: 25044"},
/* 2F93E */ { "CJK COMPATIBILITY IDEOGRAPH-2F93E","	: 3FFC"},
/* 2F93F */ { "CJK COMPATIBILITY IDEOGRAPH-2F93F","	: 4008"},
/* 2F940 */ { "CJK COMPATIBILITY IDEOGRAPH-2F940","	: 76F4"},
/* 2F941 */ { "CJK COMPATIBILITY IDEOGRAPH-2F941","	: 250F3"},
/* 2F942 */ { "CJK COMPATIBILITY IDEOGRAPH-2F942","	: 250F2"},
/* 2F943 */ { "CJK COMPATIBILITY IDEOGRAPH-2F943","	x 2511A\n"
	"	: 25119"},
/* 2F944 */ { "CJK COMPATIBILITY IDEOGRAPH-2F944","	: 25133"},
/* 2F945 */ { "CJK COMPATIBILITY IDEOGRAPH-2F945","	: 771E"},
/* 2F946 */ { "CJK COMPATIBILITY IDEOGRAPH-2F946","	: 771F"},
/* 2F947 */ { "CJK COMPATIBILITY IDEOGRAPH-2F947","	: 771F"},
/* 2F948 */ { "CJK COMPATIBILITY IDEOGRAPH-2F948","	: 774A"},
/* 2F949 */ { "CJK COMPATIBILITY IDEOGRAPH-2F949","	: 4039"},
/* 2F94A */ { "CJK COMPATIBILITY IDEOGRAPH-2F94A","	: 778B"},
/* 2F94B */ { "CJK COMPATIBILITY IDEOGRAPH-2F94B","	x 25271\n"
	"	: 4046"},
/* 2F94C */ { "CJK COMPATIBILITY IDEOGRAPH-2F94C","	: 4096"},
/* 2F94D */ { "CJK COMPATIBILITY IDEOGRAPH-2F94D","	: 2541D"},
/* 2F94E */ { "CJK COMPATIBILITY IDEOGRAPH-2F94E","	: 784E"},
/* 2F94F */ { "CJK COMPATIBILITY IDEOGRAPH-2F94F","	: 788C"},
/* 2F950 */ { "CJK COMPATIBILITY IDEOGRAPH-2F950","	: 78CC"},
/* 2F951 */ { "CJK COMPATIBILITY IDEOGRAPH-2F951","	: 40E3"},
/* 2F952 */ { "CJK COMPATIBILITY IDEOGRAPH-2F952","	: 25626"},
/* 2F953 */ { "CJK COMPATIBILITY IDEOGRAPH-2F953","	: 7956"},
/* 2F954 */ { "CJK COMPATIBILITY IDEOGRAPH-2F954","	: 2569A"},
/* 2F955 */ { "CJK COMPATIBILITY IDEOGRAPH-2F955","	: 256C5"},
/* 2F956 */ { "CJK COMPATIBILITY IDEOGRAPH-2F956","	: 798F"},
/* 2F957 */ { "CJK COMPATIBILITY IDEOGRAPH-2F957","	: 79EB"},
/* 2F958 */ { "CJK COMPATIBILITY IDEOGRAPH-2F958","	: 412F"},
/* 2F959 */ { "CJK COMPATIBILITY IDEOGRAPH-2F959","	: 7A40"},
/* 2F95A */ { "CJK COMPATIBILITY IDEOGRAPH-2F95A","	: 7A4A"},
/* 2F95B */ { "CJK COMPATIBILITY IDEOGRAPH-2F95B","	: 7A4F"},
/* 2F95C */ { "CJK COMPATIBILITY IDEOGRAPH-2F95C","	: 2597C"},
/* 2F95D */ { "CJK COMPATIBILITY IDEOGRAPH-2F95D","	: 25AA7"},
/* 2F95E */ { "CJK COMPATIBILITY IDEOGRAPH-2F95E","	: 25AA7"},
/* 2F95F */ { "CJK COMPATIBILITY IDEOGRAPH-2F95F","	: 7AEE"},
/* 2F960 */ { "CJK COMPATIBILITY IDEOGRAPH-2F960","	: 4202"},
/* 2F961 */ { "CJK COMPATIBILITY IDEOGRAPH-2F961","	: 25BAB"},
/* 2F962 */ { "CJK COMPATIBILITY IDEOGRAPH-2F962","	: 7BC6"},
/* 2F963 */ { "CJK COMPATIBILITY IDEOGRAPH-2F963","	: 7BC9"},
/* 2F964 */ { "CJK COMPATIBILITY IDEOGRAPH-2F964","	: 4227"},
/* 2F965 */ { "CJK COMPATIBILITY IDEOGRAPH-2F965","	: 25C80"},
/* 2F966 */ { "CJK COMPATIBILITY IDEOGRAPH-2F966","	: 7CD2"},
/* 2F967 */ { "CJK COMPATIBILITY IDEOGRAPH-2F967","	: 42A0"},
/* 2F968 */ { "CJK COMPATIBILITY IDEOGRAPH-2F968","	: 7CE8"},
/* 2F969 */ { "CJK COMPATIBILITY IDEOGRAPH-2F969","	: 7CE3"},
/* 2F96A */ { "CJK COMPATIBILITY IDEOGRAPH-2F96A","	: 7D00"},
/* 2F96B */ { "CJK COMPATIBILITY IDEOGRAPH-2F96B","	: 25F86"},
/* 2F96C */ { "CJK COMPATIBILITY IDEOGRAPH-2F96C","	: 7D63"},
/* 2F96D */ { "CJK COMPATIBILITY IDEOGRAPH-2F96D","	: 4301"},
/* 2F96E */ { "CJK COMPATIBILITY IDEOGRAPH-2F96E","	: 7DC7"},
/* 2F96F */ { "CJK COMPATIBILITY IDEOGRAPH-2F96F","	: 7E02"},
/* 2F970 */ { "CJK COMPATIBILITY IDEOGRAPH-2F970","	: 7E45"},
/* 2F971 */ { "CJK COMPATIBILITY IDEOGRAPH-2F971","	: 4334"},
/* 2F972 */ { "CJK COMPATIBILITY IDEOGRAPH-2F972","	: 26228"},
/* 2F973 */ { "CJK COMPATIBILITY IDEOGRAPH-2F973","	: 26247"},
/* 2F974 */ { "CJK COMPATIBILITY IDEOGRAPH-2F974","	: 4359"},
/* 2F975 */ { "CJK COMPATIBILITY IDEOGRAPH-2F975","	: 262D9"},
/* 2F976 */ { "CJK COMPATIBILITY IDEOGRAPH-2F976","	: 7F7A"},
/* 2F977 */ { "CJK COMPATIBILITY IDEOGRAPH-2F977","	: 2633E"},
/* 2F978 */ { "CJK COMPATIBILITY IDEOGRAPH-2F978","	: 7F95"},
/* 2F979 */ { "CJK COMPATIBILITY IDEOGRAPH-2F979","	: 7FFA"},
/* 2F97A */ { "CJK COMPATIBILITY IDEOGRAPH-2F97A","	: 8005"},
/* 2F97B */ { "CJK COMPATIBILITY IDEOGRAPH-2F97B","	: 264DA"},
/* 2F97C */ { "CJK COMPATIBILITY IDEOGRAPH-2F97C","	: 26523"},
/* 2F97D */ { "CJK COMPATIBILITY IDEOGRAPH-2F97D","	: 8060"},
/* 2F97E */ { "CJK COMPATIBILITY IDEOGRAPH-2F97E","	: 265A8"},
/* 2F97F */ { "CJK COMPATIBILITY IDEOGRAPH-2F97F","	: 8070"},
/* 2F980 */ { "CJK COMPATIBILITY IDEOGRAPH-2F980","	: 2335F"},
/* 2F981 */ { "CJK COMPATIBILITY IDEOGRAPH-2F981","	: 43D5"},
/* 2F982 */ { "CJK COMPATIBILITY IDEOGRAPH-2F982","	: 80B2"},
/* 2F983 */ { "CJK COMPATIBILITY IDEOGRAPH-2F983","	: 8103"},
/* 2F984 */ { "CJK COMPATIBILITY IDEOGRAPH-2F984","	: 440B"},
/* 2F985 */ { "CJK COMPATIBILITY IDEOGRAPH-2F985","	: 813E"},
/* 2F986 */ { "CJK COMPATIBILITY IDEOGRAPH-2F986","	: 5AB5"},
/* 2F987 */ { "CJK COMPATIBILITY IDEOGRAPH-2F987","	: 267A7"},
/* 2F988 */ { "CJK COMPATIBILITY IDEOGRAPH-2F988","	: 267B5"},
/* 2F989 */ { "CJK COMPATIBILITY IDEOGRAPH-2F989","	: 23393"},
/* 2F98A */ { "CJK COMPATIBILITY IDEOGRAPH-2F98A","	: 2339C"},
/* 2F98B */ { "CJK COMPATIBILITY IDEOGRAPH-2F98B","	: 8201"},
/* 2F98C */ { "CJK COMPATIBILITY IDEOGRAPH-2F98C","	: 8204"},
/* 2F98D */ { "CJK COMPATIBILITY IDEOGRAPH-2F98D","	: 8F9E"},
/* 2F98E */ { "CJK COMPATIBILITY IDEOGRAPH-2F98E","	: 446B"},
/* 2F98F */ { "CJK COMPATIBILITY IDEOGRAPH-2F98F","	: 8291"},
/* 2F990 */ { "CJK COMPATIBILITY IDEOGRAPH-2F990","	: 828B"},
/* 2F991 */ { "CJK COMPATIBILITY IDEOGRAPH-2F991","	: 829D"},
/* 2F992 */ { "CJK COMPATIBILITY IDEOGRAPH-2F992","	: 52B3"},
/* 2F993 */ { "CJK COMPATIBILITY IDEOGRAPH-2F993","	: 82B1"},
/* 2F994 */ { "CJK COMPATIBILITY IDEOGRAPH-2F994","	: 82B3"},
/* 2F995 */ { "CJK COMPATIBILITY IDEOGRAPH-2F995","	: 82BD"},
/* 2F996 */ { "CJK COMPATIBILITY IDEOGRAPH-2F996","	: 82E6"},
/* 2F997 */ { "CJK COMPATIBILITY IDEOGRAPH-2F997","	: 26B3C"},
/* 2F998 */ { "CJK COMPATIBILITY IDEOGRAPH-2F998","	: 82E5"},
/* 2F999 */ { "CJK COMPATIBILITY IDEOGRAPH-2F999","	: 831D"},
/* 2F99A */ { "CJK COMPATIBILITY IDEOGRAPH-2F99A","	: 8363"},
/* 2F99B */ { "CJK COMPATIBILITY IDEOGRAPH-2F99B","	: 83AD"},
/* 2F99C */ { "CJK COMPATIBILITY IDEOGRAPH-2F99C","	: 8323"},
/* 2F99D */ { "CJK COMPATIBILITY IDEOGRAPH-2F99D","	: 83BD"},
/* 2F99E */ { "CJK COMPATIBILITY IDEOGRAPH-2F99E","	: 83E7"},
/* 2F99F */ { "CJK COMPATIBILITY IDEOGRAPH-2F99F","	: 8457"},
/* 2F9A0 */ { "CJK COMPATIBILITY IDEOGRAPH-2F9A0","	: 8353"},
/* 2F9A1 */ { "CJK COMPATIBILITY IDEOGRAPH-2F9A1","	: 83CA"},
/* 2F9A2 */ { "CJK COMPATIBILITY IDEOGRAPH-2F9A2","	: 83CC"},
/* 2F9A3 */ { "CJK COMPATIBILITY IDEOGRAPH-2F9A3","	: 83DC"},
/* 2F9A4 */ { "CJK COMPATIBILITY IDEOGRAPH-2F9A4","	: 26C36"},
/* 2F9A5 */ { "CJK COMPATIBILITY IDEOGRAPH-2F9A5","	: 26D6B"},
/* 2F9A6 */ { "CJK COMPATIBILITY IDEOGRAPH-2F9A6","	: 26CD5"},
/* 2F9A7 */ { "CJK COMPATIBILITY IDEOGRAPH-2F9A7","	: 452B"},
/* 2F9A8 */ { "CJK COMPATIBILITY IDEOGRAPH-2F9A8","	: 84F1"},
/* 2F9A9 */ { "CJK COMPATIBILITY IDEOGRAPH-2F9A9","	: 84F3"},
/* 2F9AA */ { "CJK COMPATIBILITY IDEOGRAPH-2F9AA","	: 8516"},
/* 2F9AB */ { "CJK COMPATIBILITY IDEOGRAPH-2F9AB","	: 273CA"},
/* 2F9AC */ { "CJK COMPATIBILITY IDEOGRAPH-2F9AC","	: 8564"},
/* 2F9AD */ { "CJK COMPATIBILITY IDEOGRAPH-2F9AD","	: 26F2C"},
/* 2F9AE */ { "CJK COMPATIBILITY IDEOGRAPH-2F9AE","	: 455D"},
/* 2F9AF */ { "CJK COMPATIBILITY IDEOGRAPH-2F9AF","	: 4561"},
/* 2F9B0 */ { "CJK COMPATIBILITY IDEOGRAPH-2F9B0","	: 26FB1"},
/* 2F9B1 */ { "CJK COMPATIBILITY IDEOGRAPH-2F9B1","	: 270D2"},
/* 2F9B2 */ { "CJK COMPATIBILITY IDEOGRAPH-2F9B2","	x 5914\n"
	"	x 270CD\n"
	"	x 270F0\n"
	"	: 456B"},
/* 2F9B3 */ { "CJK COMPATIBILITY IDEOGRAPH-2F9B3","	: 8650"},
/* 2F9B4 */ { "CJK COMPATIBILITY IDEOGRAPH-2F9B4","	: 865C"},
/* 2F9B5 */ { "CJK COMPATIBILITY IDEOGRAPH-2F9B5","	: 8667"},
/* 2F9B6 */ { "CJK COMPATIBILITY IDEOGRAPH-2F9B6","	x 27205\n"
	"	: 8669"},
/* 2F9B7 */ { "CJK COMPATIBILITY IDEOGRAPH-2F9B7","	: 86A9"},
/* 2F9B8 */ { "CJK COMPATIBILITY IDEOGRAPH-2F9B8","	: 8688"},
/* 2F9B9 */ { "CJK COMPATIBILITY IDEOGRAPH-2F9B9","	: 870E"},
/* 2F9BA */ { "CJK COMPATIBILITY IDEOGRAPH-2F9BA","	: 86E2"},
/* 2F9BB */ { "CJK COMPATIBILITY IDEOGRAPH-2F9BB","	: 8779"},
/* 2F9BC */ { "CJK COMPATIBILITY IDEOGRAPH-2F9BC","	: 8728"},
/* 2F9BD */ { "CJK COMPATIBILITY IDEOGRAPH-2F9BD","	: 876B"},
/* 2F9BE */ { "CJK COMPATIBILITY IDEOGRAPH-2F9BE","	: 8786"},
/* 2F9BF */ { "CJK COMPATIBILITY IDEOGRAPH-2F9BF","	: 45D7"},
/* 2F9C0 */ { "CJK COMPATIBILITY IDEOGRAPH-2F9C0","	: 87E1"},
/* 2F9C1 */ { "CJK COMPATIBILITY IDEOGRAPH-2F9C1","	: 8801"},
/* 2F9C2 */ { "CJK COMPATIBILITY IDEOGRAPH-2F9C2","	: 45F9"},
/* 2F9C3 */ { "CJK COMPATIBILITY IDEOGRAPH-2F9C3","	: 8860"},
/* 2F9C4 */ { "CJK COMPATIBILITY IDEOGRAPH-2F9C4","	: 8863"},
/* 2F9C5 */ { "CJK COMPATIBILITY IDEOGRAPH-2F9C5","	: 27667"},
/* 2F9C6 */ { "CJK COMPATIBILITY IDEOGRAPH-2F9C6","	: 88D7"},
/* 2F9C7 */ { "CJK COMPATIBILITY IDEOGRAPH-2F9C7","	: 88DE"},
/* 2F9C8 */ { "CJK COMPATIBILITY IDEOGRAPH-2F9C8","	: 4635"},
/* 2F9C9 */ { "CJK COMPATIBILITY IDEOGRAPH-2F9C9","	: 88FA"},
/* 2F9CA */ { "CJK COMPATIBILITY IDEOGRAPH-2F9CA","	: 34BB"},
/* 2F9CB */ { "CJK COMPATIBILITY IDEOGRAPH-2F9CB","	x 4695\n"
	"	: 278AE"},
/* 2F9CC */ { "CJK COMPATIBILITY IDEOGRAPH-2F9CC","	: 27966"},
/* 2F9CD */ { "CJK COMPATIBILITY IDEOGRAPH-2F9CD","	: 46BE"},
/* 2F9CE */ { "CJK COMPATIBILITY IDEOGRAPH-2F9CE","	: 46C7"},
/* 2F9CF */ { "CJK COMPATIBILITY IDEOGRAPH-2F9CF","	: 8AA0"},
/* 2F9D0 */ { "CJK COMPATIBILITY IDEOGRAPH-2F9D0","	: 8AED"},
/* 2F9D1 */ { "CJK COMPATIBILITY IDEOGRAPH-2F9D1","	: 8B8A"},
/* 2F9D2 */ { "CJK COMPATIBILITY IDEOGRAPH-2F9D2","	: 8C55"},
/* 2F9D3 */ { "CJK COMPATIBILITY IDEOGRAPH-2F9D3","	: 27CA8"},
/* 2F9D4 */ { "CJK COMPATIBILITY IDEOGRAPH-2F9D4","	: 8CAB"},
/* 2F9D5 */ { "CJK COMPATIBILITY IDEOGRAPH-2F9D5","	: 8CC1"},
/* 2F9D6 */ { "CJK COMPATIBILITY IDEOGRAPH-2F9D6","	x 25AD4\n"
	"	: 8D1B"},
/* 2F9D7 */ { "CJK COMPATIBILITY IDEOGRAPH-2F9D7","	: 8D77"},
/* 2F9D8 */ { "CJK COMPATIBILITY IDEOGRAPH-2F9D8","	: 27F2F"},
/* 2F9D9 */ { "CJK COMPATIBILITY IDEOGRAPH-2F9D9","	: 20804"},
/* 2F9DA */ { "CJK COMPATIBILITY IDEOGRAPH-2F9DA","	: 8DCB"},
/* 2F9DB */ { "CJK COMPATIBILITY IDEOGRAPH-2F9DB","	: 8DBC"},
/* 2F9DC */ { "CJK COMPATIBILITY IDEOGRAPH-2F9DC","	: 8DF0"},
/* 2F9DD */ { "CJK COMPATIBILITY IDEOGRAPH-2F9DD","	: 208DE"},
/* 2F9DE */ { "CJK COMPATIBILITY IDEOGRAPH-2F9DE","	: 8ED4"},
/* 2F9DF */ { "CJK COMPATIBILITY IDEOGRAPH-2F9DF","	: 8F38"},
/* 2F9E0 */ { "CJK COMPATIBILITY IDEOGRAPH-2F9E0","	: 285D2"},
/* 2F9E1 */ { "CJK COMPATIBILITY IDEOGRAPH-2F9E1","	: 285ED"},
/* 2F9E2 */ { "CJK COMPATIBILITY IDEOGRAPH-2F9E2","	: 9094"},
/* 2F9E3 */ { "CJK COMPATIBILITY IDEOGRAPH-2F9E3","	: 90F1"},
/* 2F9E4 */ { "CJK COMPATIBILITY IDEOGRAPH-2F9E4","	: 9111"},
/* 2F9E5 */ { "CJK COMPATIBILITY IDEOGRAPH-2F9E5","	: 2872E"},
/* 2F9E6 */ { "CJK COMPATIBILITY IDEOGRAPH-2F9E6","	: 911B"},
/* 2F9E7 */ { "CJK COMPATIBILITY IDEOGRAPH-2F9E7","	: 9238"},
/* 2F9E8 */ { "CJK COMPATIBILITY IDEOGRAPH-2F9E8","	: 92D7"},
/* 2F9E9 */ { "CJK COMPATIBILITY IDEOGRAPH-2F9E9","	: 92D8"},
/* 2F9EA */ { "CJK COMPATIBILITY IDEOGRAPH-2F9EA","	: 927C"},
/* 2F9EB */ { "CJK COMPATIBILITY IDEOGRAPH-2F9EB","	: 93F9"},
/* 2F9EC */ { "CJK COMPATIBILITY IDEOGRAPH-2F9EC","	: 9415"},
/* 2F9ED */ { "CJK COMPATIBILITY IDEOGRAPH-2F9ED","	: 28BFA"},
/* 2F9EE */ { "CJK COMPATIBILITY IDEOGRAPH-2F9EE","	: 958B"},
/* 2F9EF */ { "CJK COMPATIBILITY IDEOGRAPH-2F9EF","	: 4995"},
/* 2F9F0 */ { "CJK COMPATIBILITY IDEOGRAPH-2F9F0","	: 95B7"},
/* 2F9F1 */ { "CJK COMPATIBILITY IDEOGRAPH-2F9F1","	: 28D77"},
/* 2F9F2 */ { "CJK COMPATIBILITY IDEOGRAPH-2F9F2","	: 49E6"},
/* 2F9F3 */ { "CJK COMPATIBILITY IDEOGRAPH-2F9F3","	: 96C3"},
/* 2F9F4 */ { "CJK COMPATIBILITY IDEOGRAPH-2F9F4","	: 5DB2"},
/* 2F9F5 */ { "CJK COMPATIBILITY IDEOGRAPH-2F9F5","	: 9723"},
/* 2F9F6 */ { "CJK COMPATIBILITY IDEOGRAPH-2F9F6","	: 29145"},
/* 2F9F7 */ { "CJK COMPATIBILITY IDEOGRAPH-2F9F7","	: 2921A"},
/* 2F9F8 */ { "CJK COMPATIBILITY IDEOGRAPH-2F9F8","	: 4A6E"},
/* 2F9F9 */ { "CJK COMPATIBILITY IDEOGRAPH-2F9F9","	: 4A76"},
/* 2F9FA */ { "CJK COMPATIBILITY IDEOGRAPH-2F9FA","	: 97E0"},
/* 2F9FB */ { "CJK COMPATIBILITY IDEOGRAPH-2F9FB","	: 2940A"},
/* 2F9FC */ { "CJK COMPATIBILITY IDEOGRAPH-2F9FC","	: 4AB2"},
/* 2F9FD */ { "CJK COMPATIBILITY IDEOGRAPH-2F9FD","	: 29496"},
/* 2F9FE */ { "CJK COMPATIBILITY IDEOGRAPH-2F9FE","	: 980B"},
/* 2F9FF */ { "CJK COMPATIBILITY IDEOGRAPH-2F9FF","	: 980B"}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_02_FA[] = {
/* 2FA00 */ { "CJK COMPATIBILITY IDEOGRAPH-2FA00","	: 9829"},
/* 2FA01 */ { "CJK COMPATIBILITY IDEOGRAPH-2FA01","	: 295B6"},
/* 2FA02 */ { "CJK COMPATIBILITY IDEOGRAPH-2FA02","	: 98E2"},
/* 2FA03 */ { "CJK COMPATIBILITY IDEOGRAPH-2FA03","	: 4B33"},
/* 2FA04 */ { "CJK COMPATIBILITY IDEOGRAPH-2FA04","	: 9929"},
/* 2FA05 */ { "CJK COMPATIBILITY IDEOGRAPH-2FA05","	: 99A7"},
/* 2FA06 */ { "CJK COMPATIBILITY IDEOGRAPH-2FA06","	: 99C2"},
/* 2FA07 */ { "CJK COMPATIBILITY IDEOGRAPH-2FA07","	: 99FE"},
/* 2FA08 */ { "CJK COMPATIBILITY IDEOGRAPH-2FA08","	: 4BCE"},
/* 2FA09 */ { "CJK COMPATIBILITY IDEOGRAPH-2FA09","	: 29B30"},
/* 2FA0A */ { "CJK COMPATIBILITY IDEOGRAPH-2FA0A","	: 9B12"},
/* 2FA0B */ { "CJK COMPATIBILITY IDEOGRAPH-2FA0B","	: 9C40"},
/* 2FA0C */ { "CJK COMPATIBILITY IDEOGRAPH-2FA0C","	: 9CFD"},
/* 2FA0D */ { "CJK COMPATIBILITY IDEOGRAPH-2FA0D","	: 4CCE"},
/* 2FA0E */ { "CJK COMPATIBILITY IDEOGRAPH-2FA0E","	: 4CED"},
/* 2FA0F */ { "CJK COMPATIBILITY IDEOGRAPH-2FA0F","	: 9D67"},
/* 2FA10 */ { "CJK COMPATIBILITY IDEOGRAPH-2FA10","	: 2A0CE"},
/* 2FA11 */ { "CJK COMPATIBILITY IDEOGRAPH-2FA11","	: 4CF8"},
/* 2FA12 */ { "CJK COMPATIBILITY IDEOGRAPH-2FA12","	: 2A105"},
/* 2FA13 */ { "CJK COMPATIBILITY IDEOGRAPH-2FA13","	: 2A20E"},
/* 2FA14 */ { "CJK COMPATIBILITY IDEOGRAPH-2FA14","	: 2A291"},
/* 2FA15 */ { "CJK COMPATIBILITY IDEOGRAPH-2FA15","	: 9EBB"},
/* 2FA16 */ { "CJK COMPATIBILITY IDEOGRAPH-2FA16","	: 4D56"},
/* 2FA17 */ { "CJK COMPATIBILITY IDEOGRAPH-2FA17","	: 9EF9"},
/* 2FA18 */ { "CJK COMPATIBILITY IDEOGRAPH-2FA18","	: 9EFE"},
/* 2FA19 */ { "CJK COMPATIBILITY IDEOGRAPH-2FA19","	: 9F05"},
/* 2FA1A */ { "CJK COMPATIBILITY IDEOGRAPH-2FA1A","	: 9F0F"},
/* 2FA1B */ { "CJK COMPATIBILITY IDEOGRAPH-2FA1B","	: 9F16"},
/* 2FA1C */ { "CJK COMPATIBILITY IDEOGRAPH-2FA1C","	: 9F3B"},
/* 2FA1D */ { "CJK COMPATIBILITY IDEOGRAPH-2FA1D","	: 2A600"},
/* 2FA1E */ { NULL,NULL},
/* 2FA1F */ { NULL,NULL},
/* 2FA20 */ { NULL,NULL},
/* 2FA21 */ { NULL,NULL},
/* 2FA22 */ { NULL,NULL},
/* 2FA23 */ { NULL,NULL},
/* 2FA24 */ { NULL,NULL},
/* 2FA25 */ { NULL,NULL},
/* 2FA26 */ { NULL,NULL},
/* 2FA27 */ { NULL,NULL},
/* 2FA28 */ { NULL,NULL},
/* 2FA29 */ { NULL,NULL},
/* 2FA2A */ { NULL,NULL},
/* 2FA2B */ { NULL,NULL},
/* 2FA2C */ { NULL,NULL},
/* 2FA2D */ { NULL,NULL},
/* 2FA2E */ { NULL,NULL},
/* 2FA2F */ { NULL,NULL},
/* 2FA30 */ { NULL,NULL},
/* 2FA31 */ { NULL,NULL},
/* 2FA32 */ { NULL,NULL},
/* 2FA33 */ { NULL,NULL},
/* 2FA34 */ { NULL,NULL},
/* 2FA35 */ { NULL,NULL},
/* 2FA36 */ { NULL,NULL},
/* 2FA37 */ { NULL,NULL},
/* 2FA38 */ { NULL,NULL},
/* 2FA39 */ { NULL,NULL},
/* 2FA3A */ { NULL,NULL},
/* 2FA3B */ { NULL,NULL},
/* 2FA3C */ { NULL,NULL},
/* 2FA3D */ { NULL,NULL},
/* 2FA3E */ { NULL,NULL},
/* 2FA3F */ { NULL,NULL},
/* 2FA40 */ { NULL,NULL},
/* 2FA41 */ { NULL,NULL},
/* 2FA42 */ { NULL,NULL},
/* 2FA43 */ { NULL,NULL},
/* 2FA44 */ { NULL,NULL},
/* 2FA45 */ { NULL,NULL},
/* 2FA46 */ { NULL,NULL},
/* 2FA47 */ { NULL,NULL},
/* 2FA48 */ { NULL,NULL},
/* 2FA49 */ { NULL,NULL},
/* 2FA4A */ { NULL,NULL},
/* 2FA4B */ { NULL,NULL},
/* 2FA4C */ { NULL,NULL},
/* 2FA4D */ { NULL,NULL},
/* 2FA4E */ { NULL,NULL},
/* 2FA4F */ { NULL,NULL},
/* 2FA50 */ { NULL,NULL},
/* 2FA51 */ { NULL,NULL},
/* 2FA52 */ { NULL,NULL},
/* 2FA53 */ { NULL,NULL},
/* 2FA54 */ { NULL,NULL},
/* 2FA55 */ { NULL,NULL},
/* 2FA56 */ { NULL,NULL},
/* 2FA57 */ { NULL,NULL},
/* 2FA58 */ { NULL,NULL},
/* 2FA59 */ { NULL,NULL},
/* 2FA5A */ { NULL,NULL},
/* 2FA5B */ { NULL,NULL},
/* 2FA5C */ { NULL,NULL},
/* 2FA5D */ { NULL,NULL},
/* 2FA5E */ { NULL,NULL},
/* 2FA5F */ { NULL,NULL},
/* 2FA60 */ { NULL,NULL},
/* 2FA61 */ { NULL,NULL},
/* 2FA62 */ { NULL,NULL},
/* 2FA63 */ { NULL,NULL},
/* 2FA64 */ { NULL,NULL},
/* 2FA65 */ { NULL,NULL},
/* 2FA66 */ { NULL,NULL},
/* 2FA67 */ { NULL,NULL},
/* 2FA68 */ { NULL,NULL},
/* 2FA69 */ { NULL,NULL},
/* 2FA6A */ { NULL,NULL},
/* 2FA6B */ { NULL,NULL},
/* 2FA6C */ { NULL,NULL},
/* 2FA6D */ { NULL,NULL},
/* 2FA6E */ { NULL,NULL},
/* 2FA6F */ { NULL,NULL},
/* 2FA70 */ { NULL,NULL},
/* 2FA71 */ { NULL,NULL},
/* 2FA72 */ { NULL,NULL},
/* 2FA73 */ { NULL,NULL},
/* 2FA74 */ { NULL,NULL},
/* 2FA75 */ { NULL,NULL},
/* 2FA76 */ { NULL,NULL},
/* 2FA77 */ { NULL,NULL},
/* 2FA78 */ { NULL,NULL},
/* 2FA79 */ { NULL,NULL},
/* 2FA7A */ { NULL,NULL},
/* 2FA7B */ { NULL,NULL},
/* 2FA7C */ { NULL,NULL},
/* 2FA7D */ { NULL,NULL},
/* 2FA7E */ { NULL,NULL},
/* 2FA7F */ { NULL,NULL},
/* 2FA80 */ { NULL,NULL},
/* 2FA81 */ { NULL,NULL},
/* 2FA82 */ { NULL,NULL},
/* 2FA83 */ { NULL,NULL},
/* 2FA84 */ { NULL,NULL},
/* 2FA85 */ { NULL,NULL},
/* 2FA86 */ { NULL,NULL},
/* 2FA87 */ { NULL,NULL},
/* 2FA88 */ { NULL,NULL},
/* 2FA89 */ { NULL,NULL},
/* 2FA8A */ { NULL,NULL},
/* 2FA8B */ { NULL,NULL},
/* 2FA8C */ { NULL,NULL},
/* 2FA8D */ { NULL,NULL},
/* 2FA8E */ { NULL,NULL},
/* 2FA8F */ { NULL,NULL},
/* 2FA90 */ { NULL,NULL},
/* 2FA91 */ { NULL,NULL},
/* 2FA92 */ { NULL,NULL},
/* 2FA93 */ { NULL,NULL},
/* 2FA94 */ { NULL,NULL},
/* 2FA95 */ { NULL,NULL},
/* 2FA96 */ { NULL,NULL},
/* 2FA97 */ { NULL,NULL},
/* 2FA98 */ { NULL,NULL},
/* 2FA99 */ { NULL,NULL},
/* 2FA9A */ { NULL,NULL},
/* 2FA9B */ { NULL,NULL},
/* 2FA9C */ { NULL,NULL},
/* 2FA9D */ { NULL,NULL},
/* 2FA9E */ { NULL,NULL},
/* 2FA9F */ { NULL,NULL},
/* 2FAA0 */ { NULL,NULL},
/* 2FAA1 */ { NULL,NULL},
/* 2FAA2 */ { NULL,NULL},
/* 2FAA3 */ { NULL,NULL},
/* 2FAA4 */ { NULL,NULL},
/* 2FAA5 */ { NULL,NULL},
/* 2FAA6 */ { NULL,NULL},
/* 2FAA7 */ { NULL,NULL},
/* 2FAA8 */ { NULL,NULL},
/* 2FAA9 */ { NULL,NULL},
/* 2FAAA */ { NULL,NULL},
/* 2FAAB */ { NULL,NULL},
/* 2FAAC */ { NULL,NULL},
/* 2FAAD */ { NULL,NULL},
/* 2FAAE */ { NULL,NULL},
/* 2FAAF */ { NULL,NULL},
/* 2FAB0 */ { NULL,NULL},
/* 2FAB1 */ { NULL,NULL},
/* 2FAB2 */ { NULL,NULL},
/* 2FAB3 */ { NULL,NULL},
/* 2FAB4 */ { NULL,NULL},
/* 2FAB5 */ { NULL,NULL},
/* 2FAB6 */ { NULL,NULL},
/* 2FAB7 */ { NULL,NULL},
/* 2FAB8 */ { NULL,NULL},
/* 2FAB9 */ { NULL,NULL},
/* 2FABA */ { NULL,NULL},
/* 2FABB */ { NULL,NULL},
/* 2FABC */ { NULL,NULL},
/* 2FABD */ { NULL,NULL},
/* 2FABE */ { NULL,NULL},
/* 2FABF */ { NULL,NULL},
/* 2FAC0 */ { NULL,NULL},
/* 2FAC1 */ { NULL,NULL},
/* 2FAC2 */ { NULL,NULL},
/* 2FAC3 */ { NULL,NULL},
/* 2FAC4 */ { NULL,NULL},
/* 2FAC5 */ { NULL,NULL},
/* 2FAC6 */ { NULL,NULL},
/* 2FAC7 */ { NULL,NULL},
/* 2FAC8 */ { NULL,NULL},
/* 2FAC9 */ { NULL,NULL},
/* 2FACA */ { NULL,NULL},
/* 2FACB */ { NULL,NULL},
/* 2FACC */ { NULL,NULL},
/* 2FACD */ { NULL,NULL},
/* 2FACE */ { NULL,NULL},
/* 2FACF */ { NULL,NULL},
/* 2FAD0 */ { NULL,NULL},
/* 2FAD1 */ { NULL,NULL},
/* 2FAD2 */ { NULL,NULL},
/* 2FAD3 */ { NULL,NULL},
/* 2FAD4 */ { NULL,NULL},
/* 2FAD5 */ { NULL,NULL},
/* 2FAD6 */ { NULL,NULL},
/* 2FAD7 */ { NULL,NULL},
/* 2FAD8 */ { NULL,NULL},
/* 2FAD9 */ { NULL,NULL},
/* 2FADA */ { NULL,NULL},
/* 2FADB */ { NULL,NULL},
/* 2FADC */ { NULL,NULL},
/* 2FADD */ { NULL,NULL},
/* 2FADE */ { NULL,NULL},
/* 2FADF */ { NULL,NULL},
/* 2FAE0 */ { NULL,NULL},
/* 2FAE1 */ { NULL,NULL},
/* 2FAE2 */ { NULL,NULL},
/* 2FAE3 */ { NULL,NULL},
/* 2FAE4 */ { NULL,NULL},
/* 2FAE5 */ { NULL,NULL},
/* 2FAE6 */ { NULL,NULL},
/* 2FAE7 */ { NULL,NULL},
/* 2FAE8 */ { NULL,NULL},
/* 2FAE9 */ { NULL,NULL},
/* 2FAEA */ { NULL,NULL},
/* 2FAEB */ { NULL,NULL},
/* 2FAEC */ { NULL,NULL},
/* 2FAED */ { NULL,NULL},
/* 2FAEE */ { NULL,NULL},
/* 2FAEF */ { NULL,NULL},
/* 2FAF0 */ { NULL,NULL},
/* 2FAF1 */ { NULL,NULL},
/* 2FAF2 */ { NULL,NULL},
/* 2FAF3 */ { NULL,NULL},
/* 2FAF4 */ { NULL,NULL},
/* 2FAF5 */ { NULL,NULL},
/* 2FAF6 */ { NULL,NULL},
/* 2FAF7 */ { NULL,NULL},
/* 2FAF8 */ { NULL,NULL},
/* 2FAF9 */ { NULL,NULL},
/* 2FAFA */ { NULL,NULL},
/* 2FAFB */ { NULL,NULL},
/* 2FAFC */ { NULL,NULL},
/* 2FAFD */ { NULL,NULL},
/* 2FAFE */ { NULL,NULL},
/* 2FAFF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_0E_00[] = {
/* E0000 */ { NULL,NULL},
/* E0001 */ { "LANGUAGE TAG","	* This character is deprecated, and its use is strongly discouraged."},
/* E0002 */ { NULL,NULL},
/* E0003 */ { NULL,NULL},
/* E0004 */ { NULL,NULL},
/* E0005 */ { NULL,NULL},
/* E0006 */ { NULL,NULL},
/* E0007 */ { NULL,NULL},
/* E0008 */ { NULL,NULL},
/* E0009 */ { NULL,NULL},
/* E000A */ { NULL,NULL},
/* E000B */ { NULL,NULL},
/* E000C */ { NULL,NULL},
/* E000D */ { NULL,NULL},
/* E000E */ { NULL,NULL},
/* E000F */ { NULL,NULL},
/* E0010 */ { NULL,NULL},
/* E0011 */ { NULL,NULL},
/* E0012 */ { NULL,NULL},
/* E0013 */ { NULL,NULL},
/* E0014 */ { NULL,NULL},
/* E0015 */ { NULL,NULL},
/* E0016 */ { NULL,NULL},
/* E0017 */ { NULL,NULL},
/* E0018 */ { NULL,NULL},
/* E0019 */ { NULL,NULL},
/* E001A */ { NULL,NULL},
/* E001B */ { NULL,NULL},
/* E001C */ { NULL,NULL},
/* E001D */ { NULL,NULL},
/* E001E */ { NULL,NULL},
/* E001F */ { NULL,NULL},
/* E0020 */ { "TAG SPACE",NULL},
/* E0021 */ { "TAG EXCLAMATION MARK",NULL},
/* E0022 */ { "TAG QUOTATION MARK",NULL},
/* E0023 */ { "TAG NUMBER SIGN",NULL},
/* E0024 */ { "TAG DOLLAR SIGN",NULL},
/* E0025 */ { "TAG PERCENT SIGN",NULL},
/* E0026 */ { "TAG AMPERSAND",NULL},
/* E0027 */ { "TAG APOSTROPHE",NULL},
/* E0028 */ { "TAG LEFT PARENTHESIS",NULL},
/* E0029 */ { "TAG RIGHT PARENTHESIS",NULL},
/* E002A */ { "TAG ASTERISK",NULL},
/* E002B */ { "TAG PLUS SIGN",NULL},
/* E002C */ { "TAG COMMA",NULL},
/* E002D */ { "TAG HYPHEN-MINUS",NULL},
/* E002E */ { "TAG FULL STOP",NULL},
/* E002F */ { "TAG SOLIDUS",NULL},
/* E0030 */ { "TAG DIGIT ZERO",NULL},
/* E0031 */ { "TAG DIGIT ONE",NULL},
/* E0032 */ { "TAG DIGIT TWO",NULL},
/* E0033 */ { "TAG DIGIT THREE",NULL},
/* E0034 */ { "TAG DIGIT FOUR",NULL},
/* E0035 */ { "TAG DIGIT FIVE",NULL},
/* E0036 */ { "TAG DIGIT SIX",NULL},
/* E0037 */ { "TAG DIGIT SEVEN",NULL},
/* E0038 */ { "TAG DIGIT EIGHT",NULL},
/* E0039 */ { "TAG DIGIT NINE",NULL},
/* E003A */ { "TAG COLON",NULL},
/* E003B */ { "TAG SEMICOLON",NULL},
/* E003C */ { "TAG LESS-THAN SIGN",NULL},
/* E003D */ { "TAG EQUALS SIGN",NULL},
/* E003E */ { "TAG GREATER-THAN SIGN",NULL},
/* E003F */ { "TAG QUESTION MARK",NULL},
/* E0040 */ { "TAG COMMERCIAL AT",NULL},
/* E0041 */ { "TAG LATIN CAPITAL LETTER A",NULL},
/* E0042 */ { "TAG LATIN CAPITAL LETTER B",NULL},
/* E0043 */ { "TAG LATIN CAPITAL LETTER C",NULL},
/* E0044 */ { "TAG LATIN CAPITAL LETTER D",NULL},
/* E0045 */ { "TAG LATIN CAPITAL LETTER E",NULL},
/* E0046 */ { "TAG LATIN CAPITAL LETTER F",NULL},
/* E0047 */ { "TAG LATIN CAPITAL LETTER G",NULL},
/* E0048 */ { "TAG LATIN CAPITAL LETTER H",NULL},
/* E0049 */ { "TAG LATIN CAPITAL LETTER I",NULL},
/* E004A */ { "TAG LATIN CAPITAL LETTER J",NULL},
/* E004B */ { "TAG LATIN CAPITAL LETTER K",NULL},
/* E004C */ { "TAG LATIN CAPITAL LETTER L",NULL},
/* E004D */ { "TAG LATIN CAPITAL LETTER M",NULL},
/* E004E */ { "TAG LATIN CAPITAL LETTER N",NULL},
/* E004F */ { "TAG LATIN CAPITAL LETTER O",NULL},
/* E0050 */ { "TAG LATIN CAPITAL LETTER P",NULL},
/* E0051 */ { "TAG LATIN CAPITAL LETTER Q",NULL},
/* E0052 */ { "TAG LATIN CAPITAL LETTER R",NULL},
/* E0053 */ { "TAG LATIN CAPITAL LETTER S",NULL},
/* E0054 */ { "TAG LATIN CAPITAL LETTER T",NULL},
/* E0055 */ { "TAG LATIN CAPITAL LETTER U",NULL},
/* E0056 */ { "TAG LATIN CAPITAL LETTER V",NULL},
/* E0057 */ { "TAG LATIN CAPITAL LETTER W",NULL},
/* E0058 */ { "TAG LATIN CAPITAL LETTER X",NULL},
/* E0059 */ { "TAG LATIN CAPITAL LETTER Y",NULL},
/* E005A */ { "TAG LATIN CAPITAL LETTER Z",NULL},
/* E005B */ { "TAG LEFT SQUARE BRACKET",NULL},
/* E005C */ { "TAG REVERSE SOLIDUS",NULL},
/* E005D */ { "TAG RIGHT SQUARE BRACKET",NULL},
/* E005E */ { "TAG CIRCUMFLEX ACCENT",NULL},
/* E005F */ { "TAG LOW LINE",NULL},
/* E0060 */ { "TAG GRAVE ACCENT",NULL},
/* E0061 */ { "TAG LATIN SMALL LETTER A",NULL},
/* E0062 */ { "TAG LATIN SMALL LETTER B",NULL},
/* E0063 */ { "TAG LATIN SMALL LETTER C",NULL},
/* E0064 */ { "TAG LATIN SMALL LETTER D",NULL},
/* E0065 */ { "TAG LATIN SMALL LETTER E",NULL},
/* E0066 */ { "TAG LATIN SMALL LETTER F",NULL},
/* E0067 */ { "TAG LATIN SMALL LETTER G",NULL},
/* E0068 */ { "TAG LATIN SMALL LETTER H",NULL},
/* E0069 */ { "TAG LATIN SMALL LETTER I",NULL},
/* E006A */ { "TAG LATIN SMALL LETTER J",NULL},
/* E006B */ { "TAG LATIN SMALL LETTER K",NULL},
/* E006C */ { "TAG LATIN SMALL LETTER L",NULL},
/* E006D */ { "TAG LATIN SMALL LETTER M",NULL},
/* E006E */ { "TAG LATIN SMALL LETTER N",NULL},
/* E006F */ { "TAG LATIN SMALL LETTER O",NULL},
/* E0070 */ { "TAG LATIN SMALL LETTER P",NULL},
/* E0071 */ { "TAG LATIN SMALL LETTER Q",NULL},
/* E0072 */ { "TAG LATIN SMALL LETTER R",NULL},
/* E0073 */ { "TAG LATIN SMALL LETTER S",NULL},
/* E0074 */ { "TAG LATIN SMALL LETTER T",NULL},
/* E0075 */ { "TAG LATIN SMALL LETTER U",NULL},
/* E0076 */ { "TAG LATIN SMALL LETTER V",NULL},
/* E0077 */ { "TAG LATIN SMALL LETTER W",NULL},
/* E0078 */ { "TAG LATIN SMALL LETTER X",NULL},
/* E0079 */ { "TAG LATIN SMALL LETTER Y",NULL},
/* E007A */ { "TAG LATIN SMALL LETTER Z",NULL},
/* E007B */ { "TAG LEFT CURLY BRACKET",NULL},
/* E007C */ { "TAG VERTICAL LINE",NULL},
/* E007D */ { "TAG RIGHT CURLY BRACKET",NULL},
/* E007E */ { "TAG TILDE",NULL},
/* E007F */ { "CANCEL TAG",NULL},
/* E0080 */ { NULL,NULL},
/* E0081 */ { NULL,NULL},
/* E0082 */ { NULL,NULL},
/* E0083 */ { NULL,NULL},
/* E0084 */ { NULL,NULL},
/* E0085 */ { NULL,NULL},
/* E0086 */ { NULL,NULL},
/* E0087 */ { NULL,NULL},
/* E0088 */ { NULL,NULL},
/* E0089 */ { NULL,NULL},
/* E008A */ { NULL,NULL},
/* E008B */ { NULL,NULL},
/* E008C */ { NULL,NULL},
/* E008D */ { NULL,NULL},
/* E008E */ { NULL,NULL},
/* E008F */ { NULL,NULL},
/* E0090 */ { NULL,NULL},
/* E0091 */ { NULL,NULL},
/* E0092 */ { NULL,NULL},
/* E0093 */ { NULL,NULL},
/* E0094 */ { NULL,NULL},
/* E0095 */ { NULL,NULL},
/* E0096 */ { NULL,NULL},
/* E0097 */ { NULL,NULL},
/* E0098 */ { NULL,NULL},
/* E0099 */ { NULL,NULL},
/* E009A */ { NULL,NULL},
/* E009B */ { NULL,NULL},
/* E009C */ { NULL,NULL},
/* E009D */ { NULL,NULL},
/* E009E */ { NULL,NULL},
/* E009F */ { NULL,NULL},
/* E00A0 */ { NULL,NULL},
/* E00A1 */ { NULL,NULL},
/* E00A2 */ { NULL,NULL},
/* E00A3 */ { NULL,NULL},
/* E00A4 */ { NULL,NULL},
/* E00A5 */ { NULL,NULL},
/* E00A6 */ { NULL,NULL},
/* E00A7 */ { NULL,NULL},
/* E00A8 */ { NULL,NULL},
/* E00A9 */ { NULL,NULL},
/* E00AA */ { NULL,NULL},
/* E00AB */ { NULL,NULL},
/* E00AC */ { NULL,NULL},
/* E00AD */ { NULL,NULL},
/* E00AE */ { NULL,NULL},
/* E00AF */ { NULL,NULL},
/* E00B0 */ { NULL,NULL},
/* E00B1 */ { NULL,NULL},
/* E00B2 */ { NULL,NULL},
/* E00B3 */ { NULL,NULL},
/* E00B4 */ { NULL,NULL},
/* E00B5 */ { NULL,NULL},
/* E00B6 */ { NULL,NULL},
/* E00B7 */ { NULL,NULL},
/* E00B8 */ { NULL,NULL},
/* E00B9 */ { NULL,NULL},
/* E00BA */ { NULL,NULL},
/* E00BB */ { NULL,NULL},
/* E00BC */ { NULL,NULL},
/* E00BD */ { NULL,NULL},
/* E00BE */ { NULL,NULL},
/* E00BF */ { NULL,NULL},
/* E00C0 */ { NULL,NULL},
/* E00C1 */ { NULL,NULL},
/* E00C2 */ { NULL,NULL},
/* E00C3 */ { NULL,NULL},
/* E00C4 */ { NULL,NULL},
/* E00C5 */ { NULL,NULL},
/* E00C6 */ { NULL,NULL},
/* E00C7 */ { NULL,NULL},
/* E00C8 */ { NULL,NULL},
/* E00C9 */ { NULL,NULL},
/* E00CA */ { NULL,NULL},
/* E00CB */ { NULL,NULL},
/* E00CC */ { NULL,NULL},
/* E00CD */ { NULL,NULL},
/* E00CE */ { NULL,NULL},
/* E00CF */ { NULL,NULL},
/* E00D0 */ { NULL,NULL},
/* E00D1 */ { NULL,NULL},
/* E00D2 */ { NULL,NULL},
/* E00D3 */ { NULL,NULL},
/* E00D4 */ { NULL,NULL},
/* E00D5 */ { NULL,NULL},
/* E00D6 */ { NULL,NULL},
/* E00D7 */ { NULL,NULL},
/* E00D8 */ { NULL,NULL},
/* E00D9 */ { NULL,NULL},
/* E00DA */ { NULL,NULL},
/* E00DB */ { NULL,NULL},
/* E00DC */ { NULL,NULL},
/* E00DD */ { NULL,NULL},
/* E00DE */ { NULL,NULL},
/* E00DF */ { NULL,NULL},
/* E00E0 */ { NULL,NULL},
/* E00E1 */ { NULL,NULL},
/* E00E2 */ { NULL,NULL},
/* E00E3 */ { NULL,NULL},
/* E00E4 */ { NULL,NULL},
/* E00E5 */ { NULL,NULL},
/* E00E6 */ { NULL,NULL},
/* E00E7 */ { NULL,NULL},
/* E00E8 */ { NULL,NULL},
/* E00E9 */ { NULL,NULL},
/* E00EA */ { NULL,NULL},
/* E00EB */ { NULL,NULL},
/* E00EC */ { NULL,NULL},
/* E00ED */ { NULL,NULL},
/* E00EE */ { NULL,NULL},
/* E00EF */ { NULL,NULL},
/* E00F0 */ { NULL,NULL},
/* E00F1 */ { NULL,NULL},
/* E00F2 */ { NULL,NULL},
/* E00F3 */ { NULL,NULL},
/* E00F4 */ { NULL,NULL},
/* E00F5 */ { NULL,NULL},
/* E00F6 */ { NULL,NULL},
/* E00F7 */ { NULL,NULL},
/* E00F8 */ { NULL,NULL},
/* E00F9 */ { NULL,NULL},
/* E00FA */ { NULL,NULL},
/* E00FB */ { NULL,NULL},
/* E00FC */ { NULL,NULL},
/* E00FD */ { NULL,NULL},
/* E00FE */ { NULL,NULL},
/* E00FF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot una_0E_01[] = {
/* E0100 */ { "VARIATION SELECTOR-17","	* these are abbreviated VS17, and so on"},
/* E0101 */ { "VARIATION SELECTOR-18",NULL},
/* E0102 */ { "VARIATION SELECTOR-19",NULL},
/* E0103 */ { "VARIATION SELECTOR-20",NULL},
/* E0104 */ { "VARIATION SELECTOR-21",NULL},
/* E0105 */ { "VARIATION SELECTOR-22",NULL},
/* E0106 */ { "VARIATION SELECTOR-23",NULL},
/* E0107 */ { "VARIATION SELECTOR-24",NULL},
/* E0108 */ { "VARIATION SELECTOR-25",NULL},
/* E0109 */ { "VARIATION SELECTOR-26",NULL},
/* E010A */ { "VARIATION SELECTOR-27",NULL},
/* E010B */ { "VARIATION SELECTOR-28",NULL},
/* E010C */ { "VARIATION SELECTOR-29",NULL},
/* E010D */ { "VARIATION SELECTOR-30",NULL},
/* E010E */ { "VARIATION SELECTOR-31",NULL},
/* E010F */ { "VARIATION SELECTOR-32",NULL},
/* E0110 */ { "VARIATION SELECTOR-33",NULL},
/* E0111 */ { "VARIATION SELECTOR-34",NULL},
/* E0112 */ { "VARIATION SELECTOR-35",NULL},
/* E0113 */ { "VARIATION SELECTOR-36",NULL},
/* E0114 */ { "VARIATION SELECTOR-37",NULL},
/* E0115 */ { "VARIATION SELECTOR-38",NULL},
/* E0116 */ { "VARIATION SELECTOR-39",NULL},
/* E0117 */ { "VARIATION SELECTOR-40",NULL},
/* E0118 */ { "VARIATION SELECTOR-41",NULL},
/* E0119 */ { "VARIATION SELECTOR-42",NULL},
/* E011A */ { "VARIATION SELECTOR-43",NULL},
/* E011B */ { "VARIATION SELECTOR-44",NULL},
/* E011C */ { "VARIATION SELECTOR-45",NULL},
/* E011D */ { "VARIATION SELECTOR-46",NULL},
/* E011E */ { "VARIATION SELECTOR-47",NULL},
/* E011F */ { "VARIATION SELECTOR-48",NULL},
/* E0120 */ { "VARIATION SELECTOR-49",NULL},
/* E0121 */ { "VARIATION SELECTOR-50",NULL},
/* E0122 */ { "VARIATION SELECTOR-51",NULL},
/* E0123 */ { "VARIATION SELECTOR-52",NULL},
/* E0124 */ { "VARIATION SELECTOR-53",NULL},
/* E0125 */ { "VARIATION SELECTOR-54",NULL},
/* E0126 */ { "VARIATION SELECTOR-55",NULL},
/* E0127 */ { "VARIATION SELECTOR-56",NULL},
/* E0128 */ { "VARIATION SELECTOR-57",NULL},
/* E0129 */ { "VARIATION SELECTOR-58",NULL},
/* E012A */ { "VARIATION SELECTOR-59",NULL},
/* E012B */ { "VARIATION SELECTOR-60",NULL},
/* E012C */ { "VARIATION SELECTOR-61",NULL},
/* E012D */ { "VARIATION SELECTOR-62",NULL},
/* E012E */ { "VARIATION SELECTOR-63",NULL},
/* E012F */ { "VARIATION SELECTOR-64",NULL},
/* E0130 */ { "VARIATION SELECTOR-65",NULL},
/* E0131 */ { "VARIATION SELECTOR-66",NULL},
/* E0132 */ { "VARIATION SELECTOR-67",NULL},
/* E0133 */ { "VARIATION SELECTOR-68",NULL},
/* E0134 */ { "VARIATION SELECTOR-69",NULL},
/* E0135 */ { "VARIATION SELECTOR-70",NULL},
/* E0136 */ { "VARIATION SELECTOR-71",NULL},
/* E0137 */ { "VARIATION SELECTOR-72",NULL},
/* E0138 */ { "VARIATION SELECTOR-73",NULL},
/* E0139 */ { "VARIATION SELECTOR-74",NULL},
/* E013A */ { "VARIATION SELECTOR-75",NULL},
/* E013B */ { "VARIATION SELECTOR-76",NULL},
/* E013C */ { "VARIATION SELECTOR-77",NULL},
/* E013D */ { "VARIATION SELECTOR-78",NULL},
/* E013E */ { "VARIATION SELECTOR-79",NULL},
/* E013F */ { "VARIATION SELECTOR-80",NULL},
/* E0140 */ { "VARIATION SELECTOR-81",NULL},
/* E0141 */ { "VARIATION SELECTOR-82",NULL},
/* E0142 */ { "VARIATION SELECTOR-83",NULL},
/* E0143 */ { "VARIATION SELECTOR-84",NULL},
/* E0144 */ { "VARIATION SELECTOR-85",NULL},
/* E0145 */ { "VARIATION SELECTOR-86",NULL},
/* E0146 */ { "VARIATION SELECTOR-87",NULL},
/* E0147 */ { "VARIATION SELECTOR-88",NULL},
/* E0148 */ { "VARIATION SELECTOR-89",NULL},
/* E0149 */ { "VARIATION SELECTOR-90",NULL},
/* E014A */ { "VARIATION SELECTOR-91",NULL},
/* E014B */ { "VARIATION SELECTOR-92",NULL},
/* E014C */ { "VARIATION SELECTOR-93",NULL},
/* E014D */ { "VARIATION SELECTOR-94",NULL},
/* E014E */ { "VARIATION SELECTOR-95",NULL},
/* E014F */ { "VARIATION SELECTOR-96",NULL},
/* E0150 */ { "VARIATION SELECTOR-97",NULL},
/* E0151 */ { "VARIATION SELECTOR-98",NULL},
/* E0152 */ { "VARIATION SELECTOR-99",NULL},
/* E0153 */ { "VARIATION SELECTOR-100",NULL},
/* E0154 */ { "VARIATION SELECTOR-101",NULL},
/* E0155 */ { "VARIATION SELECTOR-102",NULL},
/* E0156 */ { "VARIATION SELECTOR-103",NULL},
/* E0157 */ { "VARIATION SELECTOR-104",NULL},
/* E0158 */ { "VARIATION SELECTOR-105",NULL},
/* E0159 */ { "VARIATION SELECTOR-106",NULL},
/* E015A */ { "VARIATION SELECTOR-107",NULL},
/* E015B */ { "VARIATION SELECTOR-108",NULL},
/* E015C */ { "VARIATION SELECTOR-109",NULL},
/* E015D */ { "VARIATION SELECTOR-110",NULL},
/* E015E */ { "VARIATION SELECTOR-111",NULL},
/* E015F */ { "VARIATION SELECTOR-112",NULL},
/* E0160 */ { "VARIATION SELECTOR-113",NULL},
/* E0161 */ { "VARIATION SELECTOR-114",NULL},
/* E0162 */ { "VARIATION SELECTOR-115",NULL},
/* E0163 */ { "VARIATION SELECTOR-116",NULL},
/* E0164 */ { "VARIATION SELECTOR-117",NULL},
/* E0165 */ { "VARIATION SELECTOR-118",NULL},
/* E0166 */ { "VARIATION SELECTOR-119",NULL},
/* E0167 */ { "VARIATION SELECTOR-120",NULL},
/* E0168 */ { "VARIATION SELECTOR-121",NULL},
/* E0169 */ { "VARIATION SELECTOR-122",NULL},
/* E016A */ { "VARIATION SELECTOR-123",NULL},
/* E016B */ { "VARIATION SELECTOR-124",NULL},
/* E016C */ { "VARIATION SELECTOR-125",NULL},
/* E016D */ { "VARIATION SELECTOR-126",NULL},
/* E016E */ { "VARIATION SELECTOR-127",NULL},
/* E016F */ { "VARIATION SELECTOR-128",NULL},
/* E0170 */ { "VARIATION SELECTOR-129",NULL},
/* E0171 */ { "VARIATION SELECTOR-130",NULL},
/* E0172 */ { "VARIATION SELECTOR-131",NULL},
/* E0173 */ { "VARIATION SELECTOR-132",NULL},
/* E0174 */ { "VARIATION SELECTOR-133",NULL},
/* E0175 */ { "VARIATION SELECTOR-134",NULL},
/* E0176 */ { "VARIATION SELECTOR-135",NULL},
/* E0177 */ { "VARIATION SELECTOR-136",NULL},
/* E0178 */ { "VARIATION SELECTOR-137",NULL},
/* E0179 */ { "VARIATION SELECTOR-138",NULL},
/* E017A */ { "VARIATION SELECTOR-139",NULL},
/* E017B */ { "VARIATION SELECTOR-140",NULL},
/* E017C */ { "VARIATION SELECTOR-141",NULL},
/* E017D */ { "VARIATION SELECTOR-142",NULL},
/* E017E */ { "VARIATION SELECTOR-143",NULL},
/* E017F */ { "VARIATION SELECTOR-144",NULL},
/* E0180 */ { "VARIATION SELECTOR-145",NULL},
/* E0181 */ { "VARIATION SELECTOR-146",NULL},
/* E0182 */ { "VARIATION SELECTOR-147",NULL},
/* E0183 */ { "VARIATION SELECTOR-148",NULL},
/* E0184 */ { "VARIATION SELECTOR-149",NULL},
/* E0185 */ { "VARIATION SELECTOR-150",NULL},
/* E0186 */ { "VARIATION SELECTOR-151",NULL},
/* E0187 */ { "VARIATION SELECTOR-152",NULL},
/* E0188 */ { "VARIATION SELECTOR-153",NULL},
/* E0189 */ { "VARIATION SELECTOR-154",NULL},
/* E018A */ { "VARIATION SELECTOR-155",NULL},
/* E018B */ { "VARIATION SELECTOR-156",NULL},
/* E018C */ { "VARIATION SELECTOR-157",NULL},
/* E018D */ { "VARIATION SELECTOR-158",NULL},
/* E018E */ { "VARIATION SELECTOR-159",NULL},
/* E018F */ { "VARIATION SELECTOR-160",NULL},
/* E0190 */ { "VARIATION SELECTOR-161",NULL},
/* E0191 */ { "VARIATION SELECTOR-162",NULL},
/* E0192 */ { "VARIATION SELECTOR-163",NULL},
/* E0193 */ { "VARIATION SELECTOR-164",NULL},
/* E0194 */ { "VARIATION SELECTOR-165",NULL},
/* E0195 */ { "VARIATION SELECTOR-166",NULL},
/* E0196 */ { "VARIATION SELECTOR-167",NULL},
/* E0197 */ { "VARIATION SELECTOR-168",NULL},
/* E0198 */ { "VARIATION SELECTOR-169",NULL},
/* E0199 */ { "VARIATION SELECTOR-170",NULL},
/* E019A */ { "VARIATION SELECTOR-171",NULL},
/* E019B */ { "VARIATION SELECTOR-172",NULL},
/* E019C */ { "VARIATION SELECTOR-173",NULL},
/* E019D */ { "VARIATION SELECTOR-174",NULL},
/* E019E */ { "VARIATION SELECTOR-175",NULL},
/* E019F */ { "VARIATION SELECTOR-176",NULL},
/* E01A0 */ { "VARIATION SELECTOR-177",NULL},
/* E01A1 */ { "VARIATION SELECTOR-178",NULL},
/* E01A2 */ { "VARIATION SELECTOR-179",NULL},
/* E01A3 */ { "VARIATION SELECTOR-180",NULL},
/* E01A4 */ { "VARIATION SELECTOR-181",NULL},
/* E01A5 */ { "VARIATION SELECTOR-182",NULL},
/* E01A6 */ { "VARIATION SELECTOR-183",NULL},
/* E01A7 */ { "VARIATION SELECTOR-184",NULL},
/* E01A8 */ { "VARIATION SELECTOR-185",NULL},
/* E01A9 */ { "VARIATION SELECTOR-186",NULL},
/* E01AA */ { "VARIATION SELECTOR-187",NULL},
/* E01AB */ { "VARIATION SELECTOR-188",NULL},
/* E01AC */ { "VARIATION SELECTOR-189",NULL},
/* E01AD */ { "VARIATION SELECTOR-190",NULL},
/* E01AE */ { "VARIATION SELECTOR-191",NULL},
/* E01AF */ { "VARIATION SELECTOR-192",NULL},
/* E01B0 */ { "VARIATION SELECTOR-193",NULL},
/* E01B1 */ { "VARIATION SELECTOR-194",NULL},
/* E01B2 */ { "VARIATION SELECTOR-195",NULL},
/* E01B3 */ { "VARIATION SELECTOR-196",NULL},
/* E01B4 */ { "VARIATION SELECTOR-197",NULL},
/* E01B5 */ { "VARIATION SELECTOR-198",NULL},
/* E01B6 */ { "VARIATION SELECTOR-199",NULL},
/* E01B7 */ { "VARIATION SELECTOR-200",NULL},
/* E01B8 */ { "VARIATION SELECTOR-201",NULL},
/* E01B9 */ { "VARIATION SELECTOR-202",NULL},
/* E01BA */ { "VARIATION SELECTOR-203",NULL},
/* E01BB */ { "VARIATION SELECTOR-204",NULL},
/* E01BC */ { "VARIATION SELECTOR-205",NULL},
/* E01BD */ { "VARIATION SELECTOR-206",NULL},
/* E01BE */ { "VARIATION SELECTOR-207",NULL},
/* E01BF */ { "VARIATION SELECTOR-208",NULL},
/* E01C0 */ { "VARIATION SELECTOR-209",NULL},
/* E01C1 */ { "VARIATION SELECTOR-210",NULL},
/* E01C2 */ { "VARIATION SELECTOR-211",NULL},
/* E01C3 */ { "VARIATION SELECTOR-212",NULL},
/* E01C4 */ { "VARIATION SELECTOR-213",NULL},
/* E01C5 */ { "VARIATION SELECTOR-214",NULL},
/* E01C6 */ { "VARIATION SELECTOR-215",NULL},
/* E01C7 */ { "VARIATION SELECTOR-216",NULL},
/* E01C8 */ { "VARIATION SELECTOR-217",NULL},
/* E01C9 */ { "VARIATION SELECTOR-218",NULL},
/* E01CA */ { "VARIATION SELECTOR-219",NULL},
/* E01CB */ { "VARIATION SELECTOR-220",NULL},
/* E01CC */ { "VARIATION SELECTOR-221",NULL},
/* E01CD */ { "VARIATION SELECTOR-222",NULL},
/* E01CE */ { "VARIATION SELECTOR-223",NULL},
/* E01CF */ { "VARIATION SELECTOR-224",NULL},
/* E01D0 */ { "VARIATION SELECTOR-225",NULL},
/* E01D1 */ { "VARIATION SELECTOR-226",NULL},
/* E01D2 */ { "VARIATION SELECTOR-227",NULL},
/* E01D3 */ { "VARIATION SELECTOR-228",NULL},
/* E01D4 */ { "VARIATION SELECTOR-229",NULL},
/* E01D5 */ { "VARIATION SELECTOR-230",NULL},
/* E01D6 */ { "VARIATION SELECTOR-231",NULL},
/* E01D7 */ { "VARIATION SELECTOR-232",NULL},
/* E01D8 */ { "VARIATION SELECTOR-233",NULL},
/* E01D9 */ { "VARIATION SELECTOR-234",NULL},
/* E01DA */ { "VARIATION SELECTOR-235",NULL},
/* E01DB */ { "VARIATION SELECTOR-236",NULL},
/* E01DC */ { "VARIATION SELECTOR-237",NULL},
/* E01DD */ { "VARIATION SELECTOR-238",NULL},
/* E01DE */ { "VARIATION SELECTOR-239",NULL},
/* E01DF */ { "VARIATION SELECTOR-240",NULL},
/* E01E0 */ { "VARIATION SELECTOR-241",NULL},
/* E01E1 */ { "VARIATION SELECTOR-242",NULL},
/* E01E2 */ { "VARIATION SELECTOR-243",NULL},
/* E01E3 */ { "VARIATION SELECTOR-244",NULL},
/* E01E4 */ { "VARIATION SELECTOR-245",NULL},
/* E01E5 */ { "VARIATION SELECTOR-246",NULL},
/* E01E6 */ { "VARIATION SELECTOR-247",NULL},
/* E01E7 */ { "VARIATION SELECTOR-248",NULL},
/* E01E8 */ { "VARIATION SELECTOR-249",NULL},
/* E01E9 */ { "VARIATION SELECTOR-250",NULL},
/* E01EA */ { "VARIATION SELECTOR-251",NULL},
/* E01EB */ { "VARIATION SELECTOR-252",NULL},
/* E01EC */ { "VARIATION SELECTOR-253",NULL},
/* E01ED */ { "VARIATION SELECTOR-254",NULL},
/* E01EE */ { "VARIATION SELECTOR-255",NULL},
/* E01EF */ { "VARIATION SELECTOR-256",NULL},
/* E01F0 */ { NULL,NULL},
/* E01F1 */ { NULL,NULL},
/* E01F2 */ { NULL,NULL},
/* E01F3 */ { NULL,NULL},
/* E01F4 */ { NULL,NULL},
/* E01F5 */ { NULL,NULL},
/* E01F6 */ { NULL,NULL},
/* E01F7 */ { NULL,NULL},
/* E01F8 */ { NULL,NULL},
/* E01F9 */ { NULL,NULL},
/* E01FA */ { NULL,NULL},
/* E01FB */ { NULL,NULL},
/* E01FC */ { NULL,NULL},
/* E01FD */ { NULL,NULL},
/* E01FE */ { NULL,NULL},
/* E01FF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot * const una_00[] = {
	una_00_00,
	una_00_01,
	una_00_02,
	una_00_03,
	una_00_04,
	una_00_05,
	una_00_06,
	una_00_07,
	una_00_08,
	una_00_09,
	una_00_0A,
	una_00_0B,
	una_00_0C,
	una_00_0D,
	una_00_0E,
	una_00_0F,
	una_00_10,
	una_00_11,
	una_00_12,
	una_00_13,
	una_00_14,
	una_00_15,
	una_00_16,
	una_00_17,
	una_00_18,
	una_00_19,
	una_00_1A,
	una_00_1B,
	una_00_1C,
	una_00_1D,
	una_00_1E,
	una_00_1F,
	una_00_20,
	una_00_21,
	una_00_22,
	una_00_23,
	una_00_24,
	una_00_25,
	una_00_26,
	una_00_27,
	una_00_28,
	una_00_29,
	una_00_2A,
	una_00_2B,
	una_00_2C,
	una_00_2D,
	una_00_2E,
	una_00_2F,
	una_00_30,
	una_00_31,
	una_00_32,
	una_00_33,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	una_00_4D,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	una_00_A0,
	una_00_A1,
	una_00_A2,
	una_00_A3,
	una_00_A4,
	una_00_A5,
	una_00_A6,
	una_00_A7,
	una_00_A8,
	una_00_A9,
	una_00_AA,
	una_00_AB,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	una_00_D7,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	una_00_F9,
	una_00_FA,
	una_00_FB,
	una_00_FC,
	una_00_FD,
	una_00_FE,
	una_00_FF
};

UN_DLL_LOCAL
static const struct unicode_nameannot * const una_01[] = {
	una_01_00,
	una_01_01,
	una_01_02,
	una_01_03,
	una_01_04,
	una_01_05,
	una_01_06,
	una_01_07,
	una_01_08,
	una_01_09,
	una_01_0A,
	una_01_0B,
	una_01_0C,
	una_01_0D,
	una_01_0E,
	una_01_0F,
	una_01_10,
	una_01_11,
	una_01_12,
	una_01_13,
	una_01_14,
	una_01_15,
	una_01_16,
	una_01_17,
	una_01_18,
	una_01_19,
	una_01_1A,
	una_01_1B,
	una_01_1C,
	una_01_1D,
	una_01_1E,
	una_01_1F,
	una_01_20,
	una_01_21,
	una_01_22,
	una_01_23,
	una_01_24,
	una_01_25,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	una_01_2F,
	una_01_30,
	una_01_31,
	una_01_32,
	una_01_33,
	una_01_34,
	una_01_35,
	una_01_36,
	una_01_37,
	una_01_38,
	una_01_39,
	una_01_3A,
	una_01_3B,
	una_01_3C,
	una_01_3D,
	una_01_3E,
	una_01_3F,
	una_01_40,
	una_01_41,
	una_01_42,
	una_01_43,
	una_01_44,
	una_01_45,
	una_01_46,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	una_01_61,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	una_01_68,
	una_01_69,
	una_01_6A,
	una_01_6B,
	nullarray,
	una_01_6D,
	una_01_6E,
	una_01_6F,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	una_01_88,
	una_01_89,
	una_01_8A,
	una_01_8B,
	una_01_8C,
	una_01_8D,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	una_01_AF,
	una_01_B0,
	una_01_B1,
	una_01_B2,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	una_01_BC,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	una_01_CC,
	una_01_CD,
	una_01_CE,
	una_01_CF,
	una_01_D0,
	una_01_D1,
	una_01_D2,
	una_01_D3,
	una_01_D4,
	una_01_D5,
	una_01_D6,
	una_01_D7,
	una_01_D8,
	una_01_D9,
	una_01_DA,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	una_01_DF,
	una_01_E0,
	una_01_E1,
	una_01_E2,
	nullarray,
	una_01_E4,
	una_01_E5,
	una_01_E6,
	una_01_E7,
	una_01_E8,
	una_01_E9,
	nullarray,
	nullarray,
	una_01_EC,
	una_01_ED,
	una_01_EE,
	nullarray,
	una_01_F0,
	una_01_F1,
	una_01_F2,
	una_01_F3,
	una_01_F4,
	una_01_F5,
	una_01_F6,
	una_01_F7,
	una_01_F8,
	una_01_F9,
	una_01_FA,
	una_01_FB,
	nullarray,
	nullarray,
	nullarray,
	nullarray2
};

UN_DLL_LOCAL
static const struct unicode_nameannot * const una_02[] = {
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	una_02_F8,
	una_02_F9,
	una_02_FA,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray2
};

UN_DLL_LOCAL
static const struct unicode_nameannot * const una_0E[] = {
	una_0E_00,
	una_0E_01,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray,
	nullarray2
};

UN_DLL_EXPORT
const struct unicode_nameannot * const *const UnicodeNameAnnot[] = {
	una_00,
	una_01,
	una_02,
	nullnullarray,
	nullnullarray,
	nullnullarray,
	nullnullarray,
	nullnullarray,
	nullnullarray,
	nullnullarray,
	nullnullarray,
	nullnullarray,
	nullnullarray,
	nullnullarray,
	una_0E,
	nullnullarray,
	nullnullarray,
	nullnullarray,
	nullnullarray,
	nullnullarray,
	nullnullarray,
	nullnullarray,
	nullnullarray,
	nullnullarray,
	nullnullarray,
	nullnullarray,
	nullnullarray,
	nullnullarray,
	nullnullarray,
	nullnullarray,
	nullnullarray,
	nullnullarray
};

